{
 "cells": [
  {
   "cell_type": "markdown",
   "id": "97919192",
   "metadata": {
    "slideshow": {
     "slide_type": "slide"
    }
   },
   "source": [
    "# Blade Aerodynamics"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "6c2c37fd",
   "metadata": {
    "slideshow": {
     "slide_type": "skip"
    }
   },
   "source": [
    "From BEMT, it is evident that the overall rotor performance is a cumulative performance of each section of the rotor blades. Indeed, real rotor performance does depend on the aerodynamic performance parameters (Cl, Cd, Cm)[^Plotlylimitations] of the airfoil sections that make up the rotor blades. It is then helpful to revisit how these fundamental performance characterisitics of an airfoil vary with flow conditions encountered on a real rotor. \n",
    "[^Plotlylimitations]: The Plotly library used here for generating the plots is a great tool for interactively visualising data. However, it isn't compatible with mathematical notation used to write down symbols. For this reason, the use of symbols on this page has been avoided. \n"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "6dbfbd66",
   "metadata": {
    "slideshow": {
     "slide_type": "slide"
    }
   },
   "source": [
    "## Airfoil Tables"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "30576f66",
   "metadata": {
    "slideshow": {
     "slide_type": "skip"
    }
   },
   "source": [
    "Airfoil tables, as they are called in rotorcraft analyses jargon, refer to a complete database of airfoil performance parameters - Cl, Cd and Cm -  over a range of Mach numbers and angles of attack. It is worth noting that some of the most popular softwares/codes used for analysing rotorcraft performance loads such as CAMRAD II, RCAS, CHARM, Dymore etc. use an airfoil tables-based solution strategy for rotor analyses. This means that the blade section aerodynamics is solved using these airfoil tables similar to the BEMT formulation. There are of course additional models that each of these codes implements in order to solve a high-fidelity formulation of the physical rotor system, but this should re-emphasise the relevance of BEMT analyses in obtaining the blade section loads. Such airfoil aerodynamic performance data can be generated either using CFD analyses or using experimental measurements. The former approach is usually adopted since it is the more economically cheaper option. \n",
    "\n",
    "The airfoil performance over the whole spectrum of Mach numbers and angles of attack, that could possibly be encountered in flight, is contained within these airfoil tables. Typically, the Mach number range used is 0 to 1.0 and the angle of attack range used is -180° to 180°. "
   ]
  },
  {
   "cell_type": "markdown",
   "id": "41fe70ce",
   "metadata": {
    "slideshow": {
     "slide_type": "slide"
    }
   },
   "source": [
    "### CFD"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "61b6ddcf",
   "metadata": {
    "slideshow": {
     "slide_type": "skip"
    }
   },
   "source": [
    "The figures below graphically show the data contained within a typical airfoil table dataset - in this case the airfoil tables used for analysis of the Bo 105 helicopter. The variation of airfoil Cl, Cd and Cm as a function of the angle of attack and Mach number for the NACA23012 are shown. These are based on the work of Ref. {cite}`AA_C1` [^AmineAirfoilTables].\n",
    "\n",
    "[^AmineAirfoilTables]: These results were generated by solving the RANS equations using the CFD solver TAU by <a href=\"https://www.asg.ed.tum.de/ht/mitarbeiter/amine-abdelmoula-msc/\">Amine Abdelmoula</a> as part of his PhD. "
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 1,
   "id": "b834c566",
   "metadata": {
    "hide_input": true,
    "slideshow": {
     "slide_type": "-"
    },
    "tags": [
     "hide-input"
    ]
   },
   "outputs": [
    {
     "data": {
      "text/html": [
       "        <script type=\"text/javascript\">\n",
       "        window.PlotlyConfig = {MathJaxConfig: 'local'};\n",
       "        if (window.MathJax) {MathJax.Hub.Config({SVG: {font: \"STIX-Web\"}});}\n",
       "        if (typeof require !== 'undefined') {\n",
       "        require.undef(\"plotly\");\n",
       "        define('plotly', function(require, exports, module) {\n",
       "            /**\n",
       "* plotly.js v2.2.0\n",
       "* Copyright 2012-2021, Plotly, Inc.\n",
       "* All rights reserved.\n",
       "* Licensed under the MIT license\n",
       "*/\n",
       "!function(t){if(\"object\"==typeof exports&&\"undefined\"!=typeof module)module.exports=t();else if(\"function\"==typeof define&&define.amd)define([],t);else{(\"undefined\"!=typeof window?window:\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:this).Plotly=t()}}((function(){return function t(e,r,n){function i(o,s){if(!r[o]){if(!e[o]){var l=\"function\"==typeof require&&require;if(!s&&l)return l(o,!0);if(a)return a(o,!0);var c=new Error(\"Cannot find module '\"+o+\"'\");throw c.code=\"MODULE_NOT_FOUND\",c}var u=r[o]={exports:{}};e[o][0].call(u.exports,(function(t){return i(e[o][1][t]||t)}),u,u.exports,t,e,r,n)}return r[o].exports}for(var a=\"function\"==typeof require&&require,o=0;o<n.length;o++)i(n[o]);return i}({1:[function(t,e,r){\"use strict\";var n=t(\"../src/lib\"),i={\"X,X div\":'direction:ltr;font-family:\"Open Sans\",verdana,arial,sans-serif;margin:0;padding:0;',\"X input,X button\":'font-family:\"Open Sans\",verdana,arial,sans-serif;',\"X input:focus,X button:focus\":\"outline:none;\",\"X a\":\"text-decoration:none;\",\"X a:hover\":\"text-decoration:none;\",\"X .crisp\":\"shape-rendering:crispEdges;\",\"X .user-select-none\":\"-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;-o-user-select:none;user-select:none;\",\"X svg\":\"overflow:hidden;\",\"X svg a\":\"fill:#447adb;\",\"X svg a:hover\":\"fill:#3c6dc5;\",\"X .main-svg\":\"position:absolute;top:0;left:0;pointer-events:none;\",\"X .main-svg .draglayer\":\"pointer-events:all;\",\"X .cursor-default\":\"cursor:default;\",\"X .cursor-pointer\":\"cursor:pointer;\",\"X .cursor-crosshair\":\"cursor:crosshair;\",\"X .cursor-move\":\"cursor:move;\",\"X .cursor-col-resize\":\"cursor:col-resize;\",\"X .cursor-row-resize\":\"cursor:row-resize;\",\"X .cursor-ns-resize\":\"cursor:ns-resize;\",\"X .cursor-ew-resize\":\"cursor:ew-resize;\",\"X .cursor-sw-resize\":\"cursor:sw-resize;\",\"X .cursor-s-resize\":\"cursor:s-resize;\",\"X .cursor-se-resize\":\"cursor:se-resize;\",\"X .cursor-w-resize\":\"cursor:w-resize;\",\"X .cursor-e-resize\":\"cursor:e-resize;\",\"X .cursor-nw-resize\":\"cursor:nw-resize;\",\"X .cursor-n-resize\":\"cursor:n-resize;\",\"X .cursor-ne-resize\":\"cursor:ne-resize;\",\"X .cursor-grab\":\"cursor:-webkit-grab;cursor:grab;\",\"X .modebar\":\"position:absolute;top:2px;right:2px;\",\"X .ease-bg\":\"-webkit-transition:background-color .3s ease 0s;-moz-transition:background-color .3s ease 0s;-ms-transition:background-color .3s ease 0s;-o-transition:background-color .3s ease 0s;transition:background-color .3s ease 0s;\",\"X .modebar--hover>:not(.watermark)\":\"opacity:0;-webkit-transition:opacity .3s ease 0s;-moz-transition:opacity .3s ease 0s;-ms-transition:opacity .3s ease 0s;-o-transition:opacity .3s ease 0s;transition:opacity .3s ease 0s;\",\"X:hover .modebar--hover .modebar-group\":\"opacity:1;\",\"X .modebar-group\":\"float:left;display:inline-block;box-sizing:border-box;padding-left:8px;position:relative;vertical-align:middle;white-space:nowrap;\",\"X .modebar-btn\":\"position:relative;font-size:16px;padding:3px 4px;height:22px;cursor:pointer;line-height:normal;box-sizing:border-box;\",\"X .modebar-btn svg\":\"position:relative;top:2px;\",\"X .modebar.vertical\":\"display:flex;flex-direction:column;flex-wrap:wrap;align-content:flex-end;max-height:100%;\",\"X .modebar.vertical svg\":\"top:-1px;\",\"X .modebar.vertical .modebar-group\":\"display:block;float:none;padding-left:0px;padding-bottom:8px;\",\"X .modebar.vertical .modebar-group .modebar-btn\":\"display:block;text-align:center;\",\"X [data-title]:before,X [data-title]:after\":\"position:absolute;-webkit-transform:translate3d(0, 0, 0);-moz-transform:translate3d(0, 0, 0);-ms-transform:translate3d(0, 0, 0);-o-transform:translate3d(0, 0, 0);transform:translate3d(0, 0, 0);display:none;opacity:0;z-index:1001;pointer-events:none;top:110%;right:50%;\",\"X [data-title]:hover:before,X [data-title]:hover:after\":\"display:block;opacity:1;\",\"X [data-title]:before\":'content:\"\";position:absolute;background:transparent;border:6px solid transparent;z-index:1002;margin-top:-12px;border-bottom-color:#69738a;margin-right:-6px;',\"X [data-title]:after\":\"content:attr(data-title);background:#69738a;color:#fff;padding:8px 10px;font-size:12px;line-height:12px;white-space:nowrap;margin-right:-18px;border-radius:2px;\",\"X .vertical [data-title]:before,X .vertical [data-title]:after\":\"top:0%;right:200%;\",\"X .vertical [data-title]:before\":\"border:6px solid transparent;border-left-color:#69738a;margin-top:8px;margin-right:-30px;\",\"X .select-outline\":\"fill:none;stroke-width:1;shape-rendering:crispEdges;\",\"X .select-outline-1\":\"stroke:#fff;\",\"X .select-outline-2\":\"stroke:#000;stroke-dasharray:2px 2px;\",Y:'font-family:\"Open Sans\",verdana,arial,sans-serif;position:fixed;top:50px;right:20px;z-index:10000;font-size:10pt;max-width:180px;',\"Y p\":\"margin:0;\",\"Y .notifier-note\":\"min-width:180px;max-width:250px;border:1px solid #fff;z-index:3000;margin:0;background-color:#8c97af;background-color:rgba(140,151,175,.9);color:#fff;padding:10px;overflow-wrap:break-word;word-wrap:break-word;-ms-hyphens:auto;-webkit-hyphens:auto;hyphens:auto;\",\"Y .notifier-close\":\"color:#fff;opacity:.8;float:right;padding:0 5px;background:none;border:none;font-size:20px;font-weight:bold;line-height:20px;\",\"Y .notifier-close:hover\":\"color:#444;text-decoration:none;cursor:pointer;\"};for(var a in i){var o=a.replace(/^,/,\" ,\").replace(/X/g,\".js-plotly-plot .plotly\").replace(/Y/g,\".plotly-notifier\");n.addStyleRule(o,i[a])}},{\"../src/lib\":799}],2:[function(t,e,r){\"use strict\";e.exports=t(\"../src/transforms/aggregate\")},{\"../src/transforms/aggregate\":1395}],3:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/bar\")},{\"../src/traces/bar\":945}],4:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/barpolar\")},{\"../src/traces/barpolar\":958}],5:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/box\")},{\"../src/traces/box\":968}],6:[function(t,e,r){\"use strict\";e.exports=t(\"../src/components/calendars\")},{\"../src/components/calendars\":660}],7:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/candlestick\")},{\"../src/traces/candlestick\":977}],8:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/carpet\")},{\"../src/traces/carpet\":996}],9:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/choropleth\")},{\"../src/traces/choropleth\":1010}],10:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/choroplethmapbox\")},{\"../src/traces/choroplethmapbox\":1017}],11:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/cone\")},{\"../src/traces/cone\":1023}],12:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/contour\")},{\"../src/traces/contour\":1038}],13:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/contourcarpet\")},{\"../src/traces/contourcarpet\":1049}],14:[function(t,e,r){\"use strict\";e.exports=t(\"../src/core\")},{\"../src/core\":777}],15:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/densitymapbox\")},{\"../src/traces/densitymapbox\":1057}],16:[function(t,e,r){\"use strict\";e.exports=t(\"../src/transforms/filter\")},{\"../src/transforms/filter\":1396}],17:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/funnel\")},{\"../src/traces/funnel\":1067}],18:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/funnelarea\")},{\"../src/traces/funnelarea\":1076}],19:[function(t,e,r){\"use strict\";e.exports=t(\"../src/transforms/groupby\")},{\"../src/transforms/groupby\":1397}],20:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/heatmap\")},{\"../src/traces/heatmap\":1089}],21:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/heatmapgl\")},{\"../src/traces/heatmapgl\":1099}],22:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/histogram\")},{\"../src/traces/histogram\":1111}],23:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/histogram2d\")},{\"../src/traces/histogram2d\":1117}],24:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/histogram2dcontour\")},{\"../src/traces/histogram2dcontour\":1121}],25:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/icicle\")},{\"../src/traces/icicle\":1127}],26:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/image\")},{\"../src/traces/image\":1140}],27:[function(t,e,r){\"use strict\";var n=t(\"./core\");n.register([t(\"./bar\"),t(\"./box\"),t(\"./heatmap\"),t(\"./histogram\"),t(\"./histogram2d\"),t(\"./histogram2dcontour\"),t(\"./contour\"),t(\"./scatterternary\"),t(\"./violin\"),t(\"./funnel\"),t(\"./waterfall\"),t(\"./image\"),t(\"./pie\"),t(\"./sunburst\"),t(\"./treemap\"),t(\"./icicle\"),t(\"./funnelarea\"),t(\"./scatter3d\"),t(\"./surface\"),t(\"./isosurface\"),t(\"./volume\"),t(\"./mesh3d\"),t(\"./cone\"),t(\"./streamtube\"),t(\"./scattergeo\"),t(\"./choropleth\"),t(\"./scattergl\"),t(\"./splom\"),t(\"./pointcloud\"),t(\"./heatmapgl\"),t(\"./parcoords\"),t(\"./parcats\"),t(\"./scattermapbox\"),t(\"./choroplethmapbox\"),t(\"./densitymapbox\"),t(\"./sankey\"),t(\"./indicator\"),t(\"./table\"),t(\"./carpet\"),t(\"./scattercarpet\"),t(\"./contourcarpet\"),t(\"./ohlc\"),t(\"./candlestick\"),t(\"./scatterpolar\"),t(\"./scatterpolargl\"),t(\"./barpolar\"),t(\"./aggregate\"),t(\"./filter\"),t(\"./groupby\"),t(\"./sort\"),t(\"./calendars\")]),e.exports=n},{\"./aggregate\":2,\"./bar\":3,\"./barpolar\":4,\"./box\":5,\"./calendars\":6,\"./candlestick\":7,\"./carpet\":8,\"./choropleth\":9,\"./choroplethmapbox\":10,\"./cone\":11,\"./contour\":12,\"./contourcarpet\":13,\"./core\":14,\"./densitymapbox\":15,\"./filter\":16,\"./funnel\":17,\"./funnelarea\":18,\"./groupby\":19,\"./heatmap\":20,\"./heatmapgl\":21,\"./histogram\":22,\"./histogram2d\":23,\"./histogram2dcontour\":24,\"./icicle\":25,\"./image\":26,\"./indicator\":28,\"./isosurface\":29,\"./mesh3d\":30,\"./ohlc\":31,\"./parcats\":32,\"./parcoords\":33,\"./pie\":34,\"./pointcloud\":35,\"./sankey\":36,\"./scatter3d\":37,\"./scattercarpet\":38,\"./scattergeo\":39,\"./scattergl\":40,\"./scattermapbox\":41,\"./scatterpolar\":42,\"./scatterpolargl\":43,\"./scatterternary\":44,\"./sort\":45,\"./splom\":46,\"./streamtube\":47,\"./sunburst\":48,\"./surface\":49,\"./table\":50,\"./treemap\":51,\"./violin\":52,\"./volume\":53,\"./waterfall\":54}],28:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/indicator\")},{\"../src/traces/indicator\":1148}],29:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/isosurface\")},{\"../src/traces/isosurface\":1154}],30:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/mesh3d\")},{\"../src/traces/mesh3d\":1159}],31:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/ohlc\")},{\"../src/traces/ohlc\":1164}],32:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/parcats\")},{\"../src/traces/parcats\":1173}],33:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/parcoords\")},{\"../src/traces/parcoords\":1183}],34:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/pie\")},{\"../src/traces/pie\":1194}],35:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/pointcloud\")},{\"../src/traces/pointcloud\":1203}],36:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/sankey\")},{\"../src/traces/sankey\":1209}],37:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/scatter3d\")},{\"../src/traces/scatter3d\":1247}],38:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/scattercarpet\")},{\"../src/traces/scattercarpet\":1254}],39:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/scattergeo\")},{\"../src/traces/scattergeo\":1262}],40:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/scattergl\")},{\"../src/traces/scattergl\":1275}],41:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/scattermapbox\")},{\"../src/traces/scattermapbox\":1285}],42:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/scatterpolar\")},{\"../src/traces/scatterpolar\":1293}],43:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/scatterpolargl\")},{\"../src/traces/scatterpolargl\":1300}],44:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/scatterternary\")},{\"../src/traces/scatterternary\":1308}],45:[function(t,e,r){\"use strict\";e.exports=t(\"../src/transforms/sort\")},{\"../src/transforms/sort\":1399}],46:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/splom\")},{\"../src/traces/splom\":1317}],47:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/streamtube\")},{\"../src/traces/streamtube\":1325}],48:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/sunburst\")},{\"../src/traces/sunburst\":1333}],49:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/surface\")},{\"../src/traces/surface\":1342}],50:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/table\")},{\"../src/traces/table\":1350}],51:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/treemap\")},{\"../src/traces/treemap\":1361}],52:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/violin\")},{\"../src/traces/violin\":1374}],53:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/volume\")},{\"../src/traces/volume\":1382}],54:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/waterfall\")},{\"../src/traces/waterfall\":1390}],55:[function(t,e,r){\"use strict\";e.exports=function(t){var e=(t=t||{}).eye||[0,0,1],r=t.center||[0,0,0],s=t.up||[0,1,0],l=t.distanceLimits||[0,1/0],c=t.mode||\"turntable\",u=n(),f=i(),h=a();return u.setDistanceLimits(l[0],l[1]),u.lookAt(0,e,r,s),f.setDistanceLimits(l[0],l[1]),f.lookAt(0,e,r,s),h.setDistanceLimits(l[0],l[1]),h.lookAt(0,e,r,s),new o({turntable:u,orbit:f,matrix:h},c)};var n=t(\"turntable-camera-controller\"),i=t(\"orbit-camera-controller\"),a=t(\"matrix-camera-controller\");function o(t,e){this._controllerNames=Object.keys(t),this._controllerList=this._controllerNames.map((function(e){return t[e]})),this._mode=e,this._active=t[e],this._active||(this._mode=\"turntable\",this._active=t.turntable),this.modes=this._controllerNames,this.computedMatrix=this._active.computedMatrix,this.computedEye=this._active.computedEye,this.computedUp=this._active.computedUp,this.computedCenter=this._active.computedCenter,this.computedRadius=this._active.computedRadius}var s=o.prototype;[[\"flush\",1],[\"idle\",1],[\"lookAt\",4],[\"rotate\",4],[\"pan\",4],[\"translate\",4],[\"setMatrix\",2],[\"setDistanceLimits\",2],[\"setDistance\",2]].forEach((function(t){for(var e=t[0],r=[],n=0;n<t[1];++n)r.push(\"a\"+n);var i=\"var cc=this._controllerList;for(var i=0;i<cc.length;++i){cc[i].\"+t[0]+\"(\"+r.join()+\")}\";s[e]=Function.apply(null,r.concat(i))})),s.recalcMatrix=function(t){this._active.recalcMatrix(t)},s.getDistance=function(t){return this._active.getDistance(t)},s.getDistanceLimits=function(t){return this._active.getDistanceLimits(t)},s.lastT=function(){return this._active.lastT()},s.setMode=function(t){if(t!==this._mode){var e=this._controllerNames.indexOf(t);if(!(e<0)){var r=this._active,n=this._controllerList[e],i=Math.max(r.lastT(),n.lastT());r.recalcMatrix(i),n.setMatrix(i,r.computedMatrix),this._active=n,this._mode=t,this.computedMatrix=this._active.computedMatrix,this.computedEye=this._active.computedEye,this.computedUp=this._active.computedUp,this.computedCenter=this._active.computedCenter,this.computedRadius=this._active.computedRadius}}},s.getMode=function(){return this._mode}},{\"matrix-camera-controller\":464,\"orbit-camera-controller\":485,\"turntable-camera-controller\":599}],56:[function(t,e,r){!function(n,i){\"object\"==typeof r&&void 0!==e?i(r,t(\"d3-array\"),t(\"d3-collection\"),t(\"d3-shape\"),t(\"elementary-circuits-directed-graph\")):i(n.d3=n.d3||{},n.d3,n.d3,n.d3,null)}(this,(function(t,e,r,n,i){\"use strict\";function a(t){return t.target.depth}function o(t,e){return t.sourceLinks.length?t.depth:e-1}function s(t){return function(){return t}}i=i&&i.hasOwnProperty(\"default\")?i.default:i;var l=\"function\"==typeof Symbol&&\"symbol\"==typeof Symbol.iterator?function(t){return typeof t}:function(t){return t&&\"function\"==typeof Symbol&&t.constructor===Symbol&&t!==Symbol.prototype?\"symbol\":typeof t};function c(t,e){return f(t.source,e.source)||t.index-e.index}function u(t,e){return f(t.target,e.target)||t.index-e.index}function f(t,e){return t.partOfCycle===e.partOfCycle?t.y0-e.y0:\"top\"===t.circularLinkType||\"bottom\"===e.circularLinkType?-1:1}function h(t){return t.value}function p(t){return(t.y0+t.y1)/2}function d(t){return p(t.source)}function m(t){return p(t.target)}function g(t){return t.index}function v(t){return t.nodes}function y(t){return t.links}function x(t,e){var r=t.get(e);if(!r)throw new Error(\"missing: \"+e);return r}function b(t,e){return e(t)}function _(t,e,r){var n=0;if(null===r){for(var a=[],o=0;o<t.links.length;o++){var s=t.links[o],l=s.source.index,c=s.target.index;a[l]||(a[l]=[]),a[c]||(a[c]=[]),-1===a[l].indexOf(c)&&a[l].push(c)}var u=i(a);u.sort((function(t,e){return t.length-e.length}));var f={};for(o=0;o<u.length;o++){var h=u[o].slice(-2);f[h[0]]||(f[h[0]]={}),f[h[0]][h[1]]=!0}t.links.forEach((function(t){var e=t.target.index,r=t.source.index;e===r||f[r]&&f[r][e]?(t.circular=!0,t.circularLinkID=n,n+=1):t.circular=!1}))}else t.links.forEach((function(t){t.source[r]<t.target[r]?t.circular=!1:(t.circular=!0,t.circularLinkID=n,n+=1)}))}function w(t,e){var r=0,n=0;t.links.forEach((function(i){i.circular&&(i.source.circularLinkType||i.target.circularLinkType?i.circularLinkType=i.source.circularLinkType?i.source.circularLinkType:i.target.circularLinkType:i.circularLinkType=r<n?\"top\":\"bottom\",\"top\"==i.circularLinkType?r+=1:n+=1,t.nodes.forEach((function(t){b(t,e)!=b(i.source,e)&&b(t,e)!=b(i.target,e)||(t.circularLinkType=i.circularLinkType)})))})),t.links.forEach((function(t){t.circular&&(t.source.circularLinkType==t.target.circularLinkType&&(t.circularLinkType=t.source.circularLinkType),H(t,e)&&(t.circularLinkType=t.source.circularLinkType))}))}function T(t){var e=Math.abs(t.y1-t.y0),r=Math.abs(t.target.x0-t.source.x1);return Math.atan(r/e)}function k(t,e){var r=0;t.sourceLinks.forEach((function(t){r=t.circular&&!H(t,e)?r+1:r}));var n=0;return t.targetLinks.forEach((function(t){n=t.circular&&!H(t,e)?n+1:n})),r+n}function M(t){var e=t.source.sourceLinks,r=0;e.forEach((function(t){r=t.circular?r+1:r}));var n=t.target.targetLinks,i=0;return n.forEach((function(t){i=t.circular?i+1:i})),!(r>1||i>1)}function A(t,e,r){return t.sort(E),t.forEach((function(n,i){var a,o,s=0;if(H(n,r)&&M(n))n.circularPathData.verticalBuffer=s+n.width/2;else{for(var l=0;l<i;l++)if(a=t[i],o=t[l],!(a.source.column<o.target.column||a.target.column>o.source.column)){var c=t[l].circularPathData.verticalBuffer+t[l].width/2+e;s=c>s?c:s}n.circularPathData.verticalBuffer=s+n.width/2}})),t}function S(t,r,i,a){var o=e.min(t.links,(function(t){return t.source.y0}));t.links.forEach((function(t){t.circular&&(t.circularPathData={})})),A(t.links.filter((function(t){return\"top\"==t.circularLinkType})),r,a),A(t.links.filter((function(t){return\"bottom\"==t.circularLinkType})),r,a),t.links.forEach((function(e){if(e.circular){if(e.circularPathData.arcRadius=e.width+10,e.circularPathData.leftNodeBuffer=5,e.circularPathData.rightNodeBuffer=5,e.circularPathData.sourceWidth=e.source.x1-e.source.x0,e.circularPathData.sourceX=e.source.x0+e.circularPathData.sourceWidth,e.circularPathData.targetX=e.target.x0,e.circularPathData.sourceY=e.y0,e.circularPathData.targetY=e.y1,H(e,a)&&M(e))e.circularPathData.leftSmallArcRadius=10+e.width/2,e.circularPathData.leftLargeArcRadius=10+e.width/2,e.circularPathData.rightSmallArcRadius=10+e.width/2,e.circularPathData.rightLargeArcRadius=10+e.width/2,\"bottom\"==e.circularLinkType?(e.circularPathData.verticalFullExtent=e.source.y1+25+e.circularPathData.verticalBuffer,e.circularPathData.verticalLeftInnerExtent=e.circularPathData.verticalFullExtent-e.circularPathData.leftLargeArcRadius,e.circularPathData.verticalRightInnerExtent=e.circularPathData.verticalFullExtent-e.circularPathData.rightLargeArcRadius):(e.circularPathData.verticalFullExtent=e.source.y0-25-e.circularPathData.verticalBuffer,e.circularPathData.verticalLeftInnerExtent=e.circularPathData.verticalFullExtent+e.circularPathData.leftLargeArcRadius,e.circularPathData.verticalRightInnerExtent=e.circularPathData.verticalFullExtent+e.circularPathData.rightLargeArcRadius);else{var s=e.source.column,l=e.circularLinkType,c=t.links.filter((function(t){return t.source.column==s&&t.circularLinkType==l}));\"bottom\"==e.circularLinkType?c.sort(C):c.sort(L);var u=0;c.forEach((function(t,n){t.circularLinkID==e.circularLinkID&&(e.circularPathData.leftSmallArcRadius=10+e.width/2+u,e.circularPathData.leftLargeArcRadius=10+e.width/2+n*r+u),u+=t.width})),s=e.target.column,c=t.links.filter((function(t){return t.target.column==s&&t.circularLinkType==l})),\"bottom\"==e.circularLinkType?c.sort(I):c.sort(P),u=0,c.forEach((function(t,n){t.circularLinkID==e.circularLinkID&&(e.circularPathData.rightSmallArcRadius=10+e.width/2+u,e.circularPathData.rightLargeArcRadius=10+e.width/2+n*r+u),u+=t.width})),\"bottom\"==e.circularLinkType?(e.circularPathData.verticalFullExtent=Math.max(i,e.source.y1,e.target.y1)+25+e.circularPathData.verticalBuffer,e.circularPathData.verticalLeftInnerExtent=e.circularPathData.verticalFullExtent-e.circularPathData.leftLargeArcRadius,e.circularPathData.verticalRightInnerExtent=e.circularPathData.verticalFullExtent-e.circularPathData.rightLargeArcRadius):(e.circularPathData.verticalFullExtent=o-25-e.circularPathData.verticalBuffer,e.circularPathData.verticalLeftInnerExtent=e.circularPathData.verticalFullExtent+e.circularPathData.leftLargeArcRadius,e.circularPathData.verticalRightInnerExtent=e.circularPathData.verticalFullExtent+e.circularPathData.rightLargeArcRadius)}e.circularPathData.leftInnerExtent=e.circularPathData.sourceX+e.circularPathData.leftNodeBuffer,e.circularPathData.rightInnerExtent=e.circularPathData.targetX-e.circularPathData.rightNodeBuffer,e.circularPathData.leftFullExtent=e.circularPathData.sourceX+e.circularPathData.leftLargeArcRadius+e.circularPathData.leftNodeBuffer,e.circularPathData.rightFullExtent=e.circularPathData.targetX-e.circularPathData.rightLargeArcRadius-e.circularPathData.rightNodeBuffer}if(e.circular)e.path=function(t){var e=\"\";e=\"top\"==t.circularLinkType?\"M\"+t.circularPathData.sourceX+\" \"+t.circularPathData.sourceY+\" L\"+t.circularPathData.leftInnerExtent+\" \"+t.circularPathData.sourceY+\" A\"+t.circularPathData.leftLargeArcRadius+\" \"+t.circularPathData.leftSmallArcRadius+\" 0 0 0 \"+t.circularPathData.leftFullExtent+\" \"+(t.circularPathData.sourceY-t.circularPathData.leftSmallArcRadius)+\" L\"+t.circularPathData.leftFullExtent+\" \"+t.circularPathData.verticalLeftInnerExtent+\" A\"+t.circularPathData.leftLargeArcRadius+\" \"+t.circularPathData.leftLargeArcRadius+\" 0 0 0 \"+t.circularPathData.leftInnerExtent+\" \"+t.circularPathData.verticalFullExtent+\" L\"+t.circularPathData.rightInnerExtent+\" \"+t.circularPathData.verticalFullExtent+\" A\"+t.circularPathData.rightLargeArcRadius+\" \"+t.circularPathData.rightLargeArcRadius+\" 0 0 0 \"+t.circularPathData.rightFullExtent+\" \"+t.circularPathData.verticalRightInnerExtent+\" L\"+t.circularPathData.rightFullExtent+\" \"+(t.circularPathData.targetY-t.circularPathData.rightSmallArcRadius)+\" A\"+t.circularPathData.rightLargeArcRadius+\" \"+t.circularPathData.rightSmallArcRadius+\" 0 0 0 \"+t.circularPathData.rightInnerExtent+\" \"+t.circularPathData.targetY+\" L\"+t.circularPathData.targetX+\" \"+t.circularPathData.targetY:\"M\"+t.circularPathData.sourceX+\" \"+t.circularPathData.sourceY+\" L\"+t.circularPathData.leftInnerExtent+\" \"+t.circularPathData.sourceY+\" A\"+t.circularPathData.leftLargeArcRadius+\" \"+t.circularPathData.leftSmallArcRadius+\" 0 0 1 \"+t.circularPathData.leftFullExtent+\" \"+(t.circularPathData.sourceY+t.circularPathData.leftSmallArcRadius)+\" L\"+t.circularPathData.leftFullExtent+\" \"+t.circularPathData.verticalLeftInnerExtent+\" A\"+t.circularPathData.leftLargeArcRadius+\" \"+t.circularPathData.leftLargeArcRadius+\" 0 0 1 \"+t.circularPathData.leftInnerExtent+\" \"+t.circularPathData.verticalFullExtent+\" L\"+t.circularPathData.rightInnerExtent+\" \"+t.circularPathData.verticalFullExtent+\" A\"+t.circularPathData.rightLargeArcRadius+\" \"+t.circularPathData.rightLargeArcRadius+\" 0 0 1 \"+t.circularPathData.rightFullExtent+\" \"+t.circularPathData.verticalRightInnerExtent+\" L\"+t.circularPathData.rightFullExtent+\" \"+(t.circularPathData.targetY+t.circularPathData.rightSmallArcRadius)+\" A\"+t.circularPathData.rightLargeArcRadius+\" \"+t.circularPathData.rightSmallArcRadius+\" 0 0 1 \"+t.circularPathData.rightInnerExtent+\" \"+t.circularPathData.targetY+\" L\"+t.circularPathData.targetX+\" \"+t.circularPathData.targetY;return e}(e);else{var f=n.linkHorizontal().source((function(t){return[t.source.x0+(t.source.x1-t.source.x0),t.y0]})).target((function(t){return[t.target.x0,t.y1]}));e.path=f(e)}}))}function E(t,e){return O(t)==O(e)?\"bottom\"==t.circularLinkType?C(t,e):L(t,e):O(e)-O(t)}function L(t,e){return t.y0-e.y0}function C(t,e){return e.y0-t.y0}function P(t,e){return t.y1-e.y1}function I(t,e){return e.y1-t.y1}function O(t){return t.target.column-t.source.column}function z(t){return t.target.x0-t.source.x1}function D(t,e){var r=T(t),n=z(e)/Math.tan(r);return\"up\"==q(t)?t.y1+n:t.y1-n}function R(t,e){var r=T(t),n=z(e)/Math.tan(r);return\"up\"==q(t)?t.y1-n:t.y1+n}function F(t,e,r,n){t.links.forEach((function(i){if(!i.circular&&i.target.column-i.source.column>1){var a=i.source.column+1,o=i.target.column-1,s=1,l=o-a+1;for(s=1;a<=o;a++,s++)t.nodes.forEach((function(o){if(o.column==a){var c,u=s/(l+1),f=Math.pow(1-u,3),h=3*u*Math.pow(1-u,2),p=3*Math.pow(u,2)*(1-u),d=Math.pow(u,3),m=f*i.y0+h*i.y0+p*i.y1+d*i.y1,g=m-i.width/2,v=m+i.width/2;g>o.y0&&g<o.y1?(c=o.y1-g+10,c=\"bottom\"==o.circularLinkType?c:-c,o=N(o,c,e,r),t.nodes.forEach((function(t){b(t,n)!=b(o,n)&&t.column==o.column&&B(o,t)&&N(t,c,e,r)}))):(v>o.y0&&v<o.y1||g<o.y0&&v>o.y1)&&(c=v-o.y0+10,o=N(o,c,e,r),t.nodes.forEach((function(t){b(t,n)!=b(o,n)&&t.column==o.column&&t.y0<o.y1&&t.y1>o.y1&&N(t,c,e,r)})))}}))}}))}function B(t,e){return t.y0>e.y0&&t.y0<e.y1||(t.y1>e.y0&&t.y1<e.y1||t.y0<e.y0&&t.y1>e.y1)}function N(t,e,r,n){return t.y0+e>=r&&t.y1+e<=n&&(t.y0=t.y0+e,t.y1=t.y1+e,t.targetLinks.forEach((function(t){t.y1=t.y1+e})),t.sourceLinks.forEach((function(t){t.y0=t.y0+e}))),t}function j(t,e,r,n){t.nodes.forEach((function(i){n&&i.y+(i.y1-i.y0)>e&&(i.y=i.y-(i.y+(i.y1-i.y0)-e));var a=t.links.filter((function(t){return b(t.source,r)==b(i,r)})),o=a.length;o>1&&a.sort((function(t,e){if(!t.circular&&!e.circular){if(t.target.column==e.target.column)return t.y1-e.y1;if(!V(t,e))return t.y1-e.y1;if(t.target.column>e.target.column){var r=R(e,t);return t.y1-r}if(e.target.column>t.target.column)return R(t,e)-e.y1}return t.circular&&!e.circular?\"top\"==t.circularLinkType?-1:1:e.circular&&!t.circular?\"top\"==e.circularLinkType?1:-1:t.circular&&e.circular?t.circularLinkType===e.circularLinkType&&\"top\"==t.circularLinkType?t.target.column===e.target.column?t.target.y1-e.target.y1:e.target.column-t.target.column:t.circularLinkType===e.circularLinkType&&\"bottom\"==t.circularLinkType?t.target.column===e.target.column?e.target.y1-t.target.y1:t.target.column-e.target.column:\"top\"==t.circularLinkType?-1:1:void 0}));var s=i.y0;a.forEach((function(t){t.y0=s+t.width/2,s+=t.width})),a.forEach((function(t,e){if(\"bottom\"==t.circularLinkType){for(var r=e+1,n=0;r<o;r++)n+=a[r].width;t.y0=i.y1-n-t.width/2}}))}))}function U(t,e,r){t.nodes.forEach((function(e){var n=t.links.filter((function(t){return b(t.target,r)==b(e,r)})),i=n.length;i>1&&n.sort((function(t,e){if(!t.circular&&!e.circular){if(t.source.column==e.source.column)return t.y0-e.y0;if(!V(t,e))return t.y0-e.y0;if(e.source.column<t.source.column){var r=D(e,t);return t.y0-r}if(t.source.column<e.source.column)return D(t,e)-e.y0}return t.circular&&!e.circular?\"top\"==t.circularLinkType?-1:1:e.circular&&!t.circular?\"top\"==e.circularLinkType?1:-1:t.circular&&e.circular?t.circularLinkType===e.circularLinkType&&\"top\"==t.circularLinkType?t.source.column===e.source.column?t.source.y1-e.source.y1:t.source.column-e.source.column:t.circularLinkType===e.circularLinkType&&\"bottom\"==t.circularLinkType?t.source.column===e.source.column?t.source.y1-e.source.y1:e.source.column-t.source.column:\"top\"==t.circularLinkType?-1:1:void 0}));var a=e.y0;n.forEach((function(t){t.y1=a+t.width/2,a+=t.width})),n.forEach((function(t,r){if(\"bottom\"==t.circularLinkType){for(var a=r+1,o=0;a<i;a++)o+=n[a].width;t.y1=e.y1-o-t.width/2}}))}))}function V(t,e){return q(t)==q(e)}function q(t){return t.y0-t.y1>0?\"up\":\"down\"}function H(t,e){return b(t.source,e)==b(t.target,e)}function G(t,r,n){var i=t.nodes,a=t.links,o=!1,s=!1;if(a.forEach((function(t){\"top\"==t.circularLinkType?o=!0:\"bottom\"==t.circularLinkType&&(s=!0)})),0==o||0==s){var l=e.min(i,(function(t){return t.y0})),c=(n-r)/(e.max(i,(function(t){return t.y1}))-l);i.forEach((function(t){var e=(t.y1-t.y0)*c;t.y0=(t.y0-l)*c,t.y1=t.y0+e})),a.forEach((function(t){t.y0=(t.y0-l)*c,t.y1=(t.y1-l)*c,t.width=t.width*c}))}}t.sankeyCircular=function(){var t,n,i=0,a=0,b=1,T=1,M=24,A=g,E=o,L=v,C=y,P=32,I=2,O=null;function z(){var t={nodes:L.apply(null,arguments),links:C.apply(null,arguments)};D(t),_(t,A,O),R(t),B(t),w(t,A),N(t,P,A),V(t);for(var e=4,r=0;r<e;r++)j(t,T,A),U(t,T,A),F(t,a,T,A),j(t,T,A),U(t,T,A);return G(t,a,T),S(t,I,T,A),t}function D(t){t.nodes.forEach((function(t,e){t.index=e,t.sourceLinks=[],t.targetLinks=[]}));var e=r.map(t.nodes,A);return t.links.forEach((function(t,r){t.index=r;var n=t.source,i=t.target;\"object\"!==(void 0===n?\"undefined\":l(n))&&(n=t.source=x(e,n)),\"object\"!==(void 0===i?\"undefined\":l(i))&&(i=t.target=x(e,i)),n.sourceLinks.push(t),i.targetLinks.push(t)})),t}function R(t){t.nodes.forEach((function(t){t.partOfCycle=!1,t.value=Math.max(e.sum(t.sourceLinks,h),e.sum(t.targetLinks,h)),t.sourceLinks.forEach((function(e){e.circular&&(t.partOfCycle=!0,t.circularLinkType=e.circularLinkType)})),t.targetLinks.forEach((function(e){e.circular&&(t.partOfCycle=!0,t.circularLinkType=e.circularLinkType)}))}))}function B(t){var e,r,n;for(e=t.nodes,r=[],n=0;e.length;++n,e=r,r=[])e.forEach((function(t){t.depth=n,t.sourceLinks.forEach((function(t){r.indexOf(t.target)<0&&!t.circular&&r.push(t.target)}))}));for(e=t.nodes,r=[],n=0;e.length;++n,e=r,r=[])e.forEach((function(t){t.height=n,t.targetLinks.forEach((function(t){r.indexOf(t.source)<0&&!t.circular&&r.push(t.source)}))}));t.nodes.forEach((function(t){t.column=Math.floor(E.call(null,t,n))}))}function N(o,s,l){var c=r.nest().key((function(t){return t.column})).sortKeys(e.ascending).entries(o.nodes).map((function(t){return t.values}));!function(r){if(n){var s=1/0;c.forEach((function(t){var e=T*n/(t.length+1);s=e<s?e:s})),t=s}var l=e.min(c,(function(r){return(T-a-(r.length-1)*t)/e.sum(r,h)}));l*=.3,o.links.forEach((function(t){t.width=t.value*l}));var u=function(t){var r=0,n=0,i=0,a=0,o=e.max(t.nodes,(function(t){return t.column}));return t.links.forEach((function(t){t.circular&&(\"top\"==t.circularLinkType?r+=t.width:n+=t.width,0==t.target.column&&(a+=t.width),t.source.column==o&&(i+=t.width))})),{top:r=r>0?r+25+10:r,bottom:n=n>0?n+25+10:n,left:a=a>0?a+25+10:a,right:i=i>0?i+25+10:i}}(o),f=function(t,r){var n=e.max(t.nodes,(function(t){return t.column})),o=b-i,s=T-a,l=o/(o+r.right+r.left),c=s/(s+r.top+r.bottom);return i=i*l+r.left,b=0==r.right?b:b*l,a=a*c+r.top,T*=c,t.nodes.forEach((function(t){t.x0=i+t.column*((b-i-M)/n),t.x1=t.x0+M})),c}(o,u);l*=f,o.links.forEach((function(t){t.width=t.value*l})),c.forEach((function(t){var e=t.length;t.forEach((function(t,n){t.depth==c.length-1&&1==e||0==t.depth&&1==e?(t.y0=T/2-t.value*l,t.y1=t.y0+t.value*l):t.partOfCycle?0==k(t,r)?(t.y0=T/2+n,t.y1=t.y0+t.value*l):\"top\"==t.circularLinkType?(t.y0=a+n,t.y1=t.y0+t.value*l):(t.y0=T-t.value*l-n,t.y1=t.y0+t.value*l):0==u.top||0==u.bottom?(t.y0=(T-a)/e*n,t.y1=t.y0+t.value*l):(t.y0=(T-a)/2-e/2+n,t.y1=t.y0+t.value*l)}))}))}(l),y();for(var u=1,g=s;g>0;--g)v(u*=.99,l),y();function v(t,r){var n=c.length;c.forEach((function(i){var a=i.length,o=i[0].depth;i.forEach((function(i){var s;if(i.sourceLinks.length||i.targetLinks.length)if(i.partOfCycle&&k(i,r)>0);else if(0==o&&1==a)s=i.y1-i.y0,i.y0=T/2-s/2,i.y1=T/2+s/2;else if(o==n-1&&1==a)s=i.y1-i.y0,i.y0=T/2-s/2,i.y1=T/2+s/2;else{var l=e.mean(i.sourceLinks,m),c=e.mean(i.targetLinks,d),u=((l&&c?(l+c)/2:l||c)-p(i))*t;i.y0+=u,i.y1+=u}}))}))}function y(){c.forEach((function(e){var r,n,i,o=a,s=e.length;for(e.sort(f),i=0;i<s;++i)(n=o-(r=e[i]).y0)>0&&(r.y0+=n,r.y1+=n),o=r.y1+t;if((n=o-t-T)>0)for(o=r.y0-=n,r.y1-=n,i=s-2;i>=0;--i)(n=(r=e[i]).y1+t-o)>0&&(r.y0-=n,r.y1-=n),o=r.y0}))}}function V(t){t.nodes.forEach((function(t){t.sourceLinks.sort(u),t.targetLinks.sort(c)})),t.nodes.forEach((function(t){var e=t.y0,r=e,n=t.y1,i=n;t.sourceLinks.forEach((function(t){t.circular?(t.y0=n-t.width/2,n-=t.width):(t.y0=e+t.width/2,e+=t.width)})),t.targetLinks.forEach((function(t){t.circular?(t.y1=i-t.width/2,i-=t.width):(t.y1=r+t.width/2,r+=t.width)}))}))}return z.nodeId=function(t){return arguments.length?(A=\"function\"==typeof t?t:s(t),z):A},z.nodeAlign=function(t){return arguments.length?(E=\"function\"==typeof t?t:s(t),z):E},z.nodeWidth=function(t){return arguments.length?(M=+t,z):M},z.nodePadding=function(e){return arguments.length?(t=+e,z):t},z.nodes=function(t){return arguments.length?(L=\"function\"==typeof t?t:s(t),z):L},z.links=function(t){return arguments.length?(C=\"function\"==typeof t?t:s(t),z):C},z.size=function(t){return arguments.length?(i=a=0,b=+t[0],T=+t[1],z):[b-i,T-a]},z.extent=function(t){return arguments.length?(i=+t[0][0],b=+t[1][0],a=+t[0][1],T=+t[1][1],z):[[i,a],[b,T]]},z.iterations=function(t){return arguments.length?(P=+t,z):P},z.circularLinkGap=function(t){return arguments.length?(I=+t,z):I},z.nodePaddingRatio=function(t){return arguments.length?(n=+t,z):n},z.sortNodes=function(t){return arguments.length?(O=t,z):O},z.update=function(t){return w(t,A),V(t),t.links.forEach((function(t){t.circular&&(t.circularLinkType=t.y0+t.y1<T?\"top\":\"bottom\",t.source.circularLinkType=t.circularLinkType,t.target.circularLinkType=t.circularLinkType)})),j(t,T,A,!1),U(t,T,A),S(t,I,T,A),t},z},t.sankeyCenter=function(t){return t.targetLinks.length?t.depth:t.sourceLinks.length?e.min(t.sourceLinks,a)-1:0},t.sankeyLeft=function(t){return t.depth},t.sankeyRight=function(t,e){return e-1-t.height},t.sankeyJustify=o,Object.defineProperty(t,\"__esModule\",{value:!0})}))},{\"d3-array\":162,\"d3-collection\":163,\"d3-shape\":171,\"elementary-circuits-directed-graph\":184}],57:[function(t,e,r){!function(n,i){\"object\"==typeof r&&void 0!==e?i(r,t(\"d3-array\"),t(\"d3-collection\"),t(\"d3-shape\")):i(n.d3=n.d3||{},n.d3,n.d3,n.d3)}(this,(function(t,e,r,n){\"use strict\";function i(t){return t.target.depth}function a(t,e){return t.sourceLinks.length?t.depth:e-1}function o(t){return function(){return t}}function s(t,e){return c(t.source,e.source)||t.index-e.index}function l(t,e){return c(t.target,e.target)||t.index-e.index}function c(t,e){return t.y0-e.y0}function u(t){return t.value}function f(t){return(t.y0+t.y1)/2}function h(t){return f(t.source)*t.value}function p(t){return f(t.target)*t.value}function d(t){return t.index}function m(t){return t.nodes}function g(t){return t.links}function v(t,e){var r=t.get(e);if(!r)throw new Error(\"missing: \"+e);return r}function y(t){return[t.source.x1,t.y0]}function x(t){return[t.target.x0,t.y1]}t.sankey=function(){var t=0,n=0,i=1,y=1,x=24,b=8,_=d,w=a,T=m,k=g,M=32;function A(){var t={nodes:T.apply(null,arguments),links:k.apply(null,arguments)};return S(t),E(t),L(t),C(t),P(t),t}function S(t){t.nodes.forEach((function(t,e){t.index=e,t.sourceLinks=[],t.targetLinks=[]}));var e=r.map(t.nodes,_);t.links.forEach((function(t,r){t.index=r;var n=t.source,i=t.target;\"object\"!=typeof n&&(n=t.source=v(e,n)),\"object\"!=typeof i&&(i=t.target=v(e,i)),n.sourceLinks.push(t),i.targetLinks.push(t)}))}function E(t){t.nodes.forEach((function(t){t.value=Math.max(e.sum(t.sourceLinks,u),e.sum(t.targetLinks,u))}))}function L(e){var r,n,a;for(r=e.nodes,n=[],a=0;r.length;++a,r=n,n=[])r.forEach((function(t){t.depth=a,t.sourceLinks.forEach((function(t){n.indexOf(t.target)<0&&n.push(t.target)}))}));for(r=e.nodes,n=[],a=0;r.length;++a,r=n,n=[])r.forEach((function(t){t.height=a,t.targetLinks.forEach((function(t){n.indexOf(t.source)<0&&n.push(t.source)}))}));var o=(i-t-x)/(a-1);e.nodes.forEach((function(e){e.x1=(e.x0=t+Math.max(0,Math.min(a-1,Math.floor(w.call(null,e,a))))*o)+x}))}function C(t){var i=r.nest().key((function(t){return t.x0})).sortKeys(e.ascending).entries(t.nodes).map((function(t){return t.values}));!function(){var r=e.max(i,(function(t){return t.length})),a=2/3*(y-n)/(r-1);b>a&&(b=a);var o=e.min(i,(function(t){return(y-n-(t.length-1)*b)/e.sum(t,u)}));i.forEach((function(t){t.forEach((function(t,e){t.y1=(t.y0=e)+t.value*o}))})),t.links.forEach((function(t){t.width=t.value*o}))}(),d();for(var a=1,o=M;o>0;--o)l(a*=.99),d(),s(a),d();function s(t){i.forEach((function(r){r.forEach((function(r){if(r.targetLinks.length){var n=(e.sum(r.targetLinks,h)/e.sum(r.targetLinks,u)-f(r))*t;r.y0+=n,r.y1+=n}}))}))}function l(t){i.slice().reverse().forEach((function(r){r.forEach((function(r){if(r.sourceLinks.length){var n=(e.sum(r.sourceLinks,p)/e.sum(r.sourceLinks,u)-f(r))*t;r.y0+=n,r.y1+=n}}))}))}function d(){i.forEach((function(t){var e,r,i,a=n,o=t.length;for(t.sort(c),i=0;i<o;++i)(r=a-(e=t[i]).y0)>0&&(e.y0+=r,e.y1+=r),a=e.y1+b;if((r=a-b-y)>0)for(a=e.y0-=r,e.y1-=r,i=o-2;i>=0;--i)(r=(e=t[i]).y1+b-a)>0&&(e.y0-=r,e.y1-=r),a=e.y0}))}}function P(t){t.nodes.forEach((function(t){t.sourceLinks.sort(l),t.targetLinks.sort(s)})),t.nodes.forEach((function(t){var e=t.y0,r=e;t.sourceLinks.forEach((function(t){t.y0=e+t.width/2,e+=t.width})),t.targetLinks.forEach((function(t){t.y1=r+t.width/2,r+=t.width}))}))}return A.update=function(t){return P(t),t},A.nodeId=function(t){return arguments.length?(_=\"function\"==typeof t?t:o(t),A):_},A.nodeAlign=function(t){return arguments.length?(w=\"function\"==typeof t?t:o(t),A):w},A.nodeWidth=function(t){return arguments.length?(x=+t,A):x},A.nodePadding=function(t){return arguments.length?(b=+t,A):b},A.nodes=function(t){return arguments.length?(T=\"function\"==typeof t?t:o(t),A):T},A.links=function(t){return arguments.length?(k=\"function\"==typeof t?t:o(t),A):k},A.size=function(e){return arguments.length?(t=n=0,i=+e[0],y=+e[1],A):[i-t,y-n]},A.extent=function(e){return arguments.length?(t=+e[0][0],i=+e[1][0],n=+e[0][1],y=+e[1][1],A):[[t,n],[i,y]]},A.iterations=function(t){return arguments.length?(M=+t,A):M},A},t.sankeyCenter=function(t){return t.targetLinks.length?t.depth:t.sourceLinks.length?e.min(t.sourceLinks,i)-1:0},t.sankeyLeft=function(t){return t.depth},t.sankeyRight=function(t,e){return e-1-t.height},t.sankeyJustify=a,t.sankeyLinkHorizontal=function(){return n.linkHorizontal().source(y).target(x)},Object.defineProperty(t,\"__esModule\",{value:!0})}))},{\"d3-array\":162,\"d3-collection\":163,\"d3-shape\":171}],58:[function(t,e,r){(function(){var t={version:\"3.6.1\"},r=[].slice,n=function(t){return r.call(t)},i=this.document;function a(t){return t&&(t.ownerDocument||t.document||t).documentElement}function o(t){return t&&(t.ownerDocument&&t.ownerDocument.defaultView||t.document&&t||t.defaultView)}if(i)try{n(i.documentElement.childNodes)[0].nodeType}catch(t){n=function(t){for(var e=t.length,r=new Array(e);e--;)r[e]=t[e];return r}}if(Date.now||(Date.now=function(){return+new Date}),i)try{i.createElement(\"DIV\").style.setProperty(\"opacity\",0,\"\")}catch(t){var s=this.Element.prototype,l=s.setAttribute,c=s.setAttributeNS,u=this.CSSStyleDeclaration.prototype,f=u.setProperty;s.setAttribute=function(t,e){l.call(this,t,e+\"\")},s.setAttributeNS=function(t,e,r){c.call(this,t,e,r+\"\")},u.setProperty=function(t,e,r){f.call(this,t,e+\"\",r)}}function h(t,e){return t<e?-1:t>e?1:t>=e?0:NaN}function p(t){return null===t?NaN:+t}function d(t){return!isNaN(t)}function m(t){return{left:function(e,r,n,i){for(arguments.length<3&&(n=0),arguments.length<4&&(i=e.length);n<i;){var a=n+i>>>1;t(e[a],r)<0?n=a+1:i=a}return n},right:function(e,r,n,i){for(arguments.length<3&&(n=0),arguments.length<4&&(i=e.length);n<i;){var a=n+i>>>1;t(e[a],r)>0?i=a:n=a+1}return n}}}t.ascending=h,t.descending=function(t,e){return e<t?-1:e>t?1:e>=t?0:NaN},t.min=function(t,e){var r,n,i=-1,a=t.length;if(1===arguments.length){for(;++i<a;)if(null!=(n=t[i])&&n>=n){r=n;break}for(;++i<a;)null!=(n=t[i])&&r>n&&(r=n)}else{for(;++i<a;)if(null!=(n=e.call(t,t[i],i))&&n>=n){r=n;break}for(;++i<a;)null!=(n=e.call(t,t[i],i))&&r>n&&(r=n)}return r},t.max=function(t,e){var r,n,i=-1,a=t.length;if(1===arguments.length){for(;++i<a;)if(null!=(n=t[i])&&n>=n){r=n;break}for(;++i<a;)null!=(n=t[i])&&n>r&&(r=n)}else{for(;++i<a;)if(null!=(n=e.call(t,t[i],i))&&n>=n){r=n;break}for(;++i<a;)null!=(n=e.call(t,t[i],i))&&n>r&&(r=n)}return r},t.extent=function(t,e){var r,n,i,a=-1,o=t.length;if(1===arguments.length){for(;++a<o;)if(null!=(n=t[a])&&n>=n){r=i=n;break}for(;++a<o;)null!=(n=t[a])&&(r>n&&(r=n),i<n&&(i=n))}else{for(;++a<o;)if(null!=(n=e.call(t,t[a],a))&&n>=n){r=i=n;break}for(;++a<o;)null!=(n=e.call(t,t[a],a))&&(r>n&&(r=n),i<n&&(i=n))}return[r,i]},t.sum=function(t,e){var r,n=0,i=t.length,a=-1;if(1===arguments.length)for(;++a<i;)d(r=+t[a])&&(n+=r);else for(;++a<i;)d(r=+e.call(t,t[a],a))&&(n+=r);return n},t.mean=function(t,e){var r,n=0,i=t.length,a=-1,o=i;if(1===arguments.length)for(;++a<i;)d(r=p(t[a]))?n+=r:--o;else for(;++a<i;)d(r=p(e.call(t,t[a],a)))?n+=r:--o;if(o)return n/o},t.quantile=function(t,e){var r=(t.length-1)*e+1,n=Math.floor(r),i=+t[n-1],a=r-n;return a?i+a*(t[n]-i):i},t.median=function(e,r){var n,i=[],a=e.length,o=-1;if(1===arguments.length)for(;++o<a;)d(n=p(e[o]))&&i.push(n);else for(;++o<a;)d(n=p(r.call(e,e[o],o)))&&i.push(n);if(i.length)return t.quantile(i.sort(h),.5)},t.variance=function(t,e){var r,n,i=t.length,a=0,o=0,s=-1,l=0;if(1===arguments.length)for(;++s<i;)d(r=p(t[s]))&&(o+=(n=r-a)*(r-(a+=n/++l)));else for(;++s<i;)d(r=p(e.call(t,t[s],s)))&&(o+=(n=r-a)*(r-(a+=n/++l)));if(l>1)return o/(l-1)},t.deviation=function(){var e=t.variance.apply(this,arguments);return e?Math.sqrt(e):e};var g=m(h);function v(t){return t.length}t.bisectLeft=g.left,t.bisect=t.bisectRight=g.right,t.bisector=function(t){return m(1===t.length?function(e,r){return h(t(e),r)}:t)},t.shuffle=function(t,e,r){(a=arguments.length)<3&&(r=t.length,a<2&&(e=0));for(var n,i,a=r-e;a;)i=Math.random()*a--|0,n=t[a+e],t[a+e]=t[i+e],t[i+e]=n;return t},t.permute=function(t,e){for(var r=e.length,n=new Array(r);r--;)n[r]=t[e[r]];return n},t.pairs=function(t){for(var e=0,r=t.length-1,n=t[0],i=new Array(r<0?0:r);e<r;)i[e]=[n,n=t[++e]];return i},t.transpose=function(e){if(!(a=e.length))return[];for(var r=-1,n=t.min(e,v),i=new Array(n);++r<n;)for(var a,o=-1,s=i[r]=new Array(a);++o<a;)s[o]=e[o][r];return i},t.zip=function(){return t.transpose(arguments)},t.keys=function(t){var e=[];for(var r in t)e.push(r);return e},t.values=function(t){var e=[];for(var r in t)e.push(t[r]);return e},t.entries=function(t){var e=[];for(var r in t)e.push({key:r,value:t[r]});return e},t.merge=function(t){for(var e,r,n,i=t.length,a=-1,o=0;++a<i;)o+=t[a].length;for(r=new Array(o);--i>=0;)for(e=(n=t[i]).length;--e>=0;)r[--o]=n[e];return r};var y=Math.abs;function x(t){for(var e=1;t*e%1;)e*=10;return e}function b(t,e){for(var r in e)Object.defineProperty(t.prototype,r,{value:e[r],enumerable:!1})}function _(){this._=Object.create(null)}t.range=function(t,e,r){if(arguments.length<3&&(r=1,arguments.length<2&&(e=t,t=0)),(e-t)/r==1/0)throw new Error(\"infinite range\");var n,i=[],a=x(y(r)),o=-1;if(t*=a,e*=a,(r*=a)<0)for(;(n=t+r*++o)>e;)i.push(n/a);else for(;(n=t+r*++o)<e;)i.push(n/a);return i},t.map=function(t,e){var r=new _;if(t instanceof _)t.forEach((function(t,e){r.set(t,e)}));else if(Array.isArray(t)){var n,i=-1,a=t.length;if(1===arguments.length)for(;++i<a;)r.set(i,t[i]);else for(;++i<a;)r.set(e.call(t,n=t[i],i),n)}else for(var o in t)r.set(o,t[o]);return r};function w(t){return\"__proto__\"==(t+=\"\")||\"\\0\"===t[0]?\"\\0\"+t:t}function T(t){return\"\\0\"===(t+=\"\")[0]?t.slice(1):t}function k(t){return w(t)in this._}function M(t){return(t=w(t))in this._&&delete this._[t]}function A(){var t=[];for(var e in this._)t.push(T(e));return t}function S(){var t=0;for(var e in this._)++t;return t}function E(){for(var t in this._)return!1;return!0}function L(){this._=Object.create(null)}function C(t){return t}function P(t,e,r){return function(){var n=r.apply(e,arguments);return n===e?t:n}}function I(t,e){if(e in t)return e;e=e.charAt(0).toUpperCase()+e.slice(1);for(var r=0,n=O.length;r<n;++r){var i=O[r]+e;if(i in t)return i}}b(_,{has:k,get:function(t){return this._[w(t)]},set:function(t,e){return this._[w(t)]=e},remove:M,keys:A,values:function(){var t=[];for(var e in this._)t.push(this._[e]);return t},entries:function(){var t=[];for(var e in this._)t.push({key:T(e),value:this._[e]});return t},size:S,empty:E,forEach:function(t){for(var e in this._)t.call(this,T(e),this._[e])}}),t.nest=function(){var e,r,n={},i=[],a=[];function o(t,a,s){if(s>=i.length)return r?r.call(n,a):e?a.sort(e):a;for(var l,c,u,f,h=-1,p=a.length,d=i[s++],m=new _;++h<p;)(f=m.get(l=d(c=a[h])))?f.push(c):m.set(l,[c]);return t?(c=t(),u=function(e,r){c.set(e,o(t,r,s))}):(c={},u=function(e,r){c[e]=o(t,r,s)}),m.forEach(u),c}return n.map=function(t,e){return o(e,t,0)},n.entries=function(e){return function t(e,r){if(r>=i.length)return e;var n=[],o=a[r++];return e.forEach((function(e,i){n.push({key:e,values:t(i,r)})})),o?n.sort((function(t,e){return o(t.key,e.key)})):n}(o(t.map,e,0),0)},n.key=function(t){return i.push(t),n},n.sortKeys=function(t){return a[i.length-1]=t,n},n.sortValues=function(t){return e=t,n},n.rollup=function(t){return r=t,n},n},t.set=function(t){var e=new L;if(t)for(var r=0,n=t.length;r<n;++r)e.add(t[r]);return e},b(L,{has:k,add:function(t){return this._[w(t+=\"\")]=!0,t},remove:M,values:A,size:S,empty:E,forEach:function(t){for(var e in this._)t.call(this,T(e))}}),t.behavior={},t.rebind=function(t,e){for(var r,n=1,i=arguments.length;++n<i;)t[r=arguments[n]]=P(t,e,e[r]);return t};var O=[\"webkit\",\"ms\",\"moz\",\"Moz\",\"o\",\"O\"];function z(){}function D(){}function R(t){var e=[],r=new _;function n(){for(var r,n=e,i=-1,a=n.length;++i<a;)(r=n[i].on)&&r.apply(this,arguments);return t}return n.on=function(n,i){var a,o=r.get(n);return arguments.length<2?o&&o.on:(o&&(o.on=null,e=e.slice(0,a=e.indexOf(o)).concat(e.slice(a+1)),r.remove(n)),i&&e.push(r.set(n,{on:i})),t)},n}function F(){t.event.preventDefault()}function B(){for(var e,r=t.event;e=r.sourceEvent;)r=e;return r}function N(e){for(var r=new D,n=0,i=arguments.length;++n<i;)r[arguments[n]]=R(r);return r.of=function(n,i){return function(a){try{var o=a.sourceEvent=t.event;a.target=e,t.event=a,r[a.type].apply(n,i)}finally{t.event=o}}},r}t.dispatch=function(){for(var t=new D,e=-1,r=arguments.length;++e<r;)t[arguments[e]]=R(t);return t},D.prototype.on=function(t,e){var r=t.indexOf(\".\"),n=\"\";if(r>=0&&(n=t.slice(r+1),t=t.slice(0,r)),t)return arguments.length<2?this[t].on(n):this[t].on(n,e);if(2===arguments.length){if(null==e)for(t in this)this.hasOwnProperty(t)&&this[t].on(n,null);return this}},t.event=null,t.requote=function(t){return t.replace(j,\"\\\\$&\")};var j=/[\\\\\\^\\$\\*\\+\\?\\|\\[\\]\\(\\)\\.\\{\\}]/g,U={}.__proto__?function(t,e){t.__proto__=e}:function(t,e){for(var r in e)t[r]=e[r]};function V(t){return U(t,Y),t}var q=function(t,e){return e.querySelector(t)},H=function(t,e){return e.querySelectorAll(t)},G=function(t,e){var r=t.matches||t[I(t,\"matchesSelector\")];return(G=function(t,e){return r.call(t,e)})(t,e)};\"function\"==typeof Sizzle&&(q=function(t,e){return Sizzle(t,e)[0]||null},H=Sizzle,G=Sizzle.matchesSelector),t.selection=function(){return t.select(i.documentElement)};var Y=t.selection.prototype=[];function W(t){return\"function\"==typeof t?t:function(){return q(t,this)}}function X(t){return\"function\"==typeof t?t:function(){return H(t,this)}}Y.select=function(t){var e,r,n,i,a=[];t=W(t);for(var o=-1,s=this.length;++o<s;){a.push(e=[]),e.parentNode=(n=this[o]).parentNode;for(var l=-1,c=n.length;++l<c;)(i=n[l])?(e.push(r=t.call(i,i.__data__,l,o)),r&&\"__data__\"in i&&(r.__data__=i.__data__)):e.push(null)}return V(a)},Y.selectAll=function(t){var e,r,i=[];t=X(t);for(var a=-1,o=this.length;++a<o;)for(var s=this[a],l=-1,c=s.length;++l<c;)(r=s[l])&&(i.push(e=n(t.call(r,r.__data__,l,a))),e.parentNode=r);return V(i)};var Z=\"http://www.w3.org/1999/xhtml\",J={svg:\"http://www.w3.org/2000/svg\",xhtml:Z,xlink:\"http://www.w3.org/1999/xlink\",xml:\"http://www.w3.org/XML/1998/namespace\",xmlns:\"http://www.w3.org/2000/xmlns/\"};function K(e,r){return e=t.ns.qualify(e),null==r?e.local?function(){this.removeAttributeNS(e.space,e.local)}:function(){this.removeAttribute(e)}:\"function\"==typeof r?e.local?function(){var t=r.apply(this,arguments);null==t?this.removeAttributeNS(e.space,e.local):this.setAttributeNS(e.space,e.local,t)}:function(){var t=r.apply(this,arguments);null==t?this.removeAttribute(e):this.setAttribute(e,t)}:e.local?function(){this.setAttributeNS(e.space,e.local,r)}:function(){this.setAttribute(e,r)}}function Q(t){return t.trim().replace(/\\s+/g,\" \")}function $(e){return new RegExp(\"(?:^|\\\\s+)\"+t.requote(e)+\"(?:\\\\s+|$)\",\"g\")}function tt(t){return(t+\"\").trim().split(/^|\\s+/)}function et(t,e){var r=(t=tt(t).map(rt)).length;return\"function\"==typeof e?function(){for(var n=-1,i=e.apply(this,arguments);++n<r;)t[n](this,i)}:function(){for(var n=-1;++n<r;)t[n](this,e)}}function rt(t){var e=$(t);return function(r,n){if(i=r.classList)return n?i.add(t):i.remove(t);var i=r.getAttribute(\"class\")||\"\";n?(e.lastIndex=0,e.test(i)||r.setAttribute(\"class\",Q(i+\" \"+t))):r.setAttribute(\"class\",Q(i.replace(e,\" \")))}}function nt(t,e,r){return null==e?function(){this.style.removeProperty(t)}:\"function\"==typeof e?function(){var n=e.apply(this,arguments);null==n?this.style.removeProperty(t):this.style.setProperty(t,n,r)}:function(){this.style.setProperty(t,e,r)}}function it(t,e){return null==e?function(){delete this[t]}:\"function\"==typeof e?function(){var r=e.apply(this,arguments);null==r?delete this[t]:this[t]=r}:function(){this[t]=e}}function at(e){return\"function\"==typeof e?e:(e=t.ns.qualify(e)).local?function(){return this.ownerDocument.createElementNS(e.space,e.local)}:function(){var t=this.ownerDocument,r=this.namespaceURI;return r===Z&&t.documentElement.namespaceURI===Z?t.createElement(e):t.createElementNS(r,e)}}function ot(){var t=this.parentNode;t&&t.removeChild(this)}function st(t){return{__data__:t}}function lt(t){return function(){return G(this,t)}}function ct(t){return arguments.length||(t=h),function(e,r){return e&&r?t(e.__data__,r.__data__):!e-!r}}function ut(t,e){for(var r=0,n=t.length;r<n;r++)for(var i,a=t[r],o=0,s=a.length;o<s;o++)(i=a[o])&&e(i,o,r);return t}function ft(t){return U(t,ht),t}t.ns={prefix:J,qualify:function(t){var e=t.indexOf(\":\"),r=t;return e>=0&&\"xmlns\"!==(r=t.slice(0,e))&&(t=t.slice(e+1)),J.hasOwnProperty(r)?{space:J[r],local:t}:t}},Y.attr=function(e,r){if(arguments.length<2){if(\"string\"==typeof e){var n=this.node();return(e=t.ns.qualify(e)).local?n.getAttributeNS(e.space,e.local):n.getAttribute(e)}for(r in e)this.each(K(r,e[r]));return this}return this.each(K(e,r))},Y.classed=function(t,e){if(arguments.length<2){if(\"string\"==typeof t){var r=this.node(),n=(t=tt(t)).length,i=-1;if(e=r.classList){for(;++i<n;)if(!e.contains(t[i]))return!1}else for(e=r.getAttribute(\"class\");++i<n;)if(!$(t[i]).test(e))return!1;return!0}for(e in t)this.each(et(e,t[e]));return this}return this.each(et(t,e))},Y.style=function(t,e,r){var n=arguments.length;if(n<3){if(\"string\"!=typeof t){for(r in n<2&&(e=\"\"),t)this.each(nt(r,t[r],e));return this}if(n<2){var i=this.node();return o(i).getComputedStyle(i,null).getPropertyValue(t)}r=\"\"}return this.each(nt(t,e,r))},Y.property=function(t,e){if(arguments.length<2){if(\"string\"==typeof t)return this.node()[t];for(e in t)this.each(it(e,t[e]));return this}return this.each(it(t,e))},Y.text=function(t){return arguments.length?this.each(\"function\"==typeof t?function(){var e=t.apply(this,arguments);this.textContent=null==e?\"\":e}:null==t?function(){this.textContent=\"\"}:function(){this.textContent=t}):this.node().textContent},Y.html=function(t){return arguments.length?this.each(\"function\"==typeof t?function(){var e=t.apply(this,arguments);this.innerHTML=null==e?\"\":e}:null==t?function(){this.innerHTML=\"\"}:function(){this.innerHTML=t}):this.node().innerHTML},Y.append=function(t){return t=at(t),this.select((function(){return this.appendChild(t.apply(this,arguments))}))},Y.insert=function(t,e){return t=at(t),e=W(e),this.select((function(){return this.insertBefore(t.apply(this,arguments),e.apply(this,arguments)||null)}))},Y.remove=function(){return this.each(ot)},Y.data=function(t,e){var r,n,i=-1,a=this.length;if(!arguments.length){for(t=new Array(a=(r=this[0]).length);++i<a;)(n=r[i])&&(t[i]=n.__data__);return t}function o(t,r){var n,i,a,o=t.length,u=r.length,f=Math.min(o,u),h=new Array(u),p=new Array(u),d=new Array(o);if(e){var m,g=new _,v=new Array(o);for(n=-1;++n<o;)(i=t[n])&&(g.has(m=e.call(i,i.__data__,n))?d[n]=i:g.set(m,i),v[n]=m);for(n=-1;++n<u;)(i=g.get(m=e.call(r,a=r[n],n)))?!0!==i&&(h[n]=i,i.__data__=a):p[n]=st(a),g.set(m,!0);for(n=-1;++n<o;)n in v&&!0!==g.get(v[n])&&(d[n]=t[n])}else{for(n=-1;++n<f;)i=t[n],a=r[n],i?(i.__data__=a,h[n]=i):p[n]=st(a);for(;n<u;++n)p[n]=st(r[n]);for(;n<o;++n)d[n]=t[n]}p.update=h,p.parentNode=h.parentNode=d.parentNode=t.parentNode,s.push(p),l.push(h),c.push(d)}var s=ft([]),l=V([]),c=V([]);if(\"function\"==typeof t)for(;++i<a;)o(r=this[i],t.call(r,r.parentNode.__data__,i));else for(;++i<a;)o(r=this[i],t);return l.enter=function(){return s},l.exit=function(){return c},l},Y.datum=function(t){return arguments.length?this.property(\"__data__\",t):this.property(\"__data__\")},Y.filter=function(t){var e,r,n,i=[];\"function\"!=typeof t&&(t=lt(t));for(var a=0,o=this.length;a<o;a++){i.push(e=[]),e.parentNode=(r=this[a]).parentNode;for(var s=0,l=r.length;s<l;s++)(n=r[s])&&t.call(n,n.__data__,s,a)&&e.push(n)}return V(i)},Y.order=function(){for(var t=-1,e=this.length;++t<e;)for(var r,n=this[t],i=n.length-1,a=n[i];--i>=0;)(r=n[i])&&(a&&a!==r.nextSibling&&a.parentNode.insertBefore(r,a),a=r);return this},Y.sort=function(t){t=ct.apply(this,arguments);for(var e=-1,r=this.length;++e<r;)this[e].sort(t);return this.order()},Y.each=function(t){return ut(this,(function(e,r,n){t.call(e,e.__data__,r,n)}))},Y.call=function(t){var e=n(arguments);return t.apply(e[0]=this,e),this},Y.empty=function(){return!this.node()},Y.node=function(){for(var t=0,e=this.length;t<e;t++)for(var r=this[t],n=0,i=r.length;n<i;n++){var a=r[n];if(a)return a}return null},Y.size=function(){var t=0;return ut(this,(function(){++t})),t};var ht=[];function pt(t){var e,r;return function(n,i,a){var o,s=t[a].update,l=s.length;for(a!=r&&(r=a,e=0),i>=e&&(e=i+1);!(o=s[e])&&++e<l;);return o}}function dt(e,r,i){var a=\"__on\"+e,o=e.indexOf(\".\"),s=gt;o>0&&(e=e.slice(0,o));var l=mt.get(e);function c(){var t=this[a];t&&(this.removeEventListener(e,t,t.$),delete this[a])}return l&&(e=l,s=vt),o?r?function(){var t=s(r,n(arguments));c.call(this),this.addEventListener(e,this[a]=t,t.$=i),t._=r}:c:r?z:function(){var r,n=new RegExp(\"^__on([^.]+)\"+t.requote(e)+\"$\");for(var i in this)if(r=i.match(n)){var a=this[i];this.removeEventListener(r[1],a,a.$),delete this[i]}}}t.selection.enter=ft,t.selection.enter.prototype=ht,ht.append=Y.append,ht.empty=Y.empty,ht.node=Y.node,ht.call=Y.call,ht.size=Y.size,ht.select=function(t){for(var e,r,n,i,a,o=[],s=-1,l=this.length;++s<l;){n=(i=this[s]).update,o.push(e=[]),e.parentNode=i.parentNode;for(var c=-1,u=i.length;++c<u;)(a=i[c])?(e.push(n[c]=r=t.call(i.parentNode,a.__data__,c,s)),r.__data__=a.__data__):e.push(null)}return V(o)},ht.insert=function(t,e){return arguments.length<2&&(e=pt(this)),Y.insert.call(this,t,e)},t.select=function(t){var e;return\"string\"==typeof t?(e=[q(t,i)]).parentNode=i.documentElement:(e=[t]).parentNode=a(t),V([e])},t.selectAll=function(t){var e;return\"string\"==typeof t?(e=n(H(t,i))).parentNode=i.documentElement:(e=n(t)).parentNode=null,V([e])},Y.on=function(t,e,r){var n=arguments.length;if(n<3){if(\"string\"!=typeof t){for(r in n<2&&(e=!1),t)this.each(dt(r,t[r],e));return this}if(n<2)return(n=this.node()[\"__on\"+t])&&n._;r=!1}return this.each(dt(t,e,r))};var mt=t.map({mouseenter:\"mouseover\",mouseleave:\"mouseout\"});function gt(e,r){return function(n){var i=t.event;t.event=n,r[0]=this.__data__;try{e.apply(this,r)}finally{t.event=i}}}function vt(t,e){var r=gt(t,e);return function(t){var e=t.relatedTarget;e&&(e===this||8&e.compareDocumentPosition(this))||r.call(this,t)}}i&&mt.forEach((function(t){\"on\"+t in i&&mt.remove(t)}));var yt,xt=0;function bt(e){var r=\".dragsuppress-\"+ ++xt,n=\"click\"+r,i=t.select(o(e)).on(\"touchmove\"+r,F).on(\"dragstart\"+r,F).on(\"selectstart\"+r,F);if(null==yt&&(yt=!(\"onselectstart\"in e)&&I(e.style,\"userSelect\")),yt){var s=a(e).style,l=s[yt];s[yt]=\"none\"}return function(t){if(i.on(r,null),yt&&(s[yt]=l),t){var e=function(){i.on(n,null)};i.on(n,(function(){F(),e()}),!0),setTimeout(e,0)}}}t.mouse=function(t){return wt(t,B())};var _t=this.navigator&&/WebKit/.test(this.navigator.userAgent)?-1:0;function wt(e,r){r.changedTouches&&(r=r.changedTouches[0]);var n=e.ownerSVGElement||e;if(n.createSVGPoint){var i=n.createSVGPoint();if(_t<0){var a=o(e);if(a.scrollX||a.scrollY){var s=(n=t.select(\"body\").append(\"svg\").style({position:\"absolute\",top:0,left:0,margin:0,padding:0,border:\"none\"},\"important\"))[0][0].getScreenCTM();_t=!(s.f||s.e),n.remove()}}return _t?(i.x=r.pageX,i.y=r.pageY):(i.x=r.clientX,i.y=r.clientY),[(i=i.matrixTransform(e.getScreenCTM().inverse())).x,i.y]}var l=e.getBoundingClientRect();return[r.clientX-l.left-e.clientLeft,r.clientY-l.top-e.clientTop]}function Tt(){return t.event.changedTouches[0].identifier}t.touch=function(t,e,r){if(arguments.length<3&&(r=e,e=B().changedTouches),e)for(var n,i=0,a=e.length;i<a;++i)if((n=e[i]).identifier===r)return wt(t,n)},t.behavior.drag=function(){var e=N(a,\"drag\",\"dragstart\",\"dragend\"),r=null,n=s(z,t.mouse,o,\"mousemove\",\"mouseup\"),i=s(Tt,t.touch,C,\"touchmove\",\"touchend\");function a(){this.on(\"mousedown.drag\",n).on(\"touchstart.drag\",i)}function s(n,i,a,o,s){return function(){var l,c=this,u=t.event.target.correspondingElement||t.event.target,f=c.parentNode,h=e.of(c,arguments),p=0,d=n(),m=\".drag\"+(null==d?\"\":\"-\"+d),g=t.select(a(u)).on(o+m,x).on(s+m,b),v=bt(u),y=i(f,d);function x(){var t,e,r=i(f,d);r&&(t=r[0]-y[0],e=r[1]-y[1],p|=t|e,y=r,h({type:\"drag\",x:r[0]+l[0],y:r[1]+l[1],dx:t,dy:e}))}function b(){i(f,d)&&(g.on(o+m,null).on(s+m,null),v(p),h({type:\"dragend\"}))}l=r?[(l=r.apply(c,arguments)).x-y[0],l.y-y[1]]:[0,0],h({type:\"dragstart\"})}}return a.origin=function(t){return arguments.length?(r=t,a):r},t.rebind(a,e,\"on\")},t.touches=function(t,e){return arguments.length<2&&(e=B().touches),e?n(e).map((function(e){var r=wt(t,e);return r.identifier=e.identifier,r})):[]};var kt=1e-6,Mt=1e-12,At=Math.PI,St=2*At,Et=St-kt,Lt=At/2,Ct=At/180,Pt=180/At;function It(t){return t>0?1:t<0?-1:0}function Ot(t,e,r){return(e[0]-t[0])*(r[1]-t[1])-(e[1]-t[1])*(r[0]-t[0])}function zt(t){return t>1?0:t<-1?At:Math.acos(t)}function Dt(t){return t>1?Lt:t<-1?-Lt:Math.asin(t)}function Rt(t){return((t=Math.exp(t))+1/t)/2}function Ft(t){return(t=Math.sin(t/2))*t}var Bt=Math.SQRT2;t.interpolateZoom=function(t,e){var r,n,i=t[0],a=t[1],o=t[2],s=e[0],l=e[1],c=e[2],u=s-i,f=l-a,h=u*u+f*f;if(h<Mt)n=Math.log(c/o)/Bt,r=function(t){return[i+t*u,a+t*f,o*Math.exp(Bt*t*n)]};else{var p=Math.sqrt(h),d=(c*c-o*o+4*h)/(2*o*2*p),m=(c*c-o*o-4*h)/(2*c*2*p),g=Math.log(Math.sqrt(d*d+1)-d),v=Math.log(Math.sqrt(m*m+1)-m);n=(v-g)/Bt,r=function(t){var e,r=t*n,s=Rt(g),l=o/(2*p)*(s*(e=Bt*r+g,((e=Math.exp(2*e))-1)/(e+1))-function(t){return((t=Math.exp(t))-1/t)/2}(g));return[i+l*u,a+l*f,o*s/Rt(Bt*r+g)]}}return r.duration=1e3*n,r},t.behavior.zoom=function(){var e,r,n,a,s,l,c,u,f,h={x:0,y:0,k:1},p=[960,500],d=Ut,m=250,g=0,v=\"mousedown.zoom\",y=\"mousemove.zoom\",x=\"mouseup.zoom\",b=\"touchstart.zoom\",_=N(w,\"zoomstart\",\"zoom\",\"zoomend\");function w(t){t.on(v,P).on(jt+\".zoom\",O).on(\"dblclick.zoom\",z).on(b,I)}function T(t){return[(t[0]-h.x)/h.k,(t[1]-h.y)/h.k]}function k(t){h.k=Math.max(d[0],Math.min(d[1],t))}function M(t,e){e=function(t){return[t[0]*h.k+h.x,t[1]*h.k+h.y]}(e),h.x+=t[0]-e[0],h.y+=t[1]-e[1]}function A(e,n,i,a){e.__chart__={x:h.x,y:h.y,k:h.k},k(Math.pow(2,a)),M(r=n,i),e=t.select(e),m>0&&(e=e.transition().duration(m)),e.call(w.event)}function S(){c&&c.domain(l.range().map((function(t){return(t-h.x)/h.k})).map(l.invert)),f&&f.domain(u.range().map((function(t){return(t-h.y)/h.k})).map(u.invert))}function E(t){g++||t({type:\"zoomstart\"})}function L(t){S(),t({type:\"zoom\",scale:h.k,translate:[h.x,h.y]})}function C(t){--g||(t({type:\"zoomend\"}),r=null)}function P(){var e=this,r=_.of(e,arguments),n=0,i=t.select(o(e)).on(y,l).on(x,c),a=T(t.mouse(e)),s=bt(e);function l(){n=1,M(t.mouse(e),a),L(r)}function c(){i.on(y,null).on(x,null),s(n),C(r)}vs.call(e),E(r)}function I(){var e,r=this,n=_.of(r,arguments),i={},a=0,o=\".zoom-\"+t.event.changedTouches[0].identifier,l=\"touchmove\"+o,c=\"touchend\"+o,u=[],f=t.select(r),p=bt(r);function d(){var n=t.touches(r);return e=h.k,n.forEach((function(t){t.identifier in i&&(i[t.identifier]=T(t))})),n}function m(){var e=t.event.target;t.select(e).on(l,g).on(c,y),u.push(e);for(var n=t.event.changedTouches,o=0,f=n.length;o<f;++o)i[n[o].identifier]=null;var p=d(),m=Date.now();if(1===p.length){if(m-s<500){var v=p[0];A(r,v,i[v.identifier],Math.floor(Math.log(h.k)/Math.LN2)+1),F()}s=m}else if(p.length>1){v=p[0];var x=p[1],b=v[0]-x[0],_=v[1]-x[1];a=b*b+_*_}}function g(){var o,l,c,u,f=t.touches(r);vs.call(r);for(var h=0,p=f.length;h<p;++h,u=null)if(c=f[h],u=i[c.identifier]){if(l)break;o=c,l=u}if(u){var d=(d=c[0]-o[0])*d+(d=c[1]-o[1])*d,m=a&&Math.sqrt(d/a);o=[(o[0]+c[0])/2,(o[1]+c[1])/2],l=[(l[0]+u[0])/2,(l[1]+u[1])/2],k(m*e)}s=null,M(o,l),L(n)}function y(){if(t.event.touches.length){for(var e=t.event.changedTouches,r=0,a=e.length;r<a;++r)delete i[e[r].identifier];for(var s in i)return void d()}t.selectAll(u).on(o,null),f.on(v,P).on(b,I),p(),C(n)}m(),E(n),f.on(v,null).on(b,m)}function O(){var i=_.of(this,arguments);a?clearTimeout(a):(vs.call(this),e=T(r=n||t.mouse(this)),E(i)),a=setTimeout((function(){a=null,C(i)}),50),F(),k(Math.pow(2,.002*Nt())*h.k),M(r,e),L(i)}function z(){var e=t.mouse(this),r=Math.log(h.k)/Math.LN2;A(this,e,T(e),t.event.shiftKey?Math.ceil(r)-1:Math.floor(r)+1)}return jt||(jt=\"onwheel\"in i?(Nt=function(){return-t.event.deltaY*(t.event.deltaMode?120:1)},\"wheel\"):\"onmousewheel\"in i?(Nt=function(){return t.event.wheelDelta},\"mousewheel\"):(Nt=function(){return-t.event.detail},\"MozMousePixelScroll\")),w.event=function(e){e.each((function(){var e=_.of(this,arguments),n=h;bs?t.select(this).transition().each(\"start.zoom\",(function(){h=this.__chart__||{x:0,y:0,k:1},E(e)})).tween(\"zoom:zoom\",(function(){var i=p[0],a=p[1],o=r?r[0]:i/2,s=r?r[1]:a/2,l=t.interpolateZoom([(o-h.x)/h.k,(s-h.y)/h.k,i/h.k],[(o-n.x)/n.k,(s-n.y)/n.k,i/n.k]);return function(t){var r=l(t),n=i/r[2];this.__chart__=h={x:o-r[0]*n,y:s-r[1]*n,k:n},L(e)}})).each(\"interrupt.zoom\",(function(){C(e)})).each(\"end.zoom\",(function(){C(e)})):(this.__chart__=h,E(e),L(e),C(e))}))},w.translate=function(t){return arguments.length?(h={x:+t[0],y:+t[1],k:h.k},S(),w):[h.x,h.y]},w.scale=function(t){return arguments.length?(h={x:h.x,y:h.y,k:null},k(+t),S(),w):h.k},w.scaleExtent=function(t){return arguments.length?(d=null==t?Ut:[+t[0],+t[1]],w):d},w.center=function(t){return arguments.length?(n=t&&[+t[0],+t[1]],w):n},w.size=function(t){return arguments.length?(p=t&&[+t[0],+t[1]],w):p},w.duration=function(t){return arguments.length?(m=+t,w):m},w.x=function(t){return arguments.length?(c=t,l=t.copy(),h={x:0,y:0,k:1},w):c},w.y=function(t){return arguments.length?(f=t,u=t.copy(),h={x:0,y:0,k:1},w):f},t.rebind(w,_,\"on\")};var Nt,jt,Ut=[0,1/0];function Vt(){}function qt(t,e,r){return this instanceof qt?(this.h=+t,this.s=+e,void(this.l=+r)):arguments.length<2?t instanceof qt?new qt(t.h,t.s,t.l):le(\"\"+t,ce,qt):new qt(t,e,r)}t.color=Vt,Vt.prototype.toString=function(){return this.rgb()+\"\"},t.hsl=qt;var Ht=qt.prototype=new Vt;function Gt(t,e,r){var n,i;function a(t){return Math.round(255*function(t){return t>360?t-=360:t<0&&(t+=360),t<60?n+(i-n)*t/60:t<180?i:t<240?n+(i-n)*(240-t)/60:n}(t))}return t=isNaN(t)?0:(t%=360)<0?t+360:t,e=isNaN(e)||e<0?0:e>1?1:e,n=2*(r=r<0?0:r>1?1:r)-(i=r<=.5?r*(1+e):r+e-r*e),new ne(a(t+120),a(t),a(t-120))}function Yt(e,r,n){return this instanceof Yt?(this.h=+e,this.c=+r,void(this.l=+n)):arguments.length<2?e instanceof Yt?new Yt(e.h,e.c,e.l):$t(e instanceof Zt?e.l:(e=ue((e=t.rgb(e)).r,e.g,e.b)).l,e.a,e.b):new Yt(e,r,n)}Ht.brighter=function(t){return t=Math.pow(.7,arguments.length?t:1),new qt(this.h,this.s,this.l/t)},Ht.darker=function(t){return t=Math.pow(.7,arguments.length?t:1),new qt(this.h,this.s,t*this.l)},Ht.rgb=function(){return Gt(this.h,this.s,this.l)},t.hcl=Yt;var Wt=Yt.prototype=new Vt;function Xt(t,e,r){return isNaN(t)&&(t=0),isNaN(e)&&(e=0),new Zt(r,Math.cos(t*=Ct)*e,Math.sin(t)*e)}function Zt(t,e,r){return this instanceof Zt?(this.l=+t,this.a=+e,void(this.b=+r)):arguments.length<2?t instanceof Zt?new Zt(t.l,t.a,t.b):t instanceof Yt?Xt(t.h,t.c,t.l):ue((t=ne(t)).r,t.g,t.b):new Zt(t,e,r)}Wt.brighter=function(t){return new Yt(this.h,this.c,Math.min(100,this.l+Jt*(arguments.length?t:1)))},Wt.darker=function(t){return new Yt(this.h,this.c,Math.max(0,this.l-Jt*(arguments.length?t:1)))},Wt.rgb=function(){return Xt(this.h,this.c,this.l).rgb()},t.lab=Zt;var Jt=18,Kt=Zt.prototype=new Vt;function Qt(t,e,r){var n=(t+16)/116,i=n+e/500,a=n-r/200;return new ne(re(3.2404542*(i=.95047*te(i))-1.5371385*(n=1*te(n))-.4985314*(a=1.08883*te(a))),re(-.969266*i+1.8760108*n+.041556*a),re(.0556434*i-.2040259*n+1.0572252*a))}function $t(t,e,r){return t>0?new Yt(Math.atan2(r,e)*Pt,Math.sqrt(e*e+r*r),t):new Yt(NaN,NaN,t)}function te(t){return t>.206893034?t*t*t:(t-4/29)/7.787037}function ee(t){return t>.008856?Math.pow(t,1/3):7.787037*t+4/29}function re(t){return Math.round(255*(t<=.00304?12.92*t:1.055*Math.pow(t,1/2.4)-.055))}function ne(t,e,r){return this instanceof ne?(this.r=~~t,this.g=~~e,void(this.b=~~r)):arguments.length<2?t instanceof ne?new ne(t.r,t.g,t.b):le(\"\"+t,ne,Gt):new ne(t,e,r)}function ie(t){return new ne(t>>16,t>>8&255,255&t)}function ae(t){return ie(t)+\"\"}Kt.brighter=function(t){return new Zt(Math.min(100,this.l+Jt*(arguments.length?t:1)),this.a,this.b)},Kt.darker=function(t){return new Zt(Math.max(0,this.l-Jt*(arguments.length?t:1)),this.a,this.b)},Kt.rgb=function(){return Qt(this.l,this.a,this.b)},t.rgb=ne;var oe=ne.prototype=new Vt;function se(t){return t<16?\"0\"+Math.max(0,t).toString(16):Math.min(255,t).toString(16)}function le(t,e,r){var n,i,a,o=0,s=0,l=0;if(n=/([a-z]+)\\((.*)\\)/.exec(t=t.toLowerCase()))switch(i=n[2].split(\",\"),n[1]){case\"hsl\":return r(parseFloat(i[0]),parseFloat(i[1])/100,parseFloat(i[2])/100);case\"rgb\":return e(he(i[0]),he(i[1]),he(i[2]))}return(a=pe.get(t))?e(a.r,a.g,a.b):(null==t||\"#\"!==t.charAt(0)||isNaN(a=parseInt(t.slice(1),16))||(4===t.length?(o=(3840&a)>>4,o|=o>>4,s=240&a,s|=s>>4,l=15&a,l|=l<<4):7===t.length&&(o=(16711680&a)>>16,s=(65280&a)>>8,l=255&a)),e(o,s,l))}function ce(t,e,r){var n,i,a=Math.min(t/=255,e/=255,r/=255),o=Math.max(t,e,r),s=o-a,l=(o+a)/2;return s?(i=l<.5?s/(o+a):s/(2-o-a),n=t==o?(e-r)/s+(e<r?6:0):e==o?(r-t)/s+2:(t-e)/s+4,n*=60):(n=NaN,i=l>0&&l<1?0:n),new qt(n,i,l)}function ue(t,e,r){var n=ee((.4124564*(t=fe(t))+.3575761*(e=fe(e))+.1804375*(r=fe(r)))/.95047),i=ee((.2126729*t+.7151522*e+.072175*r)/1);return Zt(116*i-16,500*(n-i),200*(i-ee((.0193339*t+.119192*e+.9503041*r)/1.08883)))}function fe(t){return(t/=255)<=.04045?t/12.92:Math.pow((t+.055)/1.055,2.4)}function he(t){var e=parseFloat(t);return\"%\"===t.charAt(t.length-1)?Math.round(2.55*e):e}oe.brighter=function(t){t=Math.pow(.7,arguments.length?t:1);var e=this.r,r=this.g,n=this.b,i=30;return e||r||n?(e&&e<i&&(e=i),r&&r<i&&(r=i),n&&n<i&&(n=i),new ne(Math.min(255,e/t),Math.min(255,r/t),Math.min(255,n/t))):new ne(i,i,i)},oe.darker=function(t){return new ne((t=Math.pow(.7,arguments.length?t:1))*this.r,t*this.g,t*this.b)},oe.hsl=function(){return ce(this.r,this.g,this.b)},oe.toString=function(){return\"#\"+se(this.r)+se(this.g)+se(this.b)};var pe=t.map({aliceblue:15792383,antiquewhite:16444375,aqua:65535,aquamarine:8388564,azure:15794175,beige:16119260,bisque:16770244,black:0,blanchedalmond:16772045,blue:255,blueviolet:9055202,brown:10824234,burlywood:14596231,cadetblue:6266528,chartreuse:8388352,chocolate:13789470,coral:16744272,cornflowerblue:6591981,cornsilk:16775388,crimson:14423100,cyan:65535,darkblue:139,darkcyan:35723,darkgoldenrod:12092939,darkgray:11119017,darkgreen:25600,darkgrey:11119017,darkkhaki:12433259,darkmagenta:9109643,darkolivegreen:5597999,darkorange:16747520,darkorchid:10040012,darkred:9109504,darksalmon:15308410,darkseagreen:9419919,darkslateblue:4734347,darkslategray:3100495,darkslategrey:3100495,darkturquoise:52945,darkviolet:9699539,deeppink:16716947,deepskyblue:49151,dimgray:6908265,dimgrey:6908265,dodgerblue:2003199,firebrick:11674146,floralwhite:16775920,forestgreen:2263842,fuchsia:16711935,gainsboro:14474460,ghostwhite:16316671,gold:16766720,goldenrod:14329120,gray:8421504,green:32768,greenyellow:11403055,grey:8421504,honeydew:15794160,hotpink:16738740,indianred:13458524,indigo:4915330,ivory:16777200,khaki:15787660,lavender:15132410,lavenderblush:16773365,lawngreen:8190976,lemonchiffon:16775885,lightblue:11393254,lightcoral:15761536,lightcyan:14745599,lightgoldenrodyellow:16448210,lightgray:13882323,lightgreen:9498256,lightgrey:13882323,lightpink:16758465,lightsalmon:16752762,lightseagreen:2142890,lightskyblue:8900346,lightslategray:7833753,lightslategrey:7833753,lightsteelblue:11584734,lightyellow:16777184,lime:65280,limegreen:3329330,linen:16445670,magenta:16711935,maroon:8388608,mediumaquamarine:6737322,mediumblue:205,mediumorchid:12211667,mediumpurple:9662683,mediumseagreen:3978097,mediumslateblue:8087790,mediumspringgreen:64154,mediumturquoise:4772300,mediumvioletred:13047173,midnightblue:1644912,mintcream:16121850,mistyrose:16770273,moccasin:16770229,navajowhite:16768685,navy:128,oldlace:16643558,olive:8421376,olivedrab:7048739,orange:16753920,orangered:16729344,orchid:14315734,palegoldenrod:15657130,palegreen:10025880,paleturquoise:11529966,palevioletred:14381203,papayawhip:16773077,peachpuff:16767673,peru:13468991,pink:16761035,plum:14524637,powderblue:11591910,purple:8388736,rebeccapurple:6697881,red:16711680,rosybrown:12357519,royalblue:4286945,saddlebrown:9127187,salmon:16416882,sandybrown:16032864,seagreen:3050327,seashell:16774638,sienna:10506797,silver:12632256,skyblue:8900331,slateblue:6970061,slategray:7372944,slategrey:7372944,snow:16775930,springgreen:65407,steelblue:4620980,tan:13808780,teal:32896,thistle:14204888,tomato:16737095,turquoise:4251856,violet:15631086,wheat:16113331,white:16777215,whitesmoke:16119285,yellow:16776960,yellowgreen:10145074});function de(t){return\"function\"==typeof t?t:function(){return t}}function me(t){return function(e,r,n){return 2===arguments.length&&\"function\"==typeof r&&(n=r,r=null),ge(e,r,t,n)}}function ge(e,r,i,a){var o={},s=t.dispatch(\"beforesend\",\"progress\",\"load\",\"error\"),l={},c=new XMLHttpRequest,u=null;function f(){var t,e=c.status;if(!e&&function(t){var e=t.responseType;return e&&\"text\"!==e?t.response:t.responseText}(c)||e>=200&&e<300||304===e){try{t=i.call(o,c)}catch(t){return void s.error.call(o,t)}s.load.call(o,t)}else s.error.call(o,c)}return self.XDomainRequest&&!(\"withCredentials\"in c)&&/^(http(s)?:)?\\/\\//.test(e)&&(c=new XDomainRequest),\"onload\"in c?c.onload=c.onerror=f:c.onreadystatechange=function(){c.readyState>3&&f()},c.onprogress=function(e){var r=t.event;t.event=e;try{s.progress.call(o,c)}finally{t.event=r}},o.header=function(t,e){return t=(t+\"\").toLowerCase(),arguments.length<2?l[t]:(null==e?delete l[t]:l[t]=e+\"\",o)},o.mimeType=function(t){return arguments.length?(r=null==t?null:t+\"\",o):r},o.responseType=function(t){return arguments.length?(u=t,o):u},o.response=function(t){return i=t,o},[\"get\",\"post\"].forEach((function(t){o[t]=function(){return o.send.apply(o,[t].concat(n(arguments)))}})),o.send=function(t,n,i){if(2===arguments.length&&\"function\"==typeof n&&(i=n,n=null),c.open(t,e,!0),null==r||\"accept\"in l||(l.accept=r+\",*/*\"),c.setRequestHeader)for(var a in l)c.setRequestHeader(a,l[a]);return null!=r&&c.overrideMimeType&&c.overrideMimeType(r),null!=u&&(c.responseType=u),null!=i&&o.on(\"error\",i).on(\"load\",(function(t){i(null,t)})),s.beforesend.call(o,c),c.send(null==n?null:n),o},o.abort=function(){return c.abort(),o},t.rebind(o,s,\"on\"),null==a?o:o.get(function(t){return 1===t.length?function(e,r){t(null==e?r:null)}:t}(a))}pe.forEach((function(t,e){pe.set(t,ie(e))})),t.functor=de,t.xhr=me(C),t.dsv=function(t,e){var r=new RegExp('[\"'+t+\"\\n]\"),n=t.charCodeAt(0);function i(t,r,n){arguments.length<3&&(n=r,r=null);var i=ge(t,e,null==r?a:o(r),n);return i.row=function(t){return arguments.length?i.response(null==(r=t)?a:o(t)):r},i}function a(t){return i.parse(t.responseText)}function o(t){return function(e){return i.parse(e.responseText,t)}}function s(e){return e.map(l).join(t)}function l(t){return r.test(t)?'\"'+t.replace(/\\\"/g,'\"\"')+'\"':t}return i.parse=function(t,e){var r;return i.parseRows(t,(function(t,n){if(r)return r(t,n-1);var i=function(e){for(var r={},n=t.length,i=0;i<n;++i)r[t[i]]=e[i];return r};r=e?function(t,r){return e(i(t),r)}:i}))},i.parseRows=function(t,e){var r,i,a={},o={},s=[],l=t.length,c=0,u=0;function f(){if(c>=l)return o;if(i)return i=!1,a;var e=c;if(34===t.charCodeAt(e)){for(var r=e;r++<l;)if(34===t.charCodeAt(r)){if(34!==t.charCodeAt(r+1))break;++r}return c=r+2,13===(s=t.charCodeAt(r+1))?(i=!0,10===t.charCodeAt(r+2)&&++c):10===s&&(i=!0),t.slice(e+1,r).replace(/\"\"/g,'\"')}for(;c<l;){var s,u=1;if(10===(s=t.charCodeAt(c++)))i=!0;else if(13===s)i=!0,10===t.charCodeAt(c)&&(++c,++u);else if(s!==n)continue;return t.slice(e,c-u)}return t.slice(e)}for(;(r=f())!==o;){for(var h=[];r!==a&&r!==o;)h.push(r),r=f();e&&null==(h=e(h,u++))||s.push(h)}return s},i.format=function(e){if(Array.isArray(e[0]))return i.formatRows(e);var r=new L,n=[];return e.forEach((function(t){for(var e in t)r.has(e)||n.push(r.add(e))})),[n.map(l).join(t)].concat(e.map((function(e){return n.map((function(t){return l(e[t])})).join(t)}))).join(\"\\n\")},i.formatRows=function(t){return t.map(s).join(\"\\n\")},i},t.csv=t.dsv(\",\",\"text/csv\"),t.tsv=t.dsv(\"\\t\",\"text/tab-separated-values\");var ve,ye,xe,be,_e=this[I(this,\"requestAnimationFrame\")]||function(t){setTimeout(t,17)};function we(t,e,r){var n=arguments.length;n<2&&(e=0),n<3&&(r=Date.now());var i=r+e,a={c:t,t:i,n:null};return ye?ye.n=a:ve=a,ye=a,xe||(be=clearTimeout(be),xe=1,_e(Te)),a}function Te(){var t=ke(),e=Me()-t;e>24?(isFinite(e)&&(clearTimeout(be),be=setTimeout(Te,e)),xe=0):(xe=1,_e(Te))}function ke(){for(var t=Date.now(),e=ve;e;)t>=e.t&&e.c(t-e.t)&&(e.c=null),e=e.n;return t}function Me(){for(var t,e=ve,r=1/0;e;)e.c?(e.t<r&&(r=e.t),e=(t=e).n):e=t?t.n=e.n:ve=e.n;return ye=t,r}function Ae(t,e){return e-(t?Math.ceil(Math.log(t)/Math.LN10):1)}t.timer=function(){we.apply(this,arguments)},t.timer.flush=function(){ke(),Me()},t.round=function(t,e){return e?Math.round(t*(e=Math.pow(10,e)))/e:Math.round(t)};var Se=[\"y\",\"z\",\"a\",\"f\",\"p\",\"n\",\"\\xb5\",\"m\",\"\",\"k\",\"M\",\"G\",\"T\",\"P\",\"E\",\"Z\",\"Y\"].map((function(t,e){var r=Math.pow(10,3*y(8-e));return{scale:e>8?function(t){return t/r}:function(t){return t*r},symbol:t}}));function Ee(e){var r=e.decimal,n=e.thousands,i=e.grouping,a=e.currency,o=i&&n?function(t,e){for(var r=t.length,a=[],o=0,s=i[0],l=0;r>0&&s>0&&(l+s+1>e&&(s=Math.max(1,e-l)),a.push(t.substring(r-=s,r+s)),!((l+=s+1)>e));)s=i[o=(o+1)%i.length];return a.reverse().join(n)}:C;return function(e){var n=Le.exec(e),i=n[1]||\" \",s=n[2]||\">\",l=n[3]||\"-\",c=n[4]||\"\",u=n[5],f=+n[6],h=n[7],p=n[8],d=n[9],m=1,g=\"\",v=\"\",y=!1,x=!0;switch(p&&(p=+p.substring(1)),(u||\"0\"===i&&\"=\"===s)&&(u=i=\"0\",s=\"=\"),d){case\"n\":h=!0,d=\"g\";break;case\"%\":m=100,v=\"%\",d=\"f\";break;case\"p\":m=100,v=\"%\",d=\"r\";break;case\"b\":case\"o\":case\"x\":case\"X\":\"#\"===c&&(g=\"0\"+d.toLowerCase());case\"c\":x=!1;case\"d\":y=!0,p=0;break;case\"s\":m=-1,d=\"r\"}\"$\"===c&&(g=a[0],v=a[1]),\"r\"!=d||p||(d=\"g\"),null!=p&&(\"g\"==d?p=Math.max(1,Math.min(21,p)):\"e\"!=d&&\"f\"!=d||(p=Math.max(0,Math.min(20,p)))),d=Ce.get(d)||Pe;var b=u&&h;return function(e){var n=v;if(y&&e%1)return\"\";var a=e<0||0===e&&1/e<0?(e=-e,\"-\"):\"-\"===l?\"\":l;if(m<0){var c=t.formatPrefix(e,p);e=c.scale(e),n=c.symbol+v}else e*=m;var _,w,T=(e=d(e,p)).lastIndexOf(\".\");if(T<0){var k=x?e.lastIndexOf(\"e\"):-1;k<0?(_=e,w=\"\"):(_=e.substring(0,k),w=e.substring(k))}else _=e.substring(0,T),w=r+e.substring(T+1);!u&&h&&(_=o(_,1/0));var M=g.length+_.length+w.length+(b?0:a.length),A=M<f?new Array(M=f-M+1).join(i):\"\";return b&&(_=o(A+_,A.length?f-w.length:1/0)),a+=g,e=_+w,(\"<\"===s?a+e+A:\">\"===s?A+a+e:\"^\"===s?A.substring(0,M>>=1)+a+e+A.substring(M):a+(b?e:A+e))+n}}}t.formatPrefix=function(e,r){var n=0;return(e=+e)&&(e<0&&(e*=-1),r&&(e=t.round(e,Ae(e,r))),n=1+Math.floor(1e-12+Math.log(e)/Math.LN10),n=Math.max(-24,Math.min(24,3*Math.floor((n-1)/3)))),Se[8+n/3]};var Le=/(?:([^{])?([<>=^]))?([+\\- ])?([$#])?(0)?(\\d+)?(,)?(\\.-?\\d+)?([a-z%])?/i,Ce=t.map({b:function(t){return t.toString(2)},c:function(t){return String.fromCharCode(t)},o:function(t){return t.toString(8)},x:function(t){return t.toString(16)},X:function(t){return t.toString(16).toUpperCase()},g:function(t,e){return t.toPrecision(e)},e:function(t,e){return t.toExponential(e)},f:function(t,e){return t.toFixed(e)},r:function(e,r){return(e=t.round(e,Ae(e,r))).toFixed(Math.max(0,Math.min(20,Ae(e*(1+1e-15),r))))}});function Pe(t){return t+\"\"}var Ie=t.time={},Oe=Date;function ze(){this._=new Date(arguments.length>1?Date.UTC.apply(this,arguments):arguments[0])}ze.prototype={getDate:function(){return this._.getUTCDate()},getDay:function(){return this._.getUTCDay()},getFullYear:function(){return this._.getUTCFullYear()},getHours:function(){return this._.getUTCHours()},getMilliseconds:function(){return this._.getUTCMilliseconds()},getMinutes:function(){return this._.getUTCMinutes()},getMonth:function(){return this._.getUTCMonth()},getSeconds:function(){return this._.getUTCSeconds()},getTime:function(){return this._.getTime()},getTimezoneOffset:function(){return 0},valueOf:function(){return this._.valueOf()},setDate:function(){De.setUTCDate.apply(this._,arguments)},setDay:function(){De.setUTCDay.apply(this._,arguments)},setFullYear:function(){De.setUTCFullYear.apply(this._,arguments)},setHours:function(){De.setUTCHours.apply(this._,arguments)},setMilliseconds:function(){De.setUTCMilliseconds.apply(this._,arguments)},setMinutes:function(){De.setUTCMinutes.apply(this._,arguments)},setMonth:function(){De.setUTCMonth.apply(this._,arguments)},setSeconds:function(){De.setUTCSeconds.apply(this._,arguments)},setTime:function(){De.setTime.apply(this._,arguments)}};var De=Date.prototype;function Re(t,e,r){function n(e){var r=t(e),n=a(r,1);return e-r<n-e?r:n}function i(r){return e(r=t(new Oe(r-1)),1),r}function a(t,r){return e(t=new Oe(+t),r),t}function o(t,n,a){var o=i(t),s=[];if(a>1)for(;o<n;)r(o)%a||s.push(new Date(+o)),e(o,1);else for(;o<n;)s.push(new Date(+o)),e(o,1);return s}t.floor=t,t.round=n,t.ceil=i,t.offset=a,t.range=o;var s=t.utc=Fe(t);return s.floor=s,s.round=Fe(n),s.ceil=Fe(i),s.offset=Fe(a),s.range=function(t,e,r){try{Oe=ze;var n=new ze;return n._=t,o(n,e,r)}finally{Oe=Date}},t}function Fe(t){return function(e,r){try{Oe=ze;var n=new ze;return n._=e,t(n,r)._}finally{Oe=Date}}}function Be(e){var r=e.dateTime,n=e.date,i=e.time,a=e.periods,o=e.days,s=e.shortDays,l=e.months,c=e.shortMonths;function u(t){var e=t.length;function r(r){for(var n,i,a,o=[],s=-1,l=0;++s<e;)37===t.charCodeAt(s)&&(o.push(t.slice(l,s)),null!=(i=Ne[n=t.charAt(++s)])&&(n=t.charAt(++s)),(a=_[n])&&(n=a(r,null==i?\"e\"===n?\" \":\"0\":i)),o.push(n),l=s+1);return o.push(t.slice(l,s)),o.join(\"\")}return r.parse=function(e){var r={y:1900,m:0,d:1,H:0,M:0,S:0,L:0,Z:null};if(f(r,t,e,0)!=e.length)return null;\"p\"in r&&(r.H=r.H%12+12*r.p);var n=null!=r.Z&&Oe!==ze,i=new(n?ze:Oe);return\"j\"in r?i.setFullYear(r.y,0,r.j):\"W\"in r||\"U\"in r?(\"w\"in r||(r.w=\"W\"in r?1:0),i.setFullYear(r.y,0,1),i.setFullYear(r.y,0,\"W\"in r?(r.w+6)%7+7*r.W-(i.getDay()+5)%7:r.w+7*r.U-(i.getDay()+6)%7)):i.setFullYear(r.y,r.m,r.d),i.setHours(r.H+(r.Z/100|0),r.M+r.Z%100,r.S,r.L),n?i._:i},r.toString=function(){return t},r}function f(t,e,r,n){for(var i,a,o,s=0,l=e.length,c=r.length;s<l;){if(n>=c)return-1;if(37===(i=e.charCodeAt(s++))){if(o=e.charAt(s++),!(a=w[o in Ne?e.charAt(s++):o])||(n=a(t,r,n))<0)return-1}else if(i!=r.charCodeAt(n++))return-1}return n}u.utc=function(t){var e=u(t);function r(t){try{var r=new(Oe=ze);return r._=t,e(r)}finally{Oe=Date}}return r.parse=function(t){try{Oe=ze;var r=e.parse(t);return r&&r._}finally{Oe=Date}},r.toString=e.toString,r},u.multi=u.utc.multi=or;var h=t.map(),p=qe(o),d=He(o),m=qe(s),g=He(s),v=qe(l),y=He(l),x=qe(c),b=He(c);a.forEach((function(t,e){h.set(t.toLowerCase(),e)}));var _={a:function(t){return s[t.getDay()]},A:function(t){return o[t.getDay()]},b:function(t){return c[t.getMonth()]},B:function(t){return l[t.getMonth()]},c:u(r),d:function(t,e){return Ve(t.getDate(),e,2)},e:function(t,e){return Ve(t.getDate(),e,2)},H:function(t,e){return Ve(t.getHours(),e,2)},I:function(t,e){return Ve(t.getHours()%12||12,e,2)},j:function(t,e){return Ve(1+Ie.dayOfYear(t),e,3)},L:function(t,e){return Ve(t.getMilliseconds(),e,3)},m:function(t,e){return Ve(t.getMonth()+1,e,2)},M:function(t,e){return Ve(t.getMinutes(),e,2)},p:function(t){return a[+(t.getHours()>=12)]},S:function(t,e){return Ve(t.getSeconds(),e,2)},U:function(t,e){return Ve(Ie.sundayOfYear(t),e,2)},w:function(t){return t.getDay()},W:function(t,e){return Ve(Ie.mondayOfYear(t),e,2)},x:u(n),X:u(i),y:function(t,e){return Ve(t.getFullYear()%100,e,2)},Y:function(t,e){return Ve(t.getFullYear()%1e4,e,4)},Z:ir,\"%\":function(){return\"%\"}},w={a:function(t,e,r){m.lastIndex=0;var n=m.exec(e.slice(r));return n?(t.w=g.get(n[0].toLowerCase()),r+n[0].length):-1},A:function(t,e,r){p.lastIndex=0;var n=p.exec(e.slice(r));return n?(t.w=d.get(n[0].toLowerCase()),r+n[0].length):-1},b:function(t,e,r){x.lastIndex=0;var n=x.exec(e.slice(r));return n?(t.m=b.get(n[0].toLowerCase()),r+n[0].length):-1},B:function(t,e,r){v.lastIndex=0;var n=v.exec(e.slice(r));return n?(t.m=y.get(n[0].toLowerCase()),r+n[0].length):-1},c:function(t,e,r){return f(t,_.c.toString(),e,r)},d:Qe,e:Qe,H:tr,I:tr,j:$e,L:nr,m:Ke,M:er,p:function(t,e,r){var n=h.get(e.slice(r,r+=2).toLowerCase());return null==n?-1:(t.p=n,r)},S:rr,U:Ye,w:Ge,W:We,x:function(t,e,r){return f(t,_.x.toString(),e,r)},X:function(t,e,r){return f(t,_.X.toString(),e,r)},y:Ze,Y:Xe,Z:Je,\"%\":ar};return u}Ie.year=Re((function(t){return(t=Ie.day(t)).setMonth(0,1),t}),(function(t,e){t.setFullYear(t.getFullYear()+e)}),(function(t){return t.getFullYear()})),Ie.years=Ie.year.range,Ie.years.utc=Ie.year.utc.range,Ie.day=Re((function(t){var e=new Oe(2e3,0);return e.setFullYear(t.getFullYear(),t.getMonth(),t.getDate()),e}),(function(t,e){t.setDate(t.getDate()+e)}),(function(t){return t.getDate()-1})),Ie.days=Ie.day.range,Ie.days.utc=Ie.day.utc.range,Ie.dayOfYear=function(t){var e=Ie.year(t);return Math.floor((t-e-6e4*(t.getTimezoneOffset()-e.getTimezoneOffset()))/864e5)},[\"sunday\",\"monday\",\"tuesday\",\"wednesday\",\"thursday\",\"friday\",\"saturday\"].forEach((function(t,e){e=7-e;var r=Ie[t]=Re((function(t){return(t=Ie.day(t)).setDate(t.getDate()-(t.getDay()+e)%7),t}),(function(t,e){t.setDate(t.getDate()+7*Math.floor(e))}),(function(t){var r=Ie.year(t).getDay();return Math.floor((Ie.dayOfYear(t)+(r+e)%7)/7)-(r!==e)}));Ie[t+\"s\"]=r.range,Ie[t+\"s\"].utc=r.utc.range,Ie[t+\"OfYear\"]=function(t){var r=Ie.year(t).getDay();return Math.floor((Ie.dayOfYear(t)+(r+e)%7)/7)}})),Ie.week=Ie.sunday,Ie.weeks=Ie.sunday.range,Ie.weeks.utc=Ie.sunday.utc.range,Ie.weekOfYear=Ie.sundayOfYear;var Ne={\"-\":\"\",_:\" \",0:\"0\"},je=/^\\s*\\d+/,Ue=/^%/;function Ve(t,e,r){var n=t<0?\"-\":\"\",i=(n?-t:t)+\"\",a=i.length;return n+(a<r?new Array(r-a+1).join(e)+i:i)}function qe(e){return new RegExp(\"^(?:\"+e.map(t.requote).join(\"|\")+\")\",\"i\")}function He(t){for(var e=new _,r=-1,n=t.length;++r<n;)e.set(t[r].toLowerCase(),r);return e}function Ge(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+1));return n?(t.w=+n[0],r+n[0].length):-1}function Ye(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r));return n?(t.U=+n[0],r+n[0].length):-1}function We(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r));return n?(t.W=+n[0],r+n[0].length):-1}function Xe(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+4));return n?(t.y=+n[0],r+n[0].length):-1}function Ze(t,e,r){je.lastIndex=0;var n,i=je.exec(e.slice(r,r+2));return i?(t.y=(n=+i[0])+(n>68?1900:2e3),r+i[0].length):-1}function Je(t,e,r){return/^[+-]\\d{4}$/.test(e=e.slice(r,r+5))?(t.Z=-e,r+5):-1}function Ke(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+2));return n?(t.m=n[0]-1,r+n[0].length):-1}function Qe(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+2));return n?(t.d=+n[0],r+n[0].length):-1}function $e(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+3));return n?(t.j=+n[0],r+n[0].length):-1}function tr(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+2));return n?(t.H=+n[0],r+n[0].length):-1}function er(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+2));return n?(t.M=+n[0],r+n[0].length):-1}function rr(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+2));return n?(t.S=+n[0],r+n[0].length):-1}function nr(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+3));return n?(t.L=+n[0],r+n[0].length):-1}function ir(t){var e=t.getTimezoneOffset(),r=e>0?\"-\":\"+\",n=y(e)/60|0,i=y(e)%60;return r+Ve(n,\"0\",2)+Ve(i,\"0\",2)}function ar(t,e,r){Ue.lastIndex=0;var n=Ue.exec(e.slice(r,r+1));return n?r+n[0].length:-1}function or(t){for(var e=t.length,r=-1;++r<e;)t[r][0]=this(t[r][0]);return function(e){for(var r=0,n=t[r];!n[1](e);)n=t[++r];return n[0](e)}}t.locale=function(t){return{numberFormat:Ee(t),timeFormat:Be(t)}};var sr=t.locale({decimal:\".\",thousands:\",\",grouping:[3],currency:[\"$\",\"\"],dateTime:\"%a %b %e %X %Y\",date:\"%m/%d/%Y\",time:\"%H:%M:%S\",periods:[\"AM\",\"PM\"],days:[\"Sunday\",\"Monday\",\"Tuesday\",\"Wednesday\",\"Thursday\",\"Friday\",\"Saturday\"],shortDays:[\"Sun\",\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\"],months:[\"January\",\"February\",\"March\",\"April\",\"May\",\"June\",\"July\",\"August\",\"September\",\"October\",\"November\",\"December\"],shortMonths:[\"Jan\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\"Jul\",\"Aug\",\"Sep\",\"Oct\",\"Nov\",\"Dec\"]});function lr(){}t.format=sr.numberFormat,t.geo={},lr.prototype={s:0,t:0,add:function(t){ur(t,this.t,cr),ur(cr.s,this.s,this),this.s?this.t+=cr.t:this.s=cr.t},reset:function(){this.s=this.t=0},valueOf:function(){return this.s}};var cr=new lr;function ur(t,e,r){var n=r.s=t+e,i=n-t,a=n-i;r.t=t-a+(e-i)}function fr(t,e){t&&pr.hasOwnProperty(t.type)&&pr[t.type](t,e)}t.geo.stream=function(t,e){t&&hr.hasOwnProperty(t.type)?hr[t.type](t,e):fr(t,e)};var hr={Feature:function(t,e){fr(t.geometry,e)},FeatureCollection:function(t,e){for(var r=t.features,n=-1,i=r.length;++n<i;)fr(r[n].geometry,e)}},pr={Sphere:function(t,e){e.sphere()},Point:function(t,e){t=t.coordinates,e.point(t[0],t[1],t[2])},MultiPoint:function(t,e){for(var r=t.coordinates,n=-1,i=r.length;++n<i;)t=r[n],e.point(t[0],t[1],t[2])},LineString:function(t,e){dr(t.coordinates,e,0)},MultiLineString:function(t,e){for(var r=t.coordinates,n=-1,i=r.length;++n<i;)dr(r[n],e,0)},Polygon:function(t,e){mr(t.coordinates,e)},MultiPolygon:function(t,e){for(var r=t.coordinates,n=-1,i=r.length;++n<i;)mr(r[n],e)},GeometryCollection:function(t,e){for(var r=t.geometries,n=-1,i=r.length;++n<i;)fr(r[n],e)}};function dr(t,e,r){var n,i=-1,a=t.length-r;for(e.lineStart();++i<a;)n=t[i],e.point(n[0],n[1],n[2]);e.lineEnd()}function mr(t,e){var r=-1,n=t.length;for(e.polygonStart();++r<n;)dr(t[r],e,1);e.polygonEnd()}t.geo.area=function(e){return gr=0,t.geo.stream(e,Lr),gr};var gr,vr,yr,xr,br,_r,wr,Tr,kr,Mr,Ar,Sr,Er=new lr,Lr={sphere:function(){gr+=4*At},point:z,lineStart:z,lineEnd:z,polygonStart:function(){Er.reset(),Lr.lineStart=Cr},polygonEnd:function(){var t=2*Er;gr+=t<0?4*At+t:t,Lr.lineStart=Lr.lineEnd=Lr.point=z}};function Cr(){var t,e,r,n,i;function a(t,e){e=e*Ct/2+At/4;var a=(t*=Ct)-r,o=a>=0?1:-1,s=o*a,l=Math.cos(e),c=Math.sin(e),u=i*c,f=n*l+u*Math.cos(s),h=u*o*Math.sin(s);Er.add(Math.atan2(h,f)),r=t,n=l,i=c}Lr.point=function(o,s){Lr.point=a,r=(t=o)*Ct,n=Math.cos(s=(e=s)*Ct/2+At/4),i=Math.sin(s)},Lr.lineEnd=function(){a(t,e)}}function Pr(t){var e=t[0],r=t[1],n=Math.cos(r);return[n*Math.cos(e),n*Math.sin(e),Math.sin(r)]}function Ir(t,e){return t[0]*e[0]+t[1]*e[1]+t[2]*e[2]}function Or(t,e){return[t[1]*e[2]-t[2]*e[1],t[2]*e[0]-t[0]*e[2],t[0]*e[1]-t[1]*e[0]]}function zr(t,e){t[0]+=e[0],t[1]+=e[1],t[2]+=e[2]}function Dr(t,e){return[t[0]*e,t[1]*e,t[2]*e]}function Rr(t){var e=Math.sqrt(t[0]*t[0]+t[1]*t[1]+t[2]*t[2]);t[0]/=e,t[1]/=e,t[2]/=e}function Fr(t){return[Math.atan2(t[1],t[0]),Dt(t[2])]}function Br(t,e){return y(t[0]-e[0])<kt&&y(t[1]-e[1])<kt}t.geo.bounds=function(){var e,r,n,i,a,o,s,l,c,u,f,h={point:p,lineStart:m,lineEnd:g,polygonStart:function(){h.point=v,h.lineStart=x,h.lineEnd=b,c=0,Lr.polygonStart()},polygonEnd:function(){Lr.polygonEnd(),h.point=p,h.lineStart=m,h.lineEnd=g,Er<0?(e=-(n=180),r=-(i=90)):c>kt?i=90:c<-kt&&(r=-90),f[0]=e,f[1]=n}};function p(t,a){u.push(f=[e=t,n=t]),a<r&&(r=a),a>i&&(i=a)}function d(t,o){var s=Pr([t*Ct,o*Ct]);if(l){var c=Or(l,s),u=Or([c[1],-c[0],0],c);Rr(u),u=Fr(u);var f=t-a,h=f>0?1:-1,d=u[0]*Pt*h,m=y(f)>180;if(m^(h*a<d&&d<h*t))(g=u[1]*Pt)>i&&(i=g);else if(m^(h*a<(d=(d+360)%360-180)&&d<h*t)){var g;(g=-u[1]*Pt)<r&&(r=g)}else o<r&&(r=o),o>i&&(i=o);m?t<a?_(e,t)>_(e,n)&&(n=t):_(t,n)>_(e,n)&&(e=t):n>=e?(t<e&&(e=t),t>n&&(n=t)):t>a?_(e,t)>_(e,n)&&(n=t):_(t,n)>_(e,n)&&(e=t)}else p(t,o);l=s,a=t}function m(){h.point=d}function g(){f[0]=e,f[1]=n,h.point=p,l=null}function v(t,e){if(l){var r=t-a;c+=y(r)>180?r+(r>0?360:-360):r}else o=t,s=e;Lr.point(t,e),d(t,e)}function x(){Lr.lineStart()}function b(){v(o,s),Lr.lineEnd(),y(c)>kt&&(e=-(n=180)),f[0]=e,f[1]=n,l=null}function _(t,e){return(e-=t)<0?e+360:e}function w(t,e){return t[0]-e[0]}function T(t,e){return e[0]<=e[1]?e[0]<=t&&t<=e[1]:t<e[0]||e[1]<t}return function(a){if(i=n=-(e=r=1/0),u=[],t.geo.stream(a,h),c=u.length){u.sort(w);for(var o=1,s=[m=u[0]];o<c;++o)T((p=u[o])[0],m)||T(p[1],m)?(_(m[0],p[1])>_(m[0],m[1])&&(m[1]=p[1]),_(p[0],m[1])>_(m[0],m[1])&&(m[0]=p[0])):s.push(m=p);for(var l,c,p,d=-1/0,m=(o=0,s[c=s.length-1]);o<=c;m=p,++o)p=s[o],(l=_(m[1],p[0]))>d&&(d=l,e=p[0],n=m[1])}return u=f=null,e===1/0||r===1/0?[[NaN,NaN],[NaN,NaN]]:[[e,r],[n,i]]}}(),t.geo.centroid=function(e){vr=yr=xr=br=_r=wr=Tr=kr=Mr=Ar=Sr=0,t.geo.stream(e,Nr);var r=Mr,n=Ar,i=Sr,a=r*r+n*n+i*i;return a<Mt&&(r=wr,n=Tr,i=kr,yr<kt&&(r=xr,n=br,i=_r),(a=r*r+n*n+i*i)<Mt)?[NaN,NaN]:[Math.atan2(n,r)*Pt,Dt(i/Math.sqrt(a))*Pt]};var Nr={sphere:z,point:jr,lineStart:Vr,lineEnd:qr,polygonStart:function(){Nr.lineStart=Hr},polygonEnd:function(){Nr.lineStart=Vr}};function jr(t,e){t*=Ct;var r=Math.cos(e*=Ct);Ur(r*Math.cos(t),r*Math.sin(t),Math.sin(e))}function Ur(t,e,r){++vr,xr+=(t-xr)/vr,br+=(e-br)/vr,_r+=(r-_r)/vr}function Vr(){var t,e,r;function n(n,i){n*=Ct;var a=Math.cos(i*=Ct),o=a*Math.cos(n),s=a*Math.sin(n),l=Math.sin(i),c=Math.atan2(Math.sqrt((c=e*l-r*s)*c+(c=r*o-t*l)*c+(c=t*s-e*o)*c),t*o+e*s+r*l);yr+=c,wr+=c*(t+(t=o)),Tr+=c*(e+(e=s)),kr+=c*(r+(r=l)),Ur(t,e,r)}Nr.point=function(i,a){i*=Ct;var o=Math.cos(a*=Ct);t=o*Math.cos(i),e=o*Math.sin(i),r=Math.sin(a),Nr.point=n,Ur(t,e,r)}}function qr(){Nr.point=jr}function Hr(){var t,e,r,n,i;function a(t,e){t*=Ct;var a=Math.cos(e*=Ct),o=a*Math.cos(t),s=a*Math.sin(t),l=Math.sin(e),c=n*l-i*s,u=i*o-r*l,f=r*s-n*o,h=Math.sqrt(c*c+u*u+f*f),p=r*o+n*s+i*l,d=h&&-zt(p)/h,m=Math.atan2(h,p);Mr+=d*c,Ar+=d*u,Sr+=d*f,yr+=m,wr+=m*(r+(r=o)),Tr+=m*(n+(n=s)),kr+=m*(i+(i=l)),Ur(r,n,i)}Nr.point=function(o,s){t=o,e=s,Nr.point=a,o*=Ct;var l=Math.cos(s*=Ct);r=l*Math.cos(o),n=l*Math.sin(o),i=Math.sin(s),Ur(r,n,i)},Nr.lineEnd=function(){a(t,e),Nr.lineEnd=qr,Nr.point=jr}}function Gr(t,e){function r(r,n){return r=t(r,n),e(r[0],r[1])}return t.invert&&e.invert&&(r.invert=function(r,n){return(r=e.invert(r,n))&&t.invert(r[0],r[1])}),r}function Yr(){return!0}function Wr(t,e,r,n,i){var a=[],o=[];if(t.forEach((function(t){if(!((e=t.length-1)<=0)){var e,r=t[0],n=t[e];if(Br(r,n)){i.lineStart();for(var s=0;s<e;++s)i.point((r=t[s])[0],r[1]);i.lineEnd()}else{var l=new Zr(r,t,null,!0),c=new Zr(r,null,l,!1);l.o=c,a.push(l),o.push(c),l=new Zr(n,t,null,!1),c=new Zr(n,null,l,!0),l.o=c,a.push(l),o.push(c)}}})),o.sort(e),Xr(a),Xr(o),a.length){for(var s=0,l=r,c=o.length;s<c;++s)o[s].e=l=!l;for(var u,f,h=a[0];;){for(var p=h,d=!0;p.v;)if((p=p.n)===h)return;u=p.z,i.lineStart();do{if(p.v=p.o.v=!0,p.e){if(d)for(s=0,c=u.length;s<c;++s)i.point((f=u[s])[0],f[1]);else n(p.x,p.n.x,1,i);p=p.n}else{if(d)for(s=(u=p.p.z).length-1;s>=0;--s)i.point((f=u[s])[0],f[1]);else n(p.x,p.p.x,-1,i);p=p.p}u=(p=p.o).z,d=!d}while(!p.v);i.lineEnd()}}}function Xr(t){if(e=t.length){for(var e,r,n=0,i=t[0];++n<e;)i.n=r=t[n],r.p=i,i=r;i.n=r=t[0],r.p=i}}function Zr(t,e,r,n){this.x=t,this.z=e,this.o=r,this.e=n,this.v=!1,this.n=this.p=null}function Jr(e,r,n,i){return function(a,o){var s,l=r(o),c=a.invert(i[0],i[1]),u={point:f,lineStart:p,lineEnd:d,polygonStart:function(){u.point=b,u.lineStart=_,u.lineEnd=w,s=[],m=[]},polygonEnd:function(){u.point=f,u.lineStart=p,u.lineEnd=d,s=t.merge(s);var e=function(t,e){var r=t[0],n=t[1],i=[Math.sin(r),-Math.cos(r),0],a=0,o=0;Er.reset();for(var s=0,l=e.length;s<l;++s){var c=e[s],u=c.length;if(u)for(var f=c[0],h=f[0],p=f[1]/2+At/4,d=Math.sin(p),m=Math.cos(p),g=1;;){g===u&&(g=0);var v=(t=c[g])[0],y=t[1]/2+At/4,x=Math.sin(y),b=Math.cos(y),_=v-h,w=_>=0?1:-1,T=w*_,k=T>At,M=d*x;if(Er.add(Math.atan2(M*w*Math.sin(T),m*b+M*Math.cos(T))),a+=k?_+w*St:_,k^h>=r^v>=r){var A=Or(Pr(f),Pr(t));Rr(A);var S=Or(i,A);Rr(S);var E=(k^_>=0?-1:1)*Dt(S[2]);(n>E||n===E&&(A[0]||A[1]))&&(o+=k^_>=0?1:-1)}if(!g++)break;h=v,d=x,m=b,f=t}}return(a<-kt||a<kt&&Er<-kt)^1&o}(c,m);s.length?(x||(o.polygonStart(),x=!0),Wr(s,$r,e,n,o)):e&&(x||(o.polygonStart(),x=!0),o.lineStart(),n(null,null,1,o),o.lineEnd()),x&&(o.polygonEnd(),x=!1),s=m=null},sphere:function(){o.polygonStart(),o.lineStart(),n(null,null,1,o),o.lineEnd(),o.polygonEnd()}};function f(t,r){var n=a(t,r);e(t=n[0],r=n[1])&&o.point(t,r)}function h(t,e){var r=a(t,e);l.point(r[0],r[1])}function p(){u.point=h,l.lineStart()}function d(){u.point=f,l.lineEnd()}var m,g,v=Qr(),y=r(v),x=!1;function b(t,e){g.push([t,e]);var r=a(t,e);y.point(r[0],r[1])}function _(){y.lineStart(),g=[]}function w(){b(g[0][0],g[0][1]),y.lineEnd();var t,e=y.clean(),r=v.buffer(),n=r.length;if(g.pop(),m.push(g),g=null,n)if(1&e){var i,a=-1;if((n=(t=r[0]).length-1)>0){for(x||(o.polygonStart(),x=!0),o.lineStart();++a<n;)o.point((i=t[a])[0],i[1]);o.lineEnd()}}else n>1&&2&e&&r.push(r.pop().concat(r.shift())),s.push(r.filter(Kr))}return u}}function Kr(t){return t.length>1}function Qr(){var t,e=[];return{lineStart:function(){e.push(t=[])},point:function(e,r){t.push([e,r])},lineEnd:z,buffer:function(){var r=e;return e=[],t=null,r},rejoin:function(){e.length>1&&e.push(e.pop().concat(e.shift()))}}}function $r(t,e){return((t=t.x)[0]<0?t[1]-Lt-kt:Lt-t[1])-((e=e.x)[0]<0?e[1]-Lt-kt:Lt-e[1])}var tn=Jr(Yr,(function(t){var e,r=NaN,n=NaN,i=NaN;return{lineStart:function(){t.lineStart(),e=1},point:function(a,o){var s=a>0?At:-At,l=y(a-r);y(l-At)<kt?(t.point(r,n=(n+o)/2>0?Lt:-Lt),t.point(i,n),t.lineEnd(),t.lineStart(),t.point(s,n),t.point(a,n),e=0):i!==s&&l>=At&&(y(r-i)<kt&&(r-=i*kt),y(a-s)<kt&&(a-=s*kt),n=function(t,e,r,n){var i,a,o=Math.sin(t-r);return y(o)>kt?Math.atan((Math.sin(e)*(a=Math.cos(n))*Math.sin(r)-Math.sin(n)*(i=Math.cos(e))*Math.sin(t))/(i*a*o)):(e+n)/2}(r,n,a,o),t.point(i,n),t.lineEnd(),t.lineStart(),t.point(s,n),e=0),t.point(r=a,n=o),i=s},lineEnd:function(){t.lineEnd(),r=n=NaN},clean:function(){return 2-e}}}),(function(t,e,r,n){var i;if(null==t)i=r*Lt,n.point(-At,i),n.point(0,i),n.point(At,i),n.point(At,0),n.point(At,-i),n.point(0,-i),n.point(-At,-i),n.point(-At,0),n.point(-At,i);else if(y(t[0]-e[0])>kt){var a=t[0]<e[0]?At:-At;i=r*a/2,n.point(-a,i),n.point(0,i),n.point(a,i)}else n.point(e[0],e[1])}),[-At,-At/2]);function en(t){var e=Math.cos(t),r=e>0,n=y(e)>kt;return Jr(i,(function(t){var e,s,l,c,u;return{lineStart:function(){c=l=!1,u=1},point:function(f,h){var p,d=[f,h],m=i(f,h),g=r?m?0:o(f,h):m?o(f+(f<0?At:-At),h):0;if(!e&&(c=l=m)&&t.lineStart(),m!==l&&(p=a(e,d),(Br(e,p)||Br(d,p))&&(d[0]+=kt,d[1]+=kt,m=i(d[0],d[1]))),m!==l)u=0,m?(t.lineStart(),p=a(d,e),t.point(p[0],p[1])):(p=a(e,d),t.point(p[0],p[1]),t.lineEnd()),e=p;else if(n&&e&&r^m){var v;g&s||!(v=a(d,e,!0))||(u=0,r?(t.lineStart(),t.point(v[0][0],v[0][1]),t.point(v[1][0],v[1][1]),t.lineEnd()):(t.point(v[1][0],v[1][1]),t.lineEnd(),t.lineStart(),t.point(v[0][0],v[0][1])))}!m||e&&Br(e,d)||t.point(d[0],d[1]),e=d,l=m,s=g},lineEnd:function(){l&&t.lineEnd(),e=null},clean:function(){return u|(c&&l)<<1}}}),Bn(t,6*Ct),r?[0,-t]:[-At,t-At]);function i(t,r){return Math.cos(t)*Math.cos(r)>e}function a(t,r,n){var i=[1,0,0],a=Or(Pr(t),Pr(r)),o=Ir(a,a),s=a[0],l=o-s*s;if(!l)return!n&&t;var c=e*o/l,u=-e*s/l,f=Or(i,a),h=Dr(i,c);zr(h,Dr(a,u));var p=f,d=Ir(h,p),m=Ir(p,p),g=d*d-m*(Ir(h,h)-1);if(!(g<0)){var v=Math.sqrt(g),x=Dr(p,(-d-v)/m);if(zr(x,h),x=Fr(x),!n)return x;var b,_=t[0],w=r[0],T=t[1],k=r[1];w<_&&(b=_,_=w,w=b);var M=w-_,A=y(M-At)<kt;if(!A&&k<T&&(b=T,T=k,k=b),A||M<kt?A?T+k>0^x[1]<(y(x[0]-_)<kt?T:k):T<=x[1]&&x[1]<=k:M>At^(_<=x[0]&&x[0]<=w)){var S=Dr(p,(-d+v)/m);return zr(S,h),[x,Fr(S)]}}}function o(e,n){var i=r?t:At-t,a=0;return e<-i?a|=1:e>i&&(a|=2),n<-i?a|=4:n>i&&(a|=8),a}}function rn(t,e,r,n){return function(i){var a,o=i.a,s=i.b,l=o.x,c=o.y,u=0,f=1,h=s.x-l,p=s.y-c;if(a=t-l,h||!(a>0)){if(a/=h,h<0){if(a<u)return;a<f&&(f=a)}else if(h>0){if(a>f)return;a>u&&(u=a)}if(a=r-l,h||!(a<0)){if(a/=h,h<0){if(a>f)return;a>u&&(u=a)}else if(h>0){if(a<u)return;a<f&&(f=a)}if(a=e-c,p||!(a>0)){if(a/=p,p<0){if(a<u)return;a<f&&(f=a)}else if(p>0){if(a>f)return;a>u&&(u=a)}if(a=n-c,p||!(a<0)){if(a/=p,p<0){if(a>f)return;a>u&&(u=a)}else if(p>0){if(a<u)return;a<f&&(f=a)}return u>0&&(i.a={x:l+u*h,y:c+u*p}),f<1&&(i.b={x:l+f*h,y:c+f*p}),i}}}}}}function nn(e,r,n,i){return function(l){var c,u,f,h,p,d,m,g,v,y,x,b=l,_=Qr(),w=rn(e,r,n,i),T={point:A,lineStart:function(){T.point=S,u&&u.push(f=[]);y=!0,v=!1,m=g=NaN},lineEnd:function(){c&&(S(h,p),d&&v&&_.rejoin(),c.push(_.buffer()));T.point=A,v&&l.lineEnd()},polygonStart:function(){l=_,c=[],u=[],x=!0},polygonEnd:function(){l=b,c=t.merge(c);var r=function(t){for(var e=0,r=u.length,n=t[1],i=0;i<r;++i)for(var a,o=1,s=u[i],l=s.length,c=s[0];o<l;++o)a=s[o],c[1]<=n?a[1]>n&&Ot(c,a,t)>0&&++e:a[1]<=n&&Ot(c,a,t)<0&&--e,c=a;return 0!==e}([e,i]),n=x&&r,a=c.length;(n||a)&&(l.polygonStart(),n&&(l.lineStart(),k(null,null,1,l),l.lineEnd()),a&&Wr(c,o,r,k,l),l.polygonEnd()),c=u=f=null}};function k(t,o,l,c){var u=0,f=0;if(null==t||(u=a(t,l))!==(f=a(o,l))||s(t,o)<0^l>0)do{c.point(0===u||3===u?e:n,u>1?i:r)}while((u=(u+l+4)%4)!==f);else c.point(o[0],o[1])}function M(t,a){return e<=t&&t<=n&&r<=a&&a<=i}function A(t,e){M(t,e)&&l.point(t,e)}function S(t,e){var r=M(t=Math.max(-1e9,Math.min(1e9,t)),e=Math.max(-1e9,Math.min(1e9,e)));if(u&&f.push([t,e]),y)h=t,p=e,d=r,y=!1,r&&(l.lineStart(),l.point(t,e));else if(r&&v)l.point(t,e);else{var n={a:{x:m,y:g},b:{x:t,y:e}};w(n)?(v||(l.lineStart(),l.point(n.a.x,n.a.y)),l.point(n.b.x,n.b.y),r||l.lineEnd(),x=!1):r&&(l.lineStart(),l.point(t,e),x=!1)}m=t,g=e,v=r}return T};function a(t,i){return y(t[0]-e)<kt?i>0?0:3:y(t[0]-n)<kt?i>0?2:1:y(t[1]-r)<kt?i>0?1:0:i>0?3:2}function o(t,e){return s(t.x,e.x)}function s(t,e){var r=a(t,1),n=a(e,1);return r!==n?r-n:0===r?e[1]-t[1]:1===r?t[0]-e[0]:2===r?t[1]-e[1]:e[0]-t[0]}}function an(t){var e=0,r=At/3,n=Cn(t),i=n(e,r);return i.parallels=function(t){return arguments.length?n(e=t[0]*At/180,r=t[1]*At/180):[e/At*180,r/At*180]},i}function on(t,e){var r=Math.sin(t),n=(r+Math.sin(e))/2,i=1+r*(2*n-r),a=Math.sqrt(i)/n;function o(t,e){var r=Math.sqrt(i-2*n*Math.sin(e))/n;return[r*Math.sin(t*=n),a-r*Math.cos(t)]}return o.invert=function(t,e){var r=a-e;return[Math.atan2(t,r)/n,Dt((i-(t*t+r*r)*n*n)/(2*n))]},o}t.geo.clipExtent=function(){var t,e,r,n,i,a,o={stream:function(t){return i&&(i.valid=!1),(i=a(t)).valid=!0,i},extent:function(s){return arguments.length?(a=nn(t=+s[0][0],e=+s[0][1],r=+s[1][0],n=+s[1][1]),i&&(i.valid=!1,i=null),o):[[t,e],[r,n]]}};return o.extent([[0,0],[960,500]])},(t.geo.conicEqualArea=function(){return an(on)}).raw=on,t.geo.albers=function(){return t.geo.conicEqualArea().rotate([96,0]).center([-.6,38.7]).parallels([29.5,45.5]).scale(1070)},t.geo.albersUsa=function(){var e,r,n,i,a=t.geo.albers(),o=t.geo.conicEqualArea().rotate([154,0]).center([-2,58.5]).parallels([55,65]),s=t.geo.conicEqualArea().rotate([157,0]).center([-3,19.9]).parallels([8,18]),l={point:function(t,r){e=[t,r]}};function c(t){var a=t[0],o=t[1];return e=null,r(a,o),e||(n(a,o),e)||i(a,o),e}return c.invert=function(t){var e=a.scale(),r=a.translate(),n=(t[0]-r[0])/e,i=(t[1]-r[1])/e;return(i>=.12&&i<.234&&n>=-.425&&n<-.214?o:i>=.166&&i<.234&&n>=-.214&&n<-.115?s:a).invert(t)},c.stream=function(t){var e=a.stream(t),r=o.stream(t),n=s.stream(t);return{point:function(t,i){e.point(t,i),r.point(t,i),n.point(t,i)},sphere:function(){e.sphere(),r.sphere(),n.sphere()},lineStart:function(){e.lineStart(),r.lineStart(),n.lineStart()},lineEnd:function(){e.lineEnd(),r.lineEnd(),n.lineEnd()},polygonStart:function(){e.polygonStart(),r.polygonStart(),n.polygonStart()},polygonEnd:function(){e.polygonEnd(),r.polygonEnd(),n.polygonEnd()}}},c.precision=function(t){return arguments.length?(a.precision(t),o.precision(t),s.precision(t),c):a.precision()},c.scale=function(t){return arguments.length?(a.scale(t),o.scale(.35*t),s.scale(t),c.translate(a.translate())):a.scale()},c.translate=function(t){if(!arguments.length)return a.translate();var e=a.scale(),u=+t[0],f=+t[1];return r=a.translate(t).clipExtent([[u-.455*e,f-.238*e],[u+.455*e,f+.238*e]]).stream(l).point,n=o.translate([u-.307*e,f+.201*e]).clipExtent([[u-.425*e+kt,f+.12*e+kt],[u-.214*e-kt,f+.234*e-kt]]).stream(l).point,i=s.translate([u-.205*e,f+.212*e]).clipExtent([[u-.214*e+kt,f+.166*e+kt],[u-.115*e-kt,f+.234*e-kt]]).stream(l).point,c},c.scale(1070)};var sn,ln,cn,un,fn,hn,pn={point:z,lineStart:z,lineEnd:z,polygonStart:function(){ln=0,pn.lineStart=dn},polygonEnd:function(){pn.lineStart=pn.lineEnd=pn.point=z,sn+=y(ln/2)}};function dn(){var t,e,r,n;function i(t,e){ln+=n*t-r*e,r=t,n=e}pn.point=function(a,o){pn.point=i,t=r=a,e=n=o},pn.lineEnd=function(){i(t,e)}}var mn={point:function(t,e){t<cn&&(cn=t);t>fn&&(fn=t);e<un&&(un=e);e>hn&&(hn=e)},lineStart:z,lineEnd:z,polygonStart:z,polygonEnd:z};function gn(){var t=vn(4.5),e=[],r={point:n,lineStart:function(){r.point=i},lineEnd:o,polygonStart:function(){r.lineEnd=s},polygonEnd:function(){r.lineEnd=o,r.point=n},pointRadius:function(e){return t=vn(e),r},result:function(){if(e.length){var t=e.join(\"\");return e=[],t}}};function n(r,n){e.push(\"M\",r,\",\",n,t)}function i(t,n){e.push(\"M\",t,\",\",n),r.point=a}function a(t,r){e.push(\"L\",t,\",\",r)}function o(){r.point=n}function s(){e.push(\"Z\")}return r}function vn(t){return\"m0,\"+t+\"a\"+t+\",\"+t+\" 0 1,1 0,\"+-2*t+\"a\"+t+\",\"+t+\" 0 1,1 0,\"+2*t+\"z\"}var yn,xn={point:bn,lineStart:_n,lineEnd:wn,polygonStart:function(){xn.lineStart=Tn},polygonEnd:function(){xn.point=bn,xn.lineStart=_n,xn.lineEnd=wn}};function bn(t,e){xr+=t,br+=e,++_r}function _n(){var t,e;function r(r,n){var i=r-t,a=n-e,o=Math.sqrt(i*i+a*a);wr+=o*(t+r)/2,Tr+=o*(e+n)/2,kr+=o,bn(t=r,e=n)}xn.point=function(n,i){xn.point=r,bn(t=n,e=i)}}function wn(){xn.point=bn}function Tn(){var t,e,r,n;function i(t,e){var i=t-r,a=e-n,o=Math.sqrt(i*i+a*a);wr+=o*(r+t)/2,Tr+=o*(n+e)/2,kr+=o,Mr+=(o=n*t-r*e)*(r+t),Ar+=o*(n+e),Sr+=3*o,bn(r=t,n=e)}xn.point=function(a,o){xn.point=i,bn(t=r=a,e=n=o)},xn.lineEnd=function(){i(t,e)}}function kn(t){var e=4.5,r={point:n,lineStart:function(){r.point=i},lineEnd:o,polygonStart:function(){r.lineEnd=s},polygonEnd:function(){r.lineEnd=o,r.point=n},pointRadius:function(t){return e=t,r},result:z};function n(r,n){t.moveTo(r+e,n),t.arc(r,n,e,0,St)}function i(e,n){t.moveTo(e,n),r.point=a}function a(e,r){t.lineTo(e,r)}function o(){r.point=n}function s(){t.closePath()}return r}function Mn(t){var e=.5,r=Math.cos(30*Ct),n=16;function i(t){return(n?o:a)(t)}function a(e){return En(e,(function(r,n){r=t(r,n),e.point(r[0],r[1])}))}function o(e){var r,i,a,o,l,c,u,f,h,p,d,m,g={point:v,lineStart:y,lineEnd:b,polygonStart:function(){e.polygonStart(),g.lineStart=_},polygonEnd:function(){e.polygonEnd(),g.lineStart=y}};function v(r,n){r=t(r,n),e.point(r[0],r[1])}function y(){f=NaN,g.point=x,e.lineStart()}function x(r,i){var a=Pr([r,i]),o=t(r,i);s(f,h,u,p,d,m,f=o[0],h=o[1],u=r,p=a[0],d=a[1],m=a[2],n,e),e.point(f,h)}function b(){g.point=v,e.lineEnd()}function _(){y(),g.point=w,g.lineEnd=T}function w(t,e){x(r=t,e),i=f,a=h,o=p,l=d,c=m,g.point=x}function T(){s(f,h,u,p,d,m,i,a,r,o,l,c,n,e),g.lineEnd=b,b()}return g}function s(n,i,a,o,l,c,u,f,h,p,d,m,g,v){var x=u-n,b=f-i,_=x*x+b*b;if(_>4*e&&g--){var w=o+p,T=l+d,k=c+m,M=Math.sqrt(w*w+T*T+k*k),A=Math.asin(k/=M),S=y(y(k)-1)<kt||y(a-h)<kt?(a+h)/2:Math.atan2(T,w),E=t(S,A),L=E[0],C=E[1],P=L-n,I=C-i,O=b*P-x*I;(O*O/_>e||y((x*P+b*I)/_-.5)>.3||o*p+l*d+c*m<r)&&(s(n,i,a,o,l,c,L,C,S,w/=M,T/=M,k,g,v),v.point(L,C),s(L,C,S,w,T,k,u,f,h,p,d,m,g,v))}}return i.precision=function(t){return arguments.length?(n=(e=t*t)>0&&16,i):Math.sqrt(e)},i}function An(t){var e=Mn((function(e,r){return t([e*Pt,r*Pt])}));return function(t){return Pn(e(t))}}function Sn(t){this.stream=t}function En(t,e){return{point:e,sphere:function(){t.sphere()},lineStart:function(){t.lineStart()},lineEnd:function(){t.lineEnd()},polygonStart:function(){t.polygonStart()},polygonEnd:function(){t.polygonEnd()}}}function Ln(t){return Cn((function(){return t}))()}function Cn(e){var r,n,i,a,o,s,l=Mn((function(t,e){return[(t=r(t,e))[0]*c+a,o-t[1]*c]})),c=150,u=480,f=250,h=0,p=0,d=0,m=0,g=0,v=tn,y=C,x=null,b=null;function _(t){return[(t=i(t[0]*Ct,t[1]*Ct))[0]*c+a,o-t[1]*c]}function w(t){return(t=i.invert((t[0]-a)/c,(o-t[1])/c))&&[t[0]*Pt,t[1]*Pt]}function T(){i=Gr(n=zn(d,m,g),r);var t=r(h,p);return a=u-t[0]*c,o=f+t[1]*c,k()}function k(){return s&&(s.valid=!1,s=null),_}return _.stream=function(t){return s&&(s.valid=!1),(s=Pn(v(n,l(y(t))))).valid=!0,s},_.clipAngle=function(t){return arguments.length?(v=null==t?(x=t,tn):en((x=+t)*Ct),k()):x},_.clipExtent=function(t){return arguments.length?(b=t,y=t?nn(t[0][0],t[0][1],t[1][0],t[1][1]):C,k()):b},_.scale=function(t){return arguments.length?(c=+t,T()):c},_.translate=function(t){return arguments.length?(u=+t[0],f=+t[1],T()):[u,f]},_.center=function(t){return arguments.length?(h=t[0]%360*Ct,p=t[1]%360*Ct,T()):[h*Pt,p*Pt]},_.rotate=function(t){return arguments.length?(d=t[0]%360*Ct,m=t[1]%360*Ct,g=t.length>2?t[2]%360*Ct:0,T()):[d*Pt,m*Pt,g*Pt]},t.rebind(_,l,\"precision\"),function(){return r=e.apply(this,arguments),_.invert=r.invert&&w,T()}}function Pn(t){return En(t,(function(e,r){t.point(e*Ct,r*Ct)}))}function In(t,e){return[t,e]}function On(t,e){return[t>At?t-St:t<-At?t+St:t,e]}function zn(t,e,r){return t?e||r?Gr(Rn(t),Fn(e,r)):Rn(t):e||r?Fn(e,r):On}function Dn(t){return function(e,r){return[(e+=t)>At?e-St:e<-At?e+St:e,r]}}function Rn(t){var e=Dn(t);return e.invert=Dn(-t),e}function Fn(t,e){var r=Math.cos(t),n=Math.sin(t),i=Math.cos(e),a=Math.sin(e);function o(t,e){var o=Math.cos(e),s=Math.cos(t)*o,l=Math.sin(t)*o,c=Math.sin(e),u=c*r+s*n;return[Math.atan2(l*i-u*a,s*r-c*n),Dt(u*i+l*a)]}return o.invert=function(t,e){var o=Math.cos(e),s=Math.cos(t)*o,l=Math.sin(t)*o,c=Math.sin(e),u=c*i-l*a;return[Math.atan2(l*i+c*a,s*r+u*n),Dt(u*r-s*n)]},o}function Bn(t,e){var r=Math.cos(t),n=Math.sin(t);return function(i,a,o,s){var l=o*e;null!=i?(i=Nn(r,i),a=Nn(r,a),(o>0?i<a:i>a)&&(i+=o*St)):(i=t+o*St,a=t-.5*l);for(var c,u=i;o>0?u>a:u<a;u-=l)s.point((c=Fr([r,-n*Math.cos(u),-n*Math.sin(u)]))[0],c[1])}}function Nn(t,e){var r=Pr(e);r[0]-=t,Rr(r);var n=zt(-r[1]);return((-r[2]<0?-n:n)+2*Math.PI-kt)%(2*Math.PI)}function jn(e,r,n){var i=t.range(e,r-kt,n).concat(r);return function(t){return i.map((function(e){return[t,e]}))}}function Un(e,r,n){var i=t.range(e,r-kt,n).concat(r);return function(t){return i.map((function(e){return[e,t]}))}}function Vn(t){return t.source}function qn(t){return t.target}t.geo.path=function(){var e,r,n,i,a,o=4.5;function s(e){return e&&(\"function\"==typeof o&&i.pointRadius(+o.apply(this,arguments)),a&&a.valid||(a=n(i)),t.geo.stream(e,a)),i.result()}function l(){return a=null,s}return s.area=function(e){return sn=0,t.geo.stream(e,n(pn)),sn},s.centroid=function(e){return xr=br=_r=wr=Tr=kr=Mr=Ar=Sr=0,t.geo.stream(e,n(xn)),Sr?[Mr/Sr,Ar/Sr]:kr?[wr/kr,Tr/kr]:_r?[xr/_r,br/_r]:[NaN,NaN]},s.bounds=function(e){return fn=hn=-(cn=un=1/0),t.geo.stream(e,n(mn)),[[cn,un],[fn,hn]]},s.projection=function(t){return arguments.length?(n=(e=t)?t.stream||An(t):C,l()):e},s.context=function(t){return arguments.length?(i=null==(r=t)?new gn:new kn(t),\"function\"!=typeof o&&i.pointRadius(o),l()):r},s.pointRadius=function(t){return arguments.length?(o=\"function\"==typeof t?t:(i.pointRadius(+t),+t),s):o},s.projection(t.geo.albersUsa()).context(null)},t.geo.transform=function(t){return{stream:function(e){var r=new Sn(e);for(var n in t)r[n]=t[n];return r}}},Sn.prototype={point:function(t,e){this.stream.point(t,e)},sphere:function(){this.stream.sphere()},lineStart:function(){this.stream.lineStart()},lineEnd:function(){this.stream.lineEnd()},polygonStart:function(){this.stream.polygonStart()},polygonEnd:function(){this.stream.polygonEnd()}},t.geo.projection=Ln,t.geo.projectionMutator=Cn,(t.geo.equirectangular=function(){return Ln(In)}).raw=In.invert=In,t.geo.rotation=function(t){function e(e){return(e=t(e[0]*Ct,e[1]*Ct))[0]*=Pt,e[1]*=Pt,e}return t=zn(t[0]%360*Ct,t[1]*Ct,t.length>2?t[2]*Ct:0),e.invert=function(e){return(e=t.invert(e[0]*Ct,e[1]*Ct))[0]*=Pt,e[1]*=Pt,e},e},On.invert=In,t.geo.circle=function(){var t,e,r=[0,0],n=6;function i(){var t=\"function\"==typeof r?r.apply(this,arguments):r,n=zn(-t[0]*Ct,-t[1]*Ct,0).invert,i=[];return e(null,null,1,{point:function(t,e){i.push(t=n(t,e)),t[0]*=Pt,t[1]*=Pt}}),{type:\"Polygon\",coordinates:[i]}}return i.origin=function(t){return arguments.length?(r=t,i):r},i.angle=function(r){return arguments.length?(e=Bn((t=+r)*Ct,n*Ct),i):t},i.precision=function(r){return arguments.length?(e=Bn(t*Ct,(n=+r)*Ct),i):n},i.angle(90)},t.geo.distance=function(t,e){var r,n=(e[0]-t[0])*Ct,i=t[1]*Ct,a=e[1]*Ct,o=Math.sin(n),s=Math.cos(n),l=Math.sin(i),c=Math.cos(i),u=Math.sin(a),f=Math.cos(a);return Math.atan2(Math.sqrt((r=f*o)*r+(r=c*u-l*f*s)*r),l*u+c*f*s)},t.geo.graticule=function(){var e,r,n,i,a,o,s,l,c,u,f,h,p=10,d=p,m=90,g=360,v=2.5;function x(){return{type:\"MultiLineString\",coordinates:b()}}function b(){return t.range(Math.ceil(i/m)*m,n,m).map(f).concat(t.range(Math.ceil(l/g)*g,s,g).map(h)).concat(t.range(Math.ceil(r/p)*p,e,p).filter((function(t){return y(t%m)>kt})).map(c)).concat(t.range(Math.ceil(o/d)*d,a,d).filter((function(t){return y(t%g)>kt})).map(u))}return x.lines=function(){return b().map((function(t){return{type:\"LineString\",coordinates:t}}))},x.outline=function(){return{type:\"Polygon\",coordinates:[f(i).concat(h(s).slice(1),f(n).reverse().slice(1),h(l).reverse().slice(1))]}},x.extent=function(t){return arguments.length?x.majorExtent(t).minorExtent(t):x.minorExtent()},x.majorExtent=function(t){return arguments.length?(i=+t[0][0],n=+t[1][0],l=+t[0][1],s=+t[1][1],i>n&&(t=i,i=n,n=t),l>s&&(t=l,l=s,s=t),x.precision(v)):[[i,l],[n,s]]},x.minorExtent=function(t){return arguments.length?(r=+t[0][0],e=+t[1][0],o=+t[0][1],a=+t[1][1],r>e&&(t=r,r=e,e=t),o>a&&(t=o,o=a,a=t),x.precision(v)):[[r,o],[e,a]]},x.step=function(t){return arguments.length?x.majorStep(t).minorStep(t):x.minorStep()},x.majorStep=function(t){return arguments.length?(m=+t[0],g=+t[1],x):[m,g]},x.minorStep=function(t){return arguments.length?(p=+t[0],d=+t[1],x):[p,d]},x.precision=function(t){return arguments.length?(v=+t,c=jn(o,a,90),u=Un(r,e,v),f=jn(l,s,90),h=Un(i,n,v),x):v},x.majorExtent([[-180,-90+kt],[180,90-kt]]).minorExtent([[-180,-80-kt],[180,80+kt]])},t.geo.greatArc=function(){var e,r,n=Vn,i=qn;function a(){return{type:\"LineString\",coordinates:[e||n.apply(this,arguments),r||i.apply(this,arguments)]}}return a.distance=function(){return t.geo.distance(e||n.apply(this,arguments),r||i.apply(this,arguments))},a.source=function(t){return arguments.length?(n=t,e=\"function\"==typeof t?null:t,a):n},a.target=function(t){return arguments.length?(i=t,r=\"function\"==typeof t?null:t,a):i},a.precision=function(){return arguments.length?a:0},a},t.geo.interpolate=function(t,e){return r=t[0]*Ct,n=t[1]*Ct,i=e[0]*Ct,a=e[1]*Ct,o=Math.cos(n),s=Math.sin(n),l=Math.cos(a),c=Math.sin(a),u=o*Math.cos(r),f=o*Math.sin(r),h=l*Math.cos(i),p=l*Math.sin(i),d=2*Math.asin(Math.sqrt(Ft(a-n)+o*l*Ft(i-r))),m=1/Math.sin(d),(g=d?function(t){var e=Math.sin(t*=d)*m,r=Math.sin(d-t)*m,n=r*u+e*h,i=r*f+e*p,a=r*s+e*c;return[Math.atan2(i,n)*Pt,Math.atan2(a,Math.sqrt(n*n+i*i))*Pt]}:function(){return[r*Pt,n*Pt]}).distance=d,g;var r,n,i,a,o,s,l,c,u,f,h,p,d,m,g},t.geo.length=function(e){return yn=0,t.geo.stream(e,Hn),yn};var Hn={sphere:z,point:z,lineStart:function(){var t,e,r;function n(n,i){var a=Math.sin(i*=Ct),o=Math.cos(i),s=y((n*=Ct)-t),l=Math.cos(s);yn+=Math.atan2(Math.sqrt((s=o*Math.sin(s))*s+(s=r*a-e*o*l)*s),e*a+r*o*l),t=n,e=a,r=o}Hn.point=function(i,a){t=i*Ct,e=Math.sin(a*=Ct),r=Math.cos(a),Hn.point=n},Hn.lineEnd=function(){Hn.point=Hn.lineEnd=z}},lineEnd:z,polygonStart:z,polygonEnd:z};function Gn(t,e){function r(e,r){var n=Math.cos(e),i=Math.cos(r),a=t(n*i);return[a*i*Math.sin(e),a*Math.sin(r)]}return r.invert=function(t,r){var n=Math.sqrt(t*t+r*r),i=e(n),a=Math.sin(i),o=Math.cos(i);return[Math.atan2(t*a,n*o),Math.asin(n&&r*a/n)]},r}var Yn=Gn((function(t){return Math.sqrt(2/(1+t))}),(function(t){return 2*Math.asin(t/2)}));(t.geo.azimuthalEqualArea=function(){return Ln(Yn)}).raw=Yn;var Wn=Gn((function(t){var e=Math.acos(t);return e&&e/Math.sin(e)}),C);function Xn(t,e){var r=Math.cos(t),n=function(t){return Math.tan(At/4+t/2)},i=t===e?Math.sin(t):Math.log(r/Math.cos(e))/Math.log(n(e)/n(t)),a=r*Math.pow(n(t),i)/i;if(!i)return Kn;function o(t,e){a>0?e<-Lt+kt&&(e=-Lt+kt):e>Lt-kt&&(e=Lt-kt);var r=a/Math.pow(n(e),i);return[r*Math.sin(i*t),a-r*Math.cos(i*t)]}return o.invert=function(t,e){var r=a-e,n=It(i)*Math.sqrt(t*t+r*r);return[Math.atan2(t,r)/i,2*Math.atan(Math.pow(a/n,1/i))-Lt]},o}function Zn(t,e){var r=Math.cos(t),n=t===e?Math.sin(t):(r-Math.cos(e))/(e-t),i=r/n+t;if(y(n)<kt)return In;function a(t,e){var r=i-e;return[r*Math.sin(n*t),i-r*Math.cos(n*t)]}return a.invert=function(t,e){var r=i-e;return[Math.atan2(t,r)/n,i-It(n)*Math.sqrt(t*t+r*r)]},a}(t.geo.azimuthalEquidistant=function(){return Ln(Wn)}).raw=Wn,(t.geo.conicConformal=function(){return an(Xn)}).raw=Xn,(t.geo.conicEquidistant=function(){return an(Zn)}).raw=Zn;var Jn=Gn((function(t){return 1/t}),Math.atan);function Kn(t,e){return[t,Math.log(Math.tan(At/4+e/2))]}function Qn(t){var e,r=Ln(t),n=r.scale,i=r.translate,a=r.clipExtent;return r.scale=function(){var t=n.apply(r,arguments);return t===r?e?r.clipExtent(null):r:t},r.translate=function(){var t=i.apply(r,arguments);return t===r?e?r.clipExtent(null):r:t},r.clipExtent=function(t){var o=a.apply(r,arguments);if(o===r){if(e=null==t){var s=At*n(),l=i();a([[l[0]-s,l[1]-s],[l[0]+s,l[1]+s]])}}else e&&(o=null);return o},r.clipExtent(null)}(t.geo.gnomonic=function(){return Ln(Jn)}).raw=Jn,Kn.invert=function(t,e){return[t,2*Math.atan(Math.exp(e))-Lt]},(t.geo.mercator=function(){return Qn(Kn)}).raw=Kn;var $n=Gn((function(){return 1}),Math.asin);(t.geo.orthographic=function(){return Ln($n)}).raw=$n;var ti=Gn((function(t){return 1/(1+t)}),(function(t){return 2*Math.atan(t)}));function ei(t,e){return[Math.log(Math.tan(At/4+e/2)),-t]}function ri(t){return t[0]}function ni(t){return t[1]}function ii(t){for(var e=t.length,r=[0,1],n=2,i=2;i<e;i++){for(;n>1&&Ot(t[r[n-2]],t[r[n-1]],t[i])<=0;)--n;r[n++]=i}return r.slice(0,n)}function ai(t,e){return t[0]-e[0]||t[1]-e[1]}(t.geo.stereographic=function(){return Ln(ti)}).raw=ti,ei.invert=function(t,e){return[-e,2*Math.atan(Math.exp(t))-Lt]},(t.geo.transverseMercator=function(){var t=Qn(ei),e=t.center,r=t.rotate;return t.center=function(t){return t?e([-t[1],t[0]]):[(t=e())[1],-t[0]]},t.rotate=function(t){return t?r([t[0],t[1],t.length>2?t[2]+90:90]):[(t=r())[0],t[1],t[2]-90]},r([0,0,90])}).raw=ei,t.geom={},t.geom.hull=function(t){var e=ri,r=ni;if(arguments.length)return n(t);function n(t){if(t.length<3)return[];var n,i=de(e),a=de(r),o=t.length,s=[],l=[];for(n=0;n<o;n++)s.push([+i.call(this,t[n],n),+a.call(this,t[n],n),n]);for(s.sort(ai),n=0;n<o;n++)l.push([s[n][0],-s[n][1]]);var c=ii(s),u=ii(l),f=u[0]===c[0],h=u[u.length-1]===c[c.length-1],p=[];for(n=c.length-1;n>=0;--n)p.push(t[s[c[n]][2]]);for(n=+f;n<u.length-h;++n)p.push(t[s[u[n]][2]]);return p}return n.x=function(t){return arguments.length?(e=t,n):e},n.y=function(t){return arguments.length?(r=t,n):r},n},t.geom.polygon=function(t){return U(t,oi),t};var oi=t.geom.polygon.prototype=[];function si(t,e,r){return(r[0]-e[0])*(t[1]-e[1])<(r[1]-e[1])*(t[0]-e[0])}function li(t,e,r,n){var i=t[0],a=r[0],o=e[0]-i,s=n[0]-a,l=t[1],c=r[1],u=e[1]-l,f=n[1]-c,h=(s*(l-c)-f*(i-a))/(f*o-s*u);return[i+h*o,l+h*u]}function ci(t){var e=t[0],r=t[t.length-1];return!(e[0]-r[0]||e[1]-r[1])}oi.area=function(){for(var t,e=-1,r=this.length,n=this[r-1],i=0;++e<r;)t=n,n=this[e],i+=t[1]*n[0]-t[0]*n[1];return.5*i},oi.centroid=function(t){var e,r,n=-1,i=this.length,a=0,o=0,s=this[i-1];for(arguments.length||(t=-1/(6*this.area()));++n<i;)e=s,s=this[n],r=e[0]*s[1]-s[0]*e[1],a+=(e[0]+s[0])*r,o+=(e[1]+s[1])*r;return[a*t,o*t]},oi.clip=function(t){for(var e,r,n,i,a,o,s=ci(t),l=-1,c=this.length-ci(this),u=this[c-1];++l<c;){for(e=t.slice(),t.length=0,i=this[l],a=e[(n=e.length-s)-1],r=-1;++r<n;)si(o=e[r],u,i)?(si(a,u,i)||t.push(li(a,o,u,i)),t.push(o)):si(a,u,i)&&t.push(li(a,o,u,i)),a=o;s&&t.push(t[0]),u=i}return t};var ui,fi,hi,pi,di,mi=[],gi=[];function vi(){Ri(this),this.edge=this.site=this.circle=null}function yi(t){var e=mi.pop()||new vi;return e.site=t,e}function xi(t){Ei(t),hi.remove(t),mi.push(t),Ri(t)}function bi(t){var e=t.circle,r=e.x,n=e.cy,i={x:r,y:n},a=t.P,o=t.N,s=[t];xi(t);for(var l=a;l.circle&&y(r-l.circle.x)<kt&&y(n-l.circle.cy)<kt;)a=l.P,s.unshift(l),xi(l),l=a;s.unshift(l),Ei(l);for(var c=o;c.circle&&y(r-c.circle.x)<kt&&y(n-c.circle.cy)<kt;)o=c.N,s.push(c),xi(c),c=o;s.push(c),Ei(c);var u,f=s.length;for(u=1;u<f;++u)c=s[u],l=s[u-1],Oi(c.edge,l.site,c.site,i);l=s[0],(c=s[f-1]).edge=Pi(l.site,c.site,null,i),Si(l),Si(c)}function _i(t){for(var e,r,n,i,a=t.x,o=t.y,s=hi._;s;)if((n=wi(s,o)-a)>kt)s=s.L;else{if(!((i=a-Ti(s,o))>kt)){n>-kt?(e=s.P,r=s):i>-kt?(e=s,r=s.N):e=r=s;break}if(!s.R){e=s;break}s=s.R}var l=yi(t);if(hi.insert(e,l),e||r){if(e===r)return Ei(e),r=yi(e.site),hi.insert(l,r),l.edge=r.edge=Pi(e.site,l.site),Si(e),void Si(r);if(r){Ei(e),Ei(r);var c=e.site,u=c.x,f=c.y,h=t.x-u,p=t.y-f,d=r.site,m=d.x-u,g=d.y-f,v=2*(h*g-p*m),y=h*h+p*p,x=m*m+g*g,b={x:(g*y-p*x)/v+u,y:(h*x-m*y)/v+f};Oi(r.edge,c,d,b),l.edge=Pi(c,t,null,b),r.edge=Pi(t,d,null,b),Si(e),Si(r)}else l.edge=Pi(e.site,l.site)}}function wi(t,e){var r=t.site,n=r.x,i=r.y,a=i-e;if(!a)return n;var o=t.P;if(!o)return-1/0;var s=(r=o.site).x,l=r.y,c=l-e;if(!c)return s;var u=s-n,f=1/a-1/c,h=u/c;return f?(-h+Math.sqrt(h*h-2*f*(u*u/(-2*c)-l+c/2+i-a/2)))/f+n:(n+s)/2}function Ti(t,e){var r=t.N;if(r)return wi(r,e);var n=t.site;return n.y===e?n.x:1/0}function ki(t){this.site=t,this.edges=[]}function Mi(t,e){return e.angle-t.angle}function Ai(){Ri(this),this.x=this.y=this.arc=this.site=this.cy=null}function Si(t){var e=t.P,r=t.N;if(e&&r){var n=e.site,i=t.site,a=r.site;if(n!==a){var o=i.x,s=i.y,l=n.x-o,c=n.y-s,u=a.x-o,f=2*(l*(g=a.y-s)-c*u);if(!(f>=-Mt)){var h=l*l+c*c,p=u*u+g*g,d=(g*h-c*p)/f,m=(l*p-u*h)/f,g=m+s,v=gi.pop()||new Ai;v.arc=t,v.site=i,v.x=d+o,v.y=g+Math.sqrt(d*d+m*m),v.cy=g,t.circle=v;for(var y=null,x=di._;x;)if(v.y<x.y||v.y===x.y&&v.x<=x.x){if(!x.L){y=x.P;break}x=x.L}else{if(!x.R){y=x;break}x=x.R}di.insert(y,v),y||(pi=v)}}}}function Ei(t){var e=t.circle;e&&(e.P||(pi=e.N),di.remove(e),gi.push(e),Ri(e),t.circle=null)}function Li(t,e){var r=t.b;if(r)return!0;var n,i,a=t.a,o=e[0][0],s=e[1][0],l=e[0][1],c=e[1][1],u=t.l,f=t.r,h=u.x,p=u.y,d=f.x,m=f.y,g=(h+d)/2,v=(p+m)/2;if(m===p){if(g<o||g>=s)return;if(h>d){if(a){if(a.y>=c)return}else a={x:g,y:l};r={x:g,y:c}}else{if(a){if(a.y<l)return}else a={x:g,y:c};r={x:g,y:l}}}else if(i=v-(n=(h-d)/(m-p))*g,n<-1||n>1)if(h>d){if(a){if(a.y>=c)return}else a={x:(l-i)/n,y:l};r={x:(c-i)/n,y:c}}else{if(a){if(a.y<l)return}else a={x:(c-i)/n,y:c};r={x:(l-i)/n,y:l}}else if(p<m){if(a){if(a.x>=s)return}else a={x:o,y:n*o+i};r={x:s,y:n*s+i}}else{if(a){if(a.x<o)return}else a={x:s,y:n*s+i};r={x:o,y:n*o+i}}return t.a=a,t.b=r,!0}function Ci(t,e){this.l=t,this.r=e,this.a=this.b=null}function Pi(t,e,r,n){var i=new Ci(t,e);return ui.push(i),r&&Oi(i,t,e,r),n&&Oi(i,e,t,n),fi[t.i].edges.push(new zi(i,t,e)),fi[e.i].edges.push(new zi(i,e,t)),i}function Ii(t,e,r){var n=new Ci(t,null);return n.a=e,n.b=r,ui.push(n),n}function Oi(t,e,r,n){t.a||t.b?t.l===r?t.b=n:t.a=n:(t.a=n,t.l=e,t.r=r)}function zi(t,e,r){var n=t.a,i=t.b;this.edge=t,this.site=e,this.angle=r?Math.atan2(r.y-e.y,r.x-e.x):t.l===e?Math.atan2(i.x-n.x,n.y-i.y):Math.atan2(n.x-i.x,i.y-n.y)}function Di(){this._=null}function Ri(t){t.U=t.C=t.L=t.R=t.P=t.N=null}function Fi(t,e){var r=e,n=e.R,i=r.U;i?i.L===r?i.L=n:i.R=n:t._=n,n.U=i,r.U=n,r.R=n.L,r.R&&(r.R.U=r),n.L=r}function Bi(t,e){var r=e,n=e.L,i=r.U;i?i.L===r?i.L=n:i.R=n:t._=n,n.U=i,r.U=n,r.L=n.R,r.L&&(r.L.U=r),n.R=r}function Ni(t){for(;t.L;)t=t.L;return t}function ji(t,e){var r,n,i,a=t.sort(Ui).pop();for(ui=[],fi=new Array(t.length),hi=new Di,di=new Di;;)if(i=pi,a&&(!i||a.y<i.y||a.y===i.y&&a.x<i.x))a.x===r&&a.y===n||(fi[a.i]=new ki(a),_i(a),r=a.x,n=a.y),a=t.pop();else{if(!i)break;bi(i.arc)}e&&(function(t){for(var e,r=ui,n=rn(t[0][0],t[0][1],t[1][0],t[1][1]),i=r.length;i--;)(!Li(e=r[i],t)||!n(e)||y(e.a.x-e.b.x)<kt&&y(e.a.y-e.b.y)<kt)&&(e.a=e.b=null,r.splice(i,1))}(e),function(t){for(var e,r,n,i,a,o,s,l,c,u,f=t[0][0],h=t[1][0],p=t[0][1],d=t[1][1],m=fi,g=m.length;g--;)if((a=m[g])&&a.prepare())for(l=(s=a.edges).length,o=0;o<l;)n=(u=s[o].end()).x,i=u.y,e=(c=s[++o%l].start()).x,r=c.y,(y(n-e)>kt||y(i-r)>kt)&&(s.splice(o,0,new zi(Ii(a.site,u,y(n-f)<kt&&d-i>kt?{x:f,y:y(e-f)<kt?r:d}:y(i-d)<kt&&h-n>kt?{x:y(r-d)<kt?e:h,y:d}:y(n-h)<kt&&i-p>kt?{x:h,y:y(e-h)<kt?r:p}:y(i-p)<kt&&n-f>kt?{x:y(r-p)<kt?e:f,y:p}:null),a.site,null)),++l)}(e));var o={cells:fi,edges:ui};return hi=di=ui=fi=null,o}function Ui(t,e){return e.y-t.y||e.x-t.x}ki.prototype.prepare=function(){for(var t,e=this.edges,r=e.length;r--;)(t=e[r].edge).b&&t.a||e.splice(r,1);return e.sort(Mi),e.length},zi.prototype={start:function(){return this.edge.l===this.site?this.edge.a:this.edge.b},end:function(){return this.edge.l===this.site?this.edge.b:this.edge.a}},Di.prototype={insert:function(t,e){var r,n,i;if(t){if(e.P=t,e.N=t.N,t.N&&(t.N.P=e),t.N=e,t.R){for(t=t.R;t.L;)t=t.L;t.L=e}else t.R=e;r=t}else this._?(t=Ni(this._),e.P=null,e.N=t,t.P=t.L=e,r=t):(e.P=e.N=null,this._=e,r=null);for(e.L=e.R=null,e.U=r,e.C=!0,t=e;r&&r.C;)r===(n=r.U).L?(i=n.R)&&i.C?(r.C=i.C=!1,n.C=!0,t=n):(t===r.R&&(Fi(this,r),r=(t=r).U),r.C=!1,n.C=!0,Bi(this,n)):(i=n.L)&&i.C?(r.C=i.C=!1,n.C=!0,t=n):(t===r.L&&(Bi(this,r),r=(t=r).U),r.C=!1,n.C=!0,Fi(this,n)),r=t.U;this._.C=!1},remove:function(t){t.N&&(t.N.P=t.P),t.P&&(t.P.N=t.N),t.N=t.P=null;var e,r,n,i=t.U,a=t.L,o=t.R;if(r=a?o?Ni(o):a:o,i?i.L===t?i.L=r:i.R=r:this._=r,a&&o?(n=r.C,r.C=t.C,r.L=a,a.U=r,r!==o?(i=r.U,r.U=t.U,t=r.R,i.L=t,r.R=o,o.U=r):(r.U=i,i=r,t=r.R)):(n=t.C,t=r),t&&(t.U=i),!n)if(t&&t.C)t.C=!1;else{do{if(t===this._)break;if(t===i.L){if((e=i.R).C&&(e.C=!1,i.C=!0,Fi(this,i),e=i.R),e.L&&e.L.C||e.R&&e.R.C){e.R&&e.R.C||(e.L.C=!1,e.C=!0,Bi(this,e),e=i.R),e.C=i.C,i.C=e.R.C=!1,Fi(this,i),t=this._;break}}else if((e=i.L).C&&(e.C=!1,i.C=!0,Bi(this,i),e=i.L),e.L&&e.L.C||e.R&&e.R.C){e.L&&e.L.C||(e.R.C=!1,e.C=!0,Fi(this,e),e=i.L),e.C=i.C,i.C=e.L.C=!1,Bi(this,i),t=this._;break}e.C=!0,t=i,i=i.U}while(!t.C);t&&(t.C=!1)}}},t.geom.voronoi=function(t){var e=ri,r=ni,n=e,i=r,a=Vi;if(t)return o(t);function o(t){var e=new Array(t.length),r=a[0][0],n=a[0][1],i=a[1][0],o=a[1][1];return ji(s(t),a).cells.forEach((function(a,s){var l=a.edges,c=a.site;(e[s]=l.length?l.map((function(t){var e=t.start();return[e.x,e.y]})):c.x>=r&&c.x<=i&&c.y>=n&&c.y<=o?[[r,o],[i,o],[i,n],[r,n]]:[]).point=t[s]})),e}function s(t){return t.map((function(t,e){return{x:Math.round(n(t,e)/kt)*kt,y:Math.round(i(t,e)/kt)*kt,i:e}}))}return o.links=function(t){return ji(s(t)).edges.filter((function(t){return t.l&&t.r})).map((function(e){return{source:t[e.l.i],target:t[e.r.i]}}))},o.triangles=function(t){var e=[];return ji(s(t)).cells.forEach((function(r,n){for(var i,a,o,s,l=r.site,c=r.edges.sort(Mi),u=-1,f=c.length,h=c[f-1].edge,p=h.l===l?h.r:h.l;++u<f;)h,i=p,p=(h=c[u].edge).l===l?h.r:h.l,n<i.i&&n<p.i&&(o=i,s=p,((a=l).x-s.x)*(o.y-a.y)-(a.x-o.x)*(s.y-a.y)<0)&&e.push([t[n],t[i.i],t[p.i]])})),e},o.x=function(t){return arguments.length?(n=de(e=t),o):e},o.y=function(t){return arguments.length?(i=de(r=t),o):r},o.clipExtent=function(t){return arguments.length?(a=null==t?Vi:t,o):a===Vi?null:a},o.size=function(t){return arguments.length?o.clipExtent(t&&[[0,0],t]):a===Vi?null:a&&a[1]},o};var Vi=[[-1e6,-1e6],[1e6,1e6]];function qi(t){return t.x}function Hi(t){return t.y}function Gi(t,e,r,n,i,a){if(!t(e,r,n,i,a)){var o=.5*(r+i),s=.5*(n+a),l=e.nodes;l[0]&&Gi(t,l[0],r,n,o,s),l[1]&&Gi(t,l[1],o,n,i,s),l[2]&&Gi(t,l[2],r,s,o,a),l[3]&&Gi(t,l[3],o,s,i,a)}}function Yi(t,e,r,n,i,a,o){var s,l=1/0;return function t(c,u,f,h,p){if(!(u>a||f>o||h<n||p<i)){if(d=c.point){var d,m=e-c.x,g=r-c.y,v=m*m+g*g;if(v<l){var y=Math.sqrt(l=v);n=e-y,i=r-y,a=e+y,o=r+y,s=d}}for(var x=c.nodes,b=.5*(u+h),_=.5*(f+p),w=(r>=_)<<1|e>=b,T=w+4;w<T;++w)if(c=x[3&w])switch(3&w){case 0:t(c,u,f,b,_);break;case 1:t(c,b,f,h,_);break;case 2:t(c,u,_,b,p);break;case 3:t(c,b,_,h,p)}}}(t,n,i,a,o),s}function Wi(e,r){e=t.rgb(e),r=t.rgb(r);var n=e.r,i=e.g,a=e.b,o=r.r-n,s=r.g-i,l=r.b-a;return function(t){return\"#\"+se(Math.round(n+o*t))+se(Math.round(i+s*t))+se(Math.round(a+l*t))}}function Xi(t,e){var r,n={},i={};for(r in t)r in e?n[r]=$i(t[r],e[r]):i[r]=t[r];for(r in e)r in t||(i[r]=e[r]);return function(t){for(r in n)i[r]=n[r](t);return i}}function Zi(t,e){return t=+t,e=+e,function(r){return t*(1-r)+e*r}}function Ji(t,e){var r,n,i,a=Ki.lastIndex=Qi.lastIndex=0,o=-1,s=[],l=[];for(t+=\"\",e+=\"\";(r=Ki.exec(t))&&(n=Qi.exec(e));)(i=n.index)>a&&(i=e.slice(a,i),s[o]?s[o]+=i:s[++o]=i),(r=r[0])===(n=n[0])?s[o]?s[o]+=n:s[++o]=n:(s[++o]=null,l.push({i:o,x:Zi(r,n)})),a=Qi.lastIndex;return a<e.length&&(i=e.slice(a),s[o]?s[o]+=i:s[++o]=i),s.length<2?l[0]?(e=l[0].x,function(t){return e(t)+\"\"}):function(){return e}:(e=l.length,function(t){for(var r,n=0;n<e;++n)s[(r=l[n]).i]=r.x(t);return s.join(\"\")})}t.geom.delaunay=function(e){return t.geom.voronoi().triangles(e)},t.geom.quadtree=function(t,e,r,n,i){var a,o=ri,s=ni;if(a=arguments.length)return o=qi,s=Hi,3===a&&(i=r,n=e,r=e=0),l(t);function l(t){var l,c,u,f,h,p,d,m,g,v=de(o),x=de(s);if(null!=e)p=e,d=r,m=n,g=i;else if(m=g=-(p=d=1/0),c=[],u=[],h=t.length,a)for(f=0;f<h;++f)(l=t[f]).x<p&&(p=l.x),l.y<d&&(d=l.y),l.x>m&&(m=l.x),l.y>g&&(g=l.y),c.push(l.x),u.push(l.y);else for(f=0;f<h;++f){var b=+v(l=t[f],f),_=+x(l,f);b<p&&(p=b),_<d&&(d=_),b>m&&(m=b),_>g&&(g=_),c.push(b),u.push(_)}var w=m-p,T=g-d;function k(t,e,r,n,i,a,o,s){if(!isNaN(r)&&!isNaN(n))if(t.leaf){var l=t.x,c=t.y;if(null!=l)if(y(l-r)+y(c-n)<.01)M(t,e,r,n,i,a,o,s);else{var u=t.point;t.x=t.y=t.point=null,M(t,u,l,c,i,a,o,s),M(t,e,r,n,i,a,o,s)}else t.x=r,t.y=n,t.point=e}else M(t,e,r,n,i,a,o,s)}function M(t,e,r,n,i,a,o,s){var l=.5*(i+o),c=.5*(a+s),u=r>=l,f=n>=c,h=f<<1|u;t.leaf=!1,u?i=l:o=l,f?a=c:s=c,k(t=t.nodes[h]||(t.nodes[h]={leaf:!0,nodes:[],point:null,x:null,y:null}),e,r,n,i,a,o,s)}w>T?g=d+w:m=p+T;var A={leaf:!0,nodes:[],point:null,x:null,y:null,add:function(t){k(A,t,+v(t,++f),+x(t,f),p,d,m,g)},visit:function(t){Gi(t,A,p,d,m,g)},find:function(t){return Yi(A,t[0],t[1],p,d,m,g)}};if(f=-1,null==e){for(;++f<h;)k(A,t[f],c[f],u[f],p,d,m,g);--f}else t.forEach(A.add);return c=u=t=l=null,A}return l.x=function(t){return arguments.length?(o=t,l):o},l.y=function(t){return arguments.length?(s=t,l):s},l.extent=function(t){return arguments.length?(null==t?e=r=n=i=null:(e=+t[0][0],r=+t[0][1],n=+t[1][0],i=+t[1][1]),l):null==e?null:[[e,r],[n,i]]},l.size=function(t){return arguments.length?(null==t?e=r=n=i=null:(e=r=0,n=+t[0],i=+t[1]),l):null==e?null:[n-e,i-r]},l},t.interpolateRgb=Wi,t.interpolateObject=Xi,t.interpolateNumber=Zi,t.interpolateString=Ji;var Ki=/[-+]?(?:\\d+\\.?\\d*|\\.?\\d+)(?:[eE][-+]?\\d+)?/g,Qi=new RegExp(Ki.source,\"g\");function $i(e,r){for(var n,i=t.interpolators.length;--i>=0&&!(n=t.interpolators[i](e,r)););return n}function ta(t,e){var r,n=[],i=[],a=t.length,o=e.length,s=Math.min(t.length,e.length);for(r=0;r<s;++r)n.push($i(t[r],e[r]));for(;r<a;++r)i[r]=t[r];for(;r<o;++r)i[r]=e[r];return function(t){for(r=0;r<s;++r)i[r]=n[r](t);return i}}t.interpolate=$i,t.interpolators=[function(t,e){var r=typeof e;return(\"string\"===r?pe.has(e.toLowerCase())||/^(#|rgb\\(|hsl\\()/i.test(e)?Wi:Ji:e instanceof Vt?Wi:Array.isArray(e)?ta:\"object\"===r&&isNaN(e)?Xi:Zi)(t,e)}],t.interpolateArray=ta;var ea=function(){return C},ra=t.map({linear:ea,poly:function(t){return function(e){return Math.pow(e,t)}},quad:function(){return sa},cubic:function(){return la},sin:function(){return ua},exp:function(){return fa},circle:function(){return ha},elastic:function(t,e){var r;arguments.length<2&&(e=.45);arguments.length?r=e/St*Math.asin(1/t):(t=1,r=e/4);return function(n){return 1+t*Math.pow(2,-10*n)*Math.sin((n-r)*St/e)}},back:function(t){t||(t=1.70158);return function(e){return e*e*((t+1)*e-t)}},bounce:function(){return pa}}),na=t.map({in:C,out:aa,\"in-out\":oa,\"out-in\":function(t){return oa(aa(t))}});function ia(t){return function(e){return e<=0?0:e>=1?1:t(e)}}function aa(t){return function(e){return 1-t(1-e)}}function oa(t){return function(e){return.5*(e<.5?t(2*e):2-t(2-2*e))}}function sa(t){return t*t}function la(t){return t*t*t}function ca(t){if(t<=0)return 0;if(t>=1)return 1;var e=t*t,r=e*t;return 4*(t<.5?r:3*(t-e)+r-.75)}function ua(t){return 1-Math.cos(t*Lt)}function fa(t){return Math.pow(2,10*(t-1))}function ha(t){return 1-Math.sqrt(1-t*t)}function pa(t){return t<1/2.75?7.5625*t*t:t<2/2.75?7.5625*(t-=1.5/2.75)*t+.75:t<2.5/2.75?7.5625*(t-=2.25/2.75)*t+.9375:7.5625*(t-=2.625/2.75)*t+.984375}function da(t,e){return e-=t,function(r){return Math.round(t+e*r)}}function ma(t){var e,r,n,i=[t.a,t.b],a=[t.c,t.d],o=va(i),s=ga(i,a),l=va(((e=a)[0]+=(n=-s)*(r=i)[0],e[1]+=n*r[1],e))||0;i[0]*a[1]<a[0]*i[1]&&(i[0]*=-1,i[1]*=-1,o*=-1,s*=-1),this.rotate=(o?Math.atan2(i[1],i[0]):Math.atan2(-a[0],a[1]))*Pt,this.translate=[t.e,t.f],this.scale=[o,l],this.skew=l?Math.atan2(s,l)*Pt:0}function ga(t,e){return t[0]*e[0]+t[1]*e[1]}function va(t){var e=Math.sqrt(ga(t,t));return e&&(t[0]/=e,t[1]/=e),e}t.ease=function(t){var e=t.indexOf(\"-\"),n=e>=0?t.slice(0,e):t,i=e>=0?t.slice(e+1):\"in\";return n=ra.get(n)||ea,ia((i=na.get(i)||C)(n.apply(null,r.call(arguments,1))))},t.interpolateHcl=function(e,r){e=t.hcl(e),r=t.hcl(r);var n=e.h,i=e.c,a=e.l,o=r.h-n,s=r.c-i,l=r.l-a;isNaN(s)&&(s=0,i=isNaN(i)?r.c:i);isNaN(o)?(o=0,n=isNaN(n)?r.h:n):o>180?o-=360:o<-180&&(o+=360);return function(t){return Xt(n+o*t,i+s*t,a+l*t)+\"\"}},t.interpolateHsl=function(e,r){e=t.hsl(e),r=t.hsl(r);var n=e.h,i=e.s,a=e.l,o=r.h-n,s=r.s-i,l=r.l-a;isNaN(s)&&(s=0,i=isNaN(i)?r.s:i);isNaN(o)?(o=0,n=isNaN(n)?r.h:n):o>180?o-=360:o<-180&&(o+=360);return function(t){return Gt(n+o*t,i+s*t,a+l*t)+\"\"}},t.interpolateLab=function(e,r){e=t.lab(e),r=t.lab(r);var n=e.l,i=e.a,a=e.b,o=r.l-n,s=r.a-i,l=r.b-a;return function(t){return Qt(n+o*t,i+s*t,a+l*t)+\"\"}},t.interpolateRound=da,t.transform=function(e){var r=i.createElementNS(t.ns.prefix.svg,\"g\");return(t.transform=function(t){if(null!=t){r.setAttribute(\"transform\",t);var e=r.transform.baseVal.consolidate()}return new ma(e?e.matrix:ya)})(e)},ma.prototype.toString=function(){return\"translate(\"+this.translate+\")rotate(\"+this.rotate+\")skewX(\"+this.skew+\")scale(\"+this.scale+\")\"};var ya={a:1,b:0,c:0,d:1,e:0,f:0};function xa(t){return t.length?t.pop()+\",\":\"\"}function ba(e,r){var n=[],i=[];return e=t.transform(e),r=t.transform(r),function(t,e,r,n){if(t[0]!==e[0]||t[1]!==e[1]){var i=r.push(\"translate(\",null,\",\",null,\")\");n.push({i:i-4,x:Zi(t[0],e[0])},{i:i-2,x:Zi(t[1],e[1])})}else(e[0]||e[1])&&r.push(\"translate(\"+e+\")\")}(e.translate,r.translate,n,i),function(t,e,r,n){t!==e?(t-e>180?e+=360:e-t>180&&(t+=360),n.push({i:r.push(xa(r)+\"rotate(\",null,\")\")-2,x:Zi(t,e)})):e&&r.push(xa(r)+\"rotate(\"+e+\")\")}(e.rotate,r.rotate,n,i),function(t,e,r,n){t!==e?n.push({i:r.push(xa(r)+\"skewX(\",null,\")\")-2,x:Zi(t,e)}):e&&r.push(xa(r)+\"skewX(\"+e+\")\")}(e.skew,r.skew,n,i),function(t,e,r,n){if(t[0]!==e[0]||t[1]!==e[1]){var i=r.push(xa(r)+\"scale(\",null,\",\",null,\")\");n.push({i:i-4,x:Zi(t[0],e[0])},{i:i-2,x:Zi(t[1],e[1])})}else 1===e[0]&&1===e[1]||r.push(xa(r)+\"scale(\"+e+\")\")}(e.scale,r.scale,n,i),e=r=null,function(t){for(var e,r=-1,a=i.length;++r<a;)n[(e=i[r]).i]=e.x(t);return n.join(\"\")}}function _a(t,e){return e=(e-=t=+t)||1/e,function(r){return(r-t)/e}}function wa(t,e){return e=(e-=t=+t)||1/e,function(r){return Math.max(0,Math.min(1,(r-t)/e))}}function Ta(t){for(var e=t.source,r=t.target,n=function(t,e){if(t===e)return t;var r=ka(t),n=ka(e),i=r.pop(),a=n.pop(),o=null;for(;i===a;)o=i,i=r.pop(),a=n.pop();return o}(e,r),i=[e];e!==n;)e=e.parent,i.push(e);for(var a=i.length;r!==n;)i.splice(a,0,r),r=r.parent;return i}function ka(t){for(var e=[],r=t.parent;null!=r;)e.push(t),t=r,r=r.parent;return e.push(t),e}function Ma(t){t.fixed|=2}function Aa(t){t.fixed&=-7}function Sa(t){t.fixed|=4,t.px=t.x,t.py=t.y}function Ea(t){t.fixed&=-5}t.interpolateTransform=ba,t.layout={},t.layout.bundle=function(){return function(t){for(var e=[],r=-1,n=t.length;++r<n;)e.push(Ta(t[r]));return e}},t.layout.chord=function(){var e,r,n,i,a,o,s,l={},c=0;function u(){var l,u,h,p,d,m={},g=[],v=t.range(i),y=[];for(e=[],r=[],l=0,p=-1;++p<i;){for(u=0,d=-1;++d<i;)u+=n[p][d];g.push(u),y.push(t.range(i)),l+=u}for(a&&v.sort((function(t,e){return a(g[t],g[e])})),o&&y.forEach((function(t,e){t.sort((function(t,r){return o(n[e][t],n[e][r])}))})),l=(St-c*i)/l,u=0,p=-1;++p<i;){for(h=u,d=-1;++d<i;){var x=v[p],b=y[x][d],_=n[x][b],w=u,T=u+=_*l;m[x+\"-\"+b]={index:x,subindex:b,startAngle:w,endAngle:T,value:_}}r[x]={index:x,startAngle:h,endAngle:u,value:g[x]},u+=c}for(p=-1;++p<i;)for(d=p-1;++d<i;){var k=m[p+\"-\"+d],M=m[d+\"-\"+p];(k.value||M.value)&&e.push(k.value<M.value?{source:M,target:k}:{source:k,target:M})}s&&f()}function f(){e.sort((function(t,e){return s((t.source.value+t.target.value)/2,(e.source.value+e.target.value)/2)}))}return l.matrix=function(t){return arguments.length?(i=(n=t)&&n.length,e=r=null,l):n},l.padding=function(t){return arguments.length?(c=t,e=r=null,l):c},l.sortGroups=function(t){return arguments.length?(a=t,e=r=null,l):a},l.sortSubgroups=function(t){return arguments.length?(o=t,e=null,l):o},l.sortChords=function(t){return arguments.length?(s=t,e&&f(),l):s},l.chords=function(){return e||u(),e},l.groups=function(){return r||u(),r},l},t.layout.force=function(){var e,r,n,i,a,o,s={},l=t.dispatch(\"start\",\"tick\",\"end\"),c=[1,1],u=.9,f=La,h=Ca,p=-30,d=Pa,m=.1,g=.64,v=[],y=[];function x(t){return function(e,r,n,i){if(e.point!==t){var a=e.cx-t.x,o=e.cy-t.y,s=i-r,l=a*a+o*o;if(s*s/g<l){if(l<d){var c=e.charge/l;t.px-=a*c,t.py-=o*c}return!0}if(e.point&&l&&l<d){c=e.pointCharge/l;t.px-=a*c,t.py-=o*c}}return!e.charge}}function b(e){e.px=t.event.x,e.py=t.event.y,s.resume()}return s.tick=function(){if((n*=.99)<.005)return e=null,l.end({type:\"end\",alpha:n=0}),!0;var r,s,f,h,d,g,b,_,w,T=v.length,k=y.length;for(s=0;s<k;++s)h=(f=y[s]).source,(g=(_=(d=f.target).x-h.x)*_+(w=d.y-h.y)*w)&&(_*=g=n*a[s]*((g=Math.sqrt(g))-i[s])/g,w*=g,d.x-=_*(b=h.weight+d.weight?h.weight/(h.weight+d.weight):.5),d.y-=w*b,h.x+=_*(b=1-b),h.y+=w*b);if((b=n*m)&&(_=c[0]/2,w=c[1]/2,s=-1,b))for(;++s<T;)(f=v[s]).x+=(_-f.x)*b,f.y+=(w-f.y)*b;if(p)for(!function t(e,r,n){var i=0,a=0;if(e.charge=0,!e.leaf)for(var o,s=e.nodes,l=s.length,c=-1;++c<l;)null!=(o=s[c])&&(t(o,r,n),e.charge+=o.charge,i+=o.charge*o.cx,a+=o.charge*o.cy);if(e.point){e.leaf||(e.point.x+=Math.random()-.5,e.point.y+=Math.random()-.5);var u=r*n[e.point.index];e.charge+=e.pointCharge=u,i+=u*e.point.x,a+=u*e.point.y}e.cx=i/e.charge,e.cy=a/e.charge}(r=t.geom.quadtree(v),n,o),s=-1;++s<T;)(f=v[s]).fixed||r.visit(x(f));for(s=-1;++s<T;)(f=v[s]).fixed?(f.x=f.px,f.y=f.py):(f.x-=(f.px-(f.px=f.x))*u,f.y-=(f.py-(f.py=f.y))*u);l.tick({type:\"tick\",alpha:n})},s.nodes=function(t){return arguments.length?(v=t,s):v},s.links=function(t){return arguments.length?(y=t,s):y},s.size=function(t){return arguments.length?(c=t,s):c},s.linkDistance=function(t){return arguments.length?(f=\"function\"==typeof t?t:+t,s):f},s.distance=s.linkDistance,s.linkStrength=function(t){return arguments.length?(h=\"function\"==typeof t?t:+t,s):h},s.friction=function(t){return arguments.length?(u=+t,s):u},s.charge=function(t){return arguments.length?(p=\"function\"==typeof t?t:+t,s):p},s.chargeDistance=function(t){return arguments.length?(d=t*t,s):Math.sqrt(d)},s.gravity=function(t){return arguments.length?(m=+t,s):m},s.theta=function(t){return arguments.length?(g=t*t,s):Math.sqrt(g)},s.alpha=function(t){return arguments.length?(t=+t,n?t>0?n=t:(e.c=null,e.t=NaN,e=null,l.end({type:\"end\",alpha:n=0})):t>0&&(l.start({type:\"start\",alpha:n=t}),e=we(s.tick)),s):n},s.start=function(){var t,e,r,n=v.length,l=y.length,u=c[0],d=c[1];for(t=0;t<n;++t)(r=v[t]).index=t,r.weight=0;for(t=0;t<l;++t)\"number\"==typeof(r=y[t]).source&&(r.source=v[r.source]),\"number\"==typeof r.target&&(r.target=v[r.target]),++r.source.weight,++r.target.weight;for(t=0;t<n;++t)r=v[t],isNaN(r.x)&&(r.x=m(\"x\",u)),isNaN(r.y)&&(r.y=m(\"y\",d)),isNaN(r.px)&&(r.px=r.x),isNaN(r.py)&&(r.py=r.y);if(i=[],\"function\"==typeof f)for(t=0;t<l;++t)i[t]=+f.call(this,y[t],t);else for(t=0;t<l;++t)i[t]=f;if(a=[],\"function\"==typeof h)for(t=0;t<l;++t)a[t]=+h.call(this,y[t],t);else for(t=0;t<l;++t)a[t]=h;if(o=[],\"function\"==typeof p)for(t=0;t<n;++t)o[t]=+p.call(this,v[t],t);else for(t=0;t<n;++t)o[t]=p;function m(r,i){if(!e){for(e=new Array(n),c=0;c<n;++c)e[c]=[];for(c=0;c<l;++c){var a=y[c];e[a.source.index].push(a.target),e[a.target.index].push(a.source)}}for(var o,s=e[t],c=-1,u=s.length;++c<u;)if(!isNaN(o=s[c][r]))return o;return Math.random()*i}return s.resume()},s.resume=function(){return s.alpha(.1)},s.stop=function(){return s.alpha(0)},s.drag=function(){if(r||(r=t.behavior.drag().origin(C).on(\"dragstart.force\",Ma).on(\"drag.force\",b).on(\"dragend.force\",Aa)),!arguments.length)return r;this.on(\"mouseover.force\",Sa).on(\"mouseout.force\",Ea).call(r)},t.rebind(s,l,\"on\")};var La=20,Ca=1,Pa=1/0;function Ia(e,r){return t.rebind(e,r,\"sort\",\"children\",\"value\"),e.nodes=e,e.links=Ba,e}function Oa(t,e){for(var r=[t];null!=(t=r.pop());)if(e(t),(i=t.children)&&(n=i.length))for(var n,i;--n>=0;)r.push(i[n])}function za(t,e){for(var r=[t],n=[];null!=(t=r.pop());)if(n.push(t),(a=t.children)&&(i=a.length))for(var i,a,o=-1;++o<i;)r.push(a[o]);for(;null!=(t=n.pop());)e(t)}function Da(t){return t.children}function Ra(t){return t.value}function Fa(t,e){return e.value-t.value}function Ba(e){return t.merge(e.map((function(t){return(t.children||[]).map((function(e){return{source:t,target:e}}))})))}t.layout.hierarchy=function(){var t=Fa,e=Da,r=Ra;function n(i){var a,o=[i],s=[];for(i.depth=0;null!=(a=o.pop());)if(s.push(a),(c=e.call(n,a,a.depth))&&(l=c.length)){for(var l,c,u;--l>=0;)o.push(u=c[l]),u.parent=a,u.depth=a.depth+1;r&&(a.value=0),a.children=c}else r&&(a.value=+r.call(n,a,a.depth)||0),delete a.children;return za(i,(function(e){var n,i;t&&(n=e.children)&&n.sort(t),r&&(i=e.parent)&&(i.value+=e.value)})),s}return n.sort=function(e){return arguments.length?(t=e,n):t},n.children=function(t){return arguments.length?(e=t,n):e},n.value=function(t){return arguments.length?(r=t,n):r},n.revalue=function(t){return r&&(Oa(t,(function(t){t.children&&(t.value=0)})),za(t,(function(t){var e;t.children||(t.value=+r.call(n,t,t.depth)||0),(e=t.parent)&&(e.value+=t.value)}))),t},n},t.layout.partition=function(){var e=t.layout.hierarchy(),r=[1,1];function n(t,n){var i=e.call(this,t,n);return function t(e,r,n,i){var a=e.children;if(e.x=r,e.y=e.depth*i,e.dx=n,e.dy=i,a&&(o=a.length)){var o,s,l,c=-1;for(n=e.value?n/e.value:0;++c<o;)t(s=a[c],r,l=s.value*n,i),r+=l}}(i[0],0,r[0],r[1]/function t(e){var r=e.children,n=0;if(r&&(i=r.length))for(var i,a=-1;++a<i;)n=Math.max(n,t(r[a]));return 1+n}(i[0])),i}return n.size=function(t){return arguments.length?(r=t,n):r},Ia(n,e)},t.layout.pie=function(){var e=Number,r=Na,n=0,i=St,a=0;function o(s){var l,c=s.length,u=s.map((function(t,r){return+e.call(o,t,r)})),f=+(\"function\"==typeof n?n.apply(this,arguments):n),h=(\"function\"==typeof i?i.apply(this,arguments):i)-f,p=Math.min(Math.abs(h)/c,+(\"function\"==typeof a?a.apply(this,arguments):a)),d=p*(h<0?-1:1),m=t.sum(u),g=m?(h-c*d)/m:0,v=t.range(c),y=[];return null!=r&&v.sort(r===Na?function(t,e){return u[e]-u[t]}:function(t,e){return r(s[t],s[e])}),v.forEach((function(t){y[t]={data:s[t],value:l=u[t],startAngle:f,endAngle:f+=l*g+d,padAngle:p}})),y}return o.value=function(t){return arguments.length?(e=t,o):e},o.sort=function(t){return arguments.length?(r=t,o):r},o.startAngle=function(t){return arguments.length?(n=t,o):n},o.endAngle=function(t){return arguments.length?(i=t,o):i},o.padAngle=function(t){return arguments.length?(a=t,o):a},o};var Na={};function ja(t){return t.x}function Ua(t){return t.y}function Va(t,e,r){t.y0=e,t.y=r}t.layout.stack=function(){var e=C,r=Ga,n=Ya,i=Va,a=ja,o=Ua;function s(l,c){if(!(p=l.length))return l;var u=l.map((function(t,r){return e.call(s,t,r)})),f=u.map((function(t){return t.map((function(t,e){return[a.call(s,t,e),o.call(s,t,e)]}))})),h=r.call(s,f,c);u=t.permute(u,h),f=t.permute(f,h);var p,d,m,g,v=n.call(s,f,c),y=u[0].length;for(m=0;m<y;++m)for(i.call(s,u[0][m],g=v[m],f[0][m][1]),d=1;d<p;++d)i.call(s,u[d][m],g+=f[d-1][m][1],f[d][m][1]);return l}return s.values=function(t){return arguments.length?(e=t,s):e},s.order=function(t){return arguments.length?(r=\"function\"==typeof t?t:qa.get(t)||Ga,s):r},s.offset=function(t){return arguments.length?(n=\"function\"==typeof t?t:Ha.get(t)||Ya,s):n},s.x=function(t){return arguments.length?(a=t,s):a},s.y=function(t){return arguments.length?(o=t,s):o},s.out=function(t){return arguments.length?(i=t,s):i},s};var qa=t.map({\"inside-out\":function(e){var r,n,i=e.length,a=e.map(Wa),o=e.map(Xa),s=t.range(i).sort((function(t,e){return a[t]-a[e]})),l=0,c=0,u=[],f=[];for(r=0;r<i;++r)n=s[r],l<c?(l+=o[n],u.push(n)):(c+=o[n],f.push(n));return f.reverse().concat(u)},reverse:function(e){return t.range(e.length).reverse()},default:Ga}),Ha=t.map({silhouette:function(t){var e,r,n,i=t.length,a=t[0].length,o=[],s=0,l=[];for(r=0;r<a;++r){for(e=0,n=0;e<i;e++)n+=t[e][r][1];n>s&&(s=n),o.push(n)}for(r=0;r<a;++r)l[r]=(s-o[r])/2;return l},wiggle:function(t){var e,r,n,i,a,o,s,l,c,u=t.length,f=t[0],h=f.length,p=[];for(p[0]=l=c=0,r=1;r<h;++r){for(e=0,i=0;e<u;++e)i+=t[e][r][1];for(e=0,a=0,s=f[r][0]-f[r-1][0];e<u;++e){for(n=0,o=(t[e][r][1]-t[e][r-1][1])/(2*s);n<e;++n)o+=(t[n][r][1]-t[n][r-1][1])/s;a+=o*t[e][r][1]}p[r]=l-=i?a/i*s:0,l<c&&(c=l)}for(r=0;r<h;++r)p[r]-=c;return p},expand:function(t){var e,r,n,i=t.length,a=t[0].length,o=1/i,s=[];for(r=0;r<a;++r){for(e=0,n=0;e<i;e++)n+=t[e][r][1];if(n)for(e=0;e<i;e++)t[e][r][1]/=n;else for(e=0;e<i;e++)t[e][r][1]=o}for(r=0;r<a;++r)s[r]=0;return s},zero:Ya});function Ga(e){return t.range(e.length)}function Ya(t){for(var e=-1,r=t[0].length,n=[];++e<r;)n[e]=0;return n}function Wa(t){for(var e,r=1,n=0,i=t[0][1],a=t.length;r<a;++r)(e=t[r][1])>i&&(n=r,i=e);return n}function Xa(t){return t.reduce(Za,0)}function Za(t,e){return t+e[1]}function Ja(t,e){return Ka(t,Math.ceil(Math.log(e.length)/Math.LN2+1))}function Ka(t,e){for(var r=-1,n=+t[0],i=(t[1]-n)/e,a=[];++r<=e;)a[r]=i*r+n;return a}function Qa(e){return[t.min(e),t.max(e)]}function $a(t,e){return t.value-e.value}function to(t,e){var r=t._pack_next;t._pack_next=e,e._pack_prev=t,e._pack_next=r,r._pack_prev=e}function eo(t,e){t._pack_next=e,e._pack_prev=t}function ro(t,e){var r=e.x-t.x,n=e.y-t.y,i=t.r+e.r;return.999*i*i>r*r+n*n}function no(t){if((e=t.children)&&(l=e.length)){var e,r,n,i,a,o,s,l,c=1/0,u=-1/0,f=1/0,h=-1/0;if(e.forEach(io),(r=e[0]).x=-r.r,r.y=0,x(r),l>1&&((n=e[1]).x=n.r,n.y=0,x(n),l>2))for(oo(r,n,i=e[2]),x(i),to(r,i),r._pack_prev=i,to(i,n),n=r._pack_next,a=3;a<l;a++){oo(r,n,i=e[a]);var p=0,d=1,m=1;for(o=n._pack_next;o!==n;o=o._pack_next,d++)if(ro(o,i)){p=1;break}if(1==p)for(s=r._pack_prev;s!==o._pack_prev&&!ro(s,i);s=s._pack_prev,m++);p?(d<m||d==m&&n.r<r.r?eo(r,n=o):eo(r=s,n),a--):(to(r,i),n=i,x(i))}var g=(c+u)/2,v=(f+h)/2,y=0;for(a=0;a<l;a++)(i=e[a]).x-=g,i.y-=v,y=Math.max(y,i.r+Math.sqrt(i.x*i.x+i.y*i.y));t.r=y,e.forEach(ao)}function x(t){c=Math.min(t.x-t.r,c),u=Math.max(t.x+t.r,u),f=Math.min(t.y-t.r,f),h=Math.max(t.y+t.r,h)}}function io(t){t._pack_next=t._pack_prev=t}function ao(t){delete t._pack_next,delete t._pack_prev}function oo(t,e,r){var n=t.r+r.r,i=e.x-t.x,a=e.y-t.y;if(n&&(i||a)){var o=e.r+r.r,s=i*i+a*a,l=.5+((n*=n)-(o*=o))/(2*s),c=Math.sqrt(Math.max(0,2*o*(n+s)-(n-=s)*n-o*o))/(2*s);r.x=t.x+l*i+c*a,r.y=t.y+l*a-c*i}else r.x=t.x+n,r.y=t.y}function so(t,e){return t.parent==e.parent?1:2}function lo(t){var e=t.children;return e.length?e[0]:t.t}function co(t){var e,r=t.children;return(e=r.length)?r[e-1]:t.t}function uo(t,e,r){var n=r/(e.i-t.i);e.c-=n,e.s+=r,t.c+=n,e.z+=r,e.m+=r}function fo(t,e,r){return t.a.parent===e.parent?t.a:r}function ho(t){return{x:t.x,y:t.y,dx:t.dx,dy:t.dy}}function po(t,e){var r=t.x+e[3],n=t.y+e[0],i=t.dx-e[1]-e[3],a=t.dy-e[0]-e[2];return i<0&&(r+=i/2,i=0),a<0&&(n+=a/2,a=0),{x:r,y:n,dx:i,dy:a}}function mo(t){var e=t[0],r=t[t.length-1];return e<r?[e,r]:[r,e]}function go(t){return t.rangeExtent?t.rangeExtent():mo(t.range())}function vo(t,e,r,n){var i=r(t[0],t[1]),a=n(e[0],e[1]);return function(t){return a(i(t))}}function yo(t,e){var r,n=0,i=t.length-1,a=t[n],o=t[i];return o<a&&(r=n,n=i,i=r,r=a,a=o,o=r),t[n]=e.floor(a),t[i]=e.ceil(o),t}function xo(t){return t?{floor:function(e){return Math.floor(e/t)*t},ceil:function(e){return Math.ceil(e/t)*t}}:bo}t.layout.histogram=function(){var e=!0,r=Number,n=Qa,i=Ja;function a(a,o){for(var s,l,c=[],u=a.map(r,this),f=n.call(this,u,o),h=i.call(this,f,u,o),p=(o=-1,u.length),d=h.length-1,m=e?1:1/p;++o<d;)(s=c[o]=[]).dx=h[o+1]-(s.x=h[o]),s.y=0;if(d>0)for(o=-1;++o<p;)(l=u[o])>=f[0]&&l<=f[1]&&((s=c[t.bisect(h,l,1,d)-1]).y+=m,s.push(a[o]));return c}return a.value=function(t){return arguments.length?(r=t,a):r},a.range=function(t){return arguments.length?(n=de(t),a):n},a.bins=function(t){return arguments.length?(i=\"number\"==typeof t?function(e){return Ka(e,t)}:de(t),a):i},a.frequency=function(t){return arguments.length?(e=!!t,a):e},a},t.layout.pack=function(){var e,r=t.layout.hierarchy().sort($a),n=0,i=[1,1];function a(t,a){var o=r.call(this,t,a),s=o[0],l=i[0],c=i[1],u=null==e?Math.sqrt:\"function\"==typeof e?e:function(){return e};if(s.x=s.y=0,za(s,(function(t){t.r=+u(t.value)})),za(s,no),n){var f=n*(e?1:Math.max(2*s.r/l,2*s.r/c))/2;za(s,(function(t){t.r+=f})),za(s,no),za(s,(function(t){t.r-=f}))}return function t(e,r,n,i){var a=e.children;if(e.x=r+=i*e.x,e.y=n+=i*e.y,e.r*=i,a)for(var o=-1,s=a.length;++o<s;)t(a[o],r,n,i)}(s,l/2,c/2,e?1:1/Math.max(2*s.r/l,2*s.r/c)),o}return a.size=function(t){return arguments.length?(i=t,a):i},a.radius=function(t){return arguments.length?(e=null==t||\"function\"==typeof t?t:+t,a):e},a.padding=function(t){return arguments.length?(n=+t,a):n},Ia(a,r)},t.layout.tree=function(){var e=t.layout.hierarchy().sort(null).value(null),r=so,n=[1,1],i=null;function a(t,a){var c=e.call(this,t,a),u=c[0],f=function(t){var e,r={A:null,children:[t]},n=[r];for(;null!=(e=n.pop());)for(var i,a=e.children,o=0,s=a.length;o<s;++o)n.push((a[o]=i={_:a[o],parent:e,children:(i=a[o].children)&&i.slice()||[],A:null,a:null,z:0,m:0,c:0,s:0,t:null,i:o}).a=i);return r.children[0]}(u);if(za(f,o),f.parent.m=-f.z,Oa(f,s),i)Oa(u,l);else{var h=u,p=u,d=u;Oa(u,(function(t){t.x<h.x&&(h=t),t.x>p.x&&(p=t),t.depth>d.depth&&(d=t)}));var m=r(h,p)/2-h.x,g=n[0]/(p.x+r(p,h)/2+m),v=n[1]/(d.depth||1);Oa(u,(function(t){t.x=(t.x+m)*g,t.y=t.depth*v}))}return c}function o(t){var e=t.children,n=t.parent.children,i=t.i?n[t.i-1]:null;if(e.length){!function(t){var e,r=0,n=0,i=t.children,a=i.length;for(;--a>=0;)(e=i[a]).z+=r,e.m+=r,r+=e.s+(n+=e.c)}(t);var a=(e[0].z+e[e.length-1].z)/2;i?(t.z=i.z+r(t._,i._),t.m=t.z-a):t.z=a}else i&&(t.z=i.z+r(t._,i._));t.parent.A=function(t,e,n){if(e){for(var i,a=t,o=t,s=e,l=a.parent.children[0],c=a.m,u=o.m,f=s.m,h=l.m;s=co(s),a=lo(a),s&&a;)l=lo(l),(o=co(o)).a=t,(i=s.z+f-a.z-c+r(s._,a._))>0&&(uo(fo(s,t,n),t,i),c+=i,u+=i),f+=s.m,c+=a.m,h+=l.m,u+=o.m;s&&!co(o)&&(o.t=s,o.m+=f-u),a&&!lo(l)&&(l.t=a,l.m+=c-h,n=t)}return n}(t,i,t.parent.A||n[0])}function s(t){t._.x=t.z+t.parent.m,t.m+=t.parent.m}function l(t){t.x*=n[0],t.y=t.depth*n[1]}return a.separation=function(t){return arguments.length?(r=t,a):r},a.size=function(t){return arguments.length?(i=null==(n=t)?l:null,a):i?null:n},a.nodeSize=function(t){return arguments.length?(i=null==(n=t)?null:l,a):i?n:null},Ia(a,e)},t.layout.cluster=function(){var e=t.layout.hierarchy().sort(null).value(null),r=so,n=[1,1],i=!1;function a(a,o){var s,l=e.call(this,a,o),c=l[0],u=0;za(c,(function(e){var n=e.children;n&&n.length?(e.x=function(t){return t.reduce((function(t,e){return t+e.x}),0)/t.length}(n),e.y=function(e){return 1+t.max(e,(function(t){return t.y}))}(n)):(e.x=s?u+=r(e,s):0,e.y=0,s=e)}));var f=function t(e){var r=e.children;return r&&r.length?t(r[0]):e}(c),h=function t(e){var r,n=e.children;return n&&(r=n.length)?t(n[r-1]):e}(c),p=f.x-r(f,h)/2,d=h.x+r(h,f)/2;return za(c,i?function(t){t.x=(t.x-c.x)*n[0],t.y=(c.y-t.y)*n[1]}:function(t){t.x=(t.x-p)/(d-p)*n[0],t.y=(1-(c.y?t.y/c.y:1))*n[1]}),l}return a.separation=function(t){return arguments.length?(r=t,a):r},a.size=function(t){return arguments.length?(i=null==(n=t),a):i?null:n},a.nodeSize=function(t){return arguments.length?(i=null!=(n=t),a):i?n:null},Ia(a,e)},t.layout.treemap=function(){var e,r=t.layout.hierarchy(),n=Math.round,i=[1,1],a=null,o=ho,s=!1,l=\"squarify\",c=.5*(1+Math.sqrt(5));function u(t,e){for(var r,n,i=-1,a=t.length;++i<a;)n=(r=t[i]).value*(e<0?0:e),r.area=isNaN(n)||n<=0?0:n}function f(t){var e=t.children;if(e&&e.length){var r,n,i,a=o(t),s=[],c=e.slice(),h=1/0,m=\"slice\"===l?a.dx:\"dice\"===l?a.dy:\"slice-dice\"===l?1&t.depth?a.dy:a.dx:Math.min(a.dx,a.dy);for(u(c,a.dx*a.dy/t.value),s.area=0;(i=c.length)>0;)s.push(r=c[i-1]),s.area+=r.area,\"squarify\"!==l||(n=p(s,m))<=h?(c.pop(),h=n):(s.area-=s.pop().area,d(s,m,a,!1),m=Math.min(a.dx,a.dy),s.length=s.area=0,h=1/0);s.length&&(d(s,m,a,!0),s.length=s.area=0),e.forEach(f)}}function h(t){var e=t.children;if(e&&e.length){var r,n=o(t),i=e.slice(),a=[];for(u(i,n.dx*n.dy/t.value),a.area=0;r=i.pop();)a.push(r),a.area+=r.area,null!=r.z&&(d(a,r.z?n.dx:n.dy,n,!i.length),a.length=a.area=0);e.forEach(h)}}function p(t,e){for(var r,n=t.area,i=0,a=1/0,o=-1,s=t.length;++o<s;)(r=t[o].area)&&(r<a&&(a=r),r>i&&(i=r));return e*=e,(n*=n)?Math.max(e*i*c/n,n/(e*a*c)):1/0}function d(t,e,r,i){var a,o=-1,s=t.length,l=r.x,c=r.y,u=e?n(t.area/e):0;if(e==r.dx){for((i||u>r.dy)&&(u=r.dy);++o<s;)(a=t[o]).x=l,a.y=c,a.dy=u,l+=a.dx=Math.min(r.x+r.dx-l,u?n(a.area/u):0);a.z=!0,a.dx+=r.x+r.dx-l,r.y+=u,r.dy-=u}else{for((i||u>r.dx)&&(u=r.dx);++o<s;)(a=t[o]).x=l,a.y=c,a.dx=u,c+=a.dy=Math.min(r.y+r.dy-c,u?n(a.area/u):0);a.z=!1,a.dy+=r.y+r.dy-c,r.x+=u,r.dx-=u}}function m(t){var n=e||r(t),a=n[0];return a.x=a.y=0,a.value?(a.dx=i[0],a.dy=i[1]):a.dx=a.dy=0,e&&r.revalue(a),u([a],a.dx*a.dy/a.value),(e?h:f)(a),s&&(e=n),n}return m.size=function(t){return arguments.length?(i=t,m):i},m.padding=function(t){if(!arguments.length)return a;function e(e){var r=t.call(m,e,e.depth);return null==r?ho(e):po(e,\"number\"==typeof r?[r,r,r,r]:r)}function r(e){return po(e,t)}var n;return o=null==(a=t)?ho:\"function\"==(n=typeof t)?e:\"number\"===n?(t=[t,t,t,t],r):r,m},m.round=function(t){return arguments.length?(n=t?Math.round:Number,m):n!=Number},m.sticky=function(t){return arguments.length?(s=t,e=null,m):s},m.ratio=function(t){return arguments.length?(c=t,m):c},m.mode=function(t){return arguments.length?(l=t+\"\",m):l},Ia(m,r)},t.random={normal:function(t,e){var r=arguments.length;return r<2&&(e=1),r<1&&(t=0),function(){var r,n,i;do{i=(r=2*Math.random()-1)*r+(n=2*Math.random()-1)*n}while(!i||i>1);return t+e*r*Math.sqrt(-2*Math.log(i)/i)}},logNormal:function(){var e=t.random.normal.apply(t,arguments);return function(){return Math.exp(e())}},bates:function(e){var r=t.random.irwinHall(e);return function(){return r()/e}},irwinHall:function(t){return function(){for(var e=0,r=0;r<t;r++)e+=Math.random();return e}}},t.scale={};var bo={floor:C,ceil:C};function _o(e,r,n,i){var a=[],o=[],s=0,l=Math.min(e.length,r.length)-1;for(e[l]<e[0]&&(e=e.slice().reverse(),r=r.slice().reverse());++s<=l;)a.push(n(e[s-1],e[s])),o.push(i(r[s-1],r[s]));return function(r){var n=t.bisect(e,r,1,l)-1;return o[n](a[n](r))}}function wo(e,r){return t.rebind(e,r,\"range\",\"rangeRound\",\"interpolate\",\"clamp\")}function To(t,e){return yo(t,xo(ko(t,e)[2])),yo(t,xo(ko(t,e)[2])),t}function ko(t,e){null==e&&(e=10);var r=mo(t),n=r[1]-r[0],i=Math.pow(10,Math.floor(Math.log(n/e)/Math.LN10)),a=e/n*i;return a<=.15?i*=10:a<=.35?i*=5:a<=.75&&(i*=2),r[0]=Math.ceil(r[0]/i)*i,r[1]=Math.floor(r[1]/i)*i+.5*i,r[2]=i,r}function Mo(e,r){return t.range.apply(t,ko(e,r))}function Ao(e,r,n){var i=ko(e,r);if(n){var a=Le.exec(n);if(a.shift(),\"s\"===a[8]){var o=t.formatPrefix(Math.max(y(i[0]),y(i[1])));return a[7]||(a[7]=\".\"+Eo(o.scale(i[2]))),a[8]=\"f\",n=t.format(a.join(\"\")),function(t){return n(o.scale(t))+o.symbol}}a[7]||(a[7]=\".\"+function(t,e){var r=Eo(e[2]);return t in So?Math.abs(r-Eo(Math.max(y(e[0]),y(e[1]))))+ +(\"e\"!==t):r-2*(\"%\"===t)}(a[8],i)),n=a.join(\"\")}else n=\",.\"+Eo(i[2])+\"f\";return t.format(n)}t.scale.linear=function(){return function t(e,r,n,i){var a,o;function s(){var t=Math.min(e.length,r.length)>2?_o:vo,s=i?wa:_a;return a=t(e,r,s,n),o=t(r,e,s,$i),l}function l(t){return a(t)}return l.invert=function(t){return o(t)},l.domain=function(t){return arguments.length?(e=t.map(Number),s()):e},l.range=function(t){return arguments.length?(r=t,s()):r},l.rangeRound=function(t){return l.range(t).interpolate(da)},l.clamp=function(t){return arguments.length?(i=t,s()):i},l.interpolate=function(t){return arguments.length?(n=t,s()):n},l.ticks=function(t){return Mo(e,t)},l.tickFormat=function(t,r){return Ao(e,t,r)},l.nice=function(t){return To(e,t),s()},l.copy=function(){return t(e,r,n,i)},s()}([0,1],[0,1],$i,!1)};var So={s:1,g:1,p:1,r:1,e:1};function Eo(t){return-Math.floor(Math.log(t)/Math.LN10+.01)}t.scale.log=function(){return function e(r,n,i,a){function o(t){return(i?Math.log(t<0?0:t):-Math.log(t>0?0:-t))/Math.log(n)}function s(t){return i?Math.pow(n,t):-Math.pow(n,-t)}function l(t){return r(o(t))}return l.invert=function(t){return s(r.invert(t))},l.domain=function(t){return arguments.length?(i=t[0]>=0,r.domain((a=t.map(Number)).map(o)),l):a},l.base=function(t){return arguments.length?(n=+t,r.domain(a.map(o)),l):n},l.nice=function(){var t=yo(a.map(o),i?Math:Co);return r.domain(t),a=t.map(s),l},l.ticks=function(){var t=mo(a),e=[],r=t[0],l=t[1],c=Math.floor(o(r)),u=Math.ceil(o(l)),f=n%1?2:n;if(isFinite(u-c)){if(i){for(;c<u;c++)for(var h=1;h<f;h++)e.push(s(c)*h);e.push(s(c))}else for(e.push(s(c));c++<u;)for(h=f-1;h>0;h--)e.push(s(c)*h);for(c=0;e[c]<r;c++);for(u=e.length;e[u-1]>l;u--);e=e.slice(c,u)}return e},l.tickFormat=function(e,r){if(!arguments.length)return Lo;arguments.length<2?r=Lo:\"function\"!=typeof r&&(r=t.format(r));var i=Math.max(1,n*e/l.ticks().length);return function(t){var e=t/s(Math.round(o(t)));return e*n<n-.5&&(e*=n),e<=i?r(t):\"\"}},l.copy=function(){return e(r.copy(),n,i,a)},wo(l,r)}(t.scale.linear().domain([0,1]),10,!0,[1,10])};var Lo=t.format(\".0e\"),Co={floor:function(t){return-Math.ceil(-t)},ceil:function(t){return-Math.floor(-t)}};function Po(t){return function(e){return e<0?-Math.pow(-e,t):Math.pow(e,t)}}t.scale.pow=function(){return function t(e,r,n){var i=Po(r),a=Po(1/r);function o(t){return e(i(t))}return o.invert=function(t){return a(e.invert(t))},o.domain=function(t){return arguments.length?(e.domain((n=t.map(Number)).map(i)),o):n},o.ticks=function(t){return Mo(n,t)},o.tickFormat=function(t,e){return Ao(n,t,e)},o.nice=function(t){return o.domain(To(n,t))},o.exponent=function(t){return arguments.length?(i=Po(r=t),a=Po(1/r),e.domain(n.map(i)),o):r},o.copy=function(){return t(e.copy(),r,n)},wo(o,e)}(t.scale.linear(),1,[0,1])},t.scale.sqrt=function(){return t.scale.pow().exponent(.5)},t.scale.ordinal=function(){return function e(r,n){var i,a,o;function s(t){return a[((i.get(t)||(\"range\"===n.t?i.set(t,r.push(t)):NaN))-1)%a.length]}function l(e,n){return t.range(r.length).map((function(t){return e+n*t}))}return s.domain=function(t){if(!arguments.length)return r;r=[],i=new _;for(var e,a=-1,o=t.length;++a<o;)i.has(e=t[a])||i.set(e,r.push(e));return s[n.t].apply(s,n.a)},s.range=function(t){return arguments.length?(a=t,o=0,n={t:\"range\",a:arguments},s):a},s.rangePoints=function(t,e){arguments.length<2&&(e=0);var i=t[0],c=t[1],u=r.length<2?(i=(i+c)/2,0):(c-i)/(r.length-1+e);return a=l(i+u*e/2,u),o=0,n={t:\"rangePoints\",a:arguments},s},s.rangeRoundPoints=function(t,e){arguments.length<2&&(e=0);var i=t[0],c=t[1],u=r.length<2?(i=c=Math.round((i+c)/2),0):(c-i)/(r.length-1+e)|0;return a=l(i+Math.round(u*e/2+(c-i-(r.length-1+e)*u)/2),u),o=0,n={t:\"rangeRoundPoints\",a:arguments},s},s.rangeBands=function(t,e,i){arguments.length<2&&(e=0),arguments.length<3&&(i=e);var c=t[1]<t[0],u=t[c-0],f=t[1-c],h=(f-u)/(r.length-e+2*i);return a=l(u+h*i,h),c&&a.reverse(),o=h*(1-e),n={t:\"rangeBands\",a:arguments},s},s.rangeRoundBands=function(t,e,i){arguments.length<2&&(e=0),arguments.length<3&&(i=e);var c=t[1]<t[0],u=t[c-0],f=t[1-c],h=Math.floor((f-u)/(r.length-e+2*i));return a=l(u+Math.round((f-u-(r.length-e)*h)/2),h),c&&a.reverse(),o=Math.round(h*(1-e)),n={t:\"rangeRoundBands\",a:arguments},s},s.rangeBand=function(){return o},s.rangeExtent=function(){return mo(n.a[0])},s.copy=function(){return e(r,n)},s.domain(r)}([],{t:\"range\",a:[[]]})},t.scale.category10=function(){return t.scale.ordinal().range(Io)},t.scale.category20=function(){return t.scale.ordinal().range(Oo)},t.scale.category20b=function(){return t.scale.ordinal().range(zo)},t.scale.category20c=function(){return t.scale.ordinal().range(Do)};var Io=[2062260,16744206,2924588,14034728,9725885,9197131,14907330,8355711,12369186,1556175].map(ae),Oo=[2062260,11454440,16744206,16759672,2924588,10018698,14034728,16750742,9725885,12955861,9197131,12885140,14907330,16234194,8355711,13092807,12369186,14408589,1556175,10410725].map(ae),zo=[3750777,5395619,7040719,10264286,6519097,9216594,11915115,13556636,9202993,12426809,15186514,15190932,8666169,11356490,14049643,15177372,8077683,10834324,13528509,14589654].map(ae),Do=[3244733,7057110,10406625,13032431,15095053,16616764,16625259,16634018,3253076,7652470,10607003,13101504,7695281,10394312,12369372,14342891,6513507,9868950,12434877,14277081].map(ae);function Ro(){return 0}t.scale.quantile=function(){return function e(r,n){var i;function a(){var e=0,a=n.length;for(i=[];++e<a;)i[e-1]=t.quantile(r,e/a);return o}function o(e){if(!isNaN(e=+e))return n[t.bisect(i,e)]}return o.domain=function(t){return arguments.length?(r=t.map(p).filter(d).sort(h),a()):r},o.range=function(t){return arguments.length?(n=t,a()):n},o.quantiles=function(){return i},o.invertExtent=function(t){return(t=n.indexOf(t))<0?[NaN,NaN]:[t>0?i[t-1]:r[0],t<i.length?i[t]:r[r.length-1]]},o.copy=function(){return e(r,n)},a()}([],[])},t.scale.quantize=function(){return function t(e,r,n){var i,a;function o(t){return n[Math.max(0,Math.min(a,Math.floor(i*(t-e))))]}function s(){return i=n.length/(r-e),a=n.length-1,o}return o.domain=function(t){return arguments.length?(e=+t[0],r=+t[t.length-1],s()):[e,r]},o.range=function(t){return arguments.length?(n=t,s()):n},o.invertExtent=function(t){return[t=(t=n.indexOf(t))<0?NaN:t/i+e,t+1/i]},o.copy=function(){return t(e,r,n)},s()}(0,1,[0,1])},t.scale.threshold=function(){return function e(r,n){function i(e){if(e<=e)return n[t.bisect(r,e)]}return i.domain=function(t){return arguments.length?(r=t,i):r},i.range=function(t){return arguments.length?(n=t,i):n},i.invertExtent=function(t){return t=n.indexOf(t),[r[t-1],r[t]]},i.copy=function(){return e(r,n)},i}([.5],[0,1])},t.scale.identity=function(){return function t(e){function r(t){return+t}return r.invert=r,r.domain=r.range=function(t){return arguments.length?(e=t.map(r),r):e},r.ticks=function(t){return Mo(e,t)},r.tickFormat=function(t,r){return Ao(e,t,r)},r.copy=function(){return t(e)},r}([0,1])},t.svg={},t.svg.arc=function(){var t=Bo,e=No,r=Ro,n=Fo,i=jo,a=Uo,o=Vo;function s(){var s=Math.max(0,+t.apply(this,arguments)),c=Math.max(0,+e.apply(this,arguments)),u=i.apply(this,arguments)-Lt,f=a.apply(this,arguments)-Lt,h=Math.abs(f-u),p=u>f?0:1;if(c<s&&(d=c,c=s,s=d),h>=Et)return l(c,p)+(s?l(s,1-p):\"\")+\"Z\";var d,m,g,v,y,x,b,_,w,T,k,M,A=0,S=0,E=[];if((v=(+o.apply(this,arguments)||0)/2)&&(g=n===Fo?Math.sqrt(s*s+c*c):+n.apply(this,arguments),p||(S*=-1),c&&(S=Dt(g/c*Math.sin(v))),s&&(A=Dt(g/s*Math.sin(v)))),c){y=c*Math.cos(u+S),x=c*Math.sin(u+S),b=c*Math.cos(f-S),_=c*Math.sin(f-S);var L=Math.abs(f-u-2*S)<=At?0:1;if(S&&qo(y,x,b,_)===p^L){var C=(u+f)/2;y=c*Math.cos(C),x=c*Math.sin(C),b=_=null}}else y=x=0;if(s){w=s*Math.cos(f-A),T=s*Math.sin(f-A),k=s*Math.cos(u+A),M=s*Math.sin(u+A);var P=Math.abs(u-f+2*A)<=At?0:1;if(A&&qo(w,T,k,M)===1-p^P){var I=(u+f)/2;w=s*Math.cos(I),T=s*Math.sin(I),k=M=null}}else w=T=0;if(h>kt&&(d=Math.min(Math.abs(c-s)/2,+r.apply(this,arguments)))>.001){m=s<c^p?0:1;var O=d,z=d;if(h<At){var D=null==k?[w,T]:null==b?[y,x]:li([y,x],[k,M],[b,_],[w,T]),R=y-D[0],F=x-D[1],B=b-D[0],N=_-D[1],j=1/Math.sin(Math.acos((R*B+F*N)/(Math.sqrt(R*R+F*F)*Math.sqrt(B*B+N*N)))/2),U=Math.sqrt(D[0]*D[0]+D[1]*D[1]);z=Math.min(d,(s-U)/(j-1)),O=Math.min(d,(c-U)/(j+1))}if(null!=b){var V=Ho(null==k?[w,T]:[k,M],[y,x],c,O,p),q=Ho([b,_],[w,T],c,O,p);d===O?E.push(\"M\",V[0],\"A\",O,\",\",O,\" 0 0,\",m,\" \",V[1],\"A\",c,\",\",c,\" 0 \",1-p^qo(V[1][0],V[1][1],q[1][0],q[1][1]),\",\",p,\" \",q[1],\"A\",O,\",\",O,\" 0 0,\",m,\" \",q[0]):E.push(\"M\",V[0],\"A\",O,\",\",O,\" 0 1,\",m,\" \",q[0])}else E.push(\"M\",y,\",\",x);if(null!=k){var H=Ho([y,x],[k,M],s,-z,p),G=Ho([w,T],null==b?[y,x]:[b,_],s,-z,p);d===z?E.push(\"L\",G[0],\"A\",z,\",\",z,\" 0 0,\",m,\" \",G[1],\"A\",s,\",\",s,\" 0 \",p^qo(G[1][0],G[1][1],H[1][0],H[1][1]),\",\",1-p,\" \",H[1],\"A\",z,\",\",z,\" 0 0,\",m,\" \",H[0]):E.push(\"L\",G[0],\"A\",z,\",\",z,\" 0 0,\",m,\" \",H[0])}else E.push(\"L\",w,\",\",T)}else E.push(\"M\",y,\",\",x),null!=b&&E.push(\"A\",c,\",\",c,\" 0 \",L,\",\",p,\" \",b,\",\",_),E.push(\"L\",w,\",\",T),null!=k&&E.push(\"A\",s,\",\",s,\" 0 \",P,\",\",1-p,\" \",k,\",\",M);return E.push(\"Z\"),E.join(\"\")}function l(t,e){return\"M0,\"+t+\"A\"+t+\",\"+t+\" 0 1,\"+e+\" 0,\"+-t+\"A\"+t+\",\"+t+\" 0 1,\"+e+\" 0,\"+t}return s.innerRadius=function(e){return arguments.length?(t=de(e),s):t},s.outerRadius=function(t){return arguments.length?(e=de(t),s):e},s.cornerRadius=function(t){return arguments.length?(r=de(t),s):r},s.padRadius=function(t){return arguments.length?(n=t==Fo?Fo:de(t),s):n},s.startAngle=function(t){return arguments.length?(i=de(t),s):i},s.endAngle=function(t){return arguments.length?(a=de(t),s):a},s.padAngle=function(t){return arguments.length?(o=de(t),s):o},s.centroid=function(){var r=(+t.apply(this,arguments)+ +e.apply(this,arguments))/2,n=(+i.apply(this,arguments)+ +a.apply(this,arguments))/2-Lt;return[Math.cos(n)*r,Math.sin(n)*r]},s};var Fo=\"auto\";function Bo(t){return t.innerRadius}function No(t){return t.outerRadius}function jo(t){return t.startAngle}function Uo(t){return t.endAngle}function Vo(t){return t&&t.padAngle}function qo(t,e,r,n){return(t-r)*e-(e-n)*t>0?0:1}function Ho(t,e,r,n,i){var a=t[0]-e[0],o=t[1]-e[1],s=(i?n:-n)/Math.sqrt(a*a+o*o),l=s*o,c=-s*a,u=t[0]+l,f=t[1]+c,h=e[0]+l,p=e[1]+c,d=(u+h)/2,m=(f+p)/2,g=h-u,v=p-f,y=g*g+v*v,x=r-n,b=u*p-h*f,_=(v<0?-1:1)*Math.sqrt(Math.max(0,x*x*y-b*b)),w=(b*v-g*_)/y,T=(-b*g-v*_)/y,k=(b*v+g*_)/y,M=(-b*g+v*_)/y,A=w-d,S=T-m,E=k-d,L=M-m;return A*A+S*S>E*E+L*L&&(w=k,T=M),[[w-l,T-c],[w*r/x,T*r/x]]}function Go(t){var e=ri,r=ni,n=Yr,i=Wo,a=i.key,o=.7;function s(a){var s,l=[],c=[],u=-1,f=a.length,h=de(e),p=de(r);function d(){l.push(\"M\",i(t(c),o))}for(;++u<f;)n.call(this,s=a[u],u)?c.push([+h.call(this,s,u),+p.call(this,s,u)]):c.length&&(d(),c=[]);return c.length&&d(),l.length?l.join(\"\"):null}return s.x=function(t){return arguments.length?(e=t,s):e},s.y=function(t){return arguments.length?(r=t,s):r},s.defined=function(t){return arguments.length?(n=t,s):n},s.interpolate=function(t){return arguments.length?(a=\"function\"==typeof t?i=t:(i=Yo.get(t)||Wo).key,s):a},s.tension=function(t){return arguments.length?(o=t,s):o},s}t.svg.line=function(){return Go(C)};var Yo=t.map({linear:Wo,\"linear-closed\":Xo,step:function(t){var e=0,r=t.length,n=t[0],i=[n[0],\",\",n[1]];for(;++e<r;)i.push(\"H\",(n[0]+(n=t[e])[0])/2,\"V\",n[1]);r>1&&i.push(\"H\",n[0]);return i.join(\"\")},\"step-before\":Zo,\"step-after\":Jo,basis:$o,\"basis-open\":function(t){if(t.length<4)return Wo(t);var e,r=[],n=-1,i=t.length,a=[0],o=[0];for(;++n<3;)e=t[n],a.push(e[0]),o.push(e[1]);r.push(ts(ns,a)+\",\"+ts(ns,o)),--n;for(;++n<i;)e=t[n],a.shift(),a.push(e[0]),o.shift(),o.push(e[1]),is(r,a,o);return r.join(\"\")},\"basis-closed\":function(t){var e,r,n=-1,i=t.length,a=i+4,o=[],s=[];for(;++n<4;)r=t[n%i],o.push(r[0]),s.push(r[1]);e=[ts(ns,o),\",\",ts(ns,s)],--n;for(;++n<a;)r=t[n%i],o.shift(),o.push(r[0]),s.shift(),s.push(r[1]),is(e,o,s);return e.join(\"\")},bundle:function(t,e){var r=t.length-1;if(r)for(var n,i,a=t[0][0],o=t[0][1],s=t[r][0]-a,l=t[r][1]-o,c=-1;++c<=r;)n=t[c],i=c/r,n[0]=e*n[0]+(1-e)*(a+i*s),n[1]=e*n[1]+(1-e)*(o+i*l);return $o(t)},cardinal:function(t,e){return t.length<3?Wo(t):t[0]+Ko(t,Qo(t,e))},\"cardinal-open\":function(t,e){return t.length<4?Wo(t):t[1]+Ko(t.slice(1,-1),Qo(t,e))},\"cardinal-closed\":function(t,e){return t.length<3?Xo(t):t[0]+Ko((t.push(t[0]),t),Qo([t[t.length-2]].concat(t,[t[1]]),e))},monotone:function(t){return t.length<3?Wo(t):t[0]+Ko(t,function(t){var e,r,n,i,a=[],o=function(t){var e=0,r=t.length-1,n=[],i=t[0],a=t[1],o=n[0]=as(i,a);for(;++e<r;)n[e]=(o+(o=as(i=a,a=t[e+1])))/2;return n[e]=o,n}(t),s=-1,l=t.length-1;for(;++s<l;)e=as(t[s],t[s+1]),y(e)<kt?o[s]=o[s+1]=0:(r=o[s]/e,n=o[s+1]/e,(i=r*r+n*n)>9&&(i=3*e/Math.sqrt(i),o[s]=i*r,o[s+1]=i*n));s=-1;for(;++s<=l;)i=(t[Math.min(l,s+1)][0]-t[Math.max(0,s-1)][0])/(6*(1+o[s]*o[s])),a.push([i||0,o[s]*i||0]);return a}(t))}});function Wo(t){return t.length>1?t.join(\"L\"):t+\"Z\"}function Xo(t){return t.join(\"L\")+\"Z\"}function Zo(t){for(var e=0,r=t.length,n=t[0],i=[n[0],\",\",n[1]];++e<r;)i.push(\"V\",(n=t[e])[1],\"H\",n[0]);return i.join(\"\")}function Jo(t){for(var e=0,r=t.length,n=t[0],i=[n[0],\",\",n[1]];++e<r;)i.push(\"H\",(n=t[e])[0],\"V\",n[1]);return i.join(\"\")}function Ko(t,e){if(e.length<1||t.length!=e.length&&t.length!=e.length+2)return Wo(t);var r=t.length!=e.length,n=\"\",i=t[0],a=t[1],o=e[0],s=o,l=1;if(r&&(n+=\"Q\"+(a[0]-2*o[0]/3)+\",\"+(a[1]-2*o[1]/3)+\",\"+a[0]+\",\"+a[1],i=t[1],l=2),e.length>1){s=e[1],a=t[l],l++,n+=\"C\"+(i[0]+o[0])+\",\"+(i[1]+o[1])+\",\"+(a[0]-s[0])+\",\"+(a[1]-s[1])+\",\"+a[0]+\",\"+a[1];for(var c=2;c<e.length;c++,l++)a=t[l],s=e[c],n+=\"S\"+(a[0]-s[0])+\",\"+(a[1]-s[1])+\",\"+a[0]+\",\"+a[1]}if(r){var u=t[l];n+=\"Q\"+(a[0]+2*s[0]/3)+\",\"+(a[1]+2*s[1]/3)+\",\"+u[0]+\",\"+u[1]}return n}function Qo(t,e){for(var r,n=[],i=(1-e)/2,a=t[0],o=t[1],s=1,l=t.length;++s<l;)r=a,a=o,o=t[s],n.push([i*(o[0]-r[0]),i*(o[1]-r[1])]);return n}function $o(t){if(t.length<3)return Wo(t);var e=1,r=t.length,n=t[0],i=n[0],a=n[1],o=[i,i,i,(n=t[1])[0]],s=[a,a,a,n[1]],l=[i,\",\",a,\"L\",ts(ns,o),\",\",ts(ns,s)];for(t.push(t[r-1]);++e<=r;)n=t[e],o.shift(),o.push(n[0]),s.shift(),s.push(n[1]),is(l,o,s);return t.pop(),l.push(\"L\",n),l.join(\"\")}function ts(t,e){return t[0]*e[0]+t[1]*e[1]+t[2]*e[2]+t[3]*e[3]}Yo.forEach((function(t,e){e.key=t,e.closed=/-closed$/.test(t)}));var es=[0,2/3,1/3,0],rs=[0,1/3,2/3,0],ns=[0,1/6,2/3,1/6];function is(t,e,r){t.push(\"C\",ts(es,e),\",\",ts(es,r),\",\",ts(rs,e),\",\",ts(rs,r),\",\",ts(ns,e),\",\",ts(ns,r))}function as(t,e){return(e[1]-t[1])/(e[0]-t[0])}function os(t){for(var e,r,n,i=-1,a=t.length;++i<a;)r=(e=t[i])[0],n=e[1]-Lt,e[0]=r*Math.cos(n),e[1]=r*Math.sin(n);return t}function ss(t){var e=ri,r=ri,n=0,i=ni,a=Yr,o=Wo,s=o.key,l=o,c=\"L\",u=.7;function f(s){var f,h,p,d=[],m=[],g=[],v=-1,y=s.length,x=de(e),b=de(n),_=e===r?function(){return h}:de(r),w=n===i?function(){return p}:de(i);function T(){d.push(\"M\",o(t(g),u),c,l(t(m.reverse()),u),\"Z\")}for(;++v<y;)a.call(this,f=s[v],v)?(m.push([h=+x.call(this,f,v),p=+b.call(this,f,v)]),g.push([+_.call(this,f,v),+w.call(this,f,v)])):m.length&&(T(),m=[],g=[]);return m.length&&T(),d.length?d.join(\"\"):null}return f.x=function(t){return arguments.length?(e=r=t,f):r},f.x0=function(t){return arguments.length?(e=t,f):e},f.x1=function(t){return arguments.length?(r=t,f):r},f.y=function(t){return arguments.length?(n=i=t,f):i},f.y0=function(t){return arguments.length?(n=t,f):n},f.y1=function(t){return arguments.length?(i=t,f):i},f.defined=function(t){return arguments.length?(a=t,f):a},f.interpolate=function(t){return arguments.length?(s=\"function\"==typeof t?o=t:(o=Yo.get(t)||Wo).key,l=o.reverse||o,c=o.closed?\"M\":\"L\",f):s},f.tension=function(t){return arguments.length?(u=t,f):u},f}function ls(t){return t.radius}function cs(t){return[t.x,t.y]}function us(t){return function(){var e=t.apply(this,arguments),r=e[0],n=e[1]-Lt;return[r*Math.cos(n),r*Math.sin(n)]}}function fs(){return 64}function hs(){return\"circle\"}function ps(t){var e=Math.sqrt(t/At);return\"M0,\"+e+\"A\"+e+\",\"+e+\" 0 1,1 0,\"+-e+\"A\"+e+\",\"+e+\" 0 1,1 0,\"+e+\"Z\"}t.svg.line.radial=function(){var t=Go(os);return t.radius=t.x,delete t.x,t.angle=t.y,delete t.y,t},Zo.reverse=Jo,Jo.reverse=Zo,t.svg.area=function(){return ss(C)},t.svg.area.radial=function(){var t=ss(os);return t.radius=t.x,delete t.x,t.innerRadius=t.x0,delete t.x0,t.outerRadius=t.x1,delete t.x1,t.angle=t.y,delete t.y,t.startAngle=t.y0,delete t.y0,t.endAngle=t.y1,delete t.y1,t},t.svg.chord=function(){var t=Vn,e=qn,r=ls,n=jo,i=Uo;function a(r,n){var i,a,c=o(this,t,r,n),u=o(this,e,r,n);return\"M\"+c.p0+s(c.r,c.p1,c.a1-c.a0)+(a=u,((i=c).a0==a.a0&&i.a1==a.a1?l(c.r,c.p1,c.r,c.p0):l(c.r,c.p1,u.r,u.p0)+s(u.r,u.p1,u.a1-u.a0)+l(u.r,u.p1,c.r,c.p0))+\"Z\")}function o(t,e,a,o){var s=e.call(t,a,o),l=r.call(t,s,o),c=n.call(t,s,o)-Lt,u=i.call(t,s,o)-Lt;return{r:l,a0:c,a1:u,p0:[l*Math.cos(c),l*Math.sin(c)],p1:[l*Math.cos(u),l*Math.sin(u)]}}function s(t,e,r){return\"A\"+t+\",\"+t+\" 0 \"+ +(r>At)+\",1 \"+e}function l(t,e,r,n){return\"Q 0,0 \"+n}return a.radius=function(t){return arguments.length?(r=de(t),a):r},a.source=function(e){return arguments.length?(t=de(e),a):t},a.target=function(t){return arguments.length?(e=de(t),a):e},a.startAngle=function(t){return arguments.length?(n=de(t),a):n},a.endAngle=function(t){return arguments.length?(i=de(t),a):i},a},t.svg.diagonal=function(){var t=Vn,e=qn,r=cs;function n(n,i){var a=t.call(this,n,i),o=e.call(this,n,i),s=(a.y+o.y)/2,l=[a,{x:a.x,y:s},{x:o.x,y:s},o];return\"M\"+(l=l.map(r))[0]+\"C\"+l[1]+\" \"+l[2]+\" \"+l[3]}return n.source=function(e){return arguments.length?(t=de(e),n):t},n.target=function(t){return arguments.length?(e=de(t),n):e},n.projection=function(t){return arguments.length?(r=t,n):r},n},t.svg.diagonal.radial=function(){var e=t.svg.diagonal(),r=cs,n=e.projection;return e.projection=function(t){return arguments.length?n(us(r=t)):r},e},t.svg.symbol=function(){var t=hs,e=fs;function r(r,n){return(ds.get(t.call(this,r,n))||ps)(e.call(this,r,n))}return r.type=function(e){return arguments.length?(t=de(e),r):t},r.size=function(t){return arguments.length?(e=de(t),r):e},r};var ds=t.map({circle:ps,cross:function(t){var e=Math.sqrt(t/5)/2;return\"M\"+-3*e+\",\"+-e+\"H\"+-e+\"V\"+-3*e+\"H\"+e+\"V\"+-e+\"H\"+3*e+\"V\"+e+\"H\"+e+\"V\"+3*e+\"H\"+-e+\"V\"+e+\"H\"+-3*e+\"Z\"},diamond:function(t){var e=Math.sqrt(t/(2*gs)),r=e*gs;return\"M0,\"+-e+\"L\"+r+\",0 0,\"+e+\" \"+-r+\",0Z\"},square:function(t){var e=Math.sqrt(t)/2;return\"M\"+-e+\",\"+-e+\"L\"+e+\",\"+-e+\" \"+e+\",\"+e+\" \"+-e+\",\"+e+\"Z\"},\"triangle-down\":function(t){var e=Math.sqrt(t/ms),r=e*ms/2;return\"M0,\"+r+\"L\"+e+\",\"+-r+\" \"+-e+\",\"+-r+\"Z\"},\"triangle-up\":function(t){var e=Math.sqrt(t/ms),r=e*ms/2;return\"M0,\"+-r+\"L\"+e+\",\"+r+\" \"+-e+\",\"+r+\"Z\"}});t.svg.symbolTypes=ds.keys();var ms=Math.sqrt(3),gs=Math.tan(30*Ct);Y.transition=function(t){for(var e,r,n=bs||++Ts,i=As(t),a=[],o=_s||{time:Date.now(),ease:ca,delay:0,duration:250},s=-1,l=this.length;++s<l;){a.push(e=[]);for(var c=this[s],u=-1,f=c.length;++u<f;)(r=c[u])&&Ss(r,u,i,n,o),e.push(r)}return xs(a,i,n)},Y.interrupt=function(t){return this.each(null==t?vs:ys(As(t)))};var vs=ys(As());function ys(t){return function(){var e,r,n;(e=this[t])&&(n=e[r=e.active])&&(n.timer.c=null,n.timer.t=NaN,--e.count?delete e[r]:delete this[t],e.active+=.5,n.event&&n.event.interrupt.call(this,this.__data__,n.index))}}function xs(t,e,r){return U(t,ws),t.namespace=e,t.id=r,t}var bs,_s,ws=[],Ts=0;function ks(t,e,r,n){var i=t.id,a=t.namespace;return ut(t,\"function\"==typeof r?function(t,o,s){t[a][i].tween.set(e,n(r.call(t,t.__data__,o,s)))}:(r=n(r),function(t){t[a][i].tween.set(e,r)}))}function Ms(t){return null==t&&(t=\"\"),function(){this.textContent=t}}function As(t){return null==t?\"__transition__\":\"__transition_\"+t+\"__\"}function Ss(t,e,r,n,i){var a,o,s,l,c,u=t[r]||(t[r]={active:0,count:0}),f=u[n];function h(r){var i=u.active,h=u[i];for(var d in h&&(h.timer.c=null,h.timer.t=NaN,--u.count,delete u[i],h.event&&h.event.interrupt.call(t,t.__data__,h.index)),u)if(+d<n){var m=u[d];m.timer.c=null,m.timer.t=NaN,--u.count,delete u[d]}o.c=p,we((function(){return o.c&&p(r||1)&&(o.c=null,o.t=NaN),1}),0,a),u.active=n,f.event&&f.event.start.call(t,t.__data__,e),c=[],f.tween.forEach((function(r,n){(n=n.call(t,t.__data__,e))&&c.push(n)})),l=f.ease,s=f.duration}function p(i){for(var a=i/s,o=l(a),h=c.length;h>0;)c[--h].call(t,o);if(a>=1)return f.event&&f.event.end.call(t,t.__data__,e),--u.count?delete u[n]:delete t[r],1}f||(a=i.time,o=we((function(t){var e=f.delay;if(o.t=e+a,e<=t)return h(t-e);o.c=h}),0,a),f=u[n]={tween:new _,time:a,timer:o,delay:i.delay,duration:i.duration,ease:i.ease,index:e},i=null,++u.count)}ws.call=Y.call,ws.empty=Y.empty,ws.node=Y.node,ws.size=Y.size,t.transition=function(e,r){return e&&e.transition?bs?e.transition(r):e:t.selection().transition(e)},t.transition.prototype=ws,ws.select=function(t){var e,r,n,i=this.id,a=this.namespace,o=[];t=W(t);for(var s=-1,l=this.length;++s<l;){o.push(e=[]);for(var c=this[s],u=-1,f=c.length;++u<f;)(n=c[u])&&(r=t.call(n,n.__data__,u,s))?(\"__data__\"in n&&(r.__data__=n.__data__),Ss(r,u,a,i,n[a][i]),e.push(r)):e.push(null)}return xs(o,a,i)},ws.selectAll=function(t){var e,r,n,i,a,o=this.id,s=this.namespace,l=[];t=X(t);for(var c=-1,u=this.length;++c<u;)for(var f=this[c],h=-1,p=f.length;++h<p;)if(n=f[h]){a=n[s][o],r=t.call(n,n.__data__,h,c),l.push(e=[]);for(var d=-1,m=r.length;++d<m;)(i=r[d])&&Ss(i,d,s,o,a),e.push(i)}return xs(l,s,o)},ws.filter=function(t){var e,r,n=[];\"function\"!=typeof t&&(t=lt(t));for(var i=0,a=this.length;i<a;i++){n.push(e=[]);for(var o,s=0,l=(o=this[i]).length;s<l;s++)(r=o[s])&&t.call(r,r.__data__,s,i)&&e.push(r)}return xs(n,this.namespace,this.id)},ws.tween=function(t,e){var r=this.id,n=this.namespace;return arguments.length<2?this.node()[n][r].tween.get(t):ut(this,null==e?function(e){e[n][r].tween.remove(t)}:function(i){i[n][r].tween.set(t,e)})},ws.attr=function(e,r){if(arguments.length<2){for(r in e)this.attr(r,e[r]);return this}var n=\"transform\"==e?ba:$i,i=t.ns.qualify(e);function a(){this.removeAttribute(i)}function o(){this.removeAttributeNS(i.space,i.local)}function s(t){return null==t?a:(t+=\"\",function(){var e,r=this.getAttribute(i);return r!==t&&(e=n(r,t),function(t){this.setAttribute(i,e(t))})})}function l(t){return null==t?o:(t+=\"\",function(){var e,r=this.getAttributeNS(i.space,i.local);return r!==t&&(e=n(r,t),function(t){this.setAttributeNS(i.space,i.local,e(t))})})}return ks(this,\"attr.\"+e,r,i.local?l:s)},ws.attrTween=function(e,r){var n=t.ns.qualify(e);return this.tween(\"attr.\"+e,n.local?function(t,e){var i=r.call(this,t,e,this.getAttributeNS(n.space,n.local));return i&&function(t){this.setAttributeNS(n.space,n.local,i(t))}}:function(t,e){var i=r.call(this,t,e,this.getAttribute(n));return i&&function(t){this.setAttribute(n,i(t))}})},ws.style=function(t,e,r){var n=arguments.length;if(n<3){if(\"string\"!=typeof t){for(r in n<2&&(e=\"\"),t)this.style(r,t[r],e);return this}r=\"\"}function i(){this.style.removeProperty(t)}function a(e){return null==e?i:(e+=\"\",function(){var n,i=o(this).getComputedStyle(this,null).getPropertyValue(t);return i!==e&&(n=$i(i,e),function(e){this.style.setProperty(t,n(e),r)})})}return ks(this,\"style.\"+t,e,a)},ws.styleTween=function(t,e,r){function n(n,i){var a=e.call(this,n,i,o(this).getComputedStyle(this,null).getPropertyValue(t));return a&&function(e){this.style.setProperty(t,a(e),r)}}return arguments.length<3&&(r=\"\"),this.tween(\"style.\"+t,n)},ws.text=function(t){return ks(this,\"text\",t,Ms)},ws.remove=function(){var t=this.namespace;return this.each(\"end.transition\",(function(){var e;this[t].count<2&&(e=this.parentNode)&&e.removeChild(this)}))},ws.ease=function(e){var r=this.id,n=this.namespace;return arguments.length<1?this.node()[n][r].ease:(\"function\"!=typeof e&&(e=t.ease.apply(t,arguments)),ut(this,(function(t){t[n][r].ease=e})))},ws.delay=function(t){var e=this.id,r=this.namespace;return arguments.length<1?this.node()[r][e].delay:ut(this,\"function\"==typeof t?function(n,i,a){n[r][e].delay=+t.call(n,n.__data__,i,a)}:(t=+t,function(n){n[r][e].delay=t}))},ws.duration=function(t){var e=this.id,r=this.namespace;return arguments.length<1?this.node()[r][e].duration:ut(this,\"function\"==typeof t?function(n,i,a){n[r][e].duration=Math.max(1,t.call(n,n.__data__,i,a))}:(t=Math.max(1,t),function(n){n[r][e].duration=t}))},ws.each=function(e,r){var n=this.id,i=this.namespace;if(arguments.length<2){var a=_s,o=bs;try{bs=n,ut(this,(function(t,r,a){_s=t[i][n],e.call(t,t.__data__,r,a)}))}finally{_s=a,bs=o}}else ut(this,(function(a){var o=a[i][n];(o.event||(o.event=t.dispatch(\"start\",\"end\",\"interrupt\"))).on(e,r)}));return this},ws.transition=function(){for(var t,e,r,n=this.id,i=++Ts,a=this.namespace,o=[],s=0,l=this.length;s<l;s++){o.push(t=[]);for(var c,u=0,f=(c=this[s]).length;u<f;u++)(e=c[u])&&Ss(e,u,a,i,{time:(r=e[a][n]).time,ease:r.ease,delay:r.delay+r.duration,duration:r.duration}),t.push(e)}return xs(o,a,i)},t.svg.axis=function(){var e,r=t.scale.linear(),i=Es,a=6,o=6,s=3,l=[10],c=null;function u(n){n.each((function(){var n,u=t.select(this),f=this.__chart__||r,h=this.__chart__=r.copy(),p=null==c?h.ticks?h.ticks.apply(h,l):h.domain():c,d=null==e?h.tickFormat?h.tickFormat.apply(h,l):C:e,m=u.selectAll(\".tick\").data(p,h),g=m.enter().insert(\"g\",\".domain\").attr(\"class\",\"tick\").style(\"opacity\",kt),v=t.transition(m.exit()).style(\"opacity\",kt).remove(),y=t.transition(m.order()).style(\"opacity\",1),x=Math.max(a,0)+s,b=go(h),_=u.selectAll(\".domain\").data([0]),w=(_.enter().append(\"path\").attr(\"class\",\"domain\"),t.transition(_));g.append(\"line\"),g.append(\"text\");var T,k,M,A,S=g.select(\"line\"),E=y.select(\"line\"),L=m.select(\"text\").text(d),P=g.select(\"text\"),I=y.select(\"text\"),O=\"top\"===i||\"left\"===i?-1:1;if(\"bottom\"===i||\"top\"===i?(n=Cs,T=\"x\",M=\"y\",k=\"x2\",A=\"y2\",L.attr(\"dy\",O<0?\"0em\":\".71em\").style(\"text-anchor\",\"middle\"),w.attr(\"d\",\"M\"+b[0]+\",\"+O*o+\"V0H\"+b[1]+\"V\"+O*o)):(n=Ps,T=\"y\",M=\"x\",k=\"y2\",A=\"x2\",L.attr(\"dy\",\".32em\").style(\"text-anchor\",O<0?\"end\":\"start\"),w.attr(\"d\",\"M\"+O*o+\",\"+b[0]+\"H0V\"+b[1]+\"H\"+O*o)),S.attr(A,O*a),P.attr(M,O*x),E.attr(k,0).attr(A,O*a),I.attr(T,0).attr(M,O*x),h.rangeBand){var z=h,D=z.rangeBand()/2;f=h=function(t){return z(t)+D}}else f.rangeBand?f=h:v.call(n,h,f);g.call(n,f,h),y.call(n,h,h)}))}return u.scale=function(t){return arguments.length?(r=t,u):r},u.orient=function(t){return arguments.length?(i=t in Ls?t+\"\":Es,u):i},u.ticks=function(){return arguments.length?(l=n(arguments),u):l},u.tickValues=function(t){return arguments.length?(c=t,u):c},u.tickFormat=function(t){return arguments.length?(e=t,u):e},u.tickSize=function(t){var e=arguments.length;return e?(a=+t,o=+arguments[e-1],u):a},u.innerTickSize=function(t){return arguments.length?(a=+t,u):a},u.outerTickSize=function(t){return arguments.length?(o=+t,u):o},u.tickPadding=function(t){return arguments.length?(s=+t,u):s},u.tickSubdivide=function(){return arguments.length&&u},u};var Es=\"bottom\",Ls={top:1,right:1,bottom:1,left:1};function Cs(t,e,r){t.attr(\"transform\",(function(t){var n=e(t);return\"translate(\"+(isFinite(n)?n:r(t))+\",0)\"}))}function Ps(t,e,r){t.attr(\"transform\",(function(t){var n=e(t);return\"translate(0,\"+(isFinite(n)?n:r(t))+\")\"}))}t.svg.brush=function(){var e,r,n=N(h,\"brushstart\",\"brush\",\"brushend\"),i=null,a=null,s=[0,0],l=[0,0],c=!0,u=!0,f=Os[0];function h(e){e.each((function(){var e=t.select(this).style(\"pointer-events\",\"all\").style(\"-webkit-tap-highlight-color\",\"rgba(0,0,0,0)\").on(\"mousedown.brush\",g).on(\"touchstart.brush\",g),r=e.selectAll(\".background\").data([0]);r.enter().append(\"rect\").attr(\"class\",\"background\").style(\"visibility\",\"hidden\").style(\"cursor\",\"crosshair\"),e.selectAll(\".extent\").data([0]).enter().append(\"rect\").attr(\"class\",\"extent\").style(\"cursor\",\"move\");var n=e.selectAll(\".resize\").data(f,C);n.exit().remove(),n.enter().append(\"g\").attr(\"class\",(function(t){return\"resize \"+t})).style(\"cursor\",(function(t){return Is[t]})).append(\"rect\").attr(\"x\",(function(t){return/[ew]$/.test(t)?-3:null})).attr(\"y\",(function(t){return/^[ns]/.test(t)?-3:null})).attr(\"width\",6).attr(\"height\",6).style(\"visibility\",\"hidden\"),n.style(\"display\",h.empty()?\"none\":null);var o,s=t.transition(e),l=t.transition(r);i&&(o=go(i),l.attr(\"x\",o[0]).attr(\"width\",o[1]-o[0]),d(s)),a&&(o=go(a),l.attr(\"y\",o[0]).attr(\"height\",o[1]-o[0]),m(s)),p(s)}))}function p(t){t.selectAll(\".resize\").attr(\"transform\",(function(t){return\"translate(\"+s[+/e$/.test(t)]+\",\"+l[+/^s/.test(t)]+\")\"}))}function d(t){t.select(\".extent\").attr(\"x\",s[0]),t.selectAll(\".extent,.n>rect,.s>rect\").attr(\"width\",s[1]-s[0])}function m(t){t.select(\".extent\").attr(\"y\",l[0]),t.selectAll(\".extent,.e>rect,.w>rect\").attr(\"height\",l[1]-l[0])}function g(){var f,g,v=this,y=t.select(t.event.target),x=n.of(v,arguments),b=t.select(v),_=y.datum(),w=!/^(n|s)$/.test(_)&&i,T=!/^(e|w)$/.test(_)&&a,k=y.classed(\"extent\"),M=bt(v),A=t.mouse(v),S=t.select(o(v)).on(\"keydown.brush\",C).on(\"keyup.brush\",P);if(t.event.changedTouches?S.on(\"touchmove.brush\",I).on(\"touchend.brush\",z):S.on(\"mousemove.brush\",I).on(\"mouseup.brush\",z),b.interrupt().selectAll(\"*\").interrupt(),k)A[0]=s[0]-A[0],A[1]=l[0]-A[1];else if(_){var E=+/w$/.test(_),L=+/^n/.test(_);g=[s[1-E]-A[0],l[1-L]-A[1]],A[0]=s[E],A[1]=l[L]}else t.event.altKey&&(f=A.slice());function C(){32==t.event.keyCode&&(k||(f=null,A[0]-=s[1],A[1]-=l[1],k=2),F())}function P(){32==t.event.keyCode&&2==k&&(A[0]+=s[1],A[1]+=l[1],k=0,F())}function I(){var e=t.mouse(v),r=!1;g&&(e[0]+=g[0],e[1]+=g[1]),k||(t.event.altKey?(f||(f=[(s[0]+s[1])/2,(l[0]+l[1])/2]),A[0]=s[+(e[0]<f[0])],A[1]=l[+(e[1]<f[1])]):f=null),w&&O(e,i,0)&&(d(b),r=!0),T&&O(e,a,1)&&(m(b),r=!0),r&&(p(b),x({type:\"brush\",mode:k?\"move\":\"resize\"}))}function O(t,n,i){var a,o,h=go(n),p=h[0],d=h[1],m=A[i],g=i?l:s,v=g[1]-g[0];if(k&&(p-=m,d-=v+m),a=(i?u:c)?Math.max(p,Math.min(d,t[i])):t[i],k?o=(a+=m)+v:(f&&(m=Math.max(p,Math.min(d,2*f[i]-a))),m<a?(o=a,a=m):o=m),g[0]!=a||g[1]!=o)return i?r=null:e=null,g[0]=a,g[1]=o,!0}function z(){I(),b.style(\"pointer-events\",\"all\").selectAll(\".resize\").style(\"display\",h.empty()?\"none\":null),t.select(\"body\").style(\"cursor\",null),S.on(\"mousemove.brush\",null).on(\"mouseup.brush\",null).on(\"touchmove.brush\",null).on(\"touchend.brush\",null).on(\"keydown.brush\",null).on(\"keyup.brush\",null),M(),x({type:\"brushend\"})}b.style(\"pointer-events\",\"none\").selectAll(\".resize\").style(\"display\",null),t.select(\"body\").style(\"cursor\",y.style(\"cursor\")),x({type:\"brushstart\"}),I()}return h.event=function(i){i.each((function(){var i=n.of(this,arguments),a={x:s,y:l,i:e,j:r},o=this.__chart__||a;this.__chart__=a,bs?t.select(this).transition().each(\"start.brush\",(function(){e=o.i,r=o.j,s=o.x,l=o.y,i({type:\"brushstart\"})})).tween(\"brush:brush\",(function(){var t=ta(s,a.x),n=ta(l,a.y);return e=r=null,function(e){s=a.x=t(e),l=a.y=n(e),i({type:\"brush\",mode:\"resize\"})}})).each(\"end.brush\",(function(){e=a.i,r=a.j,i({type:\"brush\",mode:\"resize\"}),i({type:\"brushend\"})})):(i({type:\"brushstart\"}),i({type:\"brush\",mode:\"resize\"}),i({type:\"brushend\"}))}))},h.x=function(t){return arguments.length?(f=Os[!(i=t)<<1|!a],h):i},h.y=function(t){return arguments.length?(f=Os[!i<<1|!(a=t)],h):a},h.clamp=function(t){return arguments.length?(i&&a?(c=!!t[0],u=!!t[1]):i?c=!!t:a&&(u=!!t),h):i&&a?[c,u]:i?c:a?u:null},h.extent=function(t){var n,o,c,u,f;return arguments.length?(i&&(n=t[0],o=t[1],a&&(n=n[0],o=o[0]),e=[n,o],i.invert&&(n=i(n),o=i(o)),o<n&&(f=n,n=o,o=f),n==s[0]&&o==s[1]||(s=[n,o])),a&&(c=t[0],u=t[1],i&&(c=c[1],u=u[1]),r=[c,u],a.invert&&(c=a(c),u=a(u)),u<c&&(f=c,c=u,u=f),c==l[0]&&u==l[1]||(l=[c,u])),h):(i&&(e?(n=e[0],o=e[1]):(n=s[0],o=s[1],i.invert&&(n=i.invert(n),o=i.invert(o)),o<n&&(f=n,n=o,o=f))),a&&(r?(c=r[0],u=r[1]):(c=l[0],u=l[1],a.invert&&(c=a.invert(c),u=a.invert(u)),u<c&&(f=c,c=u,u=f))),i&&a?[[n,c],[o,u]]:i?[n,o]:a&&[c,u])},h.clear=function(){return h.empty()||(s=[0,0],l=[0,0],e=r=null),h},h.empty=function(){return!!i&&s[0]==s[1]||!!a&&l[0]==l[1]},t.rebind(h,n,\"on\")};var Is={n:\"ns-resize\",e:\"ew-resize\",s:\"ns-resize\",w:\"ew-resize\",nw:\"nwse-resize\",ne:\"nesw-resize\",se:\"nwse-resize\",sw:\"nesw-resize\"},Os=[[\"n\",\"e\",\"s\",\"w\",\"nw\",\"ne\",\"se\",\"sw\"],[\"e\",\"w\"],[\"n\",\"s\"],[]],zs=Ie.format=sr.timeFormat,Ds=zs.utc,Rs=Ds(\"%Y-%m-%dT%H:%M:%S.%LZ\");function Fs(t){return t.toISOString()}function Bs(e,r,n){function i(t){return e(t)}function a(e,n){var i=(e[1]-e[0])/n,a=t.bisect(js,i);return a==js.length?[r.year,ko(e.map((function(t){return t/31536e6})),n)[2]]:a?r[i/js[a-1]<js[a]/i?a-1:a]:[qs,ko(e,n)[2]]}return i.invert=function(t){return Ns(e.invert(t))},i.domain=function(t){return arguments.length?(e.domain(t),i):e.domain().map(Ns)},i.nice=function(t,e){var r=i.domain(),n=mo(r),o=null==t?a(n,10):\"number\"==typeof t&&a(n,t);function s(r){return!isNaN(r)&&!t.range(r,Ns(+r+1),e).length}return o&&(t=o[0],e=o[1]),i.domain(yo(r,e>1?{floor:function(e){for(;s(e=t.floor(e));)e=Ns(e-1);return e},ceil:function(e){for(;s(e=t.ceil(e));)e=Ns(+e+1);return e}}:t))},i.ticks=function(t,e){var r=mo(i.domain()),n=null==t?a(r,10):\"number\"==typeof t?a(r,t):!t.range&&[{range:t},e];return n&&(t=n[0],e=n[1]),t.range(r[0],Ns(+r[1]+1),e<1?1:e)},i.tickFormat=function(){return n},i.copy=function(){return Bs(e.copy(),r,n)},wo(i,e)}function Ns(t){return new Date(t)}zs.iso=Date.prototype.toISOString&&+new Date(\"2000-01-01T00:00:00.000Z\")?Fs:Rs,Fs.parse=function(t){var e=new Date(t);return isNaN(e)?null:e},Fs.toString=Rs.toString,Ie.second=Re((function(t){return new Oe(1e3*Math.floor(t/1e3))}),(function(t,e){t.setTime(t.getTime()+1e3*Math.floor(e))}),(function(t){return t.getSeconds()})),Ie.seconds=Ie.second.range,Ie.seconds.utc=Ie.second.utc.range,Ie.minute=Re((function(t){return new Oe(6e4*Math.floor(t/6e4))}),(function(t,e){t.setTime(t.getTime()+6e4*Math.floor(e))}),(function(t){return t.getMinutes()})),Ie.minutes=Ie.minute.range,Ie.minutes.utc=Ie.minute.utc.range,Ie.hour=Re((function(t){var e=t.getTimezoneOffset()/60;return new Oe(36e5*(Math.floor(t/36e5-e)+e))}),(function(t,e){t.setTime(t.getTime()+36e5*Math.floor(e))}),(function(t){return t.getHours()})),Ie.hours=Ie.hour.range,Ie.hours.utc=Ie.hour.utc.range,Ie.month=Re((function(t){return(t=Ie.day(t)).setDate(1),t}),(function(t,e){t.setMonth(t.getMonth()+e)}),(function(t){return t.getMonth()})),Ie.months=Ie.month.range,Ie.months.utc=Ie.month.utc.range;var js=[1e3,5e3,15e3,3e4,6e4,3e5,9e5,18e5,36e5,108e5,216e5,432e5,864e5,1728e5,6048e5,2592e6,7776e6,31536e6],Us=[[Ie.second,1],[Ie.second,5],[Ie.second,15],[Ie.second,30],[Ie.minute,1],[Ie.minute,5],[Ie.minute,15],[Ie.minute,30],[Ie.hour,1],[Ie.hour,3],[Ie.hour,6],[Ie.hour,12],[Ie.day,1],[Ie.day,2],[Ie.week,1],[Ie.month,1],[Ie.month,3],[Ie.year,1]],Vs=zs.multi([[\".%L\",function(t){return t.getMilliseconds()}],[\":%S\",function(t){return t.getSeconds()}],[\"%I:%M\",function(t){return t.getMinutes()}],[\"%I %p\",function(t){return t.getHours()}],[\"%a %d\",function(t){return t.getDay()&&1!=t.getDate()}],[\"%b %d\",function(t){return 1!=t.getDate()}],[\"%B\",function(t){return t.getMonth()}],[\"%Y\",Yr]]),qs={range:function(e,r,n){return t.range(Math.ceil(e/n)*n,+r,n).map(Ns)},floor:C,ceil:C};Us.year=Ie.year,Ie.scale=function(){return Bs(t.scale.linear(),Us,Vs)};var Hs=Us.map((function(t){return[t[0].utc,t[1]]})),Gs=Ds.multi([[\".%L\",function(t){return t.getUTCMilliseconds()}],[\":%S\",function(t){return t.getUTCSeconds()}],[\"%I:%M\",function(t){return t.getUTCMinutes()}],[\"%I %p\",function(t){return t.getUTCHours()}],[\"%a %d\",function(t){return t.getUTCDay()&&1!=t.getUTCDate()}],[\"%b %d\",function(t){return 1!=t.getUTCDate()}],[\"%B\",function(t){return t.getUTCMonth()}],[\"%Y\",Yr]]);function Ys(t){return JSON.parse(t.responseText)}function Ws(t){var e=i.createRange();return e.selectNode(i.body),e.createContextualFragment(t.responseText)}Hs.year=Ie.year.utc,Ie.scale.utc=function(){return Bs(t.scale.linear(),Hs,Gs)},t.text=me((function(t){return t.responseText})),t.json=function(t,e){return ge(t,\"application/json\",Ys,e)},t.html=function(t,e){return ge(t,\"text/html\",Ws,e)},t.xml=me((function(t){return t.responseXML})),\"object\"==typeof e&&e.exports?e.exports=t:this.d3=t}).apply(self)},{}],59:[function(t,e,r){\"use strict\";e.exports=t(\"./quad\")},{\"./quad\":60}],60:[function(t,e,r){\"use strict\";var n=t(\"binary-search-bounds\"),i=t(\"clamp\"),a=t(\"parse-rect\"),o=t(\"array-bounds\"),s=t(\"pick-by-alias\"),l=t(\"defined\"),c=t(\"flatten-vertex-data\"),u=t(\"is-obj\"),f=t(\"dtype\"),h=t(\"math-log2\");function p(t,e){for(var r=e[0],n=e[1],a=1/(e[2]-r),o=1/(e[3]-n),s=new Array(t.length),l=0,c=t.length/2;l<c;l++)s[2*l]=i((t[2*l]-r)*a,0,1),s[2*l+1]=i((t[2*l+1]-n)*o,0,1);return s}e.exports=function(t,e){e||(e={}),t=c(t,\"float64\"),e=s(e,{bounds:\"range bounds dataBox databox\",maxDepth:\"depth maxDepth maxdepth level maxLevel maxlevel levels\",dtype:\"type dtype format out dst output destination\"});var r=l(e.maxDepth,255),i=l(e.bounds,o(t,2));i[0]===i[2]&&i[2]++,i[1]===i[3]&&i[3]++;var d,m=p(t,i),g=t.length>>>1;e.dtype||(e.dtype=\"array\"),\"string\"==typeof e.dtype?d=new(f(e.dtype))(g):e.dtype&&(d=e.dtype,Array.isArray(d)&&(d.length=g));for(var v=0;v<g;++v)d[v]=v;var y=[],x=[],b=[],_=[];!function t(e,n,i,a,o,s){if(!a.length)return null;var l=y[o]||(y[o]=[]),c=b[o]||(b[o]=[]),u=x[o]||(x[o]=[]),f=l.length;if(++o>r||s>1073741824){for(var h=0;h<a.length;h++)l.push(a[h]),c.push(s),u.push(null,null,null,null);return f}if(l.push(a[0]),c.push(s),a.length<=1)return u.push(null,null,null,null),f;for(var p=.5*i,d=e+p,g=n+p,v=[],_=[],w=[],T=[],k=1,M=a.length;k<M;k++){var A=a[k],S=m[2*A],E=m[2*A+1];S<d?E<g?v.push(A):_.push(A):E<g?w.push(A):T.push(A)}return s<<=2,u.push(t(e,n,p,v,o,s),t(e,g,p,_,o,s+1),t(d,n,p,w,o,s+2),t(d,g,p,T,o,s+3)),f}(0,0,1,d,0,1);for(var w=0,T=0;T<y.length;T++){var k=y[T];if(d.set)d.set(k,w);else for(var M=0,A=k.length;M<A;M++)d[M+w]=k[M];var S=w+y[T].length;_[T]=[w,S],w=S}return d.range=function(){var e,r=[],n=arguments.length;for(;n--;)r[n]=arguments[n];if(u(r[r.length-1])){var o=r.pop();r.length||null==o.x&&null==o.l&&null==o.left||(r=[o],e={}),e=s(o,{level:\"level maxLevel\",d:\"d diam diameter r radius px pxSize pixel pixelSize maxD size minSize\",lod:\"lod details ranges offsets\"})}else e={};r.length||(r=i);var c=a.apply(void 0,r),f=[Math.min(c.x,c.x+c.width),Math.min(c.y,c.y+c.height),Math.max(c.x,c.x+c.width),Math.max(c.y,c.y+c.height)],d=f[0],m=f[1],g=f[2],v=f[3],b=p([d,m,g,v],i),_=b[0],w=b[1],T=b[2],k=b[3],M=l(e.level,y.length);if(null!=e.d){var A;\"number\"==typeof e.d?A=[e.d,e.d]:e.d.length&&(A=e.d),M=Math.min(Math.max(Math.ceil(-h(Math.abs(A[0])/(i[2]-i[0]))),Math.ceil(-h(Math.abs(A[1])/(i[3]-i[1])))),M)}if(M=Math.min(M,y.length),e.lod)return E(_,w,T,k,M);var S=[];function L(e,r,n,i,a,o){if(null!==a&&null!==o&&!(_>e+n||w>r+n||T<e||k<r||i>=M||a===o)){var s=y[i];void 0===o&&(o=s.length);for(var l=a;l<o;l++){var c=s[l],u=t[2*c],f=t[2*c+1];u>=d&&u<=g&&f>=m&&f<=v&&S.push(c)}var h=x[i],p=h[4*a+0],b=h[4*a+1],A=h[4*a+2],E=h[4*a+3],P=C(h,a+1),I=.5*n,O=i+1;L(e,r,I,O,p,b||A||E||P),L(e,r+I,I,O,b,A||E||P),L(e+I,r,I,O,A,E||P),L(e+I,r+I,I,O,E,P)}}function C(t,e){for(var r=null,n=0;null===r;)if(r=t[4*e+n],++n>t.length)return null;return r}return L(0,0,1,0,0,1),S},d;function E(t,e,r,i,a){for(var o=[],s=0;s<a;s++){var l=b[s],c=_[s][0],u=L(t,e,s),f=L(r,i,s),h=n.ge(l,u),p=n.gt(l,f,h,l.length-1);o[s]=[h+c,p+c]}return o}function L(t,e,r){for(var n=1,i=.5,a=.5,o=.5,s=0;s<r;s++)n<<=2,n+=t<i?e<a?0:1:e<a?2:3,o*=.5,i+=t<i?-o:o,a+=e<a?-o:o;return n}}},{\"array-bounds\":76,\"binary-search-bounds\":103,clamp:126,defined:175,dtype:180,\"flatten-vertex-data\":248,\"is-obj\":452,\"math-log2\":463,\"parse-rect\":488,\"pick-by-alias\":494}],61:[function(t,e,r){\"use strict\";Object.defineProperty(r,\"__esModule\",{value:!0});var n=t(\"@turf/meta\");function i(t){var e=0;if(t&&t.length>0){e+=Math.abs(a(t[0]));for(var r=1;r<t.length;r++)e-=Math.abs(a(t[r]))}return e}function a(t){var e,r,n,i,a,s,l=0,c=t.length;if(c>2){for(s=0;s<c;s++)s===c-2?(n=c-2,i=c-1,a=0):s===c-1?(n=c-1,i=0,a=1):(n=s,i=s+1,a=s+2),e=t[n],r=t[i],l+=(o(t[a][0])-o(e[0]))*Math.sin(o(r[1]));l=6378137*l*6378137/2}return l}function o(t){return t*Math.PI/180}r.default=function(t){return n.geomReduce(t,(function(t,e){return t+function(t){var e,r=0;switch(t.type){case\"Polygon\":return i(t.coordinates);case\"MultiPolygon\":for(e=0;e<t.coordinates.length;e++)r+=i(t.coordinates[e]);return r;case\"Point\":case\"MultiPoint\":case\"LineString\":case\"MultiLineString\":return 0}return 0}(e)}),0)}},{\"@turf/meta\":63}],62:[function(t,e,r){\"use strict\";function n(t,e,r){void 0===r&&(r={});var n={type:\"Feature\"};return(0===r.id||r.id)&&(n.id=r.id),r.bbox&&(n.bbox=r.bbox),n.properties=e||{},n.geometry=t,n}function i(t,e,r){if(void 0===r&&(r={}),!t)throw new Error(\"coordinates is required\");if(!Array.isArray(t))throw new Error(\"coordinates must be an Array\");if(t.length<2)throw new Error(\"coordinates must be at least 2 numbers long\");if(!d(t[0])||!d(t[1]))throw new Error(\"coordinates must contain numbers\");return n({type:\"Point\",coordinates:t},e,r)}function a(t,e,r){void 0===r&&(r={});for(var i=0,a=t;i<a.length;i++){var o=a[i];if(o.length<4)throw new Error(\"Each LinearRing of a Polygon must have 4 or more Positions.\");for(var s=0;s<o[o.length-1].length;s++)if(o[o.length-1][s]!==o[0][s])throw new Error(\"First and last Position are not equivalent.\")}return n({type:\"Polygon\",coordinates:t},e,r)}function o(t,e,r){if(void 0===r&&(r={}),t.length<2)throw new Error(\"coordinates must be an array of two or more positions\");return n({type:\"LineString\",coordinates:t},e,r)}function s(t,e){void 0===e&&(e={});var r={type:\"FeatureCollection\"};return e.id&&(r.id=e.id),e.bbox&&(r.bbox=e.bbox),r.features=t,r}function l(t,e,r){return void 0===r&&(r={}),n({type:\"MultiLineString\",coordinates:t},e,r)}function c(t,e,r){return void 0===r&&(r={}),n({type:\"MultiPoint\",coordinates:t},e,r)}function u(t,e,r){return void 0===r&&(r={}),n({type:\"MultiPolygon\",coordinates:t},e,r)}function f(t,e){void 0===e&&(e=\"kilometers\");var n=r.factors[e];if(!n)throw new Error(e+\" units is invalid\");return t*n}function h(t,e){void 0===e&&(e=\"kilometers\");var n=r.factors[e];if(!n)throw new Error(e+\" units is invalid\");return t/n}function p(t){return 180*(t%(2*Math.PI))/Math.PI}function d(t){return!isNaN(t)&&null!==t&&!Array.isArray(t)}Object.defineProperty(r,\"__esModule\",{value:!0}),r.earthRadius=6371008.8,r.factors={centimeters:100*r.earthRadius,centimetres:100*r.earthRadius,degrees:r.earthRadius/111325,feet:3.28084*r.earthRadius,inches:39.37*r.earthRadius,kilometers:r.earthRadius/1e3,kilometres:r.earthRadius/1e3,meters:r.earthRadius,metres:r.earthRadius,miles:r.earthRadius/1609.344,millimeters:1e3*r.earthRadius,millimetres:1e3*r.earthRadius,nauticalmiles:r.earthRadius/1852,radians:1,yards:1.0936*r.earthRadius},r.unitsFactors={centimeters:100,centimetres:100,degrees:1/111325,feet:3.28084,inches:39.37,kilometers:.001,kilometres:.001,meters:1,metres:1,miles:1/1609.344,millimeters:1e3,millimetres:1e3,nauticalmiles:1/1852,radians:1/r.earthRadius,yards:1.0936133},r.areaFactors={acres:247105e-9,centimeters:1e4,centimetres:1e4,feet:10.763910417,hectares:1e-4,inches:1550.003100006,kilometers:1e-6,kilometres:1e-6,meters:1,metres:1,miles:386e-9,millimeters:1e6,millimetres:1e6,yards:1.195990046},r.feature=n,r.geometry=function(t,e,r){switch(void 0===r&&(r={}),t){case\"Point\":return i(e).geometry;case\"LineString\":return o(e).geometry;case\"Polygon\":return a(e).geometry;case\"MultiPoint\":return c(e).geometry;case\"MultiLineString\":return l(e).geometry;case\"MultiPolygon\":return u(e).geometry;default:throw new Error(t+\" is invalid\")}},r.point=i,r.points=function(t,e,r){return void 0===r&&(r={}),s(t.map((function(t){return i(t,e)})),r)},r.polygon=a,r.polygons=function(t,e,r){return void 0===r&&(r={}),s(t.map((function(t){return a(t,e)})),r)},r.lineString=o,r.lineStrings=function(t,e,r){return void 0===r&&(r={}),s(t.map((function(t){return o(t,e)})),r)},r.featureCollection=s,r.multiLineString=l,r.multiPoint=c,r.multiPolygon=u,r.geometryCollection=function(t,e,r){return void 0===r&&(r={}),n({type:\"GeometryCollection\",geometries:t},e,r)},r.round=function(t,e){if(void 0===e&&(e=0),e&&!(e>=0))throw new Error(\"precision must be a positive number\");var r=Math.pow(10,e||0);return Math.round(t*r)/r},r.radiansToLength=f,r.lengthToRadians=h,r.lengthToDegrees=function(t,e){return p(h(t,e))},r.bearingToAzimuth=function(t){var e=t%360;return e<0&&(e+=360),e},r.radiansToDegrees=p,r.degreesToRadians=function(t){return t%360*Math.PI/180},r.convertLength=function(t,e,r){if(void 0===e&&(e=\"kilometers\"),void 0===r&&(r=\"kilometers\"),!(t>=0))throw new Error(\"length must be a positive number\");return f(h(t,e),r)},r.convertArea=function(t,e,n){if(void 0===e&&(e=\"meters\"),void 0===n&&(n=\"kilometers\"),!(t>=0))throw new Error(\"area must be a positive number\");var i=r.areaFactors[e];if(!i)throw new Error(\"invalid original units\");var a=r.areaFactors[n];if(!a)throw new Error(\"invalid final units\");return t/i*a},r.isNumber=d,r.isObject=function(t){return!!t&&t.constructor===Object},r.validateBBox=function(t){if(!t)throw new Error(\"bbox is required\");if(!Array.isArray(t))throw new Error(\"bbox must be an Array\");if(4!==t.length&&6!==t.length)throw new Error(\"bbox must be an Array of 4 or 6 numbers\");t.forEach((function(t){if(!d(t))throw new Error(\"bbox must only contain numbers\")}))},r.validateId=function(t){if(!t)throw new Error(\"id is required\");if(-1===[\"string\",\"number\"].indexOf(typeof t))throw new Error(\"id must be a number or a string\")}},{}],63:[function(t,e,r){\"use strict\";Object.defineProperty(r,\"__esModule\",{value:!0});var n=t(\"@turf/helpers\");function i(t,e,r){if(null!==t)for(var n,a,o,s,l,c,u,f,h=0,p=0,d=t.type,m=\"FeatureCollection\"===d,g=\"Feature\"===d,v=m?t.features.length:1,y=0;y<v;y++){l=(f=!!(u=m?t.features[y].geometry:g?t.geometry:t)&&\"GeometryCollection\"===u.type)?u.geometries.length:1;for(var x=0;x<l;x++){var b=0,_=0;if(null!==(s=f?u.geometries[x]:u)){c=s.coordinates;var w=s.type;switch(h=!r||\"Polygon\"!==w&&\"MultiPolygon\"!==w?0:1,w){case null:break;case\"Point\":if(!1===e(c,p,y,b,_))return!1;p++,b++;break;case\"LineString\":case\"MultiPoint\":for(n=0;n<c.length;n++){if(!1===e(c[n],p,y,b,_))return!1;p++,\"MultiPoint\"===w&&b++}\"LineString\"===w&&b++;break;case\"Polygon\":case\"MultiLineString\":for(n=0;n<c.length;n++){for(a=0;a<c[n].length-h;a++){if(!1===e(c[n][a],p,y,b,_))return!1;p++}\"MultiLineString\"===w&&b++,\"Polygon\"===w&&_++}\"Polygon\"===w&&b++;break;case\"MultiPolygon\":for(n=0;n<c.length;n++){for(_=0,a=0;a<c[n].length;a++){for(o=0;o<c[n][a].length-h;o++){if(!1===e(c[n][a][o],p,y,b,_))return!1;p++}_++}b++}break;case\"GeometryCollection\":for(n=0;n<s.geometries.length;n++)if(!1===i(s.geometries[n],e,r))return!1;break;default:throw new Error(\"Unknown Geometry Type\")}}}}}function a(t,e){var r;switch(t.type){case\"FeatureCollection\":for(r=0;r<t.features.length&&!1!==e(t.features[r].properties,r);r++);break;case\"Feature\":e(t.properties,0)}}function o(t,e){if(\"Feature\"===t.type)e(t,0);else if(\"FeatureCollection\"===t.type)for(var r=0;r<t.features.length&&!1!==e(t.features[r],r);r++);}function s(t,e){var r,n,i,a,o,s,l,c,u,f,h=0,p=\"FeatureCollection\"===t.type,d=\"Feature\"===t.type,m=p?t.features.length:1;for(r=0;r<m;r++){for(s=p?t.features[r].geometry:d?t.geometry:t,c=p?t.features[r].properties:d?t.properties:{},u=p?t.features[r].bbox:d?t.bbox:void 0,f=p?t.features[r].id:d?t.id:void 0,o=(l=!!s&&\"GeometryCollection\"===s.type)?s.geometries.length:1,i=0;i<o;i++)if(null!==(a=l?s.geometries[i]:s))switch(a.type){case\"Point\":case\"LineString\":case\"MultiPoint\":case\"Polygon\":case\"MultiLineString\":case\"MultiPolygon\":if(!1===e(a,h,c,u,f))return!1;break;case\"GeometryCollection\":for(n=0;n<a.geometries.length;n++)if(!1===e(a.geometries[n],h,c,u,f))return!1;break;default:throw new Error(\"Unknown Geometry Type\")}else if(!1===e(null,h,c,u,f))return!1;h++}}function l(t,e){s(t,(function(t,r,i,a,o){var s,l=null===t?null:t.type;switch(l){case null:case\"Point\":case\"LineString\":case\"Polygon\":return!1!==e(n.feature(t,i,{bbox:a,id:o}),r,0)&&void 0}switch(l){case\"MultiPoint\":s=\"Point\";break;case\"MultiLineString\":s=\"LineString\";break;case\"MultiPolygon\":s=\"Polygon\"}for(var c=0;c<t.coordinates.length;c++){var u={type:s,coordinates:t.coordinates[c]};if(!1===e(n.feature(u,i),r,c))return!1}}))}function c(t,e){l(t,(function(t,r,a){var o=0;if(t.geometry){var s=t.geometry.type;if(\"Point\"!==s&&\"MultiPoint\"!==s){var l,c=0,u=0,f=0;return!1!==i(t,(function(i,s,h,p,d){if(void 0===l||r>c||p>u||d>f)return l=i,c=r,u=p,f=d,void(o=0);var m=n.lineString([l,i],t.properties);if(!1===e(m,r,a,d,o))return!1;o++,l=i}))&&void 0}}}))}function u(t,e){if(!t)throw new Error(\"geojson is required\");l(t,(function(t,r,i){if(null!==t.geometry){var a=t.geometry.type,o=t.geometry.coordinates;switch(a){case\"LineString\":if(!1===e(t,r,i,0,0))return!1;break;case\"Polygon\":for(var s=0;s<o.length;s++)if(!1===e(n.lineString(o[s],t.properties),r,i,s))return!1}}}))}r.coordEach=i,r.coordReduce=function(t,e,r,n){var a=r;return i(t,(function(t,n,i,o,s){a=0===n&&void 0===r?t:e(a,t,n,i,o,s)}),n),a},r.propEach=a,r.propReduce=function(t,e,r){var n=r;return a(t,(function(t,i){n=0===i&&void 0===r?t:e(n,t,i)})),n},r.featureEach=o,r.featureReduce=function(t,e,r){var n=r;return o(t,(function(t,i){n=0===i&&void 0===r?t:e(n,t,i)})),n},r.coordAll=function(t){var e=[];return i(t,(function(t){e.push(t)})),e},r.geomEach=s,r.geomReduce=function(t,e,r){var n=r;return s(t,(function(t,i,a,o,s){n=0===i&&void 0===r?t:e(n,t,i,a,o,s)})),n},r.flattenEach=l,r.flattenReduce=function(t,e,r){var n=r;return l(t,(function(t,i,a){n=0===i&&0===a&&void 0===r?t:e(n,t,i,a)})),n},r.segmentEach=c,r.segmentReduce=function(t,e,r){var n=r,i=!1;return c(t,(function(t,a,o,s,l){n=!1===i&&void 0===r?t:e(n,t,a,o,s,l),i=!0})),n},r.lineEach=u,r.lineReduce=function(t,e,r){var n=r;return u(t,(function(t,i,a,o){n=0===i&&void 0===r?t:e(n,t,i,a,o)})),n},r.findSegment=function(t,e){if(e=e||{},!n.isObject(e))throw new Error(\"options is invalid\");var r,i=e.featureIndex||0,a=e.multiFeatureIndex||0,o=e.geometryIndex||0,s=e.segmentIndex||0,l=e.properties;switch(t.type){case\"FeatureCollection\":i<0&&(i=t.features.length+i),l=l||t.features[i].properties,r=t.features[i].geometry;break;case\"Feature\":l=l||t.properties,r=t.geometry;break;case\"Point\":case\"MultiPoint\":return null;case\"LineString\":case\"Polygon\":case\"MultiLineString\":case\"MultiPolygon\":r=t;break;default:throw new Error(\"geojson is invalid\")}if(null===r)return null;var c=r.coordinates;switch(r.type){case\"Point\":case\"MultiPoint\":return null;case\"LineString\":return s<0&&(s=c.length+s-1),n.lineString([c[s],c[s+1]],l,e);case\"Polygon\":return o<0&&(o=c.length+o),s<0&&(s=c[o].length+s-1),n.lineString([c[o][s],c[o][s+1]],l,e);case\"MultiLineString\":return a<0&&(a=c.length+a),s<0&&(s=c[a].length+s-1),n.lineString([c[a][s],c[a][s+1]],l,e);case\"MultiPolygon\":return a<0&&(a=c.length+a),o<0&&(o=c[a].length+o),s<0&&(s=c[a][o].length-s-1),n.lineString([c[a][o][s],c[a][o][s+1]],l,e)}throw new Error(\"geojson is invalid\")},r.findPoint=function(t,e){if(e=e||{},!n.isObject(e))throw new Error(\"options is invalid\");var r,i=e.featureIndex||0,a=e.multiFeatureIndex||0,o=e.geometryIndex||0,s=e.coordIndex||0,l=e.properties;switch(t.type){case\"FeatureCollection\":i<0&&(i=t.features.length+i),l=l||t.features[i].properties,r=t.features[i].geometry;break;case\"Feature\":l=l||t.properties,r=t.geometry;break;case\"Point\":case\"MultiPoint\":return null;case\"LineString\":case\"Polygon\":case\"MultiLineString\":case\"MultiPolygon\":r=t;break;default:throw new Error(\"geojson is invalid\")}if(null===r)return null;var c=r.coordinates;switch(r.type){case\"Point\":return n.point(c,l,e);case\"MultiPoint\":return a<0&&(a=c.length+a),n.point(c[a],l,e);case\"LineString\":return s<0&&(s=c.length+s),n.point(c[s],l,e);case\"Polygon\":return o<0&&(o=c.length+o),s<0&&(s=c[o].length+s),n.point(c[o][s],l,e);case\"MultiLineString\":return a<0&&(a=c.length+a),s<0&&(s=c[a].length+s),n.point(c[a][s],l,e);case\"MultiPolygon\":return a<0&&(a=c.length+a),o<0&&(o=c[a].length+o),s<0&&(s=c[a][o].length-s),n.point(c[a][o][s],l,e)}throw new Error(\"geojson is invalid\")}},{\"@turf/helpers\":62}],64:[function(t,e,r){\"use strict\";Object.defineProperty(r,\"__esModule\",{value:!0});var n=t(\"@turf/meta\");function i(t){var e=[1/0,1/0,-1/0,-1/0];return n.coordEach(t,(function(t){e[0]>t[0]&&(e[0]=t[0]),e[1]>t[1]&&(e[1]=t[1]),e[2]<t[0]&&(e[2]=t[0]),e[3]<t[1]&&(e[3]=t[1])})),e}i.default=i,r.default=i},{\"@turf/meta\":66}],65:[function(t,e,r){arguments[4][62][0].apply(r,arguments)},{dup:62}],66:[function(t,e,r){arguments[4][63][0].apply(r,arguments)},{\"@turf/helpers\":65,dup:63}],67:[function(t,e,r){\"use strict\";Object.defineProperty(r,\"__esModule\",{value:!0});var n=t(\"@turf/meta\"),i=t(\"@turf/helpers\");r.default=function(t,e){void 0===e&&(e={});var r=0,a=0,o=0;return n.coordEach(t,(function(t){r+=t[0],a+=t[1],o++})),i.point([r/o,a/o],e.properties)}},{\"@turf/helpers\":68,\"@turf/meta\":69}],68:[function(t,e,r){\"use strict\";function n(t,e,r){void 0===r&&(r={});var n={type:\"Feature\"};return(0===r.id||r.id)&&(n.id=r.id),r.bbox&&(n.bbox=r.bbox),n.properties=e||{},n.geometry=t,n}function i(t,e,r){return void 0===r&&(r={}),n({type:\"Point\",coordinates:t},e,r)}function a(t,e,r){void 0===r&&(r={});for(var i=0,a=t;i<a.length;i++){var o=a[i];if(o.length<4)throw new Error(\"Each LinearRing of a Polygon must have 4 or more Positions.\");for(var s=0;s<o[o.length-1].length;s++)if(o[o.length-1][s]!==o[0][s])throw new Error(\"First and last Position are not equivalent.\")}return n({type:\"Polygon\",coordinates:t},e,r)}function o(t,e,r){if(void 0===r&&(r={}),t.length<2)throw new Error(\"coordinates must be an array of two or more positions\");return n({type:\"LineString\",coordinates:t},e,r)}function s(t,e){void 0===e&&(e={});var r={type:\"FeatureCollection\"};return e.id&&(r.id=e.id),e.bbox&&(r.bbox=e.bbox),r.features=t,r}function l(t,e,r){return void 0===r&&(r={}),n({type:\"MultiLineString\",coordinates:t},e,r)}function c(t,e,r){return void 0===r&&(r={}),n({type:\"MultiPoint\",coordinates:t},e,r)}function u(t,e,r){return void 0===r&&(r={}),n({type:\"MultiPolygon\",coordinates:t},e,r)}function f(t,e){void 0===e&&(e=\"kilometers\");var n=r.factors[e];if(!n)throw new Error(e+\" units is invalid\");return t*n}function h(t,e){void 0===e&&(e=\"kilometers\");var n=r.factors[e];if(!n)throw new Error(e+\" units is invalid\");return t/n}function p(t){return 180*(t%(2*Math.PI))/Math.PI}function d(t){return!isNaN(t)&&null!==t&&!Array.isArray(t)&&!/^\\s*$/.test(t)}Object.defineProperty(r,\"__esModule\",{value:!0}),r.earthRadius=6371008.8,r.factors={centimeters:100*r.earthRadius,centimetres:100*r.earthRadius,degrees:r.earthRadius/111325,feet:3.28084*r.earthRadius,inches:39.37*r.earthRadius,kilometers:r.earthRadius/1e3,kilometres:r.earthRadius/1e3,meters:r.earthRadius,metres:r.earthRadius,miles:r.earthRadius/1609.344,millimeters:1e3*r.earthRadius,millimetres:1e3*r.earthRadius,nauticalmiles:r.earthRadius/1852,radians:1,yards:r.earthRadius/1.0936},r.unitsFactors={centimeters:100,centimetres:100,degrees:1/111325,feet:3.28084,inches:39.37,kilometers:.001,kilometres:.001,meters:1,metres:1,miles:1/1609.344,millimeters:1e3,millimetres:1e3,nauticalmiles:1/1852,radians:1/r.earthRadius,yards:1/1.0936},r.areaFactors={acres:247105e-9,centimeters:1e4,centimetres:1e4,feet:10.763910417,inches:1550.003100006,kilometers:1e-6,kilometres:1e-6,meters:1,metres:1,miles:386e-9,millimeters:1e6,millimetres:1e6,yards:1.195990046},r.feature=n,r.geometry=function(t,e,r){switch(void 0===r&&(r={}),t){case\"Point\":return i(e).geometry;case\"LineString\":return o(e).geometry;case\"Polygon\":return a(e).geometry;case\"MultiPoint\":return c(e).geometry;case\"MultiLineString\":return l(e).geometry;case\"MultiPolygon\":return u(e).geometry;default:throw new Error(t+\" is invalid\")}},r.point=i,r.points=function(t,e,r){return void 0===r&&(r={}),s(t.map((function(t){return i(t,e)})),r)},r.polygon=a,r.polygons=function(t,e,r){return void 0===r&&(r={}),s(t.map((function(t){return a(t,e)})),r)},r.lineString=o,r.lineStrings=function(t,e,r){return void 0===r&&(r={}),s(t.map((function(t){return o(t,e)})),r)},r.featureCollection=s,r.multiLineString=l,r.multiPoint=c,r.multiPolygon=u,r.geometryCollection=function(t,e,r){return void 0===r&&(r={}),n({type:\"GeometryCollection\",geometries:t},e,r)},r.round=function(t,e){if(void 0===e&&(e=0),e&&!(e>=0))throw new Error(\"precision must be a positive number\");var r=Math.pow(10,e||0);return Math.round(t*r)/r},r.radiansToLength=f,r.lengthToRadians=h,r.lengthToDegrees=function(t,e){return p(h(t,e))},r.bearingToAzimuth=function(t){var e=t%360;return e<0&&(e+=360),e},r.radiansToDegrees=p,r.degreesToRadians=function(t){return t%360*Math.PI/180},r.convertLength=function(t,e,r){if(void 0===e&&(e=\"kilometers\"),void 0===r&&(r=\"kilometers\"),!(t>=0))throw new Error(\"length must be a positive number\");return f(h(t,e),r)},r.convertArea=function(t,e,n){if(void 0===e&&(e=\"meters\"),void 0===n&&(n=\"kilometers\"),!(t>=0))throw new Error(\"area must be a positive number\");var i=r.areaFactors[e];if(!i)throw new Error(\"invalid original units\");var a=r.areaFactors[n];if(!a)throw new Error(\"invalid final units\");return t/i*a},r.isNumber=d,r.isObject=function(t){return!!t&&t.constructor===Object},r.validateBBox=function(t){if(!t)throw new Error(\"bbox is required\");if(!Array.isArray(t))throw new Error(\"bbox must be an Array\");if(4!==t.length&&6!==t.length)throw new Error(\"bbox must be an Array of 4 or 6 numbers\");t.forEach((function(t){if(!d(t))throw new Error(\"bbox must only contain numbers\")}))},r.validateId=function(t){if(!t)throw new Error(\"id is required\");if(-1===[\"string\",\"number\"].indexOf(typeof t))throw new Error(\"id must be a number or a string\")},r.radians2degrees=function(){throw new Error(\"method has been renamed to `radiansToDegrees`\")},r.degrees2radians=function(){throw new Error(\"method has been renamed to `degreesToRadians`\")},r.distanceToDegrees=function(){throw new Error(\"method has been renamed to `lengthToDegrees`\")},r.distanceToRadians=function(){throw new Error(\"method has been renamed to `lengthToRadians`\")},r.radiansToDistance=function(){throw new Error(\"method has been renamed to `radiansToLength`\")},r.bearingToAngle=function(){throw new Error(\"method has been renamed to `bearingToAzimuth`\")},r.convertDistance=function(){throw new Error(\"method has been renamed to `convertLength`\")}},{}],69:[function(t,e,r){\"use strict\";Object.defineProperty(r,\"__esModule\",{value:!0});var n=t(\"@turf/helpers\");function i(t,e,r){if(null!==t)for(var n,a,o,s,l,c,u,f,h=0,p=0,d=t.type,m=\"FeatureCollection\"===d,g=\"Feature\"===d,v=m?t.features.length:1,y=0;y<v;y++){l=(f=!!(u=m?t.features[y].geometry:g?t.geometry:t)&&\"GeometryCollection\"===u.type)?u.geometries.length:1;for(var x=0;x<l;x++){var b=0,_=0;if(null!==(s=f?u.geometries[x]:u)){c=s.coordinates;var w=s.type;switch(h=!r||\"Polygon\"!==w&&\"MultiPolygon\"!==w?0:1,w){case null:break;case\"Point\":if(!1===e(c,p,y,b,_))return!1;p++,b++;break;case\"LineString\":case\"MultiPoint\":for(n=0;n<c.length;n++){if(!1===e(c[n],p,y,b,_))return!1;p++,\"MultiPoint\"===w&&b++}\"LineString\"===w&&b++;break;case\"Polygon\":case\"MultiLineString\":for(n=0;n<c.length;n++){for(a=0;a<c[n].length-h;a++){if(!1===e(c[n][a],p,y,b,_))return!1;p++}\"MultiLineString\"===w&&b++,\"Polygon\"===w&&_++}\"Polygon\"===w&&b++;break;case\"MultiPolygon\":for(n=0;n<c.length;n++){for(_=0,a=0;a<c[n].length;a++){for(o=0;o<c[n][a].length-h;o++){if(!1===e(c[n][a][o],p,y,b,_))return!1;p++}_++}b++}break;case\"GeometryCollection\":for(n=0;n<s.geometries.length;n++)if(!1===i(s.geometries[n],e,r))return!1;break;default:throw new Error(\"Unknown Geometry Type\")}}}}}function a(t,e){var r;switch(t.type){case\"FeatureCollection\":for(r=0;r<t.features.length&&!1!==e(t.features[r].properties,r);r++);break;case\"Feature\":e(t.properties,0)}}function o(t,e){if(\"Feature\"===t.type)e(t,0);else if(\"FeatureCollection\"===t.type)for(var r=0;r<t.features.length&&!1!==e(t.features[r],r);r++);}function s(t,e){var r,n,i,a,o,s,l,c,u,f,h=0,p=\"FeatureCollection\"===t.type,d=\"Feature\"===t.type,m=p?t.features.length:1;for(r=0;r<m;r++){for(s=p?t.features[r].geometry:d?t.geometry:t,c=p?t.features[r].properties:d?t.properties:{},u=p?t.features[r].bbox:d?t.bbox:void 0,f=p?t.features[r].id:d?t.id:void 0,o=(l=!!s&&\"GeometryCollection\"===s.type)?s.geometries.length:1,i=0;i<o;i++)if(null!==(a=l?s.geometries[i]:s))switch(a.type){case\"Point\":case\"LineString\":case\"MultiPoint\":case\"Polygon\":case\"MultiLineString\":case\"MultiPolygon\":if(!1===e(a,h,c,u,f))return!1;break;case\"GeometryCollection\":for(n=0;n<a.geometries.length;n++)if(!1===e(a.geometries[n],h,c,u,f))return!1;break;default:throw new Error(\"Unknown Geometry Type\")}else if(!1===e(null,h,c,u,f))return!1;h++}}function l(t,e){s(t,(function(t,r,i,a,o){var s,l=null===t?null:t.type;switch(l){case null:case\"Point\":case\"LineString\":case\"Polygon\":return!1!==e(n.feature(t,i,{bbox:a,id:o}),r,0)&&void 0}switch(l){case\"MultiPoint\":s=\"Point\";break;case\"MultiLineString\":s=\"LineString\";break;case\"MultiPolygon\":s=\"Polygon\"}for(var c=0;c<t.coordinates.length;c++){var u={type:s,coordinates:t.coordinates[c]};if(!1===e(n.feature(u,i),r,c))return!1}}))}function c(t,e){l(t,(function(t,r,a){var o=0;if(t.geometry){var s=t.geometry.type;if(\"Point\"!==s&&\"MultiPoint\"!==s){var l,c=0,u=0,f=0;return!1!==i(t,(function(i,s,h,p,d){if(void 0===l||r>c||p>u||d>f)return l=i,c=r,u=p,f=d,void(o=0);var m=n.lineString([l,i],t.properties);if(!1===e(m,r,a,d,o))return!1;o++,l=i}))&&void 0}}}))}function u(t,e){if(!t)throw new Error(\"geojson is required\");l(t,(function(t,r,i){if(null!==t.geometry){var a=t.geometry.type,o=t.geometry.coordinates;switch(a){case\"LineString\":if(!1===e(t,r,i,0,0))return!1;break;case\"Polygon\":for(var s=0;s<o.length;s++)if(!1===e(n.lineString(o[s],t.properties),r,i,s))return!1}}}))}r.coordEach=i,r.coordReduce=function(t,e,r,n){var a=r;return i(t,(function(t,n,i,o,s){a=0===n&&void 0===r?t:e(a,t,n,i,o,s)}),n),a},r.propEach=a,r.propReduce=function(t,e,r){var n=r;return a(t,(function(t,i){n=0===i&&void 0===r?t:e(n,t,i)})),n},r.featureEach=o,r.featureReduce=function(t,e,r){var n=r;return o(t,(function(t,i){n=0===i&&void 0===r?t:e(n,t,i)})),n},r.coordAll=function(t){var e=[];return i(t,(function(t){e.push(t)})),e},r.geomEach=s,r.geomReduce=function(t,e,r){var n=r;return s(t,(function(t,i,a,o,s){n=0===i&&void 0===r?t:e(n,t,i,a,o,s)})),n},r.flattenEach=l,r.flattenReduce=function(t,e,r){var n=r;return l(t,(function(t,i,a){n=0===i&&0===a&&void 0===r?t:e(n,t,i,a)})),n},r.segmentEach=c,r.segmentReduce=function(t,e,r){var n=r,i=!1;return c(t,(function(t,a,o,s,l){n=!1===i&&void 0===r?t:e(n,t,a,o,s,l),i=!0})),n},r.lineEach=u,r.lineReduce=function(t,e,r){var n=r;return u(t,(function(t,i,a,o){n=0===i&&void 0===r?t:e(n,t,i,a,o)})),n},r.findSegment=function(t,e){if(e=e||{},!n.isObject(e))throw new Error(\"options is invalid\");var r,i=e.featureIndex||0,a=e.multiFeatureIndex||0,o=e.geometryIndex||0,s=e.segmentIndex||0,l=e.properties;switch(t.type){case\"FeatureCollection\":i<0&&(i=t.features.length+i),l=l||t.features[i].properties,r=t.features[i].geometry;break;case\"Feature\":l=l||t.properties,r=t.geometry;break;case\"Point\":case\"MultiPoint\":return null;case\"LineString\":case\"Polygon\":case\"MultiLineString\":case\"MultiPolygon\":r=t;break;default:throw new Error(\"geojson is invalid\")}if(null===r)return null;var c=r.coordinates;switch(r.type){case\"Point\":case\"MultiPoint\":return null;case\"LineString\":return s<0&&(s=c.length+s-1),n.lineString([c[s],c[s+1]],l,e);case\"Polygon\":return o<0&&(o=c.length+o),s<0&&(s=c[o].length+s-1),n.lineString([c[o][s],c[o][s+1]],l,e);case\"MultiLineString\":return a<0&&(a=c.length+a),s<0&&(s=c[a].length+s-1),n.lineString([c[a][s],c[a][s+1]],l,e);case\"MultiPolygon\":return a<0&&(a=c.length+a),o<0&&(o=c[a].length+o),s<0&&(s=c[a][o].length-s-1),n.lineString([c[a][o][s],c[a][o][s+1]],l,e)}throw new Error(\"geojson is invalid\")},r.findPoint=function(t,e){if(e=e||{},!n.isObject(e))throw new Error(\"options is invalid\");var r,i=e.featureIndex||0,a=e.multiFeatureIndex||0,o=e.geometryIndex||0,s=e.coordIndex||0,l=e.properties;switch(t.type){case\"FeatureCollection\":i<0&&(i=t.features.length+i),l=l||t.features[i].properties,r=t.features[i].geometry;break;case\"Feature\":l=l||t.properties,r=t.geometry;break;case\"Point\":case\"MultiPoint\":return null;case\"LineString\":case\"Polygon\":case\"MultiLineString\":case\"MultiPolygon\":r=t;break;default:throw new Error(\"geojson is invalid\")}if(null===r)return null;var c=r.coordinates;switch(r.type){case\"Point\":return n.point(c,l,e);case\"MultiPoint\":return a<0&&(a=c.length+a),n.point(c[a],l,e);case\"LineString\":return s<0&&(s=c.length+s),n.point(c[s],l,e);case\"Polygon\":return o<0&&(o=c.length+o),s<0&&(s=c[o].length+s),n.point(c[o][s],l,e);case\"MultiLineString\":return a<0&&(a=c.length+a),s<0&&(s=c[a].length+s),n.point(c[a][s],l,e);case\"MultiPolygon\":return a<0&&(a=c.length+a),o<0&&(o=c[a].length+o),s<0&&(s=c[a][o].length-s),n.point(c[a][o][s],l,e)}throw new Error(\"geojson is invalid\")}},{\"@turf/helpers\":68}],70:[function(t,e,r){\"use strict\";var n=\"undefined\"==typeof WeakMap?t(\"weak-map\"):WeakMap,i=t(\"gl-buffer\"),a=t(\"gl-vao\"),o=new n;e.exports=function(t){var e=o.get(t),r=e&&(e._triangleBuffer.handle||e._triangleBuffer.buffer);if(!r||!t.isBuffer(r)){var n=i(t,new Float32Array([-1,-1,-1,4,4,-1]));(e=a(t,[{buffer:n,type:t.FLOAT,size:2}]))._triangleBuffer=n,o.set(t,e)}e.bind(),t.drawArrays(t.TRIANGLES,0,3),e.unbind()}},{\"gl-buffer\":263,\"gl-vao\":357,\"weak-map\":621}],71:[function(t,e,r){e.exports=function(t){var e=0,r=0,n=0,i=0;return t.map((function(t){var a=(t=t.slice())[0],o=a.toUpperCase();if(a!=o)switch(t[0]=o,a){case\"a\":t[6]+=n,t[7]+=i;break;case\"v\":t[1]+=i;break;case\"h\":t[1]+=n;break;default:for(var s=1;s<t.length;)t[s++]+=n,t[s++]+=i}switch(o){case\"Z\":n=e,i=r;break;case\"H\":n=t[1];break;case\"V\":i=t[1];break;case\"M\":n=e=t[1],i=r=t[2];break;default:n=t[t.length-2],i=t[t.length-1]}return t}))}},{}],72:[function(t,e,r){var n=t(\"pad-left\");e.exports=function(t,e,r){e=\"number\"==typeof e?e:1,r=r||\": \";var i=t.split(/\\r?\\n/),a=String(i.length+e-1).length;return i.map((function(t,i){var o=i+e,s=String(o).length;return n(o,a-s)+r+t})).join(\"\\n\")}},{\"pad-left\":486}],73:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.length;if(0===e)return[];if(1===e)return[0];for(var r=t[0].length,n=[t[0]],a=[0],o=1;o<e;++o)if(n.push(t[o]),i(n,r)){if(a.push(o),a.length===r+1)return a}else n.pop();return a};var n=t(\"robust-orientation\");function i(t,e){for(var r=new Array(e+1),i=0;i<t.length;++i)r[i]=t[i];for(i=0;i<=t.length;++i){for(var a=t.length;a<=e;++a){for(var o=new Array(e),s=0;s<e;++s)o[s]=Math.pow(a+1-i,s);r[a]=o}if(n.apply(void 0,r))return!0}return!1}},{\"robust-orientation\":544}],74:[function(t,e,r){\"use strict\";e.exports=function(t,e){return n(e).filter((function(r){for(var n=new Array(r.length),a=0;a<r.length;++a)n[a]=e[r[a]];return i(n)*t<1}))};var n=t(\"delaunay-triangulate\"),i=t(\"circumradius\")},{circumradius:125,\"delaunay-triangulate\":176}],75:[function(t,e,r){e.exports=function(t,e){return i(n(t,e))};var n=t(\"alpha-complex\"),i=t(\"simplicial-complex-boundary\")},{\"alpha-complex\":74,\"simplicial-complex-boundary\":552}],76:[function(t,e,r){\"use strict\";e.exports=function(t,e){if(!t||null==t.length)throw Error(\"Argument should be an array\");e=null==e?1:Math.floor(e);for(var r=Array(2*e),n=0;n<e;n++){for(var i=-1/0,a=1/0,o=n,s=t.length;o<s;o+=e)t[o]>i&&(i=t[o]),t[o]<a&&(a=t[o]);r[n]=a,r[e+n]=i}return r}},{}],77:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){if(\"function\"==typeof Array.prototype.findIndex)return t.findIndex(e,r);if(\"function\"!=typeof e)throw new TypeError(\"predicate must be a function\");var n=Object(t),i=n.length;if(0===i)return-1;for(var a=0;a<i;a++)if(e.call(r,n[a],a,n))return a;return-1}},{}],78:[function(t,e,r){\"use strict\";var n=t(\"array-bounds\");e.exports=function(t,e,r){if(!t||null==t.length)throw Error(\"Argument should be an array\");null==e&&(e=1);null==r&&(r=n(t,e));for(var i=0;i<e;i++){var a=r[e+i],o=r[i],s=i,l=t.length;if(a===1/0&&o===-1/0)for(s=i;s<l;s+=e)t[s]=t[s]===a?1:t[s]===o?0:.5;else if(a===1/0)for(s=i;s<l;s+=e)t[s]=t[s]===a?1:0;else if(o===-1/0)for(s=i;s<l;s+=e)t[s]=t[s]===o?0:1;else{var c=a-o;for(s=i;s<l;s+=e)isNaN(t[s])||(t[s]=0===c?.5:(t[s]-o)/c)}}return t}},{\"array-bounds\":76}],79:[function(t,e,r){e.exports=function(t,e){var r=\"number\"==typeof t,n=\"number\"==typeof e;r&&!n?(e=t,t=0):r||n||(t=0,e=0);var i=(e|=0)-(t|=0);if(i<0)throw new Error(\"array length must be positive\");for(var a=new Array(i),o=0,s=t;o<i;o++,s++)a[o]=s;return a}},{}],80:[function(t,e,r){(function(r){(function(){\"use strict\";var n=t(\"object-assign\");\n",
       "/*!\n",
       " * The buffer module from node.js, for the browser.\n",
       " *\n",
       " * @author   Feross Aboukhadijeh <feross@feross.org> <http://feross.org>\n",
       " * @license  MIT\n",
       " */function i(t,e){if(t===e)return 0;for(var r=t.length,n=e.length,i=0,a=Math.min(r,n);i<a;++i)if(t[i]!==e[i]){r=t[i],n=e[i];break}return r<n?-1:n<r?1:0}function a(t){return r.Buffer&&\"function\"==typeof r.Buffer.isBuffer?r.Buffer.isBuffer(t):!(null==t||!t._isBuffer)}var o=t(\"util/\"),s=Object.prototype.hasOwnProperty,l=Array.prototype.slice,c=\"foo\"===function(){}.name;function u(t){return Object.prototype.toString.call(t)}function f(t){return!a(t)&&(\"function\"==typeof r.ArrayBuffer&&(\"function\"==typeof ArrayBuffer.isView?ArrayBuffer.isView(t):!!t&&(t instanceof DataView||!!(t.buffer&&t.buffer instanceof ArrayBuffer))))}var h=e.exports=y,p=/\\s*function\\s+([^\\(\\s]*)\\s*/;function d(t){if(o.isFunction(t)){if(c)return t.name;var e=t.toString().match(p);return e&&e[1]}}function m(t,e){return\"string\"==typeof t?t.length<e?t:t.slice(0,e):t}function g(t){if(c||!o.isFunction(t))return o.inspect(t);var e=d(t);return\"[Function\"+(e?\": \"+e:\"\")+\"]\"}function v(t,e,r,n,i){throw new h.AssertionError({message:r,actual:t,expected:e,operator:n,stackStartFunction:i})}function y(t,e){t||v(t,!0,e,\"==\",h.ok)}function x(t,e,r,n){if(t===e)return!0;if(a(t)&&a(e))return 0===i(t,e);if(o.isDate(t)&&o.isDate(e))return t.getTime()===e.getTime();if(o.isRegExp(t)&&o.isRegExp(e))return t.source===e.source&&t.global===e.global&&t.multiline===e.multiline&&t.lastIndex===e.lastIndex&&t.ignoreCase===e.ignoreCase;if(null!==t&&\"object\"==typeof t||null!==e&&\"object\"==typeof e){if(f(t)&&f(e)&&u(t)===u(e)&&!(t instanceof Float32Array||t instanceof Float64Array))return 0===i(new Uint8Array(t.buffer),new Uint8Array(e.buffer));if(a(t)!==a(e))return!1;var s=(n=n||{actual:[],expected:[]}).actual.indexOf(t);return-1!==s&&s===n.expected.indexOf(e)||(n.actual.push(t),n.expected.push(e),function(t,e,r,n){if(null==t||null==e)return!1;if(o.isPrimitive(t)||o.isPrimitive(e))return t===e;if(r&&Object.getPrototypeOf(t)!==Object.getPrototypeOf(e))return!1;var i=b(t),a=b(e);if(i&&!a||!i&&a)return!1;if(i)return t=l.call(t),e=l.call(e),x(t,e,r);var s,c,u=T(t),f=T(e);if(u.length!==f.length)return!1;for(u.sort(),f.sort(),c=u.length-1;c>=0;c--)if(u[c]!==f[c])return!1;for(c=u.length-1;c>=0;c--)if(s=u[c],!x(t[s],e[s],r,n))return!1;return!0}(t,e,r,n))}return r?t===e:t==e}function b(t){return\"[object Arguments]\"==Object.prototype.toString.call(t)}function _(t,e){if(!t||!e)return!1;if(\"[object RegExp]\"==Object.prototype.toString.call(e))return e.test(t);try{if(t instanceof e)return!0}catch(t){}return!Error.isPrototypeOf(e)&&!0===e.call({},t)}function w(t,e,r,n){var i;if(\"function\"!=typeof e)throw new TypeError('\"block\" argument must be a function');\"string\"==typeof r&&(n=r,r=null),i=function(t){var e;try{t()}catch(t){e=t}return e}(e),n=(r&&r.name?\" (\"+r.name+\").\":\".\")+(n?\" \"+n:\".\"),t&&!i&&v(i,r,\"Missing expected exception\"+n);var a=\"string\"==typeof n,s=!t&&i&&!r;if((!t&&o.isError(i)&&a&&_(i,r)||s)&&v(i,r,\"Got unwanted exception\"+n),t&&i&&r&&!_(i,r)||!t&&i)throw i}h.AssertionError=function(t){this.name=\"AssertionError\",this.actual=t.actual,this.expected=t.expected,this.operator=t.operator,t.message?(this.message=t.message,this.generatedMessage=!1):(this.message=function(t){return m(g(t.actual),128)+\" \"+t.operator+\" \"+m(g(t.expected),128)}(this),this.generatedMessage=!0);var e=t.stackStartFunction||v;if(Error.captureStackTrace)Error.captureStackTrace(this,e);else{var r=new Error;if(r.stack){var n=r.stack,i=d(e),a=n.indexOf(\"\\n\"+i);if(a>=0){var o=n.indexOf(\"\\n\",a+1);n=n.substring(o+1)}this.stack=n}}},o.inherits(h.AssertionError,Error),h.fail=v,h.ok=y,h.equal=function(t,e,r){t!=e&&v(t,e,r,\"==\",h.equal)},h.notEqual=function(t,e,r){t==e&&v(t,e,r,\"!=\",h.notEqual)},h.deepEqual=function(t,e,r){x(t,e,!1)||v(t,e,r,\"deepEqual\",h.deepEqual)},h.deepStrictEqual=function(t,e,r){x(t,e,!0)||v(t,e,r,\"deepStrictEqual\",h.deepStrictEqual)},h.notDeepEqual=function(t,e,r){x(t,e,!1)&&v(t,e,r,\"notDeepEqual\",h.notDeepEqual)},h.notDeepStrictEqual=function t(e,r,n){x(e,r,!0)&&v(e,r,n,\"notDeepStrictEqual\",t)},h.strictEqual=function(t,e,r){t!==e&&v(t,e,r,\"===\",h.strictEqual)},h.notStrictEqual=function(t,e,r){t===e&&v(t,e,r,\"!==\",h.notStrictEqual)},h.throws=function(t,e,r){w(!0,t,e,r)},h.doesNotThrow=function(t,e,r){w(!1,t,e,r)},h.ifError=function(t){if(t)throw t},h.strict=n((function t(e,r){e||v(e,!0,r,\"==\",t)}),h,{equal:h.strictEqual,deepEqual:h.deepStrictEqual,notEqual:h.notStrictEqual,notDeepEqual:h.notDeepStrictEqual}),h.strict.strict=h.strict;var T=Object.keys||function(t){var e=[];for(var r in t)s.call(t,r)&&e.push(r);return e}}).call(this)}).call(this,\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{\"object-assign\":483,\"util/\":83}],81:[function(t,e,r){\"function\"==typeof Object.create?e.exports=function(t,e){t.super_=e,t.prototype=Object.create(e.prototype,{constructor:{value:t,enumerable:!1,writable:!0,configurable:!0}})}:e.exports=function(t,e){t.super_=e;var r=function(){};r.prototype=e.prototype,t.prototype=new r,t.prototype.constructor=t}},{}],82:[function(t,e,r){e.exports=function(t){return t&&\"object\"==typeof t&&\"function\"==typeof t.copy&&\"function\"==typeof t.fill&&\"function\"==typeof t.readUInt8}},{}],83:[function(t,e,r){(function(e,n){(function(){var i=/%[sdj%]/g;r.format=function(t){if(!v(t)){for(var e=[],r=0;r<arguments.length;r++)e.push(s(arguments[r]));return e.join(\" \")}r=1;for(var n=arguments,a=n.length,o=String(t).replace(i,(function(t){if(\"%%\"===t)return\"%\";if(r>=a)return t;switch(t){case\"%s\":return String(n[r++]);case\"%d\":return Number(n[r++]);case\"%j\":try{return JSON.stringify(n[r++])}catch(t){return\"[Circular]\"}default:return t}})),l=n[r];r<a;l=n[++r])m(l)||!b(l)?o+=\" \"+l:o+=\" \"+s(l);return o},r.deprecate=function(t,i){if(y(n.process))return function(){return r.deprecate(t,i).apply(this,arguments)};if(!0===e.noDeprecation)return t;var a=!1;return function(){if(!a){if(e.throwDeprecation)throw new Error(i);e.traceDeprecation?console.trace(i):console.error(i),a=!0}return t.apply(this,arguments)}};var a,o={};function s(t,e){var n={seen:[],stylize:c};return arguments.length>=3&&(n.depth=arguments[2]),arguments.length>=4&&(n.colors=arguments[3]),d(e)?n.showHidden=e:e&&r._extend(n,e),y(n.showHidden)&&(n.showHidden=!1),y(n.depth)&&(n.depth=2),y(n.colors)&&(n.colors=!1),y(n.customInspect)&&(n.customInspect=!0),n.colors&&(n.stylize=l),u(n,t,n.depth)}function l(t,e){var r=s.styles[e];return r?\"\\x1b[\"+s.colors[r][0]+\"m\"+t+\"\\x1b[\"+s.colors[r][1]+\"m\":t}function c(t,e){return t}function u(t,e,n){if(t.customInspect&&e&&T(e.inspect)&&e.inspect!==r.inspect&&(!e.constructor||e.constructor.prototype!==e)){var i=e.inspect(n,t);return v(i)||(i=u(t,i,n)),i}var a=function(t,e){if(y(e))return t.stylize(\"undefined\",\"undefined\");if(v(e)){var r=\"'\"+JSON.stringify(e).replace(/^\"|\"$/g,\"\").replace(/'/g,\"\\\\'\").replace(/\\\\\"/g,'\"')+\"'\";return t.stylize(r,\"string\")}if(g(e))return t.stylize(\"\"+e,\"number\");if(d(e))return t.stylize(\"\"+e,\"boolean\");if(m(e))return t.stylize(\"null\",\"null\")}(t,e);if(a)return a;var o=Object.keys(e),s=function(t){var e={};return t.forEach((function(t,r){e[t]=!0})),e}(o);if(t.showHidden&&(o=Object.getOwnPropertyNames(e)),w(e)&&(o.indexOf(\"message\")>=0||o.indexOf(\"description\")>=0))return f(e);if(0===o.length){if(T(e)){var l=e.name?\": \"+e.name:\"\";return t.stylize(\"[Function\"+l+\"]\",\"special\")}if(x(e))return t.stylize(RegExp.prototype.toString.call(e),\"regexp\");if(_(e))return t.stylize(Date.prototype.toString.call(e),\"date\");if(w(e))return f(e)}var c,b=\"\",k=!1,M=[\"{\",\"}\"];(p(e)&&(k=!0,M=[\"[\",\"]\"]),T(e))&&(b=\" [Function\"+(e.name?\": \"+e.name:\"\")+\"]\");return x(e)&&(b=\" \"+RegExp.prototype.toString.call(e)),_(e)&&(b=\" \"+Date.prototype.toUTCString.call(e)),w(e)&&(b=\" \"+f(e)),0!==o.length||k&&0!=e.length?n<0?x(e)?t.stylize(RegExp.prototype.toString.call(e),\"regexp\"):t.stylize(\"[Object]\",\"special\"):(t.seen.push(e),c=k?function(t,e,r,n,i){for(var a=[],o=0,s=e.length;o<s;++o)E(e,String(o))?a.push(h(t,e,r,n,String(o),!0)):a.push(\"\");return i.forEach((function(i){i.match(/^\\d+$/)||a.push(h(t,e,r,n,i,!0))})),a}(t,e,n,s,o):o.map((function(r){return h(t,e,n,s,r,k)})),t.seen.pop(),function(t,e,r){if(t.reduce((function(t,e){return e.indexOf(\"\\n\")>=0&&0,t+e.replace(/\\u001b\\[\\d\\d?m/g,\"\").length+1}),0)>60)return r[0]+(\"\"===e?\"\":e+\"\\n \")+\" \"+t.join(\",\\n  \")+\" \"+r[1];return r[0]+e+\" \"+t.join(\", \")+\" \"+r[1]}(c,b,M)):M[0]+b+M[1]}function f(t){return\"[\"+Error.prototype.toString.call(t)+\"]\"}function h(t,e,r,n,i,a){var o,s,l;if((l=Object.getOwnPropertyDescriptor(e,i)||{value:e[i]}).get?s=l.set?t.stylize(\"[Getter/Setter]\",\"special\"):t.stylize(\"[Getter]\",\"special\"):l.set&&(s=t.stylize(\"[Setter]\",\"special\")),E(n,i)||(o=\"[\"+i+\"]\"),s||(t.seen.indexOf(l.value)<0?(s=m(r)?u(t,l.value,null):u(t,l.value,r-1)).indexOf(\"\\n\")>-1&&(s=a?s.split(\"\\n\").map((function(t){return\"  \"+t})).join(\"\\n\").substr(2):\"\\n\"+s.split(\"\\n\").map((function(t){return\"   \"+t})).join(\"\\n\")):s=t.stylize(\"[Circular]\",\"special\")),y(o)){if(a&&i.match(/^\\d+$/))return s;(o=JSON.stringify(\"\"+i)).match(/^\"([a-zA-Z_][a-zA-Z_0-9]*)\"$/)?(o=o.substr(1,o.length-2),o=t.stylize(o,\"name\")):(o=o.replace(/'/g,\"\\\\'\").replace(/\\\\\"/g,'\"').replace(/(^\"|\"$)/g,\"'\"),o=t.stylize(o,\"string\"))}return o+\": \"+s}function p(t){return Array.isArray(t)}function d(t){return\"boolean\"==typeof t}function m(t){return null===t}function g(t){return\"number\"==typeof t}function v(t){return\"string\"==typeof t}function y(t){return void 0===t}function x(t){return b(t)&&\"[object RegExp]\"===k(t)}function b(t){return\"object\"==typeof t&&null!==t}function _(t){return b(t)&&\"[object Date]\"===k(t)}function w(t){return b(t)&&(\"[object Error]\"===k(t)||t instanceof Error)}function T(t){return\"function\"==typeof t}function k(t){return Object.prototype.toString.call(t)}function M(t){return t<10?\"0\"+t.toString(10):t.toString(10)}r.debuglog=function(t){if(y(a)&&(a=e.env.NODE_DEBUG||\"\"),t=t.toUpperCase(),!o[t])if(new RegExp(\"\\\\b\"+t+\"\\\\b\",\"i\").test(a)){var n=e.pid;o[t]=function(){var e=r.format.apply(r,arguments);console.error(\"%s %d: %s\",t,n,e)}}else o[t]=function(){};return o[t]},r.inspect=s,s.colors={bold:[1,22],italic:[3,23],underline:[4,24],inverse:[7,27],white:[37,39],grey:[90,39],black:[30,39],blue:[34,39],cyan:[36,39],green:[32,39],magenta:[35,39],red:[31,39],yellow:[33,39]},s.styles={special:\"cyan\",number:\"yellow\",boolean:\"yellow\",undefined:\"grey\",null:\"bold\",string:\"green\",date:\"magenta\",regexp:\"red\"},r.isArray=p,r.isBoolean=d,r.isNull=m,r.isNullOrUndefined=function(t){return null==t},r.isNumber=g,r.isString=v,r.isSymbol=function(t){return\"symbol\"==typeof t},r.isUndefined=y,r.isRegExp=x,r.isObject=b,r.isDate=_,r.isError=w,r.isFunction=T,r.isPrimitive=function(t){return null===t||\"boolean\"==typeof t||\"number\"==typeof t||\"string\"==typeof t||\"symbol\"==typeof t||void 0===t},r.isBuffer=t(\"./support/isBuffer\");var A=[\"Jan\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\"Jul\",\"Aug\",\"Sep\",\"Oct\",\"Nov\",\"Dec\"];function S(){var t=new Date,e=[M(t.getHours()),M(t.getMinutes()),M(t.getSeconds())].join(\":\");return[t.getDate(),A[t.getMonth()],e].join(\" \")}function E(t,e){return Object.prototype.hasOwnProperty.call(t,e)}r.log=function(){console.log(\"%s - %s\",S(),r.format.apply(r,arguments))},r.inherits=t(\"inherits\"),r._extend=function(t,e){if(!e||!b(e))return t;for(var r=Object.keys(e),n=r.length;n--;)t[r[n]]=e[r[n]];return t}}).call(this)}).call(this,t(\"_process\"),\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{\"./support/isBuffer\":82,_process:524,inherits:81}],84:[function(t,e,r){e.exports=function(t){return atob(t)}},{}],85:[function(t,e,r){\"use strict\";e.exports=function(t,e){for(var r=e.length,a=new Array(r+1),o=0;o<r;++o){for(var s=new Array(r+1),l=0;l<=r;++l)s[l]=t[l][o];a[o]=s}a[r]=new Array(r+1);for(o=0;o<=r;++o)a[r][o]=1;var c=new Array(r+1);for(o=0;o<r;++o)c[o]=e[o];c[r]=1;var u=n(a,c),f=i(u[r+1]);0===f&&(f=1);var h=new Array(r+1);for(o=0;o<=r;++o)h[o]=i(u[o])/f;return h};var n=t(\"robust-linear-solve\");function i(t){for(var e=0,r=0;r<t.length;++r)e+=t[r];return e}},{\"robust-linear-solve\":543}],86:[function(t,e,r){\"use strict\";r.byteLength=function(t){var e=c(t),r=e[0],n=e[1];return 3*(r+n)/4-n},r.toByteArray=function(t){var e,r,n=c(t),o=n[0],s=n[1],l=new a(function(t,e,r){return 3*(e+r)/4-r}(0,o,s)),u=0,f=s>0?o-4:o;for(r=0;r<f;r+=4)e=i[t.charCodeAt(r)]<<18|i[t.charCodeAt(r+1)]<<12|i[t.charCodeAt(r+2)]<<6|i[t.charCodeAt(r+3)],l[u++]=e>>16&255,l[u++]=e>>8&255,l[u++]=255&e;2===s&&(e=i[t.charCodeAt(r)]<<2|i[t.charCodeAt(r+1)]>>4,l[u++]=255&e);1===s&&(e=i[t.charCodeAt(r)]<<10|i[t.charCodeAt(r+1)]<<4|i[t.charCodeAt(r+2)]>>2,l[u++]=e>>8&255,l[u++]=255&e);return l},r.fromByteArray=function(t){for(var e,r=t.length,i=r%3,a=[],o=0,s=r-i;o<s;o+=16383)a.push(u(t,o,o+16383>s?s:o+16383));1===i?(e=t[r-1],a.push(n[e>>2]+n[e<<4&63]+\"==\")):2===i&&(e=(t[r-2]<<8)+t[r-1],a.push(n[e>>10]+n[e>>4&63]+n[e<<2&63]+\"=\"));return a.join(\"\")};for(var n=[],i=[],a=\"undefined\"!=typeof Uint8Array?Uint8Array:Array,o=\"ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/\",s=0,l=o.length;s<l;++s)n[s]=o[s],i[o.charCodeAt(s)]=s;function c(t){var e=t.length;if(e%4>0)throw new Error(\"Invalid string. Length must be a multiple of 4\");var r=t.indexOf(\"=\");return-1===r&&(r=e),[r,r===e?0:4-r%4]}function u(t,e,r){for(var i,a,o=[],s=e;s<r;s+=3)i=(t[s]<<16&16711680)+(t[s+1]<<8&65280)+(255&t[s+2]),o.push(n[(a=i)>>18&63]+n[a>>12&63]+n[a>>6&63]+n[63&a]);return o.join(\"\")}i[\"-\".charCodeAt(0)]=62,i[\"_\".charCodeAt(0)]=63},{}],87:[function(t,e,r){\"use strict\";var n=t(\"./lib/rationalize\");e.exports=function(t,e){return n(t[0].mul(e[1]).add(e[0].mul(t[1])),t[1].mul(e[1]))}},{\"./lib/rationalize\":97}],88:[function(t,e,r){\"use strict\";e.exports=function(t,e){return t[0].mul(e[1]).cmp(e[0].mul(t[1]))}},{}],89:[function(t,e,r){\"use strict\";var n=t(\"./lib/rationalize\");e.exports=function(t,e){return n(t[0].mul(e[1]),t[1].mul(e[0]))}},{\"./lib/rationalize\":97}],90:[function(t,e,r){\"use strict\";var n=t(\"./is-rat\"),i=t(\"./lib/is-bn\"),a=t(\"./lib/num-to-bn\"),o=t(\"./lib/str-to-bn\"),s=t(\"./lib/rationalize\"),l=t(\"./div\");e.exports=function t(e,r){if(n(e))return r?l(e,t(r)):[e[0].clone(),e[1].clone()];var c,u,f=0;if(i(e))c=e.clone();else if(\"string\"==typeof e)c=o(e);else{if(0===e)return[a(0),a(1)];if(e===Math.floor(e))c=a(e);else{for(;e!==Math.floor(e);)e*=Math.pow(2,256),f-=256;c=a(e)}}if(n(r))c.mul(r[1]),u=r[0].clone();else if(i(r))u=r.clone();else if(\"string\"==typeof r)u=o(r);else if(r)if(r===Math.floor(r))u=a(r);else{for(;r!==Math.floor(r);)r*=Math.pow(2,256),f+=256;u=a(r)}else u=a(1);f>0?c=c.ushln(f):f<0&&(u=u.ushln(-f));return s(c,u)}},{\"./div\":89,\"./is-rat\":91,\"./lib/is-bn\":95,\"./lib/num-to-bn\":96,\"./lib/rationalize\":97,\"./lib/str-to-bn\":98}],91:[function(t,e,r){\"use strict\";var n=t(\"./lib/is-bn\");e.exports=function(t){return Array.isArray(t)&&2===t.length&&n(t[0])&&n(t[1])}},{\"./lib/is-bn\":95}],92:[function(t,e,r){\"use strict\";var n=t(\"bn.js\");e.exports=function(t){return t.cmp(new n(0))}},{\"bn.js\":106}],93:[function(t,e,r){\"use strict\";var n=t(\"./bn-sign\");e.exports=function(t){var e=t.length,r=t.words,i=0;if(1===e)i=r[0];else if(2===e)i=r[0]+67108864*r[1];else for(var a=0;a<e;a++){var o=r[a];i+=o*Math.pow(67108864,a)}return n(t)*i}},{\"./bn-sign\":92}],94:[function(t,e,r){\"use strict\";var n=t(\"double-bits\"),i=t(\"bit-twiddle\").countTrailingZeros;e.exports=function(t){var e=i(n.lo(t));if(e<32)return e;var r=i(n.hi(t));if(r>20)return 52;return r+32}},{\"bit-twiddle\":104,\"double-bits\":178}],95:[function(t,e,r){\"use strict\";t(\"bn.js\");e.exports=function(t){return t&&\"object\"==typeof t&&Boolean(t.words)}},{\"bn.js\":106}],96:[function(t,e,r){\"use strict\";var n=t(\"bn.js\"),i=t(\"double-bits\");e.exports=function(t){var e=i.exponent(t);return e<52?new n(t):new n(t*Math.pow(2,52-e)).ushln(e-52)}},{\"bn.js\":106,\"double-bits\":178}],97:[function(t,e,r){\"use strict\";var n=t(\"./num-to-bn\"),i=t(\"./bn-sign\");e.exports=function(t,e){var r=i(t),a=i(e);if(0===r)return[n(0),n(1)];if(0===a)return[n(0),n(0)];a<0&&(t=t.neg(),e=e.neg());var o=t.gcd(e);if(o.cmpn(1))return[t.div(o),e.div(o)];return[t,e]}},{\"./bn-sign\":92,\"./num-to-bn\":96}],98:[function(t,e,r){\"use strict\";var n=t(\"bn.js\");e.exports=function(t){return new n(t)}},{\"bn.js\":106}],99:[function(t,e,r){\"use strict\";var n=t(\"./lib/rationalize\");e.exports=function(t,e){return n(t[0].mul(e[0]),t[1].mul(e[1]))}},{\"./lib/rationalize\":97}],100:[function(t,e,r){\"use strict\";var n=t(\"./lib/bn-sign\");e.exports=function(t){return n(t[0])*n(t[1])}},{\"./lib/bn-sign\":92}],101:[function(t,e,r){\"use strict\";var n=t(\"./lib/rationalize\");e.exports=function(t,e){return n(t[0].mul(e[1]).sub(t[1].mul(e[0])),t[1].mul(e[1]))}},{\"./lib/rationalize\":97}],102:[function(t,e,r){\"use strict\";var n=t(\"./lib/bn-to-num\"),i=t(\"./lib/ctz\");e.exports=function(t){var e=t[0],r=t[1];if(0===e.cmpn(0))return 0;var a=e.abs().divmod(r.abs()),o=a.div,s=n(o),l=a.mod,c=e.negative!==r.negative?-1:1;if(0===l.cmpn(0))return c*s;if(s){var u=i(s)+4,f=n(l.ushln(u).divRound(r));return c*(s+f*Math.pow(2,-u))}var h=r.bitLength()-l.bitLength()+53;f=n(l.ushln(h).divRound(r));return h<1023?c*f*Math.pow(2,-h):(f*=Math.pow(2,-1023),c*f*Math.pow(2,1023-h))}},{\"./lib/bn-to-num\":93,\"./lib/ctz\":94}],103:[function(t,e,r){\"use strict\";function n(t,e,r,n,i){for(var a=i+1;n<=i;){var o=n+i>>>1,s=t[o];(void 0!==r?r(s,e):s-e)>=0?(a=o,i=o-1):n=o+1}return a}function i(t,e,r,n,i){for(var a=i+1;n<=i;){var o=n+i>>>1,s=t[o];(void 0!==r?r(s,e):s-e)>0?(a=o,i=o-1):n=o+1}return a}function a(t,e,r,n,i){for(var a=n-1;n<=i;){var o=n+i>>>1,s=t[o];(void 0!==r?r(s,e):s-e)<0?(a=o,n=o+1):i=o-1}return a}function o(t,e,r,n,i){for(var a=n-1;n<=i;){var o=n+i>>>1,s=t[o];(void 0!==r?r(s,e):s-e)<=0?(a=o,n=o+1):i=o-1}return a}function s(t,e,r,n,i){for(;n<=i;){var a=n+i>>>1,o=t[a],s=void 0!==r?r(o,e):o-e;if(0===s)return a;s<=0?n=a+1:i=a-1}return-1}function l(t,e,r,n,i,a){return\"function\"==typeof r?a(t,e,r,void 0===n?0:0|n,void 0===i?t.length-1:0|i):a(t,e,void 0,void 0===r?0:0|r,void 0===n?t.length-1:0|n)}e.exports={ge:function(t,e,r,i,a){return l(t,e,r,i,a,n)},gt:function(t,e,r,n,a){return l(t,e,r,n,a,i)},lt:function(t,e,r,n,i){return l(t,e,r,n,i,a)},le:function(t,e,r,n,i){return l(t,e,r,n,i,o)},eq:function(t,e,r,n,i){return l(t,e,r,n,i,s)}}},{}],104:[function(t,e,r){\"use strict\";function n(t){var e=32;return(t&=-t)&&e--,65535&t&&(e-=16),16711935&t&&(e-=8),252645135&t&&(e-=4),858993459&t&&(e-=2),1431655765&t&&(e-=1),e}r.INT_BITS=32,r.INT_MAX=2147483647,r.INT_MIN=-1<<31,r.sign=function(t){return(t>0)-(t<0)},r.abs=function(t){var e=t>>31;return(t^e)-e},r.min=function(t,e){return e^(t^e)&-(t<e)},r.max=function(t,e){return t^(t^e)&-(t<e)},r.isPow2=function(t){return!(t&t-1||!t)},r.log2=function(t){var e,r;return e=(t>65535)<<4,e|=r=((t>>>=e)>255)<<3,e|=r=((t>>>=r)>15)<<2,(e|=r=((t>>>=r)>3)<<1)|(t>>>=r)>>1},r.log10=function(t){return t>=1e9?9:t>=1e8?8:t>=1e7?7:t>=1e6?6:t>=1e5?5:t>=1e4?4:t>=1e3?3:t>=100?2:t>=10?1:0},r.popCount=function(t){return 16843009*((t=(858993459&(t-=t>>>1&1431655765))+(t>>>2&858993459))+(t>>>4)&252645135)>>>24},r.countTrailingZeros=n,r.nextPow2=function(t){return t+=0===t,--t,t|=t>>>1,t|=t>>>2,t|=t>>>4,t|=t>>>8,(t|=t>>>16)+1},r.prevPow2=function(t){return t|=t>>>1,t|=t>>>2,t|=t>>>4,t|=t>>>8,(t|=t>>>16)-(t>>>1)},r.parity=function(t){return t^=t>>>16,t^=t>>>8,t^=t>>>4,27030>>>(t&=15)&1};var i=new Array(256);!function(t){for(var e=0;e<256;++e){var r=e,n=e,i=7;for(r>>>=1;r;r>>>=1)n<<=1,n|=1&r,--i;t[e]=n<<i&255}}(i),r.reverse=function(t){return i[255&t]<<24|i[t>>>8&255]<<16|i[t>>>16&255]<<8|i[t>>>24&255]},r.interleave2=function(t,e){return(t=1431655765&((t=858993459&((t=252645135&((t=16711935&((t&=65535)|t<<8))|t<<4))|t<<2))|t<<1))|(e=1431655765&((e=858993459&((e=252645135&((e=16711935&((e&=65535)|e<<8))|e<<4))|e<<2))|e<<1))<<1},r.deinterleave2=function(t,e){return(t=65535&((t=16711935&((t=252645135&((t=858993459&((t=t>>>e&1431655765)|t>>>1))|t>>>2))|t>>>4))|t>>>16))<<16>>16},r.interleave3=function(t,e,r){return t=1227133513&((t=3272356035&((t=251719695&((t=4278190335&((t&=1023)|t<<16))|t<<8))|t<<4))|t<<2),(t|=(e=1227133513&((e=3272356035&((e=251719695&((e=4278190335&((e&=1023)|e<<16))|e<<8))|e<<4))|e<<2))<<1)|(r=1227133513&((r=3272356035&((r=251719695&((r=4278190335&((r&=1023)|r<<16))|r<<8))|r<<4))|r<<2))<<2},r.deinterleave3=function(t,e){return(t=1023&((t=4278190335&((t=251719695&((t=3272356035&((t=t>>>e&1227133513)|t>>>2))|t>>>4))|t>>>8))|t>>>16))<<22>>22},r.nextCombination=function(t){var e=t|t-1;return e+1|(~e&-~e)-1>>>n(t)+1}},{}],105:[function(t,e,r){\"use strict\";var n=t(\"clamp\");e.exports=function(t,e){e||(e={});var r,o,s,l,c,u,f,h,p,d,m,g=null==e.cutoff?.25:e.cutoff,v=null==e.radius?8:e.radius,y=e.channel||0;if(ArrayBuffer.isView(t)||Array.isArray(t)){if(!e.width||!e.height)throw Error(\"For raw data width and height should be provided by options\");r=e.width,o=e.height,l=t,u=e.stride?e.stride:Math.floor(t.length/r/o)}else window.HTMLCanvasElement&&t instanceof window.HTMLCanvasElement?(f=(h=t).getContext(\"2d\"),r=h.width,o=h.height,p=f.getImageData(0,0,r,o),l=p.data,u=4):window.CanvasRenderingContext2D&&t instanceof window.CanvasRenderingContext2D?(h=t.canvas,f=t,r=h.width,o=h.height,p=f.getImageData(0,0,r,o),l=p.data,u=4):window.ImageData&&t instanceof window.ImageData&&(p=t,r=t.width,o=t.height,l=p.data,u=4);if(s=Math.max(r,o),window.Uint8ClampedArray&&l instanceof window.Uint8ClampedArray||window.Uint8Array&&l instanceof window.Uint8Array)for(c=l,l=Array(r*o),d=0,m=c.length;d<m;d++)l[d]=c[d*u+y]/255;else if(1!==u)throw Error(\"Raw data can have only 1 value per pixel\");var x=Array(r*o),b=Array(r*o),_=Array(s),w=Array(s),T=Array(s+1),k=Array(s);for(d=0,m=r*o;d<m;d++){var M=l[d];x[d]=1===M?0:0===M?i:Math.pow(Math.max(0,.5-M),2),b[d]=1===M?i:0===M?0:Math.pow(Math.max(0,M-.5),2)}a(x,r,o,_,w,k,T),a(b,r,o,_,w,k,T);var A=window.Float32Array?new Float32Array(r*o):new Array(r*o);for(d=0,m=r*o;d<m;d++)A[d]=n(1-((x[d]-b[d])/v+g),0,1);return A};var i=1e20;function a(t,e,r,n,i,a,s){for(var l=0;l<e;l++){for(var c=0;c<r;c++)n[c]=t[c*e+l];for(o(n,i,a,s,r),c=0;c<r;c++)t[c*e+l]=i[c]}for(c=0;c<r;c++){for(l=0;l<e;l++)n[l]=t[c*e+l];for(o(n,i,a,s,e),l=0;l<e;l++)t[c*e+l]=Math.sqrt(i[l])}}function o(t,e,r,n,a){r[0]=0,n[0]=-i,n[1]=+i;for(var o=1,s=0;o<a;o++){for(var l=(t[o]+o*o-(t[r[s]]+r[s]*r[s]))/(2*o-2*r[s]);l<=n[s];)s--,l=(t[o]+o*o-(t[r[s]]+r[s]*r[s]))/(2*o-2*r[s]);r[++s]=o,n[s]=l,n[s+1]=+i}for(o=0,s=0;o<a;o++){for(;n[s+1]<o;)s++;e[o]=(o-r[s])*(o-r[s])+t[r[s]]}}},{clamp:126}],106:[function(t,e,r){!function(e,r){\"use strict\";function n(t,e){if(!t)throw new Error(e||\"Assertion failed\")}function i(t,e){t.super_=e;var r=function(){};r.prototype=e.prototype,t.prototype=new r,t.prototype.constructor=t}function a(t,e,r){if(a.isBN(t))return t;this.negative=0,this.words=null,this.length=0,this.red=null,null!==t&&(\"le\"!==e&&\"be\"!==e||(r=e,e=10),this._init(t||0,e||10,r||\"be\"))}var o;\"object\"==typeof e?e.exports=a:r.BN=a,a.BN=a,a.wordSize=26;try{o=t(\"buffer\").Buffer}catch(t){}function s(t,e,r){for(var n=0,i=Math.min(t.length,r),a=e;a<i;a++){var o=t.charCodeAt(a)-48;n<<=4,n|=o>=49&&o<=54?o-49+10:o>=17&&o<=22?o-17+10:15&o}return n}function l(t,e,r,n){for(var i=0,a=Math.min(t.length,r),o=e;o<a;o++){var s=t.charCodeAt(o)-48;i*=n,i+=s>=49?s-49+10:s>=17?s-17+10:s}return i}a.isBN=function(t){return t instanceof a||null!==t&&\"object\"==typeof t&&t.constructor.wordSize===a.wordSize&&Array.isArray(t.words)},a.max=function(t,e){return t.cmp(e)>0?t:e},a.min=function(t,e){return t.cmp(e)<0?t:e},a.prototype._init=function(t,e,r){if(\"number\"==typeof t)return this._initNumber(t,e,r);if(\"object\"==typeof t)return this._initArray(t,e,r);\"hex\"===e&&(e=16),n(e===(0|e)&&e>=2&&e<=36);var i=0;\"-\"===(t=t.toString().replace(/\\s+/g,\"\"))[0]&&i++,16===e?this._parseHex(t,i):this._parseBase(t,e,i),\"-\"===t[0]&&(this.negative=1),this.strip(),\"le\"===r&&this._initArray(this.toArray(),e,r)},a.prototype._initNumber=function(t,e,r){t<0&&(this.negative=1,t=-t),t<67108864?(this.words=[67108863&t],this.length=1):t<4503599627370496?(this.words=[67108863&t,t/67108864&67108863],this.length=2):(n(t<9007199254740992),this.words=[67108863&t,t/67108864&67108863,1],this.length=3),\"le\"===r&&this._initArray(this.toArray(),e,r)},a.prototype._initArray=function(t,e,r){if(n(\"number\"==typeof t.length),t.length<=0)return this.words=[0],this.length=1,this;this.length=Math.ceil(t.length/3),this.words=new Array(this.length);for(var i=0;i<this.length;i++)this.words[i]=0;var a,o,s=0;if(\"be\"===r)for(i=t.length-1,a=0;i>=0;i-=3)o=t[i]|t[i-1]<<8|t[i-2]<<16,this.words[a]|=o<<s&67108863,this.words[a+1]=o>>>26-s&67108863,(s+=24)>=26&&(s-=26,a++);else if(\"le\"===r)for(i=0,a=0;i<t.length;i+=3)o=t[i]|t[i+1]<<8|t[i+2]<<16,this.words[a]|=o<<s&67108863,this.words[a+1]=o>>>26-s&67108863,(s+=24)>=26&&(s-=26,a++);return this.strip()},a.prototype._parseHex=function(t,e){this.length=Math.ceil((t.length-e)/6),this.words=new Array(this.length);for(var r=0;r<this.length;r++)this.words[r]=0;var n,i,a=0;for(r=t.length-6,n=0;r>=e;r-=6)i=s(t,r,r+6),this.words[n]|=i<<a&67108863,this.words[n+1]|=i>>>26-a&4194303,(a+=24)>=26&&(a-=26,n++);r+6!==e&&(i=s(t,e,r+6),this.words[n]|=i<<a&67108863,this.words[n+1]|=i>>>26-a&4194303),this.strip()},a.prototype._parseBase=function(t,e,r){this.words=[0],this.length=1;for(var n=0,i=1;i<=67108863;i*=e)n++;n--,i=i/e|0;for(var a=t.length-r,o=a%n,s=Math.min(a,a-o)+r,c=0,u=r;u<s;u+=n)c=l(t,u,u+n,e),this.imuln(i),this.words[0]+c<67108864?this.words[0]+=c:this._iaddn(c);if(0!==o){var f=1;for(c=l(t,u,t.length,e),u=0;u<o;u++)f*=e;this.imuln(f),this.words[0]+c<67108864?this.words[0]+=c:this._iaddn(c)}},a.prototype.copy=function(t){t.words=new Array(this.length);for(var e=0;e<this.length;e++)t.words[e]=this.words[e];t.length=this.length,t.negative=this.negative,t.red=this.red},a.prototype.clone=function(){var t=new a(null);return this.copy(t),t},a.prototype._expand=function(t){for(;this.length<t;)this.words[this.length++]=0;return this},a.prototype.strip=function(){for(;this.length>1&&0===this.words[this.length-1];)this.length--;return this._normSign()},a.prototype._normSign=function(){return 1===this.length&&0===this.words[0]&&(this.negative=0),this},a.prototype.inspect=function(){return(this.red?\"<BN-R: \":\"<BN: \")+this.toString(16)+\">\"};var c=[\"\",\"0\",\"00\",\"000\",\"0000\",\"00000\",\"000000\",\"0000000\",\"00000000\",\"000000000\",\"0000000000\",\"00000000000\",\"000000000000\",\"0000000000000\",\"00000000000000\",\"000000000000000\",\"0000000000000000\",\"00000000000000000\",\"000000000000000000\",\"0000000000000000000\",\"00000000000000000000\",\"000000000000000000000\",\"0000000000000000000000\",\"00000000000000000000000\",\"000000000000000000000000\",\"0000000000000000000000000\"],u=[0,0,25,16,12,11,10,9,8,8,7,7,7,7,6,6,6,6,6,6,6,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5],f=[0,0,33554432,43046721,16777216,48828125,60466176,40353607,16777216,43046721,1e7,19487171,35831808,62748517,7529536,11390625,16777216,24137569,34012224,47045881,64e6,4084101,5153632,6436343,7962624,9765625,11881376,14348907,17210368,20511149,243e5,28629151,33554432,39135393,45435424,52521875,60466176];function h(t,e,r){r.negative=e.negative^t.negative;var n=t.length+e.length|0;r.length=n,n=n-1|0;var i=0|t.words[0],a=0|e.words[0],o=i*a,s=67108863&o,l=o/67108864|0;r.words[0]=s;for(var c=1;c<n;c++){for(var u=l>>>26,f=67108863&l,h=Math.min(c,e.length-1),p=Math.max(0,c-t.length+1);p<=h;p++){var d=c-p|0;u+=(o=(i=0|t.words[d])*(a=0|e.words[p])+f)/67108864|0,f=67108863&o}r.words[c]=0|f,l=0|u}return 0!==l?r.words[c]=0|l:r.length--,r.strip()}a.prototype.toString=function(t,e){var r;if(e=0|e||1,16===(t=t||10)||\"hex\"===t){r=\"\";for(var i=0,a=0,o=0;o<this.length;o++){var s=this.words[o],l=(16777215&(s<<i|a)).toString(16);r=0!==(a=s>>>24-i&16777215)||o!==this.length-1?c[6-l.length]+l+r:l+r,(i+=2)>=26&&(i-=26,o--)}for(0!==a&&(r=a.toString(16)+r);r.length%e!=0;)r=\"0\"+r;return 0!==this.negative&&(r=\"-\"+r),r}if(t===(0|t)&&t>=2&&t<=36){var h=u[t],p=f[t];r=\"\";var d=this.clone();for(d.negative=0;!d.isZero();){var m=d.modn(p).toString(t);r=(d=d.idivn(p)).isZero()?m+r:c[h-m.length]+m+r}for(this.isZero()&&(r=\"0\"+r);r.length%e!=0;)r=\"0\"+r;return 0!==this.negative&&(r=\"-\"+r),r}n(!1,\"Base should be between 2 and 36\")},a.prototype.toNumber=function(){var t=this.words[0];return 2===this.length?t+=67108864*this.words[1]:3===this.length&&1===this.words[2]?t+=4503599627370496+67108864*this.words[1]:this.length>2&&n(!1,\"Number can only safely store up to 53 bits\"),0!==this.negative?-t:t},a.prototype.toJSON=function(){return this.toString(16)},a.prototype.toBuffer=function(t,e){return n(void 0!==o),this.toArrayLike(o,t,e)},a.prototype.toArray=function(t,e){return this.toArrayLike(Array,t,e)},a.prototype.toArrayLike=function(t,e,r){var i=this.byteLength(),a=r||Math.max(1,i);n(i<=a,\"byte array longer than desired length\"),n(a>0,\"Requested array length <= 0\"),this.strip();var o,s,l=\"le\"===e,c=new t(a),u=this.clone();if(l){for(s=0;!u.isZero();s++)o=u.andln(255),u.iushrn(8),c[s]=o;for(;s<a;s++)c[s]=0}else{for(s=0;s<a-i;s++)c[s]=0;for(s=0;!u.isZero();s++)o=u.andln(255),u.iushrn(8),c[a-s-1]=o}return c},Math.clz32?a.prototype._countBits=function(t){return 32-Math.clz32(t)}:a.prototype._countBits=function(t){var e=t,r=0;return e>=4096&&(r+=13,e>>>=13),e>=64&&(r+=7,e>>>=7),e>=8&&(r+=4,e>>>=4),e>=2&&(r+=2,e>>>=2),r+e},a.prototype._zeroBits=function(t){if(0===t)return 26;var e=t,r=0;return 0==(8191&e)&&(r+=13,e>>>=13),0==(127&e)&&(r+=7,e>>>=7),0==(15&e)&&(r+=4,e>>>=4),0==(3&e)&&(r+=2,e>>>=2),0==(1&e)&&r++,r},a.prototype.bitLength=function(){var t=this.words[this.length-1],e=this._countBits(t);return 26*(this.length-1)+e},a.prototype.zeroBits=function(){if(this.isZero())return 0;for(var t=0,e=0;e<this.length;e++){var r=this._zeroBits(this.words[e]);if(t+=r,26!==r)break}return t},a.prototype.byteLength=function(){return Math.ceil(this.bitLength()/8)},a.prototype.toTwos=function(t){return 0!==this.negative?this.abs().inotn(t).iaddn(1):this.clone()},a.prototype.fromTwos=function(t){return this.testn(t-1)?this.notn(t).iaddn(1).ineg():this.clone()},a.prototype.isNeg=function(){return 0!==this.negative},a.prototype.neg=function(){return this.clone().ineg()},a.prototype.ineg=function(){return this.isZero()||(this.negative^=1),this},a.prototype.iuor=function(t){for(;this.length<t.length;)this.words[this.length++]=0;for(var e=0;e<t.length;e++)this.words[e]=this.words[e]|t.words[e];return this.strip()},a.prototype.ior=function(t){return n(0==(this.negative|t.negative)),this.iuor(t)},a.prototype.or=function(t){return this.length>t.length?this.clone().ior(t):t.clone().ior(this)},a.prototype.uor=function(t){return this.length>t.length?this.clone().iuor(t):t.clone().iuor(this)},a.prototype.iuand=function(t){var e;e=this.length>t.length?t:this;for(var r=0;r<e.length;r++)this.words[r]=this.words[r]&t.words[r];return this.length=e.length,this.strip()},a.prototype.iand=function(t){return n(0==(this.negative|t.negative)),this.iuand(t)},a.prototype.and=function(t){return this.length>t.length?this.clone().iand(t):t.clone().iand(this)},a.prototype.uand=function(t){return this.length>t.length?this.clone().iuand(t):t.clone().iuand(this)},a.prototype.iuxor=function(t){var e,r;this.length>t.length?(e=this,r=t):(e=t,r=this);for(var n=0;n<r.length;n++)this.words[n]=e.words[n]^r.words[n];if(this!==e)for(;n<e.length;n++)this.words[n]=e.words[n];return this.length=e.length,this.strip()},a.prototype.ixor=function(t){return n(0==(this.negative|t.negative)),this.iuxor(t)},a.prototype.xor=function(t){return this.length>t.length?this.clone().ixor(t):t.clone().ixor(this)},a.prototype.uxor=function(t){return this.length>t.length?this.clone().iuxor(t):t.clone().iuxor(this)},a.prototype.inotn=function(t){n(\"number\"==typeof t&&t>=0);var e=0|Math.ceil(t/26),r=t%26;this._expand(e),r>0&&e--;for(var i=0;i<e;i++)this.words[i]=67108863&~this.words[i];return r>0&&(this.words[i]=~this.words[i]&67108863>>26-r),this.strip()},a.prototype.notn=function(t){return this.clone().inotn(t)},a.prototype.setn=function(t,e){n(\"number\"==typeof t&&t>=0);var r=t/26|0,i=t%26;return this._expand(r+1),this.words[r]=e?this.words[r]|1<<i:this.words[r]&~(1<<i),this.strip()},a.prototype.iadd=function(t){var e,r,n;if(0!==this.negative&&0===t.negative)return this.negative=0,e=this.isub(t),this.negative^=1,this._normSign();if(0===this.negative&&0!==t.negative)return t.negative=0,e=this.isub(t),t.negative=1,e._normSign();this.length>t.length?(r=this,n=t):(r=t,n=this);for(var i=0,a=0;a<n.length;a++)e=(0|r.words[a])+(0|n.words[a])+i,this.words[a]=67108863&e,i=e>>>26;for(;0!==i&&a<r.length;a++)e=(0|r.words[a])+i,this.words[a]=67108863&e,i=e>>>26;if(this.length=r.length,0!==i)this.words[this.length]=i,this.length++;else if(r!==this)for(;a<r.length;a++)this.words[a]=r.words[a];return this},a.prototype.add=function(t){var e;return 0!==t.negative&&0===this.negative?(t.negative=0,e=this.sub(t),t.negative^=1,e):0===t.negative&&0!==this.negative?(this.negative=0,e=t.sub(this),this.negative=1,e):this.length>t.length?this.clone().iadd(t):t.clone().iadd(this)},a.prototype.isub=function(t){if(0!==t.negative){t.negative=0;var e=this.iadd(t);return t.negative=1,e._normSign()}if(0!==this.negative)return this.negative=0,this.iadd(t),this.negative=1,this._normSign();var r,n,i=this.cmp(t);if(0===i)return this.negative=0,this.length=1,this.words[0]=0,this;i>0?(r=this,n=t):(r=t,n=this);for(var a=0,o=0;o<n.length;o++)a=(e=(0|r.words[o])-(0|n.words[o])+a)>>26,this.words[o]=67108863&e;for(;0!==a&&o<r.length;o++)a=(e=(0|r.words[o])+a)>>26,this.words[o]=67108863&e;if(0===a&&o<r.length&&r!==this)for(;o<r.length;o++)this.words[o]=r.words[o];return this.length=Math.max(this.length,o),r!==this&&(this.negative=1),this.strip()},a.prototype.sub=function(t){return this.clone().isub(t)};var p=function(t,e,r){var n,i,a,o=t.words,s=e.words,l=r.words,c=0,u=0|o[0],f=8191&u,h=u>>>13,p=0|o[1],d=8191&p,m=p>>>13,g=0|o[2],v=8191&g,y=g>>>13,x=0|o[3],b=8191&x,_=x>>>13,w=0|o[4],T=8191&w,k=w>>>13,M=0|o[5],A=8191&M,S=M>>>13,E=0|o[6],L=8191&E,C=E>>>13,P=0|o[7],I=8191&P,O=P>>>13,z=0|o[8],D=8191&z,R=z>>>13,F=0|o[9],B=8191&F,N=F>>>13,j=0|s[0],U=8191&j,V=j>>>13,q=0|s[1],H=8191&q,G=q>>>13,Y=0|s[2],W=8191&Y,X=Y>>>13,Z=0|s[3],J=8191&Z,K=Z>>>13,Q=0|s[4],$=8191&Q,tt=Q>>>13,et=0|s[5],rt=8191&et,nt=et>>>13,it=0|s[6],at=8191&it,ot=it>>>13,st=0|s[7],lt=8191&st,ct=st>>>13,ut=0|s[8],ft=8191&ut,ht=ut>>>13,pt=0|s[9],dt=8191&pt,mt=pt>>>13;r.negative=t.negative^e.negative,r.length=19;var gt=(c+(n=Math.imul(f,U))|0)+((8191&(i=(i=Math.imul(f,V))+Math.imul(h,U)|0))<<13)|0;c=((a=Math.imul(h,V))+(i>>>13)|0)+(gt>>>26)|0,gt&=67108863,n=Math.imul(d,U),i=(i=Math.imul(d,V))+Math.imul(m,U)|0,a=Math.imul(m,V);var vt=(c+(n=n+Math.imul(f,H)|0)|0)+((8191&(i=(i=i+Math.imul(f,G)|0)+Math.imul(h,H)|0))<<13)|0;c=((a=a+Math.imul(h,G)|0)+(i>>>13)|0)+(vt>>>26)|0,vt&=67108863,n=Math.imul(v,U),i=(i=Math.imul(v,V))+Math.imul(y,U)|0,a=Math.imul(y,V),n=n+Math.imul(d,H)|0,i=(i=i+Math.imul(d,G)|0)+Math.imul(m,H)|0,a=a+Math.imul(m,G)|0;var yt=(c+(n=n+Math.imul(f,W)|0)|0)+((8191&(i=(i=i+Math.imul(f,X)|0)+Math.imul(h,W)|0))<<13)|0;c=((a=a+Math.imul(h,X)|0)+(i>>>13)|0)+(yt>>>26)|0,yt&=67108863,n=Math.imul(b,U),i=(i=Math.imul(b,V))+Math.imul(_,U)|0,a=Math.imul(_,V),n=n+Math.imul(v,H)|0,i=(i=i+Math.imul(v,G)|0)+Math.imul(y,H)|0,a=a+Math.imul(y,G)|0,n=n+Math.imul(d,W)|0,i=(i=i+Math.imul(d,X)|0)+Math.imul(m,W)|0,a=a+Math.imul(m,X)|0;var xt=(c+(n=n+Math.imul(f,J)|0)|0)+((8191&(i=(i=i+Math.imul(f,K)|0)+Math.imul(h,J)|0))<<13)|0;c=((a=a+Math.imul(h,K)|0)+(i>>>13)|0)+(xt>>>26)|0,xt&=67108863,n=Math.imul(T,U),i=(i=Math.imul(T,V))+Math.imul(k,U)|0,a=Math.imul(k,V),n=n+Math.imul(b,H)|0,i=(i=i+Math.imul(b,G)|0)+Math.imul(_,H)|0,a=a+Math.imul(_,G)|0,n=n+Math.imul(v,W)|0,i=(i=i+Math.imul(v,X)|0)+Math.imul(y,W)|0,a=a+Math.imul(y,X)|0,n=n+Math.imul(d,J)|0,i=(i=i+Math.imul(d,K)|0)+Math.imul(m,J)|0,a=a+Math.imul(m,K)|0;var bt=(c+(n=n+Math.imul(f,$)|0)|0)+((8191&(i=(i=i+Math.imul(f,tt)|0)+Math.imul(h,$)|0))<<13)|0;c=((a=a+Math.imul(h,tt)|0)+(i>>>13)|0)+(bt>>>26)|0,bt&=67108863,n=Math.imul(A,U),i=(i=Math.imul(A,V))+Math.imul(S,U)|0,a=Math.imul(S,V),n=n+Math.imul(T,H)|0,i=(i=i+Math.imul(T,G)|0)+Math.imul(k,H)|0,a=a+Math.imul(k,G)|0,n=n+Math.imul(b,W)|0,i=(i=i+Math.imul(b,X)|0)+Math.imul(_,W)|0,a=a+Math.imul(_,X)|0,n=n+Math.imul(v,J)|0,i=(i=i+Math.imul(v,K)|0)+Math.imul(y,J)|0,a=a+Math.imul(y,K)|0,n=n+Math.imul(d,$)|0,i=(i=i+Math.imul(d,tt)|0)+Math.imul(m,$)|0,a=a+Math.imul(m,tt)|0;var _t=(c+(n=n+Math.imul(f,rt)|0)|0)+((8191&(i=(i=i+Math.imul(f,nt)|0)+Math.imul(h,rt)|0))<<13)|0;c=((a=a+Math.imul(h,nt)|0)+(i>>>13)|0)+(_t>>>26)|0,_t&=67108863,n=Math.imul(L,U),i=(i=Math.imul(L,V))+Math.imul(C,U)|0,a=Math.imul(C,V),n=n+Math.imul(A,H)|0,i=(i=i+Math.imul(A,G)|0)+Math.imul(S,H)|0,a=a+Math.imul(S,G)|0,n=n+Math.imul(T,W)|0,i=(i=i+Math.imul(T,X)|0)+Math.imul(k,W)|0,a=a+Math.imul(k,X)|0,n=n+Math.imul(b,J)|0,i=(i=i+Math.imul(b,K)|0)+Math.imul(_,J)|0,a=a+Math.imul(_,K)|0,n=n+Math.imul(v,$)|0,i=(i=i+Math.imul(v,tt)|0)+Math.imul(y,$)|0,a=a+Math.imul(y,tt)|0,n=n+Math.imul(d,rt)|0,i=(i=i+Math.imul(d,nt)|0)+Math.imul(m,rt)|0,a=a+Math.imul(m,nt)|0;var wt=(c+(n=n+Math.imul(f,at)|0)|0)+((8191&(i=(i=i+Math.imul(f,ot)|0)+Math.imul(h,at)|0))<<13)|0;c=((a=a+Math.imul(h,ot)|0)+(i>>>13)|0)+(wt>>>26)|0,wt&=67108863,n=Math.imul(I,U),i=(i=Math.imul(I,V))+Math.imul(O,U)|0,a=Math.imul(O,V),n=n+Math.imul(L,H)|0,i=(i=i+Math.imul(L,G)|0)+Math.imul(C,H)|0,a=a+Math.imul(C,G)|0,n=n+Math.imul(A,W)|0,i=(i=i+Math.imul(A,X)|0)+Math.imul(S,W)|0,a=a+Math.imul(S,X)|0,n=n+Math.imul(T,J)|0,i=(i=i+Math.imul(T,K)|0)+Math.imul(k,J)|0,a=a+Math.imul(k,K)|0,n=n+Math.imul(b,$)|0,i=(i=i+Math.imul(b,tt)|0)+Math.imul(_,$)|0,a=a+Math.imul(_,tt)|0,n=n+Math.imul(v,rt)|0,i=(i=i+Math.imul(v,nt)|0)+Math.imul(y,rt)|0,a=a+Math.imul(y,nt)|0,n=n+Math.imul(d,at)|0,i=(i=i+Math.imul(d,ot)|0)+Math.imul(m,at)|0,a=a+Math.imul(m,ot)|0;var Tt=(c+(n=n+Math.imul(f,lt)|0)|0)+((8191&(i=(i=i+Math.imul(f,ct)|0)+Math.imul(h,lt)|0))<<13)|0;c=((a=a+Math.imul(h,ct)|0)+(i>>>13)|0)+(Tt>>>26)|0,Tt&=67108863,n=Math.imul(D,U),i=(i=Math.imul(D,V))+Math.imul(R,U)|0,a=Math.imul(R,V),n=n+Math.imul(I,H)|0,i=(i=i+Math.imul(I,G)|0)+Math.imul(O,H)|0,a=a+Math.imul(O,G)|0,n=n+Math.imul(L,W)|0,i=(i=i+Math.imul(L,X)|0)+Math.imul(C,W)|0,a=a+Math.imul(C,X)|0,n=n+Math.imul(A,J)|0,i=(i=i+Math.imul(A,K)|0)+Math.imul(S,J)|0,a=a+Math.imul(S,K)|0,n=n+Math.imul(T,$)|0,i=(i=i+Math.imul(T,tt)|0)+Math.imul(k,$)|0,a=a+Math.imul(k,tt)|0,n=n+Math.imul(b,rt)|0,i=(i=i+Math.imul(b,nt)|0)+Math.imul(_,rt)|0,a=a+Math.imul(_,nt)|0,n=n+Math.imul(v,at)|0,i=(i=i+Math.imul(v,ot)|0)+Math.imul(y,at)|0,a=a+Math.imul(y,ot)|0,n=n+Math.imul(d,lt)|0,i=(i=i+Math.imul(d,ct)|0)+Math.imul(m,lt)|0,a=a+Math.imul(m,ct)|0;var kt=(c+(n=n+Math.imul(f,ft)|0)|0)+((8191&(i=(i=i+Math.imul(f,ht)|0)+Math.imul(h,ft)|0))<<13)|0;c=((a=a+Math.imul(h,ht)|0)+(i>>>13)|0)+(kt>>>26)|0,kt&=67108863,n=Math.imul(B,U),i=(i=Math.imul(B,V))+Math.imul(N,U)|0,a=Math.imul(N,V),n=n+Math.imul(D,H)|0,i=(i=i+Math.imul(D,G)|0)+Math.imul(R,H)|0,a=a+Math.imul(R,G)|0,n=n+Math.imul(I,W)|0,i=(i=i+Math.imul(I,X)|0)+Math.imul(O,W)|0,a=a+Math.imul(O,X)|0,n=n+Math.imul(L,J)|0,i=(i=i+Math.imul(L,K)|0)+Math.imul(C,J)|0,a=a+Math.imul(C,K)|0,n=n+Math.imul(A,$)|0,i=(i=i+Math.imul(A,tt)|0)+Math.imul(S,$)|0,a=a+Math.imul(S,tt)|0,n=n+Math.imul(T,rt)|0,i=(i=i+Math.imul(T,nt)|0)+Math.imul(k,rt)|0,a=a+Math.imul(k,nt)|0,n=n+Math.imul(b,at)|0,i=(i=i+Math.imul(b,ot)|0)+Math.imul(_,at)|0,a=a+Math.imul(_,ot)|0,n=n+Math.imul(v,lt)|0,i=(i=i+Math.imul(v,ct)|0)+Math.imul(y,lt)|0,a=a+Math.imul(y,ct)|0,n=n+Math.imul(d,ft)|0,i=(i=i+Math.imul(d,ht)|0)+Math.imul(m,ft)|0,a=a+Math.imul(m,ht)|0;var Mt=(c+(n=n+Math.imul(f,dt)|0)|0)+((8191&(i=(i=i+Math.imul(f,mt)|0)+Math.imul(h,dt)|0))<<13)|0;c=((a=a+Math.imul(h,mt)|0)+(i>>>13)|0)+(Mt>>>26)|0,Mt&=67108863,n=Math.imul(B,H),i=(i=Math.imul(B,G))+Math.imul(N,H)|0,a=Math.imul(N,G),n=n+Math.imul(D,W)|0,i=(i=i+Math.imul(D,X)|0)+Math.imul(R,W)|0,a=a+Math.imul(R,X)|0,n=n+Math.imul(I,J)|0,i=(i=i+Math.imul(I,K)|0)+Math.imul(O,J)|0,a=a+Math.imul(O,K)|0,n=n+Math.imul(L,$)|0,i=(i=i+Math.imul(L,tt)|0)+Math.imul(C,$)|0,a=a+Math.imul(C,tt)|0,n=n+Math.imul(A,rt)|0,i=(i=i+Math.imul(A,nt)|0)+Math.imul(S,rt)|0,a=a+Math.imul(S,nt)|0,n=n+Math.imul(T,at)|0,i=(i=i+Math.imul(T,ot)|0)+Math.imul(k,at)|0,a=a+Math.imul(k,ot)|0,n=n+Math.imul(b,lt)|0,i=(i=i+Math.imul(b,ct)|0)+Math.imul(_,lt)|0,a=a+Math.imul(_,ct)|0,n=n+Math.imul(v,ft)|0,i=(i=i+Math.imul(v,ht)|0)+Math.imul(y,ft)|0,a=a+Math.imul(y,ht)|0;var At=(c+(n=n+Math.imul(d,dt)|0)|0)+((8191&(i=(i=i+Math.imul(d,mt)|0)+Math.imul(m,dt)|0))<<13)|0;c=((a=a+Math.imul(m,mt)|0)+(i>>>13)|0)+(At>>>26)|0,At&=67108863,n=Math.imul(B,W),i=(i=Math.imul(B,X))+Math.imul(N,W)|0,a=Math.imul(N,X),n=n+Math.imul(D,J)|0,i=(i=i+Math.imul(D,K)|0)+Math.imul(R,J)|0,a=a+Math.imul(R,K)|0,n=n+Math.imul(I,$)|0,i=(i=i+Math.imul(I,tt)|0)+Math.imul(O,$)|0,a=a+Math.imul(O,tt)|0,n=n+Math.imul(L,rt)|0,i=(i=i+Math.imul(L,nt)|0)+Math.imul(C,rt)|0,a=a+Math.imul(C,nt)|0,n=n+Math.imul(A,at)|0,i=(i=i+Math.imul(A,ot)|0)+Math.imul(S,at)|0,a=a+Math.imul(S,ot)|0,n=n+Math.imul(T,lt)|0,i=(i=i+Math.imul(T,ct)|0)+Math.imul(k,lt)|0,a=a+Math.imul(k,ct)|0,n=n+Math.imul(b,ft)|0,i=(i=i+Math.imul(b,ht)|0)+Math.imul(_,ft)|0,a=a+Math.imul(_,ht)|0;var St=(c+(n=n+Math.imul(v,dt)|0)|0)+((8191&(i=(i=i+Math.imul(v,mt)|0)+Math.imul(y,dt)|0))<<13)|0;c=((a=a+Math.imul(y,mt)|0)+(i>>>13)|0)+(St>>>26)|0,St&=67108863,n=Math.imul(B,J),i=(i=Math.imul(B,K))+Math.imul(N,J)|0,a=Math.imul(N,K),n=n+Math.imul(D,$)|0,i=(i=i+Math.imul(D,tt)|0)+Math.imul(R,$)|0,a=a+Math.imul(R,tt)|0,n=n+Math.imul(I,rt)|0,i=(i=i+Math.imul(I,nt)|0)+Math.imul(O,rt)|0,a=a+Math.imul(O,nt)|0,n=n+Math.imul(L,at)|0,i=(i=i+Math.imul(L,ot)|0)+Math.imul(C,at)|0,a=a+Math.imul(C,ot)|0,n=n+Math.imul(A,lt)|0,i=(i=i+Math.imul(A,ct)|0)+Math.imul(S,lt)|0,a=a+Math.imul(S,ct)|0,n=n+Math.imul(T,ft)|0,i=(i=i+Math.imul(T,ht)|0)+Math.imul(k,ft)|0,a=a+Math.imul(k,ht)|0;var Et=(c+(n=n+Math.imul(b,dt)|0)|0)+((8191&(i=(i=i+Math.imul(b,mt)|0)+Math.imul(_,dt)|0))<<13)|0;c=((a=a+Math.imul(_,mt)|0)+(i>>>13)|0)+(Et>>>26)|0,Et&=67108863,n=Math.imul(B,$),i=(i=Math.imul(B,tt))+Math.imul(N,$)|0,a=Math.imul(N,tt),n=n+Math.imul(D,rt)|0,i=(i=i+Math.imul(D,nt)|0)+Math.imul(R,rt)|0,a=a+Math.imul(R,nt)|0,n=n+Math.imul(I,at)|0,i=(i=i+Math.imul(I,ot)|0)+Math.imul(O,at)|0,a=a+Math.imul(O,ot)|0,n=n+Math.imul(L,lt)|0,i=(i=i+Math.imul(L,ct)|0)+Math.imul(C,lt)|0,a=a+Math.imul(C,ct)|0,n=n+Math.imul(A,ft)|0,i=(i=i+Math.imul(A,ht)|0)+Math.imul(S,ft)|0,a=a+Math.imul(S,ht)|0;var Lt=(c+(n=n+Math.imul(T,dt)|0)|0)+((8191&(i=(i=i+Math.imul(T,mt)|0)+Math.imul(k,dt)|0))<<13)|0;c=((a=a+Math.imul(k,mt)|0)+(i>>>13)|0)+(Lt>>>26)|0,Lt&=67108863,n=Math.imul(B,rt),i=(i=Math.imul(B,nt))+Math.imul(N,rt)|0,a=Math.imul(N,nt),n=n+Math.imul(D,at)|0,i=(i=i+Math.imul(D,ot)|0)+Math.imul(R,at)|0,a=a+Math.imul(R,ot)|0,n=n+Math.imul(I,lt)|0,i=(i=i+Math.imul(I,ct)|0)+Math.imul(O,lt)|0,a=a+Math.imul(O,ct)|0,n=n+Math.imul(L,ft)|0,i=(i=i+Math.imul(L,ht)|0)+Math.imul(C,ft)|0,a=a+Math.imul(C,ht)|0;var Ct=(c+(n=n+Math.imul(A,dt)|0)|0)+((8191&(i=(i=i+Math.imul(A,mt)|0)+Math.imul(S,dt)|0))<<13)|0;c=((a=a+Math.imul(S,mt)|0)+(i>>>13)|0)+(Ct>>>26)|0,Ct&=67108863,n=Math.imul(B,at),i=(i=Math.imul(B,ot))+Math.imul(N,at)|0,a=Math.imul(N,ot),n=n+Math.imul(D,lt)|0,i=(i=i+Math.imul(D,ct)|0)+Math.imul(R,lt)|0,a=a+Math.imul(R,ct)|0,n=n+Math.imul(I,ft)|0,i=(i=i+Math.imul(I,ht)|0)+Math.imul(O,ft)|0,a=a+Math.imul(O,ht)|0;var Pt=(c+(n=n+Math.imul(L,dt)|0)|0)+((8191&(i=(i=i+Math.imul(L,mt)|0)+Math.imul(C,dt)|0))<<13)|0;c=((a=a+Math.imul(C,mt)|0)+(i>>>13)|0)+(Pt>>>26)|0,Pt&=67108863,n=Math.imul(B,lt),i=(i=Math.imul(B,ct))+Math.imul(N,lt)|0,a=Math.imul(N,ct),n=n+Math.imul(D,ft)|0,i=(i=i+Math.imul(D,ht)|0)+Math.imul(R,ft)|0,a=a+Math.imul(R,ht)|0;var It=(c+(n=n+Math.imul(I,dt)|0)|0)+((8191&(i=(i=i+Math.imul(I,mt)|0)+Math.imul(O,dt)|0))<<13)|0;c=((a=a+Math.imul(O,mt)|0)+(i>>>13)|0)+(It>>>26)|0,It&=67108863,n=Math.imul(B,ft),i=(i=Math.imul(B,ht))+Math.imul(N,ft)|0,a=Math.imul(N,ht);var Ot=(c+(n=n+Math.imul(D,dt)|0)|0)+((8191&(i=(i=i+Math.imul(D,mt)|0)+Math.imul(R,dt)|0))<<13)|0;c=((a=a+Math.imul(R,mt)|0)+(i>>>13)|0)+(Ot>>>26)|0,Ot&=67108863;var zt=(c+(n=Math.imul(B,dt))|0)+((8191&(i=(i=Math.imul(B,mt))+Math.imul(N,dt)|0))<<13)|0;return c=((a=Math.imul(N,mt))+(i>>>13)|0)+(zt>>>26)|0,zt&=67108863,l[0]=gt,l[1]=vt,l[2]=yt,l[3]=xt,l[4]=bt,l[5]=_t,l[6]=wt,l[7]=Tt,l[8]=kt,l[9]=Mt,l[10]=At,l[11]=St,l[12]=Et,l[13]=Lt,l[14]=Ct,l[15]=Pt,l[16]=It,l[17]=Ot,l[18]=zt,0!==c&&(l[19]=c,r.length++),r};function d(t,e,r){return(new m).mulp(t,e,r)}function m(t,e){this.x=t,this.y=e}Math.imul||(p=h),a.prototype.mulTo=function(t,e){var r=this.length+t.length;return 10===this.length&&10===t.length?p(this,t,e):r<63?h(this,t,e):r<1024?function(t,e,r){r.negative=e.negative^t.negative,r.length=t.length+e.length;for(var n=0,i=0,a=0;a<r.length-1;a++){var o=i;i=0;for(var s=67108863&n,l=Math.min(a,e.length-1),c=Math.max(0,a-t.length+1);c<=l;c++){var u=a-c,f=(0|t.words[u])*(0|e.words[c]),h=67108863&f;s=67108863&(h=h+s|0),i+=(o=(o=o+(f/67108864|0)|0)+(h>>>26)|0)>>>26,o&=67108863}r.words[a]=s,n=o,o=i}return 0!==n?r.words[a]=n:r.length--,r.strip()}(this,t,e):d(this,t,e)},m.prototype.makeRBT=function(t){for(var e=new Array(t),r=a.prototype._countBits(t)-1,n=0;n<t;n++)e[n]=this.revBin(n,r,t);return e},m.prototype.revBin=function(t,e,r){if(0===t||t===r-1)return t;for(var n=0,i=0;i<e;i++)n|=(1&t)<<e-i-1,t>>=1;return n},m.prototype.permute=function(t,e,r,n,i,a){for(var o=0;o<a;o++)n[o]=e[t[o]],i[o]=r[t[o]]},m.prototype.transform=function(t,e,r,n,i,a){this.permute(a,t,e,r,n,i);for(var o=1;o<i;o<<=1)for(var s=o<<1,l=Math.cos(2*Math.PI/s),c=Math.sin(2*Math.PI/s),u=0;u<i;u+=s)for(var f=l,h=c,p=0;p<o;p++){var d=r[u+p],m=n[u+p],g=r[u+p+o],v=n[u+p+o],y=f*g-h*v;v=f*v+h*g,g=y,r[u+p]=d+g,n[u+p]=m+v,r[u+p+o]=d-g,n[u+p+o]=m-v,p!==s&&(y=l*f-c*h,h=l*h+c*f,f=y)}},m.prototype.guessLen13b=function(t,e){var r=1|Math.max(e,t),n=1&r,i=0;for(r=r/2|0;r;r>>>=1)i++;return 1<<i+1+n},m.prototype.conjugate=function(t,e,r){if(!(r<=1))for(var n=0;n<r/2;n++){var i=t[n];t[n]=t[r-n-1],t[r-n-1]=i,i=e[n],e[n]=-e[r-n-1],e[r-n-1]=-i}},m.prototype.normalize13b=function(t,e){for(var r=0,n=0;n<e/2;n++){var i=8192*Math.round(t[2*n+1]/e)+Math.round(t[2*n]/e)+r;t[n]=67108863&i,r=i<67108864?0:i/67108864|0}return t},m.prototype.convert13b=function(t,e,r,i){for(var a=0,o=0;o<e;o++)a+=0|t[o],r[2*o]=8191&a,a>>>=13,r[2*o+1]=8191&a,a>>>=13;for(o=2*e;o<i;++o)r[o]=0;n(0===a),n(0==(-8192&a))},m.prototype.stub=function(t){for(var e=new Array(t),r=0;r<t;r++)e[r]=0;return e},m.prototype.mulp=function(t,e,r){var n=2*this.guessLen13b(t.length,e.length),i=this.makeRBT(n),a=this.stub(n),o=new Array(n),s=new Array(n),l=new Array(n),c=new Array(n),u=new Array(n),f=new Array(n),h=r.words;h.length=n,this.convert13b(t.words,t.length,o,n),this.convert13b(e.words,e.length,c,n),this.transform(o,a,s,l,n,i),this.transform(c,a,u,f,n,i);for(var p=0;p<n;p++){var d=s[p]*u[p]-l[p]*f[p];l[p]=s[p]*f[p]+l[p]*u[p],s[p]=d}return this.conjugate(s,l,n),this.transform(s,l,h,a,n,i),this.conjugate(h,a,n),this.normalize13b(h,n),r.negative=t.negative^e.negative,r.length=t.length+e.length,r.strip()},a.prototype.mul=function(t){var e=new a(null);return e.words=new Array(this.length+t.length),this.mulTo(t,e)},a.prototype.mulf=function(t){var e=new a(null);return e.words=new Array(this.length+t.length),d(this,t,e)},a.prototype.imul=function(t){return this.clone().mulTo(t,this)},a.prototype.imuln=function(t){n(\"number\"==typeof t),n(t<67108864);for(var e=0,r=0;r<this.length;r++){var i=(0|this.words[r])*t,a=(67108863&i)+(67108863&e);e>>=26,e+=i/67108864|0,e+=a>>>26,this.words[r]=67108863&a}return 0!==e&&(this.words[r]=e,this.length++),this},a.prototype.muln=function(t){return this.clone().imuln(t)},a.prototype.sqr=function(){return this.mul(this)},a.prototype.isqr=function(){return this.imul(this.clone())},a.prototype.pow=function(t){var e=function(t){for(var e=new Array(t.bitLength()),r=0;r<e.length;r++){var n=r/26|0,i=r%26;e[r]=(t.words[n]&1<<i)>>>i}return e}(t);if(0===e.length)return new a(1);for(var r=this,n=0;n<e.length&&0===e[n];n++,r=r.sqr());if(++n<e.length)for(var i=r.sqr();n<e.length;n++,i=i.sqr())0!==e[n]&&(r=r.mul(i));return r},a.prototype.iushln=function(t){n(\"number\"==typeof t&&t>=0);var e,r=t%26,i=(t-r)/26,a=67108863>>>26-r<<26-r;if(0!==r){var o=0;for(e=0;e<this.length;e++){var s=this.words[e]&a,l=(0|this.words[e])-s<<r;this.words[e]=l|o,o=s>>>26-r}o&&(this.words[e]=o,this.length++)}if(0!==i){for(e=this.length-1;e>=0;e--)this.words[e+i]=this.words[e];for(e=0;e<i;e++)this.words[e]=0;this.length+=i}return this.strip()},a.prototype.ishln=function(t){return n(0===this.negative),this.iushln(t)},a.prototype.iushrn=function(t,e,r){var i;n(\"number\"==typeof t&&t>=0),i=e?(e-e%26)/26:0;var a=t%26,o=Math.min((t-a)/26,this.length),s=67108863^67108863>>>a<<a,l=r;if(i-=o,i=Math.max(0,i),l){for(var c=0;c<o;c++)l.words[c]=this.words[c];l.length=o}if(0===o);else if(this.length>o)for(this.length-=o,c=0;c<this.length;c++)this.words[c]=this.words[c+o];else this.words[0]=0,this.length=1;var u=0;for(c=this.length-1;c>=0&&(0!==u||c>=i);c--){var f=0|this.words[c];this.words[c]=u<<26-a|f>>>a,u=f&s}return l&&0!==u&&(l.words[l.length++]=u),0===this.length&&(this.words[0]=0,this.length=1),this.strip()},a.prototype.ishrn=function(t,e,r){return n(0===this.negative),this.iushrn(t,e,r)},a.prototype.shln=function(t){return this.clone().ishln(t)},a.prototype.ushln=function(t){return this.clone().iushln(t)},a.prototype.shrn=function(t){return this.clone().ishrn(t)},a.prototype.ushrn=function(t){return this.clone().iushrn(t)},a.prototype.testn=function(t){n(\"number\"==typeof t&&t>=0);var e=t%26,r=(t-e)/26,i=1<<e;return!(this.length<=r)&&!!(this.words[r]&i)},a.prototype.imaskn=function(t){n(\"number\"==typeof t&&t>=0);var e=t%26,r=(t-e)/26;if(n(0===this.negative,\"imaskn works only with positive numbers\"),this.length<=r)return this;if(0!==e&&r++,this.length=Math.min(r,this.length),0!==e){var i=67108863^67108863>>>e<<e;this.words[this.length-1]&=i}return this.strip()},a.prototype.maskn=function(t){return this.clone().imaskn(t)},a.prototype.iaddn=function(t){return n(\"number\"==typeof t),n(t<67108864),t<0?this.isubn(-t):0!==this.negative?1===this.length&&(0|this.words[0])<t?(this.words[0]=t-(0|this.words[0]),this.negative=0,this):(this.negative=0,this.isubn(t),this.negative=1,this):this._iaddn(t)},a.prototype._iaddn=function(t){this.words[0]+=t;for(var e=0;e<this.length&&this.words[e]>=67108864;e++)this.words[e]-=67108864,e===this.length-1?this.words[e+1]=1:this.words[e+1]++;return this.length=Math.max(this.length,e+1),this},a.prototype.isubn=function(t){if(n(\"number\"==typeof t),n(t<67108864),t<0)return this.iaddn(-t);if(0!==this.negative)return this.negative=0,this.iaddn(t),this.negative=1,this;if(this.words[0]-=t,1===this.length&&this.words[0]<0)this.words[0]=-this.words[0],this.negative=1;else for(var e=0;e<this.length&&this.words[e]<0;e++)this.words[e]+=67108864,this.words[e+1]-=1;return this.strip()},a.prototype.addn=function(t){return this.clone().iaddn(t)},a.prototype.subn=function(t){return this.clone().isubn(t)},a.prototype.iabs=function(){return this.negative=0,this},a.prototype.abs=function(){return this.clone().iabs()},a.prototype._ishlnsubmul=function(t,e,r){var i,a,o=t.length+r;this._expand(o);var s=0;for(i=0;i<t.length;i++){a=(0|this.words[i+r])+s;var l=(0|t.words[i])*e;s=((a-=67108863&l)>>26)-(l/67108864|0),this.words[i+r]=67108863&a}for(;i<this.length-r;i++)s=(a=(0|this.words[i+r])+s)>>26,this.words[i+r]=67108863&a;if(0===s)return this.strip();for(n(-1===s),s=0,i=0;i<this.length;i++)s=(a=-(0|this.words[i])+s)>>26,this.words[i]=67108863&a;return this.negative=1,this.strip()},a.prototype._wordDiv=function(t,e){var r=(this.length,t.length),n=this.clone(),i=t,o=0|i.words[i.length-1];0!==(r=26-this._countBits(o))&&(i=i.ushln(r),n.iushln(r),o=0|i.words[i.length-1]);var s,l=n.length-i.length;if(\"mod\"!==e){(s=new a(null)).length=l+1,s.words=new Array(s.length);for(var c=0;c<s.length;c++)s.words[c]=0}var u=n.clone()._ishlnsubmul(i,1,l);0===u.negative&&(n=u,s&&(s.words[l]=1));for(var f=l-1;f>=0;f--){var h=67108864*(0|n.words[i.length+f])+(0|n.words[i.length+f-1]);for(h=Math.min(h/o|0,67108863),n._ishlnsubmul(i,h,f);0!==n.negative;)h--,n.negative=0,n._ishlnsubmul(i,1,f),n.isZero()||(n.negative^=1);s&&(s.words[f]=h)}return s&&s.strip(),n.strip(),\"div\"!==e&&0!==r&&n.iushrn(r),{div:s||null,mod:n}},a.prototype.divmod=function(t,e,r){return n(!t.isZero()),this.isZero()?{div:new a(0),mod:new a(0)}:0!==this.negative&&0===t.negative?(s=this.neg().divmod(t,e),\"mod\"!==e&&(i=s.div.neg()),\"div\"!==e&&(o=s.mod.neg(),r&&0!==o.negative&&o.iadd(t)),{div:i,mod:o}):0===this.negative&&0!==t.negative?(s=this.divmod(t.neg(),e),\"mod\"!==e&&(i=s.div.neg()),{div:i,mod:s.mod}):0!=(this.negative&t.negative)?(s=this.neg().divmod(t.neg(),e),\"div\"!==e&&(o=s.mod.neg(),r&&0!==o.negative&&o.isub(t)),{div:s.div,mod:o}):t.length>this.length||this.cmp(t)<0?{div:new a(0),mod:this}:1===t.length?\"div\"===e?{div:this.divn(t.words[0]),mod:null}:\"mod\"===e?{div:null,mod:new a(this.modn(t.words[0]))}:{div:this.divn(t.words[0]),mod:new a(this.modn(t.words[0]))}:this._wordDiv(t,e);var i,o,s},a.prototype.div=function(t){return this.divmod(t,\"div\",!1).div},a.prototype.mod=function(t){return this.divmod(t,\"mod\",!1).mod},a.prototype.umod=function(t){return this.divmod(t,\"mod\",!0).mod},a.prototype.divRound=function(t){var e=this.divmod(t);if(e.mod.isZero())return e.div;var r=0!==e.div.negative?e.mod.isub(t):e.mod,n=t.ushrn(1),i=t.andln(1),a=r.cmp(n);return a<0||1===i&&0===a?e.div:0!==e.div.negative?e.div.isubn(1):e.div.iaddn(1)},a.prototype.modn=function(t){n(t<=67108863);for(var e=(1<<26)%t,r=0,i=this.length-1;i>=0;i--)r=(e*r+(0|this.words[i]))%t;return r},a.prototype.idivn=function(t){n(t<=67108863);for(var e=0,r=this.length-1;r>=0;r--){var i=(0|this.words[r])+67108864*e;this.words[r]=i/t|0,e=i%t}return this.strip()},a.prototype.divn=function(t){return this.clone().idivn(t)},a.prototype.egcd=function(t){n(0===t.negative),n(!t.isZero());var e=this,r=t.clone();e=0!==e.negative?e.umod(t):e.clone();for(var i=new a(1),o=new a(0),s=new a(0),l=new a(1),c=0;e.isEven()&&r.isEven();)e.iushrn(1),r.iushrn(1),++c;for(var u=r.clone(),f=e.clone();!e.isZero();){for(var h=0,p=1;0==(e.words[0]&p)&&h<26;++h,p<<=1);if(h>0)for(e.iushrn(h);h-- >0;)(i.isOdd()||o.isOdd())&&(i.iadd(u),o.isub(f)),i.iushrn(1),o.iushrn(1);for(var d=0,m=1;0==(r.words[0]&m)&&d<26;++d,m<<=1);if(d>0)for(r.iushrn(d);d-- >0;)(s.isOdd()||l.isOdd())&&(s.iadd(u),l.isub(f)),s.iushrn(1),l.iushrn(1);e.cmp(r)>=0?(e.isub(r),i.isub(s),o.isub(l)):(r.isub(e),s.isub(i),l.isub(o))}return{a:s,b:l,gcd:r.iushln(c)}},a.prototype._invmp=function(t){n(0===t.negative),n(!t.isZero());var e=this,r=t.clone();e=0!==e.negative?e.umod(t):e.clone();for(var i,o=new a(1),s=new a(0),l=r.clone();e.cmpn(1)>0&&r.cmpn(1)>0;){for(var c=0,u=1;0==(e.words[0]&u)&&c<26;++c,u<<=1);if(c>0)for(e.iushrn(c);c-- >0;)o.isOdd()&&o.iadd(l),o.iushrn(1);for(var f=0,h=1;0==(r.words[0]&h)&&f<26;++f,h<<=1);if(f>0)for(r.iushrn(f);f-- >0;)s.isOdd()&&s.iadd(l),s.iushrn(1);e.cmp(r)>=0?(e.isub(r),o.isub(s)):(r.isub(e),s.isub(o))}return(i=0===e.cmpn(1)?o:s).cmpn(0)<0&&i.iadd(t),i},a.prototype.gcd=function(t){if(this.isZero())return t.abs();if(t.isZero())return this.abs();var e=this.clone(),r=t.clone();e.negative=0,r.negative=0;for(var n=0;e.isEven()&&r.isEven();n++)e.iushrn(1),r.iushrn(1);for(;;){for(;e.isEven();)e.iushrn(1);for(;r.isEven();)r.iushrn(1);var i=e.cmp(r);if(i<0){var a=e;e=r,r=a}else if(0===i||0===r.cmpn(1))break;e.isub(r)}return r.iushln(n)},a.prototype.invm=function(t){return this.egcd(t).a.umod(t)},a.prototype.isEven=function(){return 0==(1&this.words[0])},a.prototype.isOdd=function(){return 1==(1&this.words[0])},a.prototype.andln=function(t){return this.words[0]&t},a.prototype.bincn=function(t){n(\"number\"==typeof t);var e=t%26,r=(t-e)/26,i=1<<e;if(this.length<=r)return this._expand(r+1),this.words[r]|=i,this;for(var a=i,o=r;0!==a&&o<this.length;o++){var s=0|this.words[o];a=(s+=a)>>>26,s&=67108863,this.words[o]=s}return 0!==a&&(this.words[o]=a,this.length++),this},a.prototype.isZero=function(){return 1===this.length&&0===this.words[0]},a.prototype.cmpn=function(t){var e,r=t<0;if(0!==this.negative&&!r)return-1;if(0===this.negative&&r)return 1;if(this.strip(),this.length>1)e=1;else{r&&(t=-t),n(t<=67108863,\"Number is too big\");var i=0|this.words[0];e=i===t?0:i<t?-1:1}return 0!==this.negative?0|-e:e},a.prototype.cmp=function(t){if(0!==this.negative&&0===t.negative)return-1;if(0===this.negative&&0!==t.negative)return 1;var e=this.ucmp(t);return 0!==this.negative?0|-e:e},a.prototype.ucmp=function(t){if(this.length>t.length)return 1;if(this.length<t.length)return-1;for(var e=0,r=this.length-1;r>=0;r--){var n=0|this.words[r],i=0|t.words[r];if(n!==i){n<i?e=-1:n>i&&(e=1);break}}return e},a.prototype.gtn=function(t){return 1===this.cmpn(t)},a.prototype.gt=function(t){return 1===this.cmp(t)},a.prototype.gten=function(t){return this.cmpn(t)>=0},a.prototype.gte=function(t){return this.cmp(t)>=0},a.prototype.ltn=function(t){return-1===this.cmpn(t)},a.prototype.lt=function(t){return-1===this.cmp(t)},a.prototype.lten=function(t){return this.cmpn(t)<=0},a.prototype.lte=function(t){return this.cmp(t)<=0},a.prototype.eqn=function(t){return 0===this.cmpn(t)},a.prototype.eq=function(t){return 0===this.cmp(t)},a.red=function(t){return new w(t)},a.prototype.toRed=function(t){return n(!this.red,\"Already a number in reduction context\"),n(0===this.negative,\"red works only with positives\"),t.convertTo(this)._forceRed(t)},a.prototype.fromRed=function(){return n(this.red,\"fromRed works only with numbers in reduction context\"),this.red.convertFrom(this)},a.prototype._forceRed=function(t){return this.red=t,this},a.prototype.forceRed=function(t){return n(!this.red,\"Already a number in reduction context\"),this._forceRed(t)},a.prototype.redAdd=function(t){return n(this.red,\"redAdd works only with red numbers\"),this.red.add(this,t)},a.prototype.redIAdd=function(t){return n(this.red,\"redIAdd works only with red numbers\"),this.red.iadd(this,t)},a.prototype.redSub=function(t){return n(this.red,\"redSub works only with red numbers\"),this.red.sub(this,t)},a.prototype.redISub=function(t){return n(this.red,\"redISub works only with red numbers\"),this.red.isub(this,t)},a.prototype.redShl=function(t){return n(this.red,\"redShl works only with red numbers\"),this.red.shl(this,t)},a.prototype.redMul=function(t){return n(this.red,\"redMul works only with red numbers\"),this.red._verify2(this,t),this.red.mul(this,t)},a.prototype.redIMul=function(t){return n(this.red,\"redMul works only with red numbers\"),this.red._verify2(this,t),this.red.imul(this,t)},a.prototype.redSqr=function(){return n(this.red,\"redSqr works only with red numbers\"),this.red._verify1(this),this.red.sqr(this)},a.prototype.redISqr=function(){return n(this.red,\"redISqr works only with red numbers\"),this.red._verify1(this),this.red.isqr(this)},a.prototype.redSqrt=function(){return n(this.red,\"redSqrt works only with red numbers\"),this.red._verify1(this),this.red.sqrt(this)},a.prototype.redInvm=function(){return n(this.red,\"redInvm works only with red numbers\"),this.red._verify1(this),this.red.invm(this)},a.prototype.redNeg=function(){return n(this.red,\"redNeg works only with red numbers\"),this.red._verify1(this),this.red.neg(this)},a.prototype.redPow=function(t){return n(this.red&&!t.red,\"redPow(normalNum)\"),this.red._verify1(this),this.red.pow(this,t)};var g={k256:null,p224:null,p192:null,p25519:null};function v(t,e){this.name=t,this.p=new a(e,16),this.n=this.p.bitLength(),this.k=new a(1).iushln(this.n).isub(this.p),this.tmp=this._tmp()}function y(){v.call(this,\"k256\",\"ffffffff ffffffff ffffffff ffffffff ffffffff ffffffff fffffffe fffffc2f\")}function x(){v.call(this,\"p224\",\"ffffffff ffffffff ffffffff ffffffff 00000000 00000000 00000001\")}function b(){v.call(this,\"p192\",\"ffffffff ffffffff ffffffff fffffffe ffffffff ffffffff\")}function _(){v.call(this,\"25519\",\"7fffffffffffffff ffffffffffffffff ffffffffffffffff ffffffffffffffed\")}function w(t){if(\"string\"==typeof t){var e=a._prime(t);this.m=e.p,this.prime=e}else n(t.gtn(1),\"modulus must be greater than 1\"),this.m=t,this.prime=null}function T(t){w.call(this,t),this.shift=this.m.bitLength(),this.shift%26!=0&&(this.shift+=26-this.shift%26),this.r=new a(1).iushln(this.shift),this.r2=this.imod(this.r.sqr()),this.rinv=this.r._invmp(this.m),this.minv=this.rinv.mul(this.r).isubn(1).div(this.m),this.minv=this.minv.umod(this.r),this.minv=this.r.sub(this.minv)}v.prototype._tmp=function(){var t=new a(null);return t.words=new Array(Math.ceil(this.n/13)),t},v.prototype.ireduce=function(t){var e,r=t;do{this.split(r,this.tmp),e=(r=(r=this.imulK(r)).iadd(this.tmp)).bitLength()}while(e>this.n);var n=e<this.n?-1:r.ucmp(this.p);return 0===n?(r.words[0]=0,r.length=1):n>0?r.isub(this.p):r.strip(),r},v.prototype.split=function(t,e){t.iushrn(this.n,0,e)},v.prototype.imulK=function(t){return t.imul(this.k)},i(y,v),y.prototype.split=function(t,e){for(var r=Math.min(t.length,9),n=0;n<r;n++)e.words[n]=t.words[n];if(e.length=r,t.length<=9)return t.words[0]=0,void(t.length=1);var i=t.words[9];for(e.words[e.length++]=4194303&i,n=10;n<t.length;n++){var a=0|t.words[n];t.words[n-10]=(4194303&a)<<4|i>>>22,i=a}i>>>=22,t.words[n-10]=i,0===i&&t.length>10?t.length-=10:t.length-=9},y.prototype.imulK=function(t){t.words[t.length]=0,t.words[t.length+1]=0,t.length+=2;for(var e=0,r=0;r<t.length;r++){var n=0|t.words[r];e+=977*n,t.words[r]=67108863&e,e=64*n+(e/67108864|0)}return 0===t.words[t.length-1]&&(t.length--,0===t.words[t.length-1]&&t.length--),t},i(x,v),i(b,v),i(_,v),_.prototype.imulK=function(t){for(var e=0,r=0;r<t.length;r++){var n=19*(0|t.words[r])+e,i=67108863&n;n>>>=26,t.words[r]=i,e=n}return 0!==e&&(t.words[t.length++]=e),t},a._prime=function(t){if(g[t])return g[t];var e;if(\"k256\"===t)e=new y;else if(\"p224\"===t)e=new x;else if(\"p192\"===t)e=new b;else{if(\"p25519\"!==t)throw new Error(\"Unknown prime \"+t);e=new _}return g[t]=e,e},w.prototype._verify1=function(t){n(0===t.negative,\"red works only with positives\"),n(t.red,\"red works only with red numbers\")},w.prototype._verify2=function(t,e){n(0==(t.negative|e.negative),\"red works only with positives\"),n(t.red&&t.red===e.red,\"red works only with red numbers\")},w.prototype.imod=function(t){return this.prime?this.prime.ireduce(t)._forceRed(this):t.umod(this.m)._forceRed(this)},w.prototype.neg=function(t){return t.isZero()?t.clone():this.m.sub(t)._forceRed(this)},w.prototype.add=function(t,e){this._verify2(t,e);var r=t.add(e);return r.cmp(this.m)>=0&&r.isub(this.m),r._forceRed(this)},w.prototype.iadd=function(t,e){this._verify2(t,e);var r=t.iadd(e);return r.cmp(this.m)>=0&&r.isub(this.m),r},w.prototype.sub=function(t,e){this._verify2(t,e);var r=t.sub(e);return r.cmpn(0)<0&&r.iadd(this.m),r._forceRed(this)},w.prototype.isub=function(t,e){this._verify2(t,e);var r=t.isub(e);return r.cmpn(0)<0&&r.iadd(this.m),r},w.prototype.shl=function(t,e){return this._verify1(t),this.imod(t.ushln(e))},w.prototype.imul=function(t,e){return this._verify2(t,e),this.imod(t.imul(e))},w.prototype.mul=function(t,e){return this._verify2(t,e),this.imod(t.mul(e))},w.prototype.isqr=function(t){return this.imul(t,t.clone())},w.prototype.sqr=function(t){return this.mul(t,t)},w.prototype.sqrt=function(t){if(t.isZero())return t.clone();var e=this.m.andln(3);if(n(e%2==1),3===e){var r=this.m.add(new a(1)).iushrn(2);return this.pow(t,r)}for(var i=this.m.subn(1),o=0;!i.isZero()&&0===i.andln(1);)o++,i.iushrn(1);n(!i.isZero());var s=new a(1).toRed(this),l=s.redNeg(),c=this.m.subn(1).iushrn(1),u=this.m.bitLength();for(u=new a(2*u*u).toRed(this);0!==this.pow(u,c).cmp(l);)u.redIAdd(l);for(var f=this.pow(u,i),h=this.pow(t,i.addn(1).iushrn(1)),p=this.pow(t,i),d=o;0!==p.cmp(s);){for(var m=p,g=0;0!==m.cmp(s);g++)m=m.redSqr();n(g<d);var v=this.pow(f,new a(1).iushln(d-g-1));h=h.redMul(v),f=v.redSqr(),p=p.redMul(f),d=g}return h},w.prototype.invm=function(t){var e=t._invmp(this.m);return 0!==e.negative?(e.negative=0,this.imod(e).redNeg()):this.imod(e)},w.prototype.pow=function(t,e){if(e.isZero())return new a(1).toRed(this);if(0===e.cmpn(1))return t.clone();var r=new Array(16);r[0]=new a(1).toRed(this),r[1]=t;for(var n=2;n<r.length;n++)r[n]=this.mul(r[n-1],t);var i=r[0],o=0,s=0,l=e.bitLength()%26;for(0===l&&(l=26),n=e.length-1;n>=0;n--){for(var c=e.words[n],u=l-1;u>=0;u--){var f=c>>u&1;i!==r[0]&&(i=this.sqr(i)),0!==f||0!==o?(o<<=1,o|=f,(4===++s||0===n&&0===u)&&(i=this.mul(i,r[o]),s=0,o=0)):s=0}l=26}return i},w.prototype.convertTo=function(t){var e=t.umod(this.m);return e===t?e.clone():e},w.prototype.convertFrom=function(t){var e=t.clone();return e.red=null,e},a.mont=function(t){return new T(t)},i(T,w),T.prototype.convertTo=function(t){return this.imod(t.ushln(this.shift))},T.prototype.convertFrom=function(t){var e=this.imod(t.mul(this.rinv));return e.red=null,e},T.prototype.imul=function(t,e){if(t.isZero()||e.isZero())return t.words[0]=0,t.length=1,t;var r=t.imul(e),n=r.maskn(this.shift).mul(this.minv).imaskn(this.shift).mul(this.m),i=r.isub(n).iushrn(this.shift),a=i;return i.cmp(this.m)>=0?a=i.isub(this.m):i.cmpn(0)<0&&(a=i.iadd(this.m)),a._forceRed(this)},T.prototype.mul=function(t,e){if(t.isZero()||e.isZero())return new a(0)._forceRed(this);var r=t.mul(e),n=r.maskn(this.shift).mul(this.minv).imaskn(this.shift).mul(this.m),i=r.isub(n).iushrn(this.shift),o=i;return i.cmp(this.m)>=0?o=i.isub(this.m):i.cmpn(0)<0&&(o=i.iadd(this.m)),o._forceRed(this)},T.prototype.invm=function(t){return this.imod(t._invmp(this.m).mul(this.r2))._forceRed(this)}}(void 0===e||e,this)},{buffer:115}],107:[function(t,e,r){\"use strict\";e.exports=function(t){var e,r,n,i=t.length,a=0;for(e=0;e<i;++e)a+=t[e].length;var o=new Array(a),s=0;for(e=0;e<i;++e){var l=t[e],c=l.length;for(r=0;r<c;++r){var u=o[s++]=new Array(c-1),f=0;for(n=0;n<c;++n)n!==r&&(u[f++]=l[n]);if(1&r){var h=u[1];u[1]=u[0],u[0]=h}}}return o}},{}],108:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){switch(arguments.length){case 1:return f(t);case 2:return\"function\"==typeof e?c(t,t,e,!0):h(t,e);case 3:return c(t,e,r,!1);default:throw new Error(\"box-intersect: Invalid arguments\")}};var n,i=t(\"typedarray-pool\"),a=t(\"./lib/sweep\"),o=t(\"./lib/intersect\");function s(t,e){for(var r=0;r<t;++r)if(!(e[r]<=e[r+t]))return!0;return!1}function l(t,e,r,n){for(var i=0,a=0,o=0,l=t.length;o<l;++o){var c=t[o];if(!s(e,c)){for(var u=0;u<2*e;++u)r[i++]=c[u];n[a++]=o}}return a}function c(t,e,r,n){var s=t.length,c=e.length;if(!(s<=0||c<=0)){var u=t[0].length>>>1;if(!(u<=0)){var f,h=i.mallocDouble(2*u*s),p=i.mallocInt32(s);if((s=l(t,u,h,p))>0){if(1===u&&n)a.init(s),f=a.sweepComplete(u,r,0,s,h,p,0,s,h,p);else{var d=i.mallocDouble(2*u*c),m=i.mallocInt32(c);(c=l(e,u,d,m))>0&&(a.init(s+c),f=1===u?a.sweepBipartite(u,r,0,s,h,p,0,c,d,m):o(u,r,n,s,h,p,c,d,m),i.free(d),i.free(m))}i.free(h),i.free(p)}return f}}}function u(t,e){n.push([t,e])}function f(t){return n=[],c(t,t,u,!0),n}function h(t,e){return n=[],c(t,e,u,!1),n}},{\"./lib/intersect\":110,\"./lib/sweep\":114,\"typedarray-pool\":613}],109:[function(t,e,r){\"use strict\";var n=[\"d\",\"ax\",\"vv\",\"rs\",\"re\",\"rb\",\"ri\",\"bs\",\"be\",\"bb\",\"bi\"];function i(t){var e=\"bruteForce\"+(t?\"Full\":\"Partial\"),r=[],i=n.slice();t||i.splice(3,0,\"fp\");var a=[\"function \"+e+\"(\"+i.join()+\"){\"];function o(e,i){var o=function(t,e,r){var i=\"bruteForce\"+(t?\"Red\":\"Blue\")+(e?\"Flip\":\"\")+(r?\"Full\":\"\"),a=[\"function \",i,\"(\",n.join(),\"){\",\"var \",\"es\",\"=2*\",\"d\",\";\"],o=\"for(var i=rs,rp=es*rs;i<re;++i,rp+=es){var x0=rb[ax+rp],x1=rb[ax+rp+d],xi=ri[i];\",s=\"for(var j=bs,bp=es*bs;j<be;++j,bp+=es){var y0=bb[ax+bp],\"+(r?\"y1=bb[ax+bp+d],\":\"\")+\"yi=bi[j];\";return t?a.push(o,\"Q\",\":\",s):a.push(s,\"Q\",\":\",o),r?a.push(\"if(y1<x0||x1<y0)continue;\"):e?a.push(\"if(y0<=x0||x1<y0)continue;\"):a.push(\"if(y0<x0||x1<y0)continue;\"),a.push(\"for(var k=ax+1;k<d;++k){var r0=rb[k+rp],r1=rb[k+d+rp],b0=bb[k+bp],b1=bb[k+d+bp];if(r1<b0||b1<r0)continue Q;}var rv=vv(\"),e?a.push(\"yi,xi\"):a.push(\"xi,yi\"),a.push(\");if(rv!==void 0)return rv;}}}\"),{name:i,code:a.join(\"\")}}(e,i,t);r.push(o.code),a.push(\"return \"+o.name+\"(\"+n.join()+\");\")}a.push(\"if(re-rs>be-bs){\"),t?(o(!0,!1),a.push(\"}else{\"),o(!1,!1)):(a.push(\"if(fp){\"),o(!0,!0),a.push(\"}else{\"),o(!0,!1),a.push(\"}}else{if(fp){\"),o(!1,!0),a.push(\"}else{\"),o(!1,!1),a.push(\"}\")),a.push(\"}}return \"+e);var s=r.join(\"\")+a.join(\"\");return new Function(s)()}r.partial=i(!1),r.full=i(!0)},{}],110:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,a,u,w,T,k,M){!function(t,e){var r=8*i.log2(e+1)*(t+1)|0,a=i.nextPow2(6*r);v.length<a&&(n.free(v),v=n.mallocInt32(a));var o=i.nextPow2(2*r);y.length<o&&(n.free(y),y=n.mallocDouble(o))}(t,a+T);var A,S=0,E=2*t;x(S++,0,0,a,0,T,r?16:0,-1/0,1/0),r||x(S++,0,0,T,0,a,1,-1/0,1/0);for(;S>0;){var L=6*(S-=1),C=v[L],P=v[L+1],I=v[L+2],O=v[L+3],z=v[L+4],D=v[L+5],R=2*S,F=y[R],B=y[R+1],N=1&D,j=!!(16&D),U=u,V=w,q=k,H=M;if(N&&(U=k,V=M,q=u,H=w),!(2&D&&(I=p(t,C,P,I,U,V,B),P>=I)||4&D&&(P=d(t,C,P,I,U,V,F))>=I)){var G=I-P,Y=z-O;if(j){if(t*G*(G+Y)<1<<22){if(void 0!==(A=l.scanComplete(t,C,e,P,I,U,V,O,z,q,H)))return A;continue}}else{if(t*Math.min(G,Y)<128){if(void 0!==(A=o(t,C,e,N,P,I,U,V,O,z,q,H)))return A;continue}if(t*G*Y<1<<22){if(void 0!==(A=l.scanBipartite(t,C,e,N,P,I,U,V,O,z,q,H)))return A;continue}}var W=f(t,C,P,I,U,V,F,B);if(P<W)if(t*(W-P)<128){if(void 0!==(A=s(t,C+1,e,P,W,U,V,O,z,q,H)))return A}else if(C===t-2){if(void 0!==(A=N?l.sweepBipartite(t,e,O,z,q,H,P,W,U,V):l.sweepBipartite(t,e,P,W,U,V,O,z,q,H)))return A}else x(S++,C+1,P,W,O,z,N,-1/0,1/0),x(S++,C+1,O,z,P,W,1^N,-1/0,1/0);if(W<I){var X=c(t,C,O,z,q,H),Z=q[E*X+C],J=h(t,C,X,z,q,H,Z);if(J<z&&x(S++,C,W,I,J,z,(4|N)+(j?16:0),Z,B),O<X&&x(S++,C,W,I,O,X,(2|N)+(j?16:0),F,Z),X+1===J){if(void 0!==(A=j?_(t,C,e,W,I,U,V,X,q,H[X]):b(t,C,e,N,W,I,U,V,X,q,H[X])))return A}else if(X<J){var K;if(j){if(K=m(t,C,W,I,U,V,Z),W<K){var Q=h(t,C,W,K,U,V,Z);if(C===t-2){if(W<Q&&void 0!==(A=l.sweepComplete(t,e,W,Q,U,V,X,J,q,H)))return A;if(Q<K&&void 0!==(A=l.sweepBipartite(t,e,Q,K,U,V,X,J,q,H)))return A}else W<Q&&x(S++,C+1,W,Q,X,J,16,-1/0,1/0),Q<K&&(x(S++,C+1,Q,K,X,J,0,-1/0,1/0),x(S++,C+1,X,J,Q,K,1,-1/0,1/0))}}else K=N?g(t,C,W,I,U,V,Z):m(t,C,W,I,U,V,Z),W<K&&(C===t-2?A=N?l.sweepBipartite(t,e,X,J,q,H,W,K,U,V):l.sweepBipartite(t,e,W,K,U,V,X,J,q,H):(x(S++,C+1,W,K,X,J,N,-1/0,1/0),x(S++,C+1,X,J,W,K,1^N,-1/0,1/0)))}}}}};var n=t(\"typedarray-pool\"),i=t(\"bit-twiddle\"),a=t(\"./brute\"),o=a.partial,s=a.full,l=t(\"./sweep\"),c=t(\"./median\"),u=t(\"./partition\"),f=u(\"!(lo>=p0)&&!(p1>=hi)\",[\"p0\",\"p1\"]),h=u(\"lo===p0\",[\"p0\"]),p=u(\"lo<p0\",[\"p0\"]),d=u(\"hi<=p0\",[\"p0\"]),m=u(\"lo<=p0&&p0<=hi\",[\"p0\"]),g=u(\"lo<p0&&p0<=hi\",[\"p0\"]),v=n.mallocInt32(1024),y=n.mallocDouble(1024);function x(t,e,r,n,i,a,o,s,l){var c=6*t;v[c]=e,v[c+1]=r,v[c+2]=n,v[c+3]=i,v[c+4]=a,v[c+5]=o;var u=2*t;y[u]=s,y[u+1]=l}function b(t,e,r,n,i,a,o,s,l,c,u){var f=2*t,h=l*f,p=c[h+e];t:for(var d=i,m=i*f;d<a;++d,m+=f){var g=o[m+e],v=o[m+e+t];if(!(p<g||v<p)&&(!n||p!==g)){for(var y,x=s[d],b=e+1;b<t;++b){g=o[m+b],v=o[m+b+t];var _=c[h+b],w=c[h+b+t];if(v<_||w<g)continue t}if(void 0!==(y=n?r(u,x):r(x,u)))return y}}}function _(t,e,r,n,i,a,o,s,l,c){var u=2*t,f=s*u,h=l[f+e];t:for(var p=n,d=n*u;p<i;++p,d+=u){var m=o[p];if(m!==c){var g=a[d+e],v=a[d+e+t];if(!(h<g||v<h)){for(var y=e+1;y<t;++y){g=a[d+y],v=a[d+y+t];var x=l[f+y],b=l[f+y+t];if(v<x||b<g)continue t}var _=r(m,c);if(void 0!==_)return _}}}}},{\"./brute\":109,\"./median\":111,\"./partition\":112,\"./sweep\":114,\"bit-twiddle\":104,\"typedarray-pool\":613}],111:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,a,o,s){if(a<=r+1)return r;var l=r,c=a,u=a+r>>>1,f=2*t,h=u,p=o[f*u+e];for(;l<c;){if(c-l<8){i(t,e,l,c,o,s),p=o[f*u+e];break}var d=c-l,m=Math.random()*d+l|0,g=o[f*m+e],v=Math.random()*d+l|0,y=o[f*v+e],x=Math.random()*d+l|0,b=o[f*x+e];g<=y?b>=y?(h=v,p=y):g>=b?(h=m,p=g):(h=x,p=b):y>=b?(h=v,p=y):b>=g?(h=m,p=g):(h=x,p=b);for(var _=f*(c-1),w=f*h,T=0;T<f;++T,++_,++w){var k=o[_];o[_]=o[w],o[w]=k}var M=s[c-1];s[c-1]=s[h],s[h]=M,h=n(t,e,l,c-1,o,s,p);for(_=f*(c-1),w=f*h,T=0;T<f;++T,++_,++w){k=o[_];o[_]=o[w],o[w]=k}M=s[c-1];if(s[c-1]=s[h],s[h]=M,u<h){for(c=h-1;l<c&&o[f*(c-1)+e]===p;)c-=1;c+=1}else{if(!(h<u))break;for(l=h+1;l<c&&o[f*l+e]===p;)l+=1}}return n(t,e,r,u,o,s,o[f*u+e])};var n=t(\"./partition\")(\"lo<p0\",[\"p0\"]);function i(t,e,r,n,i,a){for(var o=2*t,s=o*(r+1)+e,l=r+1;l<n;++l,s+=o)for(var c=i[s],u=l,f=o*(l-1);u>r&&i[f+e]>c;--u,f-=o){for(var h=f,p=f+o,d=0;d<o;++d,++h,++p){var m=i[h];i[h]=i[p],i[p]=m}var g=a[u];a[u]=a[u-1],a[u-1]=g}}},{\"./partition\":112}],112:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=\"abcdef\".split(\"\").concat(e),n=[];t.indexOf(\"lo\")>=0&&n.push(\"lo=e[k+n]\");t.indexOf(\"hi\")>=0&&n.push(\"hi=e[k+o]\");return r.push(\"for(var j=2*a,k=j*c,l=k,m=c,n=b,o=a+b,p=c;d>p;++p,k+=j){var _;if($)if(m===p)m+=1,l+=j;else{for(var s=0;j>s;++s){var t=e[k+s];e[k+s]=e[l],e[l++]=t}var u=f[p];f[p]=f[m],f[m++]=u}}return m\".replace(\"_\",n.join()).replace(\"$\",t)),Function.apply(void 0,r)}},{}],113:[function(t,e,r){\"use strict\";e.exports=function(t,e){e<=128?n(0,e-1,t):function t(e,r,u){var f=(r-e+1)/6|0,h=e+f,p=r-f,d=e+r>>1,m=d-f,g=d+f,v=h,y=m,x=d,b=g,_=p,w=e+1,T=r-1,k=0;l(v,y,u)&&(k=v,v=y,y=k);l(b,_,u)&&(k=b,b=_,_=k);l(v,x,u)&&(k=v,v=x,x=k);l(y,x,u)&&(k=y,y=x,x=k);l(v,b,u)&&(k=v,v=b,b=k);l(x,b,u)&&(k=x,x=b,b=k);l(y,_,u)&&(k=y,y=_,_=k);l(y,x,u)&&(k=y,y=x,x=k);l(b,_,u)&&(k=b,b=_,_=k);for(var M=u[2*y],A=u[2*y+1],S=u[2*b],E=u[2*b+1],L=2*v,C=2*x,P=2*_,I=2*h,O=2*d,z=2*p,D=0;D<2;++D){var R=u[L+D],F=u[C+D],B=u[P+D];u[I+D]=R,u[O+D]=F,u[z+D]=B}a(m,e,u),a(g,r,u);for(var N=w;N<=T;++N)if(c(N,M,A,u))N!==w&&i(N,w,u),++w;else if(!c(N,S,E,u))for(;;){if(c(T,S,E,u)){c(T,M,A,u)?(o(N,w,T,u),++w,--T):(i(N,T,u),--T);break}if(--T<N)break}s(e,w-1,M,A,u),s(r,T+1,S,E,u),w-2-e<=32?n(e,w-2,u):t(e,w-2,u);r-(T+2)<=32?n(T+2,r,u):t(T+2,r,u);T-w<=32?n(w,T,u):t(w,T,u)}(0,e-1,t)};function n(t,e,r){for(var n=2*(t+1),i=t+1;i<=e;++i){for(var a=r[n++],o=r[n++],s=i,l=n-2;s-- >t;){var c=r[l-2],u=r[l-1];if(c<a)break;if(c===a&&u<o)break;r[l]=c,r[l+1]=u,l-=2}r[l]=a,r[l+1]=o}}function i(t,e,r){e*=2;var n=r[t*=2],i=r[t+1];r[t]=r[e],r[t+1]=r[e+1],r[e]=n,r[e+1]=i}function a(t,e,r){e*=2,r[t*=2]=r[e],r[t+1]=r[e+1]}function o(t,e,r,n){e*=2,r*=2;var i=n[t*=2],a=n[t+1];n[t]=n[e],n[t+1]=n[e+1],n[e]=n[r],n[e+1]=n[r+1],n[r]=i,n[r+1]=a}function s(t,e,r,n,i){e*=2,i[t*=2]=i[e],i[e]=r,i[t+1]=i[e+1],i[e+1]=n}function l(t,e,r){e*=2;var n=r[t*=2],i=r[e];return!(n<i)&&(n!==i||r[t+1]>r[e+1])}function c(t,e,r,n){var i=n[t*=2];return i<e||i===e&&n[t+1]<r}},{}],114:[function(t,e,r){\"use strict\";e.exports={init:function(t){var e=i.nextPow2(t);o.length<e&&(n.free(o),o=n.mallocInt32(e));s.length<e&&(n.free(s),s=n.mallocInt32(e));l.length<e&&(n.free(l),l=n.mallocInt32(e));c.length<e&&(n.free(c),c=n.mallocInt32(e));u.length<e&&(n.free(u),u=n.mallocInt32(e));f.length<e&&(n.free(f),f=n.mallocInt32(e));var r=8*e;h.length<r&&(n.free(h),h=n.mallocDouble(r))},sweepBipartite:function(t,e,r,n,i,u,f,m,g,v){for(var y=0,x=2*t,b=t-1,_=x-1,w=r;w<n;++w){var T=u[w],k=x*w;h[y++]=i[k+b],h[y++]=-(T+1),h[y++]=i[k+_],h[y++]=T}for(w=f;w<m;++w){T=v[w]+(1<<28);var M=x*w;h[y++]=g[M+b],h[y++]=-T,h[y++]=g[M+_],h[y++]=T}var A=y>>>1;a(h,A);var S=0,E=0;for(w=0;w<A;++w){var L=0|h[2*w+1];if(L>=1<<28)p(l,c,E--,L=L-(1<<28)|0);else if(L>=0)p(o,s,S--,L);else if(L<=-(1<<28)){L=-L-(1<<28)|0;for(var C=0;C<S;++C){if(void 0!==(P=e(o[C],L)))return P}d(l,c,E++,L)}else{L=-L-1|0;for(C=0;C<E;++C){var P;if(void 0!==(P=e(L,l[C])))return P}d(o,s,S++,L)}}},sweepComplete:function(t,e,r,n,i,m,g,v,y,x){for(var b=0,_=2*t,w=t-1,T=_-1,k=r;k<n;++k){var M=m[k]+1<<1,A=_*k;h[b++]=i[A+w],h[b++]=-M,h[b++]=i[A+T],h[b++]=M}for(k=g;k<v;++k){M=x[k]+1<<1;var S=_*k;h[b++]=y[S+w],h[b++]=1|-M,h[b++]=y[S+T],h[b++]=1|M}var E=b>>>1;a(h,E);var L=0,C=0,P=0;for(k=0;k<E;++k){var I=0|h[2*k+1],O=1&I;if(k<E-1&&I>>1==h[2*k+3]>>1&&(O=2,k+=1),I<0){for(var z=-(I>>1)-1,D=0;D<P;++D){if(void 0!==(R=e(u[D],z)))return R}if(0!==O)for(D=0;D<L;++D){if(void 0!==(R=e(o[D],z)))return R}if(1!==O)for(D=0;D<C;++D){var R;if(void 0!==(R=e(l[D],z)))return R}0===O?d(o,s,L++,z):1===O?d(l,c,C++,z):2===O&&d(u,f,P++,z)}else{z=(I>>1)-1;0===O?p(o,s,L--,z):1===O?p(l,c,C--,z):2===O&&p(u,f,P--,z)}}},scanBipartite:function(t,e,r,n,i,l,c,u,f,m,g,v){var y=0,x=2*t,b=e,_=e+t,w=1,T=1;n?T=1<<28:w=1<<28;for(var k=i;k<l;++k){var M=k+w,A=x*k;h[y++]=c[A+b],h[y++]=-M,h[y++]=c[A+_],h[y++]=M}for(k=f;k<m;++k){M=k+T;var S=x*k;h[y++]=g[S+b],h[y++]=-M}var E=y>>>1;a(h,E);var L=0;for(k=0;k<E;++k){var C=0|h[2*k+1];if(C<0){var P=!1;if((M=-C)>=1<<28?(P=!n,M-=1<<28):(P=!!n,M-=1),P)d(o,s,L++,M);else{var I=v[M],O=x*M,z=g[O+e+1],D=g[O+e+1+t];t:for(var R=0;R<L;++R){var F=o[R],B=x*F;if(!(D<c[B+e+1]||c[B+e+1+t]<z)){for(var N=e+2;N<t;++N)if(g[O+N+t]<c[B+N]||c[B+N+t]<g[O+N])continue t;var j,U=u[F];if(void 0!==(j=n?r(I,U):r(U,I)))return j}}}}else p(o,s,L--,C-w)}},scanComplete:function(t,e,r,n,i,s,l,c,u,f,p){for(var d=0,m=2*t,g=e,v=e+t,y=n;y<i;++y){var x=y+(1<<28),b=m*y;h[d++]=s[b+g],h[d++]=-x,h[d++]=s[b+v],h[d++]=x}for(y=c;y<u;++y){x=y+1;var _=m*y;h[d++]=f[_+g],h[d++]=-x}var w=d>>>1;a(h,w);var T=0;for(y=0;y<w;++y){var k=0|h[2*y+1];if(k<0){if((x=-k)>=1<<28)o[T++]=x-(1<<28);else{var M=p[x-=1],A=m*x,S=f[A+e+1],E=f[A+e+1+t];t:for(var L=0;L<T;++L){var C=o[L],P=l[C];if(P===M)break;var I=m*C;if(!(E<s[I+e+1]||s[I+e+1+t]<S)){for(var O=e+2;O<t;++O)if(f[A+O+t]<s[I+O]||s[I+O+t]<f[A+O])continue t;var z=r(P,M);if(void 0!==z)return z}}}}else{for(x=k-(1<<28),L=T-1;L>=0;--L)if(o[L]===x){for(O=L+1;O<T;++O)o[O-1]=o[O];break}--T}}}};var n=t(\"typedarray-pool\"),i=t(\"bit-twiddle\"),a=t(\"./sort\"),o=n.mallocInt32(1024),s=n.mallocInt32(1024),l=n.mallocInt32(1024),c=n.mallocInt32(1024),u=n.mallocInt32(1024),f=n.mallocInt32(1024),h=n.mallocDouble(8192);function p(t,e,r,n){var i=e[n],a=t[r-1];t[i]=a,e[a]=i}function d(t,e,r,n){t[r]=n,e[n]=r}},{\"./sort\":113,\"bit-twiddle\":104,\"typedarray-pool\":613}],115:[function(t,e,r){},{}],116:[function(t,e,r){\"use strict\";var n,i=\"object\"==typeof Reflect?Reflect:null,a=i&&\"function\"==typeof i.apply?i.apply:function(t,e,r){return Function.prototype.apply.call(t,e,r)};n=i&&\"function\"==typeof i.ownKeys?i.ownKeys:Object.getOwnPropertySymbols?function(t){return Object.getOwnPropertyNames(t).concat(Object.getOwnPropertySymbols(t))}:function(t){return Object.getOwnPropertyNames(t)};var o=Number.isNaN||function(t){return t!=t};function s(){s.init.call(this)}e.exports=s,e.exports.once=function(t,e){return new Promise((function(r,n){function i(){void 0!==a&&t.removeListener(\"error\",a),r([].slice.call(arguments))}var a;\"error\"!==e&&(a=function(r){t.removeListener(e,i),n(r)},t.once(\"error\",a)),t.once(e,i)}))},s.EventEmitter=s,s.prototype._events=void 0,s.prototype._eventsCount=0,s.prototype._maxListeners=void 0;var l=10;function c(t){if(\"function\"!=typeof t)throw new TypeError('The \"listener\" argument must be of type Function. Received type '+typeof t)}function u(t){return void 0===t._maxListeners?s.defaultMaxListeners:t._maxListeners}function f(t,e,r,n){var i,a,o,s;if(c(r),void 0===(a=t._events)?(a=t._events=Object.create(null),t._eventsCount=0):(void 0!==a.newListener&&(t.emit(\"newListener\",e,r.listener?r.listener:r),a=t._events),o=a[e]),void 0===o)o=a[e]=r,++t._eventsCount;else if(\"function\"==typeof o?o=a[e]=n?[r,o]:[o,r]:n?o.unshift(r):o.push(r),(i=u(t))>0&&o.length>i&&!o.warned){o.warned=!0;var l=new Error(\"Possible EventEmitter memory leak detected. \"+o.length+\" \"+String(e)+\" listeners added. Use emitter.setMaxListeners() to increase limit\");l.name=\"MaxListenersExceededWarning\",l.emitter=t,l.type=e,l.count=o.length,s=l,console&&console.warn&&console.warn(s)}return t}function h(){if(!this.fired)return this.target.removeListener(this.type,this.wrapFn),this.fired=!0,0===arguments.length?this.listener.call(this.target):this.listener.apply(this.target,arguments)}function p(t,e,r){var n={fired:!1,wrapFn:void 0,target:t,type:e,listener:r},i=h.bind(n);return i.listener=r,n.wrapFn=i,i}function d(t,e,r){var n=t._events;if(void 0===n)return[];var i=n[e];return void 0===i?[]:\"function\"==typeof i?r?[i.listener||i]:[i]:r?function(t){for(var e=new Array(t.length),r=0;r<e.length;++r)e[r]=t[r].listener||t[r];return e}(i):g(i,i.length)}function m(t){var e=this._events;if(void 0!==e){var r=e[t];if(\"function\"==typeof r)return 1;if(void 0!==r)return r.length}return 0}function g(t,e){for(var r=new Array(e),n=0;n<e;++n)r[n]=t[n];return r}Object.defineProperty(s,\"defaultMaxListeners\",{enumerable:!0,get:function(){return l},set:function(t){if(\"number\"!=typeof t||t<0||o(t))throw new RangeError('The value of \"defaultMaxListeners\" is out of range. It must be a non-negative number. Received '+t+\".\");l=t}}),s.init=function(){void 0!==this._events&&this._events!==Object.getPrototypeOf(this)._events||(this._events=Object.create(null),this._eventsCount=0),this._maxListeners=this._maxListeners||void 0},s.prototype.setMaxListeners=function(t){if(\"number\"!=typeof t||t<0||o(t))throw new RangeError('The value of \"n\" is out of range. It must be a non-negative number. Received '+t+\".\");return this._maxListeners=t,this},s.prototype.getMaxListeners=function(){return u(this)},s.prototype.emit=function(t){for(var e=[],r=1;r<arguments.length;r++)e.push(arguments[r]);var n=\"error\"===t,i=this._events;if(void 0!==i)n=n&&void 0===i.error;else if(!n)return!1;if(n){var o;if(e.length>0&&(o=e[0]),o instanceof Error)throw o;var s=new Error(\"Unhandled error.\"+(o?\" (\"+o.message+\")\":\"\"));throw s.context=o,s}var l=i[t];if(void 0===l)return!1;if(\"function\"==typeof l)a(l,this,e);else{var c=l.length,u=g(l,c);for(r=0;r<c;++r)a(u[r],this,e)}return!0},s.prototype.addListener=function(t,e){return f(this,t,e,!1)},s.prototype.on=s.prototype.addListener,s.prototype.prependListener=function(t,e){return f(this,t,e,!0)},s.prototype.once=function(t,e){return c(e),this.on(t,p(this,t,e)),this},s.prototype.prependOnceListener=function(t,e){return c(e),this.prependListener(t,p(this,t,e)),this},s.prototype.removeListener=function(t,e){var r,n,i,a,o;if(c(e),void 0===(n=this._events))return this;if(void 0===(r=n[t]))return this;if(r===e||r.listener===e)0==--this._eventsCount?this._events=Object.create(null):(delete n[t],n.removeListener&&this.emit(\"removeListener\",t,r.listener||e));else if(\"function\"!=typeof r){for(i=-1,a=r.length-1;a>=0;a--)if(r[a]===e||r[a].listener===e){o=r[a].listener,i=a;break}if(i<0)return this;0===i?r.shift():function(t,e){for(;e+1<t.length;e++)t[e]=t[e+1];t.pop()}(r,i),1===r.length&&(n[t]=r[0]),void 0!==n.removeListener&&this.emit(\"removeListener\",t,o||e)}return this},s.prototype.off=s.prototype.removeListener,s.prototype.removeAllListeners=function(t){var e,r,n;if(void 0===(r=this._events))return this;if(void 0===r.removeListener)return 0===arguments.length?(this._events=Object.create(null),this._eventsCount=0):void 0!==r[t]&&(0==--this._eventsCount?this._events=Object.create(null):delete r[t]),this;if(0===arguments.length){var i,a=Object.keys(r);for(n=0;n<a.length;++n)\"removeListener\"!==(i=a[n])&&this.removeAllListeners(i);return this.removeAllListeners(\"removeListener\"),this._events=Object.create(null),this._eventsCount=0,this}if(\"function\"==typeof(e=r[t]))this.removeListener(t,e);else if(void 0!==e)for(n=e.length-1;n>=0;n--)this.removeListener(t,e[n]);return this},s.prototype.listeners=function(t){return d(this,t,!0)},s.prototype.rawListeners=function(t){return d(this,t,!1)},s.listenerCount=function(t,e){return\"function\"==typeof t.listenerCount?t.listenerCount(e):m.call(t,e)},s.prototype.listenerCount=m,s.prototype.eventNames=function(){return this._eventsCount>0?n(this._events):[]}},{}],117:[function(t,e,r){(function(e){(function(){\n",
       "/*!\n",
       " * The buffer module from node.js, for the browser.\n",
       " *\n",
       " * @author   Feross Aboukhadijeh <https://feross.org>\n",
       " * @license  MIT\n",
       " */\n",
       "\"use strict\";var e=t(\"base64-js\"),n=t(\"ieee754\");r.Buffer=a,r.SlowBuffer=function(t){+t!=t&&(t=0);return a.alloc(+t)},r.INSPECT_MAX_BYTES=50;function i(t){if(t>2147483647)throw new RangeError('The value \"'+t+'\" is invalid for option \"size\"');var e=new Uint8Array(t);return e.__proto__=a.prototype,e}function a(t,e,r){if(\"number\"==typeof t){if(\"string\"==typeof e)throw new TypeError('The \"string\" argument must be of type string. Received type number');return l(t)}return o(t,e,r)}function o(t,e,r){if(\"string\"==typeof t)return function(t,e){\"string\"==typeof e&&\"\"!==e||(e=\"utf8\");if(!a.isEncoding(e))throw new TypeError(\"Unknown encoding: \"+e);var r=0|f(t,e),n=i(r),o=n.write(t,e);o!==r&&(n=n.slice(0,o));return n}(t,e);if(ArrayBuffer.isView(t))return c(t);if(null==t)throw TypeError(\"The first argument must be one of type string, Buffer, ArrayBuffer, Array, or Array-like Object. Received type \"+typeof t);if(B(t,ArrayBuffer)||t&&B(t.buffer,ArrayBuffer))return function(t,e,r){if(e<0||t.byteLength<e)throw new RangeError('\"offset\" is outside of buffer bounds');if(t.byteLength<e+(r||0))throw new RangeError('\"length\" is outside of buffer bounds');var n;n=void 0===e&&void 0===r?new Uint8Array(t):void 0===r?new Uint8Array(t,e):new Uint8Array(t,e,r);return n.__proto__=a.prototype,n}(t,e,r);if(\"number\"==typeof t)throw new TypeError('The \"value\" argument must not be of type number. Received type number');var n=t.valueOf&&t.valueOf();if(null!=n&&n!==t)return a.from(n,e,r);var o=function(t){if(a.isBuffer(t)){var e=0|u(t.length),r=i(e);return 0===r.length||t.copy(r,0,0,e),r}if(void 0!==t.length)return\"number\"!=typeof t.length||N(t.length)?i(0):c(t);if(\"Buffer\"===t.type&&Array.isArray(t.data))return c(t.data)}(t);if(o)return o;if(\"undefined\"!=typeof Symbol&&null!=Symbol.toPrimitive&&\"function\"==typeof t[Symbol.toPrimitive])return a.from(t[Symbol.toPrimitive](\"string\"),e,r);throw new TypeError(\"The first argument must be one of type string, Buffer, ArrayBuffer, Array, or Array-like Object. Received type \"+typeof t)}function s(t){if(\"number\"!=typeof t)throw new TypeError('\"size\" argument must be of type number');if(t<0)throw new RangeError('The value \"'+t+'\" is invalid for option \"size\"')}function l(t){return s(t),i(t<0?0:0|u(t))}function c(t){for(var e=t.length<0?0:0|u(t.length),r=i(e),n=0;n<e;n+=1)r[n]=255&t[n];return r}function u(t){if(t>=2147483647)throw new RangeError(\"Attempt to allocate Buffer larger than maximum size: 0x\"+2147483647..toString(16)+\" bytes\");return 0|t}function f(t,e){if(a.isBuffer(t))return t.length;if(ArrayBuffer.isView(t)||B(t,ArrayBuffer))return t.byteLength;if(\"string\"!=typeof t)throw new TypeError('The \"string\" argument must be one of type string, Buffer, or ArrayBuffer. Received type '+typeof t);var r=t.length,n=arguments.length>2&&!0===arguments[2];if(!n&&0===r)return 0;for(var i=!1;;)switch(e){case\"ascii\":case\"latin1\":case\"binary\":return r;case\"utf8\":case\"utf-8\":return D(t).length;case\"ucs2\":case\"ucs-2\":case\"utf16le\":case\"utf-16le\":return 2*r;case\"hex\":return r>>>1;case\"base64\":return R(t).length;default:if(i)return n?-1:D(t).length;e=(\"\"+e).toLowerCase(),i=!0}}function h(t,e,r){var n=!1;if((void 0===e||e<0)&&(e=0),e>this.length)return\"\";if((void 0===r||r>this.length)&&(r=this.length),r<=0)return\"\";if((r>>>=0)<=(e>>>=0))return\"\";for(t||(t=\"utf8\");;)switch(t){case\"hex\":return A(this,e,r);case\"utf8\":case\"utf-8\":return T(this,e,r);case\"ascii\":return k(this,e,r);case\"latin1\":case\"binary\":return M(this,e,r);case\"base64\":return w(this,e,r);case\"ucs2\":case\"ucs-2\":case\"utf16le\":case\"utf-16le\":return S(this,e,r);default:if(n)throw new TypeError(\"Unknown encoding: \"+t);t=(t+\"\").toLowerCase(),n=!0}}function p(t,e,r){var n=t[e];t[e]=t[r],t[r]=n}function d(t,e,r,n,i){if(0===t.length)return-1;if(\"string\"==typeof r?(n=r,r=0):r>2147483647?r=2147483647:r<-2147483648&&(r=-2147483648),N(r=+r)&&(r=i?0:t.length-1),r<0&&(r=t.length+r),r>=t.length){if(i)return-1;r=t.length-1}else if(r<0){if(!i)return-1;r=0}if(\"string\"==typeof e&&(e=a.from(e,n)),a.isBuffer(e))return 0===e.length?-1:m(t,e,r,n,i);if(\"number\"==typeof e)return e&=255,\"function\"==typeof Uint8Array.prototype.indexOf?i?Uint8Array.prototype.indexOf.call(t,e,r):Uint8Array.prototype.lastIndexOf.call(t,e,r):m(t,[e],r,n,i);throw new TypeError(\"val must be string, number or Buffer\")}function m(t,e,r,n,i){var a,o=1,s=t.length,l=e.length;if(void 0!==n&&(\"ucs2\"===(n=String(n).toLowerCase())||\"ucs-2\"===n||\"utf16le\"===n||\"utf-16le\"===n)){if(t.length<2||e.length<2)return-1;o=2,s/=2,l/=2,r/=2}function c(t,e){return 1===o?t[e]:t.readUInt16BE(e*o)}if(i){var u=-1;for(a=r;a<s;a++)if(c(t,a)===c(e,-1===u?0:a-u)){if(-1===u&&(u=a),a-u+1===l)return u*o}else-1!==u&&(a-=a-u),u=-1}else for(r+l>s&&(r=s-l),a=r;a>=0;a--){for(var f=!0,h=0;h<l;h++)if(c(t,a+h)!==c(e,h)){f=!1;break}if(f)return a}return-1}function g(t,e,r,n){r=Number(r)||0;var i=t.length-r;n?(n=Number(n))>i&&(n=i):n=i;var a=e.length;n>a/2&&(n=a/2);for(var o=0;o<n;++o){var s=parseInt(e.substr(2*o,2),16);if(N(s))return o;t[r+o]=s}return o}function v(t,e,r,n){return F(D(e,t.length-r),t,r,n)}function y(t,e,r,n){return F(function(t){for(var e=[],r=0;r<t.length;++r)e.push(255&t.charCodeAt(r));return e}(e),t,r,n)}function x(t,e,r,n){return y(t,e,r,n)}function b(t,e,r,n){return F(R(e),t,r,n)}function _(t,e,r,n){return F(function(t,e){for(var r,n,i,a=[],o=0;o<t.length&&!((e-=2)<0);++o)r=t.charCodeAt(o),n=r>>8,i=r%256,a.push(i),a.push(n);return a}(e,t.length-r),t,r,n)}function w(t,r,n){return 0===r&&n===t.length?e.fromByteArray(t):e.fromByteArray(t.slice(r,n))}function T(t,e,r){r=Math.min(t.length,r);for(var n=[],i=e;i<r;){var a,o,s,l,c=t[i],u=null,f=c>239?4:c>223?3:c>191?2:1;if(i+f<=r)switch(f){case 1:c<128&&(u=c);break;case 2:128==(192&(a=t[i+1]))&&(l=(31&c)<<6|63&a)>127&&(u=l);break;case 3:a=t[i+1],o=t[i+2],128==(192&a)&&128==(192&o)&&(l=(15&c)<<12|(63&a)<<6|63&o)>2047&&(l<55296||l>57343)&&(u=l);break;case 4:a=t[i+1],o=t[i+2],s=t[i+3],128==(192&a)&&128==(192&o)&&128==(192&s)&&(l=(15&c)<<18|(63&a)<<12|(63&o)<<6|63&s)>65535&&l<1114112&&(u=l)}null===u?(u=65533,f=1):u>65535&&(u-=65536,n.push(u>>>10&1023|55296),u=56320|1023&u),n.push(u),i+=f}return function(t){var e=t.length;if(e<=4096)return String.fromCharCode.apply(String,t);var r=\"\",n=0;for(;n<e;)r+=String.fromCharCode.apply(String,t.slice(n,n+=4096));return r}(n)}r.kMaxLength=2147483647,a.TYPED_ARRAY_SUPPORT=function(){try{var t=new Uint8Array(1);return t.__proto__={__proto__:Uint8Array.prototype,foo:function(){return 42}},42===t.foo()}catch(t){return!1}}(),a.TYPED_ARRAY_SUPPORT||\"undefined\"==typeof console||\"function\"!=typeof console.error||console.error(\"This browser lacks typed array (Uint8Array) support which is required by `buffer` v5.x. Use `buffer` v4.x if you require old browser support.\"),Object.defineProperty(a.prototype,\"parent\",{enumerable:!0,get:function(){if(a.isBuffer(this))return this.buffer}}),Object.defineProperty(a.prototype,\"offset\",{enumerable:!0,get:function(){if(a.isBuffer(this))return this.byteOffset}}),\"undefined\"!=typeof Symbol&&null!=Symbol.species&&a[Symbol.species]===a&&Object.defineProperty(a,Symbol.species,{value:null,configurable:!0,enumerable:!1,writable:!1}),a.poolSize=8192,a.from=function(t,e,r){return o(t,e,r)},a.prototype.__proto__=Uint8Array.prototype,a.__proto__=Uint8Array,a.alloc=function(t,e,r){return function(t,e,r){return s(t),t<=0?i(t):void 0!==e?\"string\"==typeof r?i(t).fill(e,r):i(t).fill(e):i(t)}(t,e,r)},a.allocUnsafe=function(t){return l(t)},a.allocUnsafeSlow=function(t){return l(t)},a.isBuffer=function(t){return null!=t&&!0===t._isBuffer&&t!==a.prototype},a.compare=function(t,e){if(B(t,Uint8Array)&&(t=a.from(t,t.offset,t.byteLength)),B(e,Uint8Array)&&(e=a.from(e,e.offset,e.byteLength)),!a.isBuffer(t)||!a.isBuffer(e))throw new TypeError('The \"buf1\", \"buf2\" arguments must be one of type Buffer or Uint8Array');if(t===e)return 0;for(var r=t.length,n=e.length,i=0,o=Math.min(r,n);i<o;++i)if(t[i]!==e[i]){r=t[i],n=e[i];break}return r<n?-1:n<r?1:0},a.isEncoding=function(t){switch(String(t).toLowerCase()){case\"hex\":case\"utf8\":case\"utf-8\":case\"ascii\":case\"latin1\":case\"binary\":case\"base64\":case\"ucs2\":case\"ucs-2\":case\"utf16le\":case\"utf-16le\":return!0;default:return!1}},a.concat=function(t,e){if(!Array.isArray(t))throw new TypeError('\"list\" argument must be an Array of Buffers');if(0===t.length)return a.alloc(0);var r;if(void 0===e)for(e=0,r=0;r<t.length;++r)e+=t[r].length;var n=a.allocUnsafe(e),i=0;for(r=0;r<t.length;++r){var o=t[r];if(B(o,Uint8Array)&&(o=a.from(o)),!a.isBuffer(o))throw new TypeError('\"list\" argument must be an Array of Buffers');o.copy(n,i),i+=o.length}return n},a.byteLength=f,a.prototype._isBuffer=!0,a.prototype.swap16=function(){var t=this.length;if(t%2!=0)throw new RangeError(\"Buffer size must be a multiple of 16-bits\");for(var e=0;e<t;e+=2)p(this,e,e+1);return this},a.prototype.swap32=function(){var t=this.length;if(t%4!=0)throw new RangeError(\"Buffer size must be a multiple of 32-bits\");for(var e=0;e<t;e+=4)p(this,e,e+3),p(this,e+1,e+2);return this},a.prototype.swap64=function(){var t=this.length;if(t%8!=0)throw new RangeError(\"Buffer size must be a multiple of 64-bits\");for(var e=0;e<t;e+=8)p(this,e,e+7),p(this,e+1,e+6),p(this,e+2,e+5),p(this,e+3,e+4);return this},a.prototype.toString=function(){var t=this.length;return 0===t?\"\":0===arguments.length?T(this,0,t):h.apply(this,arguments)},a.prototype.toLocaleString=a.prototype.toString,a.prototype.equals=function(t){if(!a.isBuffer(t))throw new TypeError(\"Argument must be a Buffer\");return this===t||0===a.compare(this,t)},a.prototype.inspect=function(){var t=\"\",e=r.INSPECT_MAX_BYTES;return t=this.toString(\"hex\",0,e).replace(/(.{2})/g,\"$1 \").trim(),this.length>e&&(t+=\" ... \"),\"<Buffer \"+t+\">\"},a.prototype.compare=function(t,e,r,n,i){if(B(t,Uint8Array)&&(t=a.from(t,t.offset,t.byteLength)),!a.isBuffer(t))throw new TypeError('The \"target\" argument must be one of type Buffer or Uint8Array. Received type '+typeof t);if(void 0===e&&(e=0),void 0===r&&(r=t?t.length:0),void 0===n&&(n=0),void 0===i&&(i=this.length),e<0||r>t.length||n<0||i>this.length)throw new RangeError(\"out of range index\");if(n>=i&&e>=r)return 0;if(n>=i)return-1;if(e>=r)return 1;if(this===t)return 0;for(var o=(i>>>=0)-(n>>>=0),s=(r>>>=0)-(e>>>=0),l=Math.min(o,s),c=this.slice(n,i),u=t.slice(e,r),f=0;f<l;++f)if(c[f]!==u[f]){o=c[f],s=u[f];break}return o<s?-1:s<o?1:0},a.prototype.includes=function(t,e,r){return-1!==this.indexOf(t,e,r)},a.prototype.indexOf=function(t,e,r){return d(this,t,e,r,!0)},a.prototype.lastIndexOf=function(t,e,r){return d(this,t,e,r,!1)},a.prototype.write=function(t,e,r,n){if(void 0===e)n=\"utf8\",r=this.length,e=0;else if(void 0===r&&\"string\"==typeof e)n=e,r=this.length,e=0;else{if(!isFinite(e))throw new Error(\"Buffer.write(string, encoding, offset[, length]) is no longer supported\");e>>>=0,isFinite(r)?(r>>>=0,void 0===n&&(n=\"utf8\")):(n=r,r=void 0)}var i=this.length-e;if((void 0===r||r>i)&&(r=i),t.length>0&&(r<0||e<0)||e>this.length)throw new RangeError(\"Attempt to write outside buffer bounds\");n||(n=\"utf8\");for(var a=!1;;)switch(n){case\"hex\":return g(this,t,e,r);case\"utf8\":case\"utf-8\":return v(this,t,e,r);case\"ascii\":return y(this,t,e,r);case\"latin1\":case\"binary\":return x(this,t,e,r);case\"base64\":return b(this,t,e,r);case\"ucs2\":case\"ucs-2\":case\"utf16le\":case\"utf-16le\":return _(this,t,e,r);default:if(a)throw new TypeError(\"Unknown encoding: \"+n);n=(\"\"+n).toLowerCase(),a=!0}},a.prototype.toJSON=function(){return{type:\"Buffer\",data:Array.prototype.slice.call(this._arr||this,0)}};function k(t,e,r){var n=\"\";r=Math.min(t.length,r);for(var i=e;i<r;++i)n+=String.fromCharCode(127&t[i]);return n}function M(t,e,r){var n=\"\";r=Math.min(t.length,r);for(var i=e;i<r;++i)n+=String.fromCharCode(t[i]);return n}function A(t,e,r){var n=t.length;(!e||e<0)&&(e=0),(!r||r<0||r>n)&&(r=n);for(var i=\"\",a=e;a<r;++a)i+=z(t[a]);return i}function S(t,e,r){for(var n=t.slice(e,r),i=\"\",a=0;a<n.length;a+=2)i+=String.fromCharCode(n[a]+256*n[a+1]);return i}function E(t,e,r){if(t%1!=0||t<0)throw new RangeError(\"offset is not uint\");if(t+e>r)throw new RangeError(\"Trying to access beyond buffer length\")}function L(t,e,r,n,i,o){if(!a.isBuffer(t))throw new TypeError('\"buffer\" argument must be a Buffer instance');if(e>i||e<o)throw new RangeError('\"value\" argument is out of bounds');if(r+n>t.length)throw new RangeError(\"Index out of range\")}function C(t,e,r,n,i,a){if(r+n>t.length)throw new RangeError(\"Index out of range\");if(r<0)throw new RangeError(\"Index out of range\")}function P(t,e,r,i,a){return e=+e,r>>>=0,a||C(t,0,r,4),n.write(t,e,r,i,23,4),r+4}function I(t,e,r,i,a){return e=+e,r>>>=0,a||C(t,0,r,8),n.write(t,e,r,i,52,8),r+8}a.prototype.slice=function(t,e){var r=this.length;(t=~~t)<0?(t+=r)<0&&(t=0):t>r&&(t=r),(e=void 0===e?r:~~e)<0?(e+=r)<0&&(e=0):e>r&&(e=r),e<t&&(e=t);var n=this.subarray(t,e);return n.__proto__=a.prototype,n},a.prototype.readUIntLE=function(t,e,r){t>>>=0,e>>>=0,r||E(t,e,this.length);for(var n=this[t],i=1,a=0;++a<e&&(i*=256);)n+=this[t+a]*i;return n},a.prototype.readUIntBE=function(t,e,r){t>>>=0,e>>>=0,r||E(t,e,this.length);for(var n=this[t+--e],i=1;e>0&&(i*=256);)n+=this[t+--e]*i;return n},a.prototype.readUInt8=function(t,e){return t>>>=0,e||E(t,1,this.length),this[t]},a.prototype.readUInt16LE=function(t,e){return t>>>=0,e||E(t,2,this.length),this[t]|this[t+1]<<8},a.prototype.readUInt16BE=function(t,e){return t>>>=0,e||E(t,2,this.length),this[t]<<8|this[t+1]},a.prototype.readUInt32LE=function(t,e){return t>>>=0,e||E(t,4,this.length),(this[t]|this[t+1]<<8|this[t+2]<<16)+16777216*this[t+3]},a.prototype.readUInt32BE=function(t,e){return t>>>=0,e||E(t,4,this.length),16777216*this[t]+(this[t+1]<<16|this[t+2]<<8|this[t+3])},a.prototype.readIntLE=function(t,e,r){t>>>=0,e>>>=0,r||E(t,e,this.length);for(var n=this[t],i=1,a=0;++a<e&&(i*=256);)n+=this[t+a]*i;return n>=(i*=128)&&(n-=Math.pow(2,8*e)),n},a.prototype.readIntBE=function(t,e,r){t>>>=0,e>>>=0,r||E(t,e,this.length);for(var n=e,i=1,a=this[t+--n];n>0&&(i*=256);)a+=this[t+--n]*i;return a>=(i*=128)&&(a-=Math.pow(2,8*e)),a},a.prototype.readInt8=function(t,e){return t>>>=0,e||E(t,1,this.length),128&this[t]?-1*(255-this[t]+1):this[t]},a.prototype.readInt16LE=function(t,e){t>>>=0,e||E(t,2,this.length);var r=this[t]|this[t+1]<<8;return 32768&r?4294901760|r:r},a.prototype.readInt16BE=function(t,e){t>>>=0,e||E(t,2,this.length);var r=this[t+1]|this[t]<<8;return 32768&r?4294901760|r:r},a.prototype.readInt32LE=function(t,e){return t>>>=0,e||E(t,4,this.length),this[t]|this[t+1]<<8|this[t+2]<<16|this[t+3]<<24},a.prototype.readInt32BE=function(t,e){return t>>>=0,e||E(t,4,this.length),this[t]<<24|this[t+1]<<16|this[t+2]<<8|this[t+3]},a.prototype.readFloatLE=function(t,e){return t>>>=0,e||E(t,4,this.length),n.read(this,t,!0,23,4)},a.prototype.readFloatBE=function(t,e){return t>>>=0,e||E(t,4,this.length),n.read(this,t,!1,23,4)},a.prototype.readDoubleLE=function(t,e){return t>>>=0,e||E(t,8,this.length),n.read(this,t,!0,52,8)},a.prototype.readDoubleBE=function(t,e){return t>>>=0,e||E(t,8,this.length),n.read(this,t,!1,52,8)},a.prototype.writeUIntLE=function(t,e,r,n){(t=+t,e>>>=0,r>>>=0,n)||L(this,t,e,r,Math.pow(2,8*r)-1,0);var i=1,a=0;for(this[e]=255&t;++a<r&&(i*=256);)this[e+a]=t/i&255;return e+r},a.prototype.writeUIntBE=function(t,e,r,n){(t=+t,e>>>=0,r>>>=0,n)||L(this,t,e,r,Math.pow(2,8*r)-1,0);var i=r-1,a=1;for(this[e+i]=255&t;--i>=0&&(a*=256);)this[e+i]=t/a&255;return e+r},a.prototype.writeUInt8=function(t,e,r){return t=+t,e>>>=0,r||L(this,t,e,1,255,0),this[e]=255&t,e+1},a.prototype.writeUInt16LE=function(t,e,r){return t=+t,e>>>=0,r||L(this,t,e,2,65535,0),this[e]=255&t,this[e+1]=t>>>8,e+2},a.prototype.writeUInt16BE=function(t,e,r){return t=+t,e>>>=0,r||L(this,t,e,2,65535,0),this[e]=t>>>8,this[e+1]=255&t,e+2},a.prototype.writeUInt32LE=function(t,e,r){return t=+t,e>>>=0,r||L(this,t,e,4,4294967295,0),this[e+3]=t>>>24,this[e+2]=t>>>16,this[e+1]=t>>>8,this[e]=255&t,e+4},a.prototype.writeUInt32BE=function(t,e,r){return t=+t,e>>>=0,r||L(this,t,e,4,4294967295,0),this[e]=t>>>24,this[e+1]=t>>>16,this[e+2]=t>>>8,this[e+3]=255&t,e+4},a.prototype.writeIntLE=function(t,e,r,n){if(t=+t,e>>>=0,!n){var i=Math.pow(2,8*r-1);L(this,t,e,r,i-1,-i)}var a=0,o=1,s=0;for(this[e]=255&t;++a<r&&(o*=256);)t<0&&0===s&&0!==this[e+a-1]&&(s=1),this[e+a]=(t/o>>0)-s&255;return e+r},a.prototype.writeIntBE=function(t,e,r,n){if(t=+t,e>>>=0,!n){var i=Math.pow(2,8*r-1);L(this,t,e,r,i-1,-i)}var a=r-1,o=1,s=0;for(this[e+a]=255&t;--a>=0&&(o*=256);)t<0&&0===s&&0!==this[e+a+1]&&(s=1),this[e+a]=(t/o>>0)-s&255;return e+r},a.prototype.writeInt8=function(t,e,r){return t=+t,e>>>=0,r||L(this,t,e,1,127,-128),t<0&&(t=255+t+1),this[e]=255&t,e+1},a.prototype.writeInt16LE=function(t,e,r){return t=+t,e>>>=0,r||L(this,t,e,2,32767,-32768),this[e]=255&t,this[e+1]=t>>>8,e+2},a.prototype.writeInt16BE=function(t,e,r){return t=+t,e>>>=0,r||L(this,t,e,2,32767,-32768),this[e]=t>>>8,this[e+1]=255&t,e+2},a.prototype.writeInt32LE=function(t,e,r){return t=+t,e>>>=0,r||L(this,t,e,4,2147483647,-2147483648),this[e]=255&t,this[e+1]=t>>>8,this[e+2]=t>>>16,this[e+3]=t>>>24,e+4},a.prototype.writeInt32BE=function(t,e,r){return t=+t,e>>>=0,r||L(this,t,e,4,2147483647,-2147483648),t<0&&(t=4294967295+t+1),this[e]=t>>>24,this[e+1]=t>>>16,this[e+2]=t>>>8,this[e+3]=255&t,e+4},a.prototype.writeFloatLE=function(t,e,r){return P(this,t,e,!0,r)},a.prototype.writeFloatBE=function(t,e,r){return P(this,t,e,!1,r)},a.prototype.writeDoubleLE=function(t,e,r){return I(this,t,e,!0,r)},a.prototype.writeDoubleBE=function(t,e,r){return I(this,t,e,!1,r)},a.prototype.copy=function(t,e,r,n){if(!a.isBuffer(t))throw new TypeError(\"argument should be a Buffer\");if(r||(r=0),n||0===n||(n=this.length),e>=t.length&&(e=t.length),e||(e=0),n>0&&n<r&&(n=r),n===r)return 0;if(0===t.length||0===this.length)return 0;if(e<0)throw new RangeError(\"targetStart out of bounds\");if(r<0||r>=this.length)throw new RangeError(\"Index out of range\");if(n<0)throw new RangeError(\"sourceEnd out of bounds\");n>this.length&&(n=this.length),t.length-e<n-r&&(n=t.length-e+r);var i=n-r;if(this===t&&\"function\"==typeof Uint8Array.prototype.copyWithin)this.copyWithin(e,r,n);else if(this===t&&r<e&&e<n)for(var o=i-1;o>=0;--o)t[o+e]=this[o+r];else Uint8Array.prototype.set.call(t,this.subarray(r,n),e);return i},a.prototype.fill=function(t,e,r,n){if(\"string\"==typeof t){if(\"string\"==typeof e?(n=e,e=0,r=this.length):\"string\"==typeof r&&(n=r,r=this.length),void 0!==n&&\"string\"!=typeof n)throw new TypeError(\"encoding must be a string\");if(\"string\"==typeof n&&!a.isEncoding(n))throw new TypeError(\"Unknown encoding: \"+n);if(1===t.length){var i=t.charCodeAt(0);(\"utf8\"===n&&i<128||\"latin1\"===n)&&(t=i)}}else\"number\"==typeof t&&(t&=255);if(e<0||this.length<e||this.length<r)throw new RangeError(\"Out of range index\");if(r<=e)return this;var o;if(e>>>=0,r=void 0===r?this.length:r>>>0,t||(t=0),\"number\"==typeof t)for(o=e;o<r;++o)this[o]=t;else{var s=a.isBuffer(t)?t:a.from(t,n),l=s.length;if(0===l)throw new TypeError('The value \"'+t+'\" is invalid for argument \"value\"');for(o=0;o<r-e;++o)this[o+e]=s[o%l]}return this};var O=/[^+/0-9A-Za-z-_]/g;function z(t){return t<16?\"0\"+t.toString(16):t.toString(16)}function D(t,e){var r;e=e||1/0;for(var n=t.length,i=null,a=[],o=0;o<n;++o){if((r=t.charCodeAt(o))>55295&&r<57344){if(!i){if(r>56319){(e-=3)>-1&&a.push(239,191,189);continue}if(o+1===n){(e-=3)>-1&&a.push(239,191,189);continue}i=r;continue}if(r<56320){(e-=3)>-1&&a.push(239,191,189),i=r;continue}r=65536+(i-55296<<10|r-56320)}else i&&(e-=3)>-1&&a.push(239,191,189);if(i=null,r<128){if((e-=1)<0)break;a.push(r)}else if(r<2048){if((e-=2)<0)break;a.push(r>>6|192,63&r|128)}else if(r<65536){if((e-=3)<0)break;a.push(r>>12|224,r>>6&63|128,63&r|128)}else{if(!(r<1114112))throw new Error(\"Invalid code point\");if((e-=4)<0)break;a.push(r>>18|240,r>>12&63|128,r>>6&63|128,63&r|128)}}return a}function R(t){return e.toByteArray(function(t){if((t=(t=t.split(\"=\")[0]).trim().replace(O,\"\")).length<2)return\"\";for(;t.length%4!=0;)t+=\"=\";return t}(t))}function F(t,e,r,n){for(var i=0;i<n&&!(i+r>=e.length||i>=t.length);++i)e[i+r]=t[i];return i}function B(t,e){return t instanceof e||null!=t&&null!=t.constructor&&null!=t.constructor.name&&t.constructor.name===e.name}function N(t){return t!=t}}).call(this)}).call(this,t(\"buffer\").Buffer)},{\"base64-js\":86,buffer:117,ieee754:441}],118:[function(t,e,r){\"use strict\";var n=t(\"./lib/monotone\"),i=t(\"./lib/triangulation\"),a=t(\"./lib/delaunay\"),o=t(\"./lib/filter\");function s(t){return[Math.min(t[0],t[1]),Math.max(t[0],t[1])]}function l(t,e){return t[0]-e[0]||t[1]-e[1]}function c(t,e,r){return e in t?t[e]:r}e.exports=function(t,e,r){Array.isArray(e)?(r=r||{},e=e||[]):(r=e||{},e=[]);var u=!!c(r,\"delaunay\",!0),f=!!c(r,\"interior\",!0),h=!!c(r,\"exterior\",!0),p=!!c(r,\"infinity\",!1);if(!f&&!h||0===t.length)return[];var d=n(t,e);if(u||f!==h||p){for(var m=i(t.length,function(t){return t.map(s).sort(l)}(e)),g=0;g<d.length;++g){var v=d[g];m.addTriangle(v[0],v[1],v[2])}return u&&a(t,m),h?f?p?o(m,0,p):m.cells():o(m,1,p):o(m,-1)}return d}},{\"./lib/delaunay\":119,\"./lib/filter\":120,\"./lib/monotone\":121,\"./lib/triangulation\":122}],119:[function(t,e,r){\"use strict\";var n=t(\"robust-in-sphere\")[4];t(\"binary-search-bounds\");function i(t,e,r,i,a,o){var s=e.opposite(i,a);if(!(s<0)){if(a<i){var l=i;i=a,a=l,l=o,o=s,s=l}e.isConstraint(i,a)||n(t[i],t[a],t[o],t[s])<0&&r.push(i,a)}}e.exports=function(t,e){for(var r=[],a=t.length,o=e.stars,s=0;s<a;++s)for(var l=o[s],c=1;c<l.length;c+=2){if(!((p=l[c])<s)&&!e.isConstraint(s,p)){for(var u=l[c-1],f=-1,h=1;h<l.length;h+=2)if(l[h-1]===p){f=l[h];break}f<0||n(t[s],t[p],t[u],t[f])<0&&r.push(s,p)}}for(;r.length>0;){for(var p=r.pop(),d=(s=r.pop(),u=-1,f=-1,l=o[s],1);d<l.length;d+=2){var m=l[d-1],g=l[d];m===p?f=g:g===p&&(u=m)}u<0||f<0||(n(t[s],t[p],t[u],t[f])>=0||(e.flip(s,p),i(t,e,r,u,s,f),i(t,e,r,s,f,u),i(t,e,r,f,p,u),i(t,e,r,p,u,f)))}}},{\"binary-search-bounds\":103,\"robust-in-sphere\":542}],120:[function(t,e,r){\"use strict\";var n,i=t(\"binary-search-bounds\");function a(t,e,r,n,i,a,o){this.cells=t,this.neighbor=e,this.flags=n,this.constraint=r,this.active=i,this.next=a,this.boundary=o}function o(t,e){return t[0]-e[0]||t[1]-e[1]||t[2]-e[2]}e.exports=function(t,e,r){var n=function(t,e){for(var r=t.cells(),n=r.length,i=0;i<n;++i){var s=(v=r[i])[0],l=v[1],c=v[2];l<c?l<s&&(v[0]=l,v[1]=c,v[2]=s):c<s&&(v[0]=c,v[1]=s,v[2]=l)}r.sort(o);var u=new Array(n);for(i=0;i<u.length;++i)u[i]=0;var f=[],h=[],p=new Array(3*n),d=new Array(3*n),m=null;e&&(m=[]);var g=new a(r,p,d,u,f,h,m);for(i=0;i<n;++i)for(var v=r[i],y=0;y<3;++y){s=v[y],l=v[(y+1)%3];var x=p[3*i+y]=g.locate(l,s,t.opposite(l,s)),b=d[3*i+y]=t.isConstraint(s,l);x<0&&(b?h.push(i):(f.push(i),u[i]=1),e&&m.push([l,s,-1]))}return g}(t,r);if(0===e)return r?n.cells.concat(n.boundary):n.cells;var i=1,s=n.active,l=n.next,c=n.flags,u=n.cells,f=n.constraint,h=n.neighbor;for(;s.length>0||l.length>0;){for(;s.length>0;){var p=s.pop();if(c[p]!==-i){c[p]=i;u[p];for(var d=0;d<3;++d){var m=h[3*p+d];m>=0&&0===c[m]&&(f[3*p+d]?l.push(m):(s.push(m),c[m]=i))}}}var g=l;l=s,s=g,l.length=0,i=-i}var v=function(t,e,r){for(var n=0,i=0;i<t.length;++i)e[i]===r&&(t[n++]=t[i]);return t.length=n,t}(u,c,e);if(r)return v.concat(n.boundary);return v},a.prototype.locate=(n=[0,0,0],function(t,e,r){var a=t,s=e,l=r;return e<r?e<t&&(a=e,s=r,l=t):r<t&&(a=r,s=t,l=e),a<0?-1:(n[0]=a,n[1]=s,n[2]=l,i.eq(this.cells,n,o))})},{\"binary-search-bounds\":103}],121:[function(t,e,r){\"use strict\";var n=t(\"binary-search-bounds\"),i=t(\"robust-orientation\")[3];function a(t,e,r,n,i){this.a=t,this.b=e,this.idx=r,this.lowerIds=n,this.upperIds=i}function o(t,e,r,n){this.a=t,this.b=e,this.type=r,this.idx=n}function s(t,e){var r=t.a[0]-e.a[0]||t.a[1]-e.a[1]||t.type-e.type;return r||(0!==t.type&&(r=i(t.a,t.b,e.b))?r:t.idx-e.idx)}function l(t,e){return i(t.a,t.b,e)}function c(t,e,r,a,o){for(var s=n.lt(e,a,l),c=n.gt(e,a,l),u=s;u<c;++u){for(var f=e[u],h=f.lowerIds,p=h.length;p>1&&i(r[h[p-2]],r[h[p-1]],a)>0;)t.push([h[p-1],h[p-2],o]),p-=1;h.length=p,h.push(o);var d=f.upperIds;for(p=d.length;p>1&&i(r[d[p-2]],r[d[p-1]],a)<0;)t.push([d[p-2],d[p-1],o]),p-=1;d.length=p,d.push(o)}}function u(t,e){var r;return(r=t.a[0]<e.a[0]?i(t.a,t.b,e.a):i(e.b,e.a,t.a))?r:(r=e.b[0]<t.b[0]?i(t.a,t.b,e.b):i(e.b,e.a,t.b))||t.idx-e.idx}function f(t,e,r){var i=n.le(t,r,u),o=t[i],s=o.upperIds,l=s[s.length-1];o.upperIds=[l],t.splice(i+1,0,new a(r.a,r.b,r.idx,[l],s))}function h(t,e,r){var i=r.a;r.a=r.b,r.b=i;var a=n.eq(t,r,u),o=t[a];t[a-1].upperIds=o.upperIds,t.splice(a,1)}e.exports=function(t,e){for(var r=t.length,n=e.length,i=[],l=0;l<r;++l)i.push(new o(t[l],null,0,l));for(l=0;l<n;++l){var u=e[l],p=t[u[0]],d=t[u[1]];p[0]<d[0]?i.push(new o(p,d,2,l),new o(d,p,1,l)):p[0]>d[0]&&i.push(new o(d,p,2,l),new o(p,d,1,l))}i.sort(s);for(var m=i[0].a[0]-(1+Math.abs(i[0].a[0]))*Math.pow(2,-52),g=[new a([m,1],[m,0],-1,[],[],[],[])],v=[],y=(l=0,i.length);l<y;++l){var x=i[l],b=x.type;0===b?c(v,g,t,x.a,x.idx):2===b?f(g,t,x):h(g,t,x)}return v}},{\"binary-search-bounds\":103,\"robust-orientation\":544}],122:[function(t,e,r){\"use strict\";var n=t(\"binary-search-bounds\");function i(t,e){this.stars=t,this.edges=e}e.exports=function(t,e){for(var r=new Array(t),n=0;n<t;++n)r[n]=[];return new i(r,e)};var a=i.prototype;function o(t,e,r){for(var n=1,i=t.length;n<i;n+=2)if(t[n-1]===e&&t[n]===r)return t[n-1]=t[i-2],t[n]=t[i-1],void(t.length=i-2)}a.isConstraint=function(){var t=[0,0];function e(t,e){return t[0]-e[0]||t[1]-e[1]}return function(r,i){return t[0]=Math.min(r,i),t[1]=Math.max(r,i),n.eq(this.edges,t,e)>=0}}(),a.removeTriangle=function(t,e,r){var n=this.stars;o(n[t],e,r),o(n[e],r,t),o(n[r],t,e)},a.addTriangle=function(t,e,r){var n=this.stars;n[t].push(e,r),n[e].push(r,t),n[r].push(t,e)},a.opposite=function(t,e){for(var r=this.stars[e],n=1,i=r.length;n<i;n+=2)if(r[n]===t)return r[n-1];return-1},a.flip=function(t,e){var r=this.opposite(t,e),n=this.opposite(e,t);this.removeTriangle(t,e,r),this.removeTriangle(e,t,n),this.addTriangle(t,n,r),this.addTriangle(e,r,n)},a.edges=function(){for(var t=this.stars,e=[],r=0,n=t.length;r<n;++r)for(var i=t[r],a=0,o=i.length;a<o;a+=2)e.push([i[a],i[a+1]]);return e},a.cells=function(){for(var t=this.stars,e=[],r=0,n=t.length;r<n;++r)for(var i=t[r],a=0,o=i.length;a<o;a+=2){var s=i[a],l=i[a+1];r<Math.min(s,l)&&e.push([r,s,l])}return e}},{\"binary-search-bounds\":103}],123:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=1,r=1;r<t.length;++r)for(var n=0;n<r;++n)if(t[r]<t[n])e=-e;else if(t[n]===t[r])return 0;return e}},{}],124:[function(t,e,r){\"use strict\";var n=t(\"dup\"),i=t(\"robust-linear-solve\");function a(t,e){for(var r=0,n=t.length,i=0;i<n;++i)r+=t[i]*e[i];return r}function o(t){var e=t.length;if(0===e)return[];t[0].length;var r=n([t.length+1,t.length+1],1),o=n([t.length+1],1);r[e][e]=0;for(var s=0;s<e;++s){for(var l=0;l<=s;++l)r[l][s]=r[s][l]=2*a(t[s],t[l]);o[s]=a(t[s],t[s])}var c=i(r,o),u=0,f=c[e+1];for(s=0;s<f.length;++s)u+=f[s];var h=new Array(e);for(s=0;s<e;++s){f=c[s];var p=0;for(l=0;l<f.length;++l)p+=f[l];h[s]=p/u}return h}function s(t){if(0===t.length)return[];for(var e=t[0].length,r=n([e]),i=o(t),a=0;a<t.length;++a)for(var s=0;s<e;++s)r[s]+=t[a][s]*i[a];return r}s.barycenetric=o,e.exports=s},{dup:181,\"robust-linear-solve\":543}],125:[function(t,e,r){e.exports=function(t){for(var e=n(t),r=0,i=0;i<t.length;++i)for(var a=t[i],o=0;o<e.length;++o)r+=Math.pow(a[o]-e[o],2);return Math.sqrt(r/t.length)};var n=t(\"circumcenter\")},{circumcenter:124}],126:[function(t,e,r){e.exports=function(t,e,r){return e<r?t<e?e:t>r?r:t:t<r?r:t>e?e:t}},{}],127:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){var n;if(r){n=e;for(var i=new Array(e.length),a=0;a<e.length;++a){var o=e[a];i[a]=[o[0],o[1],r[a]]}e=i}var s=function(t,e,r){var n=d(t,[],p(t));return v(e,n,r),!!n}(t,e,!!r);for(;y(t,e,!!r);)s=!0;if(r&&s){n.length=0,r.length=0;for(a=0;a<e.length;++a){o=e[a];n.push([o[0],o[1]]),r.push(o[2])}}return s};var n=t(\"union-find\"),i=t(\"box-intersect\"),a=t(\"robust-segment-intersect\"),o=t(\"big-rat\"),s=t(\"big-rat/cmp\"),l=t(\"big-rat/to-float\"),c=t(\"rat-vec\"),u=t(\"nextafter\"),f=t(\"./lib/rat-seg-intersect\");function h(t){var e=l(t);return[u(e,-1/0),u(e,1/0)]}function p(t){for(var e=new Array(t.length),r=0;r<t.length;++r){var n=t[r];e[r]=[u(n[0],-1/0),u(n[1],-1/0),u(n[0],1/0),u(n[1],1/0)]}return e}function d(t,e,r){for(var a=e.length,o=new n(a),s=[],l=0;l<e.length;++l){var c=e[l],f=h(c[0]),p=h(c[1]);s.push([u(f[0],-1/0),u(p[0],-1/0),u(f[1],1/0),u(p[1],1/0)])}i(s,(function(t,e){o.link(t,e)}));var d=!0,m=new Array(a);for(l=0;l<a;++l){(v=o.find(l))!==l&&(d=!1,t[v]=[Math.min(t[l][0],t[v][0]),Math.min(t[l][1],t[v][1])])}if(d)return null;var g=0;for(l=0;l<a;++l){var v;(v=o.find(l))===l?(m[l]=g,t[g++]=t[l]):m[l]=-1}t.length=g;for(l=0;l<a;++l)m[l]<0&&(m[l]=m[o.find(l)]);return m}function m(t,e){return t[0]-e[0]||t[1]-e[1]}function g(t,e){var r=t[0]-e[0]||t[1]-e[1];return r||(t[2]<e[2]?-1:t[2]>e[2]?1:0)}function v(t,e,r){if(0!==t.length){if(e)for(var n=0;n<t.length;++n){var i=e[(o=t[n])[0]],a=e[o[1]];o[0]=Math.min(i,a),o[1]=Math.max(i,a)}else for(n=0;n<t.length;++n){var o;i=(o=t[n])[0],a=o[1];o[0]=Math.min(i,a),o[1]=Math.max(i,a)}r?t.sort(g):t.sort(m);var s=1;for(n=1;n<t.length;++n){var l=t[n-1],c=t[n];(c[0]!==l[0]||c[1]!==l[1]||r&&c[2]!==l[2])&&(t[s++]=c)}t.length=s}}function y(t,e,r){var n=function(t,e){for(var r=new Array(e.length),n=0;n<e.length;++n){var i=e[n],a=t[i[0]],o=t[i[1]];r[n]=[u(Math.min(a[0],o[0]),-1/0),u(Math.min(a[1],o[1]),-1/0),u(Math.max(a[0],o[0]),1/0),u(Math.max(a[1],o[1]),1/0)]}return r}(t,e),h=function(t,e,r){var n=[];return i(r,(function(r,i){var o=e[r],s=e[i];if(o[0]!==s[0]&&o[0]!==s[1]&&o[1]!==s[0]&&o[1]!==s[1]){var l=t[o[0]],c=t[o[1]],u=t[s[0]],f=t[s[1]];a(l,c,u,f)&&n.push([r,i])}})),n}(t,e,n),m=p(t),g=function(t,e,r,n){var o=[];return i(r,n,(function(r,n){var i=e[r];if(i[0]!==n&&i[1]!==n){var s=t[n],l=t[i[0]],c=t[i[1]];a(l,c,s,s)&&o.push([r,n])}})),o}(t,e,n,m),y=d(t,function(t,e,r,n,i){var a,u,h=t.map((function(t){return[o(t[0]),o(t[1])]}));for(a=0;a<r.length;++a){var p=r[a];u=p[0];var d=p[1],m=e[u],g=e[d],v=f(c(t[m[0]]),c(t[m[1]]),c(t[g[0]]),c(t[g[1]]));if(v){var y=t.length;t.push([l(v[0]),l(v[1])]),h.push(v),n.push([u,y],[d,y])}}for(n.sort((function(t,e){if(t[0]!==e[0])return t[0]-e[0];var r=h[t[1]],n=h[e[1]];return s(r[0],n[0])||s(r[1],n[1])})),a=n.length-1;a>=0;--a){var x=e[u=(S=n[a])[0]],b=x[0],_=x[1],w=t[b],T=t[_];if((w[0]-T[0]||w[1]-T[1])<0){var k=b;b=_,_=k}x[0]=b;var M,A=x[1]=S[1];for(i&&(M=x[2]);a>0&&n[a-1][0]===u;){var S,E=(S=n[--a])[1];i?e.push([A,E,M]):e.push([A,E]),A=E}i?e.push([A,_,M]):e.push([A,_])}return h}(t,e,h,g,r));return v(e,y,r),!!y||(h.length>0||g.length>0)}},{\"./lib/rat-seg-intersect\":128,\"big-rat\":90,\"big-rat/cmp\":88,\"big-rat/to-float\":102,\"box-intersect\":108,nextafter:480,\"rat-vec\":528,\"robust-segment-intersect\":547,\"union-find\":614}],128:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n){var a=s(e,t),f=s(n,r),h=u(a,f);if(0===o(h))return null;var p=s(t,r),d=u(f,p),m=i(d,h),g=c(a,m);return l(t,g)};var n=t(\"big-rat/mul\"),i=t(\"big-rat/div\"),a=t(\"big-rat/sub\"),o=t(\"big-rat/sign\"),s=t(\"rat-vec/sub\"),l=t(\"rat-vec/add\"),c=t(\"rat-vec/muls\");function u(t,e){return a(n(t[0],e[1]),n(t[1],e[0]))}},{\"big-rat/div\":89,\"big-rat/mul\":99,\"big-rat/sign\":100,\"big-rat/sub\":101,\"rat-vec/add\":527,\"rat-vec/muls\":529,\"rat-vec/sub\":530}],129:[function(t,e,r){\"use strict\";var n=t(\"clamp\");function i(t,e){null==e&&(e=!0);var r=t[0],i=t[1],a=t[2],o=t[3];return null==o&&(o=e?1:255),e&&(r*=255,i*=255,a*=255,o*=255),16777216*(r=255&n(r,0,255))+((i=255&n(i,0,255))<<16)+((a=255&n(a,0,255))<<8)+(o=255&n(o,0,255))}e.exports=i,e.exports.to=i,e.exports.from=function(t,e){var r=(t=+t)>>>24,n=(16711680&t)>>>16,i=(65280&t)>>>8,a=255&t;return!1===e?[r,n,i,a]:[r/255,n/255,i/255,a/255]}},{clamp:126}],130:[function(t,e,r){\"use strict\";e.exports={aliceblue:[240,248,255],antiquewhite:[250,235,215],aqua:[0,255,255],aquamarine:[127,255,212],azure:[240,255,255],beige:[245,245,220],bisque:[255,228,196],black:[0,0,0],blanchedalmond:[255,235,205],blue:[0,0,255],blueviolet:[138,43,226],brown:[165,42,42],burlywood:[222,184,135],cadetblue:[95,158,160],chartreuse:[127,255,0],chocolate:[210,105,30],coral:[255,127,80],cornflowerblue:[100,149,237],cornsilk:[255,248,220],crimson:[220,20,60],cyan:[0,255,255],darkblue:[0,0,139],darkcyan:[0,139,139],darkgoldenrod:[184,134,11],darkgray:[169,169,169],darkgreen:[0,100,0],darkgrey:[169,169,169],darkkhaki:[189,183,107],darkmagenta:[139,0,139],darkolivegreen:[85,107,47],darkorange:[255,140,0],darkorchid:[153,50,204],darkred:[139,0,0],darksalmon:[233,150,122],darkseagreen:[143,188,143],darkslateblue:[72,61,139],darkslategray:[47,79,79],darkslategrey:[47,79,79],darkturquoise:[0,206,209],darkviolet:[148,0,211],deeppink:[255,20,147],deepskyblue:[0,191,255],dimgray:[105,105,105],dimgrey:[105,105,105],dodgerblue:[30,144,255],firebrick:[178,34,34],floralwhite:[255,250,240],forestgreen:[34,139,34],fuchsia:[255,0,255],gainsboro:[220,220,220],ghostwhite:[248,248,255],gold:[255,215,0],goldenrod:[218,165,32],gray:[128,128,128],green:[0,128,0],greenyellow:[173,255,47],grey:[128,128,128],honeydew:[240,255,240],hotpink:[255,105,180],indianred:[205,92,92],indigo:[75,0,130],ivory:[255,255,240],khaki:[240,230,140],lavender:[230,230,250],lavenderblush:[255,240,245],lawngreen:[124,252,0],lemonchiffon:[255,250,205],lightblue:[173,216,230],lightcoral:[240,128,128],lightcyan:[224,255,255],lightgoldenrodyellow:[250,250,210],lightgray:[211,211,211],lightgreen:[144,238,144],lightgrey:[211,211,211],lightpink:[255,182,193],lightsalmon:[255,160,122],lightseagreen:[32,178,170],lightskyblue:[135,206,250],lightslategray:[119,136,153],lightslategrey:[119,136,153],lightsteelblue:[176,196,222],lightyellow:[255,255,224],lime:[0,255,0],limegreen:[50,205,50],linen:[250,240,230],magenta:[255,0,255],maroon:[128,0,0],mediumaquamarine:[102,205,170],mediumblue:[0,0,205],mediumorchid:[186,85,211],mediumpurple:[147,112,219],mediumseagreen:[60,179,113],mediumslateblue:[123,104,238],mediumspringgreen:[0,250,154],mediumturquoise:[72,209,204],mediumvioletred:[199,21,133],midnightblue:[25,25,112],mintcream:[245,255,250],mistyrose:[255,228,225],moccasin:[255,228,181],navajowhite:[255,222,173],navy:[0,0,128],oldlace:[253,245,230],olive:[128,128,0],olivedrab:[107,142,35],orange:[255,165,0],orangered:[255,69,0],orchid:[218,112,214],palegoldenrod:[238,232,170],palegreen:[152,251,152],paleturquoise:[175,238,238],palevioletred:[219,112,147],papayawhip:[255,239,213],peachpuff:[255,218,185],peru:[205,133,63],pink:[255,192,203],plum:[221,160,221],powderblue:[176,224,230],purple:[128,0,128],rebeccapurple:[102,51,153],red:[255,0,0],rosybrown:[188,143,143],royalblue:[65,105,225],saddlebrown:[139,69,19],salmon:[250,128,114],sandybrown:[244,164,96],seagreen:[46,139,87],seashell:[255,245,238],sienna:[160,82,45],silver:[192,192,192],skyblue:[135,206,235],slateblue:[106,90,205],slategray:[112,128,144],slategrey:[112,128,144],snow:[255,250,250],springgreen:[0,255,127],steelblue:[70,130,180],tan:[210,180,140],teal:[0,128,128],thistle:[216,191,216],tomato:[255,99,71],turquoise:[64,224,208],violet:[238,130,238],wheat:[245,222,179],white:[255,255,255],whitesmoke:[245,245,245],yellow:[255,255,0],yellowgreen:[154,205,50]}},{}],131:[function(t,e,r){\"use strict\";var n=t(\"color-rgba\"),i=t(\"clamp\"),a=t(\"dtype\");e.exports=function(t,e){\"float\"!==e&&e||(e=\"array\"),\"uint\"===e&&(e=\"uint8\"),\"uint_clamped\"===e&&(e=\"uint8_clamped\");var r=new(a(e))(4),o=\"uint8\"!==e&&\"uint8_clamped\"!==e;return t.length&&\"string\"!=typeof t||((t=n(t))[0]/=255,t[1]/=255,t[2]/=255),function(t){return t instanceof Uint8Array||t instanceof Uint8ClampedArray||!!(Array.isArray(t)&&(t[0]>1||0===t[0])&&(t[1]>1||0===t[1])&&(t[2]>1||0===t[2])&&(!t[3]||t[3]>1))}(t)?(r[0]=t[0],r[1]=t[1],r[2]=t[2],r[3]=null!=t[3]?t[3]:255,o&&(r[0]/=255,r[1]/=255,r[2]/=255,r[3]/=255),r):(o?(r[0]=t[0],r[1]=t[1],r[2]=t[2],r[3]=null!=t[3]?t[3]:1):(r[0]=i(Math.floor(255*t[0]),0,255),r[1]=i(Math.floor(255*t[1]),0,255),r[2]=i(Math.floor(255*t[2]),0,255),r[3]=null==t[3]?255:i(Math.floor(255*t[3]),0,255)),r)}},{clamp:126,\"color-rgba\":133,dtype:180}],132:[function(t,e,r){(function(r){(function(){\"use strict\";var n=t(\"color-name\"),i=t(\"is-plain-obj\"),a=t(\"defined\");e.exports=function(t){var e,s,l=[],c=1;if(\"string\"==typeof t)if(n[t])l=n[t].slice(),s=\"rgb\";else if(\"transparent\"===t)c=0,s=\"rgb\",l=[0,0,0];else if(/^#[A-Fa-f0-9]+$/.test(t)){var u=(p=t.slice(1)).length;c=1,u<=4?(l=[parseInt(p[0]+p[0],16),parseInt(p[1]+p[1],16),parseInt(p[2]+p[2],16)],4===u&&(c=parseInt(p[3]+p[3],16)/255)):(l=[parseInt(p[0]+p[1],16),parseInt(p[2]+p[3],16),parseInt(p[4]+p[5],16)],8===u&&(c=parseInt(p[6]+p[7],16)/255)),l[0]||(l[0]=0),l[1]||(l[1]=0),l[2]||(l[2]=0),s=\"rgb\"}else if(e=/^((?:rgb|hs[lvb]|hwb|cmyk?|xy[zy]|gray|lab|lchu?v?|[ly]uv|lms)a?)\\s*\\(([^\\)]*)\\)/.exec(t)){var f=e[1],h=\"rgb\"===f,p=f.replace(/a$/,\"\");s=p;u=\"cmyk\"===p?4:\"gray\"===p?1:3;l=e[2].trim().split(/\\s*,\\s*/).map((function(t,e){if(/%$/.test(t))return e===u?parseFloat(t)/100:\"rgb\"===p?255*parseFloat(t)/100:parseFloat(t);if(\"h\"===p[e]){if(/deg$/.test(t))return parseFloat(t);if(void 0!==o[t])return o[t]}return parseFloat(t)})),f===p&&l.push(1),c=h||void 0===l[u]?1:l[u],l=l.slice(0,u)}else t.length>10&&/[0-9](?:\\s|\\/)/.test(t)&&(l=t.match(/([0-9]+)/g).map((function(t){return parseFloat(t)})),s=t.match(/([a-z])/gi).join(\"\").toLowerCase());else if(isNaN(t))if(i(t)){var d=a(t.r,t.red,t.R,null);null!==d?(s=\"rgb\",l=[d,a(t.g,t.green,t.G),a(t.b,t.blue,t.B)]):(s=\"hsl\",l=[a(t.h,t.hue,t.H),a(t.s,t.saturation,t.S),a(t.l,t.lightness,t.L,t.b,t.brightness)]),c=a(t.a,t.alpha,t.opacity,1),null!=t.opacity&&(c/=100)}else(Array.isArray(t)||r.ArrayBuffer&&ArrayBuffer.isView&&ArrayBuffer.isView(t))&&(l=[t[0],t[1],t[2]],s=\"rgb\",c=4===t.length?t[3]:1);else s=\"rgb\",l=[t>>>16,(65280&t)>>>8,255&t];return{space:s,values:l,alpha:c}};var o={red:0,orange:60,yellow:120,green:180,blue:240,purple:300}}).call(this)}).call(this,\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{\"color-name\":130,defined:175,\"is-plain-obj\":453}],133:[function(t,e,r){\"use strict\";var n=t(\"color-parse\"),i=t(\"color-space/hsl\"),a=t(\"clamp\");e.exports=function(t){var e,r=n(t);return r.space?((e=Array(3))[0]=a(r.values[0],0,255),e[1]=a(r.values[1],0,255),e[2]=a(r.values[2],0,255),\"h\"===r.space[0]&&(e=i.rgb(e)),e.push(a(r.alpha,0,1)),e):[]}},{clamp:126,\"color-parse\":132,\"color-space/hsl\":134}],134:[function(t,e,r){\"use strict\";var n=t(\"./rgb\");e.exports={name:\"hsl\",min:[0,0,0],max:[360,100,100],channel:[\"hue\",\"saturation\",\"lightness\"],alias:[\"HSL\"],rgb:function(t){var e,r,n,i,a,o=t[0]/360,s=t[1]/100,l=t[2]/100;if(0===s)return[a=255*l,a,a];e=2*l-(r=l<.5?l*(1+s):l+s-l*s),i=[0,0,0];for(var c=0;c<3;c++)(n=o+1/3*-(c-1))<0?n++:n>1&&n--,a=6*n<1?e+6*(r-e)*n:2*n<1?r:3*n<2?e+(r-e)*(2/3-n)*6:e,i[c]=255*a;return i}},n.hsl=function(t){var e,r,n=t[0]/255,i=t[1]/255,a=t[2]/255,o=Math.min(n,i,a),s=Math.max(n,i,a),l=s-o;return s===o?e=0:n===s?e=(i-a)/l:i===s?e=2+(a-n)/l:a===s&&(e=4+(n-i)/l),(e=Math.min(60*e,360))<0&&(e+=360),r=(o+s)/2,[e,100*(s===o?0:r<=.5?l/(s+o):l/(2-s-o)),100*r]}},{\"./rgb\":135}],135:[function(t,e,r){\"use strict\";e.exports={name:\"rgb\",min:[0,0,0],max:[255,255,255],channel:[\"red\",\"green\",\"blue\"],alias:[\"RGB\"]}},{}],136:[function(t,e,r){e.exports={jet:[{index:0,rgb:[0,0,131]},{index:.125,rgb:[0,60,170]},{index:.375,rgb:[5,255,255]},{index:.625,rgb:[255,255,0]},{index:.875,rgb:[250,0,0]},{index:1,rgb:[128,0,0]}],hsv:[{index:0,rgb:[255,0,0]},{index:.169,rgb:[253,255,2]},{index:.173,rgb:[247,255,2]},{index:.337,rgb:[0,252,4]},{index:.341,rgb:[0,252,10]},{index:.506,rgb:[1,249,255]},{index:.671,rgb:[2,0,253]},{index:.675,rgb:[8,0,253]},{index:.839,rgb:[255,0,251]},{index:.843,rgb:[255,0,245]},{index:1,rgb:[255,0,6]}],hot:[{index:0,rgb:[0,0,0]},{index:.3,rgb:[230,0,0]},{index:.6,rgb:[255,210,0]},{index:1,rgb:[255,255,255]}],spring:[{index:0,rgb:[255,0,255]},{index:1,rgb:[255,255,0]}],summer:[{index:0,rgb:[0,128,102]},{index:1,rgb:[255,255,102]}],autumn:[{index:0,rgb:[255,0,0]},{index:1,rgb:[255,255,0]}],winter:[{index:0,rgb:[0,0,255]},{index:1,rgb:[0,255,128]}],bone:[{index:0,rgb:[0,0,0]},{index:.376,rgb:[84,84,116]},{index:.753,rgb:[169,200,200]},{index:1,rgb:[255,255,255]}],copper:[{index:0,rgb:[0,0,0]},{index:.804,rgb:[255,160,102]},{index:1,rgb:[255,199,127]}],greys:[{index:0,rgb:[0,0,0]},{index:1,rgb:[255,255,255]}],yignbu:[{index:0,rgb:[8,29,88]},{index:.125,rgb:[37,52,148]},{index:.25,rgb:[34,94,168]},{index:.375,rgb:[29,145,192]},{index:.5,rgb:[65,182,196]},{index:.625,rgb:[127,205,187]},{index:.75,rgb:[199,233,180]},{index:.875,rgb:[237,248,217]},{index:1,rgb:[255,255,217]}],greens:[{index:0,rgb:[0,68,27]},{index:.125,rgb:[0,109,44]},{index:.25,rgb:[35,139,69]},{index:.375,rgb:[65,171,93]},{index:.5,rgb:[116,196,118]},{index:.625,rgb:[161,217,155]},{index:.75,rgb:[199,233,192]},{index:.875,rgb:[229,245,224]},{index:1,rgb:[247,252,245]}],yiorrd:[{index:0,rgb:[128,0,38]},{index:.125,rgb:[189,0,38]},{index:.25,rgb:[227,26,28]},{index:.375,rgb:[252,78,42]},{index:.5,rgb:[253,141,60]},{index:.625,rgb:[254,178,76]},{index:.75,rgb:[254,217,118]},{index:.875,rgb:[255,237,160]},{index:1,rgb:[255,255,204]}],bluered:[{index:0,rgb:[0,0,255]},{index:1,rgb:[255,0,0]}],rdbu:[{index:0,rgb:[5,10,172]},{index:.35,rgb:[106,137,247]},{index:.5,rgb:[190,190,190]},{index:.6,rgb:[220,170,132]},{index:.7,rgb:[230,145,90]},{index:1,rgb:[178,10,28]}],picnic:[{index:0,rgb:[0,0,255]},{index:.1,rgb:[51,153,255]},{index:.2,rgb:[102,204,255]},{index:.3,rgb:[153,204,255]},{index:.4,rgb:[204,204,255]},{index:.5,rgb:[255,255,255]},{index:.6,rgb:[255,204,255]},{index:.7,rgb:[255,153,255]},{index:.8,rgb:[255,102,204]},{index:.9,rgb:[255,102,102]},{index:1,rgb:[255,0,0]}],rainbow:[{index:0,rgb:[150,0,90]},{index:.125,rgb:[0,0,200]},{index:.25,rgb:[0,25,255]},{index:.375,rgb:[0,152,255]},{index:.5,rgb:[44,255,150]},{index:.625,rgb:[151,255,0]},{index:.75,rgb:[255,234,0]},{index:.875,rgb:[255,111,0]},{index:1,rgb:[255,0,0]}],portland:[{index:0,rgb:[12,51,131]},{index:.25,rgb:[10,136,186]},{index:.5,rgb:[242,211,56]},{index:.75,rgb:[242,143,56]},{index:1,rgb:[217,30,30]}],blackbody:[{index:0,rgb:[0,0,0]},{index:.2,rgb:[230,0,0]},{index:.4,rgb:[230,210,0]},{index:.7,rgb:[255,255,255]},{index:1,rgb:[160,200,255]}],earth:[{index:0,rgb:[0,0,130]},{index:.1,rgb:[0,180,180]},{index:.2,rgb:[40,210,40]},{index:.4,rgb:[230,230,50]},{index:.6,rgb:[120,70,20]},{index:1,rgb:[255,255,255]}],electric:[{index:0,rgb:[0,0,0]},{index:.15,rgb:[30,0,100]},{index:.4,rgb:[120,0,100]},{index:.6,rgb:[160,90,0]},{index:.8,rgb:[230,200,0]},{index:1,rgb:[255,250,220]}],alpha:[{index:0,rgb:[255,255,255,0]},{index:1,rgb:[255,255,255,1]}],viridis:[{index:0,rgb:[68,1,84]},{index:.13,rgb:[71,44,122]},{index:.25,rgb:[59,81,139]},{index:.38,rgb:[44,113,142]},{index:.5,rgb:[33,144,141]},{index:.63,rgb:[39,173,129]},{index:.75,rgb:[92,200,99]},{index:.88,rgb:[170,220,50]},{index:1,rgb:[253,231,37]}],inferno:[{index:0,rgb:[0,0,4]},{index:.13,rgb:[31,12,72]},{index:.25,rgb:[85,15,109]},{index:.38,rgb:[136,34,106]},{index:.5,rgb:[186,54,85]},{index:.63,rgb:[227,89,51]},{index:.75,rgb:[249,140,10]},{index:.88,rgb:[249,201,50]},{index:1,rgb:[252,255,164]}],magma:[{index:0,rgb:[0,0,4]},{index:.13,rgb:[28,16,68]},{index:.25,rgb:[79,18,123]},{index:.38,rgb:[129,37,129]},{index:.5,rgb:[181,54,122]},{index:.63,rgb:[229,80,100]},{index:.75,rgb:[251,135,97]},{index:.88,rgb:[254,194,135]},{index:1,rgb:[252,253,191]}],plasma:[{index:0,rgb:[13,8,135]},{index:.13,rgb:[75,3,161]},{index:.25,rgb:[125,3,168]},{index:.38,rgb:[168,34,150]},{index:.5,rgb:[203,70,121]},{index:.63,rgb:[229,107,93]},{index:.75,rgb:[248,148,65]},{index:.88,rgb:[253,195,40]},{index:1,rgb:[240,249,33]}],warm:[{index:0,rgb:[125,0,179]},{index:.13,rgb:[172,0,187]},{index:.25,rgb:[219,0,170]},{index:.38,rgb:[255,0,130]},{index:.5,rgb:[255,63,74]},{index:.63,rgb:[255,123,0]},{index:.75,rgb:[234,176,0]},{index:.88,rgb:[190,228,0]},{index:1,rgb:[147,255,0]}],cool:[{index:0,rgb:[125,0,179]},{index:.13,rgb:[116,0,218]},{index:.25,rgb:[98,74,237]},{index:.38,rgb:[68,146,231]},{index:.5,rgb:[0,204,197]},{index:.63,rgb:[0,247,146]},{index:.75,rgb:[0,255,88]},{index:.88,rgb:[40,255,8]},{index:1,rgb:[147,255,0]}],\"rainbow-soft\":[{index:0,rgb:[125,0,179]},{index:.1,rgb:[199,0,180]},{index:.2,rgb:[255,0,121]},{index:.3,rgb:[255,108,0]},{index:.4,rgb:[222,194,0]},{index:.5,rgb:[150,255,0]},{index:.6,rgb:[0,255,55]},{index:.7,rgb:[0,246,150]},{index:.8,rgb:[50,167,222]},{index:.9,rgb:[103,51,235]},{index:1,rgb:[124,0,186]}],bathymetry:[{index:0,rgb:[40,26,44]},{index:.13,rgb:[59,49,90]},{index:.25,rgb:[64,76,139]},{index:.38,rgb:[63,110,151]},{index:.5,rgb:[72,142,158]},{index:.63,rgb:[85,174,163]},{index:.75,rgb:[120,206,163]},{index:.88,rgb:[187,230,172]},{index:1,rgb:[253,254,204]}],cdom:[{index:0,rgb:[47,15,62]},{index:.13,rgb:[87,23,86]},{index:.25,rgb:[130,28,99]},{index:.38,rgb:[171,41,96]},{index:.5,rgb:[206,67,86]},{index:.63,rgb:[230,106,84]},{index:.75,rgb:[242,149,103]},{index:.88,rgb:[249,193,135]},{index:1,rgb:[254,237,176]}],chlorophyll:[{index:0,rgb:[18,36,20]},{index:.13,rgb:[25,63,41]},{index:.25,rgb:[24,91,59]},{index:.38,rgb:[13,119,72]},{index:.5,rgb:[18,148,80]},{index:.63,rgb:[80,173,89]},{index:.75,rgb:[132,196,122]},{index:.88,rgb:[175,221,162]},{index:1,rgb:[215,249,208]}],density:[{index:0,rgb:[54,14,36]},{index:.13,rgb:[89,23,80]},{index:.25,rgb:[110,45,132]},{index:.38,rgb:[120,77,178]},{index:.5,rgb:[120,113,213]},{index:.63,rgb:[115,151,228]},{index:.75,rgb:[134,185,227]},{index:.88,rgb:[177,214,227]},{index:1,rgb:[230,241,241]}],\"freesurface-blue\":[{index:0,rgb:[30,4,110]},{index:.13,rgb:[47,14,176]},{index:.25,rgb:[41,45,236]},{index:.38,rgb:[25,99,212]},{index:.5,rgb:[68,131,200]},{index:.63,rgb:[114,156,197]},{index:.75,rgb:[157,181,203]},{index:.88,rgb:[200,208,216]},{index:1,rgb:[241,237,236]}],\"freesurface-red\":[{index:0,rgb:[60,9,18]},{index:.13,rgb:[100,17,27]},{index:.25,rgb:[142,20,29]},{index:.38,rgb:[177,43,27]},{index:.5,rgb:[192,87,63]},{index:.63,rgb:[205,125,105]},{index:.75,rgb:[216,162,148]},{index:.88,rgb:[227,199,193]},{index:1,rgb:[241,237,236]}],oxygen:[{index:0,rgb:[64,5,5]},{index:.13,rgb:[106,6,15]},{index:.25,rgb:[144,26,7]},{index:.38,rgb:[168,64,3]},{index:.5,rgb:[188,100,4]},{index:.63,rgb:[206,136,11]},{index:.75,rgb:[220,174,25]},{index:.88,rgb:[231,215,44]},{index:1,rgb:[248,254,105]}],par:[{index:0,rgb:[51,20,24]},{index:.13,rgb:[90,32,35]},{index:.25,rgb:[129,44,34]},{index:.38,rgb:[159,68,25]},{index:.5,rgb:[182,99,19]},{index:.63,rgb:[199,134,22]},{index:.75,rgb:[212,171,35]},{index:.88,rgb:[221,210,54]},{index:1,rgb:[225,253,75]}],phase:[{index:0,rgb:[145,105,18]},{index:.13,rgb:[184,71,38]},{index:.25,rgb:[186,58,115]},{index:.38,rgb:[160,71,185]},{index:.5,rgb:[110,97,218]},{index:.63,rgb:[50,123,164]},{index:.75,rgb:[31,131,110]},{index:.88,rgb:[77,129,34]},{index:1,rgb:[145,105,18]}],salinity:[{index:0,rgb:[42,24,108]},{index:.13,rgb:[33,50,162]},{index:.25,rgb:[15,90,145]},{index:.38,rgb:[40,118,137]},{index:.5,rgb:[59,146,135]},{index:.63,rgb:[79,175,126]},{index:.75,rgb:[120,203,104]},{index:.88,rgb:[193,221,100]},{index:1,rgb:[253,239,154]}],temperature:[{index:0,rgb:[4,35,51]},{index:.13,rgb:[23,51,122]},{index:.25,rgb:[85,59,157]},{index:.38,rgb:[129,79,143]},{index:.5,rgb:[175,95,130]},{index:.63,rgb:[222,112,101]},{index:.75,rgb:[249,146,66]},{index:.88,rgb:[249,196,65]},{index:1,rgb:[232,250,91]}],turbidity:[{index:0,rgb:[34,31,27]},{index:.13,rgb:[65,50,41]},{index:.25,rgb:[98,69,52]},{index:.38,rgb:[131,89,57]},{index:.5,rgb:[161,112,59]},{index:.63,rgb:[185,140,66]},{index:.75,rgb:[202,174,88]},{index:.88,rgb:[216,209,126]},{index:1,rgb:[233,246,171]}],\"velocity-blue\":[{index:0,rgb:[17,32,64]},{index:.13,rgb:[35,52,116]},{index:.25,rgb:[29,81,156]},{index:.38,rgb:[31,113,162]},{index:.5,rgb:[50,144,169]},{index:.63,rgb:[87,173,176]},{index:.75,rgb:[149,196,189]},{index:.88,rgb:[203,221,211]},{index:1,rgb:[254,251,230]}],\"velocity-green\":[{index:0,rgb:[23,35,19]},{index:.13,rgb:[24,64,38]},{index:.25,rgb:[11,95,45]},{index:.38,rgb:[39,123,35]},{index:.5,rgb:[95,146,12]},{index:.63,rgb:[152,165,18]},{index:.75,rgb:[201,186,69]},{index:.88,rgb:[233,216,137]},{index:1,rgb:[255,253,205]}],cubehelix:[{index:0,rgb:[0,0,0]},{index:.07,rgb:[22,5,59]},{index:.13,rgb:[60,4,105]},{index:.2,rgb:[109,1,135]},{index:.27,rgb:[161,0,147]},{index:.33,rgb:[210,2,142]},{index:.4,rgb:[251,11,123]},{index:.47,rgb:[255,29,97]},{index:.53,rgb:[255,54,69]},{index:.6,rgb:[255,85,46]},{index:.67,rgb:[255,120,34]},{index:.73,rgb:[255,157,37]},{index:.8,rgb:[241,191,57]},{index:.87,rgb:[224,220,93]},{index:.93,rgb:[218,241,142]},{index:1,rgb:[227,253,198]}]}},{}],137:[function(t,e,r){\"use strict\";var n=t(\"./colorScale\"),i=t(\"lerp\");function a(t){return[t[0]/255,t[1]/255,t[2]/255,t[3]]}function o(t){for(var e,r=\"#\",n=0;n<3;++n)r+=(\"00\"+(e=(e=t[n]).toString(16))).substr(e.length);return r}function s(t){return\"rgba(\"+t.join(\",\")+\")\"}e.exports=function(t){var e,r,l,c,u,f,h,p,d,m;t||(t={});p=(t.nshades||72)-1,h=t.format||\"hex\",(f=t.colormap)||(f=\"jet\");if(\"string\"==typeof f){if(f=f.toLowerCase(),!n[f])throw Error(f+\" not a supported colorscale\");u=n[f]}else{if(!Array.isArray(f))throw Error(\"unsupported colormap option\",f);u=f.slice()}if(u.length>p+1)throw new Error(f+\" map requires nshades to be at least size \"+u.length);d=Array.isArray(t.alpha)?2!==t.alpha.length?[1,1]:t.alpha.slice():\"number\"==typeof t.alpha?[t.alpha,t.alpha]:[1,1];e=u.map((function(t){return Math.round(t.index*p)})),d[0]=Math.min(Math.max(d[0],0),1),d[1]=Math.min(Math.max(d[1],0),1);var g=u.map((function(t,e){var r=u[e].index,n=u[e].rgb.slice();return 4===n.length&&n[3]>=0&&n[3]<=1||(n[3]=d[0]+(d[1]-d[0])*r),n})),v=[];for(m=0;m<e.length-1;++m){c=e[m+1]-e[m],r=g[m],l=g[m+1];for(var y=0;y<c;y++){var x=y/c;v.push([Math.round(i(r[0],l[0],x)),Math.round(i(r[1],l[1],x)),Math.round(i(r[2],l[2],x)),i(r[3],l[3],x)])}}v.push(u[u.length-1].rgb.concat(d[1])),\"hex\"===h?v=v.map(o):\"rgbaString\"===h?v=v.map(s):\"float\"===h&&(v=v.map(a));return v}},{\"./colorScale\":136,lerp:456}],138:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,a){var o=n(e,r,a);if(0===o){var s=i(n(t,e,r)),c=i(n(t,e,a));if(s===c){if(0===s){var u=l(t,e,r),f=l(t,e,a);return u===f?0:u?1:-1}return 0}return 0===c?s>0||l(t,e,a)?-1:1:0===s?c>0||l(t,e,r)?1:-1:i(c-s)}var h=n(t,e,r);return h>0?o>0&&n(t,e,a)>0?1:-1:h<0?o>0||n(t,e,a)>0?1:-1:n(t,e,a)>0||l(t,e,r)?1:-1};var n=t(\"robust-orientation\"),i=t(\"signum\"),a=t(\"two-sum\"),o=t(\"robust-product\"),s=t(\"robust-sum\");function l(t,e,r){var n=a(t[0],-e[0]),i=a(t[1],-e[1]),l=a(r[0],-e[0]),c=a(r[1],-e[1]),u=s(o(n,l),o(i,c));return u[u.length-1]>=0}},{\"robust-orientation\":544,\"robust-product\":545,\"robust-sum\":549,signum:551,\"two-sum\":601}],139:[function(t,e,r){e.exports=function(t,e){var r=t.length,a=t.length-e.length;if(a)return a;switch(r){case 0:return 0;case 1:return t[0]-e[0];case 2:return t[0]+t[1]-e[0]-e[1]||n(t[0],t[1])-n(e[0],e[1]);case 3:var o=t[0]+t[1],s=e[0]+e[1];if(a=o+t[2]-(s+e[2]))return a;var l=n(t[0],t[1]),c=n(e[0],e[1]);return n(l,t[2])-n(c,e[2])||n(l+t[2],o)-n(c+e[2],s);case 4:var u=t[0],f=t[1],h=t[2],p=t[3],d=e[0],m=e[1],g=e[2],v=e[3];return u+f+h+p-(d+m+g+v)||n(u,f,h,p)-n(d,m,g,v,d)||n(u+f,u+h,u+p,f+h,f+p,h+p)-n(d+m,d+g,d+v,m+g,m+v,g+v)||n(u+f+h,u+f+p,u+h+p,f+h+p)-n(d+m+g,d+m+v,d+g+v,m+g+v);default:for(var y=t.slice().sort(i),x=e.slice().sort(i),b=0;b<r;++b)if(a=y[b]-x[b])return a;return 0}};var n=Math.min;function i(t,e){return t-e}},{}],140:[function(t,e,r){\"use strict\";var n=t(\"compare-cell\"),i=t(\"cell-orientation\");e.exports=function(t,e){return n(t,e)||i(t)-i(e)}},{\"cell-orientation\":123,\"compare-cell\":139}],141:[function(t,e,r){\"use strict\";var n=t(\"./lib/ch1d\"),i=t(\"./lib/ch2d\"),a=t(\"./lib/chnd\");e.exports=function(t){var e=t.length;if(0===e)return[];if(1===e)return[[0]];var r=t[0].length;if(0===r)return[];if(1===r)return n(t);if(2===r)return i(t);return a(t,r)}},{\"./lib/ch1d\":142,\"./lib/ch2d\":143,\"./lib/chnd\":144}],142:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=0,r=0,n=1;n<t.length;++n)t[n][0]<t[e][0]&&(e=n),t[n][0]>t[r][0]&&(r=n);return e<r?[[e],[r]]:e>r?[[r],[e]]:[[e]]}},{}],143:[function(t,e,r){\"use strict\";e.exports=function(t){var e=n(t),r=e.length;if(r<=2)return[];for(var i=new Array(r),a=e[r-1],o=0;o<r;++o){var s=e[o];i[o]=[a,s],a=s}return i};var n=t(\"monotone-convex-hull-2d\")},{\"monotone-convex-hull-2d\":465}],144:[function(t,e,r){\"use strict\";e.exports=function(t,e){try{return n(t,!0)}catch(o){var r=i(t);if(r.length<=e)return[];var a=function(t,e){for(var r=t.length,n=new Array(r),i=0;i<e.length;++i)n[i]=t[e[i]];var a=e.length;for(i=0;i<r;++i)e.indexOf(i)<0&&(n[a++]=t[i]);return n}(t,r);return function(t,e){for(var r=t.length,n=e.length,i=0;i<r;++i)for(var a=t[i],o=0;o<a.length;++o){var s=a[o];if(s<n)a[o]=e[s];else{s-=n;for(var l=0;l<n;++l)s>=e[l]&&(s+=1);a[o]=s}}return t}(n(a,!0),r)}};var n=t(\"incremental-convex-hull\"),i=t(\"affine-hull\")},{\"affine-hull\":73,\"incremental-convex-hull\":442}],145:[function(t,e,r){e.exports={AFG:\"afghan\",ALA:\"\\\\b\\\\wland\",ALB:\"albania\",DZA:\"algeria\",ASM:\"^(?=.*americ).*samoa\",AND:\"andorra\",AGO:\"angola\",AIA:\"anguill?a\",ATA:\"antarctica\",ATG:\"antigua\",ARG:\"argentin\",ARM:\"armenia\",ABW:\"^(?!.*bonaire).*\\\\baruba\",AUS:\"australia\",AUT:\"^(?!.*hungary).*austria|\\\\baustri.*\\\\bemp\",AZE:\"azerbaijan\",BHS:\"bahamas\",BHR:\"bahrain\",BGD:\"bangladesh|^(?=.*east).*paki?stan\",BRB:\"barbados\",BLR:\"belarus|byelo\",BEL:\"^(?!.*luxem).*belgium\",BLZ:\"belize|^(?=.*british).*honduras\",BEN:\"benin|dahome\",BMU:\"bermuda\",BTN:\"bhutan\",BOL:\"bolivia\",BES:\"^(?=.*bonaire).*eustatius|^(?=.*carib).*netherlands|\\\\bbes.?islands\",BIH:\"herzegovina|bosnia\",BWA:\"botswana|bechuana\",BVT:\"bouvet\",BRA:\"brazil\",IOT:\"british.?indian.?ocean\",BRN:\"brunei\",BGR:\"bulgaria\",BFA:\"burkina|\\\\bfaso|upper.?volta\",BDI:\"burundi\",CPV:\"verde\",KHM:\"cambodia|kampuchea|khmer\",CMR:\"cameroon\",CAN:\"canada\",CYM:\"cayman\",CAF:\"\\\\bcentral.african.republic\",TCD:\"\\\\bchad\",CHL:\"\\\\bchile\",CHN:\"^(?!.*\\\\bmac)(?!.*\\\\bhong)(?!.*\\\\btai)(?!.*\\\\brep).*china|^(?=.*peo)(?=.*rep).*china\",CXR:\"christmas\",CCK:\"\\\\bcocos|keeling\",COL:\"colombia\",COM:\"comoro\",COG:\"^(?!.*\\\\bdem)(?!.*\\\\bd[\\\\.]?r)(?!.*kinshasa)(?!.*zaire)(?!.*belg)(?!.*l.opoldville)(?!.*free).*\\\\bcongo\",COK:\"\\\\bcook\",CRI:\"costa.?rica\",CIV:\"ivoire|ivory\",HRV:\"croatia\",CUB:\"\\\\bcuba\",CUW:\"^(?!.*bonaire).*\\\\bcura(c|\\xe7)ao\",CYP:\"cyprus\",CSK:\"czechoslovakia\",CZE:\"^(?=.*rep).*czech|czechia|bohemia\",COD:\"\\\\bdem.*congo|congo.*\\\\bdem|congo.*\\\\bd[\\\\.]?r|\\\\bd[\\\\.]?r.*congo|belgian.?congo|congo.?free.?state|kinshasa|zaire|l.opoldville|drc|droc|rdc\",DNK:\"denmark\",DJI:\"djibouti\",DMA:\"dominica(?!n)\",DOM:\"dominican.rep\",ECU:\"ecuador\",EGY:\"egypt\",SLV:\"el.?salvador\",GNQ:\"guine.*eq|eq.*guine|^(?=.*span).*guinea\",ERI:\"eritrea\",EST:\"estonia\",ETH:\"ethiopia|abyssinia\",FLK:\"falkland|malvinas\",FRO:\"faroe|faeroe\",FJI:\"fiji\",FIN:\"finland\",FRA:\"^(?!.*\\\\bdep)(?!.*martinique).*france|french.?republic|\\\\bgaul\",GUF:\"^(?=.*french).*guiana\",PYF:\"french.?polynesia|tahiti\",ATF:\"french.?southern\",GAB:\"gabon\",GMB:\"gambia\",GEO:\"^(?!.*south).*georgia\",DDR:\"german.?democratic.?republic|democratic.?republic.*germany|east.germany\",DEU:\"^(?!.*east).*germany|^(?=.*\\\\bfed.*\\\\brep).*german\",GHA:\"ghana|gold.?coast\",GIB:\"gibraltar\",GRC:\"greece|hellenic|hellas\",GRL:\"greenland\",GRD:\"grenada\",GLP:\"guadeloupe\",GUM:\"\\\\bguam\",GTM:\"guatemala\",GGY:\"guernsey\",GIN:\"^(?!.*eq)(?!.*span)(?!.*bissau)(?!.*portu)(?!.*new).*guinea\",GNB:\"bissau|^(?=.*portu).*guinea\",GUY:\"guyana|british.?guiana\",HTI:\"haiti\",HMD:\"heard.*mcdonald\",VAT:\"holy.?see|vatican|papal.?st\",HND:\"^(?!.*brit).*honduras\",HKG:\"hong.?kong\",HUN:\"^(?!.*austr).*hungary\",ISL:\"iceland\",IND:\"india(?!.*ocea)\",IDN:\"indonesia\",IRN:\"\\\\biran|persia\",IRQ:\"\\\\biraq|mesopotamia\",IRL:\"(^ireland)|(^republic.*ireland)\",IMN:\"^(?=.*isle).*\\\\bman\",ISR:\"israel\",ITA:\"italy\",JAM:\"jamaica\",JPN:\"japan\",JEY:\"jersey\",JOR:\"jordan\",KAZ:\"kazak\",KEN:\"kenya|british.?east.?africa|east.?africa.?prot\",KIR:\"kiribati\",PRK:\"^(?=.*democrat|people|north|d.*p.*.r).*\\\\bkorea|dprk|korea.*(d.*p.*r)\",KWT:\"kuwait\",KGZ:\"kyrgyz|kirghiz\",LAO:\"\\\\blaos?\\\\b\",LVA:\"latvia\",LBN:\"lebanon\",LSO:\"lesotho|basuto\",LBR:\"liberia\",LBY:\"libya\",LIE:\"liechtenstein\",LTU:\"lithuania\",LUX:\"^(?!.*belg).*luxem\",MAC:\"maca(o|u)\",MDG:\"madagascar|malagasy\",MWI:\"malawi|nyasa\",MYS:\"malaysia\",MDV:\"maldive\",MLI:\"\\\\bmali\\\\b\",MLT:\"\\\\bmalta\",MHL:\"marshall\",MTQ:\"martinique\",MRT:\"mauritania\",MUS:\"mauritius\",MYT:\"\\\\bmayotte\",MEX:\"\\\\bmexic\",FSM:\"fed.*micronesia|micronesia.*fed\",MCO:\"monaco\",MNG:\"mongolia\",MNE:\"^(?!.*serbia).*montenegro\",MSR:\"montserrat\",MAR:\"morocco|\\\\bmaroc\",MOZ:\"mozambique\",MMR:\"myanmar|burma\",NAM:\"namibia\",NRU:\"nauru\",NPL:\"nepal\",NLD:\"^(?!.*\\\\bant)(?!.*\\\\bcarib).*netherlands\",ANT:\"^(?=.*\\\\bant).*(nether|dutch)\",NCL:\"new.?caledonia\",NZL:\"new.?zealand\",NIC:\"nicaragua\",NER:\"\\\\bniger(?!ia)\",NGA:\"nigeria\",NIU:\"niue\",NFK:\"norfolk\",MNP:\"mariana\",NOR:\"norway\",OMN:\"\\\\boman|trucial\",PAK:\"^(?!.*east).*paki?stan\",PLW:\"palau\",PSE:\"palestin|\\\\bgaza|west.?bank\",PAN:\"panama\",PNG:\"papua|new.?guinea\",PRY:\"paraguay\",PER:\"peru\",PHL:\"philippines\",PCN:\"pitcairn\",POL:\"poland\",PRT:\"portugal\",PRI:\"puerto.?rico\",QAT:\"qatar\",KOR:\"^(?!.*d.*p.*r)(?!.*democrat)(?!.*people)(?!.*north).*\\\\bkorea(?!.*d.*p.*r)\",MDA:\"moldov|b(a|e)ssarabia\",REU:\"r(e|\\xe9)union\",ROU:\"r(o|u|ou)mania\",RUS:\"\\\\brussia|soviet.?union|u\\\\.?s\\\\.?s\\\\.?r|socialist.?republics\",RWA:\"rwanda\",BLM:\"barth(e|\\xe9)lemy\",SHN:\"helena\",KNA:\"kitts|\\\\bnevis\",LCA:\"\\\\blucia\",MAF:\"^(?=.*collectivity).*martin|^(?=.*france).*martin(?!ique)|^(?=.*french).*martin(?!ique)\",SPM:\"miquelon\",VCT:\"vincent\",WSM:\"^(?!.*amer).*samoa\",SMR:\"san.?marino\",STP:\"\\\\bs(a|\\xe3)o.?tom(e|\\xe9)\",SAU:\"\\\\bsa\\\\w*.?arabia\",SEN:\"senegal\",SRB:\"^(?!.*monte).*serbia\",SYC:\"seychell\",SLE:\"sierra\",SGP:\"singapore\",SXM:\"^(?!.*martin)(?!.*saba).*maarten\",SVK:\"^(?!.*cze).*slovak\",SVN:\"slovenia\",SLB:\"solomon\",SOM:\"somali\",ZAF:\"south.africa|s\\\\\\\\..?africa\",SGS:\"south.?georgia|sandwich\",SSD:\"\\\\bs\\\\w*.?sudan\",ESP:\"spain\",LKA:\"sri.?lanka|ceylon\",SDN:\"^(?!.*\\\\bs(?!u)).*sudan\",SUR:\"surinam|dutch.?guiana\",SJM:\"svalbard\",SWZ:\"swaziland\",SWE:\"sweden\",CHE:\"switz|swiss\",SYR:\"syria\",TWN:\"taiwan|taipei|formosa|^(?!.*peo)(?=.*rep).*china\",TJK:\"tajik\",THA:\"thailand|\\\\bsiam\",MKD:\"macedonia|fyrom\",TLS:\"^(?=.*leste).*timor|^(?=.*east).*timor\",TGO:\"togo\",TKL:\"tokelau\",TON:\"tonga\",TTO:\"trinidad|tobago\",TUN:\"tunisia\",TUR:\"turkey\",TKM:\"turkmen\",TCA:\"turks\",TUV:\"tuvalu\",UGA:\"uganda\",UKR:\"ukrain\",ARE:\"emirates|^u\\\\.?a\\\\.?e\\\\.?$|united.?arab.?em\",GBR:\"united.?kingdom|britain|^u\\\\.?k\\\\.?$\",TZA:\"tanzania\",USA:\"united.?states\\\\b(?!.*islands)|\\\\bu\\\\.?s\\\\.?a\\\\.?\\\\b|^\\\\s*u\\\\.?s\\\\.?\\\\b(?!.*islands)\",UMI:\"minor.?outlying.?is\",URY:\"uruguay\",UZB:\"uzbek\",VUT:\"vanuatu|new.?hebrides\",VEN:\"venezuela\",VNM:\"^(?!.*republic).*viet.?nam|^(?=.*socialist).*viet.?nam\",VGB:\"^(?=.*\\\\bu\\\\.?\\\\s?k).*virgin|^(?=.*brit).*virgin|^(?=.*kingdom).*virgin\",VIR:\"^(?=.*\\\\bu\\\\.?\\\\s?s).*virgin|^(?=.*states).*virgin\",WLF:\"futuna|wallis\",ESH:\"western.sahara\",YEM:\"^(?!.*arab)(?!.*north)(?!.*sana)(?!.*peo)(?!.*dem)(?!.*south)(?!.*aden)(?!.*\\\\bp\\\\.?d\\\\.?r).*yemen\",YMD:\"^(?=.*peo).*yemen|^(?!.*rep)(?=.*dem).*yemen|^(?=.*south).*yemen|^(?=.*aden).*yemen|^(?=.*\\\\bp\\\\.?d\\\\.?r).*yemen\",YUG:\"yugoslavia\",ZMB:\"zambia|northern.?rhodesia\",EAZ:\"zanzibar\",ZWE:\"zimbabwe|^(?!.*northern).*rhodesia\"}},{}],146:[function(t,e,r){e.exports=[\"xx-small\",\"x-small\",\"small\",\"medium\",\"large\",\"x-large\",\"xx-large\",\"larger\",\"smaller\"]},{}],147:[function(t,e,r){e.exports=[\"normal\",\"condensed\",\"semi-condensed\",\"extra-condensed\",\"ultra-condensed\",\"expanded\",\"semi-expanded\",\"extra-expanded\",\"ultra-expanded\"]},{}],148:[function(t,e,r){e.exports=[\"normal\",\"italic\",\"oblique\"]},{}],149:[function(t,e,r){e.exports=[\"normal\",\"bold\",\"bolder\",\"lighter\",\"100\",\"200\",\"300\",\"400\",\"500\",\"600\",\"700\",\"800\",\"900\"]},{}],150:[function(t,e,r){\"use strict\";e.exports={parse:t(\"./parse\"),stringify:t(\"./stringify\")}},{\"./parse\":152,\"./stringify\":153}],151:[function(t,e,r){\"use strict\";var n=t(\"css-font-size-keywords\");e.exports={isSize:function(t){return/^[\\d\\.]/.test(t)||-1!==t.indexOf(\"/\")||-1!==n.indexOf(t)}}},{\"css-font-size-keywords\":146}],152:[function(t,e,r){\"use strict\";var n=t(\"unquote\"),i=t(\"css-global-keywords\"),a=t(\"css-system-font-keywords\"),o=t(\"css-font-weight-keywords\"),s=t(\"css-font-style-keywords\"),l=t(\"css-font-stretch-keywords\"),c=t(\"string-split-by\"),u=t(\"./lib/util\").isSize;e.exports=h;var f=h.cache={};function h(t){if(\"string\"!=typeof t)throw new Error(\"Font argument must be a string.\");if(f[t])return f[t];if(\"\"===t)throw new Error(\"Cannot parse an empty string.\");if(-1!==a.indexOf(t))return f[t]={system:t};for(var e,r={style:\"normal\",variant:\"normal\",weight:\"normal\",stretch:\"normal\",lineHeight:\"normal\",size:\"1rem\",family:[\"serif\"]},h=c(t,/\\s+/);e=h.shift();){if(-1!==i.indexOf(e))return[\"style\",\"variant\",\"weight\",\"stretch\"].forEach((function(t){r[t]=e})),f[t]=r;if(-1===s.indexOf(e))if(\"normal\"!==e&&\"small-caps\"!==e)if(-1===l.indexOf(e)){if(-1===o.indexOf(e)){if(u(e)){var d=c(e,\"/\");if(r.size=d[0],null!=d[1]?r.lineHeight=p(d[1]):\"/\"===h[0]&&(h.shift(),r.lineHeight=p(h.shift())),!h.length)throw new Error(\"Missing required font-family.\");return r.family=c(h.join(\" \"),/\\s*,\\s*/).map(n),f[t]=r}throw new Error(\"Unknown or unsupported font token: \"+e)}r.weight=e}else r.stretch=e;else r.variant=e;else r.style=e}throw new Error(\"Missing required font-size.\")}function p(t){var e=parseFloat(t);return e.toString()===t?e:t}},{\"./lib/util\":151,\"css-font-stretch-keywords\":147,\"css-font-style-keywords\":148,\"css-font-weight-keywords\":149,\"css-global-keywords\":154,\"css-system-font-keywords\":155,\"string-split-by\":585,unquote:616}],153:[function(t,e,r){\"use strict\";var n=t(\"pick-by-alias\"),i=t(\"./lib/util\").isSize,a=m(t(\"css-global-keywords\")),o=m(t(\"css-system-font-keywords\")),s=m(t(\"css-font-weight-keywords\")),l=m(t(\"css-font-style-keywords\")),c=m(t(\"css-font-stretch-keywords\")),u={normal:1,\"small-caps\":1},f={serif:1,\"sans-serif\":1,monospace:1,cursive:1,fantasy:1,\"system-ui\":1},h=\"1rem\",p=\"serif\";function d(t,e){if(t&&!e[t]&&!a[t])throw Error(\"Unknown keyword `\"+t+\"`\");return t}function m(t){for(var e={},r=0;r<t.length;r++)e[t[r]]=1;return e}e.exports=function(t){if((t=n(t,{style:\"style fontstyle fontStyle font-style slope distinction\",variant:\"variant font-variant fontVariant fontvariant var capitalization\",weight:\"weight w font-weight fontWeight fontweight\",stretch:\"stretch font-stretch fontStretch fontstretch width\",size:\"size s font-size fontSize fontsize height em emSize\",lineHeight:\"lh line-height lineHeight lineheight leading\",family:\"font family fontFamily font-family fontfamily type typeface face\",system:\"system reserved default global\"})).system)return t.system&&d(t.system,o),t.system;if(d(t.style,l),d(t.variant,u),d(t.weight,s),d(t.stretch,c),null==t.size&&(t.size=h),\"number\"==typeof t.size&&(t.size+=\"px\"),!i)throw Error(\"Bad size value `\"+t.size+\"`\");t.family||(t.family=p),Array.isArray(t.family)&&(t.family.length||(t.family=[p]),t.family=t.family.map((function(t){return f[t]?t:'\"'+t+'\"'})).join(\", \"));var e=[];return e.push(t.style),t.variant!==t.style&&e.push(t.variant),t.weight!==t.variant&&t.weight!==t.style&&e.push(t.weight),t.stretch!==t.weight&&t.stretch!==t.variant&&t.stretch!==t.style&&e.push(t.stretch),e.push(t.size+(null==t.lineHeight||\"normal\"===t.lineHeight||t.lineHeight+\"\"==\"1\"?\"\":\"/\"+t.lineHeight)),e.push(t.family),e.filter(Boolean).join(\" \")}},{\"./lib/util\":151,\"css-font-stretch-keywords\":147,\"css-font-style-keywords\":148,\"css-font-weight-keywords\":149,\"css-global-keywords\":154,\"css-system-font-keywords\":155,\"pick-by-alias\":494}],154:[function(t,e,r){e.exports=[\"inherit\",\"initial\",\"unset\"]},{}],155:[function(t,e,r){e.exports=[\"caption\",\"icon\",\"menu\",\"message-box\",\"small-caption\",\"status-bar\"]},{}],156:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,i,a){var o=i-1,s=i*i,l=o*o,c=(1+2*i)*l,u=i*l,f=s*(3-2*i),h=s*o;if(t.length){a||(a=new Array(t.length));for(var p=t.length-1;p>=0;--p)a[p]=c*t[p]+u*e[p]+f*r[p]+h*n[p];return a}return c*t+u*e+f*r+h*n},e.exports.derivative=function(t,e,r,n,i,a){var o=6*i*i-6*i,s=3*i*i-4*i+1,l=-6*i*i+6*i,c=3*i*i-2*i;if(t.length){a||(a=new Array(t.length));for(var u=t.length-1;u>=0;--u)a[u]=o*t[u]+s*e[u]+l*r[u]+c*n[u];return a}return o*t+s*e+l*r[u]+c*n}},{}],157:[function(t,e,r){\"use strict\";var n=t(\"./lib/thunk.js\");function i(){this.argTypes=[],this.shimArgs=[],this.arrayArgs=[],this.arrayBlockIndices=[],this.scalarArgs=[],this.offsetArgs=[],this.offsetArgIndex=[],this.indexArgs=[],this.shapeArgs=[],this.funcName=\"\",this.pre=null,this.body=null,this.post=null,this.debug=!1}e.exports=function(t){var e=new i;e.pre=t.pre,e.body=t.body,e.post=t.post;var r=t.args.slice(0);e.argTypes=r;for(var a=0;a<r.length;++a){var o=r[a];if(\"array\"===o||\"object\"==typeof o&&o.blockIndices){if(e.argTypes[a]=\"array\",e.arrayArgs.push(a),e.arrayBlockIndices.push(o.blockIndices?o.blockIndices:0),e.shimArgs.push(\"array\"+a),a<e.pre.args.length&&e.pre.args[a].count>0)throw new Error(\"cwise: pre() block may not reference array args\");if(a<e.post.args.length&&e.post.args[a].count>0)throw new Error(\"cwise: post() block may not reference array args\")}else if(\"scalar\"===o)e.scalarArgs.push(a),e.shimArgs.push(\"scalar\"+a);else if(\"index\"===o){if(e.indexArgs.push(a),a<e.pre.args.length&&e.pre.args[a].count>0)throw new Error(\"cwise: pre() block may not reference array index\");if(a<e.body.args.length&&e.body.args[a].lvalue)throw new Error(\"cwise: body() block may not write to array index\");if(a<e.post.args.length&&e.post.args[a].count>0)throw new Error(\"cwise: post() block may not reference array index\")}else if(\"shape\"===o){if(e.shapeArgs.push(a),a<e.pre.args.length&&e.pre.args[a].lvalue)throw new Error(\"cwise: pre() block may not write to array shape\");if(a<e.body.args.length&&e.body.args[a].lvalue)throw new Error(\"cwise: body() block may not write to array shape\");if(a<e.post.args.length&&e.post.args[a].lvalue)throw new Error(\"cwise: post() block may not write to array shape\")}else{if(\"object\"!=typeof o||!o.offset)throw new Error(\"cwise: Unknown argument type \"+r[a]);e.argTypes[a]=\"offset\",e.offsetArgs.push({array:o.array,offset:o.offset}),e.offsetArgIndex.push(a)}}if(e.arrayArgs.length<=0)throw new Error(\"cwise: No array arguments specified\");if(e.pre.args.length>r.length)throw new Error(\"cwise: Too many arguments in pre() block\");if(e.body.args.length>r.length)throw new Error(\"cwise: Too many arguments in body() block\");if(e.post.args.length>r.length)throw new Error(\"cwise: Too many arguments in post() block\");return e.debug=!!t.printCode||!!t.debug,e.funcName=t.funcName||\"cwise\",e.blockSize=t.blockSize||64,n(e)}},{\"./lib/thunk.js\":159}],158:[function(t,e,r){\"use strict\";var n=t(\"uniq\");function i(t,e,r){var n,i,a=t.length,o=e.arrayArgs.length,s=e.indexArgs.length>0,l=[],c=[],u=0,f=0;for(n=0;n<a;++n)c.push([\"i\",n,\"=0\"].join(\"\"));for(i=0;i<o;++i)for(n=0;n<a;++n)f=u,u=t[n],0===n?c.push([\"d\",i,\"s\",n,\"=t\",i,\"p\",u].join(\"\")):c.push([\"d\",i,\"s\",n,\"=(t\",i,\"p\",u,\"-s\",f,\"*t\",i,\"p\",f,\")\"].join(\"\"));for(c.length>0&&l.push(\"var \"+c.join(\",\")),n=a-1;n>=0;--n)u=t[n],l.push([\"for(i\",n,\"=0;i\",n,\"<s\",u,\";++i\",n,\"){\"].join(\"\"));for(l.push(r),n=0;n<a;++n){for(f=u,u=t[n],i=0;i<o;++i)l.push([\"p\",i,\"+=d\",i,\"s\",n].join(\"\"));s&&(n>0&&l.push([\"index[\",f,\"]-=s\",f].join(\"\")),l.push([\"++index[\",u,\"]\"].join(\"\"))),l.push(\"}\")}return l.join(\"\\n\")}function a(t,e,r){for(var n=t.body,i=[],a=[],o=0;o<t.args.length;++o){var s=t.args[o];if(!(s.count<=0)){var l=new RegExp(s.name,\"g\"),c=\"\",u=e.arrayArgs.indexOf(o);switch(e.argTypes[o]){case\"offset\":var f=e.offsetArgIndex.indexOf(o);u=e.offsetArgs[f].array,c=\"+q\"+f;case\"array\":c=\"p\"+u+c;var h=\"l\"+o,p=\"a\"+u;if(0===e.arrayBlockIndices[u])1===s.count?\"generic\"===r[u]?s.lvalue?(i.push([\"var \",h,\"=\",p,\".get(\",c,\")\"].join(\"\")),n=n.replace(l,h),a.push([p,\".set(\",c,\",\",h,\")\"].join(\"\"))):n=n.replace(l,[p,\".get(\",c,\")\"].join(\"\")):n=n.replace(l,[p,\"[\",c,\"]\"].join(\"\")):\"generic\"===r[u]?(i.push([\"var \",h,\"=\",p,\".get(\",c,\")\"].join(\"\")),n=n.replace(l,h),s.lvalue&&a.push([p,\".set(\",c,\",\",h,\")\"].join(\"\"))):(i.push([\"var \",h,\"=\",p,\"[\",c,\"]\"].join(\"\")),n=n.replace(l,h),s.lvalue&&a.push([p,\"[\",c,\"]=\",h].join(\"\")));else{for(var d=[s.name],m=[c],g=0;g<Math.abs(e.arrayBlockIndices[u]);g++)d.push(\"\\\\s*\\\\[([^\\\\]]+)\\\\]\"),m.push(\"$\"+(g+1)+\"*t\"+u+\"b\"+g);if(l=new RegExp(d.join(\"\"),\"g\"),c=m.join(\"+\"),\"generic\"===r[u])throw new Error(\"cwise: Generic arrays not supported in combination with blocks!\");n=n.replace(l,[p,\"[\",c,\"]\"].join(\"\"))}break;case\"scalar\":n=n.replace(l,\"Y\"+e.scalarArgs.indexOf(o));break;case\"index\":n=n.replace(l,\"index\");break;case\"shape\":n=n.replace(l,\"shape\")}}}return[i.join(\"\\n\"),n,a.join(\"\\n\")].join(\"\\n\").trim()}function o(t){for(var e=new Array(t.length),r=!0,n=0;n<t.length;++n){var i=t[n],a=i.match(/\\d+/);a=a?a[0]:\"\",0===i.charAt(0)?e[n]=\"u\"+i.charAt(1)+a:e[n]=i.charAt(0)+a,n>0&&(r=r&&e[n]===e[n-1])}return r?e[0]:e.join(\"\")}e.exports=function(t,e){for(var r=e[1].length-Math.abs(t.arrayBlockIndices[0])|0,s=new Array(t.arrayArgs.length),l=new Array(t.arrayArgs.length),c=0;c<t.arrayArgs.length;++c)l[c]=e[2*c],s[c]=e[2*c+1];var u=[],f=[],h=[],p=[],d=[];for(c=0;c<t.arrayArgs.length;++c){t.arrayBlockIndices[c]<0?(h.push(0),p.push(r),u.push(r),f.push(r+t.arrayBlockIndices[c])):(h.push(t.arrayBlockIndices[c]),p.push(t.arrayBlockIndices[c]+r),u.push(0),f.push(t.arrayBlockIndices[c]));for(var m=[],g=0;g<s[c].length;g++)h[c]<=s[c][g]&&s[c][g]<p[c]&&m.push(s[c][g]-h[c]);d.push(m)}var v=[\"SS\"],y=[\"'use strict'\"],x=[];for(g=0;g<r;++g)x.push([\"s\",g,\"=SS[\",g,\"]\"].join(\"\"));for(c=0;c<t.arrayArgs.length;++c){v.push(\"a\"+c),v.push(\"t\"+c),v.push(\"p\"+c);for(g=0;g<r;++g)x.push([\"t\",c,\"p\",g,\"=t\",c,\"[\",h[c]+g,\"]\"].join(\"\"));for(g=0;g<Math.abs(t.arrayBlockIndices[c]);++g)x.push([\"t\",c,\"b\",g,\"=t\",c,\"[\",u[c]+g,\"]\"].join(\"\"))}for(c=0;c<t.scalarArgs.length;++c)v.push(\"Y\"+c);if(t.shapeArgs.length>0&&x.push(\"shape=SS.slice(0)\"),t.indexArgs.length>0){var b=new Array(r);for(c=0;c<r;++c)b[c]=\"0\";x.push([\"index=[\",b.join(\",\"),\"]\"].join(\"\"))}for(c=0;c<t.offsetArgs.length;++c){var _=t.offsetArgs[c],w=[];for(g=0;g<_.offset.length;++g)0!==_.offset[g]&&(1===_.offset[g]?w.push([\"t\",_.array,\"p\",g].join(\"\")):w.push([_.offset[g],\"*t\",_.array,\"p\",g].join(\"\")));0===w.length?x.push(\"q\"+c+\"=0\"):x.push([\"q\",c,\"=\",w.join(\"+\")].join(\"\"))}var T=n([].concat(t.pre.thisVars).concat(t.body.thisVars).concat(t.post.thisVars));for((x=x.concat(T)).length>0&&y.push(\"var \"+x.join(\",\")),c=0;c<t.arrayArgs.length;++c)y.push(\"p\"+c+\"|=0\");t.pre.body.length>3&&y.push(a(t.pre,t,l));var k=a(t.body,t,l),M=function(t){for(var e=0,r=t[0].length;e<r;){for(var n=1;n<t.length;++n)if(t[n][e]!==t[0][e])return e;++e}return e}(d);M<r?y.push(function(t,e,r,n){for(var a=e.length,o=r.arrayArgs.length,s=r.blockSize,l=r.indexArgs.length>0,c=[],u=0;u<o;++u)c.push([\"var offset\",u,\"=p\",u].join(\"\"));for(u=t;u<a;++u)c.push([\"for(var j\"+u+\"=SS[\",e[u],\"]|0;j\",u,\">0;){\"].join(\"\")),c.push([\"if(j\",u,\"<\",s,\"){\"].join(\"\")),c.push([\"s\",e[u],\"=j\",u].join(\"\")),c.push([\"j\",u,\"=0\"].join(\"\")),c.push([\"}else{s\",e[u],\"=\",s].join(\"\")),c.push([\"j\",u,\"-=\",s,\"}\"].join(\"\")),l&&c.push([\"index[\",e[u],\"]=j\",u].join(\"\"));for(u=0;u<o;++u){for(var f=[\"offset\"+u],h=t;h<a;++h)f.push([\"j\",h,\"*t\",u,\"p\",e[h]].join(\"\"));c.push([\"p\",u,\"=(\",f.join(\"+\"),\")\"].join(\"\"))}for(c.push(i(e,r,n)),u=t;u<a;++u)c.push(\"}\");return c.join(\"\\n\")}(M,d[0],t,k)):y.push(i(d[0],t,k)),t.post.body.length>3&&y.push(a(t.post,t,l)),t.debug&&console.log(\"-----Generated cwise routine for \",e,\":\\n\"+y.join(\"\\n\")+\"\\n----------\");var A=[t.funcName||\"unnamed\",\"_cwise_loop_\",s[0].join(\"s\"),\"m\",M,o(l)].join(\"\");return new Function([\"function \",A,\"(\",v.join(\",\"),\"){\",y.join(\"\\n\"),\"} return \",A].join(\"\"))()}},{uniq:615}],159:[function(t,e,r){\"use strict\";var n=t(\"./compile.js\");e.exports=function(t){var e=[\"'use strict'\",\"var CACHED={}\"],r=[],i=t.funcName+\"_cwise_thunk\";e.push([\"return function \",i,\"(\",t.shimArgs.join(\",\"),\"){\"].join(\"\"));for(var a=[],o=[],s=[[\"array\",t.arrayArgs[0],\".shape.slice(\",Math.max(0,t.arrayBlockIndices[0]),t.arrayBlockIndices[0]<0?\",\"+t.arrayBlockIndices[0]+\")\":\")\"].join(\"\")],l=[],c=[],u=0;u<t.arrayArgs.length;++u){var f=t.arrayArgs[u];r.push([\"t\",f,\"=array\",f,\".dtype,\",\"r\",f,\"=array\",f,\".order\"].join(\"\")),a.push(\"t\"+f),a.push(\"r\"+f),o.push(\"t\"+f),o.push(\"r\"+f+\".join()\"),s.push(\"array\"+f+\".data\"),s.push(\"array\"+f+\".stride\"),s.push(\"array\"+f+\".offset|0\"),u>0&&(l.push(\"array\"+t.arrayArgs[0]+\".shape.length===array\"+f+\".shape.length+\"+(Math.abs(t.arrayBlockIndices[0])-Math.abs(t.arrayBlockIndices[u]))),c.push(\"array\"+t.arrayArgs[0]+\".shape[shapeIndex+\"+Math.max(0,t.arrayBlockIndices[0])+\"]===array\"+f+\".shape[shapeIndex+\"+Math.max(0,t.arrayBlockIndices[u])+\"]\"))}for(t.arrayArgs.length>1&&(e.push(\"if (!(\"+l.join(\" && \")+\")) throw new Error('cwise: Arrays do not all have the same dimensionality!')\"),e.push(\"for(var shapeIndex=array\"+t.arrayArgs[0]+\".shape.length-\"+Math.abs(t.arrayBlockIndices[0])+\"; shapeIndex--\\x3e0;) {\"),e.push(\"if (!(\"+c.join(\" && \")+\")) throw new Error('cwise: Arrays do not all have the same shape!')\"),e.push(\"}\")),u=0;u<t.scalarArgs.length;++u)s.push(\"scalar\"+t.scalarArgs[u]);return r.push([\"type=[\",o.join(\",\"),\"].join()\"].join(\"\")),r.push(\"proc=CACHED[type]\"),e.push(\"var \"+r.join(\",\")),e.push([\"if(!proc){\",\"CACHED[type]=proc=compile([\",a.join(\",\"),\"])}\",\"return proc(\",s.join(\",\"),\")}\"].join(\"\")),t.debug&&console.log(\"-----Generated thunk:\\n\"+e.join(\"\\n\")+\"\\n----------\"),new Function(\"compile\",e.join(\"\\n\"))(n.bind(void 0,t))}},{\"./compile.js\":158}],160:[function(t,e,r){\"use strict\";var n,i=t(\"type/value/is\"),a=t(\"type/value/ensure\"),o=t(\"type/plain-function/ensure\"),s=t(\"es5-ext/object/copy\"),l=t(\"es5-ext/object/normalize-options\"),c=t(\"es5-ext/object/map\"),u=Function.prototype.bind,f=Object.defineProperty,h=Object.prototype.hasOwnProperty;n=function(t,e,r){var n,i=a(e)&&o(e.value);return delete(n=s(e)).writable,delete n.value,n.get=function(){return!r.overwriteDefinition&&h.call(this,t)?i:(e.value=u.call(i,r.resolveContext?r.resolveContext(this):this),f(this,t,e),this[t])},n},e.exports=function(t){var e=l(arguments[1]);return i(e.resolveContext)&&o(e.resolveContext),c(t,(function(t,r){return n(r,t,e)}))}},{\"es5-ext/object/copy\":201,\"es5-ext/object/map\":209,\"es5-ext/object/normalize-options\":210,\"type/plain-function/ensure\":607,\"type/value/ensure\":611,\"type/value/is\":612}],161:[function(t,e,r){\"use strict\";var n=t(\"type/value/is\"),i=t(\"type/plain-function/is\"),a=t(\"es5-ext/object/assign\"),o=t(\"es5-ext/object/normalize-options\"),s=t(\"es5-ext/string/#/contains\");(e.exports=function(t,e){var r,i,l,c,u;return arguments.length<2||\"string\"!=typeof t?(c=e,e=t,t=null):c=arguments[2],n(t)?(r=s.call(t,\"c\"),i=s.call(t,\"e\"),l=s.call(t,\"w\")):(r=l=!0,i=!1),u={value:e,configurable:r,enumerable:i,writable:l},c?a(o(c),u):u}).gs=function(t,e,r){var l,c,u,f;return\"string\"!=typeof t?(u=r,r=e,e=t,t=null):u=arguments[3],n(e)?i(e)?n(r)?i(r)||(u=r,r=void 0):r=void 0:(u=e,e=r=void 0):e=void 0,n(t)?(l=s.call(t,\"c\"),c=s.call(t,\"e\")):(l=!0,c=!1),f={get:e,set:r,configurable:l,enumerable:c},u?a(o(u),f):f}},{\"es5-ext/object/assign\":198,\"es5-ext/object/normalize-options\":210,\"es5-ext/string/#/contains\":217,\"type/plain-function/is\":608,\"type/value/is\":612}],162:[function(t,e,r){!function(t,n){n(\"object\"==typeof r&&void 0!==e?r:t.d3=t.d3||{})}(this,(function(t){\"use strict\";function e(t,e){return t<e?-1:t>e?1:t>=e?0:NaN}function r(t){var r;return 1===t.length&&(r=t,t=function(t,n){return e(r(t),n)}),{left:function(e,r,n,i){for(null==n&&(n=0),null==i&&(i=e.length);n<i;){var a=n+i>>>1;t(e[a],r)<0?n=a+1:i=a}return n},right:function(e,r,n,i){for(null==n&&(n=0),null==i&&(i=e.length);n<i;){var a=n+i>>>1;t(e[a],r)>0?i=a:n=a+1}return n}}}var n=r(e),i=n.right,a=n.left;function o(t,e){return[t,e]}function s(t){return null===t?NaN:+t}function l(t,e){var r,n,i=t.length,a=0,o=-1,l=0,c=0;if(null==e)for(;++o<i;)isNaN(r=s(t[o]))||(c+=(n=r-l)*(r-(l+=n/++a)));else for(;++o<i;)isNaN(r=s(e(t[o],o,t)))||(c+=(n=r-l)*(r-(l+=n/++a)));if(a>1)return c/(a-1)}function c(t,e){var r=l(t,e);return r?Math.sqrt(r):r}function u(t,e){var r,n,i,a=t.length,o=-1;if(null==e){for(;++o<a;)if(null!=(r=t[o])&&r>=r)for(n=i=r;++o<a;)null!=(r=t[o])&&(n>r&&(n=r),i<r&&(i=r))}else for(;++o<a;)if(null!=(r=e(t[o],o,t))&&r>=r)for(n=i=r;++o<a;)null!=(r=e(t[o],o,t))&&(n>r&&(n=r),i<r&&(i=r));return[n,i]}var f=Array.prototype,h=f.slice,p=f.map;function d(t){return function(){return t}}function m(t){return t}function g(t,e,r){t=+t,e=+e,r=(i=arguments.length)<2?(e=t,t=0,1):i<3?1:+r;for(var n=-1,i=0|Math.max(0,Math.ceil((e-t)/r)),a=new Array(i);++n<i;)a[n]=t+n*r;return a}var v=Math.sqrt(50),y=Math.sqrt(10),x=Math.sqrt(2);function b(t,e,r){var n=(e-t)/Math.max(0,r),i=Math.floor(Math.log(n)/Math.LN10),a=n/Math.pow(10,i);return i>=0?(a>=v?10:a>=y?5:a>=x?2:1)*Math.pow(10,i):-Math.pow(10,-i)/(a>=v?10:a>=y?5:a>=x?2:1)}function _(t,e,r){var n=Math.abs(e-t)/Math.max(0,r),i=Math.pow(10,Math.floor(Math.log(n)/Math.LN10)),a=n/i;return a>=v?i*=10:a>=y?i*=5:a>=x&&(i*=2),e<t?-i:i}function w(t){return Math.ceil(Math.log(t.length)/Math.LN2)+1}function T(t,e,r){if(null==r&&(r=s),n=t.length){if((e=+e)<=0||n<2)return+r(t[0],0,t);if(e>=1)return+r(t[n-1],n-1,t);var n,i=(n-1)*e,a=Math.floor(i),o=+r(t[a],a,t);return o+(+r(t[a+1],a+1,t)-o)*(i-a)}}function k(t,e){var r,n,i=t.length,a=-1;if(null==e){for(;++a<i;)if(null!=(r=t[a])&&r>=r)for(n=r;++a<i;)null!=(r=t[a])&&n>r&&(n=r)}else for(;++a<i;)if(null!=(r=e(t[a],a,t))&&r>=r)for(n=r;++a<i;)null!=(r=e(t[a],a,t))&&n>r&&(n=r);return n}function M(t){if(!(i=t.length))return[];for(var e=-1,r=k(t,A),n=new Array(r);++e<r;)for(var i,a=-1,o=n[e]=new Array(i);++a<i;)o[a]=t[a][e];return n}function A(t){return t.length}t.bisect=i,t.bisectRight=i,t.bisectLeft=a,t.ascending=e,t.bisector=r,t.cross=function(t,e,r){var n,i,a,s,l=t.length,c=e.length,u=new Array(l*c);for(null==r&&(r=o),n=a=0;n<l;++n)for(s=t[n],i=0;i<c;++i,++a)u[a]=r(s,e[i]);return u},t.descending=function(t,e){return e<t?-1:e>t?1:e>=t?0:NaN},t.deviation=c,t.extent=u,t.histogram=function(){var t=m,e=u,r=w;function n(n){var a,o,s=n.length,l=new Array(s);for(a=0;a<s;++a)l[a]=t(n[a],a,n);var c=e(l),u=c[0],f=c[1],h=r(l,u,f);Array.isArray(h)||(h=_(u,f,h),h=g(Math.ceil(u/h)*h,f,h));for(var p=h.length;h[0]<=u;)h.shift(),--p;for(;h[p-1]>f;)h.pop(),--p;var d,m=new Array(p+1);for(a=0;a<=p;++a)(d=m[a]=[]).x0=a>0?h[a-1]:u,d.x1=a<p?h[a]:f;for(a=0;a<s;++a)u<=(o=l[a])&&o<=f&&m[i(h,o,0,p)].push(n[a]);return m}return n.value=function(e){return arguments.length?(t=\"function\"==typeof e?e:d(e),n):t},n.domain=function(t){return arguments.length?(e=\"function\"==typeof t?t:d([t[0],t[1]]),n):e},n.thresholds=function(t){return arguments.length?(r=\"function\"==typeof t?t:Array.isArray(t)?d(h.call(t)):d(t),n):r},n},t.thresholdFreedmanDiaconis=function(t,r,n){return t=p.call(t,s).sort(e),Math.ceil((n-r)/(2*(T(t,.75)-T(t,.25))*Math.pow(t.length,-1/3)))},t.thresholdScott=function(t,e,r){return Math.ceil((r-e)/(3.5*c(t)*Math.pow(t.length,-1/3)))},t.thresholdSturges=w,t.max=function(t,e){var r,n,i=t.length,a=-1;if(null==e){for(;++a<i;)if(null!=(r=t[a])&&r>=r)for(n=r;++a<i;)null!=(r=t[a])&&r>n&&(n=r)}else for(;++a<i;)if(null!=(r=e(t[a],a,t))&&r>=r)for(n=r;++a<i;)null!=(r=e(t[a],a,t))&&r>n&&(n=r);return n},t.mean=function(t,e){var r,n=t.length,i=n,a=-1,o=0;if(null==e)for(;++a<n;)isNaN(r=s(t[a]))?--i:o+=r;else for(;++a<n;)isNaN(r=s(e(t[a],a,t)))?--i:o+=r;if(i)return o/i},t.median=function(t,r){var n,i=t.length,a=-1,o=[];if(null==r)for(;++a<i;)isNaN(n=s(t[a]))||o.push(n);else for(;++a<i;)isNaN(n=s(r(t[a],a,t)))||o.push(n);return T(o.sort(e),.5)},t.merge=function(t){for(var e,r,n,i=t.length,a=-1,o=0;++a<i;)o+=t[a].length;for(r=new Array(o);--i>=0;)for(e=(n=t[i]).length;--e>=0;)r[--o]=n[e];return r},t.min=k,t.pairs=function(t,e){null==e&&(e=o);for(var r=0,n=t.length-1,i=t[0],a=new Array(n<0?0:n);r<n;)a[r]=e(i,i=t[++r]);return a},t.permute=function(t,e){for(var r=e.length,n=new Array(r);r--;)n[r]=t[e[r]];return n},t.quantile=T,t.range=g,t.scan=function(t,r){if(n=t.length){var n,i,a=0,o=0,s=t[o];for(null==r&&(r=e);++a<n;)(r(i=t[a],s)<0||0!==r(s,s))&&(s=i,o=a);return 0===r(s,s)?o:void 0}},t.shuffle=function(t,e,r){for(var n,i,a=(null==r?t.length:r)-(e=null==e?0:+e);a;)i=Math.random()*a--|0,n=t[a+e],t[a+e]=t[i+e],t[i+e]=n;return t},t.sum=function(t,e){var r,n=t.length,i=-1,a=0;if(null==e)for(;++i<n;)(r=+t[i])&&(a+=r);else for(;++i<n;)(r=+e(t[i],i,t))&&(a+=r);return a},t.ticks=function(t,e,r){var n,i,a,o,s=-1;if(r=+r,(t=+t)===(e=+e)&&r>0)return[t];if((n=e<t)&&(i=t,t=e,e=i),0===(o=b(t,e,r))||!isFinite(o))return[];if(o>0)for(t=Math.ceil(t/o),e=Math.floor(e/o),a=new Array(i=Math.ceil(e-t+1));++s<i;)a[s]=(t+s)*o;else for(t=Math.floor(t*o),e=Math.ceil(e*o),a=new Array(i=Math.ceil(t-e+1));++s<i;)a[s]=(t-s)/o;return n&&a.reverse(),a},t.tickIncrement=b,t.tickStep=_,t.transpose=M,t.variance=l,t.zip=function(){return M(arguments)},Object.defineProperty(t,\"__esModule\",{value:!0})}))},{}],163:[function(t,e,r){!function(t,n){n(\"object\"==typeof r&&void 0!==e?r:t.d3=t.d3||{})}(this,(function(t){\"use strict\";function e(){}function r(t,r){var n=new e;if(t instanceof e)t.each((function(t,e){n.set(e,t)}));else if(Array.isArray(t)){var i,a=-1,o=t.length;if(null==r)for(;++a<o;)n.set(a,t[a]);else for(;++a<o;)n.set(r(i=t[a],a,t),i)}else if(t)for(var s in t)n.set(s,t[s]);return n}function n(){return{}}function i(t,e,r){t[e]=r}function a(){return r()}function o(t,e,r){t.set(e,r)}function s(){}e.prototype=r.prototype={constructor:e,has:function(t){return\"$\"+t in this},get:function(t){return this[\"$\"+t]},set:function(t,e){return this[\"$\"+t]=e,this},remove:function(t){var e=\"$\"+t;return e in this&&delete this[e]},clear:function(){for(var t in this)\"$\"===t[0]&&delete this[t]},keys:function(){var t=[];for(var e in this)\"$\"===e[0]&&t.push(e.slice(1));return t},values:function(){var t=[];for(var e in this)\"$\"===e[0]&&t.push(this[e]);return t},entries:function(){var t=[];for(var e in this)\"$\"===e[0]&&t.push({key:e.slice(1),value:this[e]});return t},size:function(){var t=0;for(var e in this)\"$\"===e[0]&&++t;return t},empty:function(){for(var t in this)if(\"$\"===t[0])return!1;return!0},each:function(t){for(var e in this)\"$\"===e[0]&&t(this[e],e.slice(1),this)}};var l=r.prototype;function c(t,e){var r=new s;if(t instanceof s)t.each((function(t){r.add(t)}));else if(t){var n=-1,i=t.length;if(null==e)for(;++n<i;)r.add(t[n]);else for(;++n<i;)r.add(e(t[n],n,t))}return r}s.prototype=c.prototype={constructor:s,has:l.has,add:function(t){return this[\"$\"+(t+=\"\")]=t,this},remove:l.remove,clear:l.clear,values:l.keys,size:l.size,empty:l.empty,each:l.each},t.nest=function(){var t,e,s,l=[],c=[];function u(n,i,a,o){if(i>=l.length)return null!=t&&n.sort(t),null!=e?e(n):n;for(var s,c,f,h=-1,p=n.length,d=l[i++],m=r(),g=a();++h<p;)(f=m.get(s=d(c=n[h])+\"\"))?f.push(c):m.set(s,[c]);return m.each((function(t,e){o(g,e,u(t,i,a,o))})),g}return s={object:function(t){return u(t,0,n,i)},map:function(t){return u(t,0,a,o)},entries:function(t){return function t(r,n){if(++n>l.length)return r;var i,a=c[n-1];return null!=e&&n>=l.length?i=r.entries():(i=[],r.each((function(e,r){i.push({key:r,values:t(e,n)})}))),null!=a?i.sort((function(t,e){return a(t.key,e.key)})):i}(u(t,0,a,o),0)},key:function(t){return l.push(t),s},sortKeys:function(t){return c[l.length-1]=t,s},sortValues:function(e){return t=e,s},rollup:function(t){return e=t,s}}},t.set=c,t.map=r,t.keys=function(t){var e=[];for(var r in t)e.push(r);return e},t.values=function(t){var e=[];for(var r in t)e.push(t[r]);return e},t.entries=function(t){var e=[];for(var r in t)e.push({key:r,value:t[r]});return e},Object.defineProperty(t,\"__esModule\",{value:!0})}))},{}],164:[function(t,e,r){!function(t,n){\"object\"==typeof r&&void 0!==e?n(r):n((t=t||self).d3=t.d3||{})}(this,(function(t){\"use strict\";function e(t,e,r){t.prototype=e.prototype=r,r.constructor=t}function r(t,e){var r=Object.create(t.prototype);for(var n in e)r[n]=e[n];return r}function n(){}var i=\"\\\\s*([+-]?\\\\d+)\\\\s*\",a=\"\\\\s*([+-]?\\\\d*\\\\.?\\\\d+(?:[eE][+-]?\\\\d+)?)\\\\s*\",o=\"\\\\s*([+-]?\\\\d*\\\\.?\\\\d+(?:[eE][+-]?\\\\d+)?)%\\\\s*\",s=/^#([0-9a-f]{3,8})$/,l=new RegExp(\"^rgb\\\\(\"+[i,i,i]+\"\\\\)$\"),c=new RegExp(\"^rgb\\\\(\"+[o,o,o]+\"\\\\)$\"),u=new RegExp(\"^rgba\\\\(\"+[i,i,i,a]+\"\\\\)$\"),f=new RegExp(\"^rgba\\\\(\"+[o,o,o,a]+\"\\\\)$\"),h=new RegExp(\"^hsl\\\\(\"+[a,o,o]+\"\\\\)$\"),p=new RegExp(\"^hsla\\\\(\"+[a,o,o,a]+\"\\\\)$\"),d={aliceblue:15792383,antiquewhite:16444375,aqua:65535,aquamarine:8388564,azure:15794175,beige:16119260,bisque:16770244,black:0,blanchedalmond:16772045,blue:255,blueviolet:9055202,brown:10824234,burlywood:14596231,cadetblue:6266528,chartreuse:8388352,chocolate:13789470,coral:16744272,cornflowerblue:6591981,cornsilk:16775388,crimson:14423100,cyan:65535,darkblue:139,darkcyan:35723,darkgoldenrod:12092939,darkgray:11119017,darkgreen:25600,darkgrey:11119017,darkkhaki:12433259,darkmagenta:9109643,darkolivegreen:5597999,darkorange:16747520,darkorchid:10040012,darkred:9109504,darksalmon:15308410,darkseagreen:9419919,darkslateblue:4734347,darkslategray:3100495,darkslategrey:3100495,darkturquoise:52945,darkviolet:9699539,deeppink:16716947,deepskyblue:49151,dimgray:6908265,dimgrey:6908265,dodgerblue:2003199,firebrick:11674146,floralwhite:16775920,forestgreen:2263842,fuchsia:16711935,gainsboro:14474460,ghostwhite:16316671,gold:16766720,goldenrod:14329120,gray:8421504,green:32768,greenyellow:11403055,grey:8421504,honeydew:15794160,hotpink:16738740,indianred:13458524,indigo:4915330,ivory:16777200,khaki:15787660,lavender:15132410,lavenderblush:16773365,lawngreen:8190976,lemonchiffon:16775885,lightblue:11393254,lightcoral:15761536,lightcyan:14745599,lightgoldenrodyellow:16448210,lightgray:13882323,lightgreen:9498256,lightgrey:13882323,lightpink:16758465,lightsalmon:16752762,lightseagreen:2142890,lightskyblue:8900346,lightslategray:7833753,lightslategrey:7833753,lightsteelblue:11584734,lightyellow:16777184,lime:65280,limegreen:3329330,linen:16445670,magenta:16711935,maroon:8388608,mediumaquamarine:6737322,mediumblue:205,mediumorchid:12211667,mediumpurple:9662683,mediumseagreen:3978097,mediumslateblue:8087790,mediumspringgreen:64154,mediumturquoise:4772300,mediumvioletred:13047173,midnightblue:1644912,mintcream:16121850,mistyrose:16770273,moccasin:16770229,navajowhite:16768685,navy:128,oldlace:16643558,olive:8421376,olivedrab:7048739,orange:16753920,orangered:16729344,orchid:14315734,palegoldenrod:15657130,palegreen:10025880,paleturquoise:11529966,palevioletred:14381203,papayawhip:16773077,peachpuff:16767673,peru:13468991,pink:16761035,plum:14524637,powderblue:11591910,purple:8388736,rebeccapurple:6697881,red:16711680,rosybrown:12357519,royalblue:4286945,saddlebrown:9127187,salmon:16416882,sandybrown:16032864,seagreen:3050327,seashell:16774638,sienna:10506797,silver:12632256,skyblue:8900331,slateblue:6970061,slategray:7372944,slategrey:7372944,snow:16775930,springgreen:65407,steelblue:4620980,tan:13808780,teal:32896,thistle:14204888,tomato:16737095,turquoise:4251856,violet:15631086,wheat:16113331,white:16777215,whitesmoke:16119285,yellow:16776960,yellowgreen:10145074};function m(){return this.rgb().formatHex()}function g(){return this.rgb().formatRgb()}function v(t){var e,r;return t=(t+\"\").trim().toLowerCase(),(e=s.exec(t))?(r=e[1].length,e=parseInt(e[1],16),6===r?y(e):3===r?new w(e>>8&15|e>>4&240,e>>4&15|240&e,(15&e)<<4|15&e,1):8===r?x(e>>24&255,e>>16&255,e>>8&255,(255&e)/255):4===r?x(e>>12&15|e>>8&240,e>>8&15|e>>4&240,e>>4&15|240&e,((15&e)<<4|15&e)/255):null):(e=l.exec(t))?new w(e[1],e[2],e[3],1):(e=c.exec(t))?new w(255*e[1]/100,255*e[2]/100,255*e[3]/100,1):(e=u.exec(t))?x(e[1],e[2],e[3],e[4]):(e=f.exec(t))?x(255*e[1]/100,255*e[2]/100,255*e[3]/100,e[4]):(e=h.exec(t))?A(e[1],e[2]/100,e[3]/100,1):(e=p.exec(t))?A(e[1],e[2]/100,e[3]/100,e[4]):d.hasOwnProperty(t)?y(d[t]):\"transparent\"===t?new w(NaN,NaN,NaN,0):null}function y(t){return new w(t>>16&255,t>>8&255,255&t,1)}function x(t,e,r,n){return n<=0&&(t=e=r=NaN),new w(t,e,r,n)}function b(t){return t instanceof n||(t=v(t)),t?new w((t=t.rgb()).r,t.g,t.b,t.opacity):new w}function _(t,e,r,n){return 1===arguments.length?b(t):new w(t,e,r,null==n?1:n)}function w(t,e,r,n){this.r=+t,this.g=+e,this.b=+r,this.opacity=+n}function T(){return\"#\"+M(this.r)+M(this.g)+M(this.b)}function k(){var t=this.opacity;return(1===(t=isNaN(t)?1:Math.max(0,Math.min(1,t)))?\"rgb(\":\"rgba(\")+Math.max(0,Math.min(255,Math.round(this.r)||0))+\", \"+Math.max(0,Math.min(255,Math.round(this.g)||0))+\", \"+Math.max(0,Math.min(255,Math.round(this.b)||0))+(1===t?\")\":\", \"+t+\")\")}function M(t){return((t=Math.max(0,Math.min(255,Math.round(t)||0)))<16?\"0\":\"\")+t.toString(16)}function A(t,e,r,n){return n<=0?t=e=r=NaN:r<=0||r>=1?t=e=NaN:e<=0&&(t=NaN),new L(t,e,r,n)}function S(t){if(t instanceof L)return new L(t.h,t.s,t.l,t.opacity);if(t instanceof n||(t=v(t)),!t)return new L;if(t instanceof L)return t;var e=(t=t.rgb()).r/255,r=t.g/255,i=t.b/255,a=Math.min(e,r,i),o=Math.max(e,r,i),s=NaN,l=o-a,c=(o+a)/2;return l?(s=e===o?(r-i)/l+6*(r<i):r===o?(i-e)/l+2:(e-r)/l+4,l/=c<.5?o+a:2-o-a,s*=60):l=c>0&&c<1?0:s,new L(s,l,c,t.opacity)}function E(t,e,r,n){return 1===arguments.length?S(t):new L(t,e,r,null==n?1:n)}function L(t,e,r,n){this.h=+t,this.s=+e,this.l=+r,this.opacity=+n}function C(t,e,r){return 255*(t<60?e+(r-e)*t/60:t<180?r:t<240?e+(r-e)*(240-t)/60:e)}e(n,v,{copy:function(t){return Object.assign(new this.constructor,this,t)},displayable:function(){return this.rgb().displayable()},hex:m,formatHex:m,formatHsl:function(){return S(this).formatHsl()},formatRgb:g,toString:g}),e(w,_,r(n,{brighter:function(t){return t=null==t?1/.7:Math.pow(1/.7,t),new w(this.r*t,this.g*t,this.b*t,this.opacity)},darker:function(t){return t=null==t?.7:Math.pow(.7,t),new w(this.r*t,this.g*t,this.b*t,this.opacity)},rgb:function(){return this},displayable:function(){return-.5<=this.r&&this.r<255.5&&-.5<=this.g&&this.g<255.5&&-.5<=this.b&&this.b<255.5&&0<=this.opacity&&this.opacity<=1},hex:T,formatHex:T,formatRgb:k,toString:k})),e(L,E,r(n,{brighter:function(t){return t=null==t?1/.7:Math.pow(1/.7,t),new L(this.h,this.s,this.l*t,this.opacity)},darker:function(t){return t=null==t?.7:Math.pow(.7,t),new L(this.h,this.s,this.l*t,this.opacity)},rgb:function(){var t=this.h%360+360*(this.h<0),e=isNaN(t)||isNaN(this.s)?0:this.s,r=this.l,n=r+(r<.5?r:1-r)*e,i=2*r-n;return new w(C(t>=240?t-240:t+120,i,n),C(t,i,n),C(t<120?t+240:t-120,i,n),this.opacity)},displayable:function(){return(0<=this.s&&this.s<=1||isNaN(this.s))&&0<=this.l&&this.l<=1&&0<=this.opacity&&this.opacity<=1},formatHsl:function(){var t=this.opacity;return(1===(t=isNaN(t)?1:Math.max(0,Math.min(1,t)))?\"hsl(\":\"hsla(\")+(this.h||0)+\", \"+100*(this.s||0)+\"%, \"+100*(this.l||0)+\"%\"+(1===t?\")\":\", \"+t+\")\")}}));var P=Math.PI/180,I=180/Math.PI,O=6/29,z=3*O*O;function D(t){if(t instanceof F)return new F(t.l,t.a,t.b,t.opacity);if(t instanceof H)return G(t);t instanceof w||(t=b(t));var e,r,n=U(t.r),i=U(t.g),a=U(t.b),o=B((.2225045*n+.7168786*i+.0606169*a)/1);return n===i&&i===a?e=r=o:(e=B((.4360747*n+.3850649*i+.1430804*a)/.96422),r=B((.0139322*n+.0971045*i+.7141733*a)/.82521)),new F(116*o-16,500*(e-o),200*(o-r),t.opacity)}function R(t,e,r,n){return 1===arguments.length?D(t):new F(t,e,r,null==n?1:n)}function F(t,e,r,n){this.l=+t,this.a=+e,this.b=+r,this.opacity=+n}function B(t){return t>.008856451679035631?Math.pow(t,1/3):t/z+4/29}function N(t){return t>O?t*t*t:z*(t-4/29)}function j(t){return 255*(t<=.0031308?12.92*t:1.055*Math.pow(t,1/2.4)-.055)}function U(t){return(t/=255)<=.04045?t/12.92:Math.pow((t+.055)/1.055,2.4)}function V(t){if(t instanceof H)return new H(t.h,t.c,t.l,t.opacity);if(t instanceof F||(t=D(t)),0===t.a&&0===t.b)return new H(NaN,0<t.l&&t.l<100?0:NaN,t.l,t.opacity);var e=Math.atan2(t.b,t.a)*I;return new H(e<0?e+360:e,Math.sqrt(t.a*t.a+t.b*t.b),t.l,t.opacity)}function q(t,e,r,n){return 1===arguments.length?V(t):new H(t,e,r,null==n?1:n)}function H(t,e,r,n){this.h=+t,this.c=+e,this.l=+r,this.opacity=+n}function G(t){if(isNaN(t.h))return new F(t.l,0,0,t.opacity);var e=t.h*P;return new F(t.l,Math.cos(e)*t.c,Math.sin(e)*t.c,t.opacity)}e(F,R,r(n,{brighter:function(t){return new F(this.l+18*(null==t?1:t),this.a,this.b,this.opacity)},darker:function(t){return new F(this.l-18*(null==t?1:t),this.a,this.b,this.opacity)},rgb:function(){var t=(this.l+16)/116,e=isNaN(this.a)?t:t+this.a/500,r=isNaN(this.b)?t:t-this.b/200;return new w(j(3.1338561*(e=.96422*N(e))-1.6168667*(t=1*N(t))-.4906146*(r=.82521*N(r))),j(-.9787684*e+1.9161415*t+.033454*r),j(.0719453*e-.2289914*t+1.4052427*r),this.opacity)}})),e(H,q,r(n,{brighter:function(t){return new H(this.h,this.c,this.l+18*(null==t?1:t),this.opacity)},darker:function(t){return new H(this.h,this.c,this.l-18*(null==t?1:t),this.opacity)},rgb:function(){return G(this).rgb()}}));var Y=-.14861,W=1.78277,X=-.29227,Z=-.90649,J=1.97294,K=J*Z,Q=J*W,$=W*X-Z*Y;function tt(t){if(t instanceof rt)return new rt(t.h,t.s,t.l,t.opacity);t instanceof w||(t=b(t));var e=t.r/255,r=t.g/255,n=t.b/255,i=($*n+K*e-Q*r)/($+K-Q),a=n-i,o=(J*(r-i)-X*a)/Z,s=Math.sqrt(o*o+a*a)/(J*i*(1-i)),l=s?Math.atan2(o,a)*I-120:NaN;return new rt(l<0?l+360:l,s,i,t.opacity)}function et(t,e,r,n){return 1===arguments.length?tt(t):new rt(t,e,r,null==n?1:n)}function rt(t,e,r,n){this.h=+t,this.s=+e,this.l=+r,this.opacity=+n}e(rt,et,r(n,{brighter:function(t){return t=null==t?1/.7:Math.pow(1/.7,t),new rt(this.h,this.s,this.l*t,this.opacity)},darker:function(t){return t=null==t?.7:Math.pow(.7,t),new rt(this.h,this.s,this.l*t,this.opacity)},rgb:function(){var t=isNaN(this.h)?0:(this.h+120)*P,e=+this.l,r=isNaN(this.s)?0:this.s*e*(1-e),n=Math.cos(t),i=Math.sin(t);return new w(255*(e+r*(Y*n+W*i)),255*(e+r*(X*n+Z*i)),255*(e+r*(J*n)),this.opacity)}})),t.color=v,t.cubehelix=et,t.gray=function(t,e){return new F(t,0,0,null==e?1:e)},t.hcl=q,t.hsl=E,t.lab=R,t.lch=function(t,e,r,n){return 1===arguments.length?V(t):new H(r,e,t,null==n?1:n)},t.rgb=_,Object.defineProperty(t,\"__esModule\",{value:!0})}))},{}],165:[function(t,e,r){!function(t,n){\"object\"==typeof r&&void 0!==e?n(r):n((t=t||self).d3=t.d3||{})}(this,(function(t){\"use strict\";var e={value:function(){}};function r(){for(var t,e=0,r=arguments.length,i={};e<r;++e){if(!(t=arguments[e]+\"\")||t in i||/[\\s.]/.test(t))throw new Error(\"illegal type: \"+t);i[t]=[]}return new n(i)}function n(t){this._=t}function i(t,e){return t.trim().split(/^|\\s+/).map((function(t){var r=\"\",n=t.indexOf(\".\");if(n>=0&&(r=t.slice(n+1),t=t.slice(0,n)),t&&!e.hasOwnProperty(t))throw new Error(\"unknown type: \"+t);return{type:t,name:r}}))}function a(t,e){for(var r,n=0,i=t.length;n<i;++n)if((r=t[n]).name===e)return r.value}function o(t,r,n){for(var i=0,a=t.length;i<a;++i)if(t[i].name===r){t[i]=e,t=t.slice(0,i).concat(t.slice(i+1));break}return null!=n&&t.push({name:r,value:n}),t}n.prototype=r.prototype={constructor:n,on:function(t,e){var r,n=this._,s=i(t+\"\",n),l=-1,c=s.length;if(!(arguments.length<2)){if(null!=e&&\"function\"!=typeof e)throw new Error(\"invalid callback: \"+e);for(;++l<c;)if(r=(t=s[l]).type)n[r]=o(n[r],t.name,e);else if(null==e)for(r in n)n[r]=o(n[r],t.name,null);return this}for(;++l<c;)if((r=(t=s[l]).type)&&(r=a(n[r],t.name)))return r},copy:function(){var t={},e=this._;for(var r in e)t[r]=e[r].slice();return new n(t)},call:function(t,e){if((r=arguments.length-2)>0)for(var r,n,i=new Array(r),a=0;a<r;++a)i[a]=arguments[a+2];if(!this._.hasOwnProperty(t))throw new Error(\"unknown type: \"+t);for(a=0,r=(n=this._[t]).length;a<r;++a)n[a].value.apply(e,i)},apply:function(t,e,r){if(!this._.hasOwnProperty(t))throw new Error(\"unknown type: \"+t);for(var n=this._[t],i=0,a=n.length;i<a;++i)n[i].value.apply(e,r)}},t.dispatch=r,Object.defineProperty(t,\"__esModule\",{value:!0})}))},{}],166:[function(t,e,r){!function(n,i){\"object\"==typeof r&&void 0!==e?i(r,t(\"d3-quadtree\"),t(\"d3-collection\"),t(\"d3-dispatch\"),t(\"d3-timer\")):i(n.d3=n.d3||{},n.d3,n.d3,n.d3,n.d3)}(this,(function(t,e,r,n,i){\"use strict\";function a(t){return function(){return t}}function o(){return 1e-6*(Math.random()-.5)}function s(t){return t.x+t.vx}function l(t){return t.y+t.vy}function c(t){return t.index}function u(t,e){var r=t.get(e);if(!r)throw new Error(\"missing: \"+e);return r}function f(t){return t.x}function h(t){return t.y}var p=Math.PI*(3-Math.sqrt(5));t.forceCenter=function(t,e){var r;function n(){var n,i,a=r.length,o=0,s=0;for(n=0;n<a;++n)o+=(i=r[n]).x,s+=i.y;for(o=o/a-t,s=s/a-e,n=0;n<a;++n)(i=r[n]).x-=o,i.y-=s}return null==t&&(t=0),null==e&&(e=0),n.initialize=function(t){r=t},n.x=function(e){return arguments.length?(t=+e,n):t},n.y=function(t){return arguments.length?(e=+t,n):e},n},t.forceCollide=function(t){var r,n,i=1,c=1;function u(){for(var t,a,u,h,p,d,m,g=r.length,v=0;v<c;++v)for(a=e.quadtree(r,s,l).visitAfter(f),t=0;t<g;++t)u=r[t],d=n[u.index],m=d*d,h=u.x+u.vx,p=u.y+u.vy,a.visit(y);function y(t,e,r,n,a){var s=t.data,l=t.r,c=d+l;if(!s)return e>h+c||n<h-c||r>p+c||a<p-c;if(s.index>u.index){var f=h-s.x-s.vx,g=p-s.y-s.vy,v=f*f+g*g;v<c*c&&(0===f&&(v+=(f=o())*f),0===g&&(v+=(g=o())*g),v=(c-(v=Math.sqrt(v)))/v*i,u.vx+=(f*=v)*(c=(l*=l)/(m+l)),u.vy+=(g*=v)*c,s.vx-=f*(c=1-c),s.vy-=g*c)}}}function f(t){if(t.data)return t.r=n[t.data.index];for(var e=t.r=0;e<4;++e)t[e]&&t[e].r>t.r&&(t.r=t[e].r)}function h(){if(r){var e,i,a=r.length;for(n=new Array(a),e=0;e<a;++e)i=r[e],n[i.index]=+t(i,e,r)}}return\"function\"!=typeof t&&(t=a(null==t?1:+t)),u.initialize=function(t){r=t,h()},u.iterations=function(t){return arguments.length?(c=+t,u):c},u.strength=function(t){return arguments.length?(i=+t,u):i},u.radius=function(e){return arguments.length?(t=\"function\"==typeof e?e:a(+e),h(),u):t},u},t.forceLink=function(t){var e,n,i,s,l,f=c,h=function(t){return 1/Math.min(s[t.source.index],s[t.target.index])},p=a(30),d=1;function m(r){for(var i=0,a=t.length;i<d;++i)for(var s,c,u,f,h,p,m,g=0;g<a;++g)c=(s=t[g]).source,f=(u=s.target).x+u.vx-c.x-c.vx||o(),h=u.y+u.vy-c.y-c.vy||o(),f*=p=((p=Math.sqrt(f*f+h*h))-n[g])/p*r*e[g],h*=p,u.vx-=f*(m=l[g]),u.vy-=h*m,c.vx+=f*(m=1-m),c.vy+=h*m}function g(){if(i){var a,o,c=i.length,h=t.length,p=r.map(i,f);for(a=0,s=new Array(c);a<h;++a)(o=t[a]).index=a,\"object\"!=typeof o.source&&(o.source=u(p,o.source)),\"object\"!=typeof o.target&&(o.target=u(p,o.target)),s[o.source.index]=(s[o.source.index]||0)+1,s[o.target.index]=(s[o.target.index]||0)+1;for(a=0,l=new Array(h);a<h;++a)o=t[a],l[a]=s[o.source.index]/(s[o.source.index]+s[o.target.index]);e=new Array(h),v(),n=new Array(h),y()}}function v(){if(i)for(var r=0,n=t.length;r<n;++r)e[r]=+h(t[r],r,t)}function y(){if(i)for(var e=0,r=t.length;e<r;++e)n[e]=+p(t[e],e,t)}return null==t&&(t=[]),m.initialize=function(t){i=t,g()},m.links=function(e){return arguments.length?(t=e,g(),m):t},m.id=function(t){return arguments.length?(f=t,m):f},m.iterations=function(t){return arguments.length?(d=+t,m):d},m.strength=function(t){return arguments.length?(h=\"function\"==typeof t?t:a(+t),v(),m):h},m.distance=function(t){return arguments.length?(p=\"function\"==typeof t?t:a(+t),y(),m):p},m},t.forceManyBody=function(){var t,r,n,i,s=a(-30),l=1,c=1/0,u=.81;function p(i){var a,o=t.length,s=e.quadtree(t,f,h).visitAfter(m);for(n=i,a=0;a<o;++a)r=t[a],s.visit(g)}function d(){if(t){var e,r,n=t.length;for(i=new Array(n),e=0;e<n;++e)r=t[e],i[r.index]=+s(r,e,t)}}function m(t){var e,r,n,a,o,s=0,l=0;if(t.length){for(n=a=o=0;o<4;++o)(e=t[o])&&(r=Math.abs(e.value))&&(s+=e.value,l+=r,n+=r*e.x,a+=r*e.y);t.x=n/l,t.y=a/l}else{(e=t).x=e.data.x,e.y=e.data.y;do{s+=i[e.data.index]}while(e=e.next)}t.value=s}function g(t,e,a,s){if(!t.value)return!0;var f=t.x-r.x,h=t.y-r.y,p=s-e,d=f*f+h*h;if(p*p/u<d)return d<c&&(0===f&&(d+=(f=o())*f),0===h&&(d+=(h=o())*h),d<l&&(d=Math.sqrt(l*d)),r.vx+=f*t.value*n/d,r.vy+=h*t.value*n/d),!0;if(!(t.length||d>=c)){(t.data!==r||t.next)&&(0===f&&(d+=(f=o())*f),0===h&&(d+=(h=o())*h),d<l&&(d=Math.sqrt(l*d)));do{t.data!==r&&(p=i[t.data.index]*n/d,r.vx+=f*p,r.vy+=h*p)}while(t=t.next)}}return p.initialize=function(e){t=e,d()},p.strength=function(t){return arguments.length?(s=\"function\"==typeof t?t:a(+t),d(),p):s},p.distanceMin=function(t){return arguments.length?(l=t*t,p):Math.sqrt(l)},p.distanceMax=function(t){return arguments.length?(c=t*t,p):Math.sqrt(c)},p.theta=function(t){return arguments.length?(u=t*t,p):Math.sqrt(u)},p},t.forceRadial=function(t,e,r){var n,i,o,s=a(.1);function l(t){for(var a=0,s=n.length;a<s;++a){var l=n[a],c=l.x-e||1e-6,u=l.y-r||1e-6,f=Math.sqrt(c*c+u*u),h=(o[a]-f)*i[a]*t/f;l.vx+=c*h,l.vy+=u*h}}function c(){if(n){var e,r=n.length;for(i=new Array(r),o=new Array(r),e=0;e<r;++e)o[e]=+t(n[e],e,n),i[e]=isNaN(o[e])?0:+s(n[e],e,n)}}return\"function\"!=typeof t&&(t=a(+t)),null==e&&(e=0),null==r&&(r=0),l.initialize=function(t){n=t,c()},l.strength=function(t){return arguments.length?(s=\"function\"==typeof t?t:a(+t),c(),l):s},l.radius=function(e){return arguments.length?(t=\"function\"==typeof e?e:a(+e),c(),l):t},l.x=function(t){return arguments.length?(e=+t,l):e},l.y=function(t){return arguments.length?(r=+t,l):r},l},t.forceSimulation=function(t){var e,a=1,o=.001,s=1-Math.pow(o,1/300),l=0,c=.6,u=r.map(),f=i.timer(d),h=n.dispatch(\"tick\",\"end\");function d(){m(),h.call(\"tick\",e),a<o&&(f.stop(),h.call(\"end\",e))}function m(r){var n,i,o=t.length;void 0===r&&(r=1);for(var f=0;f<r;++f)for(a+=(l-a)*s,u.each((function(t){t(a)})),n=0;n<o;++n)null==(i=t[n]).fx?i.x+=i.vx*=c:(i.x=i.fx,i.vx=0),null==i.fy?i.y+=i.vy*=c:(i.y=i.fy,i.vy=0);return e}function g(){for(var e,r=0,n=t.length;r<n;++r){if((e=t[r]).index=r,null!=e.fx&&(e.x=e.fx),null!=e.fy&&(e.y=e.fy),isNaN(e.x)||isNaN(e.y)){var i=10*Math.sqrt(r),a=r*p;e.x=i*Math.cos(a),e.y=i*Math.sin(a)}(isNaN(e.vx)||isNaN(e.vy))&&(e.vx=e.vy=0)}}function v(e){return e.initialize&&e.initialize(t),e}return null==t&&(t=[]),g(),e={tick:m,restart:function(){return f.restart(d),e},stop:function(){return f.stop(),e},nodes:function(r){return arguments.length?(t=r,g(),u.each(v),e):t},alpha:function(t){return arguments.length?(a=+t,e):a},alphaMin:function(t){return arguments.length?(o=+t,e):o},alphaDecay:function(t){return arguments.length?(s=+t,e):+s},alphaTarget:function(t){return arguments.length?(l=+t,e):l},velocityDecay:function(t){return arguments.length?(c=1-t,e):1-c},force:function(t,r){return arguments.length>1?(null==r?u.remove(t):u.set(t,v(r)),e):u.get(t)},find:function(e,r,n){var i,a,o,s,l,c=0,u=t.length;for(null==n?n=1/0:n*=n,c=0;c<u;++c)(o=(i=e-(s=t[c]).x)*i+(a=r-s.y)*a)<n&&(l=s,n=o);return l},on:function(t,r){return arguments.length>1?(h.on(t,r),e):h.on(t)}}},t.forceX=function(t){var e,r,n,i=a(.1);function o(t){for(var i,a=0,o=e.length;a<o;++a)(i=e[a]).vx+=(n[a]-i.x)*r[a]*t}function s(){if(e){var a,o=e.length;for(r=new Array(o),n=new Array(o),a=0;a<o;++a)r[a]=isNaN(n[a]=+t(e[a],a,e))?0:+i(e[a],a,e)}}return\"function\"!=typeof t&&(t=a(null==t?0:+t)),o.initialize=function(t){e=t,s()},o.strength=function(t){return arguments.length?(i=\"function\"==typeof t?t:a(+t),s(),o):i},o.x=function(e){return arguments.length?(t=\"function\"==typeof e?e:a(+e),s(),o):t},o},t.forceY=function(t){var e,r,n,i=a(.1);function o(t){for(var i,a=0,o=e.length;a<o;++a)(i=e[a]).vy+=(n[a]-i.y)*r[a]*t}function s(){if(e){var a,o=e.length;for(r=new Array(o),n=new Array(o),a=0;a<o;++a)r[a]=isNaN(n[a]=+t(e[a],a,e))?0:+i(e[a],a,e)}}return\"function\"!=typeof t&&(t=a(null==t?0:+t)),o.initialize=function(t){e=t,s()},o.strength=function(t){return arguments.length?(i=\"function\"==typeof t?t:a(+t),s(),o):i},o.y=function(e){return arguments.length?(t=\"function\"==typeof e?e:a(+e),s(),o):t},o},Object.defineProperty(t,\"__esModule\",{value:!0})}))},{\"d3-collection\":163,\"d3-dispatch\":165,\"d3-quadtree\":170,\"d3-timer\":174}],167:[function(t,e,r){!function(t,n){\"object\"==typeof r&&void 0!==e?n(r):n((t=t||self).d3=t.d3||{})}(this,(function(t){\"use strict\";function e(t,e){return t.parent===e.parent?1:2}function r(t,e){return t+e.x}function n(t,e){return Math.max(t,e.y)}function i(t){var e=0,r=t.children,n=r&&r.length;if(n)for(;--n>=0;)e+=r[n].value;else e=1;t.value=e}function a(t,e){var r,n,i,a,s,u=new c(t),f=+t.value&&(u.value=t.value),h=[u];for(null==e&&(e=o);r=h.pop();)if(f&&(r.value=+r.data.value),(i=e(r.data))&&(s=i.length))for(r.children=new Array(s),a=s-1;a>=0;--a)h.push(n=r.children[a]=new c(i[a])),n.parent=r,n.depth=r.depth+1;return u.eachBefore(l)}function o(t){return t.children}function s(t){t.data=t.data.data}function l(t){var e=0;do{t.height=e}while((t=t.parent)&&t.height<++e)}function c(t){this.data=t,this.depth=this.height=0,this.parent=null}c.prototype=a.prototype={constructor:c,count:function(){return this.eachAfter(i)},each:function(t){var e,r,n,i,a=this,o=[a];do{for(e=o.reverse(),o=[];a=e.pop();)if(t(a),r=a.children)for(n=0,i=r.length;n<i;++n)o.push(r[n])}while(o.length);return this},eachAfter:function(t){for(var e,r,n,i=this,a=[i],o=[];i=a.pop();)if(o.push(i),e=i.children)for(r=0,n=e.length;r<n;++r)a.push(e[r]);for(;i=o.pop();)t(i);return this},eachBefore:function(t){for(var e,r,n=this,i=[n];n=i.pop();)if(t(n),e=n.children)for(r=e.length-1;r>=0;--r)i.push(e[r]);return this},sum:function(t){return this.eachAfter((function(e){for(var r=+t(e.data)||0,n=e.children,i=n&&n.length;--i>=0;)r+=n[i].value;e.value=r}))},sort:function(t){return this.eachBefore((function(e){e.children&&e.children.sort(t)}))},path:function(t){for(var e=this,r=function(t,e){if(t===e)return t;var r=t.ancestors(),n=e.ancestors(),i=null;t=r.pop(),e=n.pop();for(;t===e;)i=t,t=r.pop(),e=n.pop();return i}(e,t),n=[e];e!==r;)e=e.parent,n.push(e);for(var i=n.length;t!==r;)n.splice(i,0,t),t=t.parent;return n},ancestors:function(){for(var t=this,e=[t];t=t.parent;)e.push(t);return e},descendants:function(){var t=[];return this.each((function(e){t.push(e)})),t},leaves:function(){var t=[];return this.eachBefore((function(e){e.children||t.push(e)})),t},links:function(){var t=this,e=[];return t.each((function(r){r!==t&&e.push({source:r.parent,target:r})})),e},copy:function(){return a(this).eachBefore(s)}};var u=Array.prototype.slice;function f(t){for(var e,r,n=0,i=(t=function(t){for(var e,r,n=t.length;n;)r=Math.random()*n--|0,e=t[n],t[n]=t[r],t[r]=e;return t}(u.call(t))).length,a=[];n<i;)e=t[n],r&&d(r,e)?++n:(r=g(a=h(a,e)),n=0);return r}function h(t,e){var r,n;if(m(e,t))return[e];for(r=0;r<t.length;++r)if(p(e,t[r])&&m(v(t[r],e),t))return[t[r],e];for(r=0;r<t.length-1;++r)for(n=r+1;n<t.length;++n)if(p(v(t[r],t[n]),e)&&p(v(t[r],e),t[n])&&p(v(t[n],e),t[r])&&m(y(t[r],t[n],e),t))return[t[r],t[n],e];throw new Error}function p(t,e){var r=t.r-e.r,n=e.x-t.x,i=e.y-t.y;return r<0||r*r<n*n+i*i}function d(t,e){var r=t.r-e.r+1e-6,n=e.x-t.x,i=e.y-t.y;return r>0&&r*r>n*n+i*i}function m(t,e){for(var r=0;r<e.length;++r)if(!d(t,e[r]))return!1;return!0}function g(t){switch(t.length){case 1:return{x:(e=t[0]).x,y:e.y,r:e.r};case 2:return v(t[0],t[1]);case 3:return y(t[0],t[1],t[2])}var e}function v(t,e){var r=t.x,n=t.y,i=t.r,a=e.x,o=e.y,s=e.r,l=a-r,c=o-n,u=s-i,f=Math.sqrt(l*l+c*c);return{x:(r+a+l/f*u)/2,y:(n+o+c/f*u)/2,r:(f+i+s)/2}}function y(t,e,r){var n=t.x,i=t.y,a=t.r,o=e.x,s=e.y,l=e.r,c=r.x,u=r.y,f=r.r,h=n-o,p=n-c,d=i-s,m=i-u,g=l-a,v=f-a,y=n*n+i*i-a*a,x=y-o*o-s*s+l*l,b=y-c*c-u*u+f*f,_=p*d-h*m,w=(d*b-m*x)/(2*_)-n,T=(m*g-d*v)/_,k=(p*x-h*b)/(2*_)-i,M=(h*v-p*g)/_,A=T*T+M*M-1,S=2*(a+w*T+k*M),E=w*w+k*k-a*a,L=-(A?(S+Math.sqrt(S*S-4*A*E))/(2*A):E/S);return{x:n+w+T*L,y:i+k+M*L,r:L}}function x(t,e,r){var n,i,a,o,s=t.x-e.x,l=t.y-e.y,c=s*s+l*l;c?(i=e.r+r.r,i*=i,o=t.r+r.r,i>(o*=o)?(n=(c+o-i)/(2*c),a=Math.sqrt(Math.max(0,o/c-n*n)),r.x=t.x-n*s-a*l,r.y=t.y-n*l+a*s):(n=(c+i-o)/(2*c),a=Math.sqrt(Math.max(0,i/c-n*n)),r.x=e.x+n*s-a*l,r.y=e.y+n*l+a*s)):(r.x=e.x+r.r,r.y=e.y)}function b(t,e){var r=t.r+e.r-1e-6,n=e.x-t.x,i=e.y-t.y;return r>0&&r*r>n*n+i*i}function _(t){var e=t._,r=t.next._,n=e.r+r.r,i=(e.x*r.r+r.x*e.r)/n,a=(e.y*r.r+r.y*e.r)/n;return i*i+a*a}function w(t){this._=t,this.next=null,this.previous=null}function T(t){if(!(i=t.length))return 0;var e,r,n,i,a,o,s,l,c,u,h;if((e=t[0]).x=0,e.y=0,!(i>1))return e.r;if(r=t[1],e.x=-r.r,r.x=e.r,r.y=0,!(i>2))return e.r+r.r;x(r,e,n=t[2]),e=new w(e),r=new w(r),n=new w(n),e.next=n.previous=r,r.next=e.previous=n,n.next=r.previous=e;t:for(s=3;s<i;++s){x(e._,r._,n=t[s]),n=new w(n),l=r.next,c=e.previous,u=r._.r,h=e._.r;do{if(u<=h){if(b(l._,n._)){r=l,e.next=r,r.previous=e,--s;continue t}u+=l._.r,l=l.next}else{if(b(c._,n._)){(e=c).next=r,r.previous=e,--s;continue t}h+=c._.r,c=c.previous}}while(l!==c.next);for(n.previous=e,n.next=r,e.next=r.previous=r=n,a=_(e);(n=n.next)!==r;)(o=_(n))<a&&(e=n,a=o);r=e.next}for(e=[r._],n=r;(n=n.next)!==r;)e.push(n._);for(n=f(e),s=0;s<i;++s)(e=t[s]).x-=n.x,e.y-=n.y;return n.r}function k(t){return null==t?null:M(t)}function M(t){if(\"function\"!=typeof t)throw new Error;return t}function A(){return 0}function S(t){return function(){return t}}function E(t){return Math.sqrt(t.value)}function L(t){return function(e){e.children||(e.r=Math.max(0,+t(e)||0))}}function C(t,e){return function(r){if(n=r.children){var n,i,a,o=n.length,s=t(r)*e||0;if(s)for(i=0;i<o;++i)n[i].r+=s;if(a=T(n),s)for(i=0;i<o;++i)n[i].r-=s;r.r=a+s}}}function P(t){return function(e){var r=e.parent;e.r*=t,r&&(e.x=r.x+t*e.x,e.y=r.y+t*e.y)}}function I(t){t.x0=Math.round(t.x0),t.y0=Math.round(t.y0),t.x1=Math.round(t.x1),t.y1=Math.round(t.y1)}function O(t,e,r,n,i){for(var a,o=t.children,s=-1,l=o.length,c=t.value&&(n-e)/t.value;++s<l;)(a=o[s]).y0=r,a.y1=i,a.x0=e,a.x1=e+=a.value*c}var z={depth:-1},D={};function R(t){return t.id}function F(t){return t.parentId}function B(t,e){return t.parent===e.parent?1:2}function N(t){var e=t.children;return e?e[0]:t.t}function j(t){var e=t.children;return e?e[e.length-1]:t.t}function U(t,e,r){var n=r/(e.i-t.i);e.c-=n,e.s+=r,t.c+=n,e.z+=r,e.m+=r}function V(t,e,r){return t.a.parent===e.parent?t.a:r}function q(t,e){this._=t,this.parent=null,this.children=null,this.A=null,this.a=this,this.z=0,this.m=0,this.c=0,this.s=0,this.t=null,this.i=e}function H(t,e,r,n,i){for(var a,o=t.children,s=-1,l=o.length,c=t.value&&(i-r)/t.value;++s<l;)(a=o[s]).x0=e,a.x1=n,a.y0=r,a.y1=r+=a.value*c}q.prototype=Object.create(c.prototype);var G=(1+Math.sqrt(5))/2;function Y(t,e,r,n,i,a){for(var o,s,l,c,u,f,h,p,d,m,g,v=[],y=e.children,x=0,b=0,_=y.length,w=e.value;x<_;){l=i-r,c=a-n;do{u=y[b++].value}while(!u&&b<_);for(f=h=u,g=u*u*(m=Math.max(c/l,l/c)/(w*t)),d=Math.max(h/g,g/f);b<_;++b){if(u+=s=y[b].value,s<f&&(f=s),s>h&&(h=s),g=u*u*m,(p=Math.max(h/g,g/f))>d){u-=s;break}d=p}v.push(o={value:u,dice:l<c,children:y.slice(x,b)}),o.dice?O(o,r,n,i,w?n+=c*u/w:a):H(o,r,n,w?r+=l*u/w:i,a),w-=u,x=b}return v}var W=function t(e){function r(t,r,n,i,a){Y(e,t,r,n,i,a)}return r.ratio=function(e){return t((e=+e)>1?e:1)},r}(G);var X=function t(e){function r(t,r,n,i,a){if((o=t._squarify)&&o.ratio===e)for(var o,s,l,c,u,f=-1,h=o.length,p=t.value;++f<h;){for(l=(s=o[f]).children,c=s.value=0,u=l.length;c<u;++c)s.value+=l[c].value;s.dice?O(s,r,n,i,n+=(a-n)*s.value/p):H(s,r,n,r+=(i-r)*s.value/p,a),p-=s.value}else t._squarify=o=Y(e,t,r,n,i,a),o.ratio=e}return r.ratio=function(e){return t((e=+e)>1?e:1)},r}(G);t.cluster=function(){var t=e,i=1,a=1,o=!1;function s(e){var s,l=0;e.eachAfter((function(e){var i=e.children;i?(e.x=function(t){return t.reduce(r,0)/t.length}(i),e.y=function(t){return 1+t.reduce(n,0)}(i)):(e.x=s?l+=t(e,s):0,e.y=0,s=e)}));var c=function(t){for(var e;e=t.children;)t=e[0];return t}(e),u=function(t){for(var e;e=t.children;)t=e[e.length-1];return t}(e),f=c.x-t(c,u)/2,h=u.x+t(u,c)/2;return e.eachAfter(o?function(t){t.x=(t.x-e.x)*i,t.y=(e.y-t.y)*a}:function(t){t.x=(t.x-f)/(h-f)*i,t.y=(1-(e.y?t.y/e.y:1))*a})}return s.separation=function(e){return arguments.length?(t=e,s):t},s.size=function(t){return arguments.length?(o=!1,i=+t[0],a=+t[1],s):o?null:[i,a]},s.nodeSize=function(t){return arguments.length?(o=!0,i=+t[0],a=+t[1],s):o?[i,a]:null},s},t.hierarchy=a,t.pack=function(){var t=null,e=1,r=1,n=A;function i(i){return i.x=e/2,i.y=r/2,t?i.eachBefore(L(t)).eachAfter(C(n,.5)).eachBefore(P(1)):i.eachBefore(L(E)).eachAfter(C(A,1)).eachAfter(C(n,i.r/Math.min(e,r))).eachBefore(P(Math.min(e,r)/(2*i.r))),i}return i.radius=function(e){return arguments.length?(t=k(e),i):t},i.size=function(t){return arguments.length?(e=+t[0],r=+t[1],i):[e,r]},i.padding=function(t){return arguments.length?(n=\"function\"==typeof t?t:S(+t),i):n},i},t.packEnclose=f,t.packSiblings=function(t){return T(t),t},t.partition=function(){var t=1,e=1,r=0,n=!1;function i(i){var a=i.height+1;return i.x0=i.y0=r,i.x1=t,i.y1=e/a,i.eachBefore(function(t,e){return function(n){n.children&&O(n,n.x0,t*(n.depth+1)/e,n.x1,t*(n.depth+2)/e);var i=n.x0,a=n.y0,o=n.x1-r,s=n.y1-r;o<i&&(i=o=(i+o)/2),s<a&&(a=s=(a+s)/2),n.x0=i,n.y0=a,n.x1=o,n.y1=s}}(e,a)),n&&i.eachBefore(I),i}return i.round=function(t){return arguments.length?(n=!!t,i):n},i.size=function(r){return arguments.length?(t=+r[0],e=+r[1],i):[t,e]},i.padding=function(t){return arguments.length?(r=+t,i):r},i},t.stratify=function(){var t=R,e=F;function r(r){var n,i,a,o,s,u,f,h=r.length,p=new Array(h),d={};for(i=0;i<h;++i)n=r[i],s=p[i]=new c(n),null!=(u=t(n,i,r))&&(u+=\"\")&&(d[f=\"$\"+(s.id=u)]=f in d?D:s);for(i=0;i<h;++i)if(s=p[i],null!=(u=e(r[i],i,r))&&(u+=\"\")){if(!(o=d[\"$\"+u]))throw new Error(\"missing: \"+u);if(o===D)throw new Error(\"ambiguous: \"+u);o.children?o.children.push(s):o.children=[s],s.parent=o}else{if(a)throw new Error(\"multiple roots\");a=s}if(!a)throw new Error(\"no root\");if(a.parent=z,a.eachBefore((function(t){t.depth=t.parent.depth+1,--h})).eachBefore(l),a.parent=null,h>0)throw new Error(\"cycle\");return a}return r.id=function(e){return arguments.length?(t=M(e),r):t},r.parentId=function(t){return arguments.length?(e=M(t),r):e},r},t.tree=function(){var t=B,e=1,r=1,n=null;function i(i){var l=function(t){for(var e,r,n,i,a,o=new q(t,0),s=[o];e=s.pop();)if(n=e._.children)for(e.children=new Array(a=n.length),i=a-1;i>=0;--i)s.push(r=e.children[i]=new q(n[i],i)),r.parent=e;return(o.parent=new q(null,0)).children=[o],o}(i);if(l.eachAfter(a),l.parent.m=-l.z,l.eachBefore(o),n)i.eachBefore(s);else{var c=i,u=i,f=i;i.eachBefore((function(t){t.x<c.x&&(c=t),t.x>u.x&&(u=t),t.depth>f.depth&&(f=t)}));var h=c===u?1:t(c,u)/2,p=h-c.x,d=e/(u.x+h+p),m=r/(f.depth||1);i.eachBefore((function(t){t.x=(t.x+p)*d,t.y=t.depth*m}))}return i}function a(e){var r=e.children,n=e.parent.children,i=e.i?n[e.i-1]:null;if(r){!function(t){for(var e,r=0,n=0,i=t.children,a=i.length;--a>=0;)(e=i[a]).z+=r,e.m+=r,r+=e.s+(n+=e.c)}(e);var a=(r[0].z+r[r.length-1].z)/2;i?(e.z=i.z+t(e._,i._),e.m=e.z-a):e.z=a}else i&&(e.z=i.z+t(e._,i._));e.parent.A=function(e,r,n){if(r){for(var i,a=e,o=e,s=r,l=a.parent.children[0],c=a.m,u=o.m,f=s.m,h=l.m;s=j(s),a=N(a),s&&a;)l=N(l),(o=j(o)).a=e,(i=s.z+f-a.z-c+t(s._,a._))>0&&(U(V(s,e,n),e,i),c+=i,u+=i),f+=s.m,c+=a.m,h+=l.m,u+=o.m;s&&!j(o)&&(o.t=s,o.m+=f-u),a&&!N(l)&&(l.t=a,l.m+=c-h,n=e)}return n}(e,i,e.parent.A||n[0])}function o(t){t._.x=t.z+t.parent.m,t.m+=t.parent.m}function s(t){t.x*=e,t.y=t.depth*r}return i.separation=function(e){return arguments.length?(t=e,i):t},i.size=function(t){return arguments.length?(n=!1,e=+t[0],r=+t[1],i):n?null:[e,r]},i.nodeSize=function(t){return arguments.length?(n=!0,e=+t[0],r=+t[1],i):n?[e,r]:null},i},t.treemap=function(){var t=W,e=!1,r=1,n=1,i=[0],a=A,o=A,s=A,l=A,c=A;function u(t){return t.x0=t.y0=0,t.x1=r,t.y1=n,t.eachBefore(f),i=[0],e&&t.eachBefore(I),t}function f(e){var r=i[e.depth],n=e.x0+r,u=e.y0+r,f=e.x1-r,h=e.y1-r;f<n&&(n=f=(n+f)/2),h<u&&(u=h=(u+h)/2),e.x0=n,e.y0=u,e.x1=f,e.y1=h,e.children&&(r=i[e.depth+1]=a(e)/2,n+=c(e)-r,u+=o(e)-r,(f-=s(e)-r)<n&&(n=f=(n+f)/2),(h-=l(e)-r)<u&&(u=h=(u+h)/2),t(e,n,u,f,h))}return u.round=function(t){return arguments.length?(e=!!t,u):e},u.size=function(t){return arguments.length?(r=+t[0],n=+t[1],u):[r,n]},u.tile=function(e){return arguments.length?(t=M(e),u):t},u.padding=function(t){return arguments.length?u.paddingInner(t).paddingOuter(t):u.paddingInner()},u.paddingInner=function(t){return arguments.length?(a=\"function\"==typeof t?t:S(+t),u):a},u.paddingOuter=function(t){return arguments.length?u.paddingTop(t).paddingRight(t).paddingBottom(t).paddingLeft(t):u.paddingTop()},u.paddingTop=function(t){return arguments.length?(o=\"function\"==typeof t?t:S(+t),u):o},u.paddingRight=function(t){return arguments.length?(s=\"function\"==typeof t?t:S(+t),u):s},u.paddingBottom=function(t){return arguments.length?(l=\"function\"==typeof t?t:S(+t),u):l},u.paddingLeft=function(t){return arguments.length?(c=\"function\"==typeof t?t:S(+t),u):c},u},t.treemapBinary=function(t,e,r,n,i){var a,o,s=t.children,l=s.length,c=new Array(l+1);for(c[0]=o=a=0;a<l;++a)c[a+1]=o+=s[a].value;!function t(e,r,n,i,a,o,l){if(e>=r-1){var u=s[e];return u.x0=i,u.y0=a,u.x1=o,void(u.y1=l)}var f=c[e],h=n/2+f,p=e+1,d=r-1;for(;p<d;){var m=p+d>>>1;c[m]<h?p=m+1:d=m}h-c[p-1]<c[p]-h&&e+1<p&&--p;var g=c[p]-f,v=n-g;if(o-i>l-a){var y=(i*v+o*g)/n;t(e,p,g,i,a,y,l),t(p,r,v,y,a,o,l)}else{var x=(a*v+l*g)/n;t(e,p,g,i,a,o,x),t(p,r,v,i,x,o,l)}}(0,l,t.value,e,r,n,i)},t.treemapDice=O,t.treemapResquarify=X,t.treemapSlice=H,t.treemapSliceDice=function(t,e,r,n,i){(1&t.depth?H:O)(t,e,r,n,i)},t.treemapSquarify=W,Object.defineProperty(t,\"__esModule\",{value:!0})}))},{}],168:[function(t,e,r){!function(n,i){\"object\"==typeof r&&void 0!==e?i(r,t(\"d3-color\")):i((n=n||self).d3=n.d3||{},n.d3)}(this,(function(t,e){\"use strict\";function r(t,e,r,n,i){var a=t*t,o=a*t;return((1-3*t+3*a-o)*e+(4-6*a+3*o)*r+(1+3*t+3*a-3*o)*n+o*i)/6}function n(t){var e=t.length-1;return function(n){var i=n<=0?n=0:n>=1?(n=1,e-1):Math.floor(n*e),a=t[i],o=t[i+1],s=i>0?t[i-1]:2*a-o,l=i<e-1?t[i+2]:2*o-a;return r((n-i/e)*e,s,a,o,l)}}function i(t){var e=t.length;return function(n){var i=Math.floor(((n%=1)<0?++n:n)*e),a=t[(i+e-1)%e],o=t[i%e],s=t[(i+1)%e],l=t[(i+2)%e];return r((n-i/e)*e,a,o,s,l)}}function a(t){return function(){return t}}function o(t,e){return function(r){return t+r*e}}function s(t,e){var r=e-t;return r?o(t,r>180||r<-180?r-360*Math.round(r/360):r):a(isNaN(t)?e:t)}function l(t){return 1==(t=+t)?c:function(e,r){return r-e?function(t,e,r){return t=Math.pow(t,r),e=Math.pow(e,r)-t,r=1/r,function(n){return Math.pow(t+n*e,r)}}(e,r,t):a(isNaN(e)?r:e)}}function c(t,e){var r=e-t;return r?o(t,r):a(isNaN(t)?e:t)}var u=function t(r){var n=l(r);function i(t,r){var i=n((t=e.rgb(t)).r,(r=e.rgb(r)).r),a=n(t.g,r.g),o=n(t.b,r.b),s=c(t.opacity,r.opacity);return function(e){return t.r=i(e),t.g=a(e),t.b=o(e),t.opacity=s(e),t+\"\"}}return i.gamma=t,i}(1);function f(t){return function(r){var n,i,a=r.length,o=new Array(a),s=new Array(a),l=new Array(a);for(n=0;n<a;++n)i=e.rgb(r[n]),o[n]=i.r||0,s[n]=i.g||0,l[n]=i.b||0;return o=t(o),s=t(s),l=t(l),i.opacity=1,function(t){return i.r=o(t),i.g=s(t),i.b=l(t),i+\"\"}}}var h=f(n),p=f(i);function d(t,e){e||(e=[]);var r,n=t?Math.min(e.length,t.length):0,i=e.slice();return function(a){for(r=0;r<n;++r)i[r]=t[r]*(1-a)+e[r]*a;return i}}function m(t){return ArrayBuffer.isView(t)&&!(t instanceof DataView)}function g(t,e){var r,n=e?e.length:0,i=t?Math.min(n,t.length):0,a=new Array(i),o=new Array(n);for(r=0;r<i;++r)a[r]=T(t[r],e[r]);for(;r<n;++r)o[r]=e[r];return function(t){for(r=0;r<i;++r)o[r]=a[r](t);return o}}function v(t,e){var r=new Date;return t=+t,e=+e,function(n){return r.setTime(t*(1-n)+e*n),r}}function y(t,e){return t=+t,e=+e,function(r){return t*(1-r)+e*r}}function x(t,e){var r,n={},i={};for(r in null!==t&&\"object\"==typeof t||(t={}),null!==e&&\"object\"==typeof e||(e={}),e)r in t?n[r]=T(t[r],e[r]):i[r]=e[r];return function(t){for(r in n)i[r]=n[r](t);return i}}var b=/[-+]?(?:\\d+\\.?\\d*|\\.?\\d+)(?:[eE][-+]?\\d+)?/g,_=new RegExp(b.source,\"g\");function w(t,e){var r,n,i,a=b.lastIndex=_.lastIndex=0,o=-1,s=[],l=[];for(t+=\"\",e+=\"\";(r=b.exec(t))&&(n=_.exec(e));)(i=n.index)>a&&(i=e.slice(a,i),s[o]?s[o]+=i:s[++o]=i),(r=r[0])===(n=n[0])?s[o]?s[o]+=n:s[++o]=n:(s[++o]=null,l.push({i:o,x:y(r,n)})),a=_.lastIndex;return a<e.length&&(i=e.slice(a),s[o]?s[o]+=i:s[++o]=i),s.length<2?l[0]?function(t){return function(e){return t(e)+\"\"}}(l[0].x):function(t){return function(){return t}}(e):(e=l.length,function(t){for(var r,n=0;n<e;++n)s[(r=l[n]).i]=r.x(t);return s.join(\"\")})}function T(t,r){var n,i=typeof r;return null==r||\"boolean\"===i?a(r):(\"number\"===i?y:\"string\"===i?(n=e.color(r))?(r=n,u):w:r instanceof e.color?u:r instanceof Date?v:m(r)?d:Array.isArray(r)?g:\"function\"!=typeof r.valueOf&&\"function\"!=typeof r.toString||isNaN(r)?x:y)(t,r)}var k,M,A,S,E=180/Math.PI,L={translateX:0,translateY:0,rotate:0,skewX:0,scaleX:1,scaleY:1};function C(t,e,r,n,i,a){var o,s,l;return(o=Math.sqrt(t*t+e*e))&&(t/=o,e/=o),(l=t*r+e*n)&&(r-=t*l,n-=e*l),(s=Math.sqrt(r*r+n*n))&&(r/=s,n/=s,l/=s),t*n<e*r&&(t=-t,e=-e,l=-l,o=-o),{translateX:i,translateY:a,rotate:Math.atan2(e,t)*E,skewX:Math.atan(l)*E,scaleX:o,scaleY:s}}function P(t,e,r,n){function i(t){return t.length?t.pop()+\" \":\"\"}return function(a,o){var s=[],l=[];return a=t(a),o=t(o),function(t,n,i,a,o,s){if(t!==i||n!==a){var l=o.push(\"translate(\",null,e,null,r);s.push({i:l-4,x:y(t,i)},{i:l-2,x:y(n,a)})}else(i||a)&&o.push(\"translate(\"+i+e+a+r)}(a.translateX,a.translateY,o.translateX,o.translateY,s,l),function(t,e,r,a){t!==e?(t-e>180?e+=360:e-t>180&&(t+=360),a.push({i:r.push(i(r)+\"rotate(\",null,n)-2,x:y(t,e)})):e&&r.push(i(r)+\"rotate(\"+e+n)}(a.rotate,o.rotate,s,l),function(t,e,r,a){t!==e?a.push({i:r.push(i(r)+\"skewX(\",null,n)-2,x:y(t,e)}):e&&r.push(i(r)+\"skewX(\"+e+n)}(a.skewX,o.skewX,s,l),function(t,e,r,n,a,o){if(t!==r||e!==n){var s=a.push(i(a)+\"scale(\",null,\",\",null,\")\");o.push({i:s-4,x:y(t,r)},{i:s-2,x:y(e,n)})}else 1===r&&1===n||a.push(i(a)+\"scale(\"+r+\",\"+n+\")\")}(a.scaleX,a.scaleY,o.scaleX,o.scaleY,s,l),a=o=null,function(t){for(var e,r=-1,n=l.length;++r<n;)s[(e=l[r]).i]=e.x(t);return s.join(\"\")}}}var I=P((function(t){return\"none\"===t?L:(k||(k=document.createElement(\"DIV\"),M=document.documentElement,A=document.defaultView),k.style.transform=t,t=A.getComputedStyle(M.appendChild(k),null).getPropertyValue(\"transform\"),M.removeChild(k),C(+(t=t.slice(7,-1).split(\",\"))[0],+t[1],+t[2],+t[3],+t[4],+t[5]))}),\"px, \",\"px)\",\"deg)\"),O=P((function(t){return null==t?L:(S||(S=document.createElementNS(\"http://www.w3.org/2000/svg\",\"g\")),S.setAttribute(\"transform\",t),(t=S.transform.baseVal.consolidate())?C((t=t.matrix).a,t.b,t.c,t.d,t.e,t.f):L)}),\", \",\")\",\")\"),z=Math.SQRT2;function D(t){return((t=Math.exp(t))+1/t)/2}function R(t){return function(r,n){var i=t((r=e.hsl(r)).h,(n=e.hsl(n)).h),a=c(r.s,n.s),o=c(r.l,n.l),s=c(r.opacity,n.opacity);return function(t){return r.h=i(t),r.s=a(t),r.l=o(t),r.opacity=s(t),r+\"\"}}}var F=R(s),B=R(c);function N(t){return function(r,n){var i=t((r=e.hcl(r)).h,(n=e.hcl(n)).h),a=c(r.c,n.c),o=c(r.l,n.l),s=c(r.opacity,n.opacity);return function(t){return r.h=i(t),r.c=a(t),r.l=o(t),r.opacity=s(t),r+\"\"}}}var j=N(s),U=N(c);function V(t){return function r(n){function i(r,i){var a=t((r=e.cubehelix(r)).h,(i=e.cubehelix(i)).h),o=c(r.s,i.s),s=c(r.l,i.l),l=c(r.opacity,i.opacity);return function(t){return r.h=a(t),r.s=o(t),r.l=s(Math.pow(t,n)),r.opacity=l(t),r+\"\"}}return n=+n,i.gamma=r,i}(1)}var q=V(s),H=V(c);t.interpolate=T,t.interpolateArray=function(t,e){return(m(e)?d:g)(t,e)},t.interpolateBasis=n,t.interpolateBasisClosed=i,t.interpolateCubehelix=q,t.interpolateCubehelixLong=H,t.interpolateDate=v,t.interpolateDiscrete=function(t){var e=t.length;return function(r){return t[Math.max(0,Math.min(e-1,Math.floor(r*e)))]}},t.interpolateHcl=j,t.interpolateHclLong=U,t.interpolateHsl=F,t.interpolateHslLong=B,t.interpolateHue=function(t,e){var r=s(+t,+e);return function(t){var e=r(t);return e-360*Math.floor(e/360)}},t.interpolateLab=function(t,r){var n=c((t=e.lab(t)).l,(r=e.lab(r)).l),i=c(t.a,r.a),a=c(t.b,r.b),o=c(t.opacity,r.opacity);return function(e){return t.l=n(e),t.a=i(e),t.b=a(e),t.opacity=o(e),t+\"\"}},t.interpolateNumber=y,t.interpolateNumberArray=d,t.interpolateObject=x,t.interpolateRgb=u,t.interpolateRgbBasis=h,t.interpolateRgbBasisClosed=p,t.interpolateRound=function(t,e){return t=+t,e=+e,function(r){return Math.round(t*(1-r)+e*r)}},t.interpolateString=w,t.interpolateTransformCss=I,t.interpolateTransformSvg=O,t.interpolateZoom=function(t,e){var r,n,i=t[0],a=t[1],o=t[2],s=e[0],l=e[1],c=e[2],u=s-i,f=l-a,h=u*u+f*f;if(h<1e-12)n=Math.log(c/o)/z,r=function(t){return[i+t*u,a+t*f,o*Math.exp(z*t*n)]};else{var p=Math.sqrt(h),d=(c*c-o*o+4*h)/(2*o*2*p),m=(c*c-o*o-4*h)/(2*c*2*p),g=Math.log(Math.sqrt(d*d+1)-d),v=Math.log(Math.sqrt(m*m+1)-m);n=(v-g)/z,r=function(t){var e,r=t*n,s=D(g),l=o/(2*p)*(s*(e=z*r+g,((e=Math.exp(2*e))-1)/(e+1))-function(t){return((t=Math.exp(t))-1/t)/2}(g));return[i+l*u,a+l*f,o*s/D(z*r+g)]}}return r.duration=1e3*n,r},t.piecewise=function(t,e){for(var r=0,n=e.length-1,i=e[0],a=new Array(n<0?0:n);r<n;)a[r]=t(i,i=e[++r]);return function(t){var e=Math.max(0,Math.min(n-1,Math.floor(t*=n)));return a[e](t-e)}},t.quantize=function(t,e){for(var r=new Array(e),n=0;n<e;++n)r[n]=t(n/(e-1));return r},Object.defineProperty(t,\"__esModule\",{value:!0})}))},{\"d3-color\":164}],169:[function(t,e,r){!function(t,n){\"object\"==typeof r&&void 0!==e?n(r):n((t=t||self).d3=t.d3||{})}(this,(function(t){\"use strict\";var e=Math.PI,r=2*e,n=r-1e-6;function i(){this._x0=this._y0=this._x1=this._y1=null,this._=\"\"}function a(){return new i}i.prototype=a.prototype={constructor:i,moveTo:function(t,e){this._+=\"M\"+(this._x0=this._x1=+t)+\",\"+(this._y0=this._y1=+e)},closePath:function(){null!==this._x1&&(this._x1=this._x0,this._y1=this._y0,this._+=\"Z\")},lineTo:function(t,e){this._+=\"L\"+(this._x1=+t)+\",\"+(this._y1=+e)},quadraticCurveTo:function(t,e,r,n){this._+=\"Q\"+ +t+\",\"+ +e+\",\"+(this._x1=+r)+\",\"+(this._y1=+n)},bezierCurveTo:function(t,e,r,n,i,a){this._+=\"C\"+ +t+\",\"+ +e+\",\"+ +r+\",\"+ +n+\",\"+(this._x1=+i)+\",\"+(this._y1=+a)},arcTo:function(t,r,n,i,a){t=+t,r=+r,n=+n,i=+i,a=+a;var o=this._x1,s=this._y1,l=n-t,c=i-r,u=o-t,f=s-r,h=u*u+f*f;if(a<0)throw new Error(\"negative radius: \"+a);if(null===this._x1)this._+=\"M\"+(this._x1=t)+\",\"+(this._y1=r);else if(h>1e-6)if(Math.abs(f*l-c*u)>1e-6&&a){var p=n-o,d=i-s,m=l*l+c*c,g=p*p+d*d,v=Math.sqrt(m),y=Math.sqrt(h),x=a*Math.tan((e-Math.acos((m+h-g)/(2*v*y)))/2),b=x/y,_=x/v;Math.abs(b-1)>1e-6&&(this._+=\"L\"+(t+b*u)+\",\"+(r+b*f)),this._+=\"A\"+a+\",\"+a+\",0,0,\"+ +(f*p>u*d)+\",\"+(this._x1=t+_*l)+\",\"+(this._y1=r+_*c)}else this._+=\"L\"+(this._x1=t)+\",\"+(this._y1=r);else;},arc:function(t,i,a,o,s,l){t=+t,i=+i,l=!!l;var c=(a=+a)*Math.cos(o),u=a*Math.sin(o),f=t+c,h=i+u,p=1^l,d=l?o-s:s-o;if(a<0)throw new Error(\"negative radius: \"+a);null===this._x1?this._+=\"M\"+f+\",\"+h:(Math.abs(this._x1-f)>1e-6||Math.abs(this._y1-h)>1e-6)&&(this._+=\"L\"+f+\",\"+h),a&&(d<0&&(d=d%r+r),d>n?this._+=\"A\"+a+\",\"+a+\",0,1,\"+p+\",\"+(t-c)+\",\"+(i-u)+\"A\"+a+\",\"+a+\",0,1,\"+p+\",\"+(this._x1=f)+\",\"+(this._y1=h):d>1e-6&&(this._+=\"A\"+a+\",\"+a+\",0,\"+ +(d>=e)+\",\"+p+\",\"+(this._x1=t+a*Math.cos(s))+\",\"+(this._y1=i+a*Math.sin(s))))},rect:function(t,e,r,n){this._+=\"M\"+(this._x0=this._x1=+t)+\",\"+(this._y0=this._y1=+e)+\"h\"+ +r+\"v\"+ +n+\"h\"+-r+\"Z\"},toString:function(){return this._}},t.path=a,Object.defineProperty(t,\"__esModule\",{value:!0})}))},{}],170:[function(t,e,r){!function(t,n){\"object\"==typeof r&&void 0!==e?n(r):n((t=t||self).d3=t.d3||{})}(this,(function(t){\"use strict\";function e(t,e,r,n){if(isNaN(e)||isNaN(r))return t;var i,a,o,s,l,c,u,f,h,p=t._root,d={data:n},m=t._x0,g=t._y0,v=t._x1,y=t._y1;if(!p)return t._root=d,t;for(;p.length;)if((c=e>=(a=(m+v)/2))?m=a:v=a,(u=r>=(o=(g+y)/2))?g=o:y=o,i=p,!(p=p[f=u<<1|c]))return i[f]=d,t;if(s=+t._x.call(null,p.data),l=+t._y.call(null,p.data),e===s&&r===l)return d.next=p,i?i[f]=d:t._root=d,t;do{i=i?i[f]=new Array(4):t._root=new Array(4),(c=e>=(a=(m+v)/2))?m=a:v=a,(u=r>=(o=(g+y)/2))?g=o:y=o}while((f=u<<1|c)==(h=(l>=o)<<1|s>=a));return i[h]=p,i[f]=d,t}function r(t,e,r,n,i){this.node=t,this.x0=e,this.y0=r,this.x1=n,this.y1=i}function n(t){return t[0]}function i(t){return t[1]}function a(t,e,r){var a=new o(null==e?n:e,null==r?i:r,NaN,NaN,NaN,NaN);return null==t?a:a.addAll(t)}function o(t,e,r,n,i,a){this._x=t,this._y=e,this._x0=r,this._y0=n,this._x1=i,this._y1=a,this._root=void 0}function s(t){for(var e={data:t.data},r=e;t=t.next;)r=r.next={data:t.data};return e}var l=a.prototype=o.prototype;l.copy=function(){var t,e,r=new o(this._x,this._y,this._x0,this._y0,this._x1,this._y1),n=this._root;if(!n)return r;if(!n.length)return r._root=s(n),r;for(t=[{source:n,target:r._root=new Array(4)}];n=t.pop();)for(var i=0;i<4;++i)(e=n.source[i])&&(e.length?t.push({source:e,target:n.target[i]=new Array(4)}):n.target[i]=s(e));return r},l.add=function(t){var r=+this._x.call(null,t),n=+this._y.call(null,t);return e(this.cover(r,n),r,n,t)},l.addAll=function(t){var r,n,i,a,o=t.length,s=new Array(o),l=new Array(o),c=1/0,u=1/0,f=-1/0,h=-1/0;for(n=0;n<o;++n)isNaN(i=+this._x.call(null,r=t[n]))||isNaN(a=+this._y.call(null,r))||(s[n]=i,l[n]=a,i<c&&(c=i),i>f&&(f=i),a<u&&(u=a),a>h&&(h=a));if(c>f||u>h)return this;for(this.cover(c,u).cover(f,h),n=0;n<o;++n)e(this,s[n],l[n],t[n]);return this},l.cover=function(t,e){if(isNaN(t=+t)||isNaN(e=+e))return this;var r=this._x0,n=this._y0,i=this._x1,a=this._y1;if(isNaN(r))i=(r=Math.floor(t))+1,a=(n=Math.floor(e))+1;else{for(var o,s,l=i-r,c=this._root;r>t||t>=i||n>e||e>=a;)switch(s=(e<n)<<1|t<r,(o=new Array(4))[s]=c,c=o,l*=2,s){case 0:i=r+l,a=n+l;break;case 1:r=i-l,a=n+l;break;case 2:i=r+l,n=a-l;break;case 3:r=i-l,n=a-l}this._root&&this._root.length&&(this._root=c)}return this._x0=r,this._y0=n,this._x1=i,this._y1=a,this},l.data=function(){var t=[];return this.visit((function(e){if(!e.length)do{t.push(e.data)}while(e=e.next)})),t},l.extent=function(t){return arguments.length?this.cover(+t[0][0],+t[0][1]).cover(+t[1][0],+t[1][1]):isNaN(this._x0)?void 0:[[this._x0,this._y0],[this._x1,this._y1]]},l.find=function(t,e,n){var i,a,o,s,l,c,u,f=this._x0,h=this._y0,p=this._x1,d=this._y1,m=[],g=this._root;for(g&&m.push(new r(g,f,h,p,d)),null==n?n=1/0:(f=t-n,h=e-n,p=t+n,d=e+n,n*=n);c=m.pop();)if(!(!(g=c.node)||(a=c.x0)>p||(o=c.y0)>d||(s=c.x1)<f||(l=c.y1)<h))if(g.length){var v=(a+s)/2,y=(o+l)/2;m.push(new r(g[3],v,y,s,l),new r(g[2],a,y,v,l),new r(g[1],v,o,s,y),new r(g[0],a,o,v,y)),(u=(e>=y)<<1|t>=v)&&(c=m[m.length-1],m[m.length-1]=m[m.length-1-u],m[m.length-1-u]=c)}else{var x=t-+this._x.call(null,g.data),b=e-+this._y.call(null,g.data),_=x*x+b*b;if(_<n){var w=Math.sqrt(n=_);f=t-w,h=e-w,p=t+w,d=e+w,i=g.data}}return i},l.remove=function(t){if(isNaN(a=+this._x.call(null,t))||isNaN(o=+this._y.call(null,t)))return this;var e,r,n,i,a,o,s,l,c,u,f,h,p=this._root,d=this._x0,m=this._y0,g=this._x1,v=this._y1;if(!p)return this;if(p.length)for(;;){if((c=a>=(s=(d+g)/2))?d=s:g=s,(u=o>=(l=(m+v)/2))?m=l:v=l,e=p,!(p=p[f=u<<1|c]))return this;if(!p.length)break;(e[f+1&3]||e[f+2&3]||e[f+3&3])&&(r=e,h=f)}for(;p.data!==t;)if(n=p,!(p=p.next))return this;return(i=p.next)&&delete p.next,n?(i?n.next=i:delete n.next,this):e?(i?e[f]=i:delete e[f],(p=e[0]||e[1]||e[2]||e[3])&&p===(e[3]||e[2]||e[1]||e[0])&&!p.length&&(r?r[h]=p:this._root=p),this):(this._root=i,this)},l.removeAll=function(t){for(var e=0,r=t.length;e<r;++e)this.remove(t[e]);return this},l.root=function(){return this._root},l.size=function(){var t=0;return this.visit((function(e){if(!e.length)do{++t}while(e=e.next)})),t},l.visit=function(t){var e,n,i,a,o,s,l=[],c=this._root;for(c&&l.push(new r(c,this._x0,this._y0,this._x1,this._y1));e=l.pop();)if(!t(c=e.node,i=e.x0,a=e.y0,o=e.x1,s=e.y1)&&c.length){var u=(i+o)/2,f=(a+s)/2;(n=c[3])&&l.push(new r(n,u,f,o,s)),(n=c[2])&&l.push(new r(n,i,f,u,s)),(n=c[1])&&l.push(new r(n,u,a,o,f)),(n=c[0])&&l.push(new r(n,i,a,u,f))}return this},l.visitAfter=function(t){var e,n=[],i=[];for(this._root&&n.push(new r(this._root,this._x0,this._y0,this._x1,this._y1));e=n.pop();){var a=e.node;if(a.length){var o,s=e.x0,l=e.y0,c=e.x1,u=e.y1,f=(s+c)/2,h=(l+u)/2;(o=a[0])&&n.push(new r(o,s,l,f,h)),(o=a[1])&&n.push(new r(o,f,l,c,h)),(o=a[2])&&n.push(new r(o,s,h,f,u)),(o=a[3])&&n.push(new r(o,f,h,c,u))}i.push(e)}for(;e=i.pop();)t(e.node,e.x0,e.y0,e.x1,e.y1);return this},l.x=function(t){return arguments.length?(this._x=t,this):this._x},l.y=function(t){return arguments.length?(this._y=t,this):this._y},t.quadtree=a,Object.defineProperty(t,\"__esModule\",{value:!0})}))},{}],171:[function(t,e,r){!function(n,i){\"object\"==typeof r&&void 0!==e?i(r,t(\"d3-path\")):i((n=n||self).d3=n.d3||{},n.d3)}(this,(function(t,e){\"use strict\";function r(t){return function(){return t}}var n=Math.abs,i=Math.atan2,a=Math.cos,o=Math.max,s=Math.min,l=Math.sin,c=Math.sqrt,u=Math.PI,f=u/2,h=2*u;function p(t){return t>1?0:t<-1?u:Math.acos(t)}function d(t){return t>=1?f:t<=-1?-f:Math.asin(t)}function m(t){return t.innerRadius}function g(t){return t.outerRadius}function v(t){return t.startAngle}function y(t){return t.endAngle}function x(t){return t&&t.padAngle}function b(t,e,r,n,i,a,o,s){var l=r-t,c=n-e,u=o-i,f=s-a,h=f*l-u*c;if(!(h*h<1e-12))return[t+(h=(u*(e-a)-f*(t-i))/h)*l,e+h*c]}function _(t,e,r,n,i,a,s){var l=t-r,u=e-n,f=(s?a:-a)/c(l*l+u*u),h=f*u,p=-f*l,d=t+h,m=e+p,g=r+h,v=n+p,y=(d+g)/2,x=(m+v)/2,b=g-d,_=v-m,w=b*b+_*_,T=i-a,k=d*v-g*m,M=(_<0?-1:1)*c(o(0,T*T*w-k*k)),A=(k*_-b*M)/w,S=(-k*b-_*M)/w,E=(k*_+b*M)/w,L=(-k*b+_*M)/w,C=A-y,P=S-x,I=E-y,O=L-x;return C*C+P*P>I*I+O*O&&(A=E,S=L),{cx:A,cy:S,x01:-h,y01:-p,x11:A*(i/T-1),y11:S*(i/T-1)}}function w(t){this._context=t}function T(t){return new w(t)}function k(t){return t[0]}function M(t){return t[1]}function A(){var t=k,n=M,i=r(!0),a=null,o=T,s=null;function l(r){var l,c,u,f=r.length,h=!1;for(null==a&&(s=o(u=e.path())),l=0;l<=f;++l)!(l<f&&i(c=r[l],l,r))===h&&((h=!h)?s.lineStart():s.lineEnd()),h&&s.point(+t(c,l,r),+n(c,l,r));if(u)return s=null,u+\"\"||null}return l.x=function(e){return arguments.length?(t=\"function\"==typeof e?e:r(+e),l):t},l.y=function(t){return arguments.length?(n=\"function\"==typeof t?t:r(+t),l):n},l.defined=function(t){return arguments.length?(i=\"function\"==typeof t?t:r(!!t),l):i},l.curve=function(t){return arguments.length?(o=t,null!=a&&(s=o(a)),l):o},l.context=function(t){return arguments.length?(null==t?a=s=null:s=o(a=t),l):a},l}function S(){var t=k,n=null,i=r(0),a=M,o=r(!0),s=null,l=T,c=null;function u(r){var u,f,h,p,d,m=r.length,g=!1,v=new Array(m),y=new Array(m);for(null==s&&(c=l(d=e.path())),u=0;u<=m;++u){if(!(u<m&&o(p=r[u],u,r))===g)if(g=!g)f=u,c.areaStart(),c.lineStart();else{for(c.lineEnd(),c.lineStart(),h=u-1;h>=f;--h)c.point(v[h],y[h]);c.lineEnd(),c.areaEnd()}g&&(v[u]=+t(p,u,r),y[u]=+i(p,u,r),c.point(n?+n(p,u,r):v[u],a?+a(p,u,r):y[u]))}if(d)return c=null,d+\"\"||null}function f(){return A().defined(o).curve(l).context(s)}return u.x=function(e){return arguments.length?(t=\"function\"==typeof e?e:r(+e),n=null,u):t},u.x0=function(e){return arguments.length?(t=\"function\"==typeof e?e:r(+e),u):t},u.x1=function(t){return arguments.length?(n=null==t?null:\"function\"==typeof t?t:r(+t),u):n},u.y=function(t){return arguments.length?(i=\"function\"==typeof t?t:r(+t),a=null,u):i},u.y0=function(t){return arguments.length?(i=\"function\"==typeof t?t:r(+t),u):i},u.y1=function(t){return arguments.length?(a=null==t?null:\"function\"==typeof t?t:r(+t),u):a},u.lineX0=u.lineY0=function(){return f().x(t).y(i)},u.lineY1=function(){return f().x(t).y(a)},u.lineX1=function(){return f().x(n).y(i)},u.defined=function(t){return arguments.length?(o=\"function\"==typeof t?t:r(!!t),u):o},u.curve=function(t){return arguments.length?(l=t,null!=s&&(c=l(s)),u):l},u.context=function(t){return arguments.length?(null==t?s=c=null:c=l(s=t),u):s},u}function E(t,e){return e<t?-1:e>t?1:e>=t?0:NaN}function L(t){return t}w.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._point=0},lineEnd:function(){(this._line||0!==this._line&&1===this._point)&&this._context.closePath(),this._line=1-this._line},point:function(t,e){switch(t=+t,e=+e,this._point){case 0:this._point=1,this._line?this._context.lineTo(t,e):this._context.moveTo(t,e);break;case 1:this._point=2;default:this._context.lineTo(t,e)}}};var C=I(T);function P(t){this._curve=t}function I(t){function e(e){return new P(t(e))}return e._curve=t,e}function O(t){var e=t.curve;return t.angle=t.x,delete t.x,t.radius=t.y,delete t.y,t.curve=function(t){return arguments.length?e(I(t)):e()._curve},t}function z(){return O(A().curve(C))}function D(){var t=S().curve(C),e=t.curve,r=t.lineX0,n=t.lineX1,i=t.lineY0,a=t.lineY1;return t.angle=t.x,delete t.x,t.startAngle=t.x0,delete t.x0,t.endAngle=t.x1,delete t.x1,t.radius=t.y,delete t.y,t.innerRadius=t.y0,delete t.y0,t.outerRadius=t.y1,delete t.y1,t.lineStartAngle=function(){return O(r())},delete t.lineX0,t.lineEndAngle=function(){return O(n())},delete t.lineX1,t.lineInnerRadius=function(){return O(i())},delete t.lineY0,t.lineOuterRadius=function(){return O(a())},delete t.lineY1,t.curve=function(t){return arguments.length?e(I(t)):e()._curve},t}function R(t,e){return[(e=+e)*Math.cos(t-=Math.PI/2),e*Math.sin(t)]}P.prototype={areaStart:function(){this._curve.areaStart()},areaEnd:function(){this._curve.areaEnd()},lineStart:function(){this._curve.lineStart()},lineEnd:function(){this._curve.lineEnd()},point:function(t,e){this._curve.point(e*Math.sin(t),e*-Math.cos(t))}};var F=Array.prototype.slice;function B(t){return t.source}function N(t){return t.target}function j(t){var n=B,i=N,a=k,o=M,s=null;function l(){var r,l=F.call(arguments),c=n.apply(this,l),u=i.apply(this,l);if(s||(s=r=e.path()),t(s,+a.apply(this,(l[0]=c,l)),+o.apply(this,l),+a.apply(this,(l[0]=u,l)),+o.apply(this,l)),r)return s=null,r+\"\"||null}return l.source=function(t){return arguments.length?(n=t,l):n},l.target=function(t){return arguments.length?(i=t,l):i},l.x=function(t){return arguments.length?(a=\"function\"==typeof t?t:r(+t),l):a},l.y=function(t){return arguments.length?(o=\"function\"==typeof t?t:r(+t),l):o},l.context=function(t){return arguments.length?(s=null==t?null:t,l):s},l}function U(t,e,r,n,i){t.moveTo(e,r),t.bezierCurveTo(e=(e+n)/2,r,e,i,n,i)}function V(t,e,r,n,i){t.moveTo(e,r),t.bezierCurveTo(e,r=(r+i)/2,n,r,n,i)}function q(t,e,r,n,i){var a=R(e,r),o=R(e,r=(r+i)/2),s=R(n,r),l=R(n,i);t.moveTo(a[0],a[1]),t.bezierCurveTo(o[0],o[1],s[0],s[1],l[0],l[1])}var H={draw:function(t,e){var r=Math.sqrt(e/u);t.moveTo(r,0),t.arc(0,0,r,0,h)}},G={draw:function(t,e){var r=Math.sqrt(e/5)/2;t.moveTo(-3*r,-r),t.lineTo(-r,-r),t.lineTo(-r,-3*r),t.lineTo(r,-3*r),t.lineTo(r,-r),t.lineTo(3*r,-r),t.lineTo(3*r,r),t.lineTo(r,r),t.lineTo(r,3*r),t.lineTo(-r,3*r),t.lineTo(-r,r),t.lineTo(-3*r,r),t.closePath()}},Y=Math.sqrt(1/3),W=2*Y,X={draw:function(t,e){var r=Math.sqrt(e/W),n=r*Y;t.moveTo(0,-r),t.lineTo(n,0),t.lineTo(0,r),t.lineTo(-n,0),t.closePath()}},Z=Math.sin(u/10)/Math.sin(7*u/10),J=Math.sin(h/10)*Z,K=-Math.cos(h/10)*Z,Q={draw:function(t,e){var r=Math.sqrt(.8908130915292852*e),n=J*r,i=K*r;t.moveTo(0,-r),t.lineTo(n,i);for(var a=1;a<5;++a){var o=h*a/5,s=Math.cos(o),l=Math.sin(o);t.lineTo(l*r,-s*r),t.lineTo(s*n-l*i,l*n+s*i)}t.closePath()}},$={draw:function(t,e){var r=Math.sqrt(e),n=-r/2;t.rect(n,n,r,r)}},tt=Math.sqrt(3),et={draw:function(t,e){var r=-Math.sqrt(e/(3*tt));t.moveTo(0,2*r),t.lineTo(-tt*r,-r),t.lineTo(tt*r,-r),t.closePath()}},rt=-.5,nt=Math.sqrt(3)/2,it=1/Math.sqrt(12),at=3*(it/2+1),ot={draw:function(t,e){var r=Math.sqrt(e/at),n=r/2,i=r*it,a=n,o=r*it+r,s=-a,l=o;t.moveTo(n,i),t.lineTo(a,o),t.lineTo(s,l),t.lineTo(rt*n-nt*i,nt*n+rt*i),t.lineTo(rt*a-nt*o,nt*a+rt*o),t.lineTo(rt*s-nt*l,nt*s+rt*l),t.lineTo(rt*n+nt*i,rt*i-nt*n),t.lineTo(rt*a+nt*o,rt*o-nt*a),t.lineTo(rt*s+nt*l,rt*l-nt*s),t.closePath()}},st=[H,G,X,$,Q,et,ot];function lt(){}function ct(t,e,r){t._context.bezierCurveTo((2*t._x0+t._x1)/3,(2*t._y0+t._y1)/3,(t._x0+2*t._x1)/3,(t._y0+2*t._y1)/3,(t._x0+4*t._x1+e)/6,(t._y0+4*t._y1+r)/6)}function ut(t){this._context=t}function ft(t){this._context=t}function ht(t){this._context=t}function pt(t,e){this._basis=new ut(t),this._beta=e}ut.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x0=this._x1=this._y0=this._y1=NaN,this._point=0},lineEnd:function(){switch(this._point){case 3:ct(this,this._x1,this._y1);case 2:this._context.lineTo(this._x1,this._y1)}(this._line||0!==this._line&&1===this._point)&&this._context.closePath(),this._line=1-this._line},point:function(t,e){switch(t=+t,e=+e,this._point){case 0:this._point=1,this._line?this._context.lineTo(t,e):this._context.moveTo(t,e);break;case 1:this._point=2;break;case 2:this._point=3,this._context.lineTo((5*this._x0+this._x1)/6,(5*this._y0+this._y1)/6);default:ct(this,t,e)}this._x0=this._x1,this._x1=t,this._y0=this._y1,this._y1=e}},ft.prototype={areaStart:lt,areaEnd:lt,lineStart:function(){this._x0=this._x1=this._x2=this._x3=this._x4=this._y0=this._y1=this._y2=this._y3=this._y4=NaN,this._point=0},lineEnd:function(){switch(this._point){case 1:this._context.moveTo(this._x2,this._y2),this._context.closePath();break;case 2:this._context.moveTo((this._x2+2*this._x3)/3,(this._y2+2*this._y3)/3),this._context.lineTo((this._x3+2*this._x2)/3,(this._y3+2*this._y2)/3),this._context.closePath();break;case 3:this.point(this._x2,this._y2),this.point(this._x3,this._y3),this.point(this._x4,this._y4)}},point:function(t,e){switch(t=+t,e=+e,this._point){case 0:this._point=1,this._x2=t,this._y2=e;break;case 1:this._point=2,this._x3=t,this._y3=e;break;case 2:this._point=3,this._x4=t,this._y4=e,this._context.moveTo((this._x0+4*this._x1+t)/6,(this._y0+4*this._y1+e)/6);break;default:ct(this,t,e)}this._x0=this._x1,this._x1=t,this._y0=this._y1,this._y1=e}},ht.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x0=this._x1=this._y0=this._y1=NaN,this._point=0},lineEnd:function(){(this._line||0!==this._line&&3===this._point)&&this._context.closePath(),this._line=1-this._line},point:function(t,e){switch(t=+t,e=+e,this._point){case 0:this._point=1;break;case 1:this._point=2;break;case 2:this._point=3;var r=(this._x0+4*this._x1+t)/6,n=(this._y0+4*this._y1+e)/6;this._line?this._context.lineTo(r,n):this._context.moveTo(r,n);break;case 3:this._point=4;default:ct(this,t,e)}this._x0=this._x1,this._x1=t,this._y0=this._y1,this._y1=e}},pt.prototype={lineStart:function(){this._x=[],this._y=[],this._basis.lineStart()},lineEnd:function(){var t=this._x,e=this._y,r=t.length-1;if(r>0)for(var n,i=t[0],a=e[0],o=t[r]-i,s=e[r]-a,l=-1;++l<=r;)n=l/r,this._basis.point(this._beta*t[l]+(1-this._beta)*(i+n*o),this._beta*e[l]+(1-this._beta)*(a+n*s));this._x=this._y=null,this._basis.lineEnd()},point:function(t,e){this._x.push(+t),this._y.push(+e)}};var dt=function t(e){function r(t){return 1===e?new ut(t):new pt(t,e)}return r.beta=function(e){return t(+e)},r}(.85);function mt(t,e,r){t._context.bezierCurveTo(t._x1+t._k*(t._x2-t._x0),t._y1+t._k*(t._y2-t._y0),t._x2+t._k*(t._x1-e),t._y2+t._k*(t._y1-r),t._x2,t._y2)}function gt(t,e){this._context=t,this._k=(1-e)/6}gt.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x0=this._x1=this._x2=this._y0=this._y1=this._y2=NaN,this._point=0},lineEnd:function(){switch(this._point){case 2:this._context.lineTo(this._x2,this._y2);break;case 3:mt(this,this._x1,this._y1)}(this._line||0!==this._line&&1===this._point)&&this._context.closePath(),this._line=1-this._line},point:function(t,e){switch(t=+t,e=+e,this._point){case 0:this._point=1,this._line?this._context.lineTo(t,e):this._context.moveTo(t,e);break;case 1:this._point=2,this._x1=t,this._y1=e;break;case 2:this._point=3;default:mt(this,t,e)}this._x0=this._x1,this._x1=this._x2,this._x2=t,this._y0=this._y1,this._y1=this._y2,this._y2=e}};var vt=function t(e){function r(t){return new gt(t,e)}return r.tension=function(e){return t(+e)},r}(0);function yt(t,e){this._context=t,this._k=(1-e)/6}yt.prototype={areaStart:lt,areaEnd:lt,lineStart:function(){this._x0=this._x1=this._x2=this._x3=this._x4=this._x5=this._y0=this._y1=this._y2=this._y3=this._y4=this._y5=NaN,this._point=0},lineEnd:function(){switch(this._point){case 1:this._context.moveTo(this._x3,this._y3),this._context.closePath();break;case 2:this._context.lineTo(this._x3,this._y3),this._context.closePath();break;case 3:this.point(this._x3,this._y3),this.point(this._x4,this._y4),this.point(this._x5,this._y5)}},point:function(t,e){switch(t=+t,e=+e,this._point){case 0:this._point=1,this._x3=t,this._y3=e;break;case 1:this._point=2,this._context.moveTo(this._x4=t,this._y4=e);break;case 2:this._point=3,this._x5=t,this._y5=e;break;default:mt(this,t,e)}this._x0=this._x1,this._x1=this._x2,this._x2=t,this._y0=this._y1,this._y1=this._y2,this._y2=e}};var xt=function t(e){function r(t){return new yt(t,e)}return r.tension=function(e){return t(+e)},r}(0);function bt(t,e){this._context=t,this._k=(1-e)/6}bt.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x0=this._x1=this._x2=this._y0=this._y1=this._y2=NaN,this._point=0},lineEnd:function(){(this._line||0!==this._line&&3===this._point)&&this._context.closePath(),this._line=1-this._line},point:function(t,e){switch(t=+t,e=+e,this._point){case 0:this._point=1;break;case 1:this._point=2;break;case 2:this._point=3,this._line?this._context.lineTo(this._x2,this._y2):this._context.moveTo(this._x2,this._y2);break;case 3:this._point=4;default:mt(this,t,e)}this._x0=this._x1,this._x1=this._x2,this._x2=t,this._y0=this._y1,this._y1=this._y2,this._y2=e}};var _t=function t(e){function r(t){return new bt(t,e)}return r.tension=function(e){return t(+e)},r}(0);function wt(t,e,r){var n=t._x1,i=t._y1,a=t._x2,o=t._y2;if(t._l01_a>1e-12){var s=2*t._l01_2a+3*t._l01_a*t._l12_a+t._l12_2a,l=3*t._l01_a*(t._l01_a+t._l12_a);n=(n*s-t._x0*t._l12_2a+t._x2*t._l01_2a)/l,i=(i*s-t._y0*t._l12_2a+t._y2*t._l01_2a)/l}if(t._l23_a>1e-12){var c=2*t._l23_2a+3*t._l23_a*t._l12_a+t._l12_2a,u=3*t._l23_a*(t._l23_a+t._l12_a);a=(a*c+t._x1*t._l23_2a-e*t._l12_2a)/u,o=(o*c+t._y1*t._l23_2a-r*t._l12_2a)/u}t._context.bezierCurveTo(n,i,a,o,t._x2,t._y2)}function Tt(t,e){this._context=t,this._alpha=e}Tt.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x0=this._x1=this._x2=this._y0=this._y1=this._y2=NaN,this._l01_a=this._l12_a=this._l23_a=this._l01_2a=this._l12_2a=this._l23_2a=this._point=0},lineEnd:function(){switch(this._point){case 2:this._context.lineTo(this._x2,this._y2);break;case 3:this.point(this._x2,this._y2)}(this._line||0!==this._line&&1===this._point)&&this._context.closePath(),this._line=1-this._line},point:function(t,e){if(t=+t,e=+e,this._point){var r=this._x2-t,n=this._y2-e;this._l23_a=Math.sqrt(this._l23_2a=Math.pow(r*r+n*n,this._alpha))}switch(this._point){case 0:this._point=1,this._line?this._context.lineTo(t,e):this._context.moveTo(t,e);break;case 1:this._point=2;break;case 2:this._point=3;default:wt(this,t,e)}this._l01_a=this._l12_a,this._l12_a=this._l23_a,this._l01_2a=this._l12_2a,this._l12_2a=this._l23_2a,this._x0=this._x1,this._x1=this._x2,this._x2=t,this._y0=this._y1,this._y1=this._y2,this._y2=e}};var kt=function t(e){function r(t){return e?new Tt(t,e):new gt(t,0)}return r.alpha=function(e){return t(+e)},r}(.5);function Mt(t,e){this._context=t,this._alpha=e}Mt.prototype={areaStart:lt,areaEnd:lt,lineStart:function(){this._x0=this._x1=this._x2=this._x3=this._x4=this._x5=this._y0=this._y1=this._y2=this._y3=this._y4=this._y5=NaN,this._l01_a=this._l12_a=this._l23_a=this._l01_2a=this._l12_2a=this._l23_2a=this._point=0},lineEnd:function(){switch(this._point){case 1:this._context.moveTo(this._x3,this._y3),this._context.closePath();break;case 2:this._context.lineTo(this._x3,this._y3),this._context.closePath();break;case 3:this.point(this._x3,this._y3),this.point(this._x4,this._y4),this.point(this._x5,this._y5)}},point:function(t,e){if(t=+t,e=+e,this._point){var r=this._x2-t,n=this._y2-e;this._l23_a=Math.sqrt(this._l23_2a=Math.pow(r*r+n*n,this._alpha))}switch(this._point){case 0:this._point=1,this._x3=t,this._y3=e;break;case 1:this._point=2,this._context.moveTo(this._x4=t,this._y4=e);break;case 2:this._point=3,this._x5=t,this._y5=e;break;default:wt(this,t,e)}this._l01_a=this._l12_a,this._l12_a=this._l23_a,this._l01_2a=this._l12_2a,this._l12_2a=this._l23_2a,this._x0=this._x1,this._x1=this._x2,this._x2=t,this._y0=this._y1,this._y1=this._y2,this._y2=e}};var At=function t(e){function r(t){return e?new Mt(t,e):new yt(t,0)}return r.alpha=function(e){return t(+e)},r}(.5);function St(t,e){this._context=t,this._alpha=e}St.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x0=this._x1=this._x2=this._y0=this._y1=this._y2=NaN,this._l01_a=this._l12_a=this._l23_a=this._l01_2a=this._l12_2a=this._l23_2a=this._point=0},lineEnd:function(){(this._line||0!==this._line&&3===this._point)&&this._context.closePath(),this._line=1-this._line},point:function(t,e){if(t=+t,e=+e,this._point){var r=this._x2-t,n=this._y2-e;this._l23_a=Math.sqrt(this._l23_2a=Math.pow(r*r+n*n,this._alpha))}switch(this._point){case 0:this._point=1;break;case 1:this._point=2;break;case 2:this._point=3,this._line?this._context.lineTo(this._x2,this._y2):this._context.moveTo(this._x2,this._y2);break;case 3:this._point=4;default:wt(this,t,e)}this._l01_a=this._l12_a,this._l12_a=this._l23_a,this._l01_2a=this._l12_2a,this._l12_2a=this._l23_2a,this._x0=this._x1,this._x1=this._x2,this._x2=t,this._y0=this._y1,this._y1=this._y2,this._y2=e}};var Et=function t(e){function r(t){return e?new St(t,e):new bt(t,0)}return r.alpha=function(e){return t(+e)},r}(.5);function Lt(t){this._context=t}function Ct(t){return t<0?-1:1}function Pt(t,e,r){var n=t._x1-t._x0,i=e-t._x1,a=(t._y1-t._y0)/(n||i<0&&-0),o=(r-t._y1)/(i||n<0&&-0),s=(a*i+o*n)/(n+i);return(Ct(a)+Ct(o))*Math.min(Math.abs(a),Math.abs(o),.5*Math.abs(s))||0}function It(t,e){var r=t._x1-t._x0;return r?(3*(t._y1-t._y0)/r-e)/2:e}function Ot(t,e,r){var n=t._x0,i=t._y0,a=t._x1,o=t._y1,s=(a-n)/3;t._context.bezierCurveTo(n+s,i+s*e,a-s,o-s*r,a,o)}function zt(t){this._context=t}function Dt(t){this._context=new Rt(t)}function Rt(t){this._context=t}function Ft(t){this._context=t}function Bt(t){var e,r,n=t.length-1,i=new Array(n),a=new Array(n),o=new Array(n);for(i[0]=0,a[0]=2,o[0]=t[0]+2*t[1],e=1;e<n-1;++e)i[e]=1,a[e]=4,o[e]=4*t[e]+2*t[e+1];for(i[n-1]=2,a[n-1]=7,o[n-1]=8*t[n-1]+t[n],e=1;e<n;++e)r=i[e]/a[e-1],a[e]-=r,o[e]-=r*o[e-1];for(i[n-1]=o[n-1]/a[n-1],e=n-2;e>=0;--e)i[e]=(o[e]-i[e+1])/a[e];for(a[n-1]=(t[n]+i[n-1])/2,e=0;e<n-1;++e)a[e]=2*t[e+1]-i[e+1];return[i,a]}function Nt(t,e){this._context=t,this._t=e}function jt(t,e){if((i=t.length)>1)for(var r,n,i,a=1,o=t[e[0]],s=o.length;a<i;++a)for(n=o,o=t[e[a]],r=0;r<s;++r)o[r][1]+=o[r][0]=isNaN(n[r][1])?n[r][0]:n[r][1]}function Ut(t){for(var e=t.length,r=new Array(e);--e>=0;)r[e]=e;return r}function Vt(t,e){return t[e]}function qt(t){var e=t.map(Ht);return Ut(t).sort((function(t,r){return e[t]-e[r]}))}function Ht(t){for(var e,r=-1,n=0,i=t.length,a=-1/0;++r<i;)(e=+t[r][1])>a&&(a=e,n=r);return n}function Gt(t){var e=t.map(Yt);return Ut(t).sort((function(t,r){return e[t]-e[r]}))}function Yt(t){for(var e,r=0,n=-1,i=t.length;++n<i;)(e=+t[n][1])&&(r+=e);return r}Lt.prototype={areaStart:lt,areaEnd:lt,lineStart:function(){this._point=0},lineEnd:function(){this._point&&this._context.closePath()},point:function(t,e){t=+t,e=+e,this._point?this._context.lineTo(t,e):(this._point=1,this._context.moveTo(t,e))}},zt.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x0=this._x1=this._y0=this._y1=this._t0=NaN,this._point=0},lineEnd:function(){switch(this._point){case 2:this._context.lineTo(this._x1,this._y1);break;case 3:Ot(this,this._t0,It(this,this._t0))}(this._line||0!==this._line&&1===this._point)&&this._context.closePath(),this._line=1-this._line},point:function(t,e){var r=NaN;if(e=+e,(t=+t)!==this._x1||e!==this._y1){switch(this._point){case 0:this._point=1,this._line?this._context.lineTo(t,e):this._context.moveTo(t,e);break;case 1:this._point=2;break;case 2:this._point=3,Ot(this,It(this,r=Pt(this,t,e)),r);break;default:Ot(this,this._t0,r=Pt(this,t,e))}this._x0=this._x1,this._x1=t,this._y0=this._y1,this._y1=e,this._t0=r}}},(Dt.prototype=Object.create(zt.prototype)).point=function(t,e){zt.prototype.point.call(this,e,t)},Rt.prototype={moveTo:function(t,e){this._context.moveTo(e,t)},closePath:function(){this._context.closePath()},lineTo:function(t,e){this._context.lineTo(e,t)},bezierCurveTo:function(t,e,r,n,i,a){this._context.bezierCurveTo(e,t,n,r,a,i)}},Ft.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x=[],this._y=[]},lineEnd:function(){var t=this._x,e=this._y,r=t.length;if(r)if(this._line?this._context.lineTo(t[0],e[0]):this._context.moveTo(t[0],e[0]),2===r)this._context.lineTo(t[1],e[1]);else for(var n=Bt(t),i=Bt(e),a=0,o=1;o<r;++a,++o)this._context.bezierCurveTo(n[0][a],i[0][a],n[1][a],i[1][a],t[o],e[o]);(this._line||0!==this._line&&1===r)&&this._context.closePath(),this._line=1-this._line,this._x=this._y=null},point:function(t,e){this._x.push(+t),this._y.push(+e)}},Nt.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x=this._y=NaN,this._point=0},lineEnd:function(){0<this._t&&this._t<1&&2===this._point&&this._context.lineTo(this._x,this._y),(this._line||0!==this._line&&1===this._point)&&this._context.closePath(),this._line>=0&&(this._t=1-this._t,this._line=1-this._line)},point:function(t,e){switch(t=+t,e=+e,this._point){case 0:this._point=1,this._line?this._context.lineTo(t,e):this._context.moveTo(t,e);break;case 1:this._point=2;default:if(this._t<=0)this._context.lineTo(this._x,e),this._context.lineTo(t,e);else{var r=this._x*(1-this._t)+t*this._t;this._context.lineTo(r,this._y),this._context.lineTo(r,e)}}this._x=t,this._y=e}},t.arc=function(){var t=m,o=g,w=r(0),T=null,k=v,M=y,A=x,S=null;function E(){var r,m,g=+t.apply(this,arguments),v=+o.apply(this,arguments),y=k.apply(this,arguments)-f,x=M.apply(this,arguments)-f,E=n(x-y),L=x>y;if(S||(S=r=e.path()),v<g&&(m=v,v=g,g=m),v>1e-12)if(E>h-1e-12)S.moveTo(v*a(y),v*l(y)),S.arc(0,0,v,y,x,!L),g>1e-12&&(S.moveTo(g*a(x),g*l(x)),S.arc(0,0,g,x,y,L));else{var C,P,I=y,O=x,z=y,D=x,R=E,F=E,B=A.apply(this,arguments)/2,N=B>1e-12&&(T?+T.apply(this,arguments):c(g*g+v*v)),j=s(n(v-g)/2,+w.apply(this,arguments)),U=j,V=j;if(N>1e-12){var q=d(N/g*l(B)),H=d(N/v*l(B));(R-=2*q)>1e-12?(z+=q*=L?1:-1,D-=q):(R=0,z=D=(y+x)/2),(F-=2*H)>1e-12?(I+=H*=L?1:-1,O-=H):(F=0,I=O=(y+x)/2)}var G=v*a(I),Y=v*l(I),W=g*a(D),X=g*l(D);if(j>1e-12){var Z,J=v*a(O),K=v*l(O),Q=g*a(z),$=g*l(z);if(E<u&&(Z=b(G,Y,Q,$,J,K,W,X))){var tt=G-Z[0],et=Y-Z[1],rt=J-Z[0],nt=K-Z[1],it=1/l(p((tt*rt+et*nt)/(c(tt*tt+et*et)*c(rt*rt+nt*nt)))/2),at=c(Z[0]*Z[0]+Z[1]*Z[1]);U=s(j,(g-at)/(it-1)),V=s(j,(v-at)/(it+1))}}F>1e-12?V>1e-12?(C=_(Q,$,G,Y,v,V,L),P=_(J,K,W,X,v,V,L),S.moveTo(C.cx+C.x01,C.cy+C.y01),V<j?S.arc(C.cx,C.cy,V,i(C.y01,C.x01),i(P.y01,P.x01),!L):(S.arc(C.cx,C.cy,V,i(C.y01,C.x01),i(C.y11,C.x11),!L),S.arc(0,0,v,i(C.cy+C.y11,C.cx+C.x11),i(P.cy+P.y11,P.cx+P.x11),!L),S.arc(P.cx,P.cy,V,i(P.y11,P.x11),i(P.y01,P.x01),!L))):(S.moveTo(G,Y),S.arc(0,0,v,I,O,!L)):S.moveTo(G,Y),g>1e-12&&R>1e-12?U>1e-12?(C=_(W,X,J,K,g,-U,L),P=_(G,Y,Q,$,g,-U,L),S.lineTo(C.cx+C.x01,C.cy+C.y01),U<j?S.arc(C.cx,C.cy,U,i(C.y01,C.x01),i(P.y01,P.x01),!L):(S.arc(C.cx,C.cy,U,i(C.y01,C.x01),i(C.y11,C.x11),!L),S.arc(0,0,g,i(C.cy+C.y11,C.cx+C.x11),i(P.cy+P.y11,P.cx+P.x11),L),S.arc(P.cx,P.cy,U,i(P.y11,P.x11),i(P.y01,P.x01),!L))):S.arc(0,0,g,D,z,L):S.lineTo(W,X)}else S.moveTo(0,0);if(S.closePath(),r)return S=null,r+\"\"||null}return E.centroid=function(){var e=(+t.apply(this,arguments)+ +o.apply(this,arguments))/2,r=(+k.apply(this,arguments)+ +M.apply(this,arguments))/2-u/2;return[a(r)*e,l(r)*e]},E.innerRadius=function(e){return arguments.length?(t=\"function\"==typeof e?e:r(+e),E):t},E.outerRadius=function(t){return arguments.length?(o=\"function\"==typeof t?t:r(+t),E):o},E.cornerRadius=function(t){return arguments.length?(w=\"function\"==typeof t?t:r(+t),E):w},E.padRadius=function(t){return arguments.length?(T=null==t?null:\"function\"==typeof t?t:r(+t),E):T},E.startAngle=function(t){return arguments.length?(k=\"function\"==typeof t?t:r(+t),E):k},E.endAngle=function(t){return arguments.length?(M=\"function\"==typeof t?t:r(+t),E):M},E.padAngle=function(t){return arguments.length?(A=\"function\"==typeof t?t:r(+t),E):A},E.context=function(t){return arguments.length?(S=null==t?null:t,E):S},E},t.area=S,t.areaRadial=D,t.curveBasis=function(t){return new ut(t)},t.curveBasisClosed=function(t){return new ft(t)},t.curveBasisOpen=function(t){return new ht(t)},t.curveBundle=dt,t.curveCardinal=vt,t.curveCardinalClosed=xt,t.curveCardinalOpen=_t,t.curveCatmullRom=kt,t.curveCatmullRomClosed=At,t.curveCatmullRomOpen=Et,t.curveLinear=T,t.curveLinearClosed=function(t){return new Lt(t)},t.curveMonotoneX=function(t){return new zt(t)},t.curveMonotoneY=function(t){return new Dt(t)},t.curveNatural=function(t){return new Ft(t)},t.curveStep=function(t){return new Nt(t,.5)},t.curveStepAfter=function(t){return new Nt(t,1)},t.curveStepBefore=function(t){return new Nt(t,0)},t.line=A,t.lineRadial=z,t.linkHorizontal=function(){return j(U)},t.linkRadial=function(){var t=j(q);return t.angle=t.x,delete t.x,t.radius=t.y,delete t.y,t},t.linkVertical=function(){return j(V)},t.pie=function(){var t=L,e=E,n=null,i=r(0),a=r(h),o=r(0);function s(r){var s,l,c,u,f,p=r.length,d=0,m=new Array(p),g=new Array(p),v=+i.apply(this,arguments),y=Math.min(h,Math.max(-h,a.apply(this,arguments)-v)),x=Math.min(Math.abs(y)/p,o.apply(this,arguments)),b=x*(y<0?-1:1);for(s=0;s<p;++s)(f=g[m[s]=s]=+t(r[s],s,r))>0&&(d+=f);for(null!=e?m.sort((function(t,r){return e(g[t],g[r])})):null!=n&&m.sort((function(t,e){return n(r[t],r[e])})),s=0,c=d?(y-p*b)/d:0;s<p;++s,v=u)l=m[s],u=v+((f=g[l])>0?f*c:0)+b,g[l]={data:r[l],index:s,value:f,startAngle:v,endAngle:u,padAngle:x};return g}return s.value=function(e){return arguments.length?(t=\"function\"==typeof e?e:r(+e),s):t},s.sortValues=function(t){return arguments.length?(e=t,n=null,s):e},s.sort=function(t){return arguments.length?(n=t,e=null,s):n},s.startAngle=function(t){return arguments.length?(i=\"function\"==typeof t?t:r(+t),s):i},s.endAngle=function(t){return arguments.length?(a=\"function\"==typeof t?t:r(+t),s):a},s.padAngle=function(t){return arguments.length?(o=\"function\"==typeof t?t:r(+t),s):o},s},t.pointRadial=R,t.radialArea=D,t.radialLine=z,t.stack=function(){var t=r([]),e=Ut,n=jt,i=Vt;function a(r){var a,o,s=t.apply(this,arguments),l=r.length,c=s.length,u=new Array(c);for(a=0;a<c;++a){for(var f,h=s[a],p=u[a]=new Array(l),d=0;d<l;++d)p[d]=f=[0,+i(r[d],h,d,r)],f.data=r[d];p.key=h}for(a=0,o=e(u);a<c;++a)u[o[a]].index=a;return n(u,o),u}return a.keys=function(e){return arguments.length?(t=\"function\"==typeof e?e:r(F.call(e)),a):t},a.value=function(t){return arguments.length?(i=\"function\"==typeof t?t:r(+t),a):i},a.order=function(t){return arguments.length?(e=null==t?Ut:\"function\"==typeof t?t:r(F.call(t)),a):e},a.offset=function(t){return arguments.length?(n=null==t?jt:t,a):n},a},t.stackOffsetDiverging=function(t,e){if((s=t.length)>0)for(var r,n,i,a,o,s,l=0,c=t[e[0]].length;l<c;++l)for(a=o=0,r=0;r<s;++r)(i=(n=t[e[r]][l])[1]-n[0])>0?(n[0]=a,n[1]=a+=i):i<0?(n[1]=o,n[0]=o+=i):(n[0]=0,n[1]=i)},t.stackOffsetExpand=function(t,e){if((n=t.length)>0){for(var r,n,i,a=0,o=t[0].length;a<o;++a){for(i=r=0;r<n;++r)i+=t[r][a][1]||0;if(i)for(r=0;r<n;++r)t[r][a][1]/=i}jt(t,e)}},t.stackOffsetNone=jt,t.stackOffsetSilhouette=function(t,e){if((r=t.length)>0){for(var r,n=0,i=t[e[0]],a=i.length;n<a;++n){for(var o=0,s=0;o<r;++o)s+=t[o][n][1]||0;i[n][1]+=i[n][0]=-s/2}jt(t,e)}},t.stackOffsetWiggle=function(t,e){if((i=t.length)>0&&(n=(r=t[e[0]]).length)>0){for(var r,n,i,a=0,o=1;o<n;++o){for(var s=0,l=0,c=0;s<i;++s){for(var u=t[e[s]],f=u[o][1]||0,h=(f-(u[o-1][1]||0))/2,p=0;p<s;++p){var d=t[e[p]];h+=(d[o][1]||0)-(d[o-1][1]||0)}l+=f,c+=h*f}r[o-1][1]+=r[o-1][0]=a,l&&(a-=c/l)}r[o-1][1]+=r[o-1][0]=a,jt(t,e)}},t.stackOrderAppearance=qt,t.stackOrderAscending=Gt,t.stackOrderDescending=function(t){return Gt(t).reverse()},t.stackOrderInsideOut=function(t){var e,r,n=t.length,i=t.map(Yt),a=qt(t),o=0,s=0,l=[],c=[];for(e=0;e<n;++e)r=a[e],o<s?(o+=i[r],l.push(r)):(s+=i[r],c.push(r));return c.reverse().concat(l)},t.stackOrderNone=Ut,t.stackOrderReverse=function(t){return Ut(t).reverse()},t.symbol=function(){var t=r(H),n=r(64),i=null;function a(){var r;if(i||(i=r=e.path()),t.apply(this,arguments).draw(i,+n.apply(this,arguments)),r)return i=null,r+\"\"||null}return a.type=function(e){return arguments.length?(t=\"function\"==typeof e?e:r(e),a):t},a.size=function(t){return arguments.length?(n=\"function\"==typeof t?t:r(+t),a):n},a.context=function(t){return arguments.length?(i=null==t?null:t,a):i},a},t.symbolCircle=H,t.symbolCross=G,t.symbolDiamond=X,t.symbolSquare=$,t.symbolStar=Q,t.symbolTriangle=et,t.symbolWye=ot,t.symbols=st,Object.defineProperty(t,\"__esModule\",{value:!0})}))},{\"d3-path\":169}],172:[function(t,e,r){!function(n,i){\"object\"==typeof r&&void 0!==e?i(r,t(\"d3-time\")):i((n=n||self).d3=n.d3||{},n.d3)}(this,(function(t,e){\"use strict\";function r(t){if(0<=t.y&&t.y<100){var e=new Date(-1,t.m,t.d,t.H,t.M,t.S,t.L);return e.setFullYear(t.y),e}return new Date(t.y,t.m,t.d,t.H,t.M,t.S,t.L)}function n(t){if(0<=t.y&&t.y<100){var e=new Date(Date.UTC(-1,t.m,t.d,t.H,t.M,t.S,t.L));return e.setUTCFullYear(t.y),e}return new Date(Date.UTC(t.y,t.m,t.d,t.H,t.M,t.S,t.L))}function i(t,e,r){return{y:t,m:e,d:r,H:0,M:0,S:0,L:0}}function a(t){var a=t.dateTime,o=t.date,l=t.time,c=t.periods,u=t.days,f=t.shortDays,h=t.months,yt=t.shortMonths,xt=p(c),bt=d(c),_t=p(u),wt=d(u),Tt=p(f),kt=d(f),Mt=p(h),At=d(h),St=p(yt),Et=d(yt),Lt={a:function(t){return f[t.getDay()]},A:function(t){return u[t.getDay()]},b:function(t){return yt[t.getMonth()]},B:function(t){return h[t.getMonth()]},c:null,d:D,e:D,f:j,H:R,I:F,j:B,L:N,m:U,M:V,p:function(t){return c[+(t.getHours()>=12)]},q:function(t){return 1+~~(t.getMonth()/3)},Q:gt,s:vt,S:q,u:H,U:G,V:Y,w:W,W:X,x:null,X:null,y:Z,Y:J,Z:K,\"%\":mt},Ct={a:function(t){return f[t.getUTCDay()]},A:function(t){return u[t.getUTCDay()]},b:function(t){return yt[t.getUTCMonth()]},B:function(t){return h[t.getUTCMonth()]},c:null,d:Q,e:Q,f:nt,H:$,I:tt,j:et,L:rt,m:it,M:at,p:function(t){return c[+(t.getUTCHours()>=12)]},q:function(t){return 1+~~(t.getUTCMonth()/3)},Q:gt,s:vt,S:ot,u:st,U:lt,V:ct,w:ut,W:ft,x:null,X:null,y:ht,Y:pt,Z:dt,\"%\":mt},Pt={a:function(t,e,r){var n=Tt.exec(e.slice(r));return n?(t.w=kt[n[0].toLowerCase()],r+n[0].length):-1},A:function(t,e,r){var n=_t.exec(e.slice(r));return n?(t.w=wt[n[0].toLowerCase()],r+n[0].length):-1},b:function(t,e,r){var n=St.exec(e.slice(r));return n?(t.m=Et[n[0].toLowerCase()],r+n[0].length):-1},B:function(t,e,r){var n=Mt.exec(e.slice(r));return n?(t.m=At[n[0].toLowerCase()],r+n[0].length):-1},c:function(t,e,r){return zt(t,a,e,r)},d:M,e:M,f:P,H:S,I:S,j:A,L:C,m:k,M:E,p:function(t,e,r){var n=xt.exec(e.slice(r));return n?(t.p=bt[n[0].toLowerCase()],r+n[0].length):-1},q:T,Q:O,s:z,S:L,u:g,U:v,V:y,w:m,W:x,x:function(t,e,r){return zt(t,o,e,r)},X:function(t,e,r){return zt(t,l,e,r)},y:_,Y:b,Z:w,\"%\":I};function It(t,e){return function(r){var n,i,a,o=[],l=-1,c=0,u=t.length;for(r instanceof Date||(r=new Date(+r));++l<u;)37===t.charCodeAt(l)&&(o.push(t.slice(c,l)),null!=(i=s[n=t.charAt(++l)])?n=t.charAt(++l):i=\"e\"===n?\" \":\"0\",(a=e[n])&&(n=a(r,i)),o.push(n),c=l+1);return o.push(t.slice(c,l)),o.join(\"\")}}function Ot(t,a){return function(o){var s,l,c=i(1900,void 0,1);if(zt(c,t,o+=\"\",0)!=o.length)return null;if(\"Q\"in c)return new Date(c.Q);if(\"s\"in c)return new Date(1e3*c.s+(\"L\"in c?c.L:0));if(a&&!(\"Z\"in c)&&(c.Z=0),\"p\"in c&&(c.H=c.H%12+12*c.p),void 0===c.m&&(c.m=\"q\"in c?c.q:0),\"V\"in c){if(c.V<1||c.V>53)return null;\"w\"in c||(c.w=1),\"Z\"in c?(l=(s=n(i(c.y,0,1))).getUTCDay(),s=l>4||0===l?e.utcMonday.ceil(s):e.utcMonday(s),s=e.utcDay.offset(s,7*(c.V-1)),c.y=s.getUTCFullYear(),c.m=s.getUTCMonth(),c.d=s.getUTCDate()+(c.w+6)%7):(l=(s=r(i(c.y,0,1))).getDay(),s=l>4||0===l?e.timeMonday.ceil(s):e.timeMonday(s),s=e.timeDay.offset(s,7*(c.V-1)),c.y=s.getFullYear(),c.m=s.getMonth(),c.d=s.getDate()+(c.w+6)%7)}else(\"W\"in c||\"U\"in c)&&(\"w\"in c||(c.w=\"u\"in c?c.u%7:\"W\"in c?1:0),l=\"Z\"in c?n(i(c.y,0,1)).getUTCDay():r(i(c.y,0,1)).getDay(),c.m=0,c.d=\"W\"in c?(c.w+6)%7+7*c.W-(l+5)%7:c.w+7*c.U-(l+6)%7);return\"Z\"in c?(c.H+=c.Z/100|0,c.M+=c.Z%100,n(c)):r(c)}}function zt(t,e,r,n){for(var i,a,o=0,l=e.length,c=r.length;o<l;){if(n>=c)return-1;if(37===(i=e.charCodeAt(o++))){if(i=e.charAt(o++),!(a=Pt[i in s?e.charAt(o++):i])||(n=a(t,r,n))<0)return-1}else if(i!=r.charCodeAt(n++))return-1}return n}return Lt.x=It(o,Lt),Lt.X=It(l,Lt),Lt.c=It(a,Lt),Ct.x=It(o,Ct),Ct.X=It(l,Ct),Ct.c=It(a,Ct),{format:function(t){var e=It(t+=\"\",Lt);return e.toString=function(){return t},e},parse:function(t){var e=Ot(t+=\"\",!1);return e.toString=function(){return t},e},utcFormat:function(t){var e=It(t+=\"\",Ct);return e.toString=function(){return t},e},utcParse:function(t){var e=Ot(t+=\"\",!0);return e.toString=function(){return t},e}}}var o,s={\"-\":\"\",_:\" \",0:\"0\"},l=/^\\s*\\d+/,c=/^%/,u=/[\\\\^$*+?|[\\]().{}]/g;function f(t,e,r){var n=t<0?\"-\":\"\",i=(n?-t:t)+\"\",a=i.length;return n+(a<r?new Array(r-a+1).join(e)+i:i)}function h(t){return t.replace(u,\"\\\\$&\")}function p(t){return new RegExp(\"^(?:\"+t.map(h).join(\"|\")+\")\",\"i\")}function d(t){for(var e={},r=-1,n=t.length;++r<n;)e[t[r].toLowerCase()]=r;return e}function m(t,e,r){var n=l.exec(e.slice(r,r+1));return n?(t.w=+n[0],r+n[0].length):-1}function g(t,e,r){var n=l.exec(e.slice(r,r+1));return n?(t.u=+n[0],r+n[0].length):-1}function v(t,e,r){var n=l.exec(e.slice(r,r+2));return n?(t.U=+n[0],r+n[0].length):-1}function y(t,e,r){var n=l.exec(e.slice(r,r+2));return n?(t.V=+n[0],r+n[0].length):-1}function x(t,e,r){var n=l.exec(e.slice(r,r+2));return n?(t.W=+n[0],r+n[0].length):-1}function b(t,e,r){var n=l.exec(e.slice(r,r+4));return n?(t.y=+n[0],r+n[0].length):-1}function _(t,e,r){var n=l.exec(e.slice(r,r+2));return n?(t.y=+n[0]+(+n[0]>68?1900:2e3),r+n[0].length):-1}function w(t,e,r){var n=/^(Z)|([+-]\\d\\d)(?::?(\\d\\d))?/.exec(e.slice(r,r+6));return n?(t.Z=n[1]?0:-(n[2]+(n[3]||\"00\")),r+n[0].length):-1}function T(t,e,r){var n=l.exec(e.slice(r,r+1));return n?(t.q=3*n[0]-3,r+n[0].length):-1}function k(t,e,r){var n=l.exec(e.slice(r,r+2));return n?(t.m=n[0]-1,r+n[0].length):-1}function M(t,e,r){var n=l.exec(e.slice(r,r+2));return n?(t.d=+n[0],r+n[0].length):-1}function A(t,e,r){var n=l.exec(e.slice(r,r+3));return n?(t.m=0,t.d=+n[0],r+n[0].length):-1}function S(t,e,r){var n=l.exec(e.slice(r,r+2));return n?(t.H=+n[0],r+n[0].length):-1}function E(t,e,r){var n=l.exec(e.slice(r,r+2));return n?(t.M=+n[0],r+n[0].length):-1}function L(t,e,r){var n=l.exec(e.slice(r,r+2));return n?(t.S=+n[0],r+n[0].length):-1}function C(t,e,r){var n=l.exec(e.slice(r,r+3));return n?(t.L=+n[0],r+n[0].length):-1}function P(t,e,r){var n=l.exec(e.slice(r,r+6));return n?(t.L=Math.floor(n[0]/1e3),r+n[0].length):-1}function I(t,e,r){var n=c.exec(e.slice(r,r+1));return n?r+n[0].length:-1}function O(t,e,r){var n=l.exec(e.slice(r));return n?(t.Q=+n[0],r+n[0].length):-1}function z(t,e,r){var n=l.exec(e.slice(r));return n?(t.s=+n[0],r+n[0].length):-1}function D(t,e){return f(t.getDate(),e,2)}function R(t,e){return f(t.getHours(),e,2)}function F(t,e){return f(t.getHours()%12||12,e,2)}function B(t,r){return f(1+e.timeDay.count(e.timeYear(t),t),r,3)}function N(t,e){return f(t.getMilliseconds(),e,3)}function j(t,e){return N(t,e)+\"000\"}function U(t,e){return f(t.getMonth()+1,e,2)}function V(t,e){return f(t.getMinutes(),e,2)}function q(t,e){return f(t.getSeconds(),e,2)}function H(t){var e=t.getDay();return 0===e?7:e}function G(t,r){return f(e.timeSunday.count(e.timeYear(t)-1,t),r,2)}function Y(t,r){var n=t.getDay();return t=n>=4||0===n?e.timeThursday(t):e.timeThursday.ceil(t),f(e.timeThursday.count(e.timeYear(t),t)+(4===e.timeYear(t).getDay()),r,2)}function W(t){return t.getDay()}function X(t,r){return f(e.timeMonday.count(e.timeYear(t)-1,t),r,2)}function Z(t,e){return f(t.getFullYear()%100,e,2)}function J(t,e){return f(t.getFullYear()%1e4,e,4)}function K(t){var e=t.getTimezoneOffset();return(e>0?\"-\":(e*=-1,\"+\"))+f(e/60|0,\"0\",2)+f(e%60,\"0\",2)}function Q(t,e){return f(t.getUTCDate(),e,2)}function $(t,e){return f(t.getUTCHours(),e,2)}function tt(t,e){return f(t.getUTCHours()%12||12,e,2)}function et(t,r){return f(1+e.utcDay.count(e.utcYear(t),t),r,3)}function rt(t,e){return f(t.getUTCMilliseconds(),e,3)}function nt(t,e){return rt(t,e)+\"000\"}function it(t,e){return f(t.getUTCMonth()+1,e,2)}function at(t,e){return f(t.getUTCMinutes(),e,2)}function ot(t,e){return f(t.getUTCSeconds(),e,2)}function st(t){var e=t.getUTCDay();return 0===e?7:e}function lt(t,r){return f(e.utcSunday.count(e.utcYear(t)-1,t),r,2)}function ct(t,r){var n=t.getUTCDay();return t=n>=4||0===n?e.utcThursday(t):e.utcThursday.ceil(t),f(e.utcThursday.count(e.utcYear(t),t)+(4===e.utcYear(t).getUTCDay()),r,2)}function ut(t){return t.getUTCDay()}function ft(t,r){return f(e.utcMonday.count(e.utcYear(t)-1,t),r,2)}function ht(t,e){return f(t.getUTCFullYear()%100,e,2)}function pt(t,e){return f(t.getUTCFullYear()%1e4,e,4)}function dt(){return\"+0000\"}function mt(){return\"%\"}function gt(t){return+t}function vt(t){return Math.floor(+t/1e3)}function yt(e){return o=a(e),t.timeFormat=o.format,t.timeParse=o.parse,t.utcFormat=o.utcFormat,t.utcParse=o.utcParse,o}yt({dateTime:\"%x, %X\",date:\"%-m/%-d/%Y\",time:\"%-I:%M:%S %p\",periods:[\"AM\",\"PM\"],days:[\"Sunday\",\"Monday\",\"Tuesday\",\"Wednesday\",\"Thursday\",\"Friday\",\"Saturday\"],shortDays:[\"Sun\",\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\"],months:[\"January\",\"February\",\"March\",\"April\",\"May\",\"June\",\"July\",\"August\",\"September\",\"October\",\"November\",\"December\"],shortMonths:[\"Jan\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\"Jul\",\"Aug\",\"Sep\",\"Oct\",\"Nov\",\"Dec\"]});var xt=Date.prototype.toISOString?function(t){return t.toISOString()}:t.utcFormat(\"%Y-%m-%dT%H:%M:%S.%LZ\");var bt=+new Date(\"2000-01-01T00:00:00.000Z\")?function(t){var e=new Date(t);return isNaN(e)?null:e}:t.utcParse(\"%Y-%m-%dT%H:%M:%S.%LZ\");t.isoFormat=xt,t.isoParse=bt,t.timeFormatDefaultLocale=yt,t.timeFormatLocale=a,Object.defineProperty(t,\"__esModule\",{value:!0})}))},{\"d3-time\":173}],173:[function(t,e,r){!function(t,n){\"object\"==typeof r&&void 0!==e?n(r):n((t=t||self).d3=t.d3||{})}(this,(function(t){\"use strict\";var e=new Date,r=new Date;function n(t,i,a,o){function s(e){return t(e=0===arguments.length?new Date:new Date(+e)),e}return s.floor=function(e){return t(e=new Date(+e)),e},s.ceil=function(e){return t(e=new Date(e-1)),i(e,1),t(e),e},s.round=function(t){var e=s(t),r=s.ceil(t);return t-e<r-t?e:r},s.offset=function(t,e){return i(t=new Date(+t),null==e?1:Math.floor(e)),t},s.range=function(e,r,n){var a,o=[];if(e=s.ceil(e),n=null==n?1:Math.floor(n),!(e<r&&n>0))return o;do{o.push(a=new Date(+e)),i(e,n),t(e)}while(a<e&&e<r);return o},s.filter=function(e){return n((function(r){if(r>=r)for(;t(r),!e(r);)r.setTime(r-1)}),(function(t,r){if(t>=t)if(r<0)for(;++r<=0;)for(;i(t,-1),!e(t););else for(;--r>=0;)for(;i(t,1),!e(t););}))},a&&(s.count=function(n,i){return e.setTime(+n),r.setTime(+i),t(e),t(r),Math.floor(a(e,r))},s.every=function(t){return t=Math.floor(t),isFinite(t)&&t>0?t>1?s.filter(o?function(e){return o(e)%t==0}:function(e){return s.count(0,e)%t==0}):s:null}),s}var i=n((function(){}),(function(t,e){t.setTime(+t+e)}),(function(t,e){return e-t}));i.every=function(t){return t=Math.floor(t),isFinite(t)&&t>0?t>1?n((function(e){e.setTime(Math.floor(e/t)*t)}),(function(e,r){e.setTime(+e+r*t)}),(function(e,r){return(r-e)/t})):i:null};var a=i.range,o=n((function(t){t.setTime(t-t.getMilliseconds())}),(function(t,e){t.setTime(+t+1e3*e)}),(function(t,e){return(e-t)/1e3}),(function(t){return t.getUTCSeconds()})),s=o.range,l=n((function(t){t.setTime(t-t.getMilliseconds()-1e3*t.getSeconds())}),(function(t,e){t.setTime(+t+6e4*e)}),(function(t,e){return(e-t)/6e4}),(function(t){return t.getMinutes()})),c=l.range,u=n((function(t){t.setTime(t-t.getMilliseconds()-1e3*t.getSeconds()-6e4*t.getMinutes())}),(function(t,e){t.setTime(+t+36e5*e)}),(function(t,e){return(e-t)/36e5}),(function(t){return t.getHours()})),f=u.range,h=n((function(t){t.setHours(0,0,0,0)}),(function(t,e){t.setDate(t.getDate()+e)}),(function(t,e){return(e-t-6e4*(e.getTimezoneOffset()-t.getTimezoneOffset()))/864e5}),(function(t){return t.getDate()-1})),p=h.range;function d(t){return n((function(e){e.setDate(e.getDate()-(e.getDay()+7-t)%7),e.setHours(0,0,0,0)}),(function(t,e){t.setDate(t.getDate()+7*e)}),(function(t,e){return(e-t-6e4*(e.getTimezoneOffset()-t.getTimezoneOffset()))/6048e5}))}var m=d(0),g=d(1),v=d(2),y=d(3),x=d(4),b=d(5),_=d(6),w=m.range,T=g.range,k=v.range,M=y.range,A=x.range,S=b.range,E=_.range,L=n((function(t){t.setDate(1),t.setHours(0,0,0,0)}),(function(t,e){t.setMonth(t.getMonth()+e)}),(function(t,e){return e.getMonth()-t.getMonth()+12*(e.getFullYear()-t.getFullYear())}),(function(t){return t.getMonth()})),C=L.range,P=n((function(t){t.setMonth(0,1),t.setHours(0,0,0,0)}),(function(t,e){t.setFullYear(t.getFullYear()+e)}),(function(t,e){return e.getFullYear()-t.getFullYear()}),(function(t){return t.getFullYear()}));P.every=function(t){return isFinite(t=Math.floor(t))&&t>0?n((function(e){e.setFullYear(Math.floor(e.getFullYear()/t)*t),e.setMonth(0,1),e.setHours(0,0,0,0)}),(function(e,r){e.setFullYear(e.getFullYear()+r*t)})):null};var I=P.range,O=n((function(t){t.setUTCSeconds(0,0)}),(function(t,e){t.setTime(+t+6e4*e)}),(function(t,e){return(e-t)/6e4}),(function(t){return t.getUTCMinutes()})),z=O.range,D=n((function(t){t.setUTCMinutes(0,0,0)}),(function(t,e){t.setTime(+t+36e5*e)}),(function(t,e){return(e-t)/36e5}),(function(t){return t.getUTCHours()})),R=D.range,F=n((function(t){t.setUTCHours(0,0,0,0)}),(function(t,e){t.setUTCDate(t.getUTCDate()+e)}),(function(t,e){return(e-t)/864e5}),(function(t){return t.getUTCDate()-1})),B=F.range;function N(t){return n((function(e){e.setUTCDate(e.getUTCDate()-(e.getUTCDay()+7-t)%7),e.setUTCHours(0,0,0,0)}),(function(t,e){t.setUTCDate(t.getUTCDate()+7*e)}),(function(t,e){return(e-t)/6048e5}))}var j=N(0),U=N(1),V=N(2),q=N(3),H=N(4),G=N(5),Y=N(6),W=j.range,X=U.range,Z=V.range,J=q.range,K=H.range,Q=G.range,$=Y.range,tt=n((function(t){t.setUTCDate(1),t.setUTCHours(0,0,0,0)}),(function(t,e){t.setUTCMonth(t.getUTCMonth()+e)}),(function(t,e){return e.getUTCMonth()-t.getUTCMonth()+12*(e.getUTCFullYear()-t.getUTCFullYear())}),(function(t){return t.getUTCMonth()})),et=tt.range,rt=n((function(t){t.setUTCMonth(0,1),t.setUTCHours(0,0,0,0)}),(function(t,e){t.setUTCFullYear(t.getUTCFullYear()+e)}),(function(t,e){return e.getUTCFullYear()-t.getUTCFullYear()}),(function(t){return t.getUTCFullYear()}));rt.every=function(t){return isFinite(t=Math.floor(t))&&t>0?n((function(e){e.setUTCFullYear(Math.floor(e.getUTCFullYear()/t)*t),e.setUTCMonth(0,1),e.setUTCHours(0,0,0,0)}),(function(e,r){e.setUTCFullYear(e.getUTCFullYear()+r*t)})):null};var nt=rt.range;t.timeDay=h,t.timeDays=p,t.timeFriday=b,t.timeFridays=S,t.timeHour=u,t.timeHours=f,t.timeInterval=n,t.timeMillisecond=i,t.timeMilliseconds=a,t.timeMinute=l,t.timeMinutes=c,t.timeMonday=g,t.timeMondays=T,t.timeMonth=L,t.timeMonths=C,t.timeSaturday=_,t.timeSaturdays=E,t.timeSecond=o,t.timeSeconds=s,t.timeSunday=m,t.timeSundays=w,t.timeThursday=x,t.timeThursdays=A,t.timeTuesday=v,t.timeTuesdays=k,t.timeWednesday=y,t.timeWednesdays=M,t.timeWeek=m,t.timeWeeks=w,t.timeYear=P,t.timeYears=I,t.utcDay=F,t.utcDays=B,t.utcFriday=G,t.utcFridays=Q,t.utcHour=D,t.utcHours=R,t.utcMillisecond=i,t.utcMilliseconds=a,t.utcMinute=O,t.utcMinutes=z,t.utcMonday=U,t.utcMondays=X,t.utcMonth=tt,t.utcMonths=et,t.utcSaturday=Y,t.utcSaturdays=$,t.utcSecond=o,t.utcSeconds=s,t.utcSunday=j,t.utcSundays=W,t.utcThursday=H,t.utcThursdays=K,t.utcTuesday=V,t.utcTuesdays=Z,t.utcWednesday=q,t.utcWednesdays=J,t.utcWeek=j,t.utcWeeks=W,t.utcYear=rt,t.utcYears=nt,Object.defineProperty(t,\"__esModule\",{value:!0})}))},{}],174:[function(t,e,r){!function(t,n){\"object\"==typeof r&&void 0!==e?n(r):n((t=t||self).d3=t.d3||{})}(this,(function(t){\"use strict\";var e,r,n=0,i=0,a=0,o=0,s=0,l=0,c=\"object\"==typeof performance&&performance.now?performance:Date,u=\"object\"==typeof window&&window.requestAnimationFrame?window.requestAnimationFrame.bind(window):function(t){setTimeout(t,17)};function f(){return s||(u(h),s=c.now()+l)}function h(){s=0}function p(){this._call=this._time=this._next=null}function d(t,e,r){var n=new p;return n.restart(t,e,r),n}function m(){f(),++n;for(var t,r=e;r;)(t=s-r._time)>=0&&r._call.call(null,t),r=r._next;--n}function g(){s=(o=c.now())+l,n=i=0;try{m()}finally{n=0,function(){var t,n,i=e,a=1/0;for(;i;)i._call?(a>i._time&&(a=i._time),t=i,i=i._next):(n=i._next,i._next=null,i=t?t._next=n:e=n);r=t,y(a)}(),s=0}}function v(){var t=c.now(),e=t-o;e>1e3&&(l-=e,o=t)}function y(t){n||(i&&(i=clearTimeout(i)),t-s>24?(t<1/0&&(i=setTimeout(g,t-c.now()-l)),a&&(a=clearInterval(a))):(a||(o=c.now(),a=setInterval(v,1e3)),n=1,u(g)))}p.prototype=d.prototype={constructor:p,restart:function(t,n,i){if(\"function\"!=typeof t)throw new TypeError(\"callback is not a function\");i=(null==i?f():+i)+(null==n?0:+n),this._next||r===this||(r?r._next=this:e=this,r=this),this._call=t,this._time=i,y()},stop:function(){this._call&&(this._call=null,this._time=1/0,y())}},t.interval=function(t,e,r){var n=new p,i=e;return null==e?(n.restart(t,e,r),n):(e=+e,r=null==r?f():+r,n.restart((function a(o){o+=i,n.restart(a,i+=e,r),t(o)}),e,r),n)},t.now=f,t.timeout=function(t,e,r){var n=new p;return e=null==e?0:+e,n.restart((function(r){n.stop(),t(r+e)}),e,r),n},t.timer=d,t.timerFlush=m,Object.defineProperty(t,\"__esModule\",{value:!0})}))},{}],175:[function(t,e,r){e.exports=function(){for(var t=0;t<arguments.length;t++)if(void 0!==arguments[t])return arguments[t]}},{}],176:[function(t,e,r){\"use strict\";var n=t(\"incremental-convex-hull\"),i=t(\"uniq\");function a(t,e){this.point=t,this.index=e}function o(t,e){for(var r=t.point,n=e.point,i=r.length,a=0;a<i;++a){var o=n[a]-r[a];if(o)return o}return 0}e.exports=function(t,e){var r=t.length;if(0===r)return[];var s=t[0].length;if(s<1)return[];if(1===s)return function(t,e,r){if(1===t)return r?[[-1,0]]:[];var n=e.map((function(t,e){return[t[0],e]}));n.sort((function(t,e){return t[0]-e[0]}));for(var i=new Array(t-1),a=1;a<t;++a){var o=n[a-1],s=n[a];i[a-1]=[o[1],s[1]]}r&&i.push([-1,i[0][1]],[i[t-1][1],-1]);return i}(r,t,e);for(var l=new Array(r),c=1,u=0;u<r;++u){for(var f=t[u],h=new Array(s+1),p=0,d=0;d<s;++d){var m=f[d];h[d]=m,p+=m*m}h[s]=p,l[u]=new a(h,u),c=Math.max(p,c)}i(l,o),r=l.length;var g=new Array(r+s+1),v=new Array(r+s+1),y=(s+1)*(s+1)*c,x=new Array(s+1);for(u=0;u<=s;++u)x[u]=0;x[s]=y,g[0]=x.slice(),v[0]=-1;for(u=0;u<=s;++u){(h=x.slice())[u]=1,g[u+1]=h,v[u+1]=-1}for(u=0;u<r;++u){var b=l[u];g[u+s+1]=b.point,v[u+s+1]=b.index}var _=n(g,!1);_=e?_.filter((function(t){for(var e=0,r=0;r<=s;++r){var n=v[t[r]];if(n<0&&++e>=2)return!1;t[r]=n}return!0})):_.filter((function(t){for(var e=0;e<=s;++e){var r=v[t[e]];if(r<0)return!1;t[e]=r}return!0}));if(1&s)for(u=0;u<_.length;++u){h=(b=_[u])[0];b[0]=b[1],b[1]=h}return _}},{\"incremental-convex-hull\":442,uniq:615}],177:[function(t,e,r){\"use strict\";e.exports=a;var n=(a.canvas=document.createElement(\"canvas\")).getContext(\"2d\"),i=o([32,126]);function a(t,e){Array.isArray(t)&&(t=t.join(\", \"));var r,a={},s=16,l=.05;e&&(2===e.length&&\"number\"==typeof e[0]?r=o(e):Array.isArray(e)?r=e:(e.o?r=o(e.o):e.pairs&&(r=e.pairs),e.fontSize&&(s=e.fontSize),null!=e.threshold&&(l=e.threshold))),r||(r=i),n.font=s+\"px \"+t;for(var c=0;c<r.length;c++){var u=r[c],f=n.measureText(u[0]).width+n.measureText(u[1]).width,h=n.measureText(u).width;if(Math.abs(f-h)>s*l){var p=(h-f)/s;a[u]=1e3*p}}return a}function o(t){for(var e=[],r=t[0];r<=t[1];r++)for(var n=String.fromCharCode(r),i=t[0];i<t[1];i++){var a=n+String.fromCharCode(i);e.push(a)}return e}a.createPairs=o,a.ascii=i},{}],178:[function(t,e,r){(function(t){(function(){var r=!1;if(\"undefined\"!=typeof Float64Array){var n=new Float64Array(1),i=new Uint32Array(n.buffer);if(n[0]=1,r=!0,1072693248===i[1]){e.exports=function(t){return n[0]=t,[i[0],i[1]]},e.exports.pack=function(t,e){return i[0]=t,i[1]=e,n[0]},e.exports.lo=function(t){return n[0]=t,i[0]},e.exports.hi=function(t){return n[0]=t,i[1]}}else if(1072693248===i[0]){e.exports=function(t){return n[0]=t,[i[1],i[0]]},e.exports.pack=function(t,e){return i[1]=t,i[0]=e,n[0]},e.exports.lo=function(t){return n[0]=t,i[1]},e.exports.hi=function(t){return n[0]=t,i[0]}}else r=!1}if(!r){var a=new t(8);e.exports=function(t){return a.writeDoubleLE(t,0,!0),[a.readUInt32LE(0,!0),a.readUInt32LE(4,!0)]},e.exports.pack=function(t,e){return a.writeUInt32LE(t,0,!0),a.writeUInt32LE(e,4,!0),a.readDoubleLE(0,!0)},e.exports.lo=function(t){return a.writeDoubleLE(t,0,!0),a.readUInt32LE(0,!0)},e.exports.hi=function(t){return a.writeDoubleLE(t,0,!0),a.readUInt32LE(4,!0)}}e.exports.sign=function(t){return e.exports.hi(t)>>>31},e.exports.exponent=function(t){return(e.exports.hi(t)<<1>>>21)-1023},e.exports.fraction=function(t){var r=e.exports.lo(t),n=e.exports.hi(t),i=1048575&n;return 2146435072&n&&(i+=1<<20),[r,i]},e.exports.denormalized=function(t){return!(2146435072&e.exports.hi(t))}}).call(this)}).call(this,t(\"buffer\").Buffer)},{buffer:117}],179:[function(t,e,r){var n=t(\"abs-svg-path\"),i=t(\"normalize-svg-path\"),a={M:\"moveTo\",C:\"bezierCurveTo\"};e.exports=function(t,e){t.beginPath(),i(n(e)).forEach((function(e){var r=e[0],n=e.slice(1);t[a[r]].apply(t,n)})),t.closePath()}},{\"abs-svg-path\":71,\"normalize-svg-path\":481}],180:[function(t,e,r){e.exports=function(t){switch(t){case\"int8\":return Int8Array;case\"int16\":return Int16Array;case\"int32\":return Int32Array;case\"uint8\":return Uint8Array;case\"uint16\":return Uint16Array;case\"uint32\":return Uint32Array;case\"float32\":return Float32Array;case\"float64\":return Float64Array;case\"array\":return Array;case\"uint8_clamped\":return Uint8ClampedArray}}},{}],181:[function(t,e,r){\"use strict\";e.exports=function(t,e){switch(void 0===e&&(e=0),typeof t){case\"number\":if(t>0)return function(t,e){var r,n;for(r=new Array(t),n=0;n<t;++n)r[n]=e;return r}(0|t,e);break;case\"object\":if(\"number\"==typeof t.length)return function t(e,r,n){var i=0|e[n];if(i<=0)return[];var a,o=new Array(i);if(n===e.length-1)for(a=0;a<i;++a)o[a]=r;else for(a=0;a<i;++a)o[a]=t(e,r,n+1);return o}(t,e,0)}return[]}},{}],182:[function(t,e,r){\"use strict\";function n(t,e,r){r=r||2;var n,s,l,c,u,p,d,g=e&&e.length,v=g?e[0]*r:t.length,y=i(t,0,v,r,!0),x=[];if(!y||y.next===y.prev)return x;if(g&&(y=function(t,e,r,n){var o,s,l,c,u,p=[];for(o=0,s=e.length;o<s;o++)l=e[o]*n,c=o<s-1?e[o+1]*n:t.length,(u=i(t,l,c,n,!1))===u.next&&(u.steiner=!0),p.push(m(u));for(p.sort(f),o=0;o<p.length;o++)h(p[o],r),r=a(r,r.next);return r}(t,e,y,r)),t.length>80*r){n=l=t[0],s=c=t[1];for(var b=r;b<v;b+=r)(u=t[b])<n&&(n=u),(p=t[b+1])<s&&(s=p),u>l&&(l=u),p>c&&(c=p);d=0!==(d=Math.max(l-n,c-s))?1/d:0}return o(y,x,r,n,s,d),x}function i(t,e,r,n,i){var a,o;if(i===E(t,e,r,n)>0)for(a=e;a<r;a+=n)o=M(a,t[a],t[a+1],o);else for(a=r-n;a>=e;a-=n)o=M(a,t[a],t[a+1],o);return o&&x(o,o.next)&&(A(o),o=o.next),o}function a(t,e){if(!t)return t;e||(e=t);var r,n=t;do{if(r=!1,n.steiner||!x(n,n.next)&&0!==y(n.prev,n,n.next))n=n.next;else{if(A(n),(n=e=n.prev)===n.next)break;r=!0}}while(r||n!==e);return e}function o(t,e,r,n,i,f,h){if(t){!h&&f&&function(t,e,r,n){var i=t;do{null===i.z&&(i.z=d(i.x,i.y,e,r,n)),i.prevZ=i.prev,i.nextZ=i.next,i=i.next}while(i!==t);i.prevZ.nextZ=null,i.prevZ=null,function(t){var e,r,n,i,a,o,s,l,c=1;do{for(r=t,t=null,a=null,o=0;r;){for(o++,n=r,s=0,e=0;e<c&&(s++,n=n.nextZ);e++);for(l=c;s>0||l>0&&n;)0!==s&&(0===l||!n||r.z<=n.z)?(i=r,r=r.nextZ,s--):(i=n,n=n.nextZ,l--),a?a.nextZ=i:t=i,i.prevZ=a,a=i;r=n}a.nextZ=null,c*=2}while(o>1)}(i)}(t,n,i,f);for(var p,m,g=t;t.prev!==t.next;)if(p=t.prev,m=t.next,f?l(t,n,i,f):s(t))e.push(p.i/r),e.push(t.i/r),e.push(m.i/r),A(t),t=m.next,g=m.next;else if((t=m)===g){h?1===h?o(t=c(a(t),e,r),e,r,n,i,f,2):2===h&&u(t,e,r,n,i,f):o(a(t),e,r,n,i,f,1);break}}}function s(t){var e=t.prev,r=t,n=t.next;if(y(e,r,n)>=0)return!1;for(var i=t.next.next;i!==t.prev;){if(g(e.x,e.y,r.x,r.y,n.x,n.y,i.x,i.y)&&y(i.prev,i,i.next)>=0)return!1;i=i.next}return!0}function l(t,e,r,n){var i=t.prev,a=t,o=t.next;if(y(i,a,o)>=0)return!1;for(var s=i.x<a.x?i.x<o.x?i.x:o.x:a.x<o.x?a.x:o.x,l=i.y<a.y?i.y<o.y?i.y:o.y:a.y<o.y?a.y:o.y,c=i.x>a.x?i.x>o.x?i.x:o.x:a.x>o.x?a.x:o.x,u=i.y>a.y?i.y>o.y?i.y:o.y:a.y>o.y?a.y:o.y,f=d(s,l,e,r,n),h=d(c,u,e,r,n),p=t.prevZ,m=t.nextZ;p&&p.z>=f&&m&&m.z<=h;){if(p!==t.prev&&p!==t.next&&g(i.x,i.y,a.x,a.y,o.x,o.y,p.x,p.y)&&y(p.prev,p,p.next)>=0)return!1;if(p=p.prevZ,m!==t.prev&&m!==t.next&&g(i.x,i.y,a.x,a.y,o.x,o.y,m.x,m.y)&&y(m.prev,m,m.next)>=0)return!1;m=m.nextZ}for(;p&&p.z>=f;){if(p!==t.prev&&p!==t.next&&g(i.x,i.y,a.x,a.y,o.x,o.y,p.x,p.y)&&y(p.prev,p,p.next)>=0)return!1;p=p.prevZ}for(;m&&m.z<=h;){if(m!==t.prev&&m!==t.next&&g(i.x,i.y,a.x,a.y,o.x,o.y,m.x,m.y)&&y(m.prev,m,m.next)>=0)return!1;m=m.nextZ}return!0}function c(t,e,r){var n=t;do{var i=n.prev,o=n.next.next;!x(i,o)&&b(i,n,n.next,o)&&T(i,o)&&T(o,i)&&(e.push(i.i/r),e.push(n.i/r),e.push(o.i/r),A(n),A(n.next),n=t=o),n=n.next}while(n!==t);return a(n)}function u(t,e,r,n,i,s){var l=t;do{for(var c=l.next.next;c!==l.prev;){if(l.i!==c.i&&v(l,c)){var u=k(l,c);return l=a(l,l.next),u=a(u,u.next),o(l,e,r,n,i,s),void o(u,e,r,n,i,s)}c=c.next}l=l.next}while(l!==t)}function f(t,e){return t.x-e.x}function h(t,e){if(e=function(t,e){var r,n=e,i=t.x,a=t.y,o=-1/0;do{if(a<=n.y&&a>=n.next.y&&n.next.y!==n.y){var s=n.x+(a-n.y)*(n.next.x-n.x)/(n.next.y-n.y);if(s<=i&&s>o){if(o=s,s===i){if(a===n.y)return n;if(a===n.next.y)return n.next}r=n.x<n.next.x?n:n.next}}n=n.next}while(n!==e);if(!r)return null;if(i===o)return r;var l,c=r,u=r.x,f=r.y,h=1/0;n=r;do{i>=n.x&&n.x>=u&&i!==n.x&&g(a<f?i:o,a,u,f,a<f?o:i,a,n.x,n.y)&&(l=Math.abs(a-n.y)/(i-n.x),T(n,t)&&(l<h||l===h&&(n.x>r.x||n.x===r.x&&p(r,n)))&&(r=n,h=l)),n=n.next}while(n!==c);return r}(t,e)){var r=k(e,t);a(e,e.next),a(r,r.next)}}function p(t,e){return y(t.prev,t,e.prev)<0&&y(e.next,t,t.next)<0}function d(t,e,r,n,i){return(t=1431655765&((t=858993459&((t=252645135&((t=16711935&((t=32767*(t-r)*i)|t<<8))|t<<4))|t<<2))|t<<1))|(e=1431655765&((e=858993459&((e=252645135&((e=16711935&((e=32767*(e-n)*i)|e<<8))|e<<4))|e<<2))|e<<1))<<1}function m(t){var e=t,r=t;do{(e.x<r.x||e.x===r.x&&e.y<r.y)&&(r=e),e=e.next}while(e!==t);return r}function g(t,e,r,n,i,a,o,s){return(i-o)*(e-s)-(t-o)*(a-s)>=0&&(t-o)*(n-s)-(r-o)*(e-s)>=0&&(r-o)*(a-s)-(i-o)*(n-s)>=0}function v(t,e){return t.next.i!==e.i&&t.prev.i!==e.i&&!function(t,e){var r=t;do{if(r.i!==t.i&&r.next.i!==t.i&&r.i!==e.i&&r.next.i!==e.i&&b(r,r.next,t,e))return!0;r=r.next}while(r!==t);return!1}(t,e)&&(T(t,e)&&T(e,t)&&function(t,e){var r=t,n=!1,i=(t.x+e.x)/2,a=(t.y+e.y)/2;do{r.y>a!=r.next.y>a&&r.next.y!==r.y&&i<(r.next.x-r.x)*(a-r.y)/(r.next.y-r.y)+r.x&&(n=!n),r=r.next}while(r!==t);return n}(t,e)&&(y(t.prev,t,e.prev)||y(t,e.prev,e))||x(t,e)&&y(t.prev,t,t.next)>0&&y(e.prev,e,e.next)>0)}function y(t,e,r){return(e.y-t.y)*(r.x-e.x)-(e.x-t.x)*(r.y-e.y)}function x(t,e){return t.x===e.x&&t.y===e.y}function b(t,e,r,n){var i=w(y(t,e,r)),a=w(y(t,e,n)),o=w(y(r,n,t)),s=w(y(r,n,e));return i!==a&&o!==s||(!(0!==i||!_(t,r,e))||(!(0!==a||!_(t,n,e))||(!(0!==o||!_(r,t,n))||!(0!==s||!_(r,e,n)))))}function _(t,e,r){return e.x<=Math.max(t.x,r.x)&&e.x>=Math.min(t.x,r.x)&&e.y<=Math.max(t.y,r.y)&&e.y>=Math.min(t.y,r.y)}function w(t){return t>0?1:t<0?-1:0}function T(t,e){return y(t.prev,t,t.next)<0?y(t,e,t.next)>=0&&y(t,t.prev,e)>=0:y(t,e,t.prev)<0||y(t,t.next,e)<0}function k(t,e){var r=new S(t.i,t.x,t.y),n=new S(e.i,e.x,e.y),i=t.next,a=e.prev;return t.next=e,e.prev=t,r.next=i,i.prev=r,n.next=r,r.prev=n,a.next=n,n.prev=a,n}function M(t,e,r,n){var i=new S(t,e,r);return n?(i.next=n.next,i.prev=n,n.next.prev=i,n.next=i):(i.prev=i,i.next=i),i}function A(t){t.next.prev=t.prev,t.prev.next=t.next,t.prevZ&&(t.prevZ.nextZ=t.nextZ),t.nextZ&&(t.nextZ.prevZ=t.prevZ)}function S(t,e,r){this.i=t,this.x=e,this.y=r,this.prev=null,this.next=null,this.z=null,this.prevZ=null,this.nextZ=null,this.steiner=!1}function E(t,e,r,n){for(var i=0,a=e,o=r-n;a<r;a+=n)i+=(t[o]-t[a])*(t[a+1]+t[o+1]),o=a;return i}e.exports=n,e.exports.default=n,n.deviation=function(t,e,r,n){var i=e&&e.length,a=i?e[0]*r:t.length,o=Math.abs(E(t,0,a,r));if(i)for(var s=0,l=e.length;s<l;s++){var c=e[s]*r,u=s<l-1?e[s+1]*r:t.length;o-=Math.abs(E(t,c,u,r))}var f=0;for(s=0;s<n.length;s+=3){var h=n[s]*r,p=n[s+1]*r,d=n[s+2]*r;f+=Math.abs((t[h]-t[d])*(t[p+1]-t[h+1])-(t[h]-t[p])*(t[d+1]-t[h+1]))}return 0===o&&0===f?0:Math.abs((f-o)/o)},n.flatten=function(t){for(var e=t[0][0].length,r={vertices:[],holes:[],dimensions:e},n=0,i=0;i<t.length;i++){for(var a=0;a<t[i].length;a++)for(var o=0;o<e;o++)r.vertices.push(t[i][a][o]);i>0&&(n+=t[i-1].length,r.holes.push(n))}return r}},{}],183:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=t.length;if(\"number\"!=typeof e){e=0;for(var i=0;i<r;++i){var a=t[i];e=Math.max(e,a[0],a[1])}e=1+(0|e)}e|=0;var o=new Array(e);for(i=0;i<e;++i)o[i]=[];for(i=0;i<r;++i){a=t[i];o[a[0]].push(a[1]),o[a[1]].push(a[0])}for(var s=0;s<e;++s)n(o[s],(function(t,e){return t-e}));return o};var n=t(\"uniq\")},{uniq:615}],184:[function(t,e,r){var n=t(\"strongly-connected-components\");e.exports=function(t,e){var r,i=[],a=[],o=[],s={},l=[];function c(t){var e,n,i=!1;for(a.push(t),o[t]=!0,e=0;e<l[t].length;e++)(n=l[t][e])===r?(u(r,a),i=!0):o[n]||(i=c(n));if(i)!function t(e){o[e]=!1,s.hasOwnProperty(e)&&Object.keys(s[e]).forEach((function(r){delete s[e][r],o[r]&&t(r)}))}(t);else for(e=0;e<l[t].length;e++){n=l[t][e];var f=s[n];f||(f={},s[n]=f),f[n]=!0}return a.pop(),i}function u(t,r){var n=[].concat(r).concat(t);e?e(c):i.push(n)}function f(e){!function(e){for(var r=0;r<t.length;r++)r<e&&(t[r]=[]),t[r]=t[r].filter((function(t){return t>=e}))}(e);for(var r,i=n(t).components.filter((function(t){return t.length>1})),a=1/0,o=0;o<i.length;o++)for(var s=0;s<i[o].length;s++)i[o][s]<a&&(a=i[o][s],r=o);var l=i[r];return!!l&&{leastVertex:a,adjList:t.map((function(t,e){return-1===l.indexOf(e)?[]:t.filter((function(t){return-1!==l.indexOf(t)}))}))}}r=0;for(var h=t.length;r<h;){var p=f(r);if(r=p.leastVertex,l=p.adjList){for(var d=0;d<l.length;d++)for(var m=0;m<l[d].length;m++){var g=l[d][m];o[+g]=!1,s[g]={}}c(r),r+=1}else r=h}return e?void 0:i}},{\"strongly-connected-components\":586}],185:[function(t,e,r){\"use strict\";var n=t(\"../../object/valid-value\");e.exports=function(){return n(this).length=0,this}},{\"../../object/valid-value\":216}],186:[function(t,e,r){\"use strict\";e.exports=t(\"./is-implemented\")()?Array.from:t(\"./shim\")},{\"./is-implemented\":187,\"./shim\":188}],187:[function(t,e,r){\"use strict\";e.exports=function(){var t,e,r=Array.from;return\"function\"==typeof r&&(e=r(t=[\"raz\",\"dwa\"]),Boolean(e&&e!==t&&\"dwa\"===e[1]))}},{}],188:[function(t,e,r){\"use strict\";var n=t(\"es6-symbol\").iterator,i=t(\"../../function/is-arguments\"),a=t(\"../../function/is-function\"),o=t(\"../../number/to-pos-integer\"),s=t(\"../../object/valid-callable\"),l=t(\"../../object/valid-value\"),c=t(\"../../object/is-value\"),u=t(\"../../string/is-string\"),f=Array.isArray,h=Function.prototype.call,p={configurable:!0,enumerable:!0,writable:!0,value:null},d=Object.defineProperty;e.exports=function(t){var e,r,m,g,v,y,x,b,_,w,T=arguments[1],k=arguments[2];if(t=Object(l(t)),c(T)&&s(T),this&&this!==Array&&a(this))e=this;else{if(!T){if(i(t))return 1!==(v=t.length)?Array.apply(null,t):((g=new Array(1))[0]=t[0],g);if(f(t)){for(g=new Array(v=t.length),r=0;r<v;++r)g[r]=t[r];return g}}g=[]}if(!f(t))if(void 0!==(_=t[n])){for(x=s(_).call(t),e&&(g=new e),b=x.next(),r=0;!b.done;)w=T?h.call(T,k,b.value,r):b.value,e?(p.value=w,d(g,r,p)):g[r]=w,b=x.next(),++r;v=r}else if(u(t)){for(v=t.length,e&&(g=new e),r=0,m=0;r<v;++r)w=t[r],r+1<v&&(y=w.charCodeAt(0))>=55296&&y<=56319&&(w+=t[++r]),w=T?h.call(T,k,w,m):w,e?(p.value=w,d(g,m,p)):g[m]=w,++m;v=m}if(void 0===v)for(v=o(t.length),e&&(g=new e(v)),r=0;r<v;++r)w=T?h.call(T,k,t[r],r):t[r],e?(p.value=w,d(g,r,p)):g[r]=w;return e&&(p.value=null,g.length=v),g}},{\"../../function/is-arguments\":189,\"../../function/is-function\":190,\"../../number/to-pos-integer\":196,\"../../object/is-value\":205,\"../../object/valid-callable\":214,\"../../object/valid-value\":216,\"../../string/is-string\":220,\"es6-symbol\":229}],189:[function(t,e,r){\"use strict\";var n=Object.prototype.toString,i=n.call(function(){return arguments}());e.exports=function(t){return n.call(t)===i}},{}],190:[function(t,e,r){\"use strict\";var n=Object.prototype.toString,i=RegExp.prototype.test.bind(/^[object [A-Za-z0-9]*Function]$/);e.exports=function(t){return\"function\"==typeof t&&i(n.call(t))}},{}],191:[function(t,e,r){\"use strict\";e.exports=function(){}},{}],192:[function(t,e,r){\"use strict\";e.exports=t(\"./is-implemented\")()?Math.sign:t(\"./shim\")},{\"./is-implemented\":193,\"./shim\":194}],193:[function(t,e,r){\"use strict\";e.exports=function(){var t=Math.sign;return\"function\"==typeof t&&(1===t(10)&&-1===t(-20))}},{}],194:[function(t,e,r){\"use strict\";e.exports=function(t){return t=Number(t),isNaN(t)||0===t?t:t>0?1:-1}},{}],195:[function(t,e,r){\"use strict\";var n=t(\"../math/sign\"),i=Math.abs,a=Math.floor;e.exports=function(t){return isNaN(t)?0:0!==(t=Number(t))&&isFinite(t)?n(t)*a(i(t)):t}},{\"../math/sign\":192}],196:[function(t,e,r){\"use strict\";var n=t(\"./to-integer\"),i=Math.max;e.exports=function(t){return i(0,n(t))}},{\"./to-integer\":195}],197:[function(t,e,r){\"use strict\";var n=t(\"./valid-callable\"),i=t(\"./valid-value\"),a=Function.prototype.bind,o=Function.prototype.call,s=Object.keys,l=Object.prototype.propertyIsEnumerable;e.exports=function(t,e){return function(r,c){var u,f=arguments[2],h=arguments[3];return r=Object(i(r)),n(c),u=s(r),h&&u.sort(\"function\"==typeof h?a.call(h,r):void 0),\"function\"!=typeof t&&(t=u[t]),o.call(t,u,(function(t,n){return l.call(r,t)?o.call(c,f,r[t],t,r,n):e}))}}},{\"./valid-callable\":214,\"./valid-value\":216}],198:[function(t,e,r){\"use strict\";e.exports=t(\"./is-implemented\")()?Object.assign:t(\"./shim\")},{\"./is-implemented\":199,\"./shim\":200}],199:[function(t,e,r){\"use strict\";e.exports=function(){var t,e=Object.assign;return\"function\"==typeof e&&(e(t={foo:\"raz\"},{bar:\"dwa\"},{trzy:\"trzy\"}),t.foo+t.bar+t.trzy===\"razdwatrzy\")}},{}],200:[function(t,e,r){\"use strict\";var n=t(\"../keys\"),i=t(\"../valid-value\"),a=Math.max;e.exports=function(t,e){var r,o,s,l=a(arguments.length,2);for(t=Object(i(t)),s=function(n){try{t[n]=e[n]}catch(t){r||(r=t)}},o=1;o<l;++o)n(e=arguments[o]).forEach(s);if(void 0!==r)throw r;return t}},{\"../keys\":206,\"../valid-value\":216}],201:[function(t,e,r){\"use strict\";var n=t(\"../array/from\"),i=t(\"./assign\"),a=t(\"./valid-value\");e.exports=function(t){var e=Object(a(t)),r=arguments[1],o=Object(arguments[2]);if(e!==t&&!r)return e;var s={};return r?n(r,(function(e){(o.ensure||e in t)&&(s[e]=t[e])})):i(s,t),s}},{\"../array/from\":186,\"./assign\":198,\"./valid-value\":216}],202:[function(t,e,r){\"use strict\";var n,i,a,o,s=Object.create;t(\"./set-prototype-of/is-implemented\")()||(n=t(\"./set-prototype-of/shim\")),e.exports=n?1!==n.level?s:(i={},a={},o={configurable:!1,enumerable:!1,writable:!0,value:void 0},Object.getOwnPropertyNames(Object.prototype).forEach((function(t){a[t]=\"__proto__\"!==t?o:{configurable:!0,enumerable:!1,writable:!0,value:void 0}})),Object.defineProperties(i,a),Object.defineProperty(n,\"nullPolyfill\",{configurable:!1,enumerable:!1,writable:!1,value:i}),function(t,e){return s(null===t?i:t,e)}):s},{\"./set-prototype-of/is-implemented\":212,\"./set-prototype-of/shim\":213}],203:[function(t,e,r){\"use strict\";e.exports=t(\"./_iterate\")(\"forEach\")},{\"./_iterate\":197}],204:[function(t,e,r){\"use strict\";var n=t(\"./is-value\"),i={function:!0,object:!0};e.exports=function(t){return n(t)&&i[typeof t]||!1}},{\"./is-value\":205}],205:[function(t,e,r){\"use strict\";var n=t(\"../function/noop\")();e.exports=function(t){return t!==n&&null!==t}},{\"../function/noop\":191}],206:[function(t,e,r){\"use strict\";e.exports=t(\"./is-implemented\")()?Object.keys:t(\"./shim\")},{\"./is-implemented\":207,\"./shim\":208}],207:[function(t,e,r){\"use strict\";e.exports=function(){try{return Object.keys(\"primitive\"),!0}catch(t){return!1}}},{}],208:[function(t,e,r){\"use strict\";var n=t(\"../is-value\"),i=Object.keys;e.exports=function(t){return i(n(t)?Object(t):t)}},{\"../is-value\":205}],209:[function(t,e,r){\"use strict\";var n=t(\"./valid-callable\"),i=t(\"./for-each\"),a=Function.prototype.call;e.exports=function(t,e){var r={},o=arguments[2];return n(e),i(t,(function(t,n,i,s){r[n]=a.call(e,o,t,n,i,s)})),r}},{\"./for-each\":203,\"./valid-callable\":214}],210:[function(t,e,r){\"use strict\";var n=t(\"./is-value\"),i=Array.prototype.forEach,a=Object.create,o=function(t,e){var r;for(r in t)e[r]=t[r]};e.exports=function(t){var e=a(null);return i.call(arguments,(function(t){n(t)&&o(Object(t),e)})),e}},{\"./is-value\":205}],211:[function(t,e,r){\"use strict\";e.exports=t(\"./is-implemented\")()?Object.setPrototypeOf:t(\"./shim\")},{\"./is-implemented\":212,\"./shim\":213}],212:[function(t,e,r){\"use strict\";var n=Object.create,i=Object.getPrototypeOf,a={};e.exports=function(){var t=Object.setPrototypeOf,e=arguments[0]||n;return\"function\"==typeof t&&i(t(e(null),a))===a}},{}],213:[function(t,e,r){\"use strict\";var n,i=t(\"../is-object\"),a=t(\"../valid-value\"),o=Object.prototype.isPrototypeOf,s=Object.defineProperty,l={configurable:!0,enumerable:!1,writable:!0,value:void 0};n=function(t,e){if(a(t),null===e||i(e))return t;throw new TypeError(\"Prototype must be null or an object\")},e.exports=function(t){var e,r;return t?(2===t.level?t.set?(r=t.set,e=function(t,e){return r.call(n(t,e),e),t}):e=function(t,e){return n(t,e).__proto__=e,t}:e=function t(e,r){var i;return n(e,r),(i=o.call(t.nullPolyfill,e))&&delete t.nullPolyfill.__proto__,null===r&&(r=t.nullPolyfill),e.__proto__=r,i&&s(t.nullPolyfill,\"__proto__\",l),e},Object.defineProperty(e,\"level\",{configurable:!1,enumerable:!1,writable:!1,value:t.level})):null}(function(){var t,e=Object.create(null),r={},n=Object.getOwnPropertyDescriptor(Object.prototype,\"__proto__\");if(n){try{(t=n.set).call(e,r)}catch(t){}if(Object.getPrototypeOf(e)===r)return{set:t,level:2}}return e.__proto__=r,Object.getPrototypeOf(e)===r?{level:2}:((e={}).__proto__=r,Object.getPrototypeOf(e)===r&&{level:1})}()),t(\"../create\")},{\"../create\":202,\"../is-object\":204,\"../valid-value\":216}],214:[function(t,e,r){\"use strict\";e.exports=function(t){if(\"function\"!=typeof t)throw new TypeError(t+\" is not a function\");return t}},{}],215:[function(t,e,r){\"use strict\";var n=t(\"./is-object\");e.exports=function(t){if(!n(t))throw new TypeError(t+\" is not an Object\");return t}},{\"./is-object\":204}],216:[function(t,e,r){\"use strict\";var n=t(\"./is-value\");e.exports=function(t){if(!n(t))throw new TypeError(\"Cannot use null or undefined\");return t}},{\"./is-value\":205}],217:[function(t,e,r){\"use strict\";e.exports=t(\"./is-implemented\")()?String.prototype.contains:t(\"./shim\")},{\"./is-implemented\":218,\"./shim\":219}],218:[function(t,e,r){\"use strict\";var n=\"razdwatrzy\";e.exports=function(){return\"function\"==typeof n.contains&&(!0===n.contains(\"dwa\")&&!1===n.contains(\"foo\"))}},{}],219:[function(t,e,r){\"use strict\";var n=String.prototype.indexOf;e.exports=function(t){return n.call(this,t,arguments[1])>-1}},{}],220:[function(t,e,r){\"use strict\";var n=Object.prototype.toString,i=n.call(\"\");e.exports=function(t){return\"string\"==typeof t||t&&\"object\"==typeof t&&(t instanceof String||n.call(t)===i)||!1}},{}],221:[function(t,e,r){\"use strict\";var n=Object.create(null),i=Math.random;e.exports=function(){var t;do{t=i().toString(36).slice(2)}while(n[t]);return t}},{}],222:[function(t,e,r){\"use strict\";var n,i=t(\"es5-ext/object/set-prototype-of\"),a=t(\"es5-ext/string/#/contains\"),o=t(\"d\"),s=t(\"es6-symbol\"),l=t(\"./\"),c=Object.defineProperty;n=e.exports=function(t,e){if(!(this instanceof n))throw new TypeError(\"Constructor requires 'new'\");l.call(this,t),e=e?a.call(e,\"key+value\")?\"key+value\":a.call(e,\"key\")?\"key\":\"value\":\"value\",c(this,\"__kind__\",o(\"\",e))},i&&i(n,l),delete n.prototype.constructor,n.prototype=Object.create(l.prototype,{_resolve:o((function(t){return\"value\"===this.__kind__?this.__list__[t]:\"key+value\"===this.__kind__?[t,this.__list__[t]]:t}))}),c(n.prototype,s.toStringTag,o(\"c\",\"Array Iterator\"))},{\"./\":225,d:161,\"es5-ext/object/set-prototype-of\":211,\"es5-ext/string/#/contains\":217,\"es6-symbol\":229}],223:[function(t,e,r){\"use strict\";var n=t(\"es5-ext/function/is-arguments\"),i=t(\"es5-ext/object/valid-callable\"),a=t(\"es5-ext/string/is-string\"),o=t(\"./get\"),s=Array.isArray,l=Function.prototype.call,c=Array.prototype.some;e.exports=function(t,e){var r,u,f,h,p,d,m,g,v=arguments[2];if(s(t)||n(t)?r=\"array\":a(t)?r=\"string\":t=o(t),i(e),f=function(){h=!0},\"array\"!==r)if(\"string\"!==r)for(u=t.next();!u.done;){if(l.call(e,v,u.value,f),h)return;u=t.next()}else for(d=t.length,p=0;p<d&&(m=t[p],p+1<d&&(g=m.charCodeAt(0))>=55296&&g<=56319&&(m+=t[++p]),l.call(e,v,m,f),!h);++p);else c.call(t,(function(t){return l.call(e,v,t,f),h}))}},{\"./get\":224,\"es5-ext/function/is-arguments\":189,\"es5-ext/object/valid-callable\":214,\"es5-ext/string/is-string\":220}],224:[function(t,e,r){\"use strict\";var n=t(\"es5-ext/function/is-arguments\"),i=t(\"es5-ext/string/is-string\"),a=t(\"./array\"),o=t(\"./string\"),s=t(\"./valid-iterable\"),l=t(\"es6-symbol\").iterator;e.exports=function(t){return\"function\"==typeof s(t)[l]?t[l]():n(t)?new a(t):i(t)?new o(t):new a(t)}},{\"./array\":222,\"./string\":227,\"./valid-iterable\":228,\"es5-ext/function/is-arguments\":189,\"es5-ext/string/is-string\":220,\"es6-symbol\":229}],225:[function(t,e,r){\"use strict\";var n,i=t(\"es5-ext/array/#/clear\"),a=t(\"es5-ext/object/assign\"),o=t(\"es5-ext/object/valid-callable\"),s=t(\"es5-ext/object/valid-value\"),l=t(\"d\"),c=t(\"d/auto-bind\"),u=t(\"es6-symbol\"),f=Object.defineProperty,h=Object.defineProperties;e.exports=n=function(t,e){if(!(this instanceof n))throw new TypeError(\"Constructor requires 'new'\");h(this,{__list__:l(\"w\",s(t)),__context__:l(\"w\",e),__nextIndex__:l(\"w\",0)}),e&&(o(e.on),e.on(\"_add\",this._onAdd),e.on(\"_delete\",this._onDelete),e.on(\"_clear\",this._onClear))},delete n.prototype.constructor,h(n.prototype,a({_next:l((function(){var t;if(this.__list__)return this.__redo__&&void 0!==(t=this.__redo__.shift())?t:this.__nextIndex__<this.__list__.length?this.__nextIndex__++:void this._unBind()})),next:l((function(){return this._createResult(this._next())})),_createResult:l((function(t){return void 0===t?{done:!0,value:void 0}:{done:!1,value:this._resolve(t)}})),_resolve:l((function(t){return this.__list__[t]})),_unBind:l((function(){this.__list__=null,delete this.__redo__,this.__context__&&(this.__context__.off(\"_add\",this._onAdd),this.__context__.off(\"_delete\",this._onDelete),this.__context__.off(\"_clear\",this._onClear),this.__context__=null)})),toString:l((function(){return\"[object \"+(this[u.toStringTag]||\"Object\")+\"]\"}))},c({_onAdd:l((function(t){t>=this.__nextIndex__||(++this.__nextIndex__,this.__redo__?(this.__redo__.forEach((function(e,r){e>=t&&(this.__redo__[r]=++e)}),this),this.__redo__.push(t)):f(this,\"__redo__\",l(\"c\",[t])))})),_onDelete:l((function(t){var e;t>=this.__nextIndex__||(--this.__nextIndex__,this.__redo__&&(-1!==(e=this.__redo__.indexOf(t))&&this.__redo__.splice(e,1),this.__redo__.forEach((function(e,r){e>t&&(this.__redo__[r]=--e)}),this)))})),_onClear:l((function(){this.__redo__&&i.call(this.__redo__),this.__nextIndex__=0}))}))),f(n.prototype,u.iterator,l((function(){return this})))},{d:161,\"d/auto-bind\":160,\"es5-ext/array/#/clear\":185,\"es5-ext/object/assign\":198,\"es5-ext/object/valid-callable\":214,\"es5-ext/object/valid-value\":216,\"es6-symbol\":229}],226:[function(t,e,r){\"use strict\";var n=t(\"es5-ext/function/is-arguments\"),i=t(\"es5-ext/object/is-value\"),a=t(\"es5-ext/string/is-string\"),o=t(\"es6-symbol\").iterator,s=Array.isArray;e.exports=function(t){return!!i(t)&&(!!s(t)||(!!a(t)||(!!n(t)||\"function\"==typeof t[o])))}},{\"es5-ext/function/is-arguments\":189,\"es5-ext/object/is-value\":205,\"es5-ext/string/is-string\":220,\"es6-symbol\":229}],227:[function(t,e,r){\"use strict\";var n,i=t(\"es5-ext/object/set-prototype-of\"),a=t(\"d\"),o=t(\"es6-symbol\"),s=t(\"./\"),l=Object.defineProperty;n=e.exports=function(t){if(!(this instanceof n))throw new TypeError(\"Constructor requires 'new'\");t=String(t),s.call(this,t),l(this,\"__length__\",a(\"\",t.length))},i&&i(n,s),delete n.prototype.constructor,n.prototype=Object.create(s.prototype,{_next:a((function(){if(this.__list__)return this.__nextIndex__<this.__length__?this.__nextIndex__++:void this._unBind()})),_resolve:a((function(t){var e,r=this.__list__[t];return this.__nextIndex__===this.__length__?r:(e=r.charCodeAt(0))>=55296&&e<=56319?r+this.__list__[this.__nextIndex__++]:r}))}),l(n.prototype,o.toStringTag,a(\"c\",\"String Iterator\"))},{\"./\":225,d:161,\"es5-ext/object/set-prototype-of\":211,\"es6-symbol\":229}],228:[function(t,e,r){\"use strict\";var n=t(\"./is-iterable\");e.exports=function(t){if(!n(t))throw new TypeError(t+\" is not iterable\");return t}},{\"./is-iterable\":226}],229:[function(t,e,r){\"use strict\";e.exports=t(\"./is-implemented\")()?t(\"ext/global-this\").Symbol:t(\"./polyfill\")},{\"./is-implemented\":230,\"./polyfill\":235,\"ext/global-this\":242}],230:[function(t,e,r){\"use strict\";var n=t(\"ext/global-this\"),i={object:!0,symbol:!0};e.exports=function(){var t,e=n.Symbol;if(\"function\"!=typeof e)return!1;t=e(\"test symbol\");try{String(t)}catch(t){return!1}return!!i[typeof e.iterator]&&(!!i[typeof e.toPrimitive]&&!!i[typeof e.toStringTag])}},{\"ext/global-this\":242}],231:[function(t,e,r){\"use strict\";e.exports=function(t){return!!t&&(\"symbol\"==typeof t||!!t.constructor&&(\"Symbol\"===t.constructor.name&&\"Symbol\"===t[t.constructor.toStringTag]))}},{}],232:[function(t,e,r){\"use strict\";var n=t(\"d\"),i=Object.create,a=Object.defineProperty,o=Object.prototype,s=i(null);e.exports=function(t){for(var e,r,i=0;s[t+(i||\"\")];)++i;return s[t+=i||\"\"]=!0,a(o,e=\"@@\"+t,n.gs(null,(function(t){r||(r=!0,a(this,e,n(t)),r=!1)}))),e}},{d:161}],233:[function(t,e,r){\"use strict\";var n=t(\"d\"),i=t(\"ext/global-this\").Symbol;e.exports=function(t){return Object.defineProperties(t,{hasInstance:n(\"\",i&&i.hasInstance||t(\"hasInstance\")),isConcatSpreadable:n(\"\",i&&i.isConcatSpreadable||t(\"isConcatSpreadable\")),iterator:n(\"\",i&&i.iterator||t(\"iterator\")),match:n(\"\",i&&i.match||t(\"match\")),replace:n(\"\",i&&i.replace||t(\"replace\")),search:n(\"\",i&&i.search||t(\"search\")),species:n(\"\",i&&i.species||t(\"species\")),split:n(\"\",i&&i.split||t(\"split\")),toPrimitive:n(\"\",i&&i.toPrimitive||t(\"toPrimitive\")),toStringTag:n(\"\",i&&i.toStringTag||t(\"toStringTag\")),unscopables:n(\"\",i&&i.unscopables||t(\"unscopables\"))})}},{d:161,\"ext/global-this\":242}],234:[function(t,e,r){\"use strict\";var n=t(\"d\"),i=t(\"../../../validate-symbol\"),a=Object.create(null);e.exports=function(t){return Object.defineProperties(t,{for:n((function(e){return a[e]?a[e]:a[e]=t(String(e))})),keyFor:n((function(t){var e;for(e in i(t),a)if(a[e]===t)return e}))})}},{\"../../../validate-symbol\":236,d:161}],235:[function(t,e,r){\"use strict\";var n,i,a,o=t(\"d\"),s=t(\"./validate-symbol\"),l=t(\"ext/global-this\").Symbol,c=t(\"./lib/private/generate-name\"),u=t(\"./lib/private/setup/standard-symbols\"),f=t(\"./lib/private/setup/symbol-registry\"),h=Object.create,p=Object.defineProperties,d=Object.defineProperty;if(\"function\"==typeof l)try{String(l()),a=!0}catch(t){}else l=null;i=function(t){if(this instanceof i)throw new TypeError(\"Symbol is not a constructor\");return n(t)},e.exports=n=function t(e){var r;if(this instanceof t)throw new TypeError(\"Symbol is not a constructor\");return a?l(e):(r=h(i.prototype),e=void 0===e?\"\":String(e),p(r,{__description__:o(\"\",e),__name__:o(\"\",c(e))}))},u(n),f(n),p(i.prototype,{constructor:o(n),toString:o(\"\",(function(){return this.__name__}))}),p(n.prototype,{toString:o((function(){return\"Symbol (\"+s(this).__description__+\")\"})),valueOf:o((function(){return s(this)}))}),d(n.prototype,n.toPrimitive,o(\"\",(function(){var t=s(this);return\"symbol\"==typeof t?t:t.toString()}))),d(n.prototype,n.toStringTag,o(\"c\",\"Symbol\")),d(i.prototype,n.toStringTag,o(\"c\",n.prototype[n.toStringTag])),d(i.prototype,n.toPrimitive,o(\"c\",n.prototype[n.toPrimitive]))},{\"./lib/private/generate-name\":232,\"./lib/private/setup/standard-symbols\":233,\"./lib/private/setup/symbol-registry\":234,\"./validate-symbol\":236,d:161,\"ext/global-this\":242}],236:[function(t,e,r){\"use strict\";var n=t(\"./is-symbol\");e.exports=function(t){if(!n(t))throw new TypeError(t+\" is not a symbol\");return t}},{\"./is-symbol\":231}],237:[function(t,e,r){\"use strict\";e.exports=t(\"./is-implemented\")()?WeakMap:t(\"./polyfill\")},{\"./is-implemented\":238,\"./polyfill\":240}],238:[function(t,e,r){\"use strict\";e.exports=function(){var t,e;if(\"function\"!=typeof WeakMap)return!1;try{t=new WeakMap([[e={},\"one\"],[{},\"two\"],[{},\"three\"]])}catch(t){return!1}return\"[object WeakMap]\"===String(t)&&(\"function\"==typeof t.set&&(t.set({},1)===t&&(\"function\"==typeof t.delete&&(\"function\"==typeof t.has&&\"one\"===t.get(e)))))}},{}],239:[function(t,e,r){\"use strict\";e.exports=\"function\"==typeof WeakMap&&\"[object WeakMap]\"===Object.prototype.toString.call(new WeakMap)},{}],240:[function(t,e,r){\"use strict\";var n,i=t(\"es5-ext/object/is-value\"),a=t(\"es5-ext/object/set-prototype-of\"),o=t(\"es5-ext/object/valid-object\"),s=t(\"es5-ext/object/valid-value\"),l=t(\"es5-ext/string/random-uniq\"),c=t(\"d\"),u=t(\"es6-iterator/get\"),f=t(\"es6-iterator/for-of\"),h=t(\"es6-symbol\").toStringTag,p=t(\"./is-native-implemented\"),d=Array.isArray,m=Object.defineProperty,g=Object.prototype.hasOwnProperty,v=Object.getPrototypeOf;e.exports=n=function(){var t,e=arguments[0];if(!(this instanceof n))throw new TypeError(\"Constructor requires 'new'\");return t=p&&a&&WeakMap!==n?a(new WeakMap,v(this)):this,i(e)&&(d(e)||(e=u(e))),m(t,\"__weakMapData__\",c(\"c\",\"$weakMap$\"+l())),e?(f(e,(function(e){s(e),t.set(e[0],e[1])})),t):t},p&&(a&&a(n,WeakMap),n.prototype=Object.create(WeakMap.prototype,{constructor:c(n)})),Object.defineProperties(n.prototype,{delete:c((function(t){return!!g.call(o(t),this.__weakMapData__)&&(delete t[this.__weakMapData__],!0)})),get:c((function(t){if(g.call(o(t),this.__weakMapData__))return t[this.__weakMapData__]})),has:c((function(t){return g.call(o(t),this.__weakMapData__)})),set:c((function(t,e){return m(o(t),this.__weakMapData__,c(\"c\",e)),this})),toString:c((function(){return\"[object WeakMap]\"}))}),m(n.prototype,h,c(\"c\",\"WeakMap\"))},{\"./is-native-implemented\":239,d:161,\"es5-ext/object/is-value\":205,\"es5-ext/object/set-prototype-of\":211,\"es5-ext/object/valid-object\":215,\"es5-ext/object/valid-value\":216,\"es5-ext/string/random-uniq\":221,\"es6-iterator/for-of\":223,\"es6-iterator/get\":224,\"es6-symbol\":229}],241:[function(t,e,r){var n=function(){if(\"object\"==typeof self&&self)return self;if(\"object\"==typeof window&&window)return window;throw new Error(\"Unable to resolve global `this`\")};e.exports=function(){if(this)return this;try{Object.defineProperty(Object.prototype,\"__global__\",{get:function(){return this},configurable:!0})}catch(t){return n()}try{return __global__||n()}finally{delete Object.prototype.__global__}}()},{}],242:[function(t,e,r){\"use strict\";e.exports=t(\"./is-implemented\")()?globalThis:t(\"./implementation\")},{\"./implementation\":241,\"./is-implemented\":243}],243:[function(t,e,r){\"use strict\";e.exports=function(){return\"object\"==typeof globalThis&&(!!globalThis&&globalThis.Array===Array)}},{}],244:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){var n=e||0,i=r||1;return[[t[12]+t[0],t[13]+t[1],t[14]+t[2],t[15]+t[3]],[t[12]-t[0],t[13]-t[1],t[14]-t[2],t[15]-t[3]],[t[12]+t[4],t[13]+t[5],t[14]+t[6],t[15]+t[7]],[t[12]-t[4],t[13]-t[5],t[14]-t[6],t[15]-t[7]],[n*t[12]+t[8],n*t[13]+t[9],n*t[14]+t[10],n*t[15]+t[11]],[i*t[12]-t[8],i*t[13]-t[9],i*t[14]-t[10],i*t[15]-t[11]]]}},{}],245:[function(t,e,r){\"use strict\";var n=t(\"is-string-blank\");e.exports=function(t){var e=typeof t;if(\"string\"===e){var r=t;if(0===(t=+t)&&n(r))return!1}else if(\"number\"!==e)return!1;return t-t<1}},{\"is-string-blank\":454}],246:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){switch(arguments.length){case 0:return new o([0],[0],0);case 1:return\"number\"==typeof t?new o(n=l(t),n,0):new o(t,l(t.length),0);case 2:if(\"number\"==typeof e){var n=l(t.length);return new o(t,n,+e)}r=0;case 3:if(t.length!==e.length)throw new Error(\"state and velocity lengths must match\");return new o(t,e,r)}};var n=t(\"cubic-hermite\"),i=t(\"binary-search-bounds\");function a(t,e,r){return Math.min(e,Math.max(t,r))}function o(t,e,r){this.dimension=t.length,this.bounds=[new Array(this.dimension),new Array(this.dimension)];for(var n=0;n<this.dimension;++n)this.bounds[0][n]=-1/0,this.bounds[1][n]=1/0;this._state=t.slice().reverse(),this._velocity=e.slice().reverse(),this._time=[r],this._scratch=[t.slice(),t.slice(),t.slice(),t.slice(),t.slice()]}var s=o.prototype;function l(t){for(var e=new Array(t),r=0;r<t;++r)e[r]=0;return e}s.flush=function(t){var e=i.gt(this._time,t)-1;e<=0||(this._time.splice(0,e),this._state.splice(0,e*this.dimension),this._velocity.splice(0,e*this.dimension))},s.curve=function(t){var e=this._time,r=e.length,o=i.le(e,t),s=this._scratch[0],l=this._state,c=this._velocity,u=this.dimension,f=this.bounds;if(o<0)for(var h=u-1,p=0;p<u;++p,--h)s[p]=l[h];else if(o>=r-1){h=l.length-1;var d=t-e[r-1];for(p=0;p<u;++p,--h)s[p]=l[h]+d*c[h]}else{h=u*(o+1)-1;var m=e[o],g=e[o+1]-m||1,v=this._scratch[1],y=this._scratch[2],x=this._scratch[3],b=this._scratch[4],_=!0;for(p=0;p<u;++p,--h)v[p]=l[h],x[p]=c[h]*g,y[p]=l[h+u],b[p]=c[h+u]*g,_=_&&v[p]===y[p]&&x[p]===b[p]&&0===x[p];if(_)for(p=0;p<u;++p)s[p]=v[p];else n(v,x,y,b,(t-m)/g,s)}var w=f[0],T=f[1];for(p=0;p<u;++p)s[p]=a(w[p],T[p],s[p]);return s},s.dcurve=function(t){var e=this._time,r=e.length,a=i.le(e,t),o=this._scratch[0],s=this._state,l=this._velocity,c=this.dimension;if(a>=r-1)for(var u=s.length-1,f=(e[r-1],0);f<c;++f,--u)o[f]=l[u];else{u=c*(a+1)-1;var h=e[a],p=e[a+1]-h||1,d=this._scratch[1],m=this._scratch[2],g=this._scratch[3],v=this._scratch[4],y=!0;for(f=0;f<c;++f,--u)d[f]=s[u],g[f]=l[u]*p,m[f]=s[u+c],v[f]=l[u+c]*p,y=y&&d[f]===m[f]&&g[f]===v[f]&&0===g[f];if(y)for(f=0;f<c;++f)o[f]=0;else{n.derivative(d,g,m,v,(t-h)/p,o);for(f=0;f<c;++f)o[f]/=p}}return o},s.lastT=function(){var t=this._time;return t[t.length-1]},s.stable=function(){for(var t=this._velocity,e=t.length,r=this.dimension-1;r>=0;--r)if(t[--e])return!1;return!0},s.jump=function(t){var e=this.lastT(),r=this.dimension;if(!(t<e||arguments.length!==r+1)){var n=this._state,i=this._velocity,o=n.length-this.dimension,s=this.bounds,l=s[0],c=s[1];this._time.push(e,t);for(var u=0;u<2;++u)for(var f=0;f<r;++f)n.push(n[o++]),i.push(0);this._time.push(t);for(f=r;f>0;--f)n.push(a(l[f-1],c[f-1],arguments[f])),i.push(0)}},s.push=function(t){var e=this.lastT(),r=this.dimension;if(!(t<e||arguments.length!==r+1)){var n=this._state,i=this._velocity,o=n.length-this.dimension,s=t-e,l=this.bounds,c=l[0],u=l[1],f=s>1e-6?1/s:0;this._time.push(t);for(var h=r;h>0;--h){var p=a(c[h-1],u[h-1],arguments[h]);n.push(p),i.push((p-n[o++])*f)}}},s.set=function(t){var e=this.dimension;if(!(t<this.lastT()||arguments.length!==e+1)){var r=this._state,n=this._velocity,i=this.bounds,o=i[0],s=i[1];this._time.push(t);for(var l=e;l>0;--l)r.push(a(o[l-1],s[l-1],arguments[l])),n.push(0)}},s.move=function(t){var e=this.lastT(),r=this.dimension;if(!(t<=e||arguments.length!==r+1)){var n=this._state,i=this._velocity,o=n.length-this.dimension,s=this.bounds,l=s[0],c=s[1],u=t-e,f=u>1e-6?1/u:0;this._time.push(t);for(var h=r;h>0;--h){var p=arguments[h];n.push(a(l[h-1],c[h-1],n[o++]+p)),i.push(p*f)}}},s.idle=function(t){var e=this.lastT();if(!(t<e)){var r=this.dimension,n=this._state,i=this._velocity,o=n.length-r,s=this.bounds,l=s[0],c=s[1],u=t-e;this._time.push(t);for(var f=r-1;f>=0;--f)n.push(a(l[f],c[f],n[o]+u*i[o])),i.push(0),o+=1}}},{\"binary-search-bounds\":247,\"cubic-hermite\":156}],247:[function(t,e,r){\"use strict\";function n(t,e,r,n,i,a){var o=[\"function \",t,\"(a,l,h,\",n.join(\",\"),\"){\",a?\"\":\"var i=\",r?\"l-1\":\"h+1\",\";while(l<=h){var m=(l+h)>>>1,x=a\",i?\".get(m)\":\"[m]\"];return a?e.indexOf(\"c\")<0?o.push(\";if(x===y){return m}else if(x<=y){\"):o.push(\";var p=c(x,y);if(p===0){return m}else if(p<=0){\"):o.push(\";if(\",e,\"){i=m;\"),r?o.push(\"l=m+1}else{h=m-1}\"):o.push(\"h=m-1}else{l=m+1}\"),o.push(\"}\"),a?o.push(\"return -1};\"):o.push(\"return i};\"),o.join(\"\")}function i(t,e,r,i){return new Function([n(\"A\",\"x\"+t+\"y\",e,[\"y\"],!1,i),n(\"B\",\"x\"+t+\"y\",e,[\"y\"],!0,i),n(\"P\",\"c(x,y)\"+t+\"0\",e,[\"y\",\"c\"],!1,i),n(\"Q\",\"c(x,y)\"+t+\"0\",e,[\"y\",\"c\"],!0,i),\"function dispatchBsearch\",r,\"(a,y,c,l,h){if(a.shape){if(typeof(c)==='function'){return Q(a,(l===undefined)?0:l|0,(h===undefined)?a.shape[0]-1:h|0,y,c)}else{return B(a,(c===undefined)?0:c|0,(l===undefined)?a.shape[0]-1:l|0,y)}}else{if(typeof(c)==='function'){return P(a,(l===undefined)?0:l|0,(h===undefined)?a.length-1:h|0,y,c)}else{return A(a,(c===undefined)?0:c|0,(l===undefined)?a.length-1:l|0,y)}}}return dispatchBsearch\",r].join(\"\"))()}e.exports={ge:i(\">=\",!1,\"GE\"),gt:i(\">\",!1,\"GT\"),lt:i(\"<\",!0,\"LT\"),le:i(\"<=\",!0,\"LE\"),eq:i(\"-\",!0,\"EQ\",!0)}},{}],248:[function(t,e,r){var n=t(\"dtype\");e.exports=function(t,e,r){if(!t)throw new TypeError(\"must specify data as first parameter\");if(r=0|+(r||0),Array.isArray(t)&&t[0]&&\"number\"==typeof t[0][0]){var i,a,o,s,l=t[0].length,c=t.length*l;e&&\"string\"!=typeof e||(e=new(n(e||\"float32\"))(c+r));var u=e.length-r;if(c!==u)throw new Error(\"source length \"+c+\" (\"+l+\"x\"+t.length+\") does not match destination length \"+u);for(i=0,o=r;i<t.length;i++)for(a=0;a<l;a++)e[o++]=null===t[i][a]?NaN:t[i][a]}else if(e&&\"string\"!=typeof e)e.set(t,r);else{var f=n(e||\"float32\");if(Array.isArray(t)||\"array\"===e)for(e=new f(t.length+r),i=0,o=r,s=e.length;o<s;o++,i++)e[o]=null===t[i]?NaN:t[i];else 0===r?e=new f(t):(e=new f(t.length+r)).set(t,r)}return e}},{dtype:180}],249:[function(t,e,r){\"use strict\";var n=t(\"css-font/stringify\"),i=[32,126];e.exports=function(t){var e=(t=t||{}).shape?t.shape:t.canvas?[t.canvas.width,t.canvas.height]:[512,512],r=t.canvas||document.createElement(\"canvas\"),a=t.font,o=\"number\"==typeof t.step?[t.step,t.step]:t.step||[32,32],s=t.chars||i;a&&\"string\"!=typeof a&&(a=n(a));if(Array.isArray(s)){if(2===s.length&&\"number\"==typeof s[0]&&\"number\"==typeof s[1]){for(var l=[],c=s[0],u=0;c<=s[1];c++)l[u++]=String.fromCharCode(c);s=l}}else s=String(s).split(\"\");e=e.slice(),r.width=e[0],r.height=e[1];var f=r.getContext(\"2d\");f.fillStyle=\"#000\",f.fillRect(0,0,r.width,r.height),f.font=a,f.textAlign=\"center\",f.textBaseline=\"middle\",f.fillStyle=\"#fff\";var h=o[0]/2,p=o[1]/2;for(c=0;c<s.length;c++)f.fillText(s[c],h,p),(h+=o[0])>e[0]-o[0]/2&&(h=o[0]/2,p+=o[1]);return r}},{\"css-font/stringify\":153}],250:[function(t,e,r){\"use strict\";function n(t,e){e||(e={}),(\"string\"==typeof t||Array.isArray(t))&&(e.family=t);var r=Array.isArray(e.family)?e.family.join(\", \"):e.family;if(!r)throw Error(\"`family` must be defined\");var s=e.size||e.fontSize||e.em||48,l=e.weight||e.fontWeight||\"\",c=(t=[e.style||e.fontStyle||\"\",l,s].join(\" \")+\"px \"+r,e.origin||\"top\");if(n.cache[r]&&s<=n.cache[r].em)return i(n.cache[r],c);var u=e.canvas||n.canvas,f=u.getContext(\"2d\"),h={upper:void 0!==e.upper?e.upper:\"H\",lower:void 0!==e.lower?e.lower:\"x\",descent:void 0!==e.descent?e.descent:\"p\",ascent:void 0!==e.ascent?e.ascent:\"h\",tittle:void 0!==e.tittle?e.tittle:\"i\",overshoot:void 0!==e.overshoot?e.overshoot:\"O\"},p=Math.ceil(1.5*s);u.height=p,u.width=.5*p,f.font=t;var d={top:0};f.clearRect(0,0,p,p),f.textBaseline=\"top\",f.fillStyle=\"black\",f.fillText(\"H\",0,0);var m=a(f.getImageData(0,0,p,p));f.clearRect(0,0,p,p),f.textBaseline=\"bottom\",f.fillText(\"H\",0,p);var g=a(f.getImageData(0,0,p,p));d.lineHeight=d.bottom=p-g+m,f.clearRect(0,0,p,p),f.textBaseline=\"alphabetic\",f.fillText(\"H\",0,p);var v=p-a(f.getImageData(0,0,p,p))-1+m;d.baseline=d.alphabetic=v,f.clearRect(0,0,p,p),f.textBaseline=\"middle\",f.fillText(\"H\",0,.5*p);var y=a(f.getImageData(0,0,p,p));d.median=d.middle=p-y-1+m-.5*p,f.clearRect(0,0,p,p),f.textBaseline=\"hanging\",f.fillText(\"H\",0,.5*p);var x=a(f.getImageData(0,0,p,p));d.hanging=p-x-1+m-.5*p,f.clearRect(0,0,p,p),f.textBaseline=\"ideographic\",f.fillText(\"H\",0,p);var b=a(f.getImageData(0,0,p,p));if(d.ideographic=p-b-1+m,h.upper&&(f.clearRect(0,0,p,p),f.textBaseline=\"top\",f.fillText(h.upper,0,0),d.upper=a(f.getImageData(0,0,p,p)),d.capHeight=d.baseline-d.upper),h.lower&&(f.clearRect(0,0,p,p),f.textBaseline=\"top\",f.fillText(h.lower,0,0),d.lower=a(f.getImageData(0,0,p,p)),d.xHeight=d.baseline-d.lower),h.tittle&&(f.clearRect(0,0,p,p),f.textBaseline=\"top\",f.fillText(h.tittle,0,0),d.tittle=a(f.getImageData(0,0,p,p))),h.ascent&&(f.clearRect(0,0,p,p),f.textBaseline=\"top\",f.fillText(h.ascent,0,0),d.ascent=a(f.getImageData(0,0,p,p))),h.descent&&(f.clearRect(0,0,p,p),f.textBaseline=\"top\",f.fillText(h.descent,0,0),d.descent=o(f.getImageData(0,0,p,p))),h.overshoot){f.clearRect(0,0,p,p),f.textBaseline=\"top\",f.fillText(h.overshoot,0,0);var _=o(f.getImageData(0,0,p,p));d.overshoot=_-v}for(var w in d)d[w]/=s;return d.em=s,n.cache[r]=d,i(d,c)}function i(t,e){var r={};for(var n in\"string\"==typeof e&&(e=t[e]),t)\"em\"!==n&&(r[n]=t[n]-e);return r}function a(t){for(var e=t.height,r=t.data,n=3;n<r.length;n+=4)if(0!==r[n])return Math.floor(.25*(n-3)/e)}function o(t){for(var e=t.height,r=t.data,n=r.length-1;n>0;n-=4)if(0!==r[n])return Math.floor(.25*(n-3)/e)}e.exports=n,n.canvas=document.createElement(\"canvas\"),n.cache={}},{}],251:[function(t,e,r){\"use strict\";e.exports=function(t){return new s(t||m,null)};function n(t,e,r,n,i,a){this._color=t,this.key=e,this.value=r,this.left=n,this.right=i,this._count=a}function i(t){return new n(t._color,t.key,t.value,t.left,t.right,t._count)}function a(t,e){return new n(t,e.key,e.value,e.left,e.right,e._count)}function o(t){t._count=1+(t.left?t.left._count:0)+(t.right?t.right._count:0)}function s(t,e){this._compare=t,this.root=e}var l=s.prototype;function c(t,e){var r;if(e.left&&(r=c(t,e.left)))return r;return(r=t(e.key,e.value))||(e.right?c(t,e.right):void 0)}function u(t,e,r,n){if(e(t,n.key)<=0){var i;if(n.left)if(i=u(t,e,r,n.left))return i;if(i=r(n.key,n.value))return i}if(n.right)return u(t,e,r,n.right)}function f(t,e,r,n,i){var a,o=r(t,i.key),s=r(e,i.key);if(o<=0){if(i.left&&(a=f(t,e,r,n,i.left)))return a;if(s>0&&(a=n(i.key,i.value)))return a}if(s>0&&i.right)return f(t,e,r,n,i.right)}function h(t,e){this.tree=t,this._stack=e}Object.defineProperty(l,\"keys\",{get:function(){var t=[];return this.forEach((function(e,r){t.push(e)})),t}}),Object.defineProperty(l,\"values\",{get:function(){var t=[];return this.forEach((function(e,r){t.push(r)})),t}}),Object.defineProperty(l,\"length\",{get:function(){return this.root?this.root._count:0}}),l.insert=function(t,e){for(var r=this._compare,i=this.root,l=[],c=[];i;){var u=r(t,i.key);l.push(i),c.push(u),i=u<=0?i.left:i.right}l.push(new n(0,t,e,null,null,1));for(var f=l.length-2;f>=0;--f){i=l[f];c[f]<=0?l[f]=new n(i._color,i.key,i.value,l[f+1],i.right,i._count+1):l[f]=new n(i._color,i.key,i.value,i.left,l[f+1],i._count+1)}for(f=l.length-1;f>1;--f){var h=l[f-1];i=l[f];if(1===h._color||1===i._color)break;var p=l[f-2];if(p.left===h)if(h.left===i){if(!(d=p.right)||0!==d._color){if(p._color=0,p.left=h.right,h._color=1,h.right=p,l[f-2]=h,l[f-1]=i,o(p),o(h),f>=3)(m=l[f-3]).left===p?m.left=h:m.right=h;break}h._color=1,p.right=a(1,d),p._color=0,f-=1}else{if(!(d=p.right)||0!==d._color){if(h.right=i.left,p._color=0,p.left=i.right,i._color=1,i.left=h,i.right=p,l[f-2]=i,l[f-1]=h,o(p),o(h),o(i),f>=3)(m=l[f-3]).left===p?m.left=i:m.right=i;break}h._color=1,p.right=a(1,d),p._color=0,f-=1}else if(h.right===i){if(!(d=p.left)||0!==d._color){if(p._color=0,p.right=h.left,h._color=1,h.left=p,l[f-2]=h,l[f-1]=i,o(p),o(h),f>=3)(m=l[f-3]).right===p?m.right=h:m.left=h;break}h._color=1,p.left=a(1,d),p._color=0,f-=1}else{var d;if(!(d=p.left)||0!==d._color){var m;if(h.left=i.right,p._color=0,p.right=i.left,i._color=1,i.right=h,i.left=p,l[f-2]=i,l[f-1]=h,o(p),o(h),o(i),f>=3)(m=l[f-3]).right===p?m.right=i:m.left=i;break}h._color=1,p.left=a(1,d),p._color=0,f-=1}}return l[0]._color=1,new s(r,l[0])},l.forEach=function(t,e,r){if(this.root)switch(arguments.length){case 1:return c(t,this.root);case 2:return u(e,this._compare,t,this.root);case 3:if(this._compare(e,r)>=0)return;return f(e,r,this._compare,t,this.root)}},Object.defineProperty(l,\"begin\",{get:function(){for(var t=[],e=this.root;e;)t.push(e),e=e.left;return new h(this,t)}}),Object.defineProperty(l,\"end\",{get:function(){for(var t=[],e=this.root;e;)t.push(e),e=e.right;return new h(this,t)}}),l.at=function(t){if(t<0)return new h(this,[]);for(var e=this.root,r=[];;){if(r.push(e),e.left){if(t<e.left._count){e=e.left;continue}t-=e.left._count}if(!t)return new h(this,r);if(t-=1,!e.right)break;if(t>=e.right._count)break;e=e.right}return new h(this,[])},l.ge=function(t){for(var e=this._compare,r=this.root,n=[],i=0;r;){var a=e(t,r.key);n.push(r),a<=0&&(i=n.length),r=a<=0?r.left:r.right}return n.length=i,new h(this,n)},l.gt=function(t){for(var e=this._compare,r=this.root,n=[],i=0;r;){var a=e(t,r.key);n.push(r),a<0&&(i=n.length),r=a<0?r.left:r.right}return n.length=i,new h(this,n)},l.lt=function(t){for(var e=this._compare,r=this.root,n=[],i=0;r;){var a=e(t,r.key);n.push(r),a>0&&(i=n.length),r=a<=0?r.left:r.right}return n.length=i,new h(this,n)},l.le=function(t){for(var e=this._compare,r=this.root,n=[],i=0;r;){var a=e(t,r.key);n.push(r),a>=0&&(i=n.length),r=a<0?r.left:r.right}return n.length=i,new h(this,n)},l.find=function(t){for(var e=this._compare,r=this.root,n=[];r;){var i=e(t,r.key);if(n.push(r),0===i)return new h(this,n);r=i<=0?r.left:r.right}return new h(this,[])},l.remove=function(t){var e=this.find(t);return e?e.remove():this},l.get=function(t){for(var e=this._compare,r=this.root;r;){var n=e(t,r.key);if(0===n)return r.value;r=n<=0?r.left:r.right}};var p=h.prototype;function d(t,e){t.key=e.key,t.value=e.value,t.left=e.left,t.right=e.right,t._color=e._color,t._count=e._count}function m(t,e){return t<e?-1:t>e?1:0}Object.defineProperty(p,\"valid\",{get:function(){return this._stack.length>0}}),Object.defineProperty(p,\"node\",{get:function(){return this._stack.length>0?this._stack[this._stack.length-1]:null},enumerable:!0}),p.clone=function(){return new h(this.tree,this._stack.slice())},p.remove=function(){var t=this._stack;if(0===t.length)return this.tree;var e=new Array(t.length),r=t[t.length-1];e[e.length-1]=new n(r._color,r.key,r.value,r.left,r.right,r._count);for(var l=t.length-2;l>=0;--l){(r=t[l]).left===t[l+1]?e[l]=new n(r._color,r.key,r.value,e[l+1],r.right,r._count):e[l]=new n(r._color,r.key,r.value,r.left,e[l+1],r._count)}if((r=e[e.length-1]).left&&r.right){var c=e.length;for(r=r.left;r.right;)e.push(r),r=r.right;var u=e[c-1];e.push(new n(r._color,u.key,u.value,r.left,r.right,r._count)),e[c-1].key=r.key,e[c-1].value=r.value;for(l=e.length-2;l>=c;--l)r=e[l],e[l]=new n(r._color,r.key,r.value,r.left,e[l+1],r._count);e[c-1].left=e[c]}if(0===(r=e[e.length-1])._color){var f=e[e.length-2];f.left===r?f.left=null:f.right===r&&(f.right=null),e.pop();for(l=0;l<e.length;++l)e[l]._count--;return new s(this.tree._compare,e[0])}if(r.left||r.right){r.left?d(r,r.left):r.right&&d(r,r.right),r._color=1;for(l=0;l<e.length-1;++l)e[l]._count--;return new s(this.tree._compare,e[0])}if(1===e.length)return new s(this.tree._compare,null);for(l=0;l<e.length;++l)e[l]._count--;var h=e[e.length-2];return function(t){for(var e,r,n,s,l=t.length-1;l>=0;--l){if(e=t[l],0===l)return void(e._color=1);if((r=t[l-1]).left===e){if((n=r.right).right&&0===n.right._color){if(s=(n=r.right=i(n)).right=i(n.right),r.right=n.left,n.left=r,n.right=s,n._color=r._color,e._color=1,r._color=1,s._color=1,o(r),o(n),l>1)(c=t[l-2]).left===r?c.left=n:c.right=n;return void(t[l-1]=n)}if(n.left&&0===n.left._color){if(s=(n=r.right=i(n)).left=i(n.left),r.right=s.left,n.left=s.right,s.left=r,s.right=n,s._color=r._color,r._color=1,n._color=1,e._color=1,o(r),o(n),o(s),l>1)(c=t[l-2]).left===r?c.left=s:c.right=s;return void(t[l-1]=s)}if(1===n._color){if(0===r._color)return r._color=1,void(r.right=a(0,n));r.right=a(0,n);continue}n=i(n),r.right=n.left,n.left=r,n._color=r._color,r._color=0,o(r),o(n),l>1&&((c=t[l-2]).left===r?c.left=n:c.right=n),t[l-1]=n,t[l]=r,l+1<t.length?t[l+1]=e:t.push(e),l+=2}else{if((n=r.left).left&&0===n.left._color){if(s=(n=r.left=i(n)).left=i(n.left),r.left=n.right,n.right=r,n.left=s,n._color=r._color,e._color=1,r._color=1,s._color=1,o(r),o(n),l>1)(c=t[l-2]).right===r?c.right=n:c.left=n;return void(t[l-1]=n)}if(n.right&&0===n.right._color){if(s=(n=r.left=i(n)).right=i(n.right),r.left=s.right,n.right=s.left,s.right=r,s.left=n,s._color=r._color,r._color=1,n._color=1,e._color=1,o(r),o(n),o(s),l>1)(c=t[l-2]).right===r?c.right=s:c.left=s;return void(t[l-1]=s)}if(1===n._color){if(0===r._color)return r._color=1,void(r.left=a(0,n));r.left=a(0,n);continue}var c;n=i(n),r.left=n.right,n.right=r,n._color=r._color,r._color=0,o(r),o(n),l>1&&((c=t[l-2]).right===r?c.right=n:c.left=n),t[l-1]=n,t[l]=r,l+1<t.length?t[l+1]=e:t.push(e),l+=2}}}(e),h.left===r?h.left=null:h.right=null,new s(this.tree._compare,e[0])},Object.defineProperty(p,\"key\",{get:function(){if(this._stack.length>0)return this._stack[this._stack.length-1].key},enumerable:!0}),Object.defineProperty(p,\"value\",{get:function(){if(this._stack.length>0)return this._stack[this._stack.length-1].value},enumerable:!0}),Object.defineProperty(p,\"index\",{get:function(){var t=0,e=this._stack;if(0===e.length){var r=this.tree.root;return r?r._count:0}e[e.length-1].left&&(t=e[e.length-1].left._count);for(var n=e.length-2;n>=0;--n)e[n+1]===e[n].right&&(++t,e[n].left&&(t+=e[n].left._count));return t},enumerable:!0}),p.next=function(){var t=this._stack;if(0!==t.length){var e=t[t.length-1];if(e.right)for(e=e.right;e;)t.push(e),e=e.left;else for(t.pop();t.length>0&&t[t.length-1].right===e;)e=t[t.length-1],t.pop()}},Object.defineProperty(p,\"hasNext\",{get:function(){var t=this._stack;if(0===t.length)return!1;if(t[t.length-1].right)return!0;for(var e=t.length-1;e>0;--e)if(t[e-1].left===t[e])return!0;return!1}}),p.update=function(t){var e=this._stack;if(0===e.length)throw new Error(\"Can't update empty node!\");var r=new Array(e.length),i=e[e.length-1];r[r.length-1]=new n(i._color,i.key,t,i.left,i.right,i._count);for(var a=e.length-2;a>=0;--a)(i=e[a]).left===e[a+1]?r[a]=new n(i._color,i.key,i.value,r[a+1],i.right,i._count):r[a]=new n(i._color,i.key,i.value,i.left,r[a+1],i._count);return new s(this.tree._compare,r[0])},p.prev=function(){var t=this._stack;if(0!==t.length){var e=t[t.length-1];if(e.left)for(e=e.left;e;)t.push(e),e=e.right;else for(t.pop();t.length>0&&t[t.length-1].left===e;)e=t[t.length-1],t.pop()}},Object.defineProperty(p,\"hasPrev\",{get:function(){var t=this._stack;if(0===t.length)return!1;if(t[t.length-1].left)return!0;for(var e=t.length-1;e>0;--e)if(t[e-1].right===t[e])return!0;return!1}})},{}],252:[function(t,e,r){var n=[.9999999999998099,676.5203681218851,-1259.1392167224028,771.3234287776531,-176.6150291621406,12.507343278686905,-.13857109526572012,9984369578019572e-21,1.5056327351493116e-7],i=[.9999999999999971,57.15623566586292,-59.59796035547549,14.136097974741746,-.4919138160976202,3399464998481189e-20,4652362892704858e-20,-9837447530487956e-20,.0001580887032249125,-.00021026444172410488,.00021743961811521265,-.0001643181065367639,8441822398385275e-20,-26190838401581408e-21,36899182659531625e-22];function a(t){if(t<0)return Number(\"0/0\");for(var e=i[0],r=i.length-1;r>0;--r)e+=i[r]/(t+r);var n=t+607/128+.5;return.5*Math.log(2*Math.PI)+(t+.5)*Math.log(n)-n+Math.log(e)-Math.log(t)}e.exports=function t(e){if(e<.5)return Math.PI/(Math.sin(Math.PI*e)*t(1-e));if(e>100)return Math.exp(a(e));e-=1;for(var r=n[0],i=1;i<9;i++)r+=n[i]/(e+i);var o=e+7+.5;return Math.sqrt(2*Math.PI)*Math.pow(o,e+.5)*Math.exp(-o)*r},e.exports.log=a},{}],253:[function(t,e,r){e.exports=function(t,e){if(\"string\"!=typeof t)throw new TypeError(\"must specify type string\");if(e=e||{},\"undefined\"==typeof document&&!e.canvas)return null;var r=e.canvas||document.createElement(\"canvas\");\"number\"==typeof e.width&&(r.width=e.width);\"number\"==typeof e.height&&(r.height=e.height);var n,i=e;try{var a=[t];0===t.indexOf(\"webgl\")&&a.push(\"experimental-\"+t);for(var o=0;o<a.length;o++)if(n=r.getContext(a[o],i))return n}catch(t){n=null}return n||null}},{}],254:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=new u(t);return r.update(e),r};var n=t(\"./lib/text.js\"),i=t(\"./lib/lines.js\"),a=t(\"./lib/background.js\"),o=t(\"./lib/cube.js\"),s=t(\"./lib/ticks.js\"),l=new Float32Array([1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1]);function c(t,e){return t[0]=e[0],t[1]=e[1],t[2]=e[2],t}function u(t){this.gl=t,this.pixelRatio=1,this.bounds=[[-10,-10,-10],[10,10,10]],this.ticks=[[],[],[]],this.autoTicks=!0,this.tickSpacing=[1,1,1],this.tickEnable=[!0,!0,!0],this.tickFont=[\"sans-serif\",\"sans-serif\",\"sans-serif\"],this.tickSize=[12,12,12],this.tickAngle=[0,0,0],this.tickAlign=[\"auto\",\"auto\",\"auto\"],this.tickColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.tickPad=[10,10,10],this.lastCubeProps={cubeEdges:[0,0,0],axis:[0,0,0]},this.labels=[\"x\",\"y\",\"z\"],this.labelEnable=[!0,!0,!0],this.labelFont=\"sans-serif\",this.labelSize=[20,20,20],this.labelAngle=[0,0,0],this.labelAlign=[\"auto\",\"auto\",\"auto\"],this.labelColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.labelPad=[10,10,10],this.lineEnable=[!0,!0,!0],this.lineMirror=[!1,!1,!1],this.lineWidth=[1,1,1],this.lineColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.lineTickEnable=[!0,!0,!0],this.lineTickMirror=[!1,!1,!1],this.lineTickLength=[0,0,0],this.lineTickWidth=[1,1,1],this.lineTickColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.gridEnable=[!0,!0,!0],this.gridWidth=[1,1,1],this.gridColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.zeroEnable=[!0,!0,!0],this.zeroLineColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.zeroLineWidth=[2,2,2],this.backgroundEnable=[!1,!1,!1],this.backgroundColor=[[.8,.8,.8,.5],[.8,.8,.8,.5],[.8,.8,.8,.5]],this._firstInit=!0,this._text=null,this._lines=null,this._background=a(t)}var f=u.prototype;function h(){this.primalOffset=[0,0,0],this.primalMinor=[0,0,0],this.mirrorOffset=[0,0,0],this.mirrorMinor=[0,0,0]}f.update=function(t){function e(e,r,n){if(n in t){var i,a=t[n],o=this[n];(e?Array.isArray(a)&&Array.isArray(a[0]):Array.isArray(a))?this[n]=i=[r(a[0]),r(a[1]),r(a[2])]:this[n]=i=[r(a),r(a),r(a)];for(var s=0;s<3;++s)if(i[s]!==o[s])return!0}return!1}t=t||{};var r,a=e.bind(this,!1,Number),o=e.bind(this,!1,Boolean),l=e.bind(this,!1,String),c=e.bind(this,!0,(function(t){if(Array.isArray(t)){if(3===t.length)return[+t[0],+t[1],+t[2],1];if(4===t.length)return[+t[0],+t[1],+t[2],+t[3]]}return[0,0,0,1]})),u=!1,f=!1;if(\"bounds\"in t)for(var h=t.bounds,p=0;p<2;++p)for(var d=0;d<3;++d)h[p][d]!==this.bounds[p][d]&&(f=!0),this.bounds[p][d]=h[p][d];if(\"ticks\"in t){r=t.ticks,u=!0,this.autoTicks=!1;for(p=0;p<3;++p)this.tickSpacing[p]=0}else a(\"tickSpacing\")&&(this.autoTicks=!0,f=!0);if(this._firstInit&&(\"ticks\"in t||\"tickSpacing\"in t||(this.autoTicks=!0),f=!0,u=!0,this._firstInit=!1),f&&this.autoTicks&&(r=s.create(this.bounds,this.tickSpacing),u=!0),u){for(p=0;p<3;++p)r[p].sort((function(t,e){return t.x-e.x}));s.equal(r,this.ticks)?u=!1:this.ticks=r}o(\"tickEnable\"),l(\"tickFont\")&&(u=!0),a(\"tickSize\"),a(\"tickAngle\"),a(\"tickPad\"),c(\"tickColor\");var m=l(\"labels\");l(\"labelFont\")&&(m=!0),o(\"labelEnable\"),a(\"labelSize\"),a(\"labelPad\"),c(\"labelColor\"),o(\"lineEnable\"),o(\"lineMirror\"),a(\"lineWidth\"),c(\"lineColor\"),o(\"lineTickEnable\"),o(\"lineTickMirror\"),a(\"lineTickLength\"),a(\"lineTickWidth\"),c(\"lineTickColor\"),o(\"gridEnable\"),a(\"gridWidth\"),c(\"gridColor\"),o(\"zeroEnable\"),c(\"zeroLineColor\"),a(\"zeroLineWidth\"),o(\"backgroundEnable\"),c(\"backgroundColor\"),this._text?this._text&&(m||u)&&this._text.update(this.bounds,this.labels,this.labelFont,this.ticks,this.tickFont):this._text=n(this.gl,this.bounds,this.labels,this.labelFont,this.ticks,this.tickFont),this._lines&&u&&(this._lines.dispose(),this._lines=null),this._lines||(this._lines=i(this.gl,this.bounds,this.ticks))};var p=[new h,new h,new h];function d(t,e,r,n,i){for(var a=t.primalOffset,o=t.primalMinor,s=t.mirrorOffset,l=t.mirrorMinor,c=n[e],u=0;u<3;++u)if(e!==u){var f=a,h=s,p=o,d=l;c&1<<u&&(f=s,h=a,p=l,d=o),f[u]=r[0][u],h[u]=r[1][u],i[u]>0?(p[u]=-1,d[u]=0):(p[u]=0,d[u]=1)}}var m=[0,0,0],g={model:l,view:l,projection:l,_ortho:!1};f.isOpaque=function(){return!0},f.isTransparent=function(){return!1},f.drawTransparent=function(t){};var v=[0,0,0],y=[0,0,0],x=[0,0,0];f.draw=function(t){t=t||g;for(var e=this.gl,r=t.model||l,n=t.view||l,i=t.projection||l,a=this.bounds,s=t._ortho||!1,u=o(r,n,i,a,s),f=u.cubeEdges,h=u.axis,b=n[12],_=n[13],w=n[14],T=n[15],k=(s?2:1)*this.pixelRatio*(i[3]*b+i[7]*_+i[11]*w+i[15]*T)/e.drawingBufferHeight,M=0;M<3;++M)this.lastCubeProps.cubeEdges[M]=f[M],this.lastCubeProps.axis[M]=h[M];var A=p;for(M=0;M<3;++M)d(p[M],M,this.bounds,f,h);e=this.gl;var S,E=m;for(M=0;M<3;++M)this.backgroundEnable[M]?E[M]=h[M]:E[M]=0;this._background.draw(r,n,i,a,E,this.backgroundColor),this._lines.bind(r,n,i,this);for(M=0;M<3;++M){var L=[0,0,0];h[M]>0?L[M]=a[1][M]:L[M]=a[0][M];for(var C=0;C<2;++C){var P=(M+1+C)%3,I=(M+1+(1^C))%3;this.gridEnable[P]&&this._lines.drawGrid(P,I,this.bounds,L,this.gridColor[P],this.gridWidth[P]*this.pixelRatio)}for(C=0;C<2;++C){P=(M+1+C)%3,I=(M+1+(1^C))%3;this.zeroEnable[I]&&Math.min(a[0][I],a[1][I])<=0&&Math.max(a[0][I],a[1][I])>=0&&this._lines.drawZero(P,I,this.bounds,L,this.zeroLineColor[I],this.zeroLineWidth[I]*this.pixelRatio)}}for(M=0;M<3;++M){this.lineEnable[M]&&this._lines.drawAxisLine(M,this.bounds,A[M].primalOffset,this.lineColor[M],this.lineWidth[M]*this.pixelRatio),this.lineMirror[M]&&this._lines.drawAxisLine(M,this.bounds,A[M].mirrorOffset,this.lineColor[M],this.lineWidth[M]*this.pixelRatio);var O=c(v,A[M].primalMinor),z=c(y,A[M].mirrorMinor),D=this.lineTickLength;for(C=0;C<3;++C){var R=k/r[5*C];O[C]*=D[C]*R,z[C]*=D[C]*R}this.lineTickEnable[M]&&this._lines.drawAxisTicks(M,A[M].primalOffset,O,this.lineTickColor[M],this.lineTickWidth[M]*this.pixelRatio),this.lineTickMirror[M]&&this._lines.drawAxisTicks(M,A[M].mirrorOffset,z,this.lineTickColor[M],this.lineTickWidth[M]*this.pixelRatio)}this._lines.unbind(),this._text.bind(r,n,i,this.pixelRatio);var F,B;function N(t){(B=[0,0,0])[t]=1}function j(t,e,r){var n=(t+1)%3,i=(t+2)%3,a=e[n],o=e[i],s=r[n],l=r[i];a>0&&l>0||a>0&&l<0||a<0&&l>0||a<0&&l<0?N(n):(o>0&&s>0||o>0&&s<0||o<0&&s>0||o<0&&s<0)&&N(i)}for(M=0;M<3;++M){var U=A[M].primalMinor,V=A[M].mirrorMinor,q=c(x,A[M].primalOffset);for(C=0;C<3;++C)this.lineTickEnable[M]&&(q[C]+=k*U[C]*Math.max(this.lineTickLength[C],0)/r[5*C]);var H=[0,0,0];if(H[M]=1,this.tickEnable[M]){-3600===this.tickAngle[M]?(this.tickAngle[M]=0,this.tickAlign[M]=\"auto\"):this.tickAlign[M]=-1,F=1,\"auto\"===(S=[this.tickAlign[M],.5,F])[0]?S[0]=0:S[0]=parseInt(\"\"+S[0]),B=[0,0,0],j(M,U,V);for(C=0;C<3;++C)q[C]+=k*U[C]*this.tickPad[C]/r[5*C];this._text.drawTicks(M,this.tickSize[M],this.tickAngle[M],q,this.tickColor[M],H,B,S)}if(this.labelEnable[M]){F=0,B=[0,0,0],this.labels[M].length>4&&(N(M),F=1),\"auto\"===(S=[this.labelAlign[M],.5,F])[0]?S[0]=0:S[0]=parseInt(\"\"+S[0]);for(C=0;C<3;++C)q[C]+=k*U[C]*this.labelPad[C]/r[5*C];q[M]+=.5*(a[0][M]+a[1][M]),this._text.drawLabel(M,this.labelSize[M],this.labelAngle[M],q,this.labelColor[M],[0,0,0],B,S)}}this._text.unbind()},f.dispose=function(){this._text.dispose(),this._lines.dispose(),this._background.dispose(),this._lines=null,this._text=null,this._background=null,this.gl=null}},{\"./lib/background.js\":255,\"./lib/cube.js\":256,\"./lib/lines.js\":257,\"./lib/text.js\":259,\"./lib/ticks.js\":260}],255:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=[],r=[],s=0,l=0;l<3;++l)for(var c=(l+1)%3,u=(l+2)%3,f=[0,0,0],h=[0,0,0],p=-1;p<=1;p+=2){r.push(s,s+2,s+1,s+1,s+2,s+3),f[l]=p,h[l]=p;for(var d=-1;d<=1;d+=2){f[c]=d;for(var m=-1;m<=1;m+=2)f[u]=m,e.push(f[0],f[1],f[2],h[0],h[1],h[2]),s+=1}var g=c;c=u,u=g}var v=n(t,new Float32Array(e)),y=n(t,new Uint16Array(r),t.ELEMENT_ARRAY_BUFFER),x=i(t,[{buffer:v,type:t.FLOAT,size:3,offset:0,stride:24},{buffer:v,type:t.FLOAT,size:3,offset:12,stride:24}],y),b=a(t);return b.attributes.position.location=0,b.attributes.normal.location=1,new o(t,v,x,b)};var n=t(\"gl-buffer\"),i=t(\"gl-vao\"),a=t(\"./shaders\").bg;function o(t,e,r,n){this.gl=t,this.buffer=e,this.vao=r,this.shader=n}var s=o.prototype;s.draw=function(t,e,r,n,i,a){for(var o=!1,s=0;s<3;++s)o=o||i[s];if(o){var l=this.gl;l.enable(l.POLYGON_OFFSET_FILL),l.polygonOffset(1,2),this.shader.bind(),this.shader.uniforms={model:t,view:e,projection:r,bounds:n,enable:i,colors:a},this.vao.bind(),this.vao.draw(this.gl.TRIANGLES,36),this.vao.unbind(),l.disable(l.POLYGON_OFFSET_FILL)}},s.dispose=function(){this.vao.dispose(),this.buffer.dispose(),this.shader.dispose()}},{\"./shaders\":258,\"gl-buffer\":263,\"gl-vao\":357}],256:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,a,p){i(s,e,t),i(s,r,s);for(var y=0,x=0;x<2;++x){u[2]=a[x][2];for(var b=0;b<2;++b){u[1]=a[b][1];for(var _=0;_<2;++_)u[0]=a[_][0],h(l[y],u,s),y+=1}}var w=-1;for(x=0;x<8;++x){for(var T=l[x][3],k=0;k<3;++k)c[x][k]=l[x][k]/T;p&&(c[x][2]*=-1),T<0&&(w<0||c[x][2]<c[w][2])&&(w=x)}if(w<0){w=0;for(var M=0;M<3;++M){for(var A=(M+2)%3,S=(M+1)%3,E=-1,L=-1,C=0;C<2;++C){var P=(O=C<<M)+(C<<A)+(1-C<<S),I=O+(1-C<<A)+(C<<S);o(c[O],c[P],c[I],f)<0||(C?E=1:L=1)}if(E<0||L<0)L>E&&(w|=1<<M);else{for(C=0;C<2;++C){P=(O=C<<M)+(C<<A)+(1-C<<S),I=O+(1-C<<A)+(C<<S);var O,z=d([l[O],l[P],l[I],l[O+(1<<A)+(1<<S)]]);C?E=z:L=z}L>E&&(w|=1<<M)}}}var D=7^w,R=-1;for(x=0;x<8;++x)x!==w&&x!==D&&(R<0||c[R][1]>c[x][1])&&(R=x);var F=-1;for(x=0;x<3;++x){if((N=R^1<<x)!==w&&N!==D)F<0&&(F=N),(S=c[N])[0]<c[F][0]&&(F=N)}var B=-1;for(x=0;x<3;++x){var N;if((N=R^1<<x)!==w&&N!==D&&N!==F)B<0&&(B=N),(S=c[N])[0]>c[B][0]&&(B=N)}var j=m;j[0]=j[1]=j[2]=0,j[n.log2(F^R)]=R&F,j[n.log2(R^B)]=R&B;var U=7^B;U===w||U===D?(U=7^F,j[n.log2(B^U)]=U&B):j[n.log2(F^U)]=U&F;var V=g,q=w;for(M=0;M<3;++M)V[M]=q&1<<M?-1:1;return v};var n=t(\"bit-twiddle\"),i=t(\"gl-mat4/multiply\"),a=t(\"split-polygon\"),o=t(\"robust-orientation\"),s=new Array(16),l=new Array(8),c=new Array(8),u=new Array(3),f=[0,0,0];function h(t,e,r){for(var n=0;n<4;++n){t[n]=r[12+n];for(var i=0;i<3;++i)t[n]+=e[i]*r[4*i+n]}}!function(){for(var t=0;t<8;++t)l[t]=[1,1,1,1],c[t]=[1,1,1]}();var p=[[0,0,1,0,0],[0,0,-1,1,0],[0,-1,0,1,0],[0,1,0,1,0],[-1,0,0,1,0],[1,0,0,1,0]];function d(t){for(var e=0;e<p.length;++e)if((t=a.positive(t,p[e])).length<3)return 0;var r=t[0],n=r[0]/r[3],i=r[1]/r[3],o=0;for(e=1;e+1<t.length;++e){var s=t[e],l=t[e+1],c=s[0]/s[3]-n,u=s[1]/s[3]-i,f=l[0]/l[3]-n,h=l[1]/l[3]-i;o+=Math.abs(c*h-u*f)}return o}var m=[1,1,1],g=[0,0,0],v={cubeEdges:m,axis:g}},{\"bit-twiddle\":104,\"gl-mat4/multiply\":297,\"robust-orientation\":544,\"split-polygon\":563}],257:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){var o=[],s=[0,0,0],l=[0,0,0],c=[0,0,0],u=[0,0,0];o.push(0,0,1,0,1,1,0,0,-1,0,0,-1,0,1,1,0,1,-1);for(var f=0;f<3;++f){for(var h=o.length/3|0,d=0;d<r[f].length;++d){var m=+r[f][d].x;o.push(m,0,1,m,1,1,m,0,-1,m,0,-1,m,1,1,m,1,-1)}var g=o.length/3|0;s[f]=h,l[f]=g-h;h=o.length/3|0;for(var v=0;v<r[f].length;++v){m=+r[f][v].x;o.push(m,0,1,m,1,1,m,0,-1,m,0,-1,m,1,1,m,1,-1)}g=o.length/3|0;c[f]=h,u[f]=g-h}var y=n(t,new Float32Array(o)),x=i(t,[{buffer:y,type:t.FLOAT,size:3,stride:0,offset:0}]),b=a(t);return b.attributes.position.location=0,new p(t,y,x,b,l,s,u,c)};var n=t(\"gl-buffer\"),i=t(\"gl-vao\"),a=t(\"./shaders\").line,o=[0,0,0],s=[0,0,0],l=[0,0,0],c=[0,0,0],u=[1,1];function f(t){return t[0]=t[1]=t[2]=0,t}function h(t,e){return t[0]=e[0],t[1]=e[1],t[2]=e[2],t}function p(t,e,r,n,i,a,o,s){this.gl=t,this.vertBuffer=e,this.vao=r,this.shader=n,this.tickCount=i,this.tickOffset=a,this.gridCount=o,this.gridOffset=s}var d=p.prototype;d.bind=function(t,e,r){this.shader.bind(),this.shader.uniforms.model=t,this.shader.uniforms.view=e,this.shader.uniforms.projection=r,u[0]=this.gl.drawingBufferWidth,u[1]=this.gl.drawingBufferHeight,this.shader.uniforms.screenShape=u,this.vao.bind()},d.unbind=function(){this.vao.unbind()},d.drawAxisLine=function(t,e,r,n,i){var a=f(s);this.shader.uniforms.majorAxis=s,a[t]=e[1][t]-e[0][t],this.shader.uniforms.minorAxis=a;var o,u=h(c,r);u[t]+=e[0][t],this.shader.uniforms.offset=u,this.shader.uniforms.lineWidth=i,this.shader.uniforms.color=n,(o=f(l))[(t+2)%3]=1,this.shader.uniforms.screenAxis=o,this.vao.draw(this.gl.TRIANGLES,6),(o=f(l))[(t+1)%3]=1,this.shader.uniforms.screenAxis=o,this.vao.draw(this.gl.TRIANGLES,6)},d.drawAxisTicks=function(t,e,r,n,i){if(this.tickCount[t]){var a=f(o);a[t]=1,this.shader.uniforms.majorAxis=a,this.shader.uniforms.offset=e,this.shader.uniforms.minorAxis=r,this.shader.uniforms.color=n,this.shader.uniforms.lineWidth=i;var s=f(l);s[t]=1,this.shader.uniforms.screenAxis=s,this.vao.draw(this.gl.TRIANGLES,this.tickCount[t],this.tickOffset[t])}},d.drawGrid=function(t,e,r,n,i,a){if(this.gridCount[t]){var u=f(s);u[e]=r[1][e]-r[0][e],this.shader.uniforms.minorAxis=u;var p=h(c,n);p[e]+=r[0][e],this.shader.uniforms.offset=p;var d=f(o);d[t]=1,this.shader.uniforms.majorAxis=d;var m=f(l);m[t]=1,this.shader.uniforms.screenAxis=m,this.shader.uniforms.lineWidth=a,this.shader.uniforms.color=i,this.vao.draw(this.gl.TRIANGLES,this.gridCount[t],this.gridOffset[t])}},d.drawZero=function(t,e,r,n,i,a){var o=f(s);this.shader.uniforms.majorAxis=o,o[t]=r[1][t]-r[0][t],this.shader.uniforms.minorAxis=o;var u=h(c,n);u[t]+=r[0][t],this.shader.uniforms.offset=u;var p=f(l);p[e]=1,this.shader.uniforms.screenAxis=p,this.shader.uniforms.lineWidth=a,this.shader.uniforms.color=i,this.vao.draw(this.gl.TRIANGLES,6)},d.dispose=function(){this.vao.dispose(),this.vertBuffer.dispose(),this.shader.dispose()}},{\"./shaders\":258,\"gl-buffer\":263,\"gl-vao\":357}],258:[function(t,e,r){\"use strict\";var n=t(\"glslify\"),i=t(\"gl-shader\"),a=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position;\\n\\nuniform mat4 model, view, projection;\\nuniform vec3 offset, majorAxis, minorAxis, screenAxis;\\nuniform float lineWidth;\\nuniform vec2 screenShape;\\n\\nvec3 project(vec3 p) {\\n  vec4 pp = projection * view * model * vec4(p, 1.0);\\n  return pp.xyz / max(pp.w, 0.0001);\\n}\\n\\nvoid main() {\\n  vec3 major = position.x * majorAxis;\\n  vec3 minor = position.y * minorAxis;\\n\\n  vec3 vPosition = major + minor + offset;\\n  vec3 pPosition = project(vPosition);\\n  vec3 offset = project(vPosition + screenAxis * position.z);\\n\\n  vec2 screen = normalize((offset - pPosition).xy * screenShape) / screenShape;\\n\\n  gl_Position = vec4(pPosition + vec3(0.5 * screen * lineWidth, 0), 1.0);\\n}\\n\"]),o=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nuniform vec4 color;\\nvoid main() {\\n  gl_FragColor = color;\\n}\"]);r.line=function(t){return i(t,a,o,null,[{name:\"position\",type:\"vec3\"}])};var s=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position;\\n\\nuniform mat4 model, view, projection;\\nuniform vec3 offset, axis, alignDir, alignOpt;\\nuniform float scale, angle, pixelScale;\\nuniform vec2 resolution;\\n\\nvec3 project(vec3 p) {\\n  vec4 pp = projection * view * model * vec4(p, 1.0);\\n  return pp.xyz / max(pp.w, 0.0001);\\n}\\n\\nfloat computeViewAngle(vec3 a, vec3 b) {\\n  vec3 A = project(a);\\n  vec3 B = project(b);\\n\\n  return atan(\\n    (B.y - A.y) * resolution.y,\\n    (B.x - A.x) * resolution.x\\n  );\\n}\\n\\nconst float PI = 3.141592;\\nconst float TWO_PI = 2.0 * PI;\\nconst float HALF_PI = 0.5 * PI;\\nconst float ONE_AND_HALF_PI = 1.5 * PI;\\n\\nint option = int(floor(alignOpt.x + 0.001));\\nfloat hv_ratio =       alignOpt.y;\\nbool enableAlign =    (alignOpt.z != 0.0);\\n\\nfloat mod_angle(float a) {\\n  return mod(a, PI);\\n}\\n\\nfloat positive_angle(float a) {\\n  return mod_angle((a < 0.0) ?\\n    a + TWO_PI :\\n    a\\n  );\\n}\\n\\nfloat look_upwards(float a) {\\n  float b = positive_angle(a);\\n  return ((b > HALF_PI) && (b <= ONE_AND_HALF_PI)) ?\\n    b - PI :\\n    b;\\n}\\n\\nfloat look_horizontal_or_vertical(float a, float ratio) {\\n  // ratio controls the ratio between being horizontal to (vertical + horizontal)\\n  // if ratio is set to 0.5 then it is 50%, 50%.\\n  // when using a higher ratio e.g. 0.75 the result would\\n  // likely be more horizontal than vertical.\\n\\n  float b = positive_angle(a);\\n\\n  return\\n    (b < (      ratio) * HALF_PI) ? 0.0 :\\n    (b < (2.0 - ratio) * HALF_PI) ? -HALF_PI :\\n    (b < (2.0 + ratio) * HALF_PI) ? 0.0 :\\n    (b < (4.0 - ratio) * HALF_PI) ? HALF_PI :\\n                                    0.0;\\n}\\n\\nfloat roundTo(float a, float b) {\\n  return float(b * floor((a + 0.5 * b) / b));\\n}\\n\\nfloat look_round_n_directions(float a, int n) {\\n  float b = positive_angle(a);\\n  float div = TWO_PI / float(n);\\n  float c = roundTo(b, div);\\n  return look_upwards(c);\\n}\\n\\nfloat applyAlignOption(float rawAngle, float delta) {\\n  return\\n    (option >  2) ? look_round_n_directions(rawAngle + delta, option) :       // option 3-n: round to n directions\\n    (option == 2) ? look_horizontal_or_vertical(rawAngle + delta, hv_ratio) : // horizontal or vertical\\n    (option == 1) ? rawAngle + delta :       // use free angle, and flip to align with one direction of the axis\\n    (option == 0) ? look_upwards(rawAngle) : // use free angle, and stay upwards\\n    (option ==-1) ? 0.0 :                    // useful for backward compatibility, all texts remains horizontal\\n                    rawAngle;                // otherwise return back raw input angle\\n}\\n\\nbool isAxisTitle = (axis.x == 0.0) &&\\n                   (axis.y == 0.0) &&\\n                   (axis.z == 0.0);\\n\\nvoid main() {\\n  //Compute world offset\\n  float axisDistance = position.z;\\n  vec3 dataPosition = axisDistance * axis + offset;\\n\\n  float beta = angle; // i.e. user defined attributes for each tick\\n\\n  float axisAngle;\\n  float clipAngle;\\n  float flip;\\n\\n  if (enableAlign) {\\n    axisAngle = (isAxisTitle) ? HALF_PI :\\n                      computeViewAngle(dataPosition, dataPosition + axis);\\n    clipAngle = computeViewAngle(dataPosition, dataPosition + alignDir);\\n\\n    axisAngle += (sin(axisAngle) < 0.0) ? PI : 0.0;\\n    clipAngle += (sin(clipAngle) < 0.0) ? PI : 0.0;\\n\\n    flip = (dot(vec2(cos(axisAngle), sin(axisAngle)),\\n                vec2(sin(clipAngle),-cos(clipAngle))) > 0.0) ? 1.0 : 0.0;\\n\\n    beta += applyAlignOption(clipAngle, flip * PI);\\n  }\\n\\n  //Compute plane offset\\n  vec2 planeCoord = position.xy * pixelScale;\\n\\n  mat2 planeXform = scale * mat2(\\n     cos(beta), sin(beta),\\n    -sin(beta), cos(beta)\\n  );\\n\\n  vec2 viewOffset = 2.0 * planeXform * planeCoord / resolution;\\n\\n  //Compute clip position\\n  vec3 clipPosition = project(dataPosition);\\n\\n  //Apply text offset in clip coordinates\\n  clipPosition += vec3(viewOffset, 0.0);\\n\\n  //Done\\n  gl_Position = vec4(clipPosition, 1.0);\\n}\"]),l=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nuniform vec4 color;\\nvoid main() {\\n  gl_FragColor = color;\\n}\"]);r.text=function(t){return i(t,s,l,null,[{name:\"position\",type:\"vec3\"}])};var c=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position;\\nattribute vec3 normal;\\n\\nuniform mat4 model, view, projection;\\nuniform vec3 enable;\\nuniform vec3 bounds[2];\\n\\nvarying vec3 colorChannel;\\n\\nvoid main() {\\n\\n  vec3 signAxis = sign(bounds[1] - bounds[0]);\\n\\n  vec3 realNormal = signAxis * normal;\\n\\n  if(dot(realNormal, enable) > 0.0) {\\n    vec3 minRange = min(bounds[0], bounds[1]);\\n    vec3 maxRange = max(bounds[0], bounds[1]);\\n    vec3 nPosition = mix(minRange, maxRange, 0.5 * (position + 1.0));\\n    gl_Position = projection * view * model * vec4(nPosition, 1.0);\\n  } else {\\n    gl_Position = vec4(0,0,0,0);\\n  }\\n\\n  colorChannel = abs(realNormal);\\n}\"]),u=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nuniform vec4 colors[3];\\n\\nvarying vec3 colorChannel;\\n\\nvoid main() {\\n  gl_FragColor = colorChannel.x * colors[0] +\\n                 colorChannel.y * colors[1] +\\n                 colorChannel.z * colors[2];\\n}\"]);r.bg=function(t){return i(t,c,u,null,[{name:\"position\",type:\"vec3\"},{name:\"normal\",type:\"vec3\"}])}},{\"gl-shader\":335,glslify:261}],259:[function(t,e,r){(function(r){(function(){\"use strict\";e.exports=function(t,e,r,a,s,l){var u=n(t),f=i(t,[{buffer:u,size:3}]),h=o(t);h.attributes.position.location=0;var p=new c(t,h,u,f);return p.update(e,r,a,s,l),p};var n=t(\"gl-buffer\"),i=t(\"gl-vao\"),a=t(\"vectorize-text\"),o=t(\"./shaders\").text,s=window||r.global||{},l=s.__TEXT_CACHE||{};s.__TEXT_CACHE={};function c(t,e,r,n){this.gl=t,this.shader=e,this.buffer=r,this.vao=n,this.tickOffset=this.tickCount=this.labelOffset=this.labelCount=null}var u=c.prototype,f=[0,0];u.bind=function(t,e,r,n){this.vao.bind(),this.shader.bind();var i=this.shader.uniforms;i.model=t,i.view=e,i.projection=r,i.pixelScale=n,f[0]=this.gl.drawingBufferWidth,f[1]=this.gl.drawingBufferHeight,this.shader.uniforms.resolution=f},u.unbind=function(){this.vao.unbind()},u.update=function(t,e,r,n,i){var o=[];function s(t,e,r,n,i,s){var c=l[r];c||(c=l[r]={});var u=c[e];u||(u=c[e]=function(t,e){try{return a(t,e)}catch(e){return console.warn('error vectorizing text:\"'+t+'\" error:',e),{cells:[],positions:[]}}}(e,{triangles:!0,font:r,textAlign:\"center\",textBaseline:\"middle\",lineSpacing:i,styletags:s}));for(var f=(n||12)/12,h=u.positions,p=u.cells,d=0,m=p.length;d<m;++d)for(var g=p[d],v=2;v>=0;--v){var y=h[g[v]];o.push(f*y[0],-f*y[1],t)}}for(var c=[0,0,0],u=[0,0,0],f=[0,0,0],h=[0,0,0],p={breaklines:!0,bolds:!0,italics:!0,subscripts:!0,superscripts:!0},d=0;d<3;++d){f[d]=o.length/3|0,s(.5*(t[0][d]+t[1][d]),e[d],r[d],12,1.25,p),h[d]=(o.length/3|0)-f[d],c[d]=o.length/3|0;for(var m=0;m<n[d].length;++m)n[d][m].text&&s(n[d][m].x,n[d][m].text,n[d][m].font||i,n[d][m].fontSize||12,1.25,p);u[d]=(o.length/3|0)-c[d]}this.buffer.update(o),this.tickOffset=c,this.tickCount=u,this.labelOffset=f,this.labelCount=h},u.drawTicks=function(t,e,r,n,i,a,o,s){this.tickCount[t]&&(this.shader.uniforms.axis=a,this.shader.uniforms.color=i,this.shader.uniforms.angle=r,this.shader.uniforms.scale=e,this.shader.uniforms.offset=n,this.shader.uniforms.alignDir=o,this.shader.uniforms.alignOpt=s,this.vao.draw(this.gl.TRIANGLES,this.tickCount[t],this.tickOffset[t]))},u.drawLabel=function(t,e,r,n,i,a,o,s){this.labelCount[t]&&(this.shader.uniforms.axis=a,this.shader.uniforms.color=i,this.shader.uniforms.angle=r,this.shader.uniforms.scale=e,this.shader.uniforms.offset=n,this.shader.uniforms.alignDir=o,this.shader.uniforms.alignOpt=s,this.vao.draw(this.gl.TRIANGLES,this.labelCount[t],this.labelOffset[t]))},u.dispose=function(){this.shader.dispose(),this.vao.dispose(),this.buffer.dispose()}}).call(this)}).call(this,t(\"_process\"))},{\"./shaders\":258,_process:524,\"gl-buffer\":263,\"gl-vao\":357,\"vectorize-text\":619}],260:[function(t,e,r){\"use strict\";function n(t,e){var r=t+\"\",n=r.indexOf(\".\"),i=0;n>=0&&(i=r.length-n-1);var a=Math.pow(10,i),o=Math.round(t*e*a),s=o+\"\";if(s.indexOf(\"e\")>=0)return s;var l=o/a,c=o%a;o<0?(l=0|-Math.ceil(l),c=0|-c):(l=0|Math.floor(l),c|=0);var u=\"\"+l;if(o<0&&(u=\"-\"+u),i){for(var f=\"\"+c;f.length<i;)f=\"0\"+f;return u+\".\"+f}return u}r.create=function(t,e){for(var r=[],i=0;i<3;++i){for(var a=[],o=(t[0][i],t[1][i],0);o*e[i]<=t[1][i];++o)a.push({x:o*e[i],text:n(e[i],o)});for(o=-1;o*e[i]>=t[0][i];--o)a.push({x:o*e[i],text:n(e[i],o)});r.push(a)}return r},r.equal=function(t,e){for(var r=0;r<3;++r){if(t[r].length!==e[r].length)return!1;for(var n=0;n<t[r].length;++n){var i=t[r][n],a=e[r][n];if(i.x!==a.x||i.text!==a.text||i.font!==a.font||i.fontColor!==a.fontColor||i.fontSize!==a.fontSize||i.dx!==a.dx||i.dy!==a.dy)return!1}}return!0}},{}],261:[function(t,e,r){e.exports=function(t){\"string\"==typeof t&&(t=[t]);for(var e=[].slice.call(arguments,1),r=[],n=0;n<t.length-1;n++)r.push(t[n],e[n]||\"\");return r.push(t[n]),r.join(\"\")}},{}],262:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,l,f){var h=e.model||c,p=e.view||c,v=e.projection||c,y=e._ortho||!1,x=t.bounds,b=(f=f||a(h,p,v,x,y)).axis;o(u,p,h),o(u,v,u);for(var _=m,w=0;w<3;++w)_[w].lo=1/0,_[w].hi=-1/0,_[w].pixelsPerDataUnit=1/0;var T=n(s(u,u));s(u,u);for(var k=0;k<3;++k){var M=(k+1)%3,A=(k+2)%3,S=g;t:for(w=0;w<2;++w){var E=[];if(b[k]<0!=!!w){S[k]=x[w][k];for(var L=0;L<2;++L){S[M]=x[L^w][M];for(var C=0;C<2;++C)S[A]=x[C^L^w][A],E.push(S.slice())}var P=y?5:4;for(L=P;L===P;++L){if(0===E.length)continue t;E=i.positive(E,T[L])}for(L=0;L<E.length;++L){A=E[L];var I=d(g,u,A,r,l);for(C=0;C<3;++C)_[C].lo=Math.min(_[C].lo,A[C]),_[C].hi=Math.max(_[C].hi,A[C]),C!==k&&(_[C].pixelsPerDataUnit=Math.min(_[C].pixelsPerDataUnit,Math.abs(I[C])))}}}}return _};var n=t(\"extract-frustum-planes\"),i=t(\"split-polygon\"),a=t(\"./lib/cube.js\"),o=t(\"gl-mat4/multiply\"),s=t(\"gl-mat4/transpose\"),l=t(\"gl-vec4/transformMat4\"),c=new Float32Array([1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1]),u=new Float32Array(16);function f(t,e,r){this.lo=t,this.hi=e,this.pixelsPerDataUnit=r}var h=[0,0,0,1],p=[0,0,0,1];function d(t,e,r,n,i){for(var a=0;a<3;++a){for(var o=h,s=p,c=0;c<3;++c)s[c]=o[c]=r[c];s[3]=o[3]=1,s[a]+=1,l(s,s,e),s[3]<0&&(t[a]=1/0),o[a]-=1,l(o,o,e),o[3]<0&&(t[a]=1/0);var u=(o[0]/o[3]-s[0]/s[3])*n,f=(o[1]/o[3]-s[1]/s[3])*i;t[a]=.25*Math.sqrt(u*u+f*f)}return t}var m=[new f(1/0,-1/0,1/0),new f(1/0,-1/0,1/0),new f(1/0,-1/0,1/0)],g=[0,0,0]},{\"./lib/cube.js\":256,\"extract-frustum-planes\":244,\"gl-mat4/multiply\":297,\"gl-mat4/transpose\":308,\"gl-vec4/transformMat4\":428,\"split-polygon\":563}],263:[function(t,e,r){\"use strict\";var n=t(\"typedarray-pool\"),i=t(\"ndarray-ops\"),a=t(\"ndarray\"),o=[\"uint8\",\"uint8_clamped\",\"uint16\",\"uint32\",\"int8\",\"int16\",\"int32\",\"float32\"];function s(t,e,r,n,i){this.gl=t,this.type=e,this.handle=r,this.length=n,this.usage=i}var l=s.prototype;function c(t,e,r,n,i,a){var o=i.length*i.BYTES_PER_ELEMENT;if(a<0)return t.bufferData(e,i,n),o;if(o+a>r)throw new Error(\"gl-buffer: If resizing buffer, must not specify offset\");return t.bufferSubData(e,a,i),r}function u(t,e){for(var r=n.malloc(t.length,e),i=t.length,a=0;a<i;++a)r[a]=t[a];return r}l.bind=function(){this.gl.bindBuffer(this.type,this.handle)},l.unbind=function(){this.gl.bindBuffer(this.type,null)},l.dispose=function(){this.gl.deleteBuffer(this.handle)},l.update=function(t,e){if(\"number\"!=typeof e&&(e=-1),this.bind(),\"object\"==typeof t&&void 0!==t.shape){var r=t.dtype;if(o.indexOf(r)<0&&(r=\"float32\"),this.type===this.gl.ELEMENT_ARRAY_BUFFER)r=gl.getExtension(\"OES_element_index_uint\")&&\"uint16\"!==r?\"uint32\":\"uint16\";if(r===t.dtype&&function(t,e){for(var r=1,n=e.length-1;n>=0;--n){if(e[n]!==r)return!1;r*=t[n]}return!0}(t.shape,t.stride))0===t.offset&&t.data.length===t.shape[0]?this.length=c(this.gl,this.type,this.length,this.usage,t.data,e):this.length=c(this.gl,this.type,this.length,this.usage,t.data.subarray(t.offset,t.shape[0]),e);else{var s=n.malloc(t.size,r),l=a(s,t.shape);i.assign(l,t),this.length=c(this.gl,this.type,this.length,this.usage,e<0?s:s.subarray(0,t.size),e),n.free(s)}}else if(Array.isArray(t)){var f;f=this.type===this.gl.ELEMENT_ARRAY_BUFFER?u(t,\"uint16\"):u(t,\"float32\"),this.length=c(this.gl,this.type,this.length,this.usage,e<0?f:f.subarray(0,t.length),e),n.free(f)}else if(\"object\"==typeof t&&\"number\"==typeof t.length)this.length=c(this.gl,this.type,this.length,this.usage,t,e);else{if(\"number\"!=typeof t&&void 0!==t)throw new Error(\"gl-buffer: Invalid data type\");if(e>=0)throw new Error(\"gl-buffer: Cannot specify offset when resizing buffer\");(t|=0)<=0&&(t=1),this.gl.bufferData(this.type,0|t,this.usage),this.length=t}},e.exports=function(t,e,r,n){if(r=r||t.ARRAY_BUFFER,n=n||t.DYNAMIC_DRAW,r!==t.ARRAY_BUFFER&&r!==t.ELEMENT_ARRAY_BUFFER)throw new Error(\"gl-buffer: Invalid type for webgl buffer, must be either gl.ARRAY_BUFFER or gl.ELEMENT_ARRAY_BUFFER\");if(n!==t.DYNAMIC_DRAW&&n!==t.STATIC_DRAW&&n!==t.STREAM_DRAW)throw new Error(\"gl-buffer: Invalid usage for buffer, must be either gl.DYNAMIC_DRAW, gl.STATIC_DRAW or gl.STREAM_DRAW\");var i=t.createBuffer(),a=new s(t,r,i,0,n);return a.update(e),a}},{ndarray:479,\"ndarray-ops\":474,\"typedarray-pool\":613}],264:[function(t,e,r){\"use strict\";var n=t(\"gl-vec3\");e.exports=function(t,e){var r=t.positions,i=t.vectors,a={positions:[],vertexIntensity:[],vertexIntensityBounds:t.vertexIntensityBounds,vectors:[],cells:[],coneOffset:t.coneOffset,colormap:t.colormap};if(0===t.positions.length)return e&&(e[0]=[0,0,0],e[1]=[0,0,0]),a;for(var o=0,s=1/0,l=-1/0,c=1/0,u=-1/0,f=1/0,h=-1/0,p=null,d=null,m=[],g=1/0,v=!1,y=0;y<r.length;y++){var x=r[y];s=Math.min(x[0],s),l=Math.max(x[0],l),c=Math.min(x[1],c),u=Math.max(x[1],u),f=Math.min(x[2],f),h=Math.max(x[2],h);var b=i[y];if(n.length(b)>o&&(o=n.length(b)),y){var _=2*n.distance(p,x)/(n.length(d)+n.length(b));_?(g=Math.min(g,_),v=!1):v=!0}v||(p=x,d=b),m.push(b)}var w=[s,c,f],T=[l,u,h];e&&(e[0]=w,e[1]=T),0===o&&(o=1);var k=1/o;isFinite(g)||(g=1),a.vectorScale=g;var M=t.coneSize||.5;t.absoluteConeSize&&(M=t.absoluteConeSize*k),a.coneScale=M;y=0;for(var A=0;y<r.length;y++)for(var S=(x=r[y])[0],E=x[1],L=x[2],C=m[y],P=n.length(C)*k,I=0;I<8;I++){a.positions.push([S,E,L,A++]),a.positions.push([S,E,L,A++]),a.positions.push([S,E,L,A++]),a.positions.push([S,E,L,A++]),a.positions.push([S,E,L,A++]),a.positions.push([S,E,L,A++]),a.vectors.push(C),a.vectors.push(C),a.vectors.push(C),a.vectors.push(C),a.vectors.push(C),a.vectors.push(C),a.vertexIntensity.push(P,P,P),a.vertexIntensity.push(P,P,P);var O=a.positions.length;a.cells.push([O-6,O-5,O-4],[O-3,O-2,O-1])}return a};var i=t(\"./lib/shaders\");e.exports.createMesh=t(\"./create_mesh\"),e.exports.createConeMesh=function(t,r){return e.exports.createMesh(t,r,{shaders:i,traceType:\"cone\"})}},{\"./create_mesh\":265,\"./lib/shaders\":266,\"gl-vec3\":376}],265:[function(t,e,r){\"use strict\";var n=t(\"gl-shader\"),i=t(\"gl-buffer\"),a=t(\"gl-vao\"),o=t(\"gl-texture2d\"),s=t(\"gl-mat4/multiply\"),l=t(\"gl-mat4/invert\"),c=t(\"ndarray\"),u=t(\"colormap\"),f=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1];function h(t,e,r,n,i,a,o,s,l,c,u){this.gl=t,this.pixelRatio=1,this.cells=[],this.positions=[],this.intensity=[],this.texture=e,this.dirty=!0,this.triShader=r,this.pickShader=n,this.trianglePositions=i,this.triangleVectors=a,this.triangleColors=s,this.triangleUVs=l,this.triangleIds=o,this.triangleVAO=c,this.triangleCount=0,this.pickId=1,this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],this.clipBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.lightPosition=[1e5,1e5,0],this.ambientLight=.8,this.diffuseLight=.8,this.specularLight=2,this.roughness=.5,this.fresnel=1.5,this.opacity=1,this.traceType=u,this.tubeScale=1,this.coneScale=2,this.vectorScale=1,this.coneOffset=.25,this._model=f,this._view=f,this._projection=f,this._resolution=[1,1]}var p=h.prototype;function d(t,e){var r=n(t,e.meshShader.vertex,e.meshShader.fragment,null,e.meshShader.attributes);return r.attributes.position.location=0,r.attributes.color.location=2,r.attributes.uv.location=3,r.attributes.vector.location=4,r}function m(t,e){var r=n(t,e.pickShader.vertex,e.pickShader.fragment,null,e.pickShader.attributes);return r.attributes.position.location=0,r.attributes.id.location=1,r.attributes.vector.location=4,r}p.isOpaque=function(){return this.opacity>=1},p.isTransparent=function(){return this.opacity<1},p.pickSlots=1,p.setPickBase=function(t){this.pickId=t},p.update=function(t){t=t||{};var e=this.gl;this.dirty=!0,\"lightPosition\"in t&&(this.lightPosition=t.lightPosition),\"opacity\"in t&&(this.opacity=t.opacity),\"ambient\"in t&&(this.ambientLight=t.ambient),\"diffuse\"in t&&(this.diffuseLight=t.diffuse),\"specular\"in t&&(this.specularLight=t.specular),\"roughness\"in t&&(this.roughness=t.roughness),\"fresnel\"in t&&(this.fresnel=t.fresnel),void 0!==t.tubeScale&&(this.tubeScale=t.tubeScale),void 0!==t.vectorScale&&(this.vectorScale=t.vectorScale),void 0!==t.coneScale&&(this.coneScale=t.coneScale),void 0!==t.coneOffset&&(this.coneOffset=t.coneOffset),t.colormap&&(this.texture.shape=[256,256],this.texture.minFilter=e.LINEAR_MIPMAP_LINEAR,this.texture.magFilter=e.LINEAR,this.texture.setPixels(function(t){for(var e=u({colormap:t,nshades:256,format:\"rgba\"}),r=new Uint8Array(1024),n=0;n<256;++n){for(var i=e[n],a=0;a<3;++a)r[4*n+a]=i[a];r[4*n+3]=255*i[3]}return c(r,[256,256,4],[4,0,1])}(t.colormap)),this.texture.generateMipmap());var r=t.cells,n=t.positions,i=t.vectors;if(n&&r&&i){var a=[],o=[],s=[],l=[],f=[];this.cells=r,this.positions=n,this.vectors=i;var h=t.meshColor||[1,1,1,1],p=t.vertexIntensity,d=1/0,m=-1/0;if(p)if(t.vertexIntensityBounds)d=+t.vertexIntensityBounds[0],m=+t.vertexIntensityBounds[1];else for(var g=0;g<p.length;++g){var v=p[g];d=Math.min(d,v),m=Math.max(m,v)}else for(g=0;g<n.length;++g){v=n[g][2];d=Math.min(d,v),m=Math.max(m,v)}this.intensity=p||function(t){for(var e=t.length,r=new Array(e),n=0;n<e;++n)r[n]=t[n][2];return r}(n),this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]];for(g=0;g<n.length;++g)for(var y=n[g],x=0;x<3;++x)!isNaN(y[x])&&isFinite(y[x])&&(this.bounds[0][x]=Math.min(this.bounds[0][x],y[x]),this.bounds[1][x]=Math.max(this.bounds[1][x],y[x]));var b=0;t:for(g=0;g<r.length;++g){var _=r[g];switch(_.length){case 3:for(x=0;x<3;++x){y=n[T=_[x]];for(var w=0;w<3;++w)if(isNaN(y[w])||!isFinite(y[w]))continue t}for(x=0;x<3;++x){var T;y=n[T=_[2-x]];a.push(y[0],y[1],y[2],y[3]);var k=i[T];o.push(k[0],k[1],k[2],k[3]||0);var M,A=h;3===A.length?s.push(A[0],A[1],A[2],1):s.push(A[0],A[1],A[2],A[3]),M=p?[(p[T]-d)/(m-d),0]:[(y[2]-d)/(m-d),0],l.push(M[0],M[1]),f.push(g)}b+=1}}this.triangleCount=b,this.trianglePositions.update(a),this.triangleVectors.update(o),this.triangleColors.update(s),this.triangleUVs.update(l),this.triangleIds.update(new Uint32Array(f))}},p.drawTransparent=p.draw=function(t){t=t||{};for(var e=this.gl,r=t.model||f,n=t.view||f,i=t.projection||f,a=[[-1e6,-1e6,-1e6],[1e6,1e6,1e6]],o=0;o<3;++o)a[0][o]=Math.max(a[0][o],this.clipBounds[0][o]),a[1][o]=Math.min(a[1][o],this.clipBounds[1][o]);var c={model:r,view:n,projection:i,inverseModel:f.slice(),clipBounds:a,kambient:this.ambientLight,kdiffuse:this.diffuseLight,kspecular:this.specularLight,roughness:this.roughness,fresnel:this.fresnel,eyePosition:[0,0,0],lightPosition:[0,0,0],opacity:this.opacity,tubeScale:this.tubeScale,vectorScale:this.vectorScale,coneScale:this.coneScale,coneOffset:this.coneOffset,texture:0};c.inverseModel=l(c.inverseModel,c.model),e.disable(e.CULL_FACE),this.texture.bind(0);var u=new Array(16);s(u,c.view,c.model),s(u,c.projection,u),l(u,u);for(o=0;o<3;++o)c.eyePosition[o]=u[12+o]/u[15];var h=u[15];for(o=0;o<3;++o)h+=this.lightPosition[o]*u[4*o+3];for(o=0;o<3;++o){for(var p=u[12+o],d=0;d<3;++d)p+=u[4*d+o]*this.lightPosition[d];c.lightPosition[o]=p/h}if(this.triangleCount>0){var m=this.triShader;m.bind(),m.uniforms=c,this.triangleVAO.bind(),e.drawArrays(e.TRIANGLES,0,3*this.triangleCount),this.triangleVAO.unbind()}},p.drawPick=function(t){t=t||{};for(var e=this.gl,r=t.model||f,n=t.view||f,i=t.projection||f,a=[[-1e6,-1e6,-1e6],[1e6,1e6,1e6]],o=0;o<3;++o)a[0][o]=Math.max(a[0][o],this.clipBounds[0][o]),a[1][o]=Math.min(a[1][o],this.clipBounds[1][o]);this._model=[].slice.call(r),this._view=[].slice.call(n),this._projection=[].slice.call(i),this._resolution=[e.drawingBufferWidth,e.drawingBufferHeight];var s={model:r,view:n,projection:i,clipBounds:a,tubeScale:this.tubeScale,vectorScale:this.vectorScale,coneScale:this.coneScale,coneOffset:this.coneOffset,pickId:this.pickId/255},l=this.pickShader;l.bind(),l.uniforms=s,this.triangleCount>0&&(this.triangleVAO.bind(),e.drawArrays(e.TRIANGLES,0,3*this.triangleCount),this.triangleVAO.unbind())},p.pick=function(t){if(!t)return null;if(t.id!==this.pickId)return null;var e=t.value[0]+256*t.value[1]+65536*t.value[2],r=this.cells[e],n=this.positions[r[1]].slice(0,3),i={position:n,dataCoordinate:n,index:Math.floor(r[1]/48)};return\"cone\"===this.traceType?i.index=Math.floor(r[1]/48):\"streamtube\"===this.traceType&&(i.intensity=this.intensity[r[1]],i.velocity=this.vectors[r[1]].slice(0,3),i.divergence=this.vectors[r[1]][3],i.index=e),i},p.dispose=function(){this.texture.dispose(),this.triShader.dispose(),this.pickShader.dispose(),this.triangleVAO.dispose(),this.trianglePositions.dispose(),this.triangleVectors.dispose(),this.triangleColors.dispose(),this.triangleUVs.dispose(),this.triangleIds.dispose()},e.exports=function(t,e,r){var n=r.shaders;1===arguments.length&&(t=(e=t).gl);var s=d(t,n),l=m(t,n),u=o(t,c(new Uint8Array([255,255,255,255]),[1,1,4]));u.generateMipmap(),u.minFilter=t.LINEAR_MIPMAP_LINEAR,u.magFilter=t.LINEAR;var f=i(t),p=i(t),g=i(t),v=i(t),y=i(t),x=a(t,[{buffer:f,type:t.FLOAT,size:4},{buffer:y,type:t.UNSIGNED_BYTE,size:4,normalized:!0},{buffer:g,type:t.FLOAT,size:4},{buffer:v,type:t.FLOAT,size:2},{buffer:p,type:t.FLOAT,size:4}]),b=new h(t,u,s,l,f,p,y,g,v,x,r.traceType||\"cone\");return b.update(e),b}},{colormap:137,\"gl-buffer\":263,\"gl-mat4/invert\":295,\"gl-mat4/multiply\":297,\"gl-shader\":335,\"gl-texture2d\":352,\"gl-vao\":357,ndarray:479}],266:[function(t,e,r){var n=t(\"glslify\"),i=n([\"precision highp float;\\n\\nprecision highp float;\\n#define GLSLIFY 1\\n\\nvec3 getOrthogonalVector(vec3 v) {\\n  // Return up-vector for only-z vector.\\n  // Return ax + by + cz = 0, a point that lies on the plane that has v as a normal and that isn't (0,0,0).\\n  // From the above if-statement we have ||a|| > 0  U  ||b|| > 0.\\n  // Assign z = 0, x = -b, y = a:\\n  // a*-b + b*a + c*0 = -ba + ba + 0 = 0\\n  if (v.x*v.x > v.z*v.z || v.y*v.y > v.z*v.z) {\\n    return normalize(vec3(-v.y, v.x, 0.0));\\n  } else {\\n    return normalize(vec3(0.0, v.z, -v.y));\\n  }\\n}\\n\\n// Calculate the cone vertex and normal at the given index.\\n//\\n// The returned vertex is for a cone with its top at origin and height of 1.0,\\n// pointing in the direction of the vector attribute.\\n//\\n// Each cone is made up of a top vertex, a center base vertex and base perimeter vertices.\\n// These vertices are used to make up the triangles of the cone by the following:\\n//   segment + 0 top vertex\\n//   segment + 1 perimeter vertex a+1\\n//   segment + 2 perimeter vertex a\\n//   segment + 3 center base vertex\\n//   segment + 4 perimeter vertex a\\n//   segment + 5 perimeter vertex a+1\\n// Where segment is the number of the radial segment * 6 and a is the angle at that radial segment.\\n// To go from index to segment, floor(index / 6)\\n// To go from segment to angle, 2*pi * (segment/segmentCount)\\n// To go from index to segment index, index - (segment*6)\\n//\\nvec3 getConePosition(vec3 d, float rawIndex, float coneOffset, out vec3 normal) {\\n\\n  const float segmentCount = 8.0;\\n\\n  float index = rawIndex - floor(rawIndex /\\n    (segmentCount * 6.0)) *\\n    (segmentCount * 6.0);\\n\\n  float segment = floor(0.001 + index/6.0);\\n  float segmentIndex = index - (segment*6.0);\\n\\n  normal = -normalize(d);\\n\\n  if (segmentIndex > 2.99 && segmentIndex < 3.01) {\\n    return mix(vec3(0.0), -d, coneOffset);\\n  }\\n\\n  float nextAngle = (\\n    (segmentIndex > 0.99 &&  segmentIndex < 1.01) ||\\n    (segmentIndex > 4.99 &&  segmentIndex < 5.01)\\n  ) ? 1.0 : 0.0;\\n  float angle = 2.0 * 3.14159 * ((segment + nextAngle) / segmentCount);\\n\\n  vec3 v1 = mix(d, vec3(0.0), coneOffset);\\n  vec3 v2 = v1 - d;\\n\\n  vec3 u = getOrthogonalVector(d);\\n  vec3 v = normalize(cross(u, d));\\n\\n  vec3 x = u * cos(angle) * length(d)*0.25;\\n  vec3 y = v * sin(angle) * length(d)*0.25;\\n  vec3 v3 = v2 + x + y;\\n  if (segmentIndex < 3.0) {\\n    vec3 tx = u * sin(angle);\\n    vec3 ty = v * -cos(angle);\\n    vec3 tangent = tx + ty;\\n    normal = normalize(cross(v3 - v1, tangent));\\n  }\\n\\n  if (segmentIndex == 0.0) {\\n    return mix(d, vec3(0.0), coneOffset);\\n  }\\n  return v3;\\n}\\n\\nattribute vec3 vector;\\nattribute vec4 color, position;\\nattribute vec2 uv;\\n\\nuniform float vectorScale, coneScale, coneOffset;\\nuniform mat4 model, view, projection, inverseModel;\\nuniform vec3 eyePosition, lightPosition;\\n\\nvarying vec3 f_normal, f_lightDirection, f_eyeDirection, f_data, f_position;\\nvarying vec4 f_color;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  // Scale the vector magnitude to stay constant with\\n  // model & view changes.\\n  vec3 normal;\\n  vec3 XYZ = getConePosition(mat3(model) * ((vectorScale * coneScale) * vector), position.w, coneOffset, normal);\\n  vec4 conePosition = model * vec4(position.xyz, 1.0) + vec4(XYZ, 0.0);\\n\\n  //Lighting geometry parameters\\n  vec4 cameraCoordinate = view * conePosition;\\n  cameraCoordinate.xyz /= cameraCoordinate.w;\\n  f_lightDirection = lightPosition - cameraCoordinate.xyz;\\n  f_eyeDirection   = eyePosition - cameraCoordinate.xyz;\\n  f_normal = normalize((vec4(normal, 0.0) * inverseModel).xyz);\\n\\n  // vec4 m_position  = model * vec4(conePosition, 1.0);\\n  vec4 t_position  = view * conePosition;\\n  gl_Position      = projection * t_position;\\n\\n  f_color          = color;\\n  f_data           = conePosition.xyz;\\n  f_position       = position.xyz;\\n  f_uv             = uv;\\n}\\n\"]),a=n([\"#extension GL_OES_standard_derivatives : enable\\n\\nprecision highp float;\\n#define GLSLIFY 1\\n\\nfloat beckmannDistribution(float x, float roughness) {\\n  float NdotH = max(x, 0.0001);\\n  float cos2Alpha = NdotH * NdotH;\\n  float tan2Alpha = (cos2Alpha - 1.0) / cos2Alpha;\\n  float roughness2 = roughness * roughness;\\n  float denom = 3.141592653589793 * roughness2 * cos2Alpha * cos2Alpha;\\n  return exp(tan2Alpha / roughness2) / denom;\\n}\\n\\nfloat cookTorranceSpecular(\\n  vec3 lightDirection,\\n  vec3 viewDirection,\\n  vec3 surfaceNormal,\\n  float roughness,\\n  float fresnel) {\\n\\n  float VdotN = max(dot(viewDirection, surfaceNormal), 0.0);\\n  float LdotN = max(dot(lightDirection, surfaceNormal), 0.0);\\n\\n  //Half angle vector\\n  vec3 H = normalize(lightDirection + viewDirection);\\n\\n  //Geometric term\\n  float NdotH = max(dot(surfaceNormal, H), 0.0);\\n  float VdotH = max(dot(viewDirection, H), 0.000001);\\n  float LdotH = max(dot(lightDirection, H), 0.000001);\\n  float G1 = (2.0 * NdotH * VdotN) / VdotH;\\n  float G2 = (2.0 * NdotH * LdotN) / LdotH;\\n  float G = min(1.0, min(G1, G2));\\n  \\n  //Distribution term\\n  float D = beckmannDistribution(NdotH, roughness);\\n\\n  //Fresnel term\\n  float F = pow(1.0 - VdotN, fresnel);\\n\\n  //Multiply terms and done\\n  return  G * F * D / max(3.14159265 * VdotN, 0.000001);\\n}\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3 clipBounds[2];\\nuniform float roughness, fresnel, kambient, kdiffuse, kspecular, opacity;\\nuniform sampler2D texture;\\n\\nvarying vec3 f_normal, f_lightDirection, f_eyeDirection, f_data, f_position;\\nvarying vec4 f_color;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], f_position)) discard;\\n  vec3 N = normalize(f_normal);\\n  vec3 L = normalize(f_lightDirection);\\n  vec3 V = normalize(f_eyeDirection);\\n\\n  if(gl_FrontFacing) {\\n    N = -N;\\n  }\\n\\n  float specular = min(1.0, max(0.0, cookTorranceSpecular(L, V, N, roughness, fresnel)));\\n  float diffuse  = min(kambient + kdiffuse * max(dot(N, L), 0.0), 1.0);\\n\\n  vec4 surfaceColor = f_color * texture2D(texture, f_uv);\\n  vec4 litColor = surfaceColor.a * vec4(diffuse * surfaceColor.rgb + kspecular * vec3(1,1,1) * specular,  1.0);\\n\\n  gl_FragColor = litColor * opacity;\\n}\\n\"]),o=n([\"precision highp float;\\n\\nprecision highp float;\\n#define GLSLIFY 1\\n\\nvec3 getOrthogonalVector(vec3 v) {\\n  // Return up-vector for only-z vector.\\n  // Return ax + by + cz = 0, a point that lies on the plane that has v as a normal and that isn't (0,0,0).\\n  // From the above if-statement we have ||a|| > 0  U  ||b|| > 0.\\n  // Assign z = 0, x = -b, y = a:\\n  // a*-b + b*a + c*0 = -ba + ba + 0 = 0\\n  if (v.x*v.x > v.z*v.z || v.y*v.y > v.z*v.z) {\\n    return normalize(vec3(-v.y, v.x, 0.0));\\n  } else {\\n    return normalize(vec3(0.0, v.z, -v.y));\\n  }\\n}\\n\\n// Calculate the cone vertex and normal at the given index.\\n//\\n// The returned vertex is for a cone with its top at origin and height of 1.0,\\n// pointing in the direction of the vector attribute.\\n//\\n// Each cone is made up of a top vertex, a center base vertex and base perimeter vertices.\\n// These vertices are used to make up the triangles of the cone by the following:\\n//   segment + 0 top vertex\\n//   segment + 1 perimeter vertex a+1\\n//   segment + 2 perimeter vertex a\\n//   segment + 3 center base vertex\\n//   segment + 4 perimeter vertex a\\n//   segment + 5 perimeter vertex a+1\\n// Where segment is the number of the radial segment * 6 and a is the angle at that radial segment.\\n// To go from index to segment, floor(index / 6)\\n// To go from segment to angle, 2*pi * (segment/segmentCount)\\n// To go from index to segment index, index - (segment*6)\\n//\\nvec3 getConePosition(vec3 d, float rawIndex, float coneOffset, out vec3 normal) {\\n\\n  const float segmentCount = 8.0;\\n\\n  float index = rawIndex - floor(rawIndex /\\n    (segmentCount * 6.0)) *\\n    (segmentCount * 6.0);\\n\\n  float segment = floor(0.001 + index/6.0);\\n  float segmentIndex = index - (segment*6.0);\\n\\n  normal = -normalize(d);\\n\\n  if (segmentIndex > 2.99 && segmentIndex < 3.01) {\\n    return mix(vec3(0.0), -d, coneOffset);\\n  }\\n\\n  float nextAngle = (\\n    (segmentIndex > 0.99 &&  segmentIndex < 1.01) ||\\n    (segmentIndex > 4.99 &&  segmentIndex < 5.01)\\n  ) ? 1.0 : 0.0;\\n  float angle = 2.0 * 3.14159 * ((segment + nextAngle) / segmentCount);\\n\\n  vec3 v1 = mix(d, vec3(0.0), coneOffset);\\n  vec3 v2 = v1 - d;\\n\\n  vec3 u = getOrthogonalVector(d);\\n  vec3 v = normalize(cross(u, d));\\n\\n  vec3 x = u * cos(angle) * length(d)*0.25;\\n  vec3 y = v * sin(angle) * length(d)*0.25;\\n  vec3 v3 = v2 + x + y;\\n  if (segmentIndex < 3.0) {\\n    vec3 tx = u * sin(angle);\\n    vec3 ty = v * -cos(angle);\\n    vec3 tangent = tx + ty;\\n    normal = normalize(cross(v3 - v1, tangent));\\n  }\\n\\n  if (segmentIndex == 0.0) {\\n    return mix(d, vec3(0.0), coneOffset);\\n  }\\n  return v3;\\n}\\n\\nattribute vec4 vector;\\nattribute vec4 position;\\nattribute vec4 id;\\n\\nuniform mat4 model, view, projection;\\nuniform float vectorScale, coneScale, coneOffset;\\n\\nvarying vec3 f_position;\\nvarying vec4 f_id;\\n\\nvoid main() {\\n  vec3 normal;\\n  vec3 XYZ = getConePosition(mat3(model) * ((vectorScale * coneScale) * vector.xyz), position.w, coneOffset, normal);\\n  vec4 conePosition = model * vec4(position.xyz, 1.0) + vec4(XYZ, 0.0);\\n  gl_Position = projection * view * conePosition;\\n  f_id        = id;\\n  f_position  = position.xyz;\\n}\\n\"]),s=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3  clipBounds[2];\\nuniform float pickId;\\n\\nvarying vec3 f_position;\\nvarying vec4 f_id;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], f_position)) discard;\\n\\n  gl_FragColor = vec4(pickId, f_id.xyz);\\n}\"]);r.meshShader={vertex:i,fragment:a,attributes:[{name:\"position\",type:\"vec4\"},{name:\"color\",type:\"vec4\"},{name:\"uv\",type:\"vec2\"},{name:\"vector\",type:\"vec3\"}]},r.pickShader={vertex:o,fragment:s,attributes:[{name:\"position\",type:\"vec4\"},{name:\"id\",type:\"vec4\"},{name:\"vector\",type:\"vec3\"}]}},{glslify:438}],267:[function(t,e,r){e.exports={0:\"NONE\",1:\"ONE\",2:\"LINE_LOOP\",3:\"LINE_STRIP\",4:\"TRIANGLES\",5:\"TRIANGLE_STRIP\",6:\"TRIANGLE_FAN\",256:\"DEPTH_BUFFER_BIT\",512:\"NEVER\",513:\"LESS\",514:\"EQUAL\",515:\"LEQUAL\",516:\"GREATER\",517:\"NOTEQUAL\",518:\"GEQUAL\",519:\"ALWAYS\",768:\"SRC_COLOR\",769:\"ONE_MINUS_SRC_COLOR\",770:\"SRC_ALPHA\",771:\"ONE_MINUS_SRC_ALPHA\",772:\"DST_ALPHA\",773:\"ONE_MINUS_DST_ALPHA\",774:\"DST_COLOR\",775:\"ONE_MINUS_DST_COLOR\",776:\"SRC_ALPHA_SATURATE\",1024:\"STENCIL_BUFFER_BIT\",1028:\"FRONT\",1029:\"BACK\",1032:\"FRONT_AND_BACK\",1280:\"INVALID_ENUM\",1281:\"INVALID_VALUE\",1282:\"INVALID_OPERATION\",1285:\"OUT_OF_MEMORY\",1286:\"INVALID_FRAMEBUFFER_OPERATION\",2304:\"CW\",2305:\"CCW\",2849:\"LINE_WIDTH\",2884:\"CULL_FACE\",2885:\"CULL_FACE_MODE\",2886:\"FRONT_FACE\",2928:\"DEPTH_RANGE\",2929:\"DEPTH_TEST\",2930:\"DEPTH_WRITEMASK\",2931:\"DEPTH_CLEAR_VALUE\",2932:\"DEPTH_FUNC\",2960:\"STENCIL_TEST\",2961:\"STENCIL_CLEAR_VALUE\",2962:\"STENCIL_FUNC\",2963:\"STENCIL_VALUE_MASK\",2964:\"STENCIL_FAIL\",2965:\"STENCIL_PASS_DEPTH_FAIL\",2966:\"STENCIL_PASS_DEPTH_PASS\",2967:\"STENCIL_REF\",2968:\"STENCIL_WRITEMASK\",2978:\"VIEWPORT\",3024:\"DITHER\",3042:\"BLEND\",3088:\"SCISSOR_BOX\",3089:\"SCISSOR_TEST\",3106:\"COLOR_CLEAR_VALUE\",3107:\"COLOR_WRITEMASK\",3317:\"UNPACK_ALIGNMENT\",3333:\"PACK_ALIGNMENT\",3379:\"MAX_TEXTURE_SIZE\",3386:\"MAX_VIEWPORT_DIMS\",3408:\"SUBPIXEL_BITS\",3410:\"RED_BITS\",3411:\"GREEN_BITS\",3412:\"BLUE_BITS\",3413:\"ALPHA_BITS\",3414:\"DEPTH_BITS\",3415:\"STENCIL_BITS\",3553:\"TEXTURE_2D\",4352:\"DONT_CARE\",4353:\"FASTEST\",4354:\"NICEST\",5120:\"BYTE\",5121:\"UNSIGNED_BYTE\",5122:\"SHORT\",5123:\"UNSIGNED_SHORT\",5124:\"INT\",5125:\"UNSIGNED_INT\",5126:\"FLOAT\",5386:\"INVERT\",5890:\"TEXTURE\",6401:\"STENCIL_INDEX\",6402:\"DEPTH_COMPONENT\",6406:\"ALPHA\",6407:\"RGB\",6408:\"RGBA\",6409:\"LUMINANCE\",6410:\"LUMINANCE_ALPHA\",7680:\"KEEP\",7681:\"REPLACE\",7682:\"INCR\",7683:\"DECR\",7936:\"VENDOR\",7937:\"RENDERER\",7938:\"VERSION\",9728:\"NEAREST\",9729:\"LINEAR\",9984:\"NEAREST_MIPMAP_NEAREST\",9985:\"LINEAR_MIPMAP_NEAREST\",9986:\"NEAREST_MIPMAP_LINEAR\",9987:\"LINEAR_MIPMAP_LINEAR\",10240:\"TEXTURE_MAG_FILTER\",10241:\"TEXTURE_MIN_FILTER\",10242:\"TEXTURE_WRAP_S\",10243:\"TEXTURE_WRAP_T\",10497:\"REPEAT\",10752:\"POLYGON_OFFSET_UNITS\",16384:\"COLOR_BUFFER_BIT\",32769:\"CONSTANT_COLOR\",32770:\"ONE_MINUS_CONSTANT_COLOR\",32771:\"CONSTANT_ALPHA\",32772:\"ONE_MINUS_CONSTANT_ALPHA\",32773:\"BLEND_COLOR\",32774:\"FUNC_ADD\",32777:\"BLEND_EQUATION_RGB\",32778:\"FUNC_SUBTRACT\",32779:\"FUNC_REVERSE_SUBTRACT\",32819:\"UNSIGNED_SHORT_4_4_4_4\",32820:\"UNSIGNED_SHORT_5_5_5_1\",32823:\"POLYGON_OFFSET_FILL\",32824:\"POLYGON_OFFSET_FACTOR\",32854:\"RGBA4\",32855:\"RGB5_A1\",32873:\"TEXTURE_BINDING_2D\",32926:\"SAMPLE_ALPHA_TO_COVERAGE\",32928:\"SAMPLE_COVERAGE\",32936:\"SAMPLE_BUFFERS\",32937:\"SAMPLES\",32938:\"SAMPLE_COVERAGE_VALUE\",32939:\"SAMPLE_COVERAGE_INVERT\",32968:\"BLEND_DST_RGB\",32969:\"BLEND_SRC_RGB\",32970:\"BLEND_DST_ALPHA\",32971:\"BLEND_SRC_ALPHA\",33071:\"CLAMP_TO_EDGE\",33170:\"GENERATE_MIPMAP_HINT\",33189:\"DEPTH_COMPONENT16\",33306:\"DEPTH_STENCIL_ATTACHMENT\",33635:\"UNSIGNED_SHORT_5_6_5\",33648:\"MIRRORED_REPEAT\",33901:\"ALIASED_POINT_SIZE_RANGE\",33902:\"ALIASED_LINE_WIDTH_RANGE\",33984:\"TEXTURE0\",33985:\"TEXTURE1\",33986:\"TEXTURE2\",33987:\"TEXTURE3\",33988:\"TEXTURE4\",33989:\"TEXTURE5\",33990:\"TEXTURE6\",33991:\"TEXTURE7\",33992:\"TEXTURE8\",33993:\"TEXTURE9\",33994:\"TEXTURE10\",33995:\"TEXTURE11\",33996:\"TEXTURE12\",33997:\"TEXTURE13\",33998:\"TEXTURE14\",33999:\"TEXTURE15\",34e3:\"TEXTURE16\",34001:\"TEXTURE17\",34002:\"TEXTURE18\",34003:\"TEXTURE19\",34004:\"TEXTURE20\",34005:\"TEXTURE21\",34006:\"TEXTURE22\",34007:\"TEXTURE23\",34008:\"TEXTURE24\",34009:\"TEXTURE25\",34010:\"TEXTURE26\",34011:\"TEXTURE27\",34012:\"TEXTURE28\",34013:\"TEXTURE29\",34014:\"TEXTURE30\",34015:\"TEXTURE31\",34016:\"ACTIVE_TEXTURE\",34024:\"MAX_RENDERBUFFER_SIZE\",34041:\"DEPTH_STENCIL\",34055:\"INCR_WRAP\",34056:\"DECR_WRAP\",34067:\"TEXTURE_CUBE_MAP\",34068:\"TEXTURE_BINDING_CUBE_MAP\",34069:\"TEXTURE_CUBE_MAP_POSITIVE_X\",34070:\"TEXTURE_CUBE_MAP_NEGATIVE_X\",34071:\"TEXTURE_CUBE_MAP_POSITIVE_Y\",34072:\"TEXTURE_CUBE_MAP_NEGATIVE_Y\",34073:\"TEXTURE_CUBE_MAP_POSITIVE_Z\",34074:\"TEXTURE_CUBE_MAP_NEGATIVE_Z\",34076:\"MAX_CUBE_MAP_TEXTURE_SIZE\",34338:\"VERTEX_ATTRIB_ARRAY_ENABLED\",34339:\"VERTEX_ATTRIB_ARRAY_SIZE\",34340:\"VERTEX_ATTRIB_ARRAY_STRIDE\",34341:\"VERTEX_ATTRIB_ARRAY_TYPE\",34342:\"CURRENT_VERTEX_ATTRIB\",34373:\"VERTEX_ATTRIB_ARRAY_POINTER\",34466:\"NUM_COMPRESSED_TEXTURE_FORMATS\",34467:\"COMPRESSED_TEXTURE_FORMATS\",34660:\"BUFFER_SIZE\",34661:\"BUFFER_USAGE\",34816:\"STENCIL_BACK_FUNC\",34817:\"STENCIL_BACK_FAIL\",34818:\"STENCIL_BACK_PASS_DEPTH_FAIL\",34819:\"STENCIL_BACK_PASS_DEPTH_PASS\",34877:\"BLEND_EQUATION_ALPHA\",34921:\"MAX_VERTEX_ATTRIBS\",34922:\"VERTEX_ATTRIB_ARRAY_NORMALIZED\",34930:\"MAX_TEXTURE_IMAGE_UNITS\",34962:\"ARRAY_BUFFER\",34963:\"ELEMENT_ARRAY_BUFFER\",34964:\"ARRAY_BUFFER_BINDING\",34965:\"ELEMENT_ARRAY_BUFFER_BINDING\",34975:\"VERTEX_ATTRIB_ARRAY_BUFFER_BINDING\",35040:\"STREAM_DRAW\",35044:\"STATIC_DRAW\",35048:\"DYNAMIC_DRAW\",35632:\"FRAGMENT_SHADER\",35633:\"VERTEX_SHADER\",35660:\"MAX_VERTEX_TEXTURE_IMAGE_UNITS\",35661:\"MAX_COMBINED_TEXTURE_IMAGE_UNITS\",35663:\"SHADER_TYPE\",35664:\"FLOAT_VEC2\",35665:\"FLOAT_VEC3\",35666:\"FLOAT_VEC4\",35667:\"INT_VEC2\",35668:\"INT_VEC3\",35669:\"INT_VEC4\",35670:\"BOOL\",35671:\"BOOL_VEC2\",35672:\"BOOL_VEC3\",35673:\"BOOL_VEC4\",35674:\"FLOAT_MAT2\",35675:\"FLOAT_MAT3\",35676:\"FLOAT_MAT4\",35678:\"SAMPLER_2D\",35680:\"SAMPLER_CUBE\",35712:\"DELETE_STATUS\",35713:\"COMPILE_STATUS\",35714:\"LINK_STATUS\",35715:\"VALIDATE_STATUS\",35716:\"INFO_LOG_LENGTH\",35717:\"ATTACHED_SHADERS\",35718:\"ACTIVE_UNIFORMS\",35719:\"ACTIVE_UNIFORM_MAX_LENGTH\",35720:\"SHADER_SOURCE_LENGTH\",35721:\"ACTIVE_ATTRIBUTES\",35722:\"ACTIVE_ATTRIBUTE_MAX_LENGTH\",35724:\"SHADING_LANGUAGE_VERSION\",35725:\"CURRENT_PROGRAM\",36003:\"STENCIL_BACK_REF\",36004:\"STENCIL_BACK_VALUE_MASK\",36005:\"STENCIL_BACK_WRITEMASK\",36006:\"FRAMEBUFFER_BINDING\",36007:\"RENDERBUFFER_BINDING\",36048:\"FRAMEBUFFER_ATTACHMENT_OBJECT_TYPE\",36049:\"FRAMEBUFFER_ATTACHMENT_OBJECT_NAME\",36050:\"FRAMEBUFFER_ATTACHMENT_TEXTURE_LEVEL\",36051:\"FRAMEBUFFER_ATTACHMENT_TEXTURE_CUBE_MAP_FACE\",36053:\"FRAMEBUFFER_COMPLETE\",36054:\"FRAMEBUFFER_INCOMPLETE_ATTACHMENT\",36055:\"FRAMEBUFFER_INCOMPLETE_MISSING_ATTACHMENT\",36057:\"FRAMEBUFFER_INCOMPLETE_DIMENSIONS\",36061:\"FRAMEBUFFER_UNSUPPORTED\",36064:\"COLOR_ATTACHMENT0\",36096:\"DEPTH_ATTACHMENT\",36128:\"STENCIL_ATTACHMENT\",36160:\"FRAMEBUFFER\",36161:\"RENDERBUFFER\",36162:\"RENDERBUFFER_WIDTH\",36163:\"RENDERBUFFER_HEIGHT\",36164:\"RENDERBUFFER_INTERNAL_FORMAT\",36168:\"STENCIL_INDEX8\",36176:\"RENDERBUFFER_RED_SIZE\",36177:\"RENDERBUFFER_GREEN_SIZE\",36178:\"RENDERBUFFER_BLUE_SIZE\",36179:\"RENDERBUFFER_ALPHA_SIZE\",36180:\"RENDERBUFFER_DEPTH_SIZE\",36181:\"RENDERBUFFER_STENCIL_SIZE\",36194:\"RGB565\",36336:\"LOW_FLOAT\",36337:\"MEDIUM_FLOAT\",36338:\"HIGH_FLOAT\",36339:\"LOW_INT\",36340:\"MEDIUM_INT\",36341:\"HIGH_INT\",36346:\"SHADER_COMPILER\",36347:\"MAX_VERTEX_UNIFORM_VECTORS\",36348:\"MAX_VARYING_VECTORS\",36349:\"MAX_FRAGMENT_UNIFORM_VECTORS\",37440:\"UNPACK_FLIP_Y_WEBGL\",37441:\"UNPACK_PREMULTIPLY_ALPHA_WEBGL\",37442:\"CONTEXT_LOST_WEBGL\",37443:\"UNPACK_COLORSPACE_CONVERSION_WEBGL\",37444:\"BROWSER_DEFAULT_WEBGL\"}},{}],268:[function(t,e,r){var n=t(\"./1.0/numbers\");e.exports=function(t){return n[t]}},{\"./1.0/numbers\":267}],269:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.gl,r=n(e),o=i(e,[{buffer:r,type:e.FLOAT,size:3,offset:0,stride:40},{buffer:r,type:e.FLOAT,size:4,offset:12,stride:40},{buffer:r,type:e.FLOAT,size:3,offset:28,stride:40}]),l=a(e);l.attributes.position.location=0,l.attributes.color.location=1,l.attributes.offset.location=2;var c=new s(e,r,o,l);return c.update(t),c};var n=t(\"gl-buffer\"),i=t(\"gl-vao\"),a=t(\"./shaders/index\"),o=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1];function s(t,e,r,n){this.gl=t,this.shader=n,this.buffer=e,this.vao=r,this.pixelRatio=1,this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],this.clipBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.lineWidth=[1,1,1],this.capSize=[10,10,10],this.lineCount=[0,0,0],this.lineOffset=[0,0,0],this.opacity=1,this.hasAlpha=!1}var l=s.prototype;function c(t,e){for(var r=0;r<3;++r)t[0][r]=Math.min(t[0][r],e[r]),t[1][r]=Math.max(t[1][r],e[r])}l.isOpaque=function(){return!this.hasAlpha},l.isTransparent=function(){return this.hasAlpha},l.drawTransparent=l.draw=function(t){var e=this.gl,r=this.shader.uniforms;this.shader.bind();var n=r.view=t.view||o,i=r.projection=t.projection||o;r.model=t.model||o,r.clipBounds=this.clipBounds,r.opacity=this.opacity;var a=n[12],s=n[13],l=n[14],c=n[15],u=(t._ortho||!1?2:1)*this.pixelRatio*(i[3]*a+i[7]*s+i[11]*l+i[15]*c)/e.drawingBufferHeight;this.vao.bind();for(var f=0;f<3;++f)e.lineWidth(this.lineWidth[f]*this.pixelRatio),r.capSize=this.capSize[f]*u,this.lineCount[f]&&e.drawArrays(e.LINES,this.lineOffset[f],this.lineCount[f]);this.vao.unbind()};var u=function(){for(var t=new Array(3),e=0;e<3;++e){for(var r=[],n=1;n<=2;++n)for(var i=-1;i<=1;i+=2){var a=[0,0,0];a[(n+e)%3]=i,r.push(a)}t[e]=r}return t}();function f(t,e,r,n){for(var i=u[n],a=0;a<i.length;++a){var o=i[a];t.push(e[0],e[1],e[2],r[0],r[1],r[2],r[3],o[0],o[1],o[2])}return i.length}l.update=function(t){\"lineWidth\"in(t=t||{})&&(this.lineWidth=t.lineWidth,Array.isArray(this.lineWidth)||(this.lineWidth=[this.lineWidth,this.lineWidth,this.lineWidth])),\"capSize\"in t&&(this.capSize=t.capSize,Array.isArray(this.capSize)||(this.capSize=[this.capSize,this.capSize,this.capSize])),this.hasAlpha=!1,\"opacity\"in t&&(this.opacity=+t.opacity,this.opacity<1&&(this.hasAlpha=!0));var e=t.color||[[0,0,0],[0,0,0],[0,0,0]],r=t.position,n=t.error;if(Array.isArray(e[0])||(e=[e,e,e]),r&&n){var i=[],a=r.length,o=0;this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],this.lineCount=[0,0,0];for(var s=0;s<3;++s){this.lineOffset[s]=o;t:for(var l=0;l<a;++l){for(var u=r[l],h=0;h<3;++h)if(isNaN(u[h])||!isFinite(u[h]))continue t;var p=n[l],d=e[s];if(Array.isArray(d[0])&&(d=e[l]),3===d.length?d=[d[0],d[1],d[2],1]:4===d.length&&(d=[d[0],d[1],d[2],d[3]],!this.hasAlpha&&d[3]<1&&(this.hasAlpha=!0)),!isNaN(p[0][s])&&!isNaN(p[1][s])){var m;if(p[0][s]<0)(m=u.slice())[s]+=p[0][s],i.push(u[0],u[1],u[2],d[0],d[1],d[2],d[3],0,0,0,m[0],m[1],m[2],d[0],d[1],d[2],d[3],0,0,0),c(this.bounds,m),o+=2+f(i,m,d,s);if(p[1][s]>0)(m=u.slice())[s]+=p[1][s],i.push(u[0],u[1],u[2],d[0],d[1],d[2],d[3],0,0,0,m[0],m[1],m[2],d[0],d[1],d[2],d[3],0,0,0),c(this.bounds,m),o+=2+f(i,m,d,s)}}this.lineCount[s]=o-this.lineOffset[s]}this.buffer.update(i)}},l.dispose=function(){this.shader.dispose(),this.buffer.dispose(),this.vao.dispose()}},{\"./shaders/index\":271,\"gl-buffer\":263,\"gl-vao\":357}],270:[function(t,e,r){arguments[4][261][0].apply(r,arguments)},{dup:261}],271:[function(t,e,r){\"use strict\";var n=t(\"glslify\"),i=t(\"gl-shader\"),a=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position, offset;\\nattribute vec4 color;\\nuniform mat4 model, view, projection;\\nuniform float capSize;\\nvarying vec4 fragColor;\\nvarying vec3 fragPosition;\\n\\nvoid main() {\\n  vec4 worldPosition  = model * vec4(position, 1.0);\\n  worldPosition       = (worldPosition / worldPosition.w) + vec4(capSize * offset, 0.0);\\n  gl_Position         = projection * view * worldPosition;\\n  fragColor           = color;\\n  fragPosition        = position;\\n}\"]),o=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3 clipBounds[2];\\nuniform float opacity;\\nvarying vec3 fragPosition;\\nvarying vec4 fragColor;\\n\\nvoid main() {\\n  if (\\n    outOfRange(clipBounds[0], clipBounds[1], fragPosition) ||\\n    fragColor.a * opacity == 0.\\n  ) discard;\\n\\n  gl_FragColor = opacity * fragColor;\\n}\"]);e.exports=function(t){return i(t,a,o,null,[{name:\"position\",type:\"vec3\"},{name:\"color\",type:\"vec4\"},{name:\"offset\",type:\"vec3\"}])}},{\"gl-shader\":335,glslify:270}],272:[function(t,e,r){\"use strict\";var n=t(\"gl-texture2d\");e.exports=function(t,e,r,n){i||(i=t.FRAMEBUFFER_UNSUPPORTED,a=t.FRAMEBUFFER_INCOMPLETE_ATTACHMENT,o=t.FRAMEBUFFER_INCOMPLETE_DIMENSIONS,s=t.FRAMEBUFFER_INCOMPLETE_MISSING_ATTACHMENT);var c=t.getExtension(\"WEBGL_draw_buffers\");!l&&c&&function(t,e){var r=t.getParameter(e.MAX_COLOR_ATTACHMENTS_WEBGL);l=new Array(r+1);for(var n=0;n<=r;++n){for(var i=new Array(r),a=0;a<n;++a)i[a]=t.COLOR_ATTACHMENT0+a;for(a=n;a<r;++a)i[a]=t.NONE;l[n]=i}}(t,c);Array.isArray(e)&&(n=r,r=0|e[1],e=0|e[0]);if(\"number\"!=typeof e)throw new Error(\"gl-fbo: Missing shape parameter\");var u=t.getParameter(t.MAX_RENDERBUFFER_SIZE);if(e<0||e>u||r<0||r>u)throw new Error(\"gl-fbo: Parameters are too large for FBO\");var f=1;if(\"color\"in(n=n||{})){if((f=Math.max(0|n.color,0))<0)throw new Error(\"gl-fbo: Must specify a nonnegative number of colors\");if(f>1){if(!c)throw new Error(\"gl-fbo: Multiple draw buffer extension not supported\");if(f>t.getParameter(c.MAX_COLOR_ATTACHMENTS_WEBGL))throw new Error(\"gl-fbo: Context does not support \"+f+\" draw buffers\")}}var h=t.UNSIGNED_BYTE,p=t.getExtension(\"OES_texture_float\");if(n.float&&f>0){if(!p)throw new Error(\"gl-fbo: Context does not support floating point textures\");h=t.FLOAT}else n.preferFloat&&f>0&&p&&(h=t.FLOAT);var m=!0;\"depth\"in n&&(m=!!n.depth);var g=!1;\"stencil\"in n&&(g=!!n.stencil);return new d(t,e,r,h,f,m,g,c)};var i,a,o,s,l=null;function c(t){return[t.getParameter(t.FRAMEBUFFER_BINDING),t.getParameter(t.RENDERBUFFER_BINDING),t.getParameter(t.TEXTURE_BINDING_2D)]}function u(t,e){t.bindFramebuffer(t.FRAMEBUFFER,e[0]),t.bindRenderbuffer(t.RENDERBUFFER,e[1]),t.bindTexture(t.TEXTURE_2D,e[2])}function f(t){switch(t){case i:throw new Error(\"gl-fbo: Framebuffer unsupported\");case a:throw new Error(\"gl-fbo: Framebuffer incomplete attachment\");case o:throw new Error(\"gl-fbo: Framebuffer incomplete dimensions\");case s:throw new Error(\"gl-fbo: Framebuffer incomplete missing attachment\");default:throw new Error(\"gl-fbo: Framebuffer failed for unspecified reason\")}}function h(t,e,r,i,a,o){if(!i)return null;var s=n(t,e,r,a,i);return s.magFilter=t.NEAREST,s.minFilter=t.NEAREST,s.mipSamples=1,s.bind(),t.framebufferTexture2D(t.FRAMEBUFFER,o,t.TEXTURE_2D,s.handle,0),s}function p(t,e,r,n,i){var a=t.createRenderbuffer();return t.bindRenderbuffer(t.RENDERBUFFER,a),t.renderbufferStorage(t.RENDERBUFFER,n,e,r),t.framebufferRenderbuffer(t.FRAMEBUFFER,i,t.RENDERBUFFER,a),a}function d(t,e,r,n,i,a,o,s){this.gl=t,this._shape=[0|e,0|r],this._destroyed=!1,this._ext=s,this.color=new Array(i);for(var d=0;d<i;++d)this.color[d]=null;this._color_rb=null,this.depth=null,this._depth_rb=null,this._colorType=n,this._useDepth=a,this._useStencil=o;var m=this,g=[0|e,0|r];Object.defineProperties(g,{0:{get:function(){return m._shape[0]},set:function(t){return m.width=t}},1:{get:function(){return m._shape[1]},set:function(t){return m.height=t}}}),this._shapeVector=g,function(t){var e=c(t.gl),r=t.gl,n=t.handle=r.createFramebuffer(),i=t._shape[0],a=t._shape[1],o=t.color.length,s=t._ext,d=t._useStencil,m=t._useDepth,g=t._colorType;r.bindFramebuffer(r.FRAMEBUFFER,n);for(var v=0;v<o;++v)t.color[v]=h(r,i,a,g,r.RGBA,r.COLOR_ATTACHMENT0+v);0===o?(t._color_rb=p(r,i,a,r.RGBA4,r.COLOR_ATTACHMENT0),s&&s.drawBuffersWEBGL(l[0])):o>1&&s.drawBuffersWEBGL(l[o]);var y=r.getExtension(\"WEBGL_depth_texture\");y?d?t.depth=h(r,i,a,y.UNSIGNED_INT_24_8_WEBGL,r.DEPTH_STENCIL,r.DEPTH_STENCIL_ATTACHMENT):m&&(t.depth=h(r,i,a,r.UNSIGNED_SHORT,r.DEPTH_COMPONENT,r.DEPTH_ATTACHMENT)):m&&d?t._depth_rb=p(r,i,a,r.DEPTH_STENCIL,r.DEPTH_STENCIL_ATTACHMENT):m?t._depth_rb=p(r,i,a,r.DEPTH_COMPONENT16,r.DEPTH_ATTACHMENT):d&&(t._depth_rb=p(r,i,a,r.STENCIL_INDEX,r.STENCIL_ATTACHMENT));var x=r.checkFramebufferStatus(r.FRAMEBUFFER);if(x!==r.FRAMEBUFFER_COMPLETE){t._destroyed=!0,r.bindFramebuffer(r.FRAMEBUFFER,null),r.deleteFramebuffer(t.handle),t.handle=null,t.depth&&(t.depth.dispose(),t.depth=null),t._depth_rb&&(r.deleteRenderbuffer(t._depth_rb),t._depth_rb=null);for(v=0;v<t.color.length;++v)t.color[v].dispose(),t.color[v]=null;t._color_rb&&(r.deleteRenderbuffer(t._color_rb),t._color_rb=null),u(r,e),f(x)}u(r,e)}(this)}var m=d.prototype;function g(t,e,r){if(t._destroyed)throw new Error(\"gl-fbo: Can't resize destroyed FBO\");if(t._shape[0]!==e||t._shape[1]!==r){var n=t.gl,i=n.getParameter(n.MAX_RENDERBUFFER_SIZE);if(e<0||e>i||r<0||r>i)throw new Error(\"gl-fbo: Can't resize FBO, invalid dimensions\");t._shape[0]=e,t._shape[1]=r;for(var a=c(n),o=0;o<t.color.length;++o)t.color[o].shape=t._shape;t._color_rb&&(n.bindRenderbuffer(n.RENDERBUFFER,t._color_rb),n.renderbufferStorage(n.RENDERBUFFER,n.RGBA4,t._shape[0],t._shape[1])),t.depth&&(t.depth.shape=t._shape),t._depth_rb&&(n.bindRenderbuffer(n.RENDERBUFFER,t._depth_rb),t._useDepth&&t._useStencil?n.renderbufferStorage(n.RENDERBUFFER,n.DEPTH_STENCIL,t._shape[0],t._shape[1]):t._useDepth?n.renderbufferStorage(n.RENDERBUFFER,n.DEPTH_COMPONENT16,t._shape[0],t._shape[1]):t._useStencil&&n.renderbufferStorage(n.RENDERBUFFER,n.STENCIL_INDEX,t._shape[0],t._shape[1])),n.bindFramebuffer(n.FRAMEBUFFER,t.handle);var s=n.checkFramebufferStatus(n.FRAMEBUFFER);s!==n.FRAMEBUFFER_COMPLETE&&(t.dispose(),u(n,a),f(s)),u(n,a)}}Object.defineProperties(m,{shape:{get:function(){return this._destroyed?[0,0]:this._shapeVector},set:function(t){if(Array.isArray(t)||(t=[0|t,0|t]),2!==t.length)throw new Error(\"gl-fbo: Shape vector must be length 2\");var e=0|t[0],r=0|t[1];return g(this,e,r),[e,r]},enumerable:!1},width:{get:function(){return this._destroyed?0:this._shape[0]},set:function(t){return g(this,t|=0,this._shape[1]),t},enumerable:!1},height:{get:function(){return this._destroyed?0:this._shape[1]},set:function(t){return t|=0,g(this,this._shape[0],t),t},enumerable:!1}}),m.bind=function(){if(!this._destroyed){var t=this.gl;t.bindFramebuffer(t.FRAMEBUFFER,this.handle),t.viewport(0,0,this._shape[0],this._shape[1])}},m.dispose=function(){if(!this._destroyed){this._destroyed=!0;var t=this.gl;t.deleteFramebuffer(this.handle),this.handle=null,this.depth&&(this.depth.dispose(),this.depth=null),this._depth_rb&&(t.deleteRenderbuffer(this._depth_rb),this._depth_rb=null);for(var e=0;e<this.color.length;++e)this.color[e].dispose(),this.color[e]=null;this._color_rb&&(t.deleteRenderbuffer(this._color_rb),this._color_rb=null)}}},{\"gl-texture2d\":352}],273:[function(t,e,r){var n=t(\"sprintf-js\").sprintf,i=t(\"gl-constants/lookup\"),a=t(\"glsl-shader-name\"),o=t(\"add-line-numbers\");e.exports=function(t,e,r){\"use strict\";var s=a(e)||\"of unknown name (see npm glsl-shader-name)\",l=\"unknown type\";void 0!==r&&(l=r===i.FRAGMENT_SHADER?\"fragment\":\"vertex\");for(var c=n(\"Error compiling %s shader %s:\\n\",l,s),u=n(\"%s%s\",c,t),f=t.split(\"\\n\"),h={},p=0;p<f.length;p++){var d=f[p];if(\"\"!==d&&\"\\0\"!==d){var m=parseInt(d.split(\":\")[2]);if(isNaN(m))throw new Error(n(\"Could not parse error: %s\",d));h[m]=d}}var g=o(e).split(\"\\n\");for(p=0;p<g.length;p++)if(h[p+3]||h[p+2]||h[p+1]){var v=g[p];if(c+=v+\"\\n\",h[p+1]){var y=h[p+1];y=y.substr(y.split(\":\",3).join(\":\").length+1).trim(),c+=n(\"^^^ %s\\n\\n\",y)}}return{long:c.trim(),short:u.trim()}}},{\"add-line-numbers\":72,\"gl-constants/lookup\":268,\"glsl-shader-name\":430,\"sprintf-js\":564}],274:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=t.gl,n=o(r,l.vertex,l.fragment),i=o(r,l.pickVertex,l.pickFragment),a=s(r),u=s(r),f=s(r),h=s(r),p=new c(t,n,i,a,u,f,h);return p.update(e),t.addObject(p),p};var n=t(\"binary-search-bounds\"),i=t(\"iota-array\"),a=t(\"typedarray-pool\"),o=t(\"gl-shader\"),s=t(\"gl-buffer\"),l=t(\"./lib/shaders\");function c(t,e,r,n,i,a,o){this.plot=t,this.shader=e,this.pickShader=r,this.positionBuffer=n,this.weightBuffer=i,this.colorBuffer=a,this.idBuffer=o,this.xData=[],this.yData=[],this.shape=[0,0],this.bounds=[1/0,1/0,-1/0,-1/0],this.pickOffset=0}var u,f=c.prototype,h=[0,0,1,0,0,1,1,0,1,1,0,1];f.draw=(u=[1,0,0,0,1,0,0,0,1],function(){var t=this.plot,e=this.shader,r=this.bounds,n=this.numVertices;if(!(n<=0)){var i=t.gl,a=t.dataBox,o=r[2]-r[0],s=r[3]-r[1],l=a[2]-a[0],c=a[3]-a[1];u[0]=2*o/l,u[4]=2*s/c,u[6]=2*(r[0]-a[0])/l-1,u[7]=2*(r[1]-a[1])/c-1,e.bind();var f=e.uniforms;f.viewTransform=u,f.shape=this.shape;var h=e.attributes;this.positionBuffer.bind(),h.position.pointer(),this.weightBuffer.bind(),h.weight.pointer(i.UNSIGNED_BYTE,!1),this.colorBuffer.bind(),h.color.pointer(i.UNSIGNED_BYTE,!0),i.drawArrays(i.TRIANGLES,0,n)}}),f.drawPick=function(){var t=[1,0,0,0,1,0,0,0,1],e=[0,0,0,0];return function(r){var n=this.plot,i=this.pickShader,a=this.bounds,o=this.numVertices;if(!(o<=0)){var s=n.gl,l=n.dataBox,c=a[2]-a[0],u=a[3]-a[1],f=l[2]-l[0],h=l[3]-l[1];t[0]=2*c/f,t[4]=2*u/h,t[6]=2*(a[0]-l[0])/f-1,t[7]=2*(a[1]-l[1])/h-1;for(var p=0;p<4;++p)e[p]=r>>8*p&255;this.pickOffset=r,i.bind();var d=i.uniforms;d.viewTransform=t,d.pickOffset=e,d.shape=this.shape;var m=i.attributes;return this.positionBuffer.bind(),m.position.pointer(),this.weightBuffer.bind(),m.weight.pointer(s.UNSIGNED_BYTE,!1),this.idBuffer.bind(),m.pickId.pointer(s.UNSIGNED_BYTE,!1),s.drawArrays(s.TRIANGLES,0,o),r+this.shape[0]*this.shape[1]}}}(),f.pick=function(t,e,r){var n=this.pickOffset,i=this.shape[0]*this.shape[1];if(r<n||r>=n+i)return null;var a=r-n,o=this.xData,s=this.yData;return{object:this,pointId:a,dataCoord:[o[a%this.shape[0]],s[a/this.shape[0]|0]]}},f.update=function(t){var e=(t=t||{}).shape||[0,0],r=t.x||i(e[0]),o=t.y||i(e[1]),s=t.z||new Float32Array(e[0]*e[1]),l=!1!==t.zsmooth;this.xData=r,this.yData=o;var c,u,f,p,d=t.colorLevels||[0],m=t.colorValues||[0,0,0,1],g=d.length,v=this.bounds;l?(c=v[0]=r[0],u=v[1]=o[0],f=v[2]=r[r.length-1],p=v[3]=o[o.length-1]):(c=v[0]=r[0]+(r[1]-r[0])/2,u=v[1]=o[0]+(o[1]-o[0])/2,f=v[2]=r[r.length-1]+(r[r.length-1]-r[r.length-2])/2,p=v[3]=o[o.length-1]+(o[o.length-1]-o[o.length-2])/2);var y=1/(f-c),x=1/(p-u),b=e[0],_=e[1];this.shape=[b,_];var w=(l?(b-1)*(_-1):b*_)*(h.length>>>1);this.numVertices=w;for(var T=a.mallocUint8(4*w),k=a.mallocFloat32(2*w),M=a.mallocUint8(2*w),A=a.mallocUint32(w),S=0,E=l?b-1:b,L=l?_-1:_,C=0;C<L;++C){var P,I;l?(P=x*(o[C]-u),I=x*(o[C+1]-u)):(P=C<_-1?x*(o[C]-(o[C+1]-o[C])/2-u):x*(o[C]-(o[C]-o[C-1])/2-u),I=C<_-1?x*(o[C]+(o[C+1]-o[C])/2-u):x*(o[C]+(o[C]-o[C-1])/2-u));for(var O=0;O<E;++O){var z,D;l?(z=y*(r[O]-c),D=y*(r[O+1]-c)):(z=O<b-1?y*(r[O]-(r[O+1]-r[O])/2-c):y*(r[O]-(r[O]-r[O-1])/2-c),D=O<b-1?y*(r[O]+(r[O+1]-r[O])/2-c):y*(r[O]+(r[O]-r[O-1])/2-c));for(var R=0;R<h.length;R+=2){var F,B,N,j,U=h[R],V=h[R+1],q=s[l?(C+V)*b+(O+U):C*b+O],H=n.le(d,q);if(H<0)F=m[0],B=m[1],N=m[2],j=m[3];else if(H===g-1)F=m[4*g-4],B=m[4*g-3],N=m[4*g-2],j=m[4*g-1];else{var G=(q-d[H])/(d[H+1]-d[H]),Y=1-G,W=4*H,X=4*(H+1);F=Y*m[W]+G*m[X],B=Y*m[W+1]+G*m[X+1],N=Y*m[W+2]+G*m[X+2],j=Y*m[W+3]+G*m[X+3]}T[4*S]=255*F,T[4*S+1]=255*B,T[4*S+2]=255*N,T[4*S+3]=255*j,k[2*S]=.5*z+.5*D,k[2*S+1]=.5*P+.5*I,M[2*S]=U,M[2*S+1]=V,A[S]=C*b+O,S+=1}}}this.positionBuffer.update(k),this.weightBuffer.update(M),this.colorBuffer.update(T),this.idBuffer.update(A),a.free(k),a.free(T),a.free(M),a.free(A)},f.dispose=function(){this.shader.dispose(),this.pickShader.dispose(),this.positionBuffer.dispose(),this.weightBuffer.dispose(),this.colorBuffer.dispose(),this.idBuffer.dispose(),this.plot.removeObject(this)}},{\"./lib/shaders\":275,\"binary-search-bounds\":103,\"gl-buffer\":263,\"gl-shader\":335,\"iota-array\":447,\"typedarray-pool\":613}],275:[function(t,e,r){\"use strict\";var n=t(\"glslify\");e.exports={fragment:n([\"precision lowp float;\\n#define GLSLIFY 1\\nvarying vec4 fragColor;\\nvoid main() {\\n  gl_FragColor = vec4(fragColor.rgb * fragColor.a, fragColor.a);\\n}\\n\"]),vertex:n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec2 position;\\nattribute vec4 color;\\nattribute vec2 weight;\\n\\nuniform vec2 shape;\\nuniform mat3 viewTransform;\\n\\nvarying vec4 fragColor;\\n\\nvoid main() {\\n  vec3 vPosition = viewTransform * vec3( position + (weight-.5)/(shape-1.) , 1.0);\\n  fragColor = color;\\n  gl_Position = vec4(vPosition.xy, 0, vPosition.z);\\n}\\n\"]),pickFragment:n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nvarying vec4 fragId;\\nvarying vec2 vWeight;\\n\\nuniform vec2 shape;\\nuniform vec4 pickOffset;\\n\\nvoid main() {\\n  vec2 d = step(.5, vWeight);\\n  vec4 id = fragId + pickOffset;\\n  id.x += d.x + d.y*shape.x;\\n\\n  id.y += floor(id.x / 256.0);\\n  id.x -= floor(id.x / 256.0) * 256.0;\\n\\n  id.z += floor(id.y / 256.0);\\n  id.y -= floor(id.y / 256.0) * 256.0;\\n\\n  id.w += floor(id.z / 256.0);\\n  id.z -= floor(id.z / 256.0) * 256.0;\\n\\n  gl_FragColor = id/255.;\\n}\\n\"]),pickVertex:n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec2 position;\\nattribute vec4 pickId;\\nattribute vec2 weight;\\n\\nuniform vec2 shape;\\nuniform mat3 viewTransform;\\n\\nvarying vec4 fragId;\\nvarying vec2 vWeight;\\n\\nvoid main() {\\n  vWeight = weight;\\n\\n  fragId = pickId;\\n\\n  vec3 vPosition = viewTransform * vec3( position + (weight-.5)/(shape-1.) , 1.0);\\n  gl_Position = vec4(vPosition.xy, 0, vPosition.z);\\n}\\n\"])}},{glslify:438}],276:[function(t,e,r){var n=t(\"glslify\"),i=t(\"gl-shader\"),a=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position, nextPosition;\\nattribute float arcLength, lineWidth;\\nattribute vec4 color;\\n\\nuniform vec2 screenShape;\\nuniform float pixelRatio;\\nuniform mat4 model, view, projection;\\n\\nvarying vec4 fragColor;\\nvarying vec3 worldPosition;\\nvarying float pixelArcLength;\\n\\nvec4 project(vec3 p) {\\n  return projection * view * model * vec4(p, 1.0);\\n}\\n\\nvoid main() {\\n  vec4 startPoint = project(position);\\n  vec4 endPoint   = project(nextPosition);\\n\\n  vec2 A = startPoint.xy / startPoint.w;\\n  vec2 B =   endPoint.xy /   endPoint.w;\\n\\n  float clipAngle = atan(\\n    (B.y - A.y) * screenShape.y,\\n    (B.x - A.x) * screenShape.x\\n  );\\n\\n  vec2 offset = 0.5 * pixelRatio * lineWidth * vec2(\\n    sin(clipAngle),\\n    -cos(clipAngle)\\n  ) / screenShape;\\n\\n  gl_Position = vec4(startPoint.xy + startPoint.w * offset, startPoint.zw);\\n\\n  worldPosition = position;\\n  pixelArcLength = arcLength;\\n  fragColor = color;\\n}\\n\"]),o=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3      clipBounds[2];\\nuniform sampler2D dashTexture;\\nuniform float     dashScale;\\nuniform float     opacity;\\n\\nvarying vec3    worldPosition;\\nvarying float   pixelArcLength;\\nvarying vec4    fragColor;\\n\\nvoid main() {\\n  if (\\n    outOfRange(clipBounds[0], clipBounds[1], worldPosition) ||\\n    fragColor.a * opacity == 0.\\n  ) discard;\\n\\n  float dashWeight = texture2D(dashTexture, vec2(dashScale * pixelArcLength, 0)).r;\\n  if(dashWeight < 0.5) {\\n    discard;\\n  }\\n  gl_FragColor = fragColor * opacity;\\n}\\n\"]),s=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\n#define FLOAT_MAX  1.70141184e38\\n#define FLOAT_MIN  1.17549435e-38\\n\\n// https://github.com/mikolalysenko/glsl-read-float/blob/master/index.glsl\\nvec4 packFloat(float v) {\\n  float av = abs(v);\\n\\n  //Handle special cases\\n  if(av < FLOAT_MIN) {\\n    return vec4(0.0, 0.0, 0.0, 0.0);\\n  } else if(v > FLOAT_MAX) {\\n    return vec4(127.0, 128.0, 0.0, 0.0) / 255.0;\\n  } else if(v < -FLOAT_MAX) {\\n    return vec4(255.0, 128.0, 0.0, 0.0) / 255.0;\\n  }\\n\\n  vec4 c = vec4(0,0,0,0);\\n\\n  //Compute exponent and mantissa\\n  float e = floor(log2(av));\\n  float m = av * pow(2.0, -e) - 1.0;\\n\\n  //Unpack mantissa\\n  c[1] = floor(128.0 * m);\\n  m -= c[1] / 128.0;\\n  c[2] = floor(32768.0 * m);\\n  m -= c[2] / 32768.0;\\n  c[3] = floor(8388608.0 * m);\\n\\n  //Unpack exponent\\n  float ebias = e + 127.0;\\n  c[0] = floor(ebias / 2.0);\\n  ebias -= c[0] * 2.0;\\n  c[1] += floor(ebias) * 128.0;\\n\\n  //Unpack sign bit\\n  c[0] += 128.0 * step(0.0, -v);\\n\\n  //Scale back to range\\n  return c / 255.0;\\n}\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform float pickId;\\nuniform vec3 clipBounds[2];\\n\\nvarying vec3 worldPosition;\\nvarying float pixelArcLength;\\nvarying vec4 fragColor;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], worldPosition)) discard;\\n\\n  gl_FragColor = vec4(pickId/255.0, packFloat(pixelArcLength).xyz);\\n}\"]),l=[{name:\"position\",type:\"vec3\"},{name:\"nextPosition\",type:\"vec3\"},{name:\"arcLength\",type:\"float\"},{name:\"lineWidth\",type:\"float\"},{name:\"color\",type:\"vec4\"}];r.createShader=function(t){return i(t,a,o,null,l)},r.createPickShader=function(t){return i(t,a,s,null,l)}},{\"gl-shader\":335,glslify:278}],277:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.gl||t.scene&&t.scene.gl,r=f(e);r.attributes.position.location=0,r.attributes.nextPosition.location=1,r.attributes.arcLength.location=2,r.attributes.lineWidth.location=3,r.attributes.color.location=4;var o=h(e);o.attributes.position.location=0,o.attributes.nextPosition.location=1,o.attributes.arcLength.location=2,o.attributes.lineWidth.location=3,o.attributes.color.location=4;for(var s=n(e),l=i(e,[{buffer:s,size:3,offset:0,stride:48},{buffer:s,size:3,offset:12,stride:48},{buffer:s,size:1,offset:24,stride:48},{buffer:s,size:1,offset:28,stride:48},{buffer:s,size:4,offset:32,stride:48}]),u=c(new Array(1024),[256,1,4]),p=0;p<1024;++p)u.data[p]=255;var d=a(e,u);d.wrap=e.REPEAT;var m=new v(e,r,o,s,l,d);return m.update(t),m};var n=t(\"gl-buffer\"),i=t(\"gl-vao\"),a=t(\"gl-texture2d\"),o=new Uint8Array(4),s=new Float32Array(o.buffer);var l=t(\"binary-search-bounds\"),c=t(\"ndarray\"),u=t(\"./lib/shaders\"),f=u.createShader,h=u.createPickShader,p=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1];function d(t,e){for(var r=0,n=0;n<3;++n){var i=t[n]-e[n];r+=i*i}return Math.sqrt(r)}function m(t){for(var e=[[-1e6,-1e6,-1e6],[1e6,1e6,1e6]],r=0;r<3;++r)e[0][r]=Math.max(t[0][r],e[0][r]),e[1][r]=Math.min(t[1][r],e[1][r]);return e}function g(t,e,r,n){this.arcLength=t,this.position=e,this.index=r,this.dataCoordinate=n}function v(t,e,r,n,i,a){this.gl=t,this.shader=e,this.pickShader=r,this.buffer=n,this.vao=i,this.clipBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.points=[],this.arcLength=[],this.vertexCount=0,this.bounds=[[0,0,0],[0,0,0]],this.pickId=0,this.lineWidth=1,this.texture=a,this.dashScale=1,this.opacity=1,this.hasAlpha=!1,this.dirty=!0,this.pixelRatio=1}var y=v.prototype;y.isTransparent=function(){return this.hasAlpha},y.isOpaque=function(){return!this.hasAlpha},y.pickSlots=1,y.setPickBase=function(t){this.pickId=t},y.drawTransparent=y.draw=function(t){if(this.vertexCount){var e=this.gl,r=this.shader,n=this.vao;r.bind(),r.uniforms={model:t.model||p,view:t.view||p,projection:t.projection||p,clipBounds:m(this.clipBounds),dashTexture:this.texture.bind(),dashScale:this.dashScale/this.arcLength[this.arcLength.length-1],opacity:this.opacity,screenShape:[e.drawingBufferWidth,e.drawingBufferHeight],pixelRatio:this.pixelRatio},n.bind(),n.draw(e.TRIANGLE_STRIP,this.vertexCount),n.unbind()}},y.drawPick=function(t){if(this.vertexCount){var e=this.gl,r=this.pickShader,n=this.vao;r.bind(),r.uniforms={model:t.model||p,view:t.view||p,projection:t.projection||p,pickId:this.pickId,clipBounds:m(this.clipBounds),screenShape:[e.drawingBufferWidth,e.drawingBufferHeight],pixelRatio:this.pixelRatio},n.bind(),n.draw(e.TRIANGLE_STRIP,this.vertexCount),n.unbind()}},y.update=function(t){var e,r;this.dirty=!0;var n=!!t.connectGaps;\"dashScale\"in t&&(this.dashScale=t.dashScale),this.hasAlpha=!1,\"opacity\"in t&&(this.opacity=+t.opacity,this.opacity<1&&(this.hasAlpha=!0));var i=[],a=[],o=[],s=0,u=0,f=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],h=t.position||t.positions;if(h){var p=t.color||t.colors||[0,0,0,1],m=t.lineWidth||1,g=!1;t:for(e=1;e<h.length;++e){var v,y,x,b=h[e-1],_=h[e];for(a.push(s),o.push(b.slice()),r=0;r<3;++r){if(isNaN(b[r])||isNaN(_[r])||!isFinite(b[r])||!isFinite(_[r])){if(!n&&i.length>0){for(var w=0;w<24;++w)i.push(i[i.length-12]);u+=2,g=!0}continue t}f[0][r]=Math.min(f[0][r],b[r],_[r]),f[1][r]=Math.max(f[1][r],b[r],_[r])}Array.isArray(p[0])?(v=p.length>e-1?p[e-1]:p.length>0?p[p.length-1]:[0,0,0,1],y=p.length>e?p[e]:p.length>0?p[p.length-1]:[0,0,0,1]):v=y=p,3===v.length&&(v=[v[0],v[1],v[2],1]),3===y.length&&(y=[y[0],y[1],y[2],1]),!this.hasAlpha&&v[3]<1&&(this.hasAlpha=!0),x=Array.isArray(m)?m.length>e-1?m[e-1]:m.length>0?m[m.length-1]:[0,0,0,1]:m;var T=s;if(s+=d(b,_),g){for(r=0;r<2;++r)i.push(b[0],b[1],b[2],_[0],_[1],_[2],T,x,v[0],v[1],v[2],v[3]);u+=2,g=!1}i.push(b[0],b[1],b[2],_[0],_[1],_[2],T,x,v[0],v[1],v[2],v[3],b[0],b[1],b[2],_[0],_[1],_[2],T,-x,v[0],v[1],v[2],v[3],_[0],_[1],_[2],b[0],b[1],b[2],s,-x,y[0],y[1],y[2],y[3],_[0],_[1],_[2],b[0],b[1],b[2],s,x,y[0],y[1],y[2],y[3]),u+=4}}if(this.buffer.update(i),a.push(s),o.push(h[h.length-1].slice()),this.bounds=f,this.vertexCount=u,this.points=o,this.arcLength=a,\"dashes\"in t){var k=t.dashes.slice();for(k.unshift(0),e=1;e<k.length;++e)k[e]=k[e-1]+k[e];var M=c(new Array(1024),[256,1,4]);for(e=0;e<256;++e){for(r=0;r<4;++r)M.set(e,0,r,0);1&l.le(k,k[k.length-1]*e/255)?M.set(e,0,0,0):M.set(e,0,0,255)}this.texture.setPixels(M)}},y.dispose=function(){this.shader.dispose(),this.vao.dispose(),this.buffer.dispose()},y.pick=function(t){if(!t)return null;if(t.id!==this.pickId)return null;var e=function(t,e,r,n){return o[0]=n,o[1]=r,o[2]=e,o[3]=t,s[0]}(t.value[0],t.value[1],t.value[2],0),r=l.le(this.arcLength,e);if(r<0)return null;if(r===this.arcLength.length-1)return new g(this.arcLength[this.arcLength.length-1],this.points[this.points.length-1].slice(),r);for(var n=this.points[r],i=this.points[Math.min(r+1,this.points.length-1)],a=(e-this.arcLength[r])/(this.arcLength[r+1]-this.arcLength[r]),c=1-a,u=[0,0,0],f=0;f<3;++f)u[f]=c*n[f]+a*i[f];var h=Math.min(a<.5?r:r+1,this.points.length-1);return new g(e,u,h,this.points[h])}},{\"./lib/shaders\":276,\"binary-search-bounds\":103,\"gl-buffer\":263,\"gl-texture2d\":352,\"gl-vao\":357,ndarray:479}],278:[function(t,e,r){arguments[4][261][0].apply(r,arguments)},{dup:261}],279:[function(t,e,r){e.exports=function(t,e){var r=e[0],n=e[1],i=e[2],a=e[3],o=e[4],s=e[5],l=e[6],c=e[7],u=e[8],f=e[9],h=e[10],p=e[11],d=e[12],m=e[13],g=e[14],v=e[15];return t[0]=s*(h*v-p*g)-f*(l*v-c*g)+m*(l*p-c*h),t[1]=-(n*(h*v-p*g)-f*(i*v-a*g)+m*(i*p-a*h)),t[2]=n*(l*v-c*g)-s*(i*v-a*g)+m*(i*c-a*l),t[3]=-(n*(l*p-c*h)-s*(i*p-a*h)+f*(i*c-a*l)),t[4]=-(o*(h*v-p*g)-u*(l*v-c*g)+d*(l*p-c*h)),t[5]=r*(h*v-p*g)-u*(i*v-a*g)+d*(i*p-a*h),t[6]=-(r*(l*v-c*g)-o*(i*v-a*g)+d*(i*c-a*l)),t[7]=r*(l*p-c*h)-o*(i*p-a*h)+u*(i*c-a*l),t[8]=o*(f*v-p*m)-u*(s*v-c*m)+d*(s*p-c*f),t[9]=-(r*(f*v-p*m)-u*(n*v-a*m)+d*(n*p-a*f)),t[10]=r*(s*v-c*m)-o*(n*v-a*m)+d*(n*c-a*s),t[11]=-(r*(s*p-c*f)-o*(n*p-a*f)+u*(n*c-a*s)),t[12]=-(o*(f*g-h*m)-u*(s*g-l*m)+d*(s*h-l*f)),t[13]=r*(f*g-h*m)-u*(n*g-i*m)+d*(n*h-i*f),t[14]=-(r*(s*g-l*m)-o*(n*g-i*m)+d*(n*l-i*s)),t[15]=r*(s*h-l*f)-o*(n*h-i*f)+u*(n*l-i*s),t}},{}],280:[function(t,e,r){e.exports=function(t){var e=new Float32Array(16);return e[0]=t[0],e[1]=t[1],e[2]=t[2],e[3]=t[3],e[4]=t[4],e[5]=t[5],e[6]=t[6],e[7]=t[7],e[8]=t[8],e[9]=t[9],e[10]=t[10],e[11]=t[11],e[12]=t[12],e[13]=t[13],e[14]=t[14],e[15]=t[15],e}},{}],281:[function(t,e,r){e.exports=function(t,e){return t[0]=e[0],t[1]=e[1],t[2]=e[2],t[3]=e[3],t[4]=e[4],t[5]=e[5],t[6]=e[6],t[7]=e[7],t[8]=e[8],t[9]=e[9],t[10]=e[10],t[11]=e[11],t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15],t}},{}],282:[function(t,e,r){e.exports=function(){var t=new Float32Array(16);return t[0]=1,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=1,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[10]=1,t[11]=0,t[12]=0,t[13]=0,t[14]=0,t[15]=1,t}},{}],283:[function(t,e,r){e.exports=function(t){var e=t[0],r=t[1],n=t[2],i=t[3],a=t[4],o=t[5],s=t[6],l=t[7],c=t[8],u=t[9],f=t[10],h=t[11],p=t[12],d=t[13],m=t[14],g=t[15];return(e*o-r*a)*(f*g-h*m)-(e*s-n*a)*(u*g-h*d)+(e*l-i*a)*(u*m-f*d)+(r*s-n*o)*(c*g-h*p)-(r*l-i*o)*(c*m-f*p)+(n*l-i*s)*(c*d-u*p)}},{}],284:[function(t,e,r){e.exports=function(t,e){var r=e[0],n=e[1],i=e[2],a=e[3],o=r+r,s=n+n,l=i+i,c=r*o,u=n*o,f=n*s,h=i*o,p=i*s,d=i*l,m=a*o,g=a*s,v=a*l;return t[0]=1-f-d,t[1]=u+v,t[2]=h-g,t[3]=0,t[4]=u-v,t[5]=1-c-d,t[6]=p+m,t[7]=0,t[8]=h+g,t[9]=p-m,t[10]=1-c-f,t[11]=0,t[12]=0,t[13]=0,t[14]=0,t[15]=1,t}},{}],285:[function(t,e,r){e.exports=function(t,e,r){var n,i,a,o=r[0],s=r[1],l=r[2],c=Math.sqrt(o*o+s*s+l*l);if(Math.abs(c)<1e-6)return null;return o*=c=1/c,s*=c,l*=c,n=Math.sin(e),i=Math.cos(e),a=1-i,t[0]=o*o*a+i,t[1]=s*o*a+l*n,t[2]=l*o*a-s*n,t[3]=0,t[4]=o*s*a-l*n,t[5]=s*s*a+i,t[6]=l*s*a+o*n,t[7]=0,t[8]=o*l*a+s*n,t[9]=s*l*a-o*n,t[10]=l*l*a+i,t[11]=0,t[12]=0,t[13]=0,t[14]=0,t[15]=1,t}},{}],286:[function(t,e,r){e.exports=function(t,e,r){var n=e[0],i=e[1],a=e[2],o=e[3],s=n+n,l=i+i,c=a+a,u=n*s,f=n*l,h=n*c,p=i*l,d=i*c,m=a*c,g=o*s,v=o*l,y=o*c;return t[0]=1-(p+m),t[1]=f+y,t[2]=h-v,t[3]=0,t[4]=f-y,t[5]=1-(u+m),t[6]=d+g,t[7]=0,t[8]=h+v,t[9]=d-g,t[10]=1-(u+p),t[11]=0,t[12]=r[0],t[13]=r[1],t[14]=r[2],t[15]=1,t}},{}],287:[function(t,e,r){e.exports=function(t,e){return t[0]=e[0],t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=e[1],t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[10]=e[2],t[11]=0,t[12]=0,t[13]=0,t[14]=0,t[15]=1,t}},{}],288:[function(t,e,r){e.exports=function(t,e){return t[0]=1,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=1,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[10]=1,t[11]=0,t[12]=e[0],t[13]=e[1],t[14]=e[2],t[15]=1,t}},{}],289:[function(t,e,r){e.exports=function(t,e){var r=Math.sin(e),n=Math.cos(e);return t[0]=1,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=n,t[6]=r,t[7]=0,t[8]=0,t[9]=-r,t[10]=n,t[11]=0,t[12]=0,t[13]=0,t[14]=0,t[15]=1,t}},{}],290:[function(t,e,r){e.exports=function(t,e){var r=Math.sin(e),n=Math.cos(e);return t[0]=n,t[1]=0,t[2]=-r,t[3]=0,t[4]=0,t[5]=1,t[6]=0,t[7]=0,t[8]=r,t[9]=0,t[10]=n,t[11]=0,t[12]=0,t[13]=0,t[14]=0,t[15]=1,t}},{}],291:[function(t,e,r){e.exports=function(t,e){var r=Math.sin(e),n=Math.cos(e);return t[0]=n,t[1]=r,t[2]=0,t[3]=0,t[4]=-r,t[5]=n,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[10]=1,t[11]=0,t[12]=0,t[13]=0,t[14]=0,t[15]=1,t}},{}],292:[function(t,e,r){e.exports=function(t,e,r,n,i,a,o){var s=1/(r-e),l=1/(i-n),c=1/(a-o);return t[0]=2*a*s,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=2*a*l,t[6]=0,t[7]=0,t[8]=(r+e)*s,t[9]=(i+n)*l,t[10]=(o+a)*c,t[11]=-1,t[12]=0,t[13]=0,t[14]=o*a*2*c,t[15]=0,t}},{}],293:[function(t,e,r){e.exports=function(t){return t[0]=1,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=1,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[10]=1,t[11]=0,t[12]=0,t[13]=0,t[14]=0,t[15]=1,t}},{}],294:[function(t,e,r){e.exports={create:t(\"./create\"),clone:t(\"./clone\"),copy:t(\"./copy\"),identity:t(\"./identity\"),transpose:t(\"./transpose\"),invert:t(\"./invert\"),adjoint:t(\"./adjoint\"),determinant:t(\"./determinant\"),multiply:t(\"./multiply\"),translate:t(\"./translate\"),scale:t(\"./scale\"),rotate:t(\"./rotate\"),rotateX:t(\"./rotateX\"),rotateY:t(\"./rotateY\"),rotateZ:t(\"./rotateZ\"),fromRotation:t(\"./fromRotation\"),fromRotationTranslation:t(\"./fromRotationTranslation\"),fromScaling:t(\"./fromScaling\"),fromTranslation:t(\"./fromTranslation\"),fromXRotation:t(\"./fromXRotation\"),fromYRotation:t(\"./fromYRotation\"),fromZRotation:t(\"./fromZRotation\"),fromQuat:t(\"./fromQuat\"),frustum:t(\"./frustum\"),perspective:t(\"./perspective\"),perspectiveFromFieldOfView:t(\"./perspectiveFromFieldOfView\"),ortho:t(\"./ortho\"),lookAt:t(\"./lookAt\"),str:t(\"./str\")}},{\"./adjoint\":279,\"./clone\":280,\"./copy\":281,\"./create\":282,\"./determinant\":283,\"./fromQuat\":284,\"./fromRotation\":285,\"./fromRotationTranslation\":286,\"./fromScaling\":287,\"./fromTranslation\":288,\"./fromXRotation\":289,\"./fromYRotation\":290,\"./fromZRotation\":291,\"./frustum\":292,\"./identity\":293,\"./invert\":295,\"./lookAt\":296,\"./multiply\":297,\"./ortho\":298,\"./perspective\":299,\"./perspectiveFromFieldOfView\":300,\"./rotate\":301,\"./rotateX\":302,\"./rotateY\":303,\"./rotateZ\":304,\"./scale\":305,\"./str\":306,\"./translate\":307,\"./transpose\":308}],295:[function(t,e,r){e.exports=function(t,e){var r=e[0],n=e[1],i=e[2],a=e[3],o=e[4],s=e[5],l=e[6],c=e[7],u=e[8],f=e[9],h=e[10],p=e[11],d=e[12],m=e[13],g=e[14],v=e[15],y=r*s-n*o,x=r*l-i*o,b=r*c-a*o,_=n*l-i*s,w=n*c-a*s,T=i*c-a*l,k=u*m-f*d,M=u*g-h*d,A=u*v-p*d,S=f*g-h*m,E=f*v-p*m,L=h*v-p*g,C=y*L-x*E+b*S+_*A-w*M+T*k;if(!C)return null;return C=1/C,t[0]=(s*L-l*E+c*S)*C,t[1]=(i*E-n*L-a*S)*C,t[2]=(m*T-g*w+v*_)*C,t[3]=(h*w-f*T-p*_)*C,t[4]=(l*A-o*L-c*M)*C,t[5]=(r*L-i*A+a*M)*C,t[6]=(g*b-d*T-v*x)*C,t[7]=(u*T-h*b+p*x)*C,t[8]=(o*E-s*A+c*k)*C,t[9]=(n*A-r*E-a*k)*C,t[10]=(d*w-m*b+v*y)*C,t[11]=(f*b-u*w-p*y)*C,t[12]=(s*M-o*S-l*k)*C,t[13]=(r*S-n*M+i*k)*C,t[14]=(m*x-d*_-g*y)*C,t[15]=(u*_-f*x+h*y)*C,t}},{}],296:[function(t,e,r){var n=t(\"./identity\");e.exports=function(t,e,r,i){var a,o,s,l,c,u,f,h,p,d,m=e[0],g=e[1],v=e[2],y=i[0],x=i[1],b=i[2],_=r[0],w=r[1],T=r[2];if(Math.abs(m-_)<1e-6&&Math.abs(g-w)<1e-6&&Math.abs(v-T)<1e-6)return n(t);f=m-_,h=g-w,p=v-T,d=1/Math.sqrt(f*f+h*h+p*p),a=x*(p*=d)-b*(h*=d),o=b*(f*=d)-y*p,s=y*h-x*f,(d=Math.sqrt(a*a+o*o+s*s))?(a*=d=1/d,o*=d,s*=d):(a=0,o=0,s=0);l=h*s-p*o,c=p*a-f*s,u=f*o-h*a,(d=Math.sqrt(l*l+c*c+u*u))?(l*=d=1/d,c*=d,u*=d):(l=0,c=0,u=0);return t[0]=a,t[1]=l,t[2]=f,t[3]=0,t[4]=o,t[5]=c,t[6]=h,t[7]=0,t[8]=s,t[9]=u,t[10]=p,t[11]=0,t[12]=-(a*m+o*g+s*v),t[13]=-(l*m+c*g+u*v),t[14]=-(f*m+h*g+p*v),t[15]=1,t}},{\"./identity\":293}],297:[function(t,e,r){e.exports=function(t,e,r){var n=e[0],i=e[1],a=e[2],o=e[3],s=e[4],l=e[5],c=e[6],u=e[7],f=e[8],h=e[9],p=e[10],d=e[11],m=e[12],g=e[13],v=e[14],y=e[15],x=r[0],b=r[1],_=r[2],w=r[3];return t[0]=x*n+b*s+_*f+w*m,t[1]=x*i+b*l+_*h+w*g,t[2]=x*a+b*c+_*p+w*v,t[3]=x*o+b*u+_*d+w*y,x=r[4],b=r[5],_=r[6],w=r[7],t[4]=x*n+b*s+_*f+w*m,t[5]=x*i+b*l+_*h+w*g,t[6]=x*a+b*c+_*p+w*v,t[7]=x*o+b*u+_*d+w*y,x=r[8],b=r[9],_=r[10],w=r[11],t[8]=x*n+b*s+_*f+w*m,t[9]=x*i+b*l+_*h+w*g,t[10]=x*a+b*c+_*p+w*v,t[11]=x*o+b*u+_*d+w*y,x=r[12],b=r[13],_=r[14],w=r[15],t[12]=x*n+b*s+_*f+w*m,t[13]=x*i+b*l+_*h+w*g,t[14]=x*a+b*c+_*p+w*v,t[15]=x*o+b*u+_*d+w*y,t}},{}],298:[function(t,e,r){e.exports=function(t,e,r,n,i,a,o){var s=1/(e-r),l=1/(n-i),c=1/(a-o);return t[0]=-2*s,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=-2*l,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[10]=2*c,t[11]=0,t[12]=(e+r)*s,t[13]=(i+n)*l,t[14]=(o+a)*c,t[15]=1,t}},{}],299:[function(t,e,r){e.exports=function(t,e,r,n,i){var a=1/Math.tan(e/2),o=1/(n-i);return t[0]=a/r,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=a,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[10]=(i+n)*o,t[11]=-1,t[12]=0,t[13]=0,t[14]=2*i*n*o,t[15]=0,t}},{}],300:[function(t,e,r){e.exports=function(t,e,r,n){var i=Math.tan(e.upDegrees*Math.PI/180),a=Math.tan(e.downDegrees*Math.PI/180),o=Math.tan(e.leftDegrees*Math.PI/180),s=Math.tan(e.rightDegrees*Math.PI/180),l=2/(o+s),c=2/(i+a);return t[0]=l,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=c,t[6]=0,t[7]=0,t[8]=-(o-s)*l*.5,t[9]=(i-a)*c*.5,t[10]=n/(r-n),t[11]=-1,t[12]=0,t[13]=0,t[14]=n*r/(r-n),t[15]=0,t}},{}],301:[function(t,e,r){e.exports=function(t,e,r,n){var i,a,o,s,l,c,u,f,h,p,d,m,g,v,y,x,b,_,w,T,k,M,A,S,E=n[0],L=n[1],C=n[2],P=Math.sqrt(E*E+L*L+C*C);if(Math.abs(P)<1e-6)return null;E*=P=1/P,L*=P,C*=P,i=Math.sin(r),a=Math.cos(r),o=1-a,s=e[0],l=e[1],c=e[2],u=e[3],f=e[4],h=e[5],p=e[6],d=e[7],m=e[8],g=e[9],v=e[10],y=e[11],x=E*E*o+a,b=L*E*o+C*i,_=C*E*o-L*i,w=E*L*o-C*i,T=L*L*o+a,k=C*L*o+E*i,M=E*C*o+L*i,A=L*C*o-E*i,S=C*C*o+a,t[0]=s*x+f*b+m*_,t[1]=l*x+h*b+g*_,t[2]=c*x+p*b+v*_,t[3]=u*x+d*b+y*_,t[4]=s*w+f*T+m*k,t[5]=l*w+h*T+g*k,t[6]=c*w+p*T+v*k,t[7]=u*w+d*T+y*k,t[8]=s*M+f*A+m*S,t[9]=l*M+h*A+g*S,t[10]=c*M+p*A+v*S,t[11]=u*M+d*A+y*S,e!==t&&(t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15]);return t}},{}],302:[function(t,e,r){e.exports=function(t,e,r){var n=Math.sin(r),i=Math.cos(r),a=e[4],o=e[5],s=e[6],l=e[7],c=e[8],u=e[9],f=e[10],h=e[11];e!==t&&(t[0]=e[0],t[1]=e[1],t[2]=e[2],t[3]=e[3],t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15]);return t[4]=a*i+c*n,t[5]=o*i+u*n,t[6]=s*i+f*n,t[7]=l*i+h*n,t[8]=c*i-a*n,t[9]=u*i-o*n,t[10]=f*i-s*n,t[11]=h*i-l*n,t}},{}],303:[function(t,e,r){e.exports=function(t,e,r){var n=Math.sin(r),i=Math.cos(r),a=e[0],o=e[1],s=e[2],l=e[3],c=e[8],u=e[9],f=e[10],h=e[11];e!==t&&(t[4]=e[4],t[5]=e[5],t[6]=e[6],t[7]=e[7],t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15]);return t[0]=a*i-c*n,t[1]=o*i-u*n,t[2]=s*i-f*n,t[3]=l*i-h*n,t[8]=a*n+c*i,t[9]=o*n+u*i,t[10]=s*n+f*i,t[11]=l*n+h*i,t}},{}],304:[function(t,e,r){e.exports=function(t,e,r){var n=Math.sin(r),i=Math.cos(r),a=e[0],o=e[1],s=e[2],l=e[3],c=e[4],u=e[5],f=e[6],h=e[7];e!==t&&(t[8]=e[8],t[9]=e[9],t[10]=e[10],t[11]=e[11],t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15]);return t[0]=a*i+c*n,t[1]=o*i+u*n,t[2]=s*i+f*n,t[3]=l*i+h*n,t[4]=c*i-a*n,t[5]=u*i-o*n,t[6]=f*i-s*n,t[7]=h*i-l*n,t}},{}],305:[function(t,e,r){e.exports=function(t,e,r){var n=r[0],i=r[1],a=r[2];return t[0]=e[0]*n,t[1]=e[1]*n,t[2]=e[2]*n,t[3]=e[3]*n,t[4]=e[4]*i,t[5]=e[5]*i,t[6]=e[6]*i,t[7]=e[7]*i,t[8]=e[8]*a,t[9]=e[9]*a,t[10]=e[10]*a,t[11]=e[11]*a,t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15],t}},{}],306:[function(t,e,r){e.exports=function(t){return\"mat4(\"+t[0]+\", \"+t[1]+\", \"+t[2]+\", \"+t[3]+\", \"+t[4]+\", \"+t[5]+\", \"+t[6]+\", \"+t[7]+\", \"+t[8]+\", \"+t[9]+\", \"+t[10]+\", \"+t[11]+\", \"+t[12]+\", \"+t[13]+\", \"+t[14]+\", \"+t[15]+\")\"}},{}],307:[function(t,e,r){e.exports=function(t,e,r){var n,i,a,o,s,l,c,u,f,h,p,d,m=r[0],g=r[1],v=r[2];e===t?(t[12]=e[0]*m+e[4]*g+e[8]*v+e[12],t[13]=e[1]*m+e[5]*g+e[9]*v+e[13],t[14]=e[2]*m+e[6]*g+e[10]*v+e[14],t[15]=e[3]*m+e[7]*g+e[11]*v+e[15]):(n=e[0],i=e[1],a=e[2],o=e[3],s=e[4],l=e[5],c=e[6],u=e[7],f=e[8],h=e[9],p=e[10],d=e[11],t[0]=n,t[1]=i,t[2]=a,t[3]=o,t[4]=s,t[5]=l,t[6]=c,t[7]=u,t[8]=f,t[9]=h,t[10]=p,t[11]=d,t[12]=n*m+s*g+f*v+e[12],t[13]=i*m+l*g+h*v+e[13],t[14]=a*m+c*g+p*v+e[14],t[15]=o*m+u*g+d*v+e[15]);return t}},{}],308:[function(t,e,r){e.exports=function(t,e){if(t===e){var r=e[1],n=e[2],i=e[3],a=e[6],o=e[7],s=e[11];t[1]=e[4],t[2]=e[8],t[3]=e[12],t[4]=r,t[6]=e[9],t[7]=e[13],t[8]=n,t[9]=a,t[11]=e[14],t[12]=i,t[13]=o,t[14]=s}else t[0]=e[0],t[1]=e[4],t[2]=e[8],t[3]=e[12],t[4]=e[1],t[5]=e[5],t[6]=e[9],t[7]=e[13],t[8]=e[2],t[9]=e[6],t[10]=e[10],t[11]=e[14],t[12]=e[3],t[13]=e[7],t[14]=e[11],t[15]=e[15];return t}},{}],309:[function(t,e,r){\"use strict\";var n=t(\"barycentric\"),i=t(\"polytope-closest-point/lib/closest_point_2d.js\");function a(t,e){for(var r=[0,0,0,0],n=0;n<4;++n)for(var i=0;i<4;++i)r[i]+=t[4*n+i]*e[n];return r}function o(t,e,r,n,i){for(var o=a(n,a(r,a(e,[t[0],t[1],t[2],1]))),s=0;s<3;++s)o[s]/=o[3];return[.5*i[0]*(1+o[0]),.5*i[1]*(1-o[1])]}function s(t,e){for(var r=[0,0,0],n=0;n<t.length;++n)for(var i=t[n],a=e[n],o=0;o<3;++o)r[o]+=a*i[o];return r}e.exports=function(t,e,r,a,l,c){if(1===t.length)return[0,t[0].slice()];for(var u=new Array(t.length),f=0;f<t.length;++f)u[f]=o(t[f],r,a,l,c);var h=0,p=1/0;for(f=0;f<u.length;++f){for(var d=0,m=0;m<2;++m)d+=Math.pow(u[f][m]-e[m],2);d<p&&(p=d,h=f)}var g=function(t,e){if(2===t.length){for(var r=0,a=0,o=0;o<2;++o)r+=Math.pow(e[o]-t[0][o],2),a+=Math.pow(e[o]-t[1][o],2);return r=Math.sqrt(r),a=Math.sqrt(a),r+a<1e-6?[1,0]:[a/(r+a),r/(a+r)]}if(3===t.length){var s=[0,0];return i(t[0],t[1],t[2],e,s),n(t,s)}return[]}(u,e),v=0;for(f=0;f<3;++f){if(g[f]<-.001||g[f]>1.0001)return null;v+=g[f]}if(Math.abs(v-1)>.001)return null;return[h,s(t,g),g]}},{barycentric:85,\"polytope-closest-point/lib/closest_point_2d.js\":508}],310:[function(t,e,r){var n=t(\"glslify\"),i=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position, normal;\\nattribute vec4 color;\\nattribute vec2 uv;\\n\\nuniform mat4 model\\n           , view\\n           , projection\\n           , inverseModel;\\nuniform vec3 eyePosition\\n           , lightPosition;\\n\\nvarying vec3 f_normal\\n           , f_lightDirection\\n           , f_eyeDirection\\n           , f_data;\\nvarying vec4 f_color;\\nvarying vec2 f_uv;\\n\\nvec4 project(vec3 p) {\\n  return projection * view * model * vec4(p, 1.0);\\n}\\n\\nvoid main() {\\n  gl_Position      = project(position);\\n\\n  //Lighting geometry parameters\\n  vec4 cameraCoordinate = view * vec4(position , 1.0);\\n  cameraCoordinate.xyz /= cameraCoordinate.w;\\n  f_lightDirection = lightPosition - cameraCoordinate.xyz;\\n  f_eyeDirection   = eyePosition - cameraCoordinate.xyz;\\n  f_normal  = normalize((vec4(normal, 0.0) * inverseModel).xyz);\\n\\n  f_color          = color;\\n  f_data           = position;\\n  f_uv             = uv;\\n}\\n\"]),a=n([\"#extension GL_OES_standard_derivatives : enable\\n\\nprecision highp float;\\n#define GLSLIFY 1\\n\\nfloat beckmannDistribution(float x, float roughness) {\\n  float NdotH = max(x, 0.0001);\\n  float cos2Alpha = NdotH * NdotH;\\n  float tan2Alpha = (cos2Alpha - 1.0) / cos2Alpha;\\n  float roughness2 = roughness * roughness;\\n  float denom = 3.141592653589793 * roughness2 * cos2Alpha * cos2Alpha;\\n  return exp(tan2Alpha / roughness2) / denom;\\n}\\n\\nfloat cookTorranceSpecular(\\n  vec3 lightDirection,\\n  vec3 viewDirection,\\n  vec3 surfaceNormal,\\n  float roughness,\\n  float fresnel) {\\n\\n  float VdotN = max(dot(viewDirection, surfaceNormal), 0.0);\\n  float LdotN = max(dot(lightDirection, surfaceNormal), 0.0);\\n\\n  //Half angle vector\\n  vec3 H = normalize(lightDirection + viewDirection);\\n\\n  //Geometric term\\n  float NdotH = max(dot(surfaceNormal, H), 0.0);\\n  float VdotH = max(dot(viewDirection, H), 0.000001);\\n  float LdotH = max(dot(lightDirection, H), 0.000001);\\n  float G1 = (2.0 * NdotH * VdotN) / VdotH;\\n  float G2 = (2.0 * NdotH * LdotN) / LdotH;\\n  float G = min(1.0, min(G1, G2));\\n  \\n  //Distribution term\\n  float D = beckmannDistribution(NdotH, roughness);\\n\\n  //Fresnel term\\n  float F = pow(1.0 - VdotN, fresnel);\\n\\n  //Multiply terms and done\\n  return  G * F * D / max(3.14159265 * VdotN, 0.000001);\\n}\\n\\n//#pragma glslify: beckmann = require(glsl-specular-beckmann) // used in gl-surface3d\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3 clipBounds[2];\\nuniform float roughness\\n            , fresnel\\n            , kambient\\n            , kdiffuse\\n            , kspecular;\\nuniform sampler2D texture;\\n\\nvarying vec3 f_normal\\n           , f_lightDirection\\n           , f_eyeDirection\\n           , f_data;\\nvarying vec4 f_color;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  if (f_color.a == 0.0 ||\\n    outOfRange(clipBounds[0], clipBounds[1], f_data)\\n  ) discard;\\n\\n  vec3 N = normalize(f_normal);\\n  vec3 L = normalize(f_lightDirection);\\n  vec3 V = normalize(f_eyeDirection);\\n\\n  if(gl_FrontFacing) {\\n    N = -N;\\n  }\\n\\n  float specular = min(1.0, max(0.0, cookTorranceSpecular(L, V, N, roughness, fresnel)));\\n  //float specular = max(0.0, beckmann(L, V, N, roughness)); // used in gl-surface3d\\n\\n  float diffuse  = min(kambient + kdiffuse * max(dot(N, L), 0.0), 1.0);\\n\\n  vec4 surfaceColor = vec4(f_color.rgb, 1.0) * texture2D(texture, f_uv);\\n  vec4 litColor = surfaceColor.a * vec4(diffuse * surfaceColor.rgb + kspecular * vec3(1,1,1) * specular,  1.0);\\n\\n  gl_FragColor = litColor * f_color.a;\\n}\\n\"]),o=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position;\\nattribute vec4 color;\\nattribute vec2 uv;\\n\\nuniform mat4 model, view, projection;\\n\\nvarying vec4 f_color;\\nvarying vec3 f_data;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  gl_Position = projection * view * model * vec4(position, 1.0);\\n  f_color = color;\\n  f_data  = position;\\n  f_uv    = uv;\\n}\"]),s=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3 clipBounds[2];\\nuniform sampler2D texture;\\nuniform float opacity;\\n\\nvarying vec4 f_color;\\nvarying vec3 f_data;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], f_data)) discard;\\n\\n  gl_FragColor = f_color * texture2D(texture, f_uv) * opacity;\\n}\"]),l=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nattribute vec3 position;\\nattribute vec4 color;\\nattribute vec2 uv;\\nattribute float pointSize;\\n\\nuniform mat4 model, view, projection;\\nuniform vec3 clipBounds[2];\\n\\nvarying vec4 f_color;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], position)) {\\n\\n    gl_Position = vec4(0.0, 0.0 ,0.0 ,0.0);\\n  } else {\\n    gl_Position = projection * view * model * vec4(position, 1.0);\\n  }\\n  gl_PointSize = pointSize;\\n  f_color = color;\\n  f_uv = uv;\\n}\"]),c=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nuniform sampler2D texture;\\nuniform float opacity;\\n\\nvarying vec4 f_color;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  vec2 pointR = gl_PointCoord.xy - vec2(0.5, 0.5);\\n  if(dot(pointR, pointR) > 0.25) {\\n    discard;\\n  }\\n  gl_FragColor = f_color * texture2D(texture, f_uv) * opacity;\\n}\"]),u=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position;\\nattribute vec4 id;\\n\\nuniform mat4 model, view, projection;\\n\\nvarying vec3 f_position;\\nvarying vec4 f_id;\\n\\nvoid main() {\\n  gl_Position = projection * view * model * vec4(position, 1.0);\\n  f_id        = id;\\n  f_position  = position;\\n}\"]),f=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3  clipBounds[2];\\nuniform float pickId;\\n\\nvarying vec3 f_position;\\nvarying vec4 f_id;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], f_position)) discard;\\n\\n  gl_FragColor = vec4(pickId, f_id.xyz);\\n}\"]),h=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nattribute vec3  position;\\nattribute float pointSize;\\nattribute vec4  id;\\n\\nuniform mat4 model, view, projection;\\nuniform vec3 clipBounds[2];\\n\\nvarying vec3 f_position;\\nvarying vec4 f_id;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], position)) {\\n\\n    gl_Position = vec4(0.0, 0.0, 0.0, 0.0);\\n  } else {\\n    gl_Position  = projection * view * model * vec4(position, 1.0);\\n    gl_PointSize = pointSize;\\n  }\\n  f_id         = id;\\n  f_position   = position;\\n}\"]),p=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position;\\n\\nuniform mat4 model, view, projection;\\n\\nvoid main() {\\n  gl_Position = projection * view * model * vec4(position, 1.0);\\n}\"]),d=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nuniform vec3 contourColor;\\n\\nvoid main() {\\n  gl_FragColor = vec4(contourColor, 1.0);\\n}\\n\"]);r.meshShader={vertex:i,fragment:a,attributes:[{name:\"position\",type:\"vec3\"},{name:\"normal\",type:\"vec3\"},{name:\"color\",type:\"vec4\"},{name:\"uv\",type:\"vec2\"}]},r.wireShader={vertex:o,fragment:s,attributes:[{name:\"position\",type:\"vec3\"},{name:\"color\",type:\"vec4\"},{name:\"uv\",type:\"vec2\"}]},r.pointShader={vertex:l,fragment:c,attributes:[{name:\"position\",type:\"vec3\"},{name:\"color\",type:\"vec4\"},{name:\"uv\",type:\"vec2\"},{name:\"pointSize\",type:\"float\"}]},r.pickShader={vertex:u,fragment:f,attributes:[{name:\"position\",type:\"vec3\"},{name:\"id\",type:\"vec4\"}]},r.pointPickShader={vertex:h,fragment:f,attributes:[{name:\"position\",type:\"vec3\"},{name:\"pointSize\",type:\"float\"},{name:\"id\",type:\"vec4\"}]},r.contourShader={vertex:p,fragment:d,attributes:[{name:\"position\",type:\"vec3\"}]}},{glslify:438}],311:[function(t,e,r){\"use strict\";var n=t(\"gl-shader\"),i=t(\"gl-buffer\"),a=t(\"gl-vao\"),o=t(\"gl-texture2d\"),s=t(\"normals\"),l=t(\"gl-mat4/multiply\"),c=t(\"gl-mat4/invert\"),u=t(\"ndarray\"),f=t(\"colormap\"),h=t(\"simplicial-complex-contour\"),p=t(\"typedarray-pool\"),d=t(\"./lib/shaders\"),m=t(\"./lib/closest-point\"),g=d.meshShader,v=d.wireShader,y=d.pointShader,x=d.pickShader,b=d.pointPickShader,_=d.contourShader,w=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1];function T(t,e,r,n,i,a,o,s,l,c,u,f,h,p,d,m,g,v,y,x,b,_,T,k,M,A,S){this.gl=t,this.pixelRatio=1,this.cells=[],this.positions=[],this.intensity=[],this.texture=e,this.dirty=!0,this.triShader=r,this.lineShader=n,this.pointShader=i,this.pickShader=a,this.pointPickShader=o,this.contourShader=s,this.trianglePositions=l,this.triangleColors=u,this.triangleNormals=h,this.triangleUVs=f,this.triangleIds=c,this.triangleVAO=p,this.triangleCount=0,this.lineWidth=1,this.edgePositions=d,this.edgeColors=g,this.edgeUVs=v,this.edgeIds=m,this.edgeVAO=y,this.edgeCount=0,this.pointPositions=x,this.pointColors=_,this.pointUVs=T,this.pointSizes=k,this.pointIds=b,this.pointVAO=M,this.pointCount=0,this.contourLineWidth=1,this.contourPositions=A,this.contourVAO=S,this.contourCount=0,this.contourColor=[0,0,0],this.contourEnable=!0,this.pickVertex=!0,this.pickId=1,this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],this.clipBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.lightPosition=[1e5,1e5,0],this.ambientLight=.8,this.diffuseLight=.8,this.specularLight=2,this.roughness=.5,this.fresnel=1.5,this.opacity=1,this.hasAlpha=!1,this.opacityscale=!1,this._model=w,this._view=w,this._projection=w,this._resolution=[1,1]}var k=T.prototype;function M(t,e){if(!e)return 1;if(!e.length)return 1;for(var r=0;r<e.length;++r){if(e.length<2)return 1;if(e[r][0]===t)return e[r][1];if(e[r][0]>t&&r>0){var n=(e[r][0]-t)/(e[r][0]-e[r-1][0]);return e[r][1]*(1-n)+n*e[r-1][1]}}return 1}function A(t){var e=n(t,g.vertex,g.fragment);return e.attributes.position.location=0,e.attributes.color.location=2,e.attributes.uv.location=3,e.attributes.normal.location=4,e}function S(t){var e=n(t,v.vertex,v.fragment);return e.attributes.position.location=0,e.attributes.color.location=2,e.attributes.uv.location=3,e}function E(t){var e=n(t,y.vertex,y.fragment);return e.attributes.position.location=0,e.attributes.color.location=2,e.attributes.uv.location=3,e.attributes.pointSize.location=4,e}function L(t){var e=n(t,x.vertex,x.fragment);return e.attributes.position.location=0,e.attributes.id.location=1,e}function C(t){var e=n(t,b.vertex,b.fragment);return e.attributes.position.location=0,e.attributes.id.location=1,e.attributes.pointSize.location=4,e}function P(t){var e=n(t,_.vertex,_.fragment);return e.attributes.position.location=0,e}k.isOpaque=function(){return!this.hasAlpha},k.isTransparent=function(){return this.hasAlpha},k.pickSlots=1,k.setPickBase=function(t){this.pickId=t},k.highlight=function(t){if(t&&this.contourEnable){for(var e=h(this.cells,this.intensity,t.intensity),r=e.cells,n=e.vertexIds,i=e.vertexWeights,a=r.length,o=p.mallocFloat32(6*a),s=0,l=0;l<a;++l)for(var c=r[l],u=0;u<2;++u){var f=c[0];2===c.length&&(f=c[u]);for(var d=n[f][0],m=n[f][1],g=i[f],v=1-g,y=this.positions[d],x=this.positions[m],b=0;b<3;++b)o[s++]=g*y[b]+v*x[b]}this.contourCount=s/3|0,this.contourPositions.update(o.subarray(0,s)),p.free(o)}else this.contourCount=0},k.update=function(t){t=t||{};var e=this.gl;this.dirty=!0,\"contourEnable\"in t&&(this.contourEnable=t.contourEnable),\"contourColor\"in t&&(this.contourColor=t.contourColor),\"lineWidth\"in t&&(this.lineWidth=t.lineWidth),\"lightPosition\"in t&&(this.lightPosition=t.lightPosition),this.hasAlpha=!1,\"opacity\"in t&&(this.opacity=t.opacity,this.opacity<1&&(this.hasAlpha=!0)),\"opacityscale\"in t&&(this.opacityscale=t.opacityscale,this.hasAlpha=!0),\"ambient\"in t&&(this.ambientLight=t.ambient),\"diffuse\"in t&&(this.diffuseLight=t.diffuse),\"specular\"in t&&(this.specularLight=t.specular),\"roughness\"in t&&(this.roughness=t.roughness),\"fresnel\"in t&&(this.fresnel=t.fresnel),t.texture?(this.texture.dispose(),this.texture=o(e,t.texture)):t.colormap&&(this.texture.shape=[256,256],this.texture.minFilter=e.LINEAR_MIPMAP_LINEAR,this.texture.magFilter=e.LINEAR,this.texture.setPixels(function(t,e){for(var r=f({colormap:t,nshades:256,format:\"rgba\"}),n=new Uint8Array(1024),i=0;i<256;++i){for(var a=r[i],o=0;o<3;++o)n[4*i+o]=a[o];n[4*i+3]=e?255*M(i/255,e):255*a[3]}return u(n,[256,256,4],[4,0,1])}(t.colormap,this.opacityscale)),this.texture.generateMipmap());var r=t.cells,n=t.positions;if(n&&r){var i=[],a=[],l=[],c=[],h=[],p=[],d=[],m=[],g=[],v=[],y=[],x=[],b=[],_=[];this.cells=r,this.positions=n;var w=t.vertexNormals,T=t.cellNormals,k=void 0===t.vertexNormalsEpsilon?1e-6:t.vertexNormalsEpsilon,A=void 0===t.faceNormalsEpsilon?1e-6:t.faceNormalsEpsilon;t.useFacetNormals&&!T&&(T=s.faceNormals(r,n,A)),T||w||(w=s.vertexNormals(r,n,k));var S=t.vertexColors,E=t.cellColors,L=t.meshColor||[1,1,1,1],C=t.vertexUVs,P=t.vertexIntensity,I=t.cellUVs,O=t.cellIntensity,z=1/0,D=-1/0;if(!C&&!I)if(P)if(t.vertexIntensityBounds)z=+t.vertexIntensityBounds[0],D=+t.vertexIntensityBounds[1];else for(var R=0;R<P.length;++R){var F=P[R];z=Math.min(z,F),D=Math.max(D,F)}else if(O)if(t.cellIntensityBounds)z=+t.cellIntensityBounds[0],D=+t.cellIntensityBounds[1];else for(R=0;R<O.length;++R){F=O[R];z=Math.min(z,F),D=Math.max(D,F)}else for(R=0;R<n.length;++R){F=n[R][2];z=Math.min(z,F),D=Math.max(D,F)}this.intensity=P||(O||function(t){for(var e=t.length,r=new Array(e),n=0;n<e;++n)r[n]=t[n][2];return r}(n)),this.pickVertex=!(O||E);var B=t.pointSizes,N=t.pointSize||1;this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]];for(R=0;R<n.length;++R)for(var j=n[R],U=0;U<3;++U)!isNaN(j[U])&&isFinite(j[U])&&(this.bounds[0][U]=Math.min(this.bounds[0][U],j[U]),this.bounds[1][U]=Math.max(this.bounds[1][U],j[U]));var V=0,q=0,H=0;t:for(R=0;R<r.length;++R){var G=r[R];switch(G.length){case 1:for(j=n[W=G[0]],U=0;U<3;++U)if(isNaN(j[U])||!isFinite(j[U]))continue t;v.push(j[0],j[1],j[2]),X=S?S[W]:E?E[R]:L,this.opacityscale&&P?a.push(X[0],X[1],X[2],this.opacity*M((P[W]-z)/(D-z),this.opacityscale)):3===X.length?y.push(X[0],X[1],X[2],this.opacity):(y.push(X[0],X[1],X[2],X[3]*this.opacity),X[3]<1&&(this.hasAlpha=!0)),Z=C?C[W]:P?[(P[W]-z)/(D-z),0]:I?I[R]:O?[(O[R]-z)/(D-z),0]:[(j[2]-z)/(D-z),0],x.push(Z[0],Z[1]),B?b.push(B[W]):b.push(N),_.push(R),H+=1;break;case 2:for(U=0;U<2;++U){j=n[W=G[U]];for(var Y=0;Y<3;++Y)if(isNaN(j[Y])||!isFinite(j[Y]))continue t}for(U=0;U<2;++U){j=n[W=G[U]];p.push(j[0],j[1],j[2]),X=S?S[W]:E?E[R]:L,this.opacityscale&&P?a.push(X[0],X[1],X[2],this.opacity*M((P[W]-z)/(D-z),this.opacityscale)):3===X.length?d.push(X[0],X[1],X[2],this.opacity):(d.push(X[0],X[1],X[2],X[3]*this.opacity),X[3]<1&&(this.hasAlpha=!0)),Z=C?C[W]:P?[(P[W]-z)/(D-z),0]:I?I[R]:O?[(O[R]-z)/(D-z),0]:[(j[2]-z)/(D-z),0],m.push(Z[0],Z[1]),g.push(R)}q+=1;break;case 3:for(U=0;U<3;++U)for(j=n[W=G[U]],Y=0;Y<3;++Y)if(isNaN(j[Y])||!isFinite(j[Y]))continue t;for(U=0;U<3;++U){var W,X,Z,J;j=n[W=G[2-U]];i.push(j[0],j[1],j[2]),(X=S?S[W]:E?E[R]:L)?this.opacityscale&&P?a.push(X[0],X[1],X[2],this.opacity*M((P[W]-z)/(D-z),this.opacityscale)):3===X.length?a.push(X[0],X[1],X[2],this.opacity):(a.push(X[0],X[1],X[2],X[3]*this.opacity),X[3]<1&&(this.hasAlpha=!0)):a.push(.5,.5,.5,1),Z=C?C[W]:P?[(P[W]-z)/(D-z),0]:I?I[R]:O?[(O[R]-z)/(D-z),0]:[(j[2]-z)/(D-z),0],c.push(Z[0],Z[1]),J=w?w[W]:T[R],l.push(J[0],J[1],J[2]),h.push(R)}V+=1}}this.pointCount=H,this.edgeCount=q,this.triangleCount=V,this.pointPositions.update(v),this.pointColors.update(y),this.pointUVs.update(x),this.pointSizes.update(b),this.pointIds.update(new Uint32Array(_)),this.edgePositions.update(p),this.edgeColors.update(d),this.edgeUVs.update(m),this.edgeIds.update(new Uint32Array(g)),this.trianglePositions.update(i),this.triangleColors.update(a),this.triangleUVs.update(c),this.triangleNormals.update(l),this.triangleIds.update(new Uint32Array(h))}},k.drawTransparent=k.draw=function(t){t=t||{};for(var e=this.gl,r=t.model||w,n=t.view||w,i=t.projection||w,a=[[-1e6,-1e6,-1e6],[1e6,1e6,1e6]],o=0;o<3;++o)a[0][o]=Math.max(a[0][o],this.clipBounds[0][o]),a[1][o]=Math.min(a[1][o],this.clipBounds[1][o]);var s={model:r,view:n,projection:i,inverseModel:w.slice(),clipBounds:a,kambient:this.ambientLight,kdiffuse:this.diffuseLight,kspecular:this.specularLight,roughness:this.roughness,fresnel:this.fresnel,eyePosition:[0,0,0],lightPosition:[0,0,0],contourColor:this.contourColor,texture:0};s.inverseModel=c(s.inverseModel,s.model),e.disable(e.CULL_FACE),this.texture.bind(0);var u=new Array(16);l(u,s.view,s.model),l(u,s.projection,u),c(u,u);for(o=0;o<3;++o)s.eyePosition[o]=u[12+o]/u[15];var f,h=u[15];for(o=0;o<3;++o)h+=this.lightPosition[o]*u[4*o+3];for(o=0;o<3;++o){for(var p=u[12+o],d=0;d<3;++d)p+=u[4*d+o]*this.lightPosition[d];s.lightPosition[o]=p/h}this.triangleCount>0&&((f=this.triShader).bind(),f.uniforms=s,this.triangleVAO.bind(),e.drawArrays(e.TRIANGLES,0,3*this.triangleCount),this.triangleVAO.unbind());this.edgeCount>0&&this.lineWidth>0&&((f=this.lineShader).bind(),f.uniforms=s,this.edgeVAO.bind(),e.lineWidth(this.lineWidth*this.pixelRatio),e.drawArrays(e.LINES,0,2*this.edgeCount),this.edgeVAO.unbind());this.pointCount>0&&((f=this.pointShader).bind(),f.uniforms=s,this.pointVAO.bind(),e.drawArrays(e.POINTS,0,this.pointCount),this.pointVAO.unbind());this.contourEnable&&this.contourCount>0&&this.contourLineWidth>0&&((f=this.contourShader).bind(),f.uniforms=s,this.contourVAO.bind(),e.drawArrays(e.LINES,0,this.contourCount),this.contourVAO.unbind())},k.drawPick=function(t){t=t||{};for(var e=this.gl,r=t.model||w,n=t.view||w,i=t.projection||w,a=[[-1e6,-1e6,-1e6],[1e6,1e6,1e6]],o=0;o<3;++o)a[0][o]=Math.max(a[0][o],this.clipBounds[0][o]),a[1][o]=Math.min(a[1][o],this.clipBounds[1][o]);this._model=[].slice.call(r),this._view=[].slice.call(n),this._projection=[].slice.call(i),this._resolution=[e.drawingBufferWidth,e.drawingBufferHeight];var s,l={model:r,view:n,projection:i,clipBounds:a,pickId:this.pickId/255};((s=this.pickShader).bind(),s.uniforms=l,this.triangleCount>0&&(this.triangleVAO.bind(),e.drawArrays(e.TRIANGLES,0,3*this.triangleCount),this.triangleVAO.unbind()),this.edgeCount>0&&(this.edgeVAO.bind(),e.lineWidth(this.lineWidth*this.pixelRatio),e.drawArrays(e.LINES,0,2*this.edgeCount),this.edgeVAO.unbind()),this.pointCount>0)&&((s=this.pointPickShader).bind(),s.uniforms=l,this.pointVAO.bind(),e.drawArrays(e.POINTS,0,this.pointCount),this.pointVAO.unbind())},k.pick=function(t){if(!t)return null;if(t.id!==this.pickId)return null;for(var e=t.value[0]+256*t.value[1]+65536*t.value[2],r=this.cells[e],n=this.positions,i=new Array(r.length),a=0;a<r.length;++a)i[a]=n[r[a]];var o=t.coord[0],s=t.coord[1];if(!this.pickVertex){var l=this.positions[r[0]],c=this.positions[r[1]],u=this.positions[r[2]],f=[(l[0]+c[0]+u[0])/3,(l[1]+c[1]+u[1])/3,(l[2]+c[2]+u[2])/3];return{_cellCenter:!0,position:[o,s],index:e,cell:r,cellId:e,intensity:this.intensity[e],dataCoordinate:f}}var h=m(i,[o*this.pixelRatio,this._resolution[1]-s*this.pixelRatio],this._model,this._view,this._projection,this._resolution);if(!h)return null;var p=h[2],d=0;for(a=0;a<r.length;++a)d+=p[a]*this.intensity[r[a]];return{position:h[1],index:r[h[0]],cell:r,cellId:e,intensity:d,dataCoordinate:this.positions[r[h[0]]]}},k.dispose=function(){this.texture.dispose(),this.triShader.dispose(),this.lineShader.dispose(),this.pointShader.dispose(),this.pickShader.dispose(),this.pointPickShader.dispose(),this.triangleVAO.dispose(),this.trianglePositions.dispose(),this.triangleColors.dispose(),this.triangleUVs.dispose(),this.triangleNormals.dispose(),this.triangleIds.dispose(),this.edgeVAO.dispose(),this.edgePositions.dispose(),this.edgeColors.dispose(),this.edgeUVs.dispose(),this.edgeIds.dispose(),this.pointVAO.dispose(),this.pointPositions.dispose(),this.pointColors.dispose(),this.pointUVs.dispose(),this.pointSizes.dispose(),this.pointIds.dispose(),this.contourVAO.dispose(),this.contourPositions.dispose(),this.contourShader.dispose()},e.exports=function(t,e){1===arguments.length&&(t=(e=t).gl);var r=t.getExtension(\"OES_standard_derivatives\")||t.getExtension(\"MOZ_OES_standard_derivatives\")||t.getExtension(\"WEBKIT_OES_standard_derivatives\");if(!r)throw new Error(\"derivatives not supported\");var n=A(t),s=S(t),l=E(t),c=L(t),f=C(t),h=P(t),p=o(t,u(new Uint8Array([255,255,255,255]),[1,1,4]));p.generateMipmap(),p.minFilter=t.LINEAR_MIPMAP_LINEAR,p.magFilter=t.LINEAR;var d=i(t),m=i(t),g=i(t),v=i(t),y=i(t),x=a(t,[{buffer:d,type:t.FLOAT,size:3},{buffer:y,type:t.UNSIGNED_BYTE,size:4,normalized:!0},{buffer:m,type:t.FLOAT,size:4},{buffer:g,type:t.FLOAT,size:2},{buffer:v,type:t.FLOAT,size:3}]),b=i(t),_=i(t),w=i(t),k=i(t),M=a(t,[{buffer:b,type:t.FLOAT,size:3},{buffer:k,type:t.UNSIGNED_BYTE,size:4,normalized:!0},{buffer:_,type:t.FLOAT,size:4},{buffer:w,type:t.FLOAT,size:2}]),I=i(t),O=i(t),z=i(t),D=i(t),R=i(t),F=a(t,[{buffer:I,type:t.FLOAT,size:3},{buffer:R,type:t.UNSIGNED_BYTE,size:4,normalized:!0},{buffer:O,type:t.FLOAT,size:4},{buffer:z,type:t.FLOAT,size:2},{buffer:D,type:t.FLOAT,size:1}]),B=i(t),N=a(t,[{buffer:B,type:t.FLOAT,size:3}]),j=new T(t,p,n,s,l,c,f,h,d,y,m,g,v,x,b,k,_,w,M,I,R,O,z,D,F,B,N);return j.update(e),j}},{\"./lib/closest-point\":309,\"./lib/shaders\":310,colormap:137,\"gl-buffer\":263,\"gl-mat4/invert\":295,\"gl-mat4/multiply\":297,\"gl-shader\":335,\"gl-texture2d\":352,\"gl-vao\":357,ndarray:479,normals:482,\"simplicial-complex-contour\":553,\"typedarray-pool\":613}],312:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.gl,r=n(e,[0,0,0,1,1,0,1,1]),s=i(e,a.boxVert,a.lineFrag);return new o(t,r,s)};var n=t(\"gl-buffer\"),i=t(\"gl-shader\"),a=t(\"./shaders\");function o(t,e,r){this.plot=t,this.vbo=e,this.shader=r}var s,l,c=o.prototype;c.bind=function(){var t=this.shader;this.vbo.bind(),this.shader.bind(),t.attributes.coord.pointer(),t.uniforms.screenBox=this.plot.screenBox},c.drawBox=(s=[0,0],l=[0,0],function(t,e,r,n,i){var a=this.plot,o=this.shader,c=a.gl;s[0]=t,s[1]=e,l[0]=r,l[1]=n,o.uniforms.lo=s,o.uniforms.hi=l,o.uniforms.color=i,c.drawArrays(c.TRIANGLE_STRIP,0,4)}),c.dispose=function(){this.vbo.dispose(),this.shader.dispose()}},{\"./shaders\":315,\"gl-buffer\":263,\"gl-shader\":335}],313:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.gl,r=n(e),a=i(e,o.gridVert,o.gridFrag),l=i(e,o.tickVert,o.gridFrag);return new s(t,r,a,l)};var n=t(\"gl-buffer\"),i=t(\"gl-shader\"),a=t(\"binary-search-bounds\"),o=t(\"./shaders\");function s(t,e,r,n){this.plot=t,this.vbo=e,this.shader=r,this.tickShader=n,this.ticks=[[],[]]}function l(t,e){return t-e}var c,u,f,h,p,d=s.prototype;d.draw=(c=[0,0],u=[0,0],f=[0,0],function(){for(var t=this.plot,e=this.vbo,r=this.shader,n=this.ticks,i=t.gl,a=t._tickBounds,o=t.dataBox,s=t.viewBox,l=t.gridLineWidth,h=t.gridLineColor,p=t.gridLineEnable,d=t.pixelRatio,m=0;m<2;++m){var g=a[m],v=a[m+2]-g,y=.5*(o[m+2]+o[m]),x=o[m+2]-o[m];u[m]=2*v/x,c[m]=2*(g-y)/x}r.bind(),e.bind(),r.attributes.dataCoord.pointer(),r.uniforms.dataShift=c,r.uniforms.dataScale=u;var b=0;for(m=0;m<2;++m){f[0]=f[1]=0,f[m]=1,r.uniforms.dataAxis=f,r.uniforms.lineWidth=l[m]/(s[m+2]-s[m])*d,r.uniforms.color=h[m];var _=6*n[m].length;p[m]&&_&&i.drawArrays(i.TRIANGLES,b,_),b+=_}}),d.drawTickMarks=function(){var t=[0,0],e=[0,0],r=[1,0],n=[0,1],i=[0,0],o=[0,0];return function(){for(var s=this.plot,c=this.vbo,u=this.tickShader,f=this.ticks,h=s.gl,p=s._tickBounds,d=s.dataBox,m=s.viewBox,g=s.pixelRatio,v=s.screenBox,y=v[2]-v[0],x=v[3]-v[1],b=m[2]-m[0],_=m[3]-m[1],w=0;w<2;++w){var T=p[w],k=p[w+2]-T,M=.5*(d[w+2]+d[w]),A=d[w+2]-d[w];e[w]=2*k/A,t[w]=2*(T-M)/A}e[0]*=b/y,t[0]*=b/y,e[1]*=_/x,t[1]*=_/x,u.bind(),c.bind(),u.attributes.dataCoord.pointer();var S=u.uniforms;S.dataShift=t,S.dataScale=e;var E=s.tickMarkLength,L=s.tickMarkWidth,C=s.tickMarkColor,P=6*f[0].length,I=Math.min(a.ge(f[0],(d[0]-p[0])/(p[2]-p[0]),l),f[0].length),O=Math.min(a.gt(f[0],(d[2]-p[0])/(p[2]-p[0]),l),f[0].length),z=0+6*I,D=6*Math.max(0,O-I),R=Math.min(a.ge(f[1],(d[1]-p[1])/(p[3]-p[1]),l),f[1].length),F=Math.min(a.gt(f[1],(d[3]-p[1])/(p[3]-p[1]),l),f[1].length),B=P+6*R,N=6*Math.max(0,F-R);i[0]=2*(m[0]-E[1])/y-1,i[1]=(m[3]+m[1])/x-1,o[0]=E[1]*g/y,o[1]=L[1]*g/x,N&&(S.color=C[1],S.tickScale=o,S.dataAxis=n,S.screenOffset=i,h.drawArrays(h.TRIANGLES,B,N)),i[0]=(m[2]+m[0])/y-1,i[1]=2*(m[1]-E[0])/x-1,o[0]=L[0]*g/y,o[1]=E[0]*g/x,D&&(S.color=C[0],S.tickScale=o,S.dataAxis=r,S.screenOffset=i,h.drawArrays(h.TRIANGLES,z,D)),i[0]=2*(m[2]+E[3])/y-1,i[1]=(m[3]+m[1])/x-1,o[0]=E[3]*g/y,o[1]=L[3]*g/x,N&&(S.color=C[3],S.tickScale=o,S.dataAxis=n,S.screenOffset=i,h.drawArrays(h.TRIANGLES,B,N)),i[0]=(m[2]+m[0])/y-1,i[1]=2*(m[3]+E[2])/x-1,o[0]=L[2]*g/y,o[1]=E[2]*g/x,D&&(S.color=C[2],S.tickScale=o,S.dataAxis=r,S.screenOffset=i,h.drawArrays(h.TRIANGLES,z,D))}}(),d.update=(h=[1,1,-1,-1,1,-1],p=[1,-1,1,1,-1,-1],function(t){for(var e=t.ticks,r=t.bounds,n=new Float32Array(18*(e[0].length+e[1].length)),i=(this.plot.zeroLineEnable,0),a=[[],[]],o=0;o<2;++o)for(var s=a[o],l=e[o],c=r[o],u=r[o+2],f=0;f<l.length;++f){var d=(l[f].x-c)/(u-c);s.push(d);for(var m=0;m<6;++m)n[i++]=d,n[i++]=h[m],n[i++]=p[m]}this.ticks=a,this.vbo.update(n)}),d.dispose=function(){this.vbo.dispose(),this.shader.dispose(),this.tickShader.dispose()}},{\"./shaders\":315,\"binary-search-bounds\":103,\"gl-buffer\":263,\"gl-shader\":335}],314:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.gl,r=n(e,[-1,-1,-1,1,1,-1,1,1]),s=i(e,a.lineVert,a.lineFrag);return new o(t,r,s)};var n=t(\"gl-buffer\"),i=t(\"gl-shader\"),a=t(\"./shaders\");function o(t,e,r){this.plot=t,this.vbo=e,this.shader=r}var s,l,c=o.prototype;c.bind=function(){var t=this.shader;this.vbo.bind(),this.shader.bind(),t.attributes.coord.pointer(),t.uniforms.screenBox=this.plot.screenBox},c.drawLine=(s=[0,0],l=[0,0],function(t,e,r,n,i,a){var o=this.plot,c=this.shader,u=o.gl;s[0]=t,s[1]=e,l[0]=r,l[1]=n,c.uniforms.start=s,c.uniforms.end=l,c.uniforms.width=i*o.pixelRatio,c.uniforms.color=a,u.drawArrays(u.TRIANGLE_STRIP,0,4)}),c.dispose=function(){this.vbo.dispose(),this.shader.dispose()}},{\"./shaders\":315,\"gl-buffer\":263,\"gl-shader\":335}],315:[function(t,e,r){\"use strict\";var n=t(\"glslify\"),i=n([\"precision lowp float;\\n#define GLSLIFY 1\\nuniform vec4 color;\\nvoid main() {\\n  gl_FragColor = vec4(color.xyz * color.w, color.w);\\n}\\n\"]);e.exports={lineVert:n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec2 coord;\\n\\nuniform vec4 screenBox;\\nuniform vec2 start, end;\\nuniform float width;\\n\\nvec2 perp(vec2 v) {\\n  return vec2(v.y, -v.x);\\n}\\n\\nvec2 screen(vec2 v) {\\n  return 2.0 * (v - screenBox.xy) / (screenBox.zw - screenBox.xy) - 1.0;\\n}\\n\\nvoid main() {\\n  vec2 delta = normalize(perp(start - end));\\n  vec2 offset = mix(start, end, 0.5 * (coord.y+1.0));\\n  gl_Position = vec4(screen(offset + 0.5 * width * delta * coord.x), 0, 1);\\n}\\n\"]),lineFrag:i,textVert:n([\"#define GLSLIFY 1\\nattribute vec3 textCoordinate;\\n\\nuniform vec2 dataScale, dataShift, dataAxis, screenOffset, textScale;\\nuniform float angle;\\n\\nvoid main() {\\n  float dataOffset  = textCoordinate.z;\\n  vec2 glyphOffset  = textCoordinate.xy;\\n  mat2 glyphMatrix = mat2(cos(angle), sin(angle), -sin(angle), cos(angle));\\n  vec2 screenCoordinate = dataAxis * (dataScale * dataOffset + dataShift) +\\n    glyphMatrix * glyphOffset * textScale + screenOffset;\\n  gl_Position = vec4(screenCoordinate, 0, 1);\\n}\\n\"]),textFrag:i,gridVert:n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec3 dataCoord;\\n\\nuniform vec2 dataAxis, dataShift, dataScale;\\nuniform float lineWidth;\\n\\nvoid main() {\\n  vec2 pos = dataAxis * (dataScale * dataCoord.x + dataShift);\\n  pos += 10.0 * dataCoord.y * vec2(dataAxis.y, -dataAxis.x) + dataCoord.z * lineWidth;\\n  gl_Position = vec4(pos, 0, 1);\\n}\\n\"]),gridFrag:i,boxVert:n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec2 coord;\\n\\nuniform vec4 screenBox;\\nuniform vec2 lo, hi;\\n\\nvec2 screen(vec2 v) {\\n  return 2.0 * (v - screenBox.xy) / (screenBox.zw - screenBox.xy) - 1.0;\\n}\\n\\nvoid main() {\\n  gl_Position = vec4(screen(mix(lo, hi, coord)), 0, 1);\\n}\\n\"]),tickVert:n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec3 dataCoord;\\n\\nuniform vec2 dataAxis, dataShift, dataScale, screenOffset, tickScale;\\n\\nvoid main() {\\n  vec2 pos = dataAxis * (dataScale * dataCoord.x + dataShift);\\n  gl_Position = vec4(pos + tickScale*dataCoord.yz + screenOffset, 0, 1);\\n}\\n\"])}},{glslify:317}],316:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.gl,r=n(e),a=i(e,s.textVert,s.textFrag);return new l(t,r,a)};var n=t(\"gl-buffer\"),i=t(\"gl-shader\"),a=t(\"text-cache\"),o=t(\"binary-search-bounds\"),s=t(\"./shaders\");function l(t,e,r){this.plot=t,this.vbo=e,this.shader=r,this.tickOffset=[[],[]],this.tickX=[[],[]],this.labelOffset=[0,0],this.labelCount=[0,0]}var c,u,f,h,p,d,m=l.prototype;m.drawTicks=(c=[0,0],u=[0,0],f=[0,0],function(t){var e=this.plot,r=this.shader,n=this.tickX[t],i=this.tickOffset[t],a=e.gl,s=e.viewBox,l=e.dataBox,h=e.screenBox,p=e.pixelRatio,d=e.tickEnable,m=e.tickPad,g=e.tickColor,v=e.tickAngle,y=e.labelEnable,x=e.labelPad,b=e.labelColor,_=e.labelAngle,w=this.labelOffset[t],T=this.labelCount[t],k=o.lt(n,l[t]),M=o.le(n,l[t+2]);c[0]=c[1]=0,c[t]=1,u[t]=(s[2+t]+s[t])/(h[2+t]-h[t])-1;var A=2/h[2+(1^t)]-h[1^t];u[1^t]=A*s[1^t]-1,d[t]&&(u[1^t]-=A*p*m[t],k<M&&i[M]>i[k]&&(r.uniforms.dataAxis=c,r.uniforms.screenOffset=u,r.uniforms.color=g[t],r.uniforms.angle=v[t],a.drawArrays(a.TRIANGLES,i[k],i[M]-i[k]))),y[t]&&T&&(u[1^t]-=A*p*x[t],r.uniforms.dataAxis=f,r.uniforms.screenOffset=u,r.uniforms.color=b[t],r.uniforms.angle=_[t],a.drawArrays(a.TRIANGLES,w,T)),u[1^t]=A*s[2+(1^t)]-1,d[t+2]&&(u[1^t]+=A*p*m[t+2],k<M&&i[M]>i[k]&&(r.uniforms.dataAxis=c,r.uniforms.screenOffset=u,r.uniforms.color=g[t+2],r.uniforms.angle=v[t+2],a.drawArrays(a.TRIANGLES,i[k],i[M]-i[k]))),y[t+2]&&T&&(u[1^t]+=A*p*x[t+2],r.uniforms.dataAxis=f,r.uniforms.screenOffset=u,r.uniforms.color=b[t+2],r.uniforms.angle=_[t+2],a.drawArrays(a.TRIANGLES,w,T))}),m.drawTitle=function(){var t=[0,0],e=[0,0];return function(){var r=this.plot,n=this.shader,i=r.gl,a=r.screenBox,o=r.titleCenter,s=r.titleAngle,l=r.titleColor,c=r.pixelRatio;if(this.titleCount){for(var u=0;u<2;++u)e[u]=2*(o[u]*c-a[u])/(a[2+u]-a[u])-1;n.bind(),n.uniforms.dataAxis=t,n.uniforms.screenOffset=e,n.uniforms.angle=s,n.uniforms.color=l,i.drawArrays(i.TRIANGLES,this.titleOffset,this.titleCount)}}}(),m.bind=(h=[0,0],p=[0,0],d=[0,0],function(){var t=this.plot,e=this.shader,r=t._tickBounds,n=t.dataBox,i=t.screenBox,a=t.viewBox;e.bind();for(var o=0;o<2;++o){var s=r[o],l=r[o+2]-s,c=.5*(n[o+2]+n[o]),u=n[o+2]-n[o],f=a[o],m=a[o+2]-f,g=i[o],v=i[o+2]-g;p[o]=2*l/u*m/v,h[o]=2*(s-c)/u*m/v}d[1]=2*t.pixelRatio/(i[3]-i[1]),d[0]=d[1]*(i[3]-i[1])/(i[2]-i[0]),e.uniforms.dataScale=p,e.uniforms.dataShift=h,e.uniforms.textScale=d,this.vbo.bind(),e.attributes.textCoordinate.pointer()}),m.update=function(t){var e,r,n,i,o,s=[],l=t.ticks,c=t.bounds;for(o=0;o<2;++o){var u=[Math.floor(s.length/3)],f=[-1/0],h=l[o];for(e=0;e<h.length;++e){var p=h[e],d=p.x,m=p.text,g=p.font||\"sans-serif\";i=p.fontSize||12;for(var v=1/(c[o+2]-c[o]),y=c[o],x=m.split(\"\\n\"),b=0;b<x.length;b++)for(n=a(g,x[b]).data,r=0;r<n.length;r+=2)s.push(n[r]*i,-n[r+1]*i-b*i*1.2,(d-y)*v);u.push(Math.floor(s.length/3)),f.push(d)}this.tickOffset[o]=u,this.tickX[o]=f}for(o=0;o<2;++o){for(this.labelOffset[o]=Math.floor(s.length/3),n=a(t.labelFont[o],t.labels[o],{textAlign:\"center\"}).data,i=t.labelSize[o],e=0;e<n.length;e+=2)s.push(n[e]*i,-n[e+1]*i,0);this.labelCount[o]=Math.floor(s.length/3)-this.labelOffset[o]}for(this.titleOffset=Math.floor(s.length/3),n=a(t.titleFont,t.title).data,i=t.titleSize,e=0;e<n.length;e+=2)s.push(n[e]*i,-n[e+1]*i,0);this.titleCount=Math.floor(s.length/3)-this.titleOffset,this.vbo.update(s)},m.dispose=function(){this.vbo.dispose(),this.shader.dispose()}},{\"./shaders\":315,\"binary-search-bounds\":103,\"gl-buffer\":263,\"gl-shader\":335,\"text-cache\":592}],317:[function(t,e,r){arguments[4][261][0].apply(r,arguments)},{dup:261}],318:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.gl,r=n(e,[e.drawingBufferWidth,e.drawingBufferHeight]),c=new l(e,r);return c.grid=i(c),c.text=a(c),c.line=o(c),c.box=s(c),c.update(t),c};var n=t(\"gl-select-static\"),i=t(\"./lib/grid\"),a=t(\"./lib/text\"),o=t(\"./lib/line\"),s=t(\"./lib/box\");function l(t,e){this.gl=t,this.pickBuffer=e,this.screenBox=[0,0,t.drawingBufferWidth,t.drawingBufferHeight],this.viewBox=[0,0,0,0],this.dataBox=[-10,-10,10,10],this.gridLineEnable=[!0,!0],this.gridLineWidth=[1,1],this.gridLineColor=[[0,0,0,1],[0,0,0,1]],this.pixelRatio=1,this.tickMarkLength=[0,0,0,0],this.tickMarkWidth=[0,0,0,0],this.tickMarkColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.tickPad=[15,15,15,15],this.tickAngle=[0,0,0,0],this.tickEnable=[!0,!0,!0,!0],this.tickColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.labelPad=[15,15,15,15],this.labelAngle=[0,Math.PI/2,0,3*Math.PI/2],this.labelEnable=[!0,!0,!0,!0],this.labelColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.titleCenter=[0,0],this.titleEnable=!0,this.titleAngle=0,this.titleColor=[0,0,0,1],this.borderColor=[0,0,0,0],this.backgroundColor=[0,0,0,0],this.zeroLineEnable=[!0,!0],this.zeroLineWidth=[4,4],this.zeroLineColor=[[0,0,0,1],[0,0,0,1]],this.borderLineEnable=[!0,!0,!0,!0],this.borderLineWidth=[2,2,2,2],this.borderLineColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.grid=null,this.text=null,this.line=null,this.box=null,this.objects=[],this.overlays=[],this._tickBounds=[1/0,1/0,-1/0,-1/0],this.static=!1,this.dirty=!1,this.pickDirty=!1,this.pickDelay=120,this.pickRadius=10,this._pickTimeout=null,this._drawPick=this.drawPick.bind(this),this._depthCounter=0}var c=l.prototype;function u(t){for(var e=t.slice(),r=0;r<e.length;++r)e[r]=e[r].slice();return e}function f(t,e){return t.x-e.x}c.setDirty=function(){this.dirty=this.pickDirty=!0},c.setOverlayDirty=function(){this.dirty=!0},c.nextDepthValue=function(){return this._depthCounter++/65536},c.draw=function(){var t=this.gl,e=this.screenBox,r=this.viewBox,n=this.dataBox,i=this.pixelRatio,a=this.grid,o=this.line,s=this.text,l=this.objects;if(this._depthCounter=0,this.pickDirty&&(this._pickTimeout&&clearTimeout(this._pickTimeout),this.pickDirty=!1,this._pickTimeout=setTimeout(this._drawPick,this.pickDelay)),this.dirty){if(this.dirty=!1,t.bindFramebuffer(t.FRAMEBUFFER,null),t.enable(t.SCISSOR_TEST),t.disable(t.DEPTH_TEST),t.depthFunc(t.LESS),t.depthMask(!1),t.enable(t.BLEND),t.blendEquation(t.FUNC_ADD,t.FUNC_ADD),t.blendFunc(t.ONE,t.ONE_MINUS_SRC_ALPHA),this.borderColor){t.scissor(e[0],e[1],e[2]-e[0],e[3]-e[1]);var c=this.borderColor;t.clearColor(c[0]*c[3],c[1]*c[3],c[2]*c[3],c[3]),t.clear(t.COLOR_BUFFER_BIT|t.DEPTH_BUFFER_BIT)}t.scissor(r[0],r[1],r[2]-r[0],r[3]-r[1]),t.viewport(r[0],r[1],r[2]-r[0],r[3]-r[1]);var u=this.backgroundColor;t.clearColor(u[0]*u[3],u[1]*u[3],u[2]*u[3],u[3]),t.clear(t.COLOR_BUFFER_BIT),a.draw();var f=this.zeroLineEnable,h=this.zeroLineColor,p=this.zeroLineWidth;if(f[0]||f[1]){o.bind();for(var d=0;d<2;++d)if(f[d]&&n[d]<=0&&n[d+2]>=0){var m=e[d]-n[d]*(e[d+2]-e[d])/(n[d+2]-n[d]);0===d?o.drawLine(m,e[1],m,e[3],p[d],h[d]):o.drawLine(e[0],m,e[2],m,p[d],h[d])}}for(d=0;d<l.length;++d)l[d].draw();t.viewport(e[0],e[1],e[2]-e[0],e[3]-e[1]),t.scissor(e[0],e[1],e[2]-e[0],e[3]-e[1]),this.grid.drawTickMarks(),o.bind();var g=this.borderLineEnable,v=this.borderLineWidth,y=this.borderLineColor;for(g[1]&&o.drawLine(r[0],r[1]-.5*v[1]*i,r[0],r[3]+.5*v[3]*i,v[1],y[1]),g[0]&&o.drawLine(r[0]-.5*v[0]*i,r[1],r[2]+.5*v[2]*i,r[1],v[0],y[0]),g[3]&&o.drawLine(r[2],r[1]-.5*v[1]*i,r[2],r[3]+.5*v[3]*i,v[3],y[3]),g[2]&&o.drawLine(r[0]-.5*v[0]*i,r[3],r[2]+.5*v[2]*i,r[3],v[2],y[2]),s.bind(),d=0;d<2;++d)s.drawTicks(d);this.titleEnable&&s.drawTitle();var x=this.overlays;for(d=0;d<x.length;++d)x[d].draw();t.disable(t.SCISSOR_TEST),t.disable(t.BLEND),t.depthMask(!0)}},c.drawPick=function(){if(!this.static){var t=this.pickBuffer;this.gl,this._pickTimeout=null,t.begin();for(var e=1,r=this.objects,n=0;n<r.length;++n)e=r[n].drawPick(e);t.end()}},c.pick=function(t,e){if(!this.static){var r=this.pixelRatio,n=this.pickPixelRatio,i=this.viewBox,a=0|Math.round((t-i[0]/r)*n),o=0|Math.round((e-i[1]/r)*n),s=this.pickBuffer.query(a,o,this.pickRadius);if(!s)return null;for(var l=s.id+(s.value[0]<<8)+(s.value[1]<<16)+(s.value[2]<<24),c=this.objects,u=0;u<c.length;++u){var f=c[u].pick(a,o,l);if(f)return f}return null}},c.setScreenBox=function(t){var e=this.screenBox,r=this.pixelRatio;e[0]=0|Math.round(t[0]*r),e[1]=0|Math.round(t[1]*r),e[2]=0|Math.round(t[2]*r),e[3]=0|Math.round(t[3]*r),this.setDirty()},c.setDataBox=function(t){var e=this.dataBox;(e[0]!==t[0]||e[1]!==t[1]||e[2]!==t[2]||e[3]!==t[3])&&(e[0]=t[0],e[1]=t[1],e[2]=t[2],e[3]=t[3],this.setDirty())},c.setViewBox=function(t){var e=this.pixelRatio,r=this.viewBox;r[0]=0|Math.round(t[0]*e),r[1]=0|Math.round(t[1]*e),r[2]=0|Math.round(t[2]*e),r[3]=0|Math.round(t[3]*e);var n=this.pickPixelRatio;this.pickBuffer.shape=[0|Math.round((t[2]-t[0])*n),0|Math.round((t[3]-t[1])*n)],this.setDirty()},c.update=function(t){t=t||{};var e=this.gl;this.pixelRatio=t.pixelRatio||1;var r=this.pixelRatio;this.pickPixelRatio=Math.max(r,1),this.setScreenBox(t.screenBox||[0,0,e.drawingBufferWidth/r,e.drawingBufferHeight/r]);this.screenBox;this.setViewBox(t.viewBox||[.125*(this.screenBox[2]-this.screenBox[0])/r,.125*(this.screenBox[3]-this.screenBox[1])/r,.875*(this.screenBox[2]-this.screenBox[0])/r,.875*(this.screenBox[3]-this.screenBox[1])/r]);var n=this.viewBox,i=(n[2]-n[0])/(n[3]-n[1]);this.setDataBox(t.dataBox||[-10,-10/i,10,10/i]),this.borderColor=!1!==t.borderColor&&(t.borderColor||[0,0,0,0]).slice(),this.backgroundColor=(t.backgroundColor||[0,0,0,0]).slice(),this.gridLineEnable=(t.gridLineEnable||[!0,!0]).slice(),this.gridLineWidth=(t.gridLineWidth||[1,1]).slice(),this.gridLineColor=u(t.gridLineColor||[[.5,.5,.5,1],[.5,.5,.5,1]]),this.zeroLineEnable=(t.zeroLineEnable||[!0,!0]).slice(),this.zeroLineWidth=(t.zeroLineWidth||[4,4]).slice(),this.zeroLineColor=u(t.zeroLineColor||[[0,0,0,1],[0,0,0,1]]),this.tickMarkLength=(t.tickMarkLength||[0,0,0,0]).slice(),this.tickMarkWidth=(t.tickMarkWidth||[0,0,0,0]).slice(),this.tickMarkColor=u(t.tickMarkColor||[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]]),this.titleCenter=(t.titleCenter||[.5*(n[0]+n[2])/r,(n[3]+120)/r]).slice(),this.titleEnable=!(\"titleEnable\"in t)||!!t.titleEnable,this.titleAngle=t.titleAngle||0,this.titleColor=(t.titleColor||[0,0,0,1]).slice(),this.labelPad=(t.labelPad||[15,15,15,15]).slice(),this.labelAngle=(t.labelAngle||[0,Math.PI/2,0,3*Math.PI/2]).slice(),this.labelEnable=(t.labelEnable||[!0,!0,!0,!0]).slice(),this.labelColor=u(t.labelColor||[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]]),this.tickPad=(t.tickPad||[15,15,15,15]).slice(),this.tickAngle=(t.tickAngle||[0,0,0,0]).slice(),this.tickEnable=(t.tickEnable||[!0,!0,!0,!0]).slice(),this.tickColor=u(t.tickColor||[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]]),this.borderLineEnable=(t.borderLineEnable||[!0,!0,!0,!0]).slice(),this.borderLineWidth=(t.borderLineWidth||[2,2,2,2]).slice(),this.borderLineColor=u(t.borderLineColor||[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]]);var a=t.ticks||[[],[]],o=this._tickBounds;o[0]=o[1]=1/0,o[2]=o[3]=-1/0;for(var s=0;s<2;++s){var l=a[s].slice(0);0!==l.length&&(l.sort(f),o[s]=Math.min(o[s],l[0].x),o[s+2]=Math.max(o[s+2],l[l.length-1].x))}this.grid.update({bounds:o,ticks:a}),this.text.update({bounds:o,ticks:a,labels:t.labels||[\"x\",\"y\"],labelSize:t.labelSize||[12,12],labelFont:t.labelFont||[\"sans-serif\",\"sans-serif\"],title:t.title||\"\",titleSize:t.titleSize||18,titleFont:t.titleFont||\"sans-serif\"}),this.static=!!t.static,this.setDirty()},c.dispose=function(){this.box.dispose(),this.grid.dispose(),this.text.dispose(),this.line.dispose();for(var t=this.objects.length-1;t>=0;--t)this.objects[t].dispose();this.objects.length=0;for(t=this.overlays.length-1;t>=0;--t)this.overlays[t].dispose();this.overlays.length=0,this.gl=null},c.addObject=function(t){this.objects.indexOf(t)<0&&(this.objects.push(t),this.setDirty())},c.removeObject=function(t){for(var e=this.objects,r=0;r<e.length;++r)if(e[r]===t){e.splice(r,1),this.setDirty();break}},c.addOverlay=function(t){this.overlays.indexOf(t)<0&&(this.overlays.push(t),this.setOverlayDirty())},c.removeOverlay=function(t){for(var e=this.overlays,r=0;r<e.length;++r)if(e[r]===t){e.splice(r,1),this.setOverlayDirty();break}}},{\"./lib/box\":312,\"./lib/grid\":313,\"./lib/line\":314,\"./lib/text\":316,\"gl-select-static\":334}],319:[function(t,e,r){\"use strict\";e.exports=function(t,e){t=t||document.body,e=e||{};var r=[.01,1/0];\"distanceLimits\"in e&&(r[0]=e.distanceLimits[0],r[1]=e.distanceLimits[1]);\"zoomMin\"in e&&(r[0]=e.zoomMin);\"zoomMax\"in e&&(r[1]=e.zoomMax);var c=i({center:e.center||[0,0,0],up:e.up||[0,1,0],eye:e.eye||[0,0,10],mode:e.mode||\"orbit\",distanceLimits:r}),u=[0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0],f=0,h=t.clientWidth,p=t.clientHeight,d={keyBindingMode:\"rotate\",enableWheel:!0,view:c,element:t,delay:e.delay||16,rotateSpeed:e.rotateSpeed||1,zoomSpeed:e.zoomSpeed||1,translateSpeed:e.translateSpeed||1,flipX:!!e.flipX,flipY:!!e.flipY,modes:c.modes,_ortho:e._ortho||e.projection&&\"orthographic\"===e.projection.type||!1,tick:function(){var e=n(),r=this.delay,i=e-2*r;c.idle(e-r),c.recalcMatrix(i),c.flush(e-(100+2*r));for(var a=!0,o=c.computedMatrix,s=0;s<16;++s)a=a&&u[s]===o[s],u[s]=o[s];var l=t.clientWidth===h&&t.clientHeight===p;return h=t.clientWidth,p=t.clientHeight,a?!l:(f=Math.exp(c.computedRadius[0]),!0)},lookAt:function(t,e,r){c.lookAt(c.lastT(),t,e,r)},rotate:function(t,e,r){c.rotate(c.lastT(),t,e,r)},pan:function(t,e,r){c.pan(c.lastT(),t,e,r)},translate:function(t,e,r){c.translate(c.lastT(),t,e,r)}};return Object.defineProperties(d,{matrix:{get:function(){return c.computedMatrix},set:function(t){return c.setMatrix(c.lastT(),t),c.computedMatrix},enumerable:!0},mode:{get:function(){return c.getMode()},set:function(t){var e=c.computedUp.slice(),r=c.computedEye.slice(),i=c.computedCenter.slice();if(c.setMode(t),\"turntable\"===t){var a=n();c._active.lookAt(a,r,i,e),c._active.lookAt(a+500,r,i,[0,0,1]),c._active.flush(a)}return c.getMode()},enumerable:!0},center:{get:function(){return c.computedCenter},set:function(t){return c.lookAt(c.lastT(),null,t),c.computedCenter},enumerable:!0},eye:{get:function(){return c.computedEye},set:function(t){return c.lookAt(c.lastT(),t),c.computedEye},enumerable:!0},up:{get:function(){return c.computedUp},set:function(t){return c.lookAt(c.lastT(),null,null,t),c.computedUp},enumerable:!0},distance:{get:function(){return f},set:function(t){return c.setDistance(c.lastT(),t),t},enumerable:!0},distanceLimits:{get:function(){return c.getDistanceLimits(r)},set:function(t){return c.setDistanceLimits(t),t},enumerable:!0}}),t.addEventListener(\"contextmenu\",(function(t){return t.preventDefault(),!1})),d._lastX=-1,d._lastY=-1,d._lastMods={shift:!1,control:!1,alt:!1,meta:!1},d.enableMouseListeners=function(){function e(e,r,i,a){var o=d.keyBindingMode;if(!1!==o){var s=\"rotate\"===o,l=\"pan\"===o,u=\"zoom\"===o,h=!!a.control,p=!!a.alt,m=!!a.shift,g=!!(1&e),v=!!(2&e),y=!!(4&e),x=1/t.clientHeight,b=x*(r-d._lastX),_=x*(i-d._lastY),w=d.flipX?1:-1,T=d.flipY?1:-1,k=Math.PI*d.rotateSpeed,M=n();if(-1!==d._lastX&&-1!==d._lastY&&((s&&g&&!h&&!p&&!m||g&&!h&&!p&&m)&&c.rotate(M,w*k*b,-T*k*_,0),(l&&g&&!h&&!p&&!m||v||g&&h&&!p&&!m)&&c.pan(M,-d.translateSpeed*b*f,d.translateSpeed*_*f,0),u&&g&&!h&&!p&&!m||y||g&&!h&&p&&!m)){var A=-d.zoomSpeed*_/window.innerHeight*(M-c.lastT())*100;c.pan(M,0,0,f*(Math.exp(A)-1))}return d._lastX=r,d._lastY=i,d._lastMods=a,!0}}d.mouseListener=a(t,e),t.addEventListener(\"touchstart\",(function(r){var n=s(r.changedTouches[0],t);e(0,n[0],n[1],d._lastMods),e(1,n[0],n[1],d._lastMods)}),!!l&&{passive:!0}),t.addEventListener(\"touchmove\",(function(r){var n=s(r.changedTouches[0],t);e(1,n[0],n[1],d._lastMods),r.preventDefault()}),!!l&&{passive:!1}),t.addEventListener(\"touchend\",(function(t){e(0,d._lastX,d._lastY,d._lastMods)}),!!l&&{passive:!0}),d.wheelListener=o(t,(function(t,e){if(!1!==d.keyBindingMode&&d.enableWheel){var r=d.flipX?1:-1,i=d.flipY?1:-1,a=n();if(Math.abs(t)>Math.abs(e))c.rotate(a,0,0,-t*r*Math.PI*d.rotateSpeed/window.innerWidth);else if(!d._ortho){var o=-d.zoomSpeed*i*e/window.innerHeight*(a-c.lastT())/20;c.pan(a,0,0,f*(Math.exp(o)-1))}}}),!0)},d.enableMouseListeners(),d};var n=t(\"right-now\"),i=t(\"3d-view\"),a=t(\"mouse-change\"),o=t(\"mouse-wheel\"),s=t(\"mouse-event-offset\"),l=t(\"has-passive-events\")},{\"3d-view\":55,\"has-passive-events\":440,\"mouse-change\":466,\"mouse-event-offset\":467,\"mouse-wheel\":469,\"right-now\":538}],320:[function(t,e,r){var n=t(\"glslify\"),i=t(\"gl-shader\"),a=n([\"precision mediump float;\\n#define GLSLIFY 1\\nattribute vec2 position;\\nvarying vec2 uv;\\nvoid main() {\\n  uv = position;\\n  gl_Position = vec4(position, 0, 1);\\n}\"]),o=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nuniform sampler2D accumBuffer;\\nvarying vec2 uv;\\n\\nvoid main() {\\n  vec4 accum = texture2D(accumBuffer, 0.5 * (uv + 1.0));\\n  gl_FragColor = min(vec4(1,1,1,1), accum);\\n}\"]);e.exports=function(t){return i(t,a,o,null,[{name:\"position\",type:\"vec2\"}])}},{\"gl-shader\":335,glslify:321}],321:[function(t,e,r){arguments[4][261][0].apply(r,arguments)},{dup:261}],322:[function(t,e,r){\"use strict\";var n=t(\"./camera.js\"),i=t(\"gl-axes3d\"),a=t(\"gl-axes3d/properties\"),o=t(\"gl-spikes3d\"),s=t(\"gl-select-static\"),l=t(\"gl-fbo\"),c=t(\"a-big-triangle\"),u=t(\"mouse-change\"),f=t(\"gl-mat4/perspective\"),h=t(\"gl-mat4/ortho\"),p=t(\"./lib/shader\"),d=t(\"is-mobile\")({tablet:!0,featureDetect:!0});function m(){this.mouse=[-1,-1],this.screen=null,this.distance=1/0,this.index=null,this.dataCoordinate=null,this.dataPosition=null,this.object=null,this.data=null}function g(t){var e=Math.round(Math.log(Math.abs(t))/Math.log(10));if(e<0){var r=Math.round(Math.pow(10,-e));return Math.ceil(t*r)/r}if(e>0){r=Math.round(Math.pow(10,e));return Math.ceil(t/r)*r}return Math.ceil(t)}function v(t){return\"boolean\"!=typeof t||t}e.exports={createScene:function(t){(t=t||{}).camera=t.camera||{};var e=t.canvas;if(!e){if(e=document.createElement(\"canvas\"),t.container)t.container.appendChild(e);else document.body.appendChild(e)}var r=t.gl;r||(t.glOptions&&(d=!!t.glOptions.preserveDrawingBuffer),r=function(t,e){var r=null;try{(r=t.getContext(\"webgl\",e))||(r=t.getContext(\"experimental-webgl\",e))}catch(t){return null}return r}(e,t.glOptions||{premultipliedAlpha:!0,antialias:!0,preserveDrawingBuffer:d}));if(!r)throw new Error(\"webgl not supported\");var y=t.bounds||[[-10,-10,-10],[10,10,10]],x=new m,b=l(r,r.drawingBufferWidth,r.drawingBufferHeight,{preferFloat:!d}),_=p(r),w=t.cameraObject&&!0===t.cameraObject._ortho||t.camera.projection&&\"orthographic\"===t.camera.projection.type||!1,T={eye:t.camera.eye||[2,0,0],center:t.camera.center||[0,0,0],up:t.camera.up||[0,1,0],zoomMin:t.camera.zoomMax||.1,zoomMax:t.camera.zoomMin||100,mode:t.camera.mode||\"turntable\",_ortho:w},k=t.axes||{},M=i(r,k);M.enable=!k.disable;var A=t.spikes||{},S=o(r,A),E=[],L=[],C=[],P=[],I=!0,O=!0,z=new Array(16),D=new Array(16),R={view:null,projection:z,model:D,_ortho:!1},F=(O=!0,[r.drawingBufferWidth,r.drawingBufferHeight]),B=t.cameraObject||n(e,T),N={gl:r,contextLost:!1,pixelRatio:t.pixelRatio||1,canvas:e,selection:x,camera:B,axes:M,axesPixels:null,spikes:S,bounds:y,objects:E,shape:F,aspect:t.aspectRatio||[1,1,1],pickRadius:t.pickRadius||10,zNear:t.zNear||.01,zFar:t.zFar||1e3,fovy:t.fovy||Math.PI/4,clearColor:t.clearColor||[0,0,0,0],autoResize:v(t.autoResize),autoBounds:v(t.autoBounds),autoScale:!!t.autoScale,autoCenter:v(t.autoCenter),clipToBounds:v(t.clipToBounds),snapToData:!!t.snapToData,onselect:t.onselect||null,onrender:t.onrender||null,onclick:t.onclick||null,cameraParams:R,oncontextloss:null,mouseListener:null,_stopped:!1,getAspectratio:function(){return{x:this.aspect[0],y:this.aspect[1],z:this.aspect[2]}},setAspectratio:function(t){this.aspect[0]=t.x,this.aspect[1]=t.y,this.aspect[2]=t.z,O=!0},setBounds:function(t,e){this.bounds[0][t]=e.min,this.bounds[1][t]=e.max},setClearColor:function(t){this.clearColor=t},clearRGBA:function(){this.gl.clearColor(this.clearColor[0],this.clearColor[1],this.clearColor[2],this.clearColor[3]),this.gl.clear(this.gl.COLOR_BUFFER_BIT|this.gl.DEPTH_BUFFER_BIT)}},j=[r.drawingBufferWidth/N.pixelRatio|0,r.drawingBufferHeight/N.pixelRatio|0];function U(){if(!N._stopped&&N.autoResize){var t=e.parentNode,r=1,n=1;t&&t!==document.body?(r=t.clientWidth,n=t.clientHeight):(r=window.innerWidth,n=window.innerHeight);var i=0|Math.ceil(r*N.pixelRatio),a=0|Math.ceil(n*N.pixelRatio);if(i!==e.width||a!==e.height){e.width=i,e.height=a;var o=e.style;o.position=o.position||\"absolute\",o.left=\"0px\",o.top=\"0px\",o.width=r+\"px\",o.height=n+\"px\",I=!0}}}N.autoResize&&U();function V(){for(var t=E.length,e=P.length,n=0;n<e;++n)C[n]=0;t:for(n=0;n<t;++n){var i=E[n],a=i.pickSlots;if(a){for(var o=0;o<e;++o)if(C[o]+a<255){L[n]=o,i.setPickBase(C[o]+1),C[o]+=a;continue t}var l=s(r,F);L[n]=e,P.push(l),C.push(a),i.setPickBase(1),e+=1}else L[n]=-1}for(;e>0&&0===C[e-1];)C.pop(),P.pop().dispose()}function q(){if(N.contextLost)return!0;r.isContextLost()&&(N.contextLost=!0,N.mouseListener.enabled=!1,N.selection.object=null,N.oncontextloss&&N.oncontextloss())}window.addEventListener(\"resize\",U),N.update=function(t){N._stopped||(t=t||{},I=!0,O=!0)},N.add=function(t){N._stopped||(t.axes=M,E.push(t),L.push(-1),I=!0,O=!0,V())},N.remove=function(t){if(!N._stopped){var e=E.indexOf(t);e<0||(E.splice(e,1),L.pop(),I=!0,O=!0,V())}},N.dispose=function(){if(!N._stopped&&(N._stopped=!0,window.removeEventListener(\"resize\",U),e.removeEventListener(\"webglcontextlost\",q),N.mouseListener.enabled=!1,!N.contextLost)){M.dispose(),S.dispose();for(var t=0;t<E.length;++t)E[t].dispose();b.dispose();for(t=0;t<P.length;++t)P[t].dispose();_.dispose(),r=null,M=null,S=null,E=[]}},N._mouseRotating=!1,N._prevButtons=0,N.enableMouseListeners=function(){N.mouseListener=u(e,(function(t,e,r){if(!N._stopped){var n=P.length,i=E.length,a=x.object;x.distance=1/0,x.mouse[0]=e,x.mouse[1]=r,x.object=null,x.screen=null,x.dataCoordinate=x.dataPosition=null;var o=!1;if(t&&N._prevButtons)N._mouseRotating=!0;else{N._mouseRotating&&(O=!0),N._mouseRotating=!1;for(var s=0;s<n;++s){var l=P[s].query(e,j[1]-r-1,N.pickRadius);if(l){if(l.distance>x.distance)continue;for(var c=0;c<i;++c){var u=E[c];if(L[c]===s){var f=u.pick(l);f&&(x.buttons=t,x.screen=l.coord,x.distance=l.distance,x.object=u,x.index=f.distance,x.dataPosition=f.position,x.dataCoordinate=f.dataCoordinate,x.data=f,o=!0)}}}}}a&&a!==x.object&&(a.highlight&&a.highlight(null),I=!0),x.object&&(x.object.highlight&&x.object.highlight(x.data),I=!0),(o=o||x.object!==a)&&N.onselect&&N.onselect(x),1&t&&!(1&N._prevButtons)&&N.onclick&&N.onclick(x),N._prevButtons=t}}))},e.addEventListener(\"webglcontextlost\",q);var H=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],G=[H[0].slice(),H[1].slice()];function Y(){if(!q()){U();var t=N.camera.tick();R.view=N.camera.matrix,I=I||t,O=O||t,M.pixelRatio=N.pixelRatio,S.pixelRatio=N.pixelRatio;var e=E.length,n=H[0],i=H[1];n[0]=n[1]=n[2]=1/0,i[0]=i[1]=i[2]=-1/0;for(var o=0;o<e;++o){(C=E[o]).pixelRatio=N.pixelRatio,C.axes=N.axes,I=I||!!C.dirty,O=O||!!C.dirty;var s=C.bounds;if(s)for(var l=s[0],u=s[1],p=0;p<3;++p)n[p]=Math.min(n[p],l[p]),i[p]=Math.max(i[p],u[p])}var d=N.bounds;if(N.autoBounds)for(p=0;p<3;++p){if(i[p]<n[p])n[p]=-1,i[p]=1;else{n[p]===i[p]&&(n[p]-=1,i[p]+=1);var m=.05*(i[p]-n[p]);n[p]=n[p]-m,i[p]=i[p]+m}d[0][p]=n[p],d[1][p]=i[p]}var v=!1;for(p=0;p<3;++p)v=v||G[0][p]!==d[0][p]||G[1][p]!==d[1][p],G[0][p]=d[0][p],G[1][p]=d[1][p];if(O=O||v,I=I||v){if(v){var y=[0,0,0];for(o=0;o<3;++o)y[o]=g((d[1][o]-d[0][o])/10);M.autoTicks?M.update({bounds:d,tickSpacing:y}):M.update({bounds:d})}var T=r.drawingBufferWidth,k=r.drawingBufferHeight;F[0]=T,F[1]=k,j[0]=0|Math.max(T/N.pixelRatio,1),j[1]=0|Math.max(k/N.pixelRatio,1),function(t,e){var r=t.bounds,n=t.cameraParams,i=n.projection,a=n.model,o=t.gl.drawingBufferWidth,s=t.gl.drawingBufferHeight,l=t.zNear,c=t.zFar,u=t.fovy,p=o/s;e?(h(i,-p,p,-1,1,l,c),n._ortho=!0):(f(i,u,p,l,c),n._ortho=!1);for(var d=0;d<16;++d)a[d]=0;a[15]=1;var m=0;for(d=0;d<3;++d)m=Math.max(m,r[1][d]-r[0][d]);for(d=0;d<3;++d)t.autoScale?a[5*d]=t.aspect[d]/(r[1][d]-r[0][d]):a[5*d]=1/m,t.autoCenter&&(a[12+d]=.5*-a[5*d]*(r[0][d]+r[1][d]))}(N,w);for(o=0;o<e;++o){(C=E[o]).axesBounds=d,N.clipToBounds&&(C.clipBounds=d)}x.object&&(N.snapToData?S.position=x.dataCoordinate:S.position=x.dataPosition,S.bounds=d),O&&(O=!1,function(){if(!q()){r.colorMask(!0,!0,!0,!0),r.depthMask(!0),r.disable(r.BLEND),r.enable(r.DEPTH_TEST),r.depthFunc(r.LEQUAL);for(var t=E.length,e=P.length,n=0;n<e;++n){var i=P[n];i.shape=j,i.begin();for(var a=0;a<t;++a)if(L[a]===n){var o=E[a];o.drawPick&&(o.pixelRatio=1,o.drawPick(R))}i.end()}}}()),N.axesPixels=a(N.axes,R,T,k),N.onrender&&N.onrender(),r.bindFramebuffer(r.FRAMEBUFFER,null),r.viewport(0,0,T,k),N.clearRGBA(),r.depthMask(!0),r.colorMask(!0,!0,!0,!0),r.enable(r.DEPTH_TEST),r.depthFunc(r.LEQUAL),r.disable(r.BLEND),r.disable(r.CULL_FACE);var A=!1;M.enable&&(A=A||M.isTransparent(),M.draw(R)),S.axes=M,x.object&&S.draw(R),r.disable(r.CULL_FACE);for(o=0;o<e;++o){(C=E[o]).axes=M,C.pixelRatio=N.pixelRatio,C.isOpaque&&C.isOpaque()&&C.draw(R),C.isTransparent&&C.isTransparent()&&(A=!0)}if(A){b.shape=F,b.bind(),r.clear(r.DEPTH_BUFFER_BIT),r.colorMask(!1,!1,!1,!1),r.depthMask(!0),r.depthFunc(r.LESS),M.enable&&M.isTransparent()&&M.drawTransparent(R);for(o=0;o<e;++o){(C=E[o]).isOpaque&&C.isOpaque()&&C.draw(R)}r.enable(r.BLEND),r.blendEquation(r.FUNC_ADD),r.blendFunc(r.ONE,r.ONE_MINUS_SRC_ALPHA),r.colorMask(!0,!0,!0,!0),r.depthMask(!1),r.clearColor(0,0,0,0),r.clear(r.COLOR_BUFFER_BIT),M.isTransparent()&&M.drawTransparent(R);for(o=0;o<e;++o){var C;(C=E[o]).isTransparent&&C.isTransparent()&&C.drawTransparent(R)}r.bindFramebuffer(r.FRAMEBUFFER,null),r.blendFunc(r.ONE,r.ONE_MINUS_SRC_ALPHA),r.disable(r.DEPTH_TEST),_.bind(),b.color[0].bind(0),_.uniforms.accumBuffer=0,c(r),r.disable(r.BLEND)}I=!1;for(o=0;o<e;++o)E[o].dirty=!1}}}return N.enableMouseListeners(),function t(){if(N._stopped||N.contextLost)return;Y(),requestAnimationFrame(t)}(),N.redraw=function(){N._stopped||(I=!0,Y())},N},createCamera:n}},{\"./camera.js\":319,\"./lib/shader\":320,\"a-big-triangle\":70,\"gl-axes3d\":254,\"gl-axes3d/properties\":262,\"gl-fbo\":272,\"gl-mat4/ortho\":298,\"gl-mat4/perspective\":299,\"gl-select-static\":334,\"gl-spikes3d\":345,\"is-mobile\":451,\"mouse-change\":466}],323:[function(t,e,r){var n=t(\"glslify\");r.pointVertex=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec2 position;\\n\\nuniform mat3 matrix;\\nuniform float pointSize;\\nuniform float pointCloud;\\n\\nhighp float rand(vec2 co) {\\n  highp float a = 12.9898;\\n  highp float b = 78.233;\\n  highp float c = 43758.5453;\\n  highp float d = dot(co.xy, vec2(a, b));\\n  highp float e = mod(d, 3.14);\\n  return fract(sin(e) * c);\\n}\\n\\nvoid main() {\\n  vec3 hgPosition = matrix * vec3(position, 1);\\n  gl_Position  = vec4(hgPosition.xy, 0, hgPosition.z);\\n    // if we don't jitter the point size a bit, overall point cloud\\n    // saturation 'jumps' on zooming, which is disturbing and confusing\\n  gl_PointSize = pointSize * ((19.5 + rand(position)) / 20.0);\\n  if(pointCloud != 0.0) { // pointCloud is truthy\\n    // get the same square surface as circle would be\\n    gl_PointSize *= 0.886;\\n  }\\n}\"]),r.pointFragment=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nuniform vec4 color, borderColor;\\nuniform float centerFraction;\\nuniform float pointCloud;\\n\\nvoid main() {\\n  float radius;\\n  vec4 baseColor;\\n  if(pointCloud != 0.0) { // pointCloud is truthy\\n    if(centerFraction == 1.0) {\\n      gl_FragColor = color;\\n    } else {\\n      gl_FragColor = mix(borderColor, color, centerFraction);\\n    }\\n  } else {\\n    radius = length(2.0 * gl_PointCoord.xy - 1.0);\\n    if(radius > 1.0) {\\n      discard;\\n    }\\n    baseColor = mix(borderColor, color, step(radius, centerFraction));\\n    gl_FragColor = vec4(baseColor.rgb * baseColor.a, baseColor.a);\\n  }\\n}\\n\"]),r.pickVertex=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec2 position;\\nattribute vec4 pickId;\\n\\nuniform mat3 matrix;\\nuniform float pointSize;\\nuniform vec4 pickOffset;\\n\\nvarying vec4 fragId;\\n\\nvoid main() {\\n  vec3 hgPosition = matrix * vec3(position, 1);\\n  gl_Position  = vec4(hgPosition.xy, 0, hgPosition.z);\\n  gl_PointSize = pointSize;\\n\\n  vec4 id = pickId + pickOffset;\\n  id.y += floor(id.x / 256.0);\\n  id.x -= floor(id.x / 256.0) * 256.0;\\n\\n  id.z += floor(id.y / 256.0);\\n  id.y -= floor(id.y / 256.0) * 256.0;\\n\\n  id.w += floor(id.z / 256.0);\\n  id.z -= floor(id.z / 256.0) * 256.0;\\n\\n  fragId = id;\\n}\\n\"]),r.pickFragment=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nvarying vec4 fragId;\\n\\nvoid main() {\\n  float radius = length(2.0 * gl_PointCoord.xy - 1.0);\\n  if(radius > 1.0) {\\n    discard;\\n  }\\n  gl_FragColor = fragId / 255.0;\\n}\\n\"])},{glslify:438}],324:[function(t,e,r){\"use strict\";var n=t(\"gl-shader\"),i=t(\"gl-buffer\"),a=t(\"typedarray-pool\"),o=t(\"./lib/shader\");function s(t,e,r,n,i){this.plot=t,this.offsetBuffer=e,this.pickBuffer=r,this.shader=n,this.pickShader=i,this.sizeMin=.5,this.sizeMinCap=2,this.sizeMax=20,this.areaRatio=1,this.pointCount=0,this.color=[1,0,0,1],this.borderColor=[0,0,0,1],this.blend=!1,this.pickOffset=0,this.points=null}e.exports=function(t,e){var r=t.gl,a=i(r),l=i(r),c=n(r,o.pointVertex,o.pointFragment),u=n(r,o.pickVertex,o.pickFragment),f=new s(t,a,l,c,u);return f.update(e),t.addObject(f),f};var l,c,u=s.prototype;u.dispose=function(){this.shader.dispose(),this.pickShader.dispose(),this.offsetBuffer.dispose(),this.pickBuffer.dispose(),this.plot.removeObject(this)},u.update=function(t){var e;function r(e,r){return e in t?t[e]:r}t=t||{},this.sizeMin=r(\"sizeMin\",.5),this.sizeMax=r(\"sizeMax\",20),this.color=r(\"color\",[1,0,0,1]).slice(),this.areaRatio=r(\"areaRatio\",1),this.borderColor=r(\"borderColor\",[0,0,0,1]).slice(),this.blend=r(\"blend\",!1);var n=t.positions.length>>>1,i=t.positions instanceof Float32Array,o=t.idToIndex instanceof Int32Array&&t.idToIndex.length>=n,s=t.positions,l=i?s:a.mallocFloat32(s.length),c=o?t.idToIndex:a.mallocInt32(n);if(i||l.set(s),!o)for(l.set(s),e=0;e<n;e++)c[e]=e;this.points=s,this.offsetBuffer.update(l),this.pickBuffer.update(c),i||a.free(l),o||a.free(c),this.pointCount=n,this.pickOffset=0},u.unifiedDraw=(l=[1,0,0,0,1,0,0,0,1],c=[0,0,0,0],function(t){var e=void 0!==t,r=e?this.pickShader:this.shader,n=this.plot.gl,i=this.plot.dataBox;if(0===this.pointCount)return t;var a=i[2]-i[0],o=i[3]-i[1],s=function(t,e){var r,n=0,i=t.length>>>1;for(r=0;r<i;r++){var a=t[2*r],o=t[2*r+1];a>=e[0]&&a<=e[2]&&o>=e[1]&&o<=e[3]&&n++}return n}(this.points,i),u=this.plot.pickPixelRatio*Math.max(Math.min(this.sizeMinCap,this.sizeMin),Math.min(this.sizeMax,this.sizeMax/Math.pow(s,.33333)));l[0]=2/a,l[4]=2/o,l[6]=-2*i[0]/a-1,l[7]=-2*i[1]/o-1,this.offsetBuffer.bind(),r.bind(),r.attributes.position.pointer(),r.uniforms.matrix=l,r.uniforms.color=this.color,r.uniforms.borderColor=this.borderColor,r.uniforms.pointCloud=u<5,r.uniforms.pointSize=u,r.uniforms.centerFraction=Math.min(1,Math.max(0,Math.sqrt(1-this.areaRatio))),e&&(c[0]=255&t,c[1]=t>>8&255,c[2]=t>>16&255,c[3]=t>>24&255,this.pickBuffer.bind(),r.attributes.pickId.pointer(n.UNSIGNED_BYTE),r.uniforms.pickOffset=c,this.pickOffset=t);var f=n.getParameter(n.BLEND),h=n.getParameter(n.DITHER);return f&&!this.blend&&n.disable(n.BLEND),h&&n.disable(n.DITHER),n.drawArrays(n.POINTS,0,this.pointCount),f&&!this.blend&&n.enable(n.BLEND),h&&n.enable(n.DITHER),t+this.pointCount}),u.draw=u.unifiedDraw,u.drawPick=u.unifiedDraw,u.pick=function(t,e,r){var n=this.pickOffset,i=this.pointCount;if(r<n||r>=n+i)return null;var a=r-n,o=this.points;return{object:this,pointId:a,dataCoord:[o[2*a],o[2*a+1]]}}},{\"./lib/shader\":323,\"gl-buffer\":263,\"gl-shader\":335,\"typedarray-pool\":613}],325:[function(t,e,r){e.exports=function(t,e,r,n){var i,a,o,s,l,c=e[0],u=e[1],f=e[2],h=e[3],p=r[0],d=r[1],m=r[2],g=r[3];(a=c*p+u*d+f*m+h*g)<0&&(a=-a,p=-p,d=-d,m=-m,g=-g);1-a>1e-6?(i=Math.acos(a),o=Math.sin(i),s=Math.sin((1-n)*i)/o,l=Math.sin(n*i)/o):(s=1-n,l=n);return t[0]=s*c+l*p,t[1]=s*u+l*d,t[2]=s*f+l*m,t[3]=s*h+l*g,t}},{}],326:[function(t,e,r){\"use strict\";e.exports=function(t){return t||0===t?t.toString():\"\"}},{}],327:[function(t,e,r){\"use strict\";var n=t(\"vectorize-text\");e.exports=function(t,e,r){var a=i[e];a||(a=i[e]={});if(t in a)return a[t];var o={textAlign:\"center\",textBaseline:\"middle\",lineHeight:1,font:e,lineSpacing:1.25,styletags:{breaklines:!0,bolds:!0,italics:!0,subscripts:!0,superscripts:!0},triangles:!0},s=n(t,o);o.triangles=!1;var l,c,u=n(t,o);if(r&&1!==r){for(l=0;l<s.positions.length;++l)for(c=0;c<s.positions[l].length;++c)s.positions[l][c]/=r;for(l=0;l<u.positions.length;++l)for(c=0;c<u.positions[l].length;++c)u.positions[l][c]/=r}var f=[[1/0,1/0],[-1/0,-1/0]],h=u.positions.length;for(l=0;l<h;++l){var p=u.positions[l];for(c=0;c<2;++c)f[0][c]=Math.min(f[0][c],p[c]),f[1][c]=Math.max(f[1][c],p[c])}return a[t]=[s,u,f]};var i={}},{\"vectorize-text\":619}],328:[function(t,e,r){var n=t(\"gl-shader\"),i=t(\"glslify\"),a=i([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nattribute vec3 position;\\nattribute vec4 color;\\nattribute vec2 glyph;\\nattribute vec4 id;\\n\\nuniform vec4 highlightId;\\nuniform float highlightScale;\\nuniform mat4 model, view, projection;\\nuniform vec3 clipBounds[2];\\n\\nvarying vec4 interpColor;\\nvarying vec4 pickId;\\nvarying vec3 dataCoordinate;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], position)) {\\n\\n    gl_Position = vec4(0,0,0,0);\\n  } else {\\n    float scale = 1.0;\\n    if(distance(highlightId, id) < 0.0001) {\\n      scale = highlightScale;\\n    }\\n\\n    vec4 worldPosition = model * vec4(position, 1);\\n    vec4 viewPosition = view * worldPosition;\\n    viewPosition = viewPosition / viewPosition.w;\\n    vec4 clipPosition = projection * (viewPosition + scale * vec4(glyph.x, -glyph.y, 0, 0));\\n\\n    gl_Position = clipPosition;\\n    interpColor = color;\\n    pickId = id;\\n    dataCoordinate = position;\\n  }\\n}\"]),o=i([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nattribute vec3 position;\\nattribute vec4 color;\\nattribute vec2 glyph;\\nattribute vec4 id;\\n\\nuniform mat4 model, view, projection;\\nuniform vec2 screenSize;\\nuniform vec3 clipBounds[2];\\nuniform float highlightScale, pixelRatio;\\nuniform vec4 highlightId;\\n\\nvarying vec4 interpColor;\\nvarying vec4 pickId;\\nvarying vec3 dataCoordinate;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], position)) {\\n\\n    gl_Position = vec4(0,0,0,0);\\n  } else {\\n    float scale = pixelRatio;\\n    if(distance(highlightId.bgr, id.bgr) < 0.001) {\\n      scale *= highlightScale;\\n    }\\n\\n    vec4 worldPosition = model * vec4(position, 1.0);\\n    vec4 viewPosition = view * worldPosition;\\n    vec4 clipPosition = projection * viewPosition;\\n    clipPosition /= clipPosition.w;\\n\\n    gl_Position = clipPosition + vec4(screenSize * scale * vec2(glyph.x, -glyph.y), 0.0, 0.0);\\n    interpColor = color;\\n    pickId = id;\\n    dataCoordinate = position;\\n  }\\n}\"]),s=i([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nattribute vec3 position;\\nattribute vec4 color;\\nattribute vec2 glyph;\\nattribute vec4 id;\\n\\nuniform float highlightScale;\\nuniform vec4 highlightId;\\nuniform vec3 axes[2];\\nuniform mat4 model, view, projection;\\nuniform vec2 screenSize;\\nuniform vec3 clipBounds[2];\\nuniform float scale, pixelRatio;\\n\\nvarying vec4 interpColor;\\nvarying vec4 pickId;\\nvarying vec3 dataCoordinate;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], position)) {\\n\\n    gl_Position = vec4(0,0,0,0);\\n  } else {\\n    float lscale = pixelRatio * scale;\\n    if(distance(highlightId, id) < 0.0001) {\\n      lscale *= highlightScale;\\n    }\\n\\n    vec4 clipCenter   = projection * view * model * vec4(position, 1);\\n    vec3 dataPosition = position + 0.5*lscale*(axes[0] * glyph.x + axes[1] * glyph.y) * clipCenter.w * screenSize.y;\\n    vec4 clipPosition = projection * view * model * vec4(dataPosition, 1);\\n\\n    gl_Position = clipPosition;\\n    interpColor = color;\\n    pickId = id;\\n    dataCoordinate = dataPosition;\\n  }\\n}\\n\"]),l=i([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3 fragClipBounds[2];\\nuniform float opacity;\\n\\nvarying vec4 interpColor;\\nvarying vec3 dataCoordinate;\\n\\nvoid main() {\\n  if (\\n    outOfRange(fragClipBounds[0], fragClipBounds[1], dataCoordinate) ||\\n    interpColor.a * opacity == 0.\\n  ) discard;\\n  gl_FragColor = interpColor * opacity;\\n}\\n\"]),c=i([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3 fragClipBounds[2];\\nuniform float pickGroup;\\n\\nvarying vec4 pickId;\\nvarying vec3 dataCoordinate;\\n\\nvoid main() {\\n  if (outOfRange(fragClipBounds[0], fragClipBounds[1], dataCoordinate)) discard;\\n\\n  gl_FragColor = vec4(pickGroup, pickId.bgr);\\n}\"]),u=[{name:\"position\",type:\"vec3\"},{name:\"color\",type:\"vec4\"},{name:\"glyph\",type:\"vec2\"},{name:\"id\",type:\"vec4\"}],f={vertex:a,fragment:l,attributes:u},h={vertex:o,fragment:l,attributes:u},p={vertex:s,fragment:l,attributes:u},d={vertex:a,fragment:c,attributes:u},m={vertex:o,fragment:c,attributes:u},g={vertex:s,fragment:c,attributes:u};function v(t,e){var r=n(t,e),i=r.attributes;return i.position.location=0,i.color.location=1,i.glyph.location=2,i.id.location=3,r}r.createPerspective=function(t){return v(t,f)},r.createOrtho=function(t){return v(t,h)},r.createProject=function(t){return v(t,p)},r.createPickPerspective=function(t){return v(t,d)},r.createPickOrtho=function(t){return v(t,m)},r.createPickProject=function(t){return v(t,g)}},{\"gl-shader\":335,glslify:329}],329:[function(t,e,r){arguments[4][261][0].apply(r,arguments)},{dup:261}],330:[function(t,e,r){\"use strict\";var n=t(\"is-string-blank\"),i=t(\"gl-buffer\"),a=t(\"gl-vao\"),o=t(\"typedarray-pool\"),s=t(\"gl-mat4/multiply\"),l=t(\"./lib/shaders\"),c=t(\"./lib/glyphs\"),u=t(\"./lib/get-simple-string\"),f=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1];function h(t,e){var r=t[0],n=t[1],i=t[2],a=t[3];return t[0]=e[0]*r+e[4]*n+e[8]*i+e[12]*a,t[1]=e[1]*r+e[5]*n+e[9]*i+e[13]*a,t[2]=e[2]*r+e[6]*n+e[10]*i+e[14]*a,t[3]=e[3]*r+e[7]*n+e[11]*i+e[15]*a,t}function p(t,e,r,n){return h(n,n),h(n,n),h(n,n)}function d(t,e){this.index=t,this.dataCoordinate=this.position=e}function m(t){return!0===t||t>1?1:t}function g(t,e,r,n,i,a,o,s,l,c,u,f){this.gl=t,this.pixelRatio=1,this.shader=e,this.orthoShader=r,this.projectShader=n,this.pointBuffer=i,this.colorBuffer=a,this.glyphBuffer=o,this.idBuffer=s,this.vao=l,this.vertexCount=0,this.lineVertexCount=0,this.opacity=1,this.hasAlpha=!1,this.lineWidth=0,this.projectScale=[2/3,2/3,2/3],this.projectOpacity=[1,1,1],this.projectHasAlpha=!1,this.pickId=0,this.pickPerspectiveShader=c,this.pickOrthoShader=u,this.pickProjectShader=f,this.points=[],this._selectResult=new d(0,[0,0,0]),this.useOrtho=!0,this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],this.axesProject=[!0,!0,!0],this.axesBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.highlightId=[1,1,1,1],this.highlightScale=2,this.clipBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.dirty=!0}e.exports=function(t){var e=t.gl,r=l.createPerspective(e),n=l.createOrtho(e),o=l.createProject(e),s=l.createPickPerspective(e),c=l.createPickOrtho(e),u=l.createPickProject(e),f=i(e),h=i(e),p=i(e),d=i(e),m=a(e,[{buffer:f,size:3,type:e.FLOAT},{buffer:h,size:4,type:e.FLOAT},{buffer:p,size:2,type:e.FLOAT},{buffer:d,size:4,type:e.UNSIGNED_BYTE,normalized:!0}]),v=new g(e,r,n,o,f,h,p,d,m,s,c,u);return v.update(t),v};var v=g.prototype;v.pickSlots=1,v.setPickBase=function(t){this.pickId=t},v.isTransparent=function(){if(this.hasAlpha)return!0;for(var t=0;t<3;++t)if(this.axesProject[t]&&this.projectHasAlpha)return!0;return!1},v.isOpaque=function(){if(!this.hasAlpha)return!0;for(var t=0;t<3;++t)if(this.axesProject[t]&&!this.projectHasAlpha)return!0;return!1};var y=[0,0],x=[0,0,0],b=[0,0,0],_=[0,0,0,1],w=[0,0,0,1],T=f.slice(),k=[0,0,0],M=[[0,0,0],[0,0,0]];function A(t){return t[0]=t[1]=t[2]=0,t}function S(t,e){return t[0]=e[0],t[1]=e[1],t[2]=e[2],t[3]=1,t}function E(t,e,r,n){return t[0]=e[0],t[1]=e[1],t[2]=e[2],t[r]=n,t}function L(t,e,r,n){var i,a=e.axesProject,o=e.gl,l=t.uniforms,c=r.model||f,u=r.view||f,h=r.projection||f,d=e.axesBounds,m=function(t){for(var e=M,r=0;r<2;++r)for(var n=0;n<3;++n)e[r][n]=Math.max(Math.min(t[r][n],1e8),-1e8);return e}(e.clipBounds);i=e.axes&&e.axes.lastCubeProps?e.axes.lastCubeProps.axis:[1,1,1],y[0]=2/o.drawingBufferWidth,y[1]=2/o.drawingBufferHeight,t.bind(),l.view=u,l.projection=h,l.screenSize=y,l.highlightId=e.highlightId,l.highlightScale=e.highlightScale,l.clipBounds=m,l.pickGroup=e.pickId/255,l.pixelRatio=n;for(var g=0;g<3;++g)if(a[g]){l.scale=e.projectScale[g],l.opacity=e.projectOpacity[g];for(var v=T,L=0;L<16;++L)v[L]=0;for(L=0;L<4;++L)v[5*L]=1;v[5*g]=0,i[g]<0?v[12+g]=d[0][g]:v[12+g]=d[1][g],s(v,c,v),l.model=v;var C=(g+1)%3,P=(g+2)%3,I=A(x),O=A(b);I[C]=1,O[P]=1;var z=p(0,0,0,S(_,I)),D=p(0,0,0,S(w,O));if(Math.abs(z[1])>Math.abs(D[1])){var R=z;z=D,D=R,R=I,I=O,O=R;var F=C;C=P,P=F}z[0]<0&&(I[C]=-1),D[1]>0&&(O[P]=-1);var B=0,N=0;for(L=0;L<4;++L)B+=Math.pow(c[4*C+L],2),N+=Math.pow(c[4*P+L],2);I[C]/=Math.sqrt(B),O[P]/=Math.sqrt(N),l.axes[0]=I,l.axes[1]=O,l.fragClipBounds[0]=E(k,m[0],g,-1e8),l.fragClipBounds[1]=E(k,m[1],g,1e8),e.vao.bind(),e.vao.draw(o.TRIANGLES,e.vertexCount),e.lineWidth>0&&(o.lineWidth(e.lineWidth*n),e.vao.draw(o.LINES,e.lineVertexCount,e.vertexCount)),e.vao.unbind()}}var C=[[-1e8,-1e8,-1e8],[1e8,1e8,1e8]];function P(t,e,r,n,i,a,o){var s=r.gl;if((a===r.projectHasAlpha||o)&&L(e,r,n,i),a===r.hasAlpha||o){t.bind();var l=t.uniforms;l.model=n.model||f,l.view=n.view||f,l.projection=n.projection||f,y[0]=2/s.drawingBufferWidth,y[1]=2/s.drawingBufferHeight,l.screenSize=y,l.highlightId=r.highlightId,l.highlightScale=r.highlightScale,l.fragClipBounds=C,l.clipBounds=r.axes.bounds,l.opacity=r.opacity,l.pickGroup=r.pickId/255,l.pixelRatio=i,r.vao.bind(),r.vao.draw(s.TRIANGLES,r.vertexCount),r.lineWidth>0&&(s.lineWidth(r.lineWidth*i),r.vao.draw(s.LINES,r.lineVertexCount,r.vertexCount)),r.vao.unbind()}}function I(t,e,r,i){var a;a=Array.isArray(t)?e<t.length?t[e]:void 0:t,a=u(a);var o=!0;n(a)&&(a=\"\\u25bc\",o=!1);var s=c(a,r,i);return{mesh:s[0],lines:s[1],bounds:s[2],visible:o}}v.draw=function(t){P(this.useOrtho?this.orthoShader:this.shader,this.projectShader,this,t,this.pixelRatio,!1,!1)},v.drawTransparent=function(t){P(this.useOrtho?this.orthoShader:this.shader,this.projectShader,this,t,this.pixelRatio,!0,!1)},v.drawPick=function(t){P(this.useOrtho?this.pickOrthoShader:this.pickPerspectiveShader,this.pickProjectShader,this,t,1,!0,!0)},v.pick=function(t){if(!t)return null;if(t.id!==this.pickId)return null;var e=t.value[2]+(t.value[1]<<8)+(t.value[0]<<16);if(e>=this.pointCount||e<0)return null;var r=this.points[e],n=this._selectResult;n.index=e;for(var i=0;i<3;++i)n.position[i]=n.dataCoordinate[i]=r[i];return n},v.highlight=function(t){if(t){var e=t.index,r=255&e,n=e>>8&255,i=e>>16&255;this.highlightId=[r/255,n/255,i/255,0]}else this.highlightId=[1,1,1,1]},v.update=function(t){if(\"perspective\"in(t=t||{})&&(this.useOrtho=!t.perspective),\"orthographic\"in t&&(this.useOrtho=!!t.orthographic),\"lineWidth\"in t&&(this.lineWidth=t.lineWidth),\"project\"in t)if(Array.isArray(t.project))this.axesProject=t.project;else{var e=!!t.project;this.axesProject=[e,e,e]}if(\"projectScale\"in t)if(Array.isArray(t.projectScale))this.projectScale=t.projectScale.slice();else{var r=+t.projectScale;this.projectScale=[r,r,r]}if(this.projectHasAlpha=!1,\"projectOpacity\"in t){if(Array.isArray(t.projectOpacity))this.projectOpacity=t.projectOpacity.slice();else{r=+t.projectOpacity;this.projectOpacity=[r,r,r]}for(var n=0;n<3;++n)this.projectOpacity[n]=m(this.projectOpacity[n]),this.projectOpacity[n]<1&&(this.projectHasAlpha=!0)}this.hasAlpha=!1,\"opacity\"in t&&(this.opacity=m(t.opacity),this.opacity<1&&(this.hasAlpha=!0)),this.dirty=!0;var i,a,s=t.position,l=t.font||\"normal\",c=t.alignment||[0,0];if(2===c.length)i=c[0],a=c[1];else{i=[],a=[];for(n=0;n<c.length;++n)i[n]=c[n][0],a[n]=c[n][1]}var u=[1/0,1/0,1/0],f=[-1/0,-1/0,-1/0],h=t.glyph,p=t.color,d=t.size,g=t.angle,v=t.lineColor,y=-1,x=0,b=0,_=0;if(s.length){_=s.length;t:for(n=0;n<_;++n){for(var w=s[n],T=0;T<3;++T)if(isNaN(w[T])||!isFinite(w[T]))continue t;var k=(N=I(h,n,l,this.pixelRatio)).mesh,M=N.lines,A=N.bounds;x+=3*k.cells.length,b+=2*M.edges.length}}var S=x+b,E=o.mallocFloat(3*S),L=o.mallocFloat(4*S),C=o.mallocFloat(2*S),P=o.mallocUint32(S);if(S>0){var O=0,z=x,D=[0,0,0,1],R=[0,0,0,1],F=Array.isArray(p)&&Array.isArray(p[0]),B=Array.isArray(v)&&Array.isArray(v[0]);t:for(n=0;n<_;++n){y+=1;for(w=s[n],T=0;T<3;++T){if(isNaN(w[T])||!isFinite(w[T]))continue t;f[T]=Math.max(f[T],w[T]),u[T]=Math.min(u[T],w[T])}k=(N=I(h,n,l,this.pixelRatio)).mesh,M=N.lines,A=N.bounds;var N,j=N.visible;if(j)if(Array.isArray(p)){if(3===(U=F?n<p.length?p[n]:[0,0,0,0]:p).length){for(T=0;T<3;++T)D[T]=U[T];D[3]=1}else if(4===U.length){for(T=0;T<4;++T)D[T]=U[T];!this.hasAlpha&&U[3]<1&&(this.hasAlpha=!0)}}else D[0]=D[1]=D[2]=0,D[3]=1;else D=[1,1,1,0];if(j)if(Array.isArray(v)){var U;if(3===(U=B?n<v.length?v[n]:[0,0,0,0]:v).length){for(T=0;T<3;++T)R[T]=U[T];R[T]=1}else if(4===U.length){for(T=0;T<4;++T)R[T]=U[T];!this.hasAlpha&&U[3]<1&&(this.hasAlpha=!0)}}else R[0]=R[1]=R[2]=0,R[3]=1;else R=[1,1,1,0];var V=.5;j?Array.isArray(d)?V=n<d.length?+d[n]:12:d?V=+d:this.useOrtho&&(V=12):V=0;var q=0;Array.isArray(g)?q=n<g.length?+g[n]:0:g&&(q=+g);var H=Math.cos(q),G=Math.sin(q);for(w=s[n],T=0;T<3;++T)f[T]=Math.max(f[T],w[T]),u[T]=Math.min(u[T],w[T]);var Y=i,W=a;Y=0;Array.isArray(i)?Y=n<i.length?i[n]:0:i&&(Y=i);W=0;Array.isArray(a)?W=n<a.length?a[n]:0:a&&(W=a);var X=[Y*=Y>0?1-A[0][0]:Y<0?1+A[1][0]:1,W*=W>0?1-A[0][1]:W<0?1+A[1][1]:1],Z=k.cells||[],J=k.positions||[];for(T=0;T<Z.length;++T)for(var K=Z[T],Q=0;Q<3;++Q){for(var $=0;$<3;++$)E[3*O+$]=w[$];for($=0;$<4;++$)L[4*O+$]=D[$];P[O]=y;var tt=J[K[Q]];C[2*O]=V*(H*tt[0]-G*tt[1]+X[0]),C[2*O+1]=V*(G*tt[0]+H*tt[1]+X[1]),O+=1}for(Z=M.edges,J=M.positions,T=0;T<Z.length;++T)for(K=Z[T],Q=0;Q<2;++Q){for($=0;$<3;++$)E[3*z+$]=w[$];for($=0;$<4;++$)L[4*z+$]=R[$];P[z]=y;tt=J[K[Q]];C[2*z]=V*(H*tt[0]-G*tt[1]+X[0]),C[2*z+1]=V*(G*tt[0]+H*tt[1]+X[1]),z+=1}}}this.bounds=[u,f],this.points=s,this.pointCount=s.length,this.vertexCount=x,this.lineVertexCount=b,this.pointBuffer.update(E),this.colorBuffer.update(L),this.glyphBuffer.update(C),this.idBuffer.update(P),o.free(E),o.free(L),o.free(C),o.free(P)},v.dispose=function(){this.shader.dispose(),this.orthoShader.dispose(),this.pickPerspectiveShader.dispose(),this.pickOrthoShader.dispose(),this.vao.dispose(),this.pointBuffer.dispose(),this.colorBuffer.dispose(),this.glyphBuffer.dispose(),this.idBuffer.dispose()}},{\"./lib/get-simple-string\":326,\"./lib/glyphs\":327,\"./lib/shaders\":328,\"gl-buffer\":263,\"gl-mat4/multiply\":297,\"gl-vao\":357,\"is-string-blank\":454,\"typedarray-pool\":613}],331:[function(t,e,r){\"use strict\";var n=t(\"glslify\");r.boxVertex=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec2 vertex;\\n\\nuniform vec2 cornerA, cornerB;\\n\\nvoid main() {\\n  gl_Position = vec4(mix(cornerA, cornerB, vertex), 0, 1);\\n}\\n\"]),r.boxFragment=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nuniform vec4 color;\\n\\nvoid main() {\\n  gl_FragColor = color;\\n}\\n\"])},{glslify:332}],332:[function(t,e,r){arguments[4][261][0].apply(r,arguments)},{dup:261}],333:[function(t,e,r){\"use strict\";var n=t(\"gl-shader\"),i=t(\"gl-buffer\"),a=t(\"./lib/shaders\");function o(t,e,r){this.plot=t,this.boxBuffer=e,this.boxShader=r,this.enabled=!0,this.selectBox=[1/0,1/0,-1/0,-1/0],this.borderColor=[0,0,0,1],this.innerFill=!1,this.innerColor=[0,0,0,.25],this.outerFill=!0,this.outerColor=[0,0,0,.5],this.borderWidth=10}e.exports=function(t,e){var r=t.gl,s=i(r,[0,0,0,1,1,0,1,1]),l=n(r,a.boxVertex,a.boxFragment),c=new o(t,s,l);return c.update(e),t.addOverlay(c),c};var s=o.prototype;s.draw=function(){if(this.enabled){var t=this.plot,e=this.selectBox,r=this.borderWidth,n=(this.innerFill,this.innerColor),i=(this.outerFill,this.outerColor),a=this.borderColor,o=t.box,s=t.screenBox,l=t.dataBox,c=t.viewBox,u=t.pixelRatio,f=(e[0]-l[0])*(c[2]-c[0])/(l[2]-l[0])+c[0],h=(e[1]-l[1])*(c[3]-c[1])/(l[3]-l[1])+c[1],p=(e[2]-l[0])*(c[2]-c[0])/(l[2]-l[0])+c[0],d=(e[3]-l[1])*(c[3]-c[1])/(l[3]-l[1])+c[1];if(f=Math.max(f,c[0]),h=Math.max(h,c[1]),p=Math.min(p,c[2]),d=Math.min(d,c[3]),!(p<f||d<h)){o.bind();var m=s[2]-s[0],g=s[3]-s[1];if(this.outerFill&&(o.drawBox(0,0,m,h,i),o.drawBox(0,h,f,d,i),o.drawBox(0,d,m,g,i),o.drawBox(p,h,m,d,i)),this.innerFill&&o.drawBox(f,h,p,d,n),r>0){var v=r*u;o.drawBox(f-v,h-v,p+v,h+v,a),o.drawBox(f-v,d-v,p+v,d+v,a),o.drawBox(f-v,h-v,f+v,d+v,a),o.drawBox(p-v,h-v,p+v,d+v,a)}}}},s.update=function(t){t=t||{},this.innerFill=!!t.innerFill,this.outerFill=!!t.outerFill,this.innerColor=(t.innerColor||[0,0,0,.5]).slice(),this.outerColor=(t.outerColor||[0,0,0,.5]).slice(),this.borderColor=(t.borderColor||[0,0,0,1]).slice(),this.borderWidth=t.borderWidth||0,this.selectBox=(t.selectBox||this.selectBox).slice()},s.dispose=function(){this.boxBuffer.dispose(),this.boxShader.dispose(),this.plot.removeOverlay(this)}},{\"./lib/shaders\":331,\"gl-buffer\":263,\"gl-shader\":335}],334:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=e[0],a=e[1],o=n(t,r,a,{}),s=i.mallocUint8(r*a*4);return new l(t,o,s)};var n=t(\"gl-fbo\"),i=t(\"typedarray-pool\"),a=t(\"ndarray\"),o=t(\"bit-twiddle\").nextPow2;function s(t,e,r,n,i){this.coord=[t,e],this.id=r,this.value=n,this.distance=i}function l(t,e,r){this.gl=t,this.fbo=e,this.buffer=r,this._readTimeout=null;var n=this;this._readCallback=function(){n.gl&&(e.bind(),t.readPixels(0,0,e.shape[0],e.shape[1],t.RGBA,t.UNSIGNED_BYTE,n.buffer),n._readTimeout=null)}}var c=l.prototype;Object.defineProperty(c,\"shape\",{get:function(){return this.gl?this.fbo.shape.slice():[0,0]},set:function(t){if(this.gl){this.fbo.shape=t;var e=this.fbo.shape[0],r=this.fbo.shape[1];if(r*e*4>this.buffer.length){i.free(this.buffer);for(var n=this.buffer=i.mallocUint8(o(r*e*4)),a=0;a<r*e*4;++a)n[a]=255}return t}}}),c.begin=function(){var t=this.gl;this.shape;t&&(this.fbo.bind(),t.clearColor(1,1,1,1),t.clear(t.COLOR_BUFFER_BIT|t.DEPTH_BUFFER_BIT))},c.end=function(){var t=this.gl;t&&(t.bindFramebuffer(t.FRAMEBUFFER,null),this._readTimeout||clearTimeout(this._readTimeout),this._readTimeout=setTimeout(this._readCallback,1))},c.query=function(t,e,r){if(!this.gl)return null;var n=this.fbo.shape.slice();t|=0,e|=0,\"number\"!=typeof r&&(r=1);var i=0|Math.min(Math.max(t-r,0),n[0]),o=0|Math.min(Math.max(t+r,0),n[0]),l=0|Math.min(Math.max(e-r,0),n[1]),c=0|Math.min(Math.max(e+r,0),n[1]);if(o<=i||c<=l)return null;var u=[o-i,c-l],f=a(this.buffer,[u[0],u[1],4],[4,4*n[0],1],4*(i+n[0]*l)),h=function(t,e,r){for(var n=1e8,i=-1,a=-1,o=t.shape[0],s=t.shape[1],l=0;l<o;l++)for(var c=0;c<s;c++){var u=t.get(l,c,0),f=t.get(l,c,1),h=t.get(l,c,2),p=t.get(l,c,3);if(u<255||f<255||h<255||p<255){var d=e-l,m=r-c,g=d*d+m*m;g<n&&(n=g,i=l,a=c)}}return[i,a,n]}(f.hi(u[0],u[1],1),r,r),p=h[0],d=h[1];return p<0||Math.pow(this.radius,2)<h[2]?null:new s(p+i|0,d+l|0,f.get(p,d,0),[f.get(p,d,1),f.get(p,d,2),f.get(p,d,3)],Math.sqrt(h[2]))},c.dispose=function(){this.gl&&(this.fbo.dispose(),i.free(this.buffer),this.gl=null,this._readTimeout&&clearTimeout(this._readTimeout))}},{\"bit-twiddle\":104,\"gl-fbo\":272,ndarray:479,\"typedarray-pool\":613}],335:[function(t,e,r){\"use strict\";var n=t(\"./lib/create-uniforms\"),i=t(\"./lib/create-attributes\"),a=t(\"./lib/reflect\"),o=t(\"./lib/shader-cache\"),s=t(\"./lib/runtime-reflect\"),l=t(\"./lib/GLError\");function c(t){this.gl=t,this.gl.lastAttribCount=0,this._vref=this._fref=this._relink=this.vertShader=this.fragShader=this.program=this.attributes=this.uniforms=this.types=null}var u=c.prototype;function f(t,e){return t.name<e.name?-1:1}u.bind=function(){var t;this.program||this._relink();var e=this.gl.getProgramParameter(this.program,this.gl.ACTIVE_ATTRIBUTES),r=this.gl.lastAttribCount;if(e>r)for(t=r;t<e;t++)this.gl.enableVertexAttribArray(t);else if(r>e)for(t=e;t<r;t++)this.gl.disableVertexAttribArray(t);this.gl.lastAttribCount=e,this.gl.useProgram(this.program)},u.dispose=function(){for(var t=this.gl.lastAttribCount,e=0;e<t;e++)this.gl.disableVertexAttribArray(e);this.gl.lastAttribCount=0,this._fref&&this._fref.dispose(),this._vref&&this._vref.dispose(),this.attributes=this.types=this.vertShader=this.fragShader=this.program=this._relink=this._fref=this._vref=null},u.update=function(t,e,r,c){if(!e||1===arguments.length){var u=t;t=u.vertex,e=u.fragment,r=u.uniforms,c=u.attributes}var h=this,p=h.gl,d=h._vref;h._vref=o.shader(p,p.VERTEX_SHADER,t),d&&d.dispose(),h.vertShader=h._vref.shader;var m=this._fref;if(h._fref=o.shader(p,p.FRAGMENT_SHADER,e),m&&m.dispose(),h.fragShader=h._fref.shader,!r||!c){var g=p.createProgram();if(p.attachShader(g,h.fragShader),p.attachShader(g,h.vertShader),p.linkProgram(g),!p.getProgramParameter(g,p.LINK_STATUS)){var v=p.getProgramInfoLog(g);throw new l(v,\"Error linking program:\"+v)}r=r||s.uniforms(p,g),c=c||s.attributes(p,g),p.deleteProgram(g)}(c=c.slice()).sort(f);var y,x=[],b=[],_=[];for(y=0;y<c.length;++y){var w=c[y];if(w.type.indexOf(\"mat\")>=0){for(var T=0|w.type.charAt(w.type.length-1),k=new Array(T),M=0;M<T;++M)k[M]=_.length,b.push(w.name+\"[\"+M+\"]\"),\"number\"==typeof w.location?_.push(w.location+M):Array.isArray(w.location)&&w.location.length===T&&\"number\"==typeof w.location[M]?_.push(0|w.location[M]):_.push(-1);x.push({name:w.name,type:w.type,locations:k})}else x.push({name:w.name,type:w.type,locations:[_.length]}),b.push(w.name),\"number\"==typeof w.location?_.push(0|w.location):_.push(-1)}var A=0;for(y=0;y<_.length;++y)if(_[y]<0){for(;_.indexOf(A)>=0;)A+=1;_[y]=A}var S=new Array(r.length);function E(){h.program=o.program(p,h._vref,h._fref,b,_);for(var t=0;t<r.length;++t)S[t]=p.getUniformLocation(h.program,r[t].name)}E(),h._relink=E,h.types={uniforms:a(r),attributes:a(c)},h.attributes=i(p,h,x,_),Object.defineProperty(h,\"uniforms\",n(p,h,r,S))},e.exports=function(t,e,r,n,i){var a=new c(t);return a.update(e,r,n,i),a}},{\"./lib/GLError\":336,\"./lib/create-attributes\":337,\"./lib/create-uniforms\":338,\"./lib/reflect\":339,\"./lib/runtime-reflect\":340,\"./lib/shader-cache\":341}],336:[function(t,e,r){function n(t,e,r){this.shortMessage=e||\"\",this.longMessage=r||\"\",this.rawError=t||\"\",this.message=\"gl-shader: \"+(e||t||\"\")+(r?\"\\n\"+r:\"\"),this.stack=(new Error).stack}n.prototype=new Error,n.prototype.name=\"GLError\",n.prototype.constructor=n,e.exports=n},{}],337:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,i){for(var a={},l=0,c=r.length;l<c;++l){var u=r[l],f=u.name,h=u.type,p=u.locations;switch(h){case\"bool\":case\"int\":case\"float\":o(t,e,p[0],i,1,a,f);break;default:if(h.indexOf(\"vec\")>=0){if((d=h.charCodeAt(h.length-1)-48)<2||d>4)throw new n(\"\",\"Invalid data type for attribute \"+f+\": \"+h);o(t,e,p[0],i,d,a,f)}else{if(!(h.indexOf(\"mat\")>=0))throw new n(\"\",\"Unknown data type for attribute \"+f+\": \"+h);var d;if((d=h.charCodeAt(h.length-1)-48)<2||d>4)throw new n(\"\",\"Invalid data type for attribute \"+f+\": \"+h);s(t,e,p,i,d,a,f)}}}return a};var n=t(\"./GLError\");function i(t,e,r,n,i,a){this._gl=t,this._wrapper=e,this._index=r,this._locations=n,this._dimension=i,this._constFunc=a}var a=i.prototype;function o(t,e,r,n,a,o,s){for(var l=[\"gl\",\"v\"],c=[],u=0;u<a;++u)l.push(\"x\"+u),c.push(\"x\"+u);l.push(\"if(x0.length===void 0){return gl.vertexAttrib\"+a+\"f(v,\"+c.join()+\")}else{return gl.vertexAttrib\"+a+\"fv(v,x0)}\");var f=Function.apply(null,l),h=new i(t,e,r,n,a,f);Object.defineProperty(o,s,{set:function(e){return t.disableVertexAttribArray(n[r]),f(t,n[r],e),e},get:function(){return h},enumerable:!0})}function s(t,e,r,n,i,a,s){for(var l=new Array(i),c=new Array(i),u=0;u<i;++u)o(t,e,r[u],n,i,l,u),c[u]=l[u];Object.defineProperty(l,\"location\",{set:function(t){if(Array.isArray(t))for(var e=0;e<i;++e)c[e].location=t[e];else for(e=0;e<i;++e)c[e].location=t+e;return t},get:function(){for(var t=new Array(i),e=0;e<i;++e)t[e]=n[r[e]];return t},enumerable:!0}),l.pointer=function(e,a,o,s){e=e||t.FLOAT,a=!!a,o=o||i*i,s=s||0;for(var l=0;l<i;++l){var c=n[r[l]];t.vertexAttribPointer(c,i,e,a,o,s+l*i),t.enableVertexAttribArray(c)}};var f=new Array(i),h=t[\"vertexAttrib\"+i+\"fv\"];Object.defineProperty(a,s,{set:function(e){for(var a=0;a<i;++a){var o=n[r[a]];if(t.disableVertexAttribArray(o),Array.isArray(e[0]))h.call(t,o,e[a]);else{for(var s=0;s<i;++s)f[s]=e[i*a+s];h.call(t,o,f)}}return e},get:function(){return l},enumerable:!0})}a.pointer=function(t,e,r,n){var i=this._gl,a=this._locations[this._index];i.vertexAttribPointer(a,this._dimension,t||i.FLOAT,!!e,r||0,n||0),i.enableVertexAttribArray(a)},a.set=function(t,e,r,n){return this._constFunc(this._locations[this._index],t,e,r,n)},Object.defineProperty(a,\"location\",{get:function(){return this._locations[this._index]},set:function(t){return t!==this._locations[this._index]&&(this._locations[this._index]=0|t,this._wrapper.program=null),0|t}})},{\"./GLError\":336}],338:[function(t,e,r){\"use strict\";var n=t(\"./reflect\"),i=t(\"./GLError\");function a(t){return new Function(\"y\",\"return function(){return y}\")(t)}function o(t,e){for(var r=new Array(t),n=0;n<t;++n)r[n]=e;return r}e.exports=function(t,e,r,s){function l(t,e,r){switch(r){case\"bool\":case\"int\":case\"sampler2D\":case\"samplerCube\":return\"gl.uniform1i(locations[\"+e+\"],obj\"+t+\")\";case\"float\":return\"gl.uniform1f(locations[\"+e+\"],obj\"+t+\")\";default:var n=r.indexOf(\"vec\");if(!(0<=n&&n<=1&&r.length===4+n)){if(0===r.indexOf(\"mat\")&&4===r.length){var a;if((a=r.charCodeAt(r.length-1)-48)<2||a>4)throw new i(\"\",\"Invalid uniform dimension type for matrix \"+name+\": \"+r);return\"gl.uniformMatrix\"+a+\"fv(locations[\"+e+\"],false,obj\"+t+\")\"}throw new i(\"\",\"Unknown uniform data type for \"+name+\": \"+r)}if((a=r.charCodeAt(r.length-1)-48)<2||a>4)throw new i(\"\",\"Invalid data type\");switch(r.charAt(0)){case\"b\":case\"i\":return\"gl.uniform\"+a+\"iv(locations[\"+e+\"],obj\"+t+\")\";case\"v\":return\"gl.uniform\"+a+\"fv(locations[\"+e+\"],obj\"+t+\")\";default:throw new i(\"\",\"Unrecognized data type for vector \"+name+\": \"+r)}}}function c(e){for(var n=[\"return function updateProperty(obj){\"],i=function t(e,r){if(\"object\"!=typeof r)return[[e,r]];var n=[];for(var i in r){var a=r[i],o=e;parseInt(i)+\"\"===i?o+=\"[\"+i+\"]\":o+=\".\"+i,\"object\"==typeof a?n.push.apply(n,t(o,a)):n.push([o,a])}return n}(\"\",e),a=0;a<i.length;++a){var o=i[a],c=o[0],u=o[1];s[u]&&n.push(l(c,u,r[u].type))}return n.push(\"return obj}\"),new Function(\"gl\",\"locations\",n.join(\"\\n\"))(t,s)}function u(n,l,u){if(\"object\"==typeof u){var h=f(u);Object.defineProperty(n,l,{get:a(h),set:c(u),enumerable:!0,configurable:!1})}else s[u]?Object.defineProperty(n,l,{get:(p=u,new Function(\"gl\",\"wrapper\",\"locations\",\"return function(){return gl.getUniform(wrapper.program,locations[\"+p+\"])}\")(t,e,s)),set:c(u),enumerable:!0,configurable:!1}):n[l]=function(t){switch(t){case\"bool\":return!1;case\"int\":case\"sampler2D\":case\"samplerCube\":case\"float\":return 0;default:var e=t.indexOf(\"vec\");if(0<=e&&e<=1&&t.length===4+e){if((r=t.charCodeAt(t.length-1)-48)<2||r>4)throw new i(\"\",\"Invalid data type\");return\"b\"===t.charAt(0)?o(r,!1):o(r,0)}if(0===t.indexOf(\"mat\")&&4===t.length){var r;if((r=t.charCodeAt(t.length-1)-48)<2||r>4)throw new i(\"\",\"Invalid uniform dimension type for matrix \"+name+\": \"+t);return o(r*r,0)}throw new i(\"\",\"Unknown uniform data type for \"+name+\": \"+t)}}(r[u].type);var p}function f(t){var e;if(Array.isArray(t)){e=new Array(t.length);for(var r=0;r<t.length;++r)u(e,r,t[r])}else for(var n in e={},t)u(e,n,t[n]);return e}var h=n(r,!0);return{get:a(f(h)),set:c(h),enumerable:!0,configurable:!0}}},{\"./GLError\":336,\"./reflect\":339}],339:[function(t,e,r){\"use strict\";e.exports=function(t,e){for(var r={},n=0;n<t.length;++n)for(var i=t[n].name.split(\".\"),a=r,o=0;o<i.length;++o){var s=i[o].split(\"[\");if(s.length>1){s[0]in a||(a[s[0]]=[]),a=a[s[0]];for(var l=1;l<s.length;++l){var c=parseInt(s[l]);l<s.length-1||o<i.length-1?(c in a||(l<s.length-1?a[c]=[]:a[c]={}),a=a[c]):a[c]=e?n:t[n].type}}else o<i.length-1?(s[0]in a||(a[s[0]]={}),a=a[s[0]]):a[s[0]]=e?n:t[n].type}return r}},{}],340:[function(t,e,r){\"use strict\";r.uniforms=function(t,e){for(var r=t.getProgramParameter(e,t.ACTIVE_UNIFORMS),n=[],i=0;i<r;++i){var o=t.getActiveUniform(e,i);if(o){var s=a(t,o.type);if(o.size>1)for(var l=0;l<o.size;++l)n.push({name:o.name.replace(\"[0]\",\"[\"+l+\"]\"),type:s});else n.push({name:o.name,type:s})}}return n},r.attributes=function(t,e){for(var r=t.getProgramParameter(e,t.ACTIVE_ATTRIBUTES),n=[],i=0;i<r;++i){var o=t.getActiveAttrib(e,i);o&&n.push({name:o.name,type:a(t,o.type)})}return n};var n={FLOAT:\"float\",FLOAT_VEC2:\"vec2\",FLOAT_VEC3:\"vec3\",FLOAT_VEC4:\"vec4\",INT:\"int\",INT_VEC2:\"ivec2\",INT_VEC3:\"ivec3\",INT_VEC4:\"ivec4\",BOOL:\"bool\",BOOL_VEC2:\"bvec2\",BOOL_VEC3:\"bvec3\",BOOL_VEC4:\"bvec4\",FLOAT_MAT2:\"mat2\",FLOAT_MAT3:\"mat3\",FLOAT_MAT4:\"mat4\",SAMPLER_2D:\"sampler2D\",SAMPLER_CUBE:\"samplerCube\"},i=null;function a(t,e){if(!i){var r=Object.keys(n);i={};for(var a=0;a<r.length;++a){var o=r[a];i[t[o]]=n[o]}}return i[e]}},{}],341:[function(t,e,r){\"use strict\";r.shader=function(t,e,r){return u(t).getShaderReference(e,r)},r.program=function(t,e,r,n,i){return u(t).getProgram(e,r,n,i)};var n=t(\"./GLError\"),i=t(\"gl-format-compiler-error\"),a=new(\"undefined\"==typeof WeakMap?t(\"weakmap-shim\"):WeakMap),o=0;function s(t,e,r,n,i,a,o){this.id=t,this.src=e,this.type=r,this.shader=n,this.count=a,this.programs=[],this.cache=o}function l(t){this.gl=t,this.shaders=[{},{}],this.programs={}}s.prototype.dispose=function(){if(0==--this.count){for(var t=this.cache,e=t.gl,r=this.programs,n=0,i=r.length;n<i;++n){var a=t.programs[r[n]];a&&(delete t.programs[n],e.deleteProgram(a))}e.deleteShader(this.shader),delete t.shaders[this.type===e.FRAGMENT_SHADER|0][this.src]}};var c=l.prototype;function u(t){var e=a.get(t);return e||(e=new l(t),a.set(t,e)),e}c.getShaderReference=function(t,e){var r=this.gl,a=this.shaders[t===r.FRAGMENT_SHADER|0],l=a[e];if(l&&r.isShader(l.shader))l.count+=1;else{var c=function(t,e,r){var a=t.createShader(e);if(t.shaderSource(a,r),t.compileShader(a),!t.getShaderParameter(a,t.COMPILE_STATUS)){var o=t.getShaderInfoLog(a);try{var s=i(o,r,e)}catch(t){throw console.warn(\"Failed to format compiler error: \"+t),new n(o,\"Error compiling shader:\\n\"+o)}throw new n(o,s.short,s.long)}return a}(r,t,e);l=a[e]=new s(o++,e,t,c,[],1,this)}return l},c.getProgram=function(t,e,r,i){var a=[t.id,e.id,r.join(\":\"),i.join(\":\")].join(\"@\"),o=this.programs[a];return o&&this.gl.isProgram(o)||(this.programs[a]=o=function(t,e,r,i,a){var o=t.createProgram();t.attachShader(o,e),t.attachShader(o,r);for(var s=0;s<i.length;++s)t.bindAttribLocation(o,a[s],i[s]);if(t.linkProgram(o),!t.getProgramParameter(o,t.LINK_STATUS)){var l=t.getProgramInfoLog(o);throw new n(l,\"Error linking program: \"+l)}return o}(this.gl,t.shader,e.shader,r,i),t.programs.push(a),e.programs.push(a)),o}},{\"./GLError\":336,\"gl-format-compiler-error\":273,\"weakmap-shim\":624}],342:[function(t,e,r){\"use strict\";function n(t){this.plot=t,this.enable=[!0,!0,!1,!1],this.width=[1,1,1,1],this.color=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.center=[1/0,1/0]}e.exports=function(t,e){var r=new n(t);return r.update(e),t.addOverlay(r),r};var i=n.prototype;i.update=function(t){t=t||{},this.enable=(t.enable||[!0,!0,!1,!1]).slice(),this.width=(t.width||[1,1,1,1]).slice(),this.color=(t.color||[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]]).map((function(t){return t.slice()})),this.center=(t.center||[1/0,1/0]).slice(),this.plot.setOverlayDirty()},i.draw=function(){var t=this.enable,e=this.width,r=this.color,n=this.center,i=this.plot,a=i.line,o=i.dataBox,s=i.viewBox;if(a.bind(),o[0]<=n[0]&&n[0]<=o[2]&&o[1]<=n[1]&&n[1]<=o[3]){var l=s[0]+(n[0]-o[0])/(o[2]-o[0])*(s[2]-s[0]),c=s[1]+(n[1]-o[1])/(o[3]-o[1])*(s[3]-s[1]);t[0]&&a.drawLine(l,c,s[0],c,e[0],r[0]),t[1]&&a.drawLine(l,c,l,s[1],e[1],r[1]),t[2]&&a.drawLine(l,c,s[2],c,e[2],r[2]),t[3]&&a.drawLine(l,c,l,s[3],e[3],r[3])}},i.dispose=function(){this.plot.removeOverlay(this)}},{}],343:[function(t,e,r){arguments[4][261][0].apply(r,arguments)},{dup:261}],344:[function(t,e,r){\"use strict\";var n=t(\"glslify\"),i=t(\"gl-shader\"),a=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position, color;\\nattribute float weight;\\n\\nuniform mat4 model, view, projection;\\nuniform vec3 coordinates[3];\\nuniform vec4 colors[3];\\nuniform vec2 screenShape;\\nuniform float lineWidth;\\n\\nvarying vec4 fragColor;\\n\\nvoid main() {\\n  vec3 vertexPosition = mix(coordinates[0],\\n    mix(coordinates[2], coordinates[1], 0.5 * (position + 1.0)), abs(position));\\n\\n  vec4 clipPos = projection * view * model * vec4(vertexPosition, 1.0);\\n  vec2 clipOffset = (projection * view * model * vec4(color, 0.0)).xy;\\n  vec2 delta = weight * clipOffset * screenShape;\\n  vec2 lineOffset = normalize(vec2(delta.y, -delta.x)) / screenShape;\\n\\n  gl_Position   = vec4(clipPos.xy + clipPos.w * 0.5 * lineWidth * lineOffset, clipPos.z, clipPos.w);\\n  fragColor     = color.x * colors[0] + color.y * colors[1] + color.z * colors[2];\\n}\\n\"]),o=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nvarying vec4 fragColor;\\n\\nvoid main() {\\n  gl_FragColor = fragColor;\\n}\"]);e.exports=function(t){return i(t,a,o,null,[{name:\"position\",type:\"vec3\"},{name:\"color\",type:\"vec3\"},{name:\"weight\",type:\"float\"}])}},{\"gl-shader\":335,glslify:343}],345:[function(t,e,r){\"use strict\";var n=t(\"gl-buffer\"),i=t(\"gl-vao\"),a=t(\"./shaders/index\");e.exports=function(t,e){var r=[];function o(t,e,n,i,a,o){var s=[t,e,n,0,0,0,1];s[i+3]=1,s[i]=a,r.push.apply(r,s),s[6]=-1,r.push.apply(r,s),s[i]=o,r.push.apply(r,s),r.push.apply(r,s),s[6]=1,r.push.apply(r,s),s[i]=a,r.push.apply(r,s)}o(0,0,0,0,0,1),o(0,0,0,1,0,1),o(0,0,0,2,0,1),o(1,0,0,1,-1,1),o(1,0,0,2,-1,1),o(0,1,0,0,-1,1),o(0,1,0,2,-1,1),o(0,0,1,0,-1,1),o(0,0,1,1,-1,1);var l=n(t,r),c=i(t,[{type:t.FLOAT,buffer:l,size:3,offset:0,stride:28},{type:t.FLOAT,buffer:l,size:3,offset:12,stride:28},{type:t.FLOAT,buffer:l,size:1,offset:24,stride:28}]),u=a(t);u.attributes.position.location=0,u.attributes.color.location=1,u.attributes.weight.location=2;var f=new s(t,l,c,u);return f.update(e),f};var o=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1];function s(t,e,r,n){this.gl=t,this.buffer=e,this.vao=r,this.shader=n,this.pixelRatio=1,this.bounds=[[-1e3,-1e3,-1e3],[1e3,1e3,1e3]],this.position=[0,0,0],this.lineWidth=[2,2,2],this.colors=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.enabled=[!0,!0,!0],this.drawSides=[!0,!0,!0],this.axes=null}var l=s.prototype,c=[0,0,0],u=[0,0,0],f=[0,0];l.isTransparent=function(){return!1},l.drawTransparent=function(t){},l.draw=function(t){var e=this.gl,r=this.vao,n=this.shader;r.bind(),n.bind();var i,a=t.model||o,s=t.view||o,l=t.projection||o;this.axes&&(i=this.axes.lastCubeProps.axis);for(var h=c,p=u,d=0;d<3;++d)i&&i[d]<0?(h[d]=this.bounds[0][d],p[d]=this.bounds[1][d]):(h[d]=this.bounds[1][d],p[d]=this.bounds[0][d]);f[0]=e.drawingBufferWidth,f[1]=e.drawingBufferHeight,n.uniforms.model=a,n.uniforms.view=s,n.uniforms.projection=l,n.uniforms.coordinates=[this.position,h,p],n.uniforms.colors=this.colors,n.uniforms.screenShape=f;for(d=0;d<3;++d)n.uniforms.lineWidth=this.lineWidth[d]*this.pixelRatio,this.enabled[d]&&(r.draw(e.TRIANGLES,6,6*d),this.drawSides[d]&&r.draw(e.TRIANGLES,12,18+12*d));r.unbind()},l.update=function(t){t&&(\"bounds\"in t&&(this.bounds=t.bounds),\"position\"in t&&(this.position=t.position),\"lineWidth\"in t&&(this.lineWidth=t.lineWidth),\"colors\"in t&&(this.colors=t.colors),\"enabled\"in t&&(this.enabled=t.enabled),\"drawSides\"in t&&(this.drawSides=t.drawSides))},l.dispose=function(){this.vao.dispose(),this.buffer.dispose(),this.shader.dispose()}},{\"./shaders/index\":344,\"gl-buffer\":263,\"gl-vao\":357}],346:[function(t,e,r){var n=t(\"glslify\"),i=n([\"precision highp float;\\n\\nprecision highp float;\\n#define GLSLIFY 1\\n\\nvec3 getOrthogonalVector(vec3 v) {\\n  // Return up-vector for only-z vector.\\n  // Return ax + by + cz = 0, a point that lies on the plane that has v as a normal and that isn't (0,0,0).\\n  // From the above if-statement we have ||a|| > 0  U  ||b|| > 0.\\n  // Assign z = 0, x = -b, y = a:\\n  // a*-b + b*a + c*0 = -ba + ba + 0 = 0\\n  if (v.x*v.x > v.z*v.z || v.y*v.y > v.z*v.z) {\\n    return normalize(vec3(-v.y, v.x, 0.0));\\n  } else {\\n    return normalize(vec3(0.0, v.z, -v.y));\\n  }\\n}\\n\\n// Calculate the tube vertex and normal at the given index.\\n//\\n// The returned vertex is for a tube ring with its center at origin, radius of length(d), pointing in the direction of d.\\n//\\n// Each tube segment is made up of a ring of vertices.\\n// These vertices are used to make up the triangles of the tube by connecting them together in the vertex array.\\n// The indexes of tube segments run from 0 to 8.\\n//\\nvec3 getTubePosition(vec3 d, float index, out vec3 normal) {\\n  float segmentCount = 8.0;\\n\\n  float angle = 2.0 * 3.14159 * (index / segmentCount);\\n\\n  vec3 u = getOrthogonalVector(d);\\n  vec3 v = normalize(cross(u, d));\\n\\n  vec3 x = u * cos(angle) * length(d);\\n  vec3 y = v * sin(angle) * length(d);\\n  vec3 v3 = x + y;\\n\\n  normal = normalize(v3);\\n\\n  return v3;\\n}\\n\\nattribute vec4 vector;\\nattribute vec4 color, position;\\nattribute vec2 uv;\\n\\nuniform float vectorScale, tubeScale;\\nuniform mat4 model, view, projection, inverseModel;\\nuniform vec3 eyePosition, lightPosition;\\n\\nvarying vec3 f_normal, f_lightDirection, f_eyeDirection, f_data, f_position;\\nvarying vec4 f_color;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  // Scale the vector magnitude to stay constant with\\n  // model & view changes.\\n  vec3 normal;\\n  vec3 XYZ = getTubePosition(mat3(model) * (tubeScale * vector.w * normalize(vector.xyz)), position.w, normal);\\n  vec4 tubePosition = model * vec4(position.xyz, 1.0) + vec4(XYZ, 0.0);\\n\\n  //Lighting geometry parameters\\n  vec4 cameraCoordinate = view * tubePosition;\\n  cameraCoordinate.xyz /= cameraCoordinate.w;\\n  f_lightDirection = lightPosition - cameraCoordinate.xyz;\\n  f_eyeDirection   = eyePosition - cameraCoordinate.xyz;\\n  f_normal = normalize((vec4(normal, 0.0) * inverseModel).xyz);\\n\\n  // vec4 m_position  = model * vec4(tubePosition, 1.0);\\n  vec4 t_position  = view * tubePosition;\\n  gl_Position      = projection * t_position;\\n\\n  f_color          = color;\\n  f_data           = tubePosition.xyz;\\n  f_position       = position.xyz;\\n  f_uv             = uv;\\n}\\n\"]),a=n([\"#extension GL_OES_standard_derivatives : enable\\n\\nprecision highp float;\\n#define GLSLIFY 1\\n\\nfloat beckmannDistribution(float x, float roughness) {\\n  float NdotH = max(x, 0.0001);\\n  float cos2Alpha = NdotH * NdotH;\\n  float tan2Alpha = (cos2Alpha - 1.0) / cos2Alpha;\\n  float roughness2 = roughness * roughness;\\n  float denom = 3.141592653589793 * roughness2 * cos2Alpha * cos2Alpha;\\n  return exp(tan2Alpha / roughness2) / denom;\\n}\\n\\nfloat cookTorranceSpecular(\\n  vec3 lightDirection,\\n  vec3 viewDirection,\\n  vec3 surfaceNormal,\\n  float roughness,\\n  float fresnel) {\\n\\n  float VdotN = max(dot(viewDirection, surfaceNormal), 0.0);\\n  float LdotN = max(dot(lightDirection, surfaceNormal), 0.0);\\n\\n  //Half angle vector\\n  vec3 H = normalize(lightDirection + viewDirection);\\n\\n  //Geometric term\\n  float NdotH = max(dot(surfaceNormal, H), 0.0);\\n  float VdotH = max(dot(viewDirection, H), 0.000001);\\n  float LdotH = max(dot(lightDirection, H), 0.000001);\\n  float G1 = (2.0 * NdotH * VdotN) / VdotH;\\n  float G2 = (2.0 * NdotH * LdotN) / LdotH;\\n  float G = min(1.0, min(G1, G2));\\n  \\n  //Distribution term\\n  float D = beckmannDistribution(NdotH, roughness);\\n\\n  //Fresnel term\\n  float F = pow(1.0 - VdotN, fresnel);\\n\\n  //Multiply terms and done\\n  return  G * F * D / max(3.14159265 * VdotN, 0.000001);\\n}\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3 clipBounds[2];\\nuniform float roughness, fresnel, kambient, kdiffuse, kspecular, opacity;\\nuniform sampler2D texture;\\n\\nvarying vec3 f_normal, f_lightDirection, f_eyeDirection, f_data, f_position;\\nvarying vec4 f_color;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], f_position)) discard;\\n  vec3 N = normalize(f_normal);\\n  vec3 L = normalize(f_lightDirection);\\n  vec3 V = normalize(f_eyeDirection);\\n\\n  if(gl_FrontFacing) {\\n    N = -N;\\n  }\\n\\n  float specular = min(1.0, max(0.0, cookTorranceSpecular(L, V, N, roughness, fresnel)));\\n  float diffuse  = min(kambient + kdiffuse * max(dot(N, L), 0.0), 1.0);\\n\\n  vec4 surfaceColor = f_color * texture2D(texture, f_uv);\\n  vec4 litColor = surfaceColor.a * vec4(diffuse * surfaceColor.rgb + kspecular * vec3(1,1,1) * specular,  1.0);\\n\\n  gl_FragColor = litColor * opacity;\\n}\\n\"]),o=n([\"precision highp float;\\n\\nprecision highp float;\\n#define GLSLIFY 1\\n\\nvec3 getOrthogonalVector(vec3 v) {\\n  // Return up-vector for only-z vector.\\n  // Return ax + by + cz = 0, a point that lies on the plane that has v as a normal and that isn't (0,0,0).\\n  // From the above if-statement we have ||a|| > 0  U  ||b|| > 0.\\n  // Assign z = 0, x = -b, y = a:\\n  // a*-b + b*a + c*0 = -ba + ba + 0 = 0\\n  if (v.x*v.x > v.z*v.z || v.y*v.y > v.z*v.z) {\\n    return normalize(vec3(-v.y, v.x, 0.0));\\n  } else {\\n    return normalize(vec3(0.0, v.z, -v.y));\\n  }\\n}\\n\\n// Calculate the tube vertex and normal at the given index.\\n//\\n// The returned vertex is for a tube ring with its center at origin, radius of length(d), pointing in the direction of d.\\n//\\n// Each tube segment is made up of a ring of vertices.\\n// These vertices are used to make up the triangles of the tube by connecting them together in the vertex array.\\n// The indexes of tube segments run from 0 to 8.\\n//\\nvec3 getTubePosition(vec3 d, float index, out vec3 normal) {\\n  float segmentCount = 8.0;\\n\\n  float angle = 2.0 * 3.14159 * (index / segmentCount);\\n\\n  vec3 u = getOrthogonalVector(d);\\n  vec3 v = normalize(cross(u, d));\\n\\n  vec3 x = u * cos(angle) * length(d);\\n  vec3 y = v * sin(angle) * length(d);\\n  vec3 v3 = x + y;\\n\\n  normal = normalize(v3);\\n\\n  return v3;\\n}\\n\\nattribute vec4 vector;\\nattribute vec4 position;\\nattribute vec4 id;\\n\\nuniform mat4 model, view, projection;\\nuniform float tubeScale;\\n\\nvarying vec3 f_position;\\nvarying vec4 f_id;\\n\\nvoid main() {\\n  vec3 normal;\\n  vec3 XYZ = getTubePosition(mat3(model) * (tubeScale * vector.w * normalize(vector.xyz)), position.w, normal);\\n  vec4 tubePosition = model * vec4(position.xyz, 1.0) + vec4(XYZ, 0.0);\\n\\n  gl_Position = projection * view * tubePosition;\\n  f_id        = id;\\n  f_position  = position.xyz;\\n}\\n\"]),s=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3  clipBounds[2];\\nuniform float pickId;\\n\\nvarying vec3 f_position;\\nvarying vec4 f_id;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], f_position)) discard;\\n\\n  gl_FragColor = vec4(pickId, f_id.xyz);\\n}\"]);r.meshShader={vertex:i,fragment:a,attributes:[{name:\"position\",type:\"vec4\"},{name:\"color\",type:\"vec4\"},{name:\"uv\",type:\"vec2\"},{name:\"vector\",type:\"vec4\"}]},r.pickShader={vertex:o,fragment:s,attributes:[{name:\"position\",type:\"vec4\"},{name:\"id\",type:\"vec4\"},{name:\"vector\",type:\"vec4\"}]}},{glslify:347}],347:[function(t,e,r){arguments[4][261][0].apply(r,arguments)},{dup:261}],348:[function(t,e,r){\"use strict\";var n=t(\"gl-vec3\"),i=t(\"gl-vec4\"),a=[\"xyz\",\"xzy\",\"yxz\",\"yzx\",\"zxy\",\"zyx\"],o=function(t,e,r,a){for(var o=0,s=0;s<t.length;s++)for(var l=t[s].velocities,c=0;c<l.length;c++)o=Math.max(o,n.length(l[c]));var u=t.map((function(t){return function(t,e,r,a){for(var o=t.points,s=t.velocities,l=t.divergences,c=[],u=[],f=[],h=[],p=[],d=[],m=0,g=0,v=i.create(),y=i.create(),x=0;x<o.length;x++){var b=o[x],_=s[x],w=l[x];0===e&&(w=.05*r),g=n.length(_)/a,v=i.create(),n.copy(v,_),v[3]=w;for(var T=0;T<8;T++)p[T]=[b[0],b[1],b[2],T];if(h.length>0)for(T=0;T<8;T++){var k=(T+1)%8;c.push(h[T],p[T],p[k],p[k],h[k],h[T]),f.push(y,v,v,v,y,y),d.push(m,g,g,g,m,m);var M=c.length;u.push([M-6,M-5,M-4],[M-3,M-2,M-1])}var A=h;h=p,p=A;var S=y;y=v,v=S;var E=m;m=g,g=E}return{positions:c,cells:u,vectors:f,vertexIntensity:d}}(t,r,a,o)})),f=[],h=[],p=[],d=[];for(s=0;s<u.length;s++){var m=u[s],g=f.length;f=f.concat(m.positions),p=p.concat(m.vectors),d=d.concat(m.vertexIntensity);for(c=0;c<m.cells.length;c++){var v=m.cells[c],y=[];h.push(y);for(var x=0;x<v.length;x++)y.push(v[x]+g)}}return{positions:f,cells:h,vectors:p,vertexIntensity:d,colormap:e}},s=function(t,e){var r,n=t.length;for(r=0;r<n;r++){var i=t[r];if(i===e)return r;if(i>e)return r-1}return r},l=function(t,e,r){return t<e?e:t>r?r:t},c=function(t){var e=1/0;t.sort((function(t,e){return t-e}));for(var r=t.length,n=1;n<r;n++){var i=Math.abs(t[n]-t[n-1]);i<e&&(e=i)}return e};e.exports=function(t,e){var r=t.startingPositions,i=t.maxLength||1e3,u=t.tubeSize||1,f=t.absoluteTubeSize,h=t.gridFill||\"+x+y+z\",p={};-1!==h.indexOf(\"-x\")&&(p.reversedX=!0),-1!==h.indexOf(\"-y\")&&(p.reversedY=!0),-1!==h.indexOf(\"-z\")&&(p.reversedZ=!0),p.filled=a.indexOf(h.replace(/-/g,\"\").replace(/\\+/g,\"\"));var d=t.getVelocity||function(e){return function(t,e,r){var i=e.vectors,a=e.meshgrid,o=t[0],c=t[1],u=t[2],f=a[0].length,h=a[1].length,p=a[2].length,d=s(a[0],o),m=s(a[1],c),g=s(a[2],u),v=d+1,y=m+1,x=g+1;if(d=l(d,0,f-1),v=l(v,0,f-1),m=l(m,0,h-1),y=l(y,0,h-1),g=l(g,0,p-1),x=l(x,0,p-1),d<0||m<0||g<0||v>f-1||y>h-1||x>p-1)return n.create();var b,_,w,T,k,M,A=a[0][d],S=a[0][v],E=a[1][m],L=a[1][y],C=a[2][g],P=(o-A)/(S-A),I=(c-E)/(L-E),O=(u-C)/(a[2][x]-C);switch(isFinite(P)||(P=.5),isFinite(I)||(I=.5),isFinite(O)||(O=.5),r.reversedX&&(d=f-1-d,v=f-1-v),r.reversedY&&(m=h-1-m,y=h-1-y),r.reversedZ&&(g=p-1-g,x=p-1-x),r.filled){case 5:k=g,M=x,w=m*p,T=y*p,b=d*p*h,_=v*p*h;break;case 4:k=g,M=x,b=d*p,_=v*p,w=m*p*f,T=y*p*f;break;case 3:w=m,T=y,k=g*h,M=x*h,b=d*h*p,_=v*h*p;break;case 2:w=m,T=y,b=d*h,_=v*h,k=g*h*f,M=x*h*f;break;case 1:b=d,_=v,k=g*f,M=x*f,w=m*f*p,T=y*f*p;break;default:b=d,_=v,w=m*f,T=y*f,k=g*f*h,M=x*f*h}var z=i[b+w+k],D=i[b+w+M],R=i[b+T+k],F=i[b+T+M],B=i[_+w+k],N=i[_+w+M],j=i[_+T+k],U=i[_+T+M],V=n.create(),q=n.create(),H=n.create(),G=n.create();n.lerp(V,z,B,P),n.lerp(q,D,N,P),n.lerp(H,R,j,P),n.lerp(G,F,U,P);var Y=n.create(),W=n.create();n.lerp(Y,V,H,I),n.lerp(W,q,G,I);var X=n.create();return n.lerp(X,Y,W,O),X}(e,t,p)},m=t.getDivergence||function(t,e){var r=n.create(),i=1e-4;n.add(r,t,[i,0,0]);var a=d(r);n.subtract(a,a,e),n.scale(a,a,1/i),n.add(r,t,[0,i,0]);var o=d(r);n.subtract(o,o,e),n.scale(o,o,1/i),n.add(r,t,[0,0,i]);var s=d(r);return n.subtract(s,s,e),n.scale(s,s,1/i),n.add(r,a,o),n.add(r,r,s),r},g=[],v=e[0][0],y=e[0][1],x=e[0][2],b=e[1][0],_=e[1][1],w=e[1][2],T=function(t){var e=t[0],r=t[1],n=t[2];return!(e<v||e>b||r<y||r>_||n<x||n>w)},k=10*n.distance(e[0],e[1])/i,M=k*k,A=1,S=0,E=r.length;E>1&&(A=function(t){for(var e=[],r=[],n=[],i={},a={},o={},s=t.length,l=0;l<s;l++){var u=t[l],f=u[0],h=u[1],p=u[2];i[f]||(e.push(f),i[f]=!0),a[h]||(r.push(h),a[h]=!0),o[p]||(n.push(p),o[p]=!0)}var d=c(e),m=c(r),g=c(n),v=Math.min(d,m,g);return isFinite(v)?v:1}(r));for(var L=0;L<E;L++){var C=n.create();n.copy(C,r[L]);var P=[C],I=[],O=d(C),z=C;I.push(O);var D=[],R=m(C,O),F=n.length(R);isFinite(F)&&F>S&&(S=F),D.push(F),g.push({points:P,velocities:I,divergences:D});for(var B=0;B<100*i&&P.length<i&&T(C);){B++;var N=n.clone(O),j=n.squaredLength(N);if(0===j)break;if(j>M&&n.scale(N,N,k/Math.sqrt(j)),n.add(N,N,C),O=d(N),n.squaredDistance(z,N)-M>-1e-4*M){P.push(N),z=N,I.push(O);R=m(N,O),F=n.length(R);isFinite(F)&&F>S&&(S=F),D.push(F)}C=N}}var U=o(g,t.colormap,S,A);return f?U.tubeScale=f:(0===S&&(S=1),U.tubeScale=.5*u*A/S),U};var u=t(\"./lib/shaders\"),f=t(\"gl-cone3d\").createMesh;e.exports.createTubeMesh=function(t,e){return f(t,e,{shaders:u,traceType:\"streamtube\"})}},{\"./lib/shaders\":346,\"gl-cone3d\":264,\"gl-vec3\":376,\"gl-vec4\":412}],349:[function(t,e,r){var n=t(\"gl-shader\"),i=t(\"glslify\"),a=i([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec4 uv;\\nattribute vec3 f;\\nattribute vec3 normal;\\n\\nuniform vec3 objectOffset;\\nuniform mat4 model, view, projection, inverseModel;\\nuniform vec3 lightPosition, eyePosition;\\nuniform sampler2D colormap;\\n\\nvarying float value, kill;\\nvarying vec3 worldCoordinate;\\nvarying vec2 planeCoordinate;\\nvarying vec3 lightDirection, eyeDirection, surfaceNormal;\\nvarying vec4 vColor;\\n\\nvoid main() {\\n  vec3 localCoordinate = vec3(uv.zw, f.x);\\n  worldCoordinate = objectOffset + localCoordinate;\\n  vec4 worldPosition = model * vec4(worldCoordinate, 1.0);\\n  vec4 clipPosition = projection * view * worldPosition;\\n  gl_Position = clipPosition;\\n  kill = f.y;\\n  value = f.z;\\n  planeCoordinate = uv.xy;\\n\\n  vColor = texture2D(colormap, vec2(value, value));\\n\\n  //Lighting geometry parameters\\n  vec4 cameraCoordinate = view * worldPosition;\\n  cameraCoordinate.xyz /= cameraCoordinate.w;\\n  lightDirection = lightPosition - cameraCoordinate.xyz;\\n  eyeDirection   = eyePosition - cameraCoordinate.xyz;\\n  surfaceNormal  = normalize((vec4(normal,0) * inverseModel).xyz);\\n}\\n\"]),o=i([\"precision highp float;\\n#define GLSLIFY 1\\n\\nfloat beckmannDistribution(float x, float roughness) {\\n  float NdotH = max(x, 0.0001);\\n  float cos2Alpha = NdotH * NdotH;\\n  float tan2Alpha = (cos2Alpha - 1.0) / cos2Alpha;\\n  float roughness2 = roughness * roughness;\\n  float denom = 3.141592653589793 * roughness2 * cos2Alpha * cos2Alpha;\\n  return exp(tan2Alpha / roughness2) / denom;\\n}\\n\\nfloat beckmannSpecular(\\n  vec3 lightDirection,\\n  vec3 viewDirection,\\n  vec3 surfaceNormal,\\n  float roughness) {\\n  return beckmannDistribution(dot(surfaceNormal, normalize(lightDirection + viewDirection)), roughness);\\n}\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3 lowerBound, upperBound;\\nuniform float contourTint;\\nuniform vec4 contourColor;\\nuniform sampler2D colormap;\\nuniform vec3 clipBounds[2];\\nuniform float roughness, fresnel, kambient, kdiffuse, kspecular, opacity;\\nuniform float vertexColor;\\n\\nvarying float value, kill;\\nvarying vec3 worldCoordinate;\\nvarying vec3 lightDirection, eyeDirection, surfaceNormal;\\nvarying vec4 vColor;\\n\\nvoid main() {\\n  if (\\n    kill > 0.0 ||\\n    vColor.a == 0.0 ||\\n    outOfRange(clipBounds[0], clipBounds[1], worldCoordinate)\\n  ) discard;\\n\\n  vec3 N = normalize(surfaceNormal);\\n  vec3 V = normalize(eyeDirection);\\n  vec3 L = normalize(lightDirection);\\n\\n  if(gl_FrontFacing) {\\n    N = -N;\\n  }\\n\\n  float specular = max(beckmannSpecular(L, V, N, roughness), 0.);\\n  float diffuse  = min(kambient + kdiffuse * max(dot(N, L), 0.0), 1.0);\\n\\n  //decide how to interpolate color \\u2014 in vertex or in fragment\\n  vec4 surfaceColor =\\n    step(vertexColor, .5) * texture2D(colormap, vec2(value, value)) +\\n    step(.5, vertexColor) * vColor;\\n\\n  vec4 litColor = surfaceColor.a * vec4(diffuse * surfaceColor.rgb + kspecular * vec3(1,1,1) * specular,  1.0);\\n\\n  gl_FragColor = mix(litColor, contourColor, contourTint) * opacity;\\n}\\n\"]),s=i([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec4 uv;\\nattribute float f;\\n\\nuniform vec3 objectOffset;\\nuniform mat3 permutation;\\nuniform mat4 model, view, projection;\\nuniform float height, zOffset;\\nuniform sampler2D colormap;\\n\\nvarying float value, kill;\\nvarying vec3 worldCoordinate;\\nvarying vec2 planeCoordinate;\\nvarying vec3 lightDirection, eyeDirection, surfaceNormal;\\nvarying vec4 vColor;\\n\\nvoid main() {\\n  vec3 dataCoordinate = permutation * vec3(uv.xy, height);\\n  worldCoordinate = objectOffset + dataCoordinate;\\n  vec4 worldPosition = model * vec4(worldCoordinate, 1.0);\\n\\n  vec4 clipPosition = projection * view * worldPosition;\\n  clipPosition.z += zOffset;\\n\\n  gl_Position = clipPosition;\\n  value = f + objectOffset.z;\\n  kill = -1.0;\\n  planeCoordinate = uv.zw;\\n\\n  vColor = texture2D(colormap, vec2(value, value));\\n\\n  //Don't do lighting for contours\\n  surfaceNormal   = vec3(1,0,0);\\n  eyeDirection    = vec3(0,1,0);\\n  lightDirection  = vec3(0,0,1);\\n}\\n\"]),l=i([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec2 shape;\\nuniform vec3 clipBounds[2];\\nuniform float pickId;\\n\\nvarying float value, kill;\\nvarying vec3 worldCoordinate;\\nvarying vec2 planeCoordinate;\\nvarying vec3 surfaceNormal;\\n\\nvec2 splitFloat(float v) {\\n  float vh = 255.0 * v;\\n  float upper = floor(vh);\\n  float lower = fract(vh);\\n  return vec2(upper / 255.0, floor(lower * 16.0) / 16.0);\\n}\\n\\nvoid main() {\\n  if ((kill > 0.0) ||\\n      (outOfRange(clipBounds[0], clipBounds[1], worldCoordinate))) discard;\\n\\n  vec2 ux = splitFloat(planeCoordinate.x / shape.x);\\n  vec2 uy = splitFloat(planeCoordinate.y / shape.y);\\n  gl_FragColor = vec4(pickId, ux.x, uy.x, ux.y + (uy.y/16.0));\\n}\\n\"]);r.createShader=function(t){var e=n(t,a,o,null,[{name:\"uv\",type:\"vec4\"},{name:\"f\",type:\"vec3\"},{name:\"normal\",type:\"vec3\"}]);return e.attributes.uv.location=0,e.attributes.f.location=1,e.attributes.normal.location=2,e},r.createPickShader=function(t){var e=n(t,a,l,null,[{name:\"uv\",type:\"vec4\"},{name:\"f\",type:\"vec3\"},{name:\"normal\",type:\"vec3\"}]);return e.attributes.uv.location=0,e.attributes.f.location=1,e.attributes.normal.location=2,e},r.createContourShader=function(t){var e=n(t,s,o,null,[{name:\"uv\",type:\"vec4\"},{name:\"f\",type:\"float\"}]);return e.attributes.uv.location=0,e.attributes.f.location=1,e},r.createPickContourShader=function(t){var e=n(t,s,l,null,[{name:\"uv\",type:\"vec4\"},{name:\"f\",type:\"float\"}]);return e.attributes.uv.location=0,e.attributes.f.location=1,e}},{\"gl-shader\":335,glslify:438}],350:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.gl,r=y(e),n=b(e),s=x(e),l=_(e),c=i(e),u=a(e,[{buffer:c,size:4,stride:40,offset:0},{buffer:c,size:3,stride:40,offset:16},{buffer:c,size:3,stride:40,offset:28}]),f=i(e),h=a(e,[{buffer:f,size:4,stride:20,offset:0},{buffer:f,size:1,stride:20,offset:16}]),p=i(e),d=a(e,[{buffer:p,size:2,type:e.FLOAT}]),m=o(e,1,256,e.RGBA,e.UNSIGNED_BYTE);m.minFilter=e.LINEAR,m.magFilter=e.LINEAR;var g=new A(e,[0,0],[[0,0,0],[0,0,0]],r,n,c,u,m,s,l,f,h,p,d,[0,0,0]),v={levels:[[],[],[]]};for(var w in t)v[w]=t[w];return v.colormap=v.colormap||\"jet\",g.update(v),g};var n=t(\"bit-twiddle\"),i=t(\"gl-buffer\"),a=t(\"gl-vao\"),o=t(\"gl-texture2d\"),s=t(\"typedarray-pool\"),l=t(\"colormap\"),c=t(\"ndarray-ops\"),u=t(\"ndarray-pack\"),f=t(\"ndarray\"),h=t(\"surface-nets\"),p=t(\"gl-mat4/multiply\"),d=t(\"gl-mat4/invert\"),m=t(\"binary-search-bounds\"),g=t(\"ndarray-gradient\"),v=t(\"./lib/shaders\"),y=v.createShader,x=v.createContourShader,b=v.createPickShader,_=v.createPickContourShader,w=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1],T=[[0,0],[0,1],[1,0],[1,1],[1,0],[0,1]],k=[[0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0]];function M(t,e,r,n,i){this.position=t,this.index=e,this.uv=r,this.level=n,this.dataCoordinate=i}!function(){for(var t=0;t<3;++t){var e=k[t],r=(t+2)%3;e[(t+1)%3+0]=1,e[r+3]=1,e[t+6]=1}}();function A(t,e,r,n,i,a,o,l,c,u,h,p,d,m,g){this.gl=t,this.shape=e,this.bounds=r,this.objectOffset=g,this.intensityBounds=[],this._shader=n,this._pickShader=i,this._coordinateBuffer=a,this._vao=o,this._colorMap=l,this._contourShader=c,this._contourPickShader=u,this._contourBuffer=h,this._contourVAO=p,this._contourOffsets=[[],[],[]],this._contourCounts=[[],[],[]],this._vertexCount=0,this._pickResult=new M([0,0,0],[0,0],[0,0],[0,0,0],[0,0,0]),this._dynamicBuffer=d,this._dynamicVAO=m,this._dynamicOffsets=[0,0,0],this._dynamicCounts=[0,0,0],this.contourWidth=[1,1,1],this.contourLevels=[[1],[1],[1]],this.contourTint=[0,0,0],this.contourColor=[[.5,.5,.5,1],[.5,.5,.5,1],[.5,.5,.5,1]],this.showContour=!0,this.showSurface=!0,this.enableHighlight=[!0,!0,!0],this.highlightColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.highlightTint=[1,1,1],this.highlightLevel=[-1,-1,-1],this.enableDynamic=[!0,!0,!0],this.dynamicLevel=[NaN,NaN,NaN],this.dynamicColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.dynamicTint=[1,1,1],this.dynamicWidth=[1,1,1],this.axesBounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],this.surfaceProject=[!1,!1,!1],this.contourProject=[[!1,!1,!1],[!1,!1,!1],[!1,!1,!1]],this.colorBounds=[!1,!1],this._field=[f(s.mallocFloat(1024),[0,0]),f(s.mallocFloat(1024),[0,0]),f(s.mallocFloat(1024),[0,0])],this.pickId=1,this.clipBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.snapToData=!1,this.pixelRatio=1,this.opacity=1,this.lightPosition=[10,1e4,0],this.ambientLight=.8,this.diffuseLight=.8,this.specularLight=2,this.roughness=.5,this.fresnel=1.5,this.vertexColor=0,this.dirty=!0}var S=A.prototype;S.genColormap=function(t,e){var r=!1,n=u([l({colormap:t,nshades:256,format:\"rgba\"}).map((function(t,n){var i=e?function(t,e){if(!e)return 1;if(!e.length)return 1;for(var r=0;r<e.length;++r){if(e.length<2)return 1;if(e[r][0]===t)return e[r][1];if(e[r][0]>t&&r>0){var n=(e[r][0]-t)/(e[r][0]-e[r-1][0]);return e[r][1]*(1-n)+n*e[r-1][1]}}return 1}(n/255,e):t[3];return i<1&&(r=!0),[t[0],t[1],t[2],255*i]}))]);return c.divseq(n,255),this.hasAlphaScale=r,n},S.isTransparent=function(){return this.opacity<1||this.hasAlphaScale},S.isOpaque=function(){return!this.isTransparent()},S.pickSlots=1,S.setPickBase=function(t){this.pickId=t};var E=[0,0,0],L={showSurface:!1,showContour:!1,projections:[w.slice(),w.slice(),w.slice()],clipBounds:[[[0,0,0],[0,0,0]],[[0,0,0],[0,0,0]],[[0,0,0],[0,0,0]]]};function C(t,e){var r,n,i,a=e.axes&&e.axes.lastCubeProps.axis||E,o=e.showSurface,s=e.showContour;for(r=0;r<3;++r)for(o=o||e.surfaceProject[r],n=0;n<3;++n)s=s||e.contourProject[r][n];for(r=0;r<3;++r){var l=L.projections[r];for(n=0;n<16;++n)l[n]=0;for(n=0;n<4;++n)l[5*n]=1;l[5*r]=0,l[12+r]=e.axesBounds[+(a[r]>0)][r],p(l,t.model,l);var c=L.clipBounds[r];for(i=0;i<2;++i)for(n=0;n<3;++n)c[i][n]=t.clipBounds[i][n];c[0][r]=-1e8,c[1][r]=1e8}return L.showSurface=o,L.showContour=s,L}var P={model:w,view:w,projection:w,inverseModel:w.slice(),lowerBound:[0,0,0],upperBound:[0,0,0],colorMap:0,clipBounds:[[0,0,0],[0,0,0]],height:0,contourTint:0,contourColor:[0,0,0,1],permutation:[1,0,0,0,1,0,0,0,1],zOffset:-1e-4,objectOffset:[0,0,0],kambient:1,kdiffuse:1,kspecular:1,lightPosition:[1e3,1e3,1e3],eyePosition:[0,0,0],roughness:1,fresnel:1,opacity:1,vertexColor:0},I=w.slice(),O=[1,0,0,0,1,0,0,0,1];function z(t,e){t=t||{};var r=this.gl;r.disable(r.CULL_FACE),this._colorMap.bind(0);var n=P;n.model=t.model||w,n.view=t.view||w,n.projection=t.projection||w,n.lowerBound=[this.bounds[0][0],this.bounds[0][1],this.colorBounds[0]||this.bounds[0][2]],n.upperBound=[this.bounds[1][0],this.bounds[1][1],this.colorBounds[1]||this.bounds[1][2]],n.objectOffset=this.objectOffset,n.contourColor=this.contourColor[0],n.inverseModel=d(n.inverseModel,n.model);for(var i=0;i<2;++i)for(var a=n.clipBounds[i],o=0;o<3;++o)a[o]=Math.min(Math.max(this.clipBounds[i][o],-1e8),1e8);n.kambient=this.ambientLight,n.kdiffuse=this.diffuseLight,n.kspecular=this.specularLight,n.roughness=this.roughness,n.fresnel=this.fresnel,n.opacity=this.opacity,n.height=0,n.permutation=O,n.vertexColor=this.vertexColor;var s=I;for(p(s,n.view,n.model),p(s,n.projection,s),d(s,s),i=0;i<3;++i)n.eyePosition[i]=s[12+i]/s[15];var l=s[15];for(i=0;i<3;++i)l+=this.lightPosition[i]*s[4*i+3];for(i=0;i<3;++i){var c=s[12+i];for(o=0;o<3;++o)c+=s[4*o+i]*this.lightPosition[o];n.lightPosition[i]=c/l}var u=C(n,this);if(u.showSurface){for(this._shader.bind(),this._shader.uniforms=n,this._vao.bind(),this.showSurface&&this._vertexCount&&this._vao.draw(r.TRIANGLES,this._vertexCount),i=0;i<3;++i)this.surfaceProject[i]&&this.vertexCount&&(this._shader.uniforms.model=u.projections[i],this._shader.uniforms.clipBounds=u.clipBounds[i],this._vao.draw(r.TRIANGLES,this._vertexCount));this._vao.unbind()}if(u.showContour){var f=this._contourShader;n.kambient=1,n.kdiffuse=0,n.kspecular=0,n.opacity=1,f.bind(),f.uniforms=n;var h=this._contourVAO;for(h.bind(),i=0;i<3;++i)for(f.uniforms.permutation=k[i],r.lineWidth(this.contourWidth[i]*this.pixelRatio),o=0;o<this.contourLevels[i].length;++o)o===this.highlightLevel[i]?(f.uniforms.contourColor=this.highlightColor[i],f.uniforms.contourTint=this.highlightTint[i]):0!==o&&o-1!==this.highlightLevel[i]||(f.uniforms.contourColor=this.contourColor[i],f.uniforms.contourTint=this.contourTint[i]),this._contourCounts[i][o]&&(f.uniforms.height=this.contourLevels[i][o],h.draw(r.LINES,this._contourCounts[i][o],this._contourOffsets[i][o]));for(i=0;i<3;++i)for(f.uniforms.model=u.projections[i],f.uniforms.clipBounds=u.clipBounds[i],o=0;o<3;++o)if(this.contourProject[i][o]){f.uniforms.permutation=k[o],r.lineWidth(this.contourWidth[o]*this.pixelRatio);for(var m=0;m<this.contourLevels[o].length;++m)m===this.highlightLevel[o]?(f.uniforms.contourColor=this.highlightColor[o],f.uniforms.contourTint=this.highlightTint[o]):0!==m&&m-1!==this.highlightLevel[o]||(f.uniforms.contourColor=this.contourColor[o],f.uniforms.contourTint=this.contourTint[o]),this._contourCounts[o][m]&&(f.uniforms.height=this.contourLevels[o][m],h.draw(r.LINES,this._contourCounts[o][m],this._contourOffsets[o][m]))}for(h.unbind(),(h=this._dynamicVAO).bind(),i=0;i<3;++i)if(0!==this._dynamicCounts[i])for(f.uniforms.model=n.model,f.uniforms.clipBounds=n.clipBounds,f.uniforms.permutation=k[i],r.lineWidth(this.dynamicWidth[i]*this.pixelRatio),f.uniforms.contourColor=this.dynamicColor[i],f.uniforms.contourTint=this.dynamicTint[i],f.uniforms.height=this.dynamicLevel[i],h.draw(r.LINES,this._dynamicCounts[i],this._dynamicOffsets[i]),o=0;o<3;++o)this.contourProject[o][i]&&(f.uniforms.model=u.projections[o],f.uniforms.clipBounds=u.clipBounds[o],h.draw(r.LINES,this._dynamicCounts[i],this._dynamicOffsets[i]));h.unbind()}}S.draw=function(t){return z.call(this,t,!1)},S.drawTransparent=function(t){return z.call(this,t,!0)};var D={model:w,view:w,projection:w,inverseModel:w,clipBounds:[[0,0,0],[0,0,0]],height:0,shape:[0,0],pickId:0,lowerBound:[0,0,0],upperBound:[0,0,0],zOffset:0,objectOffset:[0,0,0],permutation:[1,0,0,0,1,0,0,0,1],lightPosition:[0,0,0],eyePosition:[0,0,0]};function R(t,e){return Array.isArray(t)?[e(t[0]),e(t[1]),e(t[2])]:[e(t),e(t),e(t)]}function F(t){return Array.isArray(t)?3===t.length?[t[0],t[1],t[2],1]:[t[0],t[1],t[2],t[3]]:[0,0,0,1]}function B(t){if(Array.isArray(t)){if(Array.isArray(t))return[F(t[0]),F(t[1]),F(t[2])];var e=F(t);return[e.slice(),e.slice(),e.slice()]}}S.drawPick=function(t){t=t||{};var e=this.gl;e.disable(e.CULL_FACE);var r=D;r.model=t.model||w,r.view=t.view||w,r.projection=t.projection||w,r.shape=this._field[2].shape,r.pickId=this.pickId/255,r.lowerBound=this.bounds[0],r.upperBound=this.bounds[1],r.objectOffset=this.objectOffset,r.permutation=O;for(var n=0;n<2;++n)for(var i=r.clipBounds[n],a=0;a<3;++a)i[a]=Math.min(Math.max(this.clipBounds[n][a],-1e8),1e8);var o=C(r,this);if(o.showSurface){for(this._pickShader.bind(),this._pickShader.uniforms=r,this._vao.bind(),this._vao.draw(e.TRIANGLES,this._vertexCount),n=0;n<3;++n)this.surfaceProject[n]&&(this._pickShader.uniforms.model=o.projections[n],this._pickShader.uniforms.clipBounds=o.clipBounds[n],this._vao.draw(e.TRIANGLES,this._vertexCount));this._vao.unbind()}if(o.showContour){var s=this._contourPickShader;s.bind(),s.uniforms=r;var l=this._contourVAO;for(l.bind(),a=0;a<3;++a)for(e.lineWidth(this.contourWidth[a]*this.pixelRatio),s.uniforms.permutation=k[a],n=0;n<this.contourLevels[a].length;++n)this._contourCounts[a][n]&&(s.uniforms.height=this.contourLevels[a][n],l.draw(e.LINES,this._contourCounts[a][n],this._contourOffsets[a][n]));for(n=0;n<3;++n)for(s.uniforms.model=o.projections[n],s.uniforms.clipBounds=o.clipBounds[n],a=0;a<3;++a)if(this.contourProject[n][a]){s.uniforms.permutation=k[a],e.lineWidth(this.contourWidth[a]*this.pixelRatio);for(var c=0;c<this.contourLevels[a].length;++c)this._contourCounts[a][c]&&(s.uniforms.height=this.contourLevels[a][c],l.draw(e.LINES,this._contourCounts[a][c],this._contourOffsets[a][c]))}l.unbind()}},S.pick=function(t){if(!t)return null;if(t.id!==this.pickId)return null;var e=this._field[2].shape,r=this._pickResult,n=e[0]*(t.value[0]+(t.value[2]>>4)/16)/255,i=Math.floor(n),a=n-i,o=e[1]*(t.value[1]+(15&t.value[2])/16)/255,s=Math.floor(o),l=o-s;i+=1,s+=1;var c=r.position;c[0]=c[1]=c[2]=0;for(var u=0;u<2;++u)for(var f=u?a:1-a,h=0;h<2;++h)for(var p=i+u,d=s+h,g=f*(h?l:1-l),v=0;v<3;++v)c[v]+=this._field[v].get(p,d)*g;for(var y=this._pickResult.level,x=0;x<3;++x)if(y[x]=m.le(this.contourLevels[x],c[x]),y[x]<0)this.contourLevels[x].length>0&&(y[x]=0);else if(y[x]<this.contourLevels[x].length-1){var b=this.contourLevels[x][y[x]],_=this.contourLevels[x][y[x]+1];Math.abs(b-c[x])>Math.abs(_-c[x])&&(y[x]+=1)}for(r.index[0]=a<.5?i:i+1,r.index[1]=l<.5?s:s+1,r.uv[0]=n/e[0],r.uv[1]=o/e[1],v=0;v<3;++v)r.dataCoordinate[v]=this._field[v].get(r.index[0],r.index[1]);return r},S.padField=function(t,e){var r=e.shape.slice(),n=t.shape.slice();c.assign(t.lo(1,1).hi(r[0],r[1]),e),c.assign(t.lo(1).hi(r[0],1),e.hi(r[0],1)),c.assign(t.lo(1,n[1]-1).hi(r[0],1),e.lo(0,r[1]-1).hi(r[0],1)),c.assign(t.lo(0,1).hi(1,r[1]),e.hi(1)),c.assign(t.lo(n[0]-1,1).hi(1,r[1]),e.lo(r[0]-1)),t.set(0,0,e.get(0,0)),t.set(0,n[1]-1,e.get(0,r[1]-1)),t.set(n[0]-1,0,e.get(r[0]-1,0)),t.set(n[0]-1,n[1]-1,e.get(r[0]-1,r[1]-1))},S.update=function(t){t=t||{},this.objectOffset=t.objectOffset||this.objectOffset,this.dirty=!0,\"contourWidth\"in t&&(this.contourWidth=R(t.contourWidth,Number)),\"showContour\"in t&&(this.showContour=R(t.showContour,Boolean)),\"showSurface\"in t&&(this.showSurface=!!t.showSurface),\"contourTint\"in t&&(this.contourTint=R(t.contourTint,Boolean)),\"contourColor\"in t&&(this.contourColor=B(t.contourColor)),\"contourProject\"in t&&(this.contourProject=R(t.contourProject,(function(t){return R(t,Boolean)}))),\"surfaceProject\"in t&&(this.surfaceProject=t.surfaceProject),\"dynamicColor\"in t&&(this.dynamicColor=B(t.dynamicColor)),\"dynamicTint\"in t&&(this.dynamicTint=R(t.dynamicTint,Number)),\"dynamicWidth\"in t&&(this.dynamicWidth=R(t.dynamicWidth,Number)),\"opacity\"in t&&(this.opacity=t.opacity),\"opacityscale\"in t&&(this.opacityscale=t.opacityscale),\"colorBounds\"in t&&(this.colorBounds=t.colorBounds),\"vertexColor\"in t&&(this.vertexColor=t.vertexColor?1:0),\"colormap\"in t&&this._colorMap.setPixels(this.genColormap(t.colormap,this.opacityscale));var e=t.field||t.coords&&t.coords[2]||null,r=!1;if(e||(e=this._field[2].shape[0]||this._field[2].shape[2]?this._field[2].lo(1,1).hi(this._field[2].shape[0]-2,this._field[2].shape[1]-2):this._field[2].hi(0,0)),\"field\"in t||\"coords\"in t){var i=(e.shape[0]+2)*(e.shape[1]+2);i>this._field[2].data.length&&(s.freeFloat(this._field[2].data),this._field[2].data=s.mallocFloat(n.nextPow2(i))),this._field[2]=f(this._field[2].data,[e.shape[0]+2,e.shape[1]+2]),this.padField(this._field[2],e),this.shape=e.shape.slice();for(var a=this.shape,o=0;o<2;++o)this._field[2].size>this._field[o].data.length&&(s.freeFloat(this._field[o].data),this._field[o].data=s.mallocFloat(this._field[2].size)),this._field[o]=f(this._field[o].data,[a[0]+2,a[1]+2]);if(t.coords){var l=t.coords;if(!Array.isArray(l)||3!==l.length)throw new Error(\"gl-surface: invalid coordinates for x/y\");for(o=0;o<2;++o){var c=l[o];for(v=0;v<2;++v)if(c.shape[v]!==a[v])throw new Error(\"gl-surface: coords have incorrect shape\");this.padField(this._field[o],c)}}else if(t.ticks){var u=t.ticks;if(!Array.isArray(u)||2!==u.length)throw new Error(\"gl-surface: invalid ticks\");for(o=0;o<2;++o){var p=u[o];if((Array.isArray(p)||p.length)&&(p=f(p)),p.shape[0]!==a[o])throw new Error(\"gl-surface: invalid tick length\");var d=f(p.data,a);d.stride[o]=p.stride[0],d.stride[1^o]=0,this.padField(this._field[o],d)}}else{for(o=0;o<2;++o){var m=[0,0];m[o]=1,this._field[o]=f(this._field[o].data,[a[0]+2,a[1]+2],m,0)}this._field[0].set(0,0,0);for(var v=0;v<a[0];++v)this._field[0].set(v+1,0,v);for(this._field[0].set(a[0]+1,0,a[0]-1),this._field[1].set(0,0,0),v=0;v<a[1];++v)this._field[1].set(0,v+1,v);this._field[1].set(0,a[1]+1,a[1]-1)}var y=this._field,x=f(s.mallocFloat(3*y[2].size*2),[3,a[0]+2,a[1]+2,2]);for(o=0;o<3;++o)g(x.pick(o),y[o],\"mirror\");var b=f(s.mallocFloat(3*y[2].size),[a[0]+2,a[1]+2,3]);for(o=0;o<a[0]+2;++o)for(v=0;v<a[1]+2;++v){var _=x.get(0,o,v,0),w=x.get(0,o,v,1),k=x.get(1,o,v,0),M=x.get(1,o,v,1),A=x.get(2,o,v,0),S=x.get(2,o,v,1),E=k*S-M*A,L=A*w-S*_,C=_*M-w*k,P=Math.sqrt(E*E+L*L+C*C);P<1e-8?(P=Math.max(Math.abs(E),Math.abs(L),Math.abs(C)))<1e-8?(C=1,L=E=0,P=1):P=1/P:P=1/Math.sqrt(P),b.set(o,v,0,E*P),b.set(o,v,1,L*P),b.set(o,v,2,C*P)}s.free(x.data);var I=[1/0,1/0,1/0],O=[-1/0,-1/0,-1/0],z=1/0,D=-1/0,F=(a[0]-1)*(a[1]-1)*6,N=s.mallocFloat(n.nextPow2(10*F)),j=0,U=0;for(o=0;o<a[0]-1;++o)t:for(v=0;v<a[1]-1;++v){for(var V=0;V<2;++V)for(var q=0;q<2;++q)for(var H=0;H<3;++H){var G=this._field[H].get(1+o+V,1+v+q);if(isNaN(G)||!isFinite(G))continue t}for(H=0;H<6;++H){var Y=o+T[H][0],W=v+T[H][1],X=this._field[0].get(Y+1,W+1),Z=this._field[1].get(Y+1,W+1);G=this._field[2].get(Y+1,W+1),E=b.get(Y+1,W+1,0),L=b.get(Y+1,W+1,1),C=b.get(Y+1,W+1,2),t.intensity&&(J=t.intensity.get(Y,W));var J=t.intensity?t.intensity.get(Y,W):G+this.objectOffset[2];N[j++]=Y,N[j++]=W,N[j++]=X,N[j++]=Z,N[j++]=G,N[j++]=0,N[j++]=J,N[j++]=E,N[j++]=L,N[j++]=C,I[0]=Math.min(I[0],X+this.objectOffset[0]),I[1]=Math.min(I[1],Z+this.objectOffset[1]),I[2]=Math.min(I[2],G+this.objectOffset[2]),z=Math.min(z,J),O[0]=Math.max(O[0],X+this.objectOffset[0]),O[1]=Math.max(O[1],Z+this.objectOffset[1]),O[2]=Math.max(O[2],G+this.objectOffset[2]),D=Math.max(D,J),U+=1}}for(t.intensityBounds&&(z=+t.intensityBounds[0],D=+t.intensityBounds[1]),o=6;o<j;o+=10)N[o]=(N[o]-z)/(D-z);this._vertexCount=U,this._coordinateBuffer.update(N.subarray(0,j)),s.freeFloat(N),s.free(b.data),this.bounds=[I,O],this.intensity=t.intensity||this._field[2],this.intensityBounds[0]===z&&this.intensityBounds[1]===D||(r=!0),this.intensityBounds=[z,D]}if(\"levels\"in t){var K=t.levels;for(K=Array.isArray(K[0])?K.slice():[[],[],K],o=0;o<3;++o)K[o]=K[o].slice(),K[o].sort((function(t,e){return t-e}));for(o=0;o<3;++o)for(v=0;v<K[o].length;++v)K[o][v]-=this.objectOffset[o];t:for(o=0;o<3;++o){if(K[o].length!==this.contourLevels[o].length){r=!0;break}for(v=0;v<K[o].length;++v)if(K[o][v]!==this.contourLevels[o][v]){r=!0;break t}}this.contourLevels=K}if(r){y=this._field,a=this.shape;for(var Q=[],$=0;$<3;++$){var tt=this.contourLevels[$],et=[],rt=[],nt=[0,0,0];for(o=0;o<tt.length;++o){var it=h(this._field[$],tt[o]);et.push(Q.length/5|0),U=0;t:for(v=0;v<it.cells.length;++v){var at=it.cells[v];for(H=0;H<2;++H){var ot=it.positions[at[H]],st=ot[0],lt=0|Math.floor(st),ct=st-lt,ut=ot[1],ft=0|Math.floor(ut),ht=ut-ft,pt=!1;e:for(var dt=0;dt<3;++dt){nt[dt]=0;var mt=($+dt+1)%3;for(V=0;V<2;++V){var gt=V?ct:1-ct;for(Y=0|Math.min(Math.max(lt+V,0),a[0]),q=0;q<2;++q){var vt=q?ht:1-ht;if(W=0|Math.min(Math.max(ft+q,0),a[1]),G=dt<2?this._field[mt].get(Y,W):(this.intensity.get(Y,W)-this.intensityBounds[0])/(this.intensityBounds[1]-this.intensityBounds[0]),!isFinite(G)||isNaN(G)){pt=!0;break e}var yt=gt*vt;nt[dt]+=yt*G}}}if(pt){if(H>0){for(var xt=0;xt<5;++xt)Q.pop();U-=1}continue t}Q.push(nt[0],nt[1],ot[0],ot[1],nt[2]),U+=1}}rt.push(U)}this._contourOffsets[$]=et,this._contourCounts[$]=rt}var bt=s.mallocFloat(Q.length);for(o=0;o<Q.length;++o)bt[o]=Q[o];this._contourBuffer.update(bt),s.freeFloat(bt)}},S.dispose=function(){this._shader.dispose(),this._vao.dispose(),this._coordinateBuffer.dispose(),this._colorMap.dispose(),this._contourBuffer.dispose(),this._contourVAO.dispose(),this._contourShader.dispose(),this._contourPickShader.dispose(),this._dynamicBuffer.dispose(),this._dynamicVAO.dispose();for(var t=0;t<3;++t)s.freeFloat(this._field[t].data)},S.highlight=function(t){var e,r;if(!t)return this._dynamicCounts=[0,0,0],this.dyanamicLevel=[NaN,NaN,NaN],void(this.highlightLevel=[-1,-1,-1]);for(e=0;e<3;++e)this.enableHighlight[e]?this.highlightLevel[e]=t.level[e]:this.highlightLevel[e]=-1;for(r=this.snapToData?t.dataCoordinate:t.position,e=0;e<3;++e)r[e]-=this.objectOffset[e];if(this.enableDynamic[0]&&r[0]!==this.dynamicLevel[0]||this.enableDynamic[1]&&r[1]!==this.dynamicLevel[1]||this.enableDynamic[2]&&r[2]!==this.dynamicLevel[2]){for(var n=0,i=this.shape,a=s.mallocFloat(12*i[0]*i[1]),o=0;o<3;++o)if(this.enableDynamic[o]){this.dynamicLevel[o]=r[o];var l=(o+1)%3,c=(o+2)%3,u=this._field[o],f=this._field[l],p=this._field[c],d=h(u,r[o]),m=d.cells,g=d.positions;for(this._dynamicOffsets[o]=n,e=0;e<m.length;++e)for(var v=m[e],y=0;y<2;++y){var x=g[v[y]],b=+x[0],_=0|b,w=0|Math.min(_+1,i[0]),T=b-_,k=1-T,M=+x[1],A=0|M,S=0|Math.min(A+1,i[1]),E=M-A,L=1-E,C=k*L,P=k*E,I=T*L,O=T*E,z=C*f.get(_,A)+P*f.get(_,S)+I*f.get(w,A)+O*f.get(w,S),D=C*p.get(_,A)+P*p.get(_,S)+I*p.get(w,A)+O*p.get(w,S);if(isNaN(z)||isNaN(D)){y&&(n-=1);break}a[2*n+0]=z,a[2*n+1]=D,n+=1}this._dynamicCounts[o]=n-this._dynamicOffsets[o]}else this.dynamicLevel[o]=NaN,this._dynamicCounts[o]=0;this._dynamicBuffer.update(a.subarray(0,2*n)),s.freeFloat(a)}}},{\"./lib/shaders\":349,\"binary-search-bounds\":103,\"bit-twiddle\":104,colormap:137,\"gl-buffer\":263,\"gl-mat4/invert\":295,\"gl-mat4/multiply\":297,\"gl-texture2d\":352,\"gl-vao\":357,ndarray:479,\"ndarray-gradient\":472,\"ndarray-ops\":474,\"ndarray-pack\":475,\"surface-nets\":587,\"typedarray-pool\":613}],351:[function(t,e,r){\"use strict\";var n=t(\"css-font\"),i=t(\"pick-by-alias\"),a=t(\"regl\"),o=t(\"gl-util/context\"),s=t(\"es6-weak-map\"),l=t(\"color-normalize\"),c=t(\"font-atlas\"),u=t(\"typedarray-pool\"),f=t(\"parse-rect\"),h=t(\"is-plain-obj\"),p=t(\"parse-unit\"),d=t(\"to-px\"),m=t(\"detect-kerning\"),g=t(\"object-assign\"),v=t(\"font-measure\"),y=t(\"flatten-vertex-data\"),x=t(\"bit-twiddle\").nextPow2,b=new s,_=!1;if(document.body){var w=document.body.appendChild(document.createElement(\"div\"));w.style.font=\"italic small-caps bold condensed 16px/2 cursive\",getComputedStyle(w).fontStretch&&(_=!0),document.body.removeChild(w)}var T=function(t){!function(t){return\"function\"==typeof t&&t._gl&&t.prop&&t.texture&&t.buffer}(t)?this.gl=o(t):(t={regl:t},this.gl=t.regl._gl),this.shader=b.get(this.gl),this.shader?this.regl=this.shader.regl:this.regl=t.regl||a({gl:this.gl}),this.charBuffer=this.regl.buffer({type:\"uint8\",usage:\"stream\"}),this.sizeBuffer=this.regl.buffer({type:\"float\",usage:\"stream\"}),this.shader||(this.shader=this.createShader(),b.set(this.gl,this.shader)),this.batch=[],this.fontSize=[],this.font=[],this.fontAtlas=[],this.draw=this.shader.draw.bind(this),this.render=function(){this.regl._refresh(),this.draw(this.batch)},this.canvas=this.gl.canvas,this.update(h(t)?t:{})};T.prototype.createShader=function(){var t=this.regl,e=t({blend:{enable:!0,color:[0,0,0,1],func:{srcRGB:\"src alpha\",dstRGB:\"one minus src alpha\",srcAlpha:\"one minus dst alpha\",dstAlpha:\"one\"}},stencil:{enable:!1},depth:{enable:!1},count:t.prop(\"count\"),offset:t.prop(\"offset\"),attributes:{charOffset:{offset:4,stride:8,buffer:t.this(\"sizeBuffer\")},width:{offset:0,stride:8,buffer:t.this(\"sizeBuffer\")},char:t.this(\"charBuffer\"),position:t.this(\"position\")},uniforms:{atlasSize:function(t,e){return[e.atlas.width,e.atlas.height]},atlasDim:function(t,e){return[e.atlas.cols,e.atlas.rows]},atlas:function(t,e){return e.atlas.texture},charStep:function(t,e){return e.atlas.step},em:function(t,e){return e.atlas.em},color:t.prop(\"color\"),opacity:t.prop(\"opacity\"),viewport:t.this(\"viewportArray\"),scale:t.this(\"scale\"),align:t.prop(\"align\"),baseline:t.prop(\"baseline\"),translate:t.this(\"translate\"),positionOffset:t.prop(\"positionOffset\")},primitive:\"points\",viewport:t.this(\"viewport\"),vert:\"\\n\\t\\t\\tprecision highp float;\\n\\t\\t\\tattribute float width, charOffset, char;\\n\\t\\t\\tattribute vec2 position;\\n\\t\\t\\tuniform float fontSize, charStep, em, align, baseline;\\n\\t\\t\\tuniform vec4 viewport;\\n\\t\\t\\tuniform vec4 color;\\n\\t\\t\\tuniform vec2 atlasSize, atlasDim, scale, translate, positionOffset;\\n\\t\\t\\tvarying vec2 charCoord, charId;\\n\\t\\t\\tvarying float charWidth;\\n\\t\\t\\tvarying vec4 fontColor;\\n\\t\\t\\tvoid main () {\\n\\t\\t\\t\\t\"+(T.normalViewport?\"\":\"vec2 positionOffset = vec2(positionOffset.x,- positionOffset.y);\")+\"\\n\\n\\t\\t\\t\\tvec2 offset = floor(em * (vec2(align + charOffset, baseline)\\n\\t\\t\\t\\t\\t+ positionOffset))\\n\\t\\t\\t\\t\\t/ (viewport.zw * scale.xy);\\n\\n\\t\\t\\t\\tvec2 position = (position + translate) * scale;\\n\\t\\t\\t\\tposition += offset * scale;\\n\\n\\t\\t\\t\\t\"+(T.normalViewport?\"position.y = 1. - position.y;\":\"\")+\"\\n\\n\\t\\t\\t\\tcharCoord = position * viewport.zw + viewport.xy;\\n\\n\\t\\t\\t\\tgl_Position = vec4(position * 2. - 1., 0, 1);\\n\\n\\t\\t\\t\\tgl_PointSize = charStep;\\n\\n\\t\\t\\t\\tcharId.x = mod(char, atlasDim.x);\\n\\t\\t\\t\\tcharId.y = floor(char / atlasDim.x);\\n\\n\\t\\t\\t\\tcharWidth = width * em;\\n\\n\\t\\t\\t\\tfontColor = color / 255.;\\n\\t\\t\\t}\",frag:\"\\n\\t\\t\\tprecision highp float;\\n\\t\\t\\tuniform sampler2D atlas;\\n\\t\\t\\tuniform float fontSize, charStep, opacity;\\n\\t\\t\\tuniform vec2 atlasSize;\\n\\t\\t\\tuniform vec4 viewport;\\n\\t\\t\\tvarying vec4 fontColor;\\n\\t\\t\\tvarying vec2 charCoord, charId;\\n\\t\\t\\tvarying float charWidth;\\n\\n\\t\\t\\tfloat lightness(vec4 color) {\\n\\t\\t\\t\\treturn color.r * 0.299 + color.g * 0.587 + color.b * 0.114;\\n\\t\\t\\t}\\n\\n\\t\\t\\tvoid main () {\\n\\t\\t\\t\\tvec2 uv = gl_FragCoord.xy - charCoord + charStep * .5;\\n\\t\\t\\t\\tfloat halfCharStep = floor(charStep * .5 + .5);\\n\\n\\t\\t\\t\\t// invert y and shift by 1px (FF expecially needs that)\\n\\t\\t\\t\\tuv.y = charStep - uv.y;\\n\\n\\t\\t\\t\\t// ignore points outside of character bounding box\\n\\t\\t\\t\\tfloat halfCharWidth = ceil(charWidth * .5);\\n\\t\\t\\t\\tif (floor(uv.x) > halfCharStep + halfCharWidth ||\\n\\t\\t\\t\\t\\tfloor(uv.x) < halfCharStep - halfCharWidth) return;\\n\\n\\t\\t\\t\\tuv += charId * charStep;\\n\\t\\t\\t\\tuv = uv / atlasSize;\\n\\n\\t\\t\\t\\tvec4 color = fontColor;\\n\\t\\t\\t\\tvec4 mask = texture2D(atlas, uv);\\n\\n\\t\\t\\t\\tfloat maskY = lightness(mask);\\n\\t\\t\\t\\t// float colorY = lightness(color);\\n\\t\\t\\t\\tcolor.a *= maskY;\\n\\t\\t\\t\\tcolor.a *= opacity;\\n\\n\\t\\t\\t\\t// color.a += .1;\\n\\n\\t\\t\\t\\t// antialiasing, see yiq color space y-channel formula\\n\\t\\t\\t\\t// color.rgb += (1. - color.rgb) * (1. - mask.rgb);\\n\\n\\t\\t\\t\\tgl_FragColor = color;\\n\\t\\t\\t}\"});return{regl:t,draw:e,atlas:{}}},T.prototype.update=function(t){var e=this;if(\"string\"==typeof t)t={text:t};else if(!t)return;null!=(t=i(t,{position:\"position positions coord coords coordinates\",font:\"font fontFace fontface typeface cssFont css-font family fontFamily\",fontSize:\"fontSize fontsize size font-size\",text:\"text texts chars characters value values symbols\",align:\"align alignment textAlign textbaseline\",baseline:\"baseline textBaseline textbaseline\",direction:\"dir direction textDirection\",color:\"color colour fill fill-color fillColor textColor textcolor\",kerning:\"kerning kern\",range:\"range dataBox\",viewport:\"vp viewport viewBox viewbox viewPort\",opacity:\"opacity alpha transparency visible visibility opaque\",offset:\"offset positionOffset padding shift indent indentation\"},!0)).opacity&&(Array.isArray(t.opacity)?this.opacity=t.opacity.map((function(t){return parseFloat(t)})):this.opacity=parseFloat(t.opacity)),null!=t.viewport&&(this.viewport=f(t.viewport),T.normalViewport&&(this.viewport.y=this.canvas.height-this.viewport.y-this.viewport.height),this.viewportArray=[this.viewport.x,this.viewport.y,this.viewport.width,this.viewport.height]),null==this.viewport&&(this.viewport={x:0,y:0,width:this.gl.drawingBufferWidth,height:this.gl.drawingBufferHeight},this.viewportArray=[this.viewport.x,this.viewport.y,this.viewport.width,this.viewport.height]),null!=t.kerning&&(this.kerning=t.kerning),null!=t.offset&&(\"number\"==typeof t.offset&&(t.offset=[t.offset,0]),this.positionOffset=y(t.offset)),t.direction&&(this.direction=t.direction),t.range&&(this.range=t.range,this.scale=[1/(t.range[2]-t.range[0]),1/(t.range[3]-t.range[1])],this.translate=[-t.range[0],-t.range[1]]),t.scale&&(this.scale=t.scale),t.translate&&(this.translate=t.translate),this.scale||(this.scale=[1/this.viewport.width,1/this.viewport.height]),this.translate||(this.translate=[0,0]),this.font.length||t.font||(t.font=T.baseFontSize+\"px sans-serif\");var r,a=!1,o=!1;if(t.font&&(Array.isArray(t.font)?t.font:[t.font]).forEach((function(t,r){if(\"string\"==typeof t)try{t=n.parse(t)}catch(e){t=n.parse(T.baseFontSize+\"px \"+t)}else t=n.parse(n.stringify(t));var i=n.stringify({size:T.baseFontSize,family:t.family,stretch:_?t.stretch:void 0,variant:t.variant,weight:t.weight,style:t.style}),s=p(t.size),l=Math.round(s[0]*d(s[1]));if(l!==e.fontSize[r]&&(o=!0,e.fontSize[r]=l),!(e.font[r]&&i==e.font[r].baseString||(a=!0,e.font[r]=T.fonts[i],e.font[r]))){var c=t.family.join(\", \"),u=[t.style];t.style!=t.variant&&u.push(t.variant),t.variant!=t.weight&&u.push(t.weight),_&&t.weight!=t.stretch&&u.push(t.stretch),e.font[r]={baseString:i,family:c,weight:t.weight,stretch:t.stretch,style:t.style,variant:t.variant,width:{},kerning:{},metrics:v(c,{origin:\"top\",fontSize:T.baseFontSize,fontStyle:u.join(\" \")})},T.fonts[i]=e.font[r]}})),(a||o)&&this.font.forEach((function(r,i){var a=n.stringify({size:e.fontSize[i],family:r.family,stretch:_?r.stretch:void 0,variant:r.variant,weight:r.weight,style:r.style});if(e.fontAtlas[i]=e.shader.atlas[a],!e.fontAtlas[i]){var o=r.metrics;e.shader.atlas[a]=e.fontAtlas[i]={fontString:a,step:2*Math.ceil(e.fontSize[i]*o.bottom*.5),em:e.fontSize[i],cols:0,rows:0,height:0,width:0,chars:[],ids:{},texture:e.regl.texture()}}null==t.text&&(t.text=e.text)})),\"string\"==typeof t.text&&t.position&&t.position.length>2){for(var s=Array(.5*t.position.length),h=0;h<s.length;h++)s[h]=t.text;t.text=s}if(null!=t.text||a){if(this.textOffsets=[0],Array.isArray(t.text)){this.count=t.text[0].length,this.counts=[this.count];for(var b=1;b<t.text.length;b++)this.textOffsets[b]=this.textOffsets[b-1]+t.text[b-1].length,this.count+=t.text[b].length,this.counts.push(t.text[b].length);this.text=t.text.join(\"\")}else this.text=t.text,this.count=this.text.length,this.counts=[this.count];r=[],this.font.forEach((function(t,n){T.atlasContext.font=t.baseString;for(var i=e.fontAtlas[n],a=0;a<e.text.length;a++){var o=e.text.charAt(a);if(null==i.ids[o]&&(i.ids[o]=i.chars.length,i.chars.push(o),r.push(o)),null==t.width[o]&&(t.width[o]=T.atlasContext.measureText(o).width/T.baseFontSize,e.kerning)){var s=[];for(var l in t.width)s.push(l+o,o+l);g(t.kerning,m(t.family,{pairs:s}))}}}))}if(t.position)if(t.position.length>2){for(var w=!t.position[0].length,k=u.mallocFloat(2*this.count),M=0,A=0;M<this.counts.length;M++){var S=this.counts[M];if(w)for(var E=0;E<S;E++)k[A++]=t.position[2*M],k[A++]=t.position[2*M+1];else for(var L=0;L<S;L++)k[A++]=t.position[M][0],k[A++]=t.position[M][1]}this.position.call?this.position({type:\"float\",data:k}):this.position=this.regl.buffer({type:\"float\",data:k}),u.freeFloat(k)}else this.position.destroy&&this.position.destroy(),this.position={constant:t.position};if(t.text||a){var C=u.mallocUint8(this.count),P=u.mallocFloat(2*this.count);this.textWidth=[];for(var I=0,O=0;I<this.counts.length;I++){for(var z=this.counts[I],D=this.font[I]||this.font[0],R=this.fontAtlas[I]||this.fontAtlas[0],F=0;F<z;F++){var B=this.text.charAt(O),N=this.text.charAt(O-1);if(C[O]=R.ids[B],P[2*O]=D.width[B],F){var j=P[2*O-2],U=P[2*O],V=P[2*O-1]+.5*j+.5*U;if(this.kerning){var q=D.kerning[N+B];q&&(V+=.001*q)}P[2*O+1]=V}else P[2*O+1]=.5*P[2*O];O++}this.textWidth.push(P.length?.5*P[2*O-2]+P[2*O-1]:0)}t.align||(t.align=this.align),this.charBuffer({data:C,type:\"uint8\",usage:\"stream\"}),this.sizeBuffer({data:P,type:\"float\",usage:\"stream\"}),u.freeUint8(C),u.freeFloat(P),r.length&&this.font.forEach((function(t,r){var n=e.fontAtlas[r],i=n.step,a=Math.floor(T.maxAtlasSize/i),o=Math.min(a,n.chars.length),s=Math.ceil(n.chars.length/o),l=x(o*i),u=x(s*i);n.width=l,n.height=u,n.rows=s,n.cols=o,n.em&&n.texture({data:c({canvas:T.atlasCanvas,font:n.fontString,chars:n.chars,shape:[l,u],step:[i,i]})})}))}if(t.align&&(this.align=t.align,this.alignOffset=this.textWidth.map((function(t,r){var n=Array.isArray(e.align)?e.align.length>1?e.align[r]:e.align[0]:e.align;if(\"number\"==typeof n)return n;switch(n){case\"right\":case\"end\":return-t;case\"center\":case\"centre\":case\"middle\":return.5*-t}return 0}))),null==this.baseline&&null==t.baseline&&(t.baseline=0),null!=t.baseline&&(this.baseline=t.baseline,Array.isArray(this.baseline)||(this.baseline=[this.baseline]),this.baselineOffset=this.baseline.map((function(t,r){var n=(e.font[r]||e.font[0]).metrics,i=0;return i+=.5*n.bottom,i+=\"number\"==typeof t?t-n.baseline:-n[t],T.normalViewport||(i*=-1),i}))),null!=t.color)if(t.color||(t.color=\"transparent\"),\"string\"!=typeof t.color&&isNaN(t.color)){var H;if(\"number\"==typeof t.color[0]&&t.color.length>this.counts.length){var G=t.color.length;H=u.mallocUint8(G);for(var Y=(t.color.subarray||t.color.slice).bind(t.color),W=0;W<G;W+=4)H.set(l(Y(W,W+4),\"uint8\"),W)}else{var X=t.color.length;H=u.mallocUint8(4*X);for(var Z=0;Z<X;Z++)H.set(l(t.color[Z]||0,\"uint8\"),4*Z)}this.color=H}else this.color=l(t.color,\"uint8\");if(t.position||t.text||t.color||t.baseline||t.align||t.font||t.offset||t.opacity)if(this.color.length>4||this.baselineOffset.length>1||this.align&&this.align.length>1||this.fontAtlas.length>1||this.positionOffset.length>2){var J=Math.max(.5*this.position.length||0,.25*this.color.length||0,this.baselineOffset.length||0,this.alignOffset.length||0,this.font.length||0,this.opacity.length||0,.5*this.positionOffset.length||0);this.batch=Array(J);for(var K=0;K<this.batch.length;K++)this.batch[K]={count:this.counts.length>1?this.counts[K]:this.counts[0],offset:this.textOffsets.length>1?this.textOffsets[K]:this.textOffsets[0],color:this.color?this.color.length<=4?this.color:this.color.subarray(4*K,4*K+4):[0,0,0,255],opacity:Array.isArray(this.opacity)?this.opacity[K]:this.opacity,baseline:null!=this.baselineOffset[K]?this.baselineOffset[K]:this.baselineOffset[0],align:this.align?null!=this.alignOffset[K]?this.alignOffset[K]:this.alignOffset[0]:0,atlas:this.fontAtlas[K]||this.fontAtlas[0],positionOffset:this.positionOffset.length>2?this.positionOffset.subarray(2*K,2*K+2):this.positionOffset}}else this.count?this.batch=[{count:this.count,offset:0,color:this.color||[0,0,0,255],opacity:Array.isArray(this.opacity)?this.opacity[0]:this.opacity,baseline:this.baselineOffset[0],align:this.alignOffset?this.alignOffset[0]:0,atlas:this.fontAtlas[0],positionOffset:this.positionOffset}]:this.batch=[]},T.prototype.destroy=function(){},T.prototype.kerning=!0,T.prototype.position={constant:new Float32Array(2)},T.prototype.translate=null,T.prototype.scale=null,T.prototype.font=null,T.prototype.text=\"\",T.prototype.positionOffset=[0,0],T.prototype.opacity=1,T.prototype.color=new Uint8Array([0,0,0,255]),T.prototype.alignOffset=[0,0],T.normalViewport=!1,T.maxAtlasSize=1024,T.atlasCanvas=document.createElement(\"canvas\"),T.atlasContext=T.atlasCanvas.getContext(\"2d\",{alpha:!1}),T.baseFontSize=64,T.fonts={},e.exports=T},{\"bit-twiddle\":104,\"color-normalize\":131,\"css-font\":150,\"detect-kerning\":177,\"es6-weak-map\":237,\"flatten-vertex-data\":248,\"font-atlas\":249,\"font-measure\":250,\"gl-util/context\":353,\"is-plain-obj\":453,\"object-assign\":483,\"parse-rect\":488,\"parse-unit\":490,\"pick-by-alias\":494,regl:536,\"to-px\":596,\"typedarray-pool\":613}],352:[function(t,e,r){\"use strict\";var n=t(\"ndarray\"),i=t(\"ndarray-ops\"),a=t(\"typedarray-pool\");e.exports=function(t){if(arguments.length<=1)throw new Error(\"gl-texture2d: Missing arguments for texture2d constructor\");o||c(t);if(\"number\"==typeof arguments[1])return v(t,arguments[1],arguments[2],arguments[3]||t.RGBA,arguments[4]||t.UNSIGNED_BYTE);if(Array.isArray(arguments[1]))return v(t,0|arguments[1][0],0|arguments[1][1],arguments[2]||t.RGBA,arguments[3]||t.UNSIGNED_BYTE);if(\"object\"==typeof arguments[1]){var e=arguments[1],r=u(e)?e:e.raw;if(r)return y(t,r,0|e.width,0|e.height,arguments[2]||t.RGBA,arguments[3]||t.UNSIGNED_BYTE);if(e.shape&&e.data&&e.stride)return x(t,e)}throw new Error(\"gl-texture2d: Invalid arguments for texture2d constructor\")};var o=null,s=null,l=null;function c(t){o=[t.LINEAR,t.NEAREST_MIPMAP_LINEAR,t.LINEAR_MIPMAP_NEAREST,t.LINEAR_MIPMAP_NEAREST],s=[t.NEAREST,t.LINEAR,t.NEAREST_MIPMAP_NEAREST,t.NEAREST_MIPMAP_LINEAR,t.LINEAR_MIPMAP_NEAREST,t.LINEAR_MIPMAP_LINEAR],l=[t.REPEAT,t.CLAMP_TO_EDGE,t.MIRRORED_REPEAT]}function u(t){return\"undefined\"!=typeof HTMLCanvasElement&&t instanceof HTMLCanvasElement||\"undefined\"!=typeof HTMLImageElement&&t instanceof HTMLImageElement||\"undefined\"!=typeof HTMLVideoElement&&t instanceof HTMLVideoElement||\"undefined\"!=typeof ImageData&&t instanceof ImageData}var f=function(t,e){i.muls(t,e,255)};function h(t,e,r){var n=t.gl,i=n.getParameter(n.MAX_TEXTURE_SIZE);if(e<0||e>i||r<0||r>i)throw new Error(\"gl-texture2d: Invalid texture size\");return t._shape=[e,r],t.bind(),n.texImage2D(n.TEXTURE_2D,0,t.format,e,r,0,t.format,t.type,null),t._mipLevels=[0],t}function p(t,e,r,n,i,a){this.gl=t,this.handle=e,this.format=i,this.type=a,this._shape=[r,n],this._mipLevels=[0],this._magFilter=t.NEAREST,this._minFilter=t.NEAREST,this._wrapS=t.CLAMP_TO_EDGE,this._wrapT=t.CLAMP_TO_EDGE,this._anisoSamples=1;var o=this,s=[this._wrapS,this._wrapT];Object.defineProperties(s,[{get:function(){return o._wrapS},set:function(t){return o.wrapS=t}},{get:function(){return o._wrapT},set:function(t){return o.wrapT=t}}]),this._wrapVector=s;var l=[this._shape[0],this._shape[1]];Object.defineProperties(l,[{get:function(){return o._shape[0]},set:function(t){return o.width=t}},{get:function(){return o._shape[1]},set:function(t){return o.height=t}}]),this._shapeVector=l}var d=p.prototype;function m(t,e){return 3===t.length?1===e[2]&&e[1]===t[0]*t[2]&&e[0]===t[2]:1===e[0]&&e[1]===t[0]}function g(t){var e=t.createTexture();return t.bindTexture(t.TEXTURE_2D,e),t.texParameteri(t.TEXTURE_2D,t.TEXTURE_MIN_FILTER,t.NEAREST),t.texParameteri(t.TEXTURE_2D,t.TEXTURE_MAG_FILTER,t.NEAREST),t.texParameteri(t.TEXTURE_2D,t.TEXTURE_WRAP_S,t.CLAMP_TO_EDGE),t.texParameteri(t.TEXTURE_2D,t.TEXTURE_WRAP_T,t.CLAMP_TO_EDGE),e}function v(t,e,r,n,i){var a=t.getParameter(t.MAX_TEXTURE_SIZE);if(e<0||e>a||r<0||r>a)throw new Error(\"gl-texture2d: Invalid texture shape\");if(i===t.FLOAT&&!t.getExtension(\"OES_texture_float\"))throw new Error(\"gl-texture2d: Floating point textures not supported on this platform\");var o=g(t);return t.texImage2D(t.TEXTURE_2D,0,n,e,r,0,n,i,null),new p(t,o,e,r,n,i)}function y(t,e,r,n,i,a){var o=g(t);return t.texImage2D(t.TEXTURE_2D,0,i,i,a,e),new p(t,o,r,n,i,a)}function x(t,e){var r=e.dtype,o=e.shape.slice(),s=t.getParameter(t.MAX_TEXTURE_SIZE);if(o[0]<0||o[0]>s||o[1]<0||o[1]>s)throw new Error(\"gl-texture2d: Invalid texture size\");var l=m(o,e.stride.slice()),c=0;\"float32\"===r?c=t.FLOAT:\"float64\"===r?(c=t.FLOAT,l=!1,r=\"float32\"):\"uint8\"===r?c=t.UNSIGNED_BYTE:(c=t.UNSIGNED_BYTE,l=!1,r=\"uint8\");var u,h,d=0;if(2===o.length)d=t.LUMINANCE,o=[o[0],o[1],1],e=n(e.data,o,[e.stride[0],e.stride[1],1],e.offset);else{if(3!==o.length)throw new Error(\"gl-texture2d: Invalid shape for texture\");if(1===o[2])d=t.ALPHA;else if(2===o[2])d=t.LUMINANCE_ALPHA;else if(3===o[2])d=t.RGB;else{if(4!==o[2])throw new Error(\"gl-texture2d: Invalid shape for pixel coords\");d=t.RGBA}}c!==t.FLOAT||t.getExtension(\"OES_texture_float\")||(c=t.UNSIGNED_BYTE,l=!1);var v=e.size;if(l)u=0===e.offset&&e.data.length===v?e.data:e.data.subarray(e.offset,e.offset+v);else{var y=[o[2],o[2]*o[0],1];h=a.malloc(v,r);var x=n(h,o,y,0);\"float32\"!==r&&\"float64\"!==r||c!==t.UNSIGNED_BYTE?i.assign(x,e):f(x,e),u=h.subarray(0,v)}var b=g(t);return t.texImage2D(t.TEXTURE_2D,0,d,o[0],o[1],0,d,c,u),l||a.free(h),new p(t,b,o[0],o[1],d,c)}Object.defineProperties(d,{minFilter:{get:function(){return this._minFilter},set:function(t){this.bind();var e=this.gl;if(this.type===e.FLOAT&&o.indexOf(t)>=0&&(e.getExtension(\"OES_texture_float_linear\")||(t=e.NEAREST)),s.indexOf(t)<0)throw new Error(\"gl-texture2d: Unknown filter mode \"+t);return e.texParameteri(e.TEXTURE_2D,e.TEXTURE_MIN_FILTER,t),this._minFilter=t}},magFilter:{get:function(){return this._magFilter},set:function(t){this.bind();var e=this.gl;if(this.type===e.FLOAT&&o.indexOf(t)>=0&&(e.getExtension(\"OES_texture_float_linear\")||(t=e.NEAREST)),s.indexOf(t)<0)throw new Error(\"gl-texture2d: Unknown filter mode \"+t);return e.texParameteri(e.TEXTURE_2D,e.TEXTURE_MAG_FILTER,t),this._magFilter=t}},mipSamples:{get:function(){return this._anisoSamples},set:function(t){var e=this._anisoSamples;if(this._anisoSamples=0|Math.max(t,1),e!==this._anisoSamples){var r=this.gl.getExtension(\"EXT_texture_filter_anisotropic\");r&&this.gl.texParameterf(this.gl.TEXTURE_2D,r.TEXTURE_MAX_ANISOTROPY_EXT,this._anisoSamples)}return this._anisoSamples}},wrapS:{get:function(){return this._wrapS},set:function(t){if(this.bind(),l.indexOf(t)<0)throw new Error(\"gl-texture2d: Unknown wrap mode \"+t);return this.gl.texParameteri(this.gl.TEXTURE_2D,this.gl.TEXTURE_WRAP_S,t),this._wrapS=t}},wrapT:{get:function(){return this._wrapT},set:function(t){if(this.bind(),l.indexOf(t)<0)throw new Error(\"gl-texture2d: Unknown wrap mode \"+t);return this.gl.texParameteri(this.gl.TEXTURE_2D,this.gl.TEXTURE_WRAP_T,t),this._wrapT=t}},wrap:{get:function(){return this._wrapVector},set:function(t){if(Array.isArray(t)||(t=[t,t]),2!==t.length)throw new Error(\"gl-texture2d: Must specify wrap mode for rows and columns\");for(var e=0;e<2;++e)if(l.indexOf(t[e])<0)throw new Error(\"gl-texture2d: Unknown wrap mode \"+t);this._wrapS=t[0],this._wrapT=t[1];var r=this.gl;return this.bind(),r.texParameteri(r.TEXTURE_2D,r.TEXTURE_WRAP_S,this._wrapS),r.texParameteri(r.TEXTURE_2D,r.TEXTURE_WRAP_T,this._wrapT),t}},shape:{get:function(){return this._shapeVector},set:function(t){if(Array.isArray(t)){if(2!==t.length)throw new Error(\"gl-texture2d: Invalid texture shape\")}else t=[0|t,0|t];return h(this,0|t[0],0|t[1]),[0|t[0],0|t[1]]}},width:{get:function(){return this._shape[0]},set:function(t){return h(this,t|=0,this._shape[1]),t}},height:{get:function(){return this._shape[1]},set:function(t){return t|=0,h(this,this._shape[0],t),t}}}),d.bind=function(t){var e=this.gl;return void 0!==t&&e.activeTexture(e.TEXTURE0+(0|t)),e.bindTexture(e.TEXTURE_2D,this.handle),void 0!==t?0|t:e.getParameter(e.ACTIVE_TEXTURE)-e.TEXTURE0},d.dispose=function(){this.gl.deleteTexture(this.handle)},d.generateMipmap=function(){this.bind(),this.gl.generateMipmap(this.gl.TEXTURE_2D);for(var t=Math.min(this._shape[0],this._shape[1]),e=0;t>0;++e,t>>>=1)this._mipLevels.indexOf(e)<0&&this._mipLevels.push(e)},d.setPixels=function(t,e,r,o){var s=this.gl;this.bind(),Array.isArray(e)?(o=r,r=0|e[1],e=0|e[0]):(e=e||0,r=r||0),o=o||0;var l=u(t)?t:t.raw;if(l){this._mipLevels.indexOf(o)<0?(s.texImage2D(s.TEXTURE_2D,0,this.format,this.format,this.type,l),this._mipLevels.push(o)):s.texSubImage2D(s.TEXTURE_2D,o,e,r,this.format,this.type,l)}else{if(!(t.shape&&t.stride&&t.data))throw new Error(\"gl-texture2d: Unsupported data type\");if(t.shape.length<2||e+t.shape[1]>this._shape[1]>>>o||r+t.shape[0]>this._shape[0]>>>o||e<0||r<0)throw new Error(\"gl-texture2d: Texture dimensions are out of bounds\");!function(t,e,r,o,s,l,c,u){var h=u.dtype,p=u.shape.slice();if(p.length<2||p.length>3)throw new Error(\"gl-texture2d: Invalid ndarray, must be 2d or 3d\");var d=0,g=0,v=m(p,u.stride.slice());\"float32\"===h?d=t.FLOAT:\"float64\"===h?(d=t.FLOAT,v=!1,h=\"float32\"):\"uint8\"===h?d=t.UNSIGNED_BYTE:(d=t.UNSIGNED_BYTE,v=!1,h=\"uint8\");if(2===p.length)g=t.LUMINANCE,p=[p[0],p[1],1],u=n(u.data,p,[u.stride[0],u.stride[1],1],u.offset);else{if(3!==p.length)throw new Error(\"gl-texture2d: Invalid shape for texture\");if(1===p[2])g=t.ALPHA;else if(2===p[2])g=t.LUMINANCE_ALPHA;else if(3===p[2])g=t.RGB;else{if(4!==p[2])throw new Error(\"gl-texture2d: Invalid shape for pixel coords\");g=t.RGBA}p[2]}g!==t.LUMINANCE&&g!==t.ALPHA||s!==t.LUMINANCE&&s!==t.ALPHA||(g=s);if(g!==s)throw new Error(\"gl-texture2d: Incompatible texture format for setPixels\");var y=u.size,x=c.indexOf(o)<0;x&&c.push(o);if(d===l&&v)0===u.offset&&u.data.length===y?x?t.texImage2D(t.TEXTURE_2D,o,s,p[0],p[1],0,s,l,u.data):t.texSubImage2D(t.TEXTURE_2D,o,e,r,p[0],p[1],s,l,u.data):x?t.texImage2D(t.TEXTURE_2D,o,s,p[0],p[1],0,s,l,u.data.subarray(u.offset,u.offset+y)):t.texSubImage2D(t.TEXTURE_2D,o,e,r,p[0],p[1],s,l,u.data.subarray(u.offset,u.offset+y));else{var b;b=l===t.FLOAT?a.mallocFloat32(y):a.mallocUint8(y);var _=n(b,p,[p[2],p[2]*p[0],1]);d===t.FLOAT&&l===t.UNSIGNED_BYTE?f(_,u):i.assign(_,u),x?t.texImage2D(t.TEXTURE_2D,o,s,p[0],p[1],0,s,l,b.subarray(0,y)):t.texSubImage2D(t.TEXTURE_2D,o,e,r,p[0],p[1],s,l,b.subarray(0,y)),l===t.FLOAT?a.freeFloat32(b):a.freeUint8(b)}}(s,e,r,o,this.format,this.type,this._mipLevels,t)}}},{ndarray:479,\"ndarray-ops\":474,\"typedarray-pool\":613}],353:[function(t,e,r){(function(r){(function(){\"use strict\";var n=t(\"pick-by-alias\");function i(t){if(t.container)if(t.container==document.body)document.body.style.width||(t.canvas.width=t.width||t.pixelRatio*r.innerWidth),document.body.style.height||(t.canvas.height=t.height||t.pixelRatio*r.innerHeight);else{var e=t.container.getBoundingClientRect();t.canvas.width=t.width||e.right-e.left,t.canvas.height=t.height||e.bottom-e.top}}function a(t){return\"function\"==typeof t.getContext&&\"width\"in t&&\"height\"in t}function o(){var t=document.createElement(\"canvas\");return t.style.position=\"absolute\",t.style.top=0,t.style.left=0,t}e.exports=function(t){var e;if(t?\"string\"==typeof t&&(t={container:t}):t={},a(t)?t={container:t}:t=\"string\"==typeof(e=t).nodeName&&\"function\"==typeof e.appendChild&&\"function\"==typeof e.getBoundingClientRect?{container:t}:function(t){return\"function\"==typeof t.drawArrays||\"function\"==typeof t.drawElements}(t)?{gl:t}:n(t,{container:\"container target element el canvas holder parent parentNode wrapper use ref root node\",gl:\"gl context webgl glContext\",attrs:\"attributes attrs contextAttributes\",pixelRatio:\"pixelRatio pxRatio px ratio pxratio pixelratio\",width:\"w width\",height:\"h height\"},!0),t.pixelRatio||(t.pixelRatio=r.pixelRatio||1),t.gl)return t.gl;if(t.canvas&&(t.container=t.canvas.parentNode),t.container){if(\"string\"==typeof t.container){var s=document.querySelector(t.container);if(!s)throw Error(\"Element \"+t.container+\" is not found\");t.container=s}a(t.container)?(t.canvas=t.container,t.container=t.canvas.parentNode):t.canvas||(t.canvas=o(),t.container.appendChild(t.canvas),i(t))}else if(!t.canvas){if(\"undefined\"==typeof document)throw Error(\"Not DOM environment. Use headless-gl.\");t.container=document.body||document.documentElement,t.canvas=o(),t.container.appendChild(t.canvas),i(t)}if(!t.gl)try{t.gl=t.canvas.getContext(\"webgl\",t.attrs)}catch(e){try{t.gl=t.canvas.getContext(\"experimental-webgl\",t.attrs)}catch(e){t.gl=t.canvas.getContext(\"webgl-experimental\",t.attrs)}}return t.gl}}).call(this)}).call(this,\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{\"pick-by-alias\":494}],354:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){e?e.bind():t.bindBuffer(t.ELEMENT_ARRAY_BUFFER,null);var n=0|t.getParameter(t.MAX_VERTEX_ATTRIBS);if(r){if(r.length>n)throw new Error(\"gl-vao: Too many vertex attributes\");for(var i=0;i<r.length;++i){var a=r[i];if(a.buffer){var o=a.buffer,s=a.size||4,l=a.type||t.FLOAT,c=!!a.normalized,u=a.stride||0,f=a.offset||0;o.bind(),t.enableVertexAttribArray(i),t.vertexAttribPointer(i,s,l,c,u,f)}else{if(\"number\"==typeof a)t.vertexAttrib1f(i,a);else if(1===a.length)t.vertexAttrib1f(i,a[0]);else if(2===a.length)t.vertexAttrib2f(i,a[0],a[1]);else if(3===a.length)t.vertexAttrib3f(i,a[0],a[1],a[2]);else{if(4!==a.length)throw new Error(\"gl-vao: Invalid vertex attribute\");t.vertexAttrib4f(i,a[0],a[1],a[2],a[3])}t.disableVertexAttribArray(i)}}for(;i<n;++i)t.disableVertexAttribArray(i)}else{t.bindBuffer(t.ARRAY_BUFFER,null);for(i=0;i<n;++i)t.disableVertexAttribArray(i)}}},{}],355:[function(t,e,r){\"use strict\";var n=t(\"./do-bind.js\");function i(t){this.gl=t,this._elements=null,this._attributes=null,this._elementsType=t.UNSIGNED_SHORT}i.prototype.bind=function(){n(this.gl,this._elements,this._attributes)},i.prototype.update=function(t,e,r){this._elements=e,this._attributes=t,this._elementsType=r||this.gl.UNSIGNED_SHORT},i.prototype.dispose=function(){},i.prototype.unbind=function(){},i.prototype.draw=function(t,e,r){r=r||0;var n=this.gl;this._elements?n.drawElements(t,e,this._elementsType,r):n.drawArrays(t,r,e)},e.exports=function(t){return new i(t)}},{\"./do-bind.js\":354}],356:[function(t,e,r){\"use strict\";var n=t(\"./do-bind.js\");function i(t,e,r,n,i,a){this.location=t,this.dimension=e,this.a=r,this.b=n,this.c=i,this.d=a}function a(t,e,r){this.gl=t,this._ext=e,this.handle=r,this._attribs=[],this._useElements=!1,this._elementsType=t.UNSIGNED_SHORT}i.prototype.bind=function(t){switch(this.dimension){case 1:t.vertexAttrib1f(this.location,this.a);break;case 2:t.vertexAttrib2f(this.location,this.a,this.b);break;case 3:t.vertexAttrib3f(this.location,this.a,this.b,this.c);break;case 4:t.vertexAttrib4f(this.location,this.a,this.b,this.c,this.d)}},a.prototype.bind=function(){this._ext.bindVertexArrayOES(this.handle);for(var t=0;t<this._attribs.length;++t)this._attribs[t].bind(this.gl)},a.prototype.unbind=function(){this._ext.bindVertexArrayOES(null)},a.prototype.dispose=function(){this._ext.deleteVertexArrayOES(this.handle)},a.prototype.update=function(t,e,r){if(this.bind(),n(this.gl,e,t),this.unbind(),this._attribs.length=0,t)for(var a=0;a<t.length;++a){var o=t[a];\"number\"==typeof o?this._attribs.push(new i(a,1,o)):Array.isArray(o)&&this._attribs.push(new i(a,o.length,o[0],o[1],o[2],o[3]))}this._useElements=!!e,this._elementsType=r||this.gl.UNSIGNED_SHORT},a.prototype.draw=function(t,e,r){r=r||0;var n=this.gl;this._useElements?n.drawElements(t,e,this._elementsType,r):n.drawArrays(t,r,e)},e.exports=function(t,e){return new a(t,e,e.createVertexArrayOES())}},{\"./do-bind.js\":354}],357:[function(t,e,r){\"use strict\";var n=t(\"./lib/vao-native.js\"),i=t(\"./lib/vao-emulated.js\");function a(t){this.bindVertexArrayOES=t.bindVertexArray.bind(t),this.createVertexArrayOES=t.createVertexArray.bind(t),this.deleteVertexArrayOES=t.deleteVertexArray.bind(t)}e.exports=function(t,e,r,o){var s,l=t.createVertexArray?new a(t):t.getExtension(\"OES_vertex_array_object\");return(s=l?n(t,l):i(t)).update(e,r,o),s}},{\"./lib/vao-emulated.js\":355,\"./lib/vao-native.js\":356}],358:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]+r[0],t[1]=e[1]+r[1],t[2]=e[2]+r[2],t}},{}],359:[function(t,e,r){e.exports=function(t,e){var r=n(t[0],t[1],t[2]),o=n(e[0],e[1],e[2]);i(r,r),i(o,o);var s=a(r,o);return s>1?0:Math.acos(s)};var n=t(\"./fromValues\"),i=t(\"./normalize\"),a=t(\"./dot\")},{\"./dot\":369,\"./fromValues\":375,\"./normalize\":386}],360:[function(t,e,r){e.exports=function(t,e){return t[0]=Math.ceil(e[0]),t[1]=Math.ceil(e[1]),t[2]=Math.ceil(e[2]),t}},{}],361:[function(t,e,r){e.exports=function(t){var e=new Float32Array(3);return e[0]=t[0],e[1]=t[1],e[2]=t[2],e}},{}],362:[function(t,e,r){e.exports=function(t,e){return t[0]=e[0],t[1]=e[1],t[2]=e[2],t}},{}],363:[function(t,e,r){e.exports=function(){var t=new Float32Array(3);return t[0]=0,t[1]=0,t[2]=0,t}},{}],364:[function(t,e,r){e.exports=function(t,e,r){var n=e[0],i=e[1],a=e[2],o=r[0],s=r[1],l=r[2];return t[0]=i*l-a*s,t[1]=a*o-n*l,t[2]=n*s-i*o,t}},{}],365:[function(t,e,r){e.exports=t(\"./distance\")},{\"./distance\":366}],366:[function(t,e,r){e.exports=function(t,e){var r=e[0]-t[0],n=e[1]-t[1],i=e[2]-t[2];return Math.sqrt(r*r+n*n+i*i)}},{}],367:[function(t,e,r){e.exports=t(\"./divide\")},{\"./divide\":368}],368:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]/r[0],t[1]=e[1]/r[1],t[2]=e[2]/r[2],t}},{}],369:[function(t,e,r){e.exports=function(t,e){return t[0]*e[0]+t[1]*e[1]+t[2]*e[2]}},{}],370:[function(t,e,r){e.exports=1e-6},{}],371:[function(t,e,r){e.exports=function(t,e){var r=t[0],i=t[1],a=t[2],o=e[0],s=e[1],l=e[2];return Math.abs(r-o)<=n*Math.max(1,Math.abs(r),Math.abs(o))&&Math.abs(i-s)<=n*Math.max(1,Math.abs(i),Math.abs(s))&&Math.abs(a-l)<=n*Math.max(1,Math.abs(a),Math.abs(l))};var n=t(\"./epsilon\")},{\"./epsilon\":370}],372:[function(t,e,r){e.exports=function(t,e){return t[0]===e[0]&&t[1]===e[1]&&t[2]===e[2]}},{}],373:[function(t,e,r){e.exports=function(t,e){return t[0]=Math.floor(e[0]),t[1]=Math.floor(e[1]),t[2]=Math.floor(e[2]),t}},{}],374:[function(t,e,r){e.exports=function(t,e,r,i,a,o){var s,l;e||(e=3);r||(r=0);l=i?Math.min(i*e+r,t.length):t.length;for(s=r;s<l;s+=e)n[0]=t[s],n[1]=t[s+1],n[2]=t[s+2],a(n,n,o),t[s]=n[0],t[s+1]=n[1],t[s+2]=n[2];return t};var n=t(\"./create\")()},{\"./create\":363}],375:[function(t,e,r){e.exports=function(t,e,r){var n=new Float32Array(3);return n[0]=t,n[1]=e,n[2]=r,n}},{}],376:[function(t,e,r){e.exports={EPSILON:t(\"./epsilon\"),create:t(\"./create\"),clone:t(\"./clone\"),angle:t(\"./angle\"),fromValues:t(\"./fromValues\"),copy:t(\"./copy\"),set:t(\"./set\"),equals:t(\"./equals\"),exactEquals:t(\"./exactEquals\"),add:t(\"./add\"),subtract:t(\"./subtract\"),sub:t(\"./sub\"),multiply:t(\"./multiply\"),mul:t(\"./mul\"),divide:t(\"./divide\"),div:t(\"./div\"),min:t(\"./min\"),max:t(\"./max\"),floor:t(\"./floor\"),ceil:t(\"./ceil\"),round:t(\"./round\"),scale:t(\"./scale\"),scaleAndAdd:t(\"./scaleAndAdd\"),distance:t(\"./distance\"),dist:t(\"./dist\"),squaredDistance:t(\"./squaredDistance\"),sqrDist:t(\"./sqrDist\"),length:t(\"./length\"),len:t(\"./len\"),squaredLength:t(\"./squaredLength\"),sqrLen:t(\"./sqrLen\"),negate:t(\"./negate\"),inverse:t(\"./inverse\"),normalize:t(\"./normalize\"),dot:t(\"./dot\"),cross:t(\"./cross\"),lerp:t(\"./lerp\"),random:t(\"./random\"),transformMat4:t(\"./transformMat4\"),transformMat3:t(\"./transformMat3\"),transformQuat:t(\"./transformQuat\"),rotateX:t(\"./rotateX\"),rotateY:t(\"./rotateY\"),rotateZ:t(\"./rotateZ\"),forEach:t(\"./forEach\")}},{\"./add\":358,\"./angle\":359,\"./ceil\":360,\"./clone\":361,\"./copy\":362,\"./create\":363,\"./cross\":364,\"./dist\":365,\"./distance\":366,\"./div\":367,\"./divide\":368,\"./dot\":369,\"./epsilon\":370,\"./equals\":371,\"./exactEquals\":372,\"./floor\":373,\"./forEach\":374,\"./fromValues\":375,\"./inverse\":377,\"./len\":378,\"./length\":379,\"./lerp\":380,\"./max\":381,\"./min\":382,\"./mul\":383,\"./multiply\":384,\"./negate\":385,\"./normalize\":386,\"./random\":387,\"./rotateX\":388,\"./rotateY\":389,\"./rotateZ\":390,\"./round\":391,\"./scale\":392,\"./scaleAndAdd\":393,\"./set\":394,\"./sqrDist\":395,\"./sqrLen\":396,\"./squaredDistance\":397,\"./squaredLength\":398,\"./sub\":399,\"./subtract\":400,\"./transformMat3\":401,\"./transformMat4\":402,\"./transformQuat\":403}],377:[function(t,e,r){e.exports=function(t,e){return t[0]=1/e[0],t[1]=1/e[1],t[2]=1/e[2],t}},{}],378:[function(t,e,r){e.exports=t(\"./length\")},{\"./length\":379}],379:[function(t,e,r){e.exports=function(t){var e=t[0],r=t[1],n=t[2];return Math.sqrt(e*e+r*r+n*n)}},{}],380:[function(t,e,r){e.exports=function(t,e,r,n){var i=e[0],a=e[1],o=e[2];return t[0]=i+n*(r[0]-i),t[1]=a+n*(r[1]-a),t[2]=o+n*(r[2]-o),t}},{}],381:[function(t,e,r){e.exports=function(t,e,r){return t[0]=Math.max(e[0],r[0]),t[1]=Math.max(e[1],r[1]),t[2]=Math.max(e[2],r[2]),t}},{}],382:[function(t,e,r){e.exports=function(t,e,r){return t[0]=Math.min(e[0],r[0]),t[1]=Math.min(e[1],r[1]),t[2]=Math.min(e[2],r[2]),t}},{}],383:[function(t,e,r){e.exports=t(\"./multiply\")},{\"./multiply\":384}],384:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]*r[0],t[1]=e[1]*r[1],t[2]=e[2]*r[2],t}},{}],385:[function(t,e,r){e.exports=function(t,e){return t[0]=-e[0],t[1]=-e[1],t[2]=-e[2],t}},{}],386:[function(t,e,r){e.exports=function(t,e){var r=e[0],n=e[1],i=e[2],a=r*r+n*n+i*i;a>0&&(a=1/Math.sqrt(a),t[0]=e[0]*a,t[1]=e[1]*a,t[2]=e[2]*a);return t}},{}],387:[function(t,e,r){e.exports=function(t,e){e=e||1;var r=2*Math.random()*Math.PI,n=2*Math.random()-1,i=Math.sqrt(1-n*n)*e;return t[0]=Math.cos(r)*i,t[1]=Math.sin(r)*i,t[2]=n*e,t}},{}],388:[function(t,e,r){e.exports=function(t,e,r,n){var i=r[1],a=r[2],o=e[1]-i,s=e[2]-a,l=Math.sin(n),c=Math.cos(n);return t[0]=e[0],t[1]=i+o*c-s*l,t[2]=a+o*l+s*c,t}},{}],389:[function(t,e,r){e.exports=function(t,e,r,n){var i=r[0],a=r[2],o=e[0]-i,s=e[2]-a,l=Math.sin(n),c=Math.cos(n);return t[0]=i+s*l+o*c,t[1]=e[1],t[2]=a+s*c-o*l,t}},{}],390:[function(t,e,r){e.exports=function(t,e,r,n){var i=r[0],a=r[1],o=e[0]-i,s=e[1]-a,l=Math.sin(n),c=Math.cos(n);return t[0]=i+o*c-s*l,t[1]=a+o*l+s*c,t[2]=e[2],t}},{}],391:[function(t,e,r){e.exports=function(t,e){return t[0]=Math.round(e[0]),t[1]=Math.round(e[1]),t[2]=Math.round(e[2]),t}},{}],392:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]*r,t[1]=e[1]*r,t[2]=e[2]*r,t}},{}],393:[function(t,e,r){e.exports=function(t,e,r,n){return t[0]=e[0]+r[0]*n,t[1]=e[1]+r[1]*n,t[2]=e[2]+r[2]*n,t}},{}],394:[function(t,e,r){e.exports=function(t,e,r,n){return t[0]=e,t[1]=r,t[2]=n,t}},{}],395:[function(t,e,r){e.exports=t(\"./squaredDistance\")},{\"./squaredDistance\":397}],396:[function(t,e,r){e.exports=t(\"./squaredLength\")},{\"./squaredLength\":398}],397:[function(t,e,r){e.exports=function(t,e){var r=e[0]-t[0],n=e[1]-t[1],i=e[2]-t[2];return r*r+n*n+i*i}},{}],398:[function(t,e,r){e.exports=function(t){var e=t[0],r=t[1],n=t[2];return e*e+r*r+n*n}},{}],399:[function(t,e,r){e.exports=t(\"./subtract\")},{\"./subtract\":400}],400:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]-r[0],t[1]=e[1]-r[1],t[2]=e[2]-r[2],t}},{}],401:[function(t,e,r){e.exports=function(t,e,r){var n=e[0],i=e[1],a=e[2];return t[0]=n*r[0]+i*r[3]+a*r[6],t[1]=n*r[1]+i*r[4]+a*r[7],t[2]=n*r[2]+i*r[5]+a*r[8],t}},{}],402:[function(t,e,r){e.exports=function(t,e,r){var n=e[0],i=e[1],a=e[2],o=r[3]*n+r[7]*i+r[11]*a+r[15];return o=o||1,t[0]=(r[0]*n+r[4]*i+r[8]*a+r[12])/o,t[1]=(r[1]*n+r[5]*i+r[9]*a+r[13])/o,t[2]=(r[2]*n+r[6]*i+r[10]*a+r[14])/o,t}},{}],403:[function(t,e,r){e.exports=function(t,e,r){var n=e[0],i=e[1],a=e[2],o=r[0],s=r[1],l=r[2],c=r[3],u=c*n+s*a-l*i,f=c*i+l*n-o*a,h=c*a+o*i-s*n,p=-o*n-s*i-l*a;return t[0]=u*c+p*-o+f*-l-h*-s,t[1]=f*c+p*-s+h*-o-u*-l,t[2]=h*c+p*-l+u*-s-f*-o,t}},{}],404:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]+r[0],t[1]=e[1]+r[1],t[2]=e[2]+r[2],t[3]=e[3]+r[3],t}},{}],405:[function(t,e,r){e.exports=function(t){var e=new Float32Array(4);return e[0]=t[0],e[1]=t[1],e[2]=t[2],e[3]=t[3],e}},{}],406:[function(t,e,r){e.exports=function(t,e){return t[0]=e[0],t[1]=e[1],t[2]=e[2],t[3]=e[3],t}},{}],407:[function(t,e,r){e.exports=function(){var t=new Float32Array(4);return t[0]=0,t[1]=0,t[2]=0,t[3]=0,t}},{}],408:[function(t,e,r){e.exports=function(t,e){var r=e[0]-t[0],n=e[1]-t[1],i=e[2]-t[2],a=e[3]-t[3];return Math.sqrt(r*r+n*n+i*i+a*a)}},{}],409:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]/r[0],t[1]=e[1]/r[1],t[2]=e[2]/r[2],t[3]=e[3]/r[3],t}},{}],410:[function(t,e,r){e.exports=function(t,e){return t[0]*e[0]+t[1]*e[1]+t[2]*e[2]+t[3]*e[3]}},{}],411:[function(t,e,r){e.exports=function(t,e,r,n){var i=new Float32Array(4);return i[0]=t,i[1]=e,i[2]=r,i[3]=n,i}},{}],412:[function(t,e,r){e.exports={create:t(\"./create\"),clone:t(\"./clone\"),fromValues:t(\"./fromValues\"),copy:t(\"./copy\"),set:t(\"./set\"),add:t(\"./add\"),subtract:t(\"./subtract\"),multiply:t(\"./multiply\"),divide:t(\"./divide\"),min:t(\"./min\"),max:t(\"./max\"),scale:t(\"./scale\"),scaleAndAdd:t(\"./scaleAndAdd\"),distance:t(\"./distance\"),squaredDistance:t(\"./squaredDistance\"),length:t(\"./length\"),squaredLength:t(\"./squaredLength\"),negate:t(\"./negate\"),inverse:t(\"./inverse\"),normalize:t(\"./normalize\"),dot:t(\"./dot\"),lerp:t(\"./lerp\"),random:t(\"./random\"),transformMat4:t(\"./transformMat4\"),transformQuat:t(\"./transformQuat\")}},{\"./add\":404,\"./clone\":405,\"./copy\":406,\"./create\":407,\"./distance\":408,\"./divide\":409,\"./dot\":410,\"./fromValues\":411,\"./inverse\":413,\"./length\":414,\"./lerp\":415,\"./max\":416,\"./min\":417,\"./multiply\":418,\"./negate\":419,\"./normalize\":420,\"./random\":421,\"./scale\":422,\"./scaleAndAdd\":423,\"./set\":424,\"./squaredDistance\":425,\"./squaredLength\":426,\"./subtract\":427,\"./transformMat4\":428,\"./transformQuat\":429}],413:[function(t,e,r){e.exports=function(t,e){return t[0]=1/e[0],t[1]=1/e[1],t[2]=1/e[2],t[3]=1/e[3],t}},{}],414:[function(t,e,r){e.exports=function(t){var e=t[0],r=t[1],n=t[2],i=t[3];return Math.sqrt(e*e+r*r+n*n+i*i)}},{}],415:[function(t,e,r){e.exports=function(t,e,r,n){var i=e[0],a=e[1],o=e[2],s=e[3];return t[0]=i+n*(r[0]-i),t[1]=a+n*(r[1]-a),t[2]=o+n*(r[2]-o),t[3]=s+n*(r[3]-s),t}},{}],416:[function(t,e,r){e.exports=function(t,e,r){return t[0]=Math.max(e[0],r[0]),t[1]=Math.max(e[1],r[1]),t[2]=Math.max(e[2],r[2]),t[3]=Math.max(e[3],r[3]),t}},{}],417:[function(t,e,r){e.exports=function(t,e,r){return t[0]=Math.min(e[0],r[0]),t[1]=Math.min(e[1],r[1]),t[2]=Math.min(e[2],r[2]),t[3]=Math.min(e[3],r[3]),t}},{}],418:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]*r[0],t[1]=e[1]*r[1],t[2]=e[2]*r[2],t[3]=e[3]*r[3],t}},{}],419:[function(t,e,r){e.exports=function(t,e){return t[0]=-e[0],t[1]=-e[1],t[2]=-e[2],t[3]=-e[3],t}},{}],420:[function(t,e,r){e.exports=function(t,e){var r=e[0],n=e[1],i=e[2],a=e[3],o=r*r+n*n+i*i+a*a;o>0&&(o=1/Math.sqrt(o),t[0]=r*o,t[1]=n*o,t[2]=i*o,t[3]=a*o);return t}},{}],421:[function(t,e,r){var n=t(\"./normalize\"),i=t(\"./scale\");e.exports=function(t,e){return e=e||1,t[0]=Math.random(),t[1]=Math.random(),t[2]=Math.random(),t[3]=Math.random(),n(t,t),i(t,t,e),t}},{\"./normalize\":420,\"./scale\":422}],422:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]*r,t[1]=e[1]*r,t[2]=e[2]*r,t[3]=e[3]*r,t}},{}],423:[function(t,e,r){e.exports=function(t,e,r,n){return t[0]=e[0]+r[0]*n,t[1]=e[1]+r[1]*n,t[2]=e[2]+r[2]*n,t[3]=e[3]+r[3]*n,t}},{}],424:[function(t,e,r){e.exports=function(t,e,r,n,i){return t[0]=e,t[1]=r,t[2]=n,t[3]=i,t}},{}],425:[function(t,e,r){e.exports=function(t,e){var r=e[0]-t[0],n=e[1]-t[1],i=e[2]-t[2],a=e[3]-t[3];return r*r+n*n+i*i+a*a}},{}],426:[function(t,e,r){e.exports=function(t){var e=t[0],r=t[1],n=t[2],i=t[3];return e*e+r*r+n*n+i*i}},{}],427:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]-r[0],t[1]=e[1]-r[1],t[2]=e[2]-r[2],t[3]=e[3]-r[3],t}},{}],428:[function(t,e,r){e.exports=function(t,e,r){var n=e[0],i=e[1],a=e[2],o=e[3];return t[0]=r[0]*n+r[4]*i+r[8]*a+r[12]*o,t[1]=r[1]*n+r[5]*i+r[9]*a+r[13]*o,t[2]=r[2]*n+r[6]*i+r[10]*a+r[14]*o,t[3]=r[3]*n+r[7]*i+r[11]*a+r[15]*o,t}},{}],429:[function(t,e,r){e.exports=function(t,e,r){var n=e[0],i=e[1],a=e[2],o=r[0],s=r[1],l=r[2],c=r[3],u=c*n+s*a-l*i,f=c*i+l*n-o*a,h=c*a+o*i-s*n,p=-o*n-s*i-l*a;return t[0]=u*c+p*-o+f*-l-h*-s,t[1]=f*c+p*-s+h*-o-u*-l,t[2]=h*c+p*-l+u*-s-f*-o,t[3]=e[3],t}},{}],430:[function(t,e,r){var n=t(\"glsl-tokenizer\"),i=t(\"atob-lite\");e.exports=function(t){for(var e=Array.isArray(t)?t:n(t),r=0;r<e.length;r++){var a=e[r];if(\"preprocessor\"===a.type){var o=a.data.match(/\\#define\\s+SHADER_NAME(_B64)?\\s+(.+)$/);if(o&&o[2]){var s=o[1],l=o[2];return(s?i(l):l).trim()}}}}},{\"atob-lite\":84,\"glsl-tokenizer\":437}],431:[function(t,e,r){e.exports=function(t){var e,r,c,u=0,f=0,h=999,p=[],d=[],m=1,g=0,v=0,y=!1,x=!1,b=\"\",_=a,w=n;\"300 es\"===(t=t||{}).version&&(_=s,w=o);var T={},k={};for(u=0;u<_.length;u++)T[_[u]]=!0;for(u=0;u<w.length;u++)k[w[u]]=!0;return function(t){return d=[],null!==t?function(t){u=0,t.toString&&(t=t.toString());var r;b+=t.replace(/\\r\\n/g,\"\\n\"),c=b.length;for(;e=b[u],u<c;){switch(r=u,h){case 0:u=L();break;case 1:case 2:u=E();break;case 3:u=C();break;case 4:u=O();break;case 11:u=I();break;case 5:u=z();break;case 9999:u=D();break;case 9:u=S();break;case 999:u=A()}if(r!==u)switch(b[r]){case\"\\n\":g=0,++m;break;default:++g}}return f+=u,b=b.slice(u),d}(t):function(t){p.length&&M(p.join(\"\"));return h=10,M(\"(eof)\"),d}()};function M(t){t.length&&d.push({type:l[h],data:t,position:v,line:m,column:g})}function A(){return p=p.length?[]:p,\"/\"===r&&\"*\"===e?(v=f+u-1,h=0,r=e,u+1):\"/\"===r&&\"/\"===e?(v=f+u-1,h=1,r=e,u+1):\"#\"===e?(h=2,v=f+u,u):/\\s/.test(e)?(h=9,v=f+u,u):(y=/\\d/.test(e),x=/[^\\w_]/.test(e),v=f+u,h=y?4:x?3:9999,u)}function S(){return/[^\\s]/g.test(e)?(M(p.join(\"\")),h=999,u):(p.push(e),r=e,u+1)}function E(){return\"\\r\"!==e&&\"\\n\"!==e||\"\\\\\"===r?(p.push(e),r=e,u+1):(M(p.join(\"\")),h=999,u)}function L(){return\"/\"===e&&\"*\"===r?(p.push(e),M(p.join(\"\")),h=999,u+1):(p.push(e),r=e,u+1)}function C(){if(\".\"===r&&/\\d/.test(e))return h=5,u;if(\"/\"===r&&\"*\"===e)return h=0,u;if(\"/\"===r&&\"/\"===e)return h=1,u;if(\".\"===e&&p.length){for(;P(p););return h=5,u}if(\";\"===e||\")\"===e||\"(\"===e){if(p.length)for(;P(p););return M(e),h=999,u+1}var t=2===p.length&&\"=\"!==e;if(/[\\w_\\d\\s]/.test(e)||t){for(;P(p););return h=999,u}return p.push(e),r=e,u+1}function P(t){for(var e,r,n=0;;){if(e=i.indexOf(t.slice(0,t.length+n).join(\"\")),r=i[e],-1===e){if(n--+t.length>0)continue;r=t.slice(0,1).join(\"\")}return M(r),v+=r.length,(p=p.slice(r.length)).length}}function I(){return/[^a-fA-F0-9]/.test(e)?(M(p.join(\"\")),h=999,u):(p.push(e),r=e,u+1)}function O(){return\".\"===e||/[eE]/.test(e)?(p.push(e),h=5,r=e,u+1):\"x\"===e&&1===p.length&&\"0\"===p[0]?(h=11,p.push(e),r=e,u+1):/[^\\d]/.test(e)?(M(p.join(\"\")),h=999,u):(p.push(e),r=e,u+1)}function z(){return\"f\"===e&&(p.push(e),r=e,u+=1),/[eE]/.test(e)?(p.push(e),r=e,u+1):(\"-\"!==e&&\"+\"!==e||!/[eE]/.test(r))&&/[^\\d]/.test(e)?(M(p.join(\"\")),h=999,u):(p.push(e),r=e,u+1)}function D(){if(/[^\\d\\w_]/.test(e)){var t=p.join(\"\");return h=k[t]?8:T[t]?7:6,M(p.join(\"\")),h=999,u}return p.push(e),r=e,u+1}};var n=t(\"./lib/literals\"),i=t(\"./lib/operators\"),a=t(\"./lib/builtins\"),o=t(\"./lib/literals-300es\"),s=t(\"./lib/builtins-300es\"),l=[\"block-comment\",\"line-comment\",\"preprocessor\",\"operator\",\"integer\",\"float\",\"ident\",\"builtin\",\"keyword\",\"whitespace\",\"eof\",\"integer\"]},{\"./lib/builtins\":433,\"./lib/builtins-300es\":432,\"./lib/literals\":435,\"./lib/literals-300es\":434,\"./lib/operators\":436}],432:[function(t,e,r){var n=t(\"./builtins\");n=n.slice().filter((function(t){return!/^(gl\\_|texture)/.test(t)})),e.exports=n.concat([\"gl_VertexID\",\"gl_InstanceID\",\"gl_Position\",\"gl_PointSize\",\"gl_FragCoord\",\"gl_FrontFacing\",\"gl_FragDepth\",\"gl_PointCoord\",\"gl_MaxVertexAttribs\",\"gl_MaxVertexUniformVectors\",\"gl_MaxVertexOutputVectors\",\"gl_MaxFragmentInputVectors\",\"gl_MaxVertexTextureImageUnits\",\"gl_MaxCombinedTextureImageUnits\",\"gl_MaxTextureImageUnits\",\"gl_MaxFragmentUniformVectors\",\"gl_MaxDrawBuffers\",\"gl_MinProgramTexelOffset\",\"gl_MaxProgramTexelOffset\",\"gl_DepthRangeParameters\",\"gl_DepthRange\",\"trunc\",\"round\",\"roundEven\",\"isnan\",\"isinf\",\"floatBitsToInt\",\"floatBitsToUint\",\"intBitsToFloat\",\"uintBitsToFloat\",\"packSnorm2x16\",\"unpackSnorm2x16\",\"packUnorm2x16\",\"unpackUnorm2x16\",\"packHalf2x16\",\"unpackHalf2x16\",\"outerProduct\",\"transpose\",\"determinant\",\"inverse\",\"texture\",\"textureSize\",\"textureProj\",\"textureLod\",\"textureOffset\",\"texelFetch\",\"texelFetchOffset\",\"textureProjOffset\",\"textureLodOffset\",\"textureProjLod\",\"textureProjLodOffset\",\"textureGrad\",\"textureGradOffset\",\"textureProjGrad\",\"textureProjGradOffset\"])},{\"./builtins\":433}],433:[function(t,e,r){e.exports=[\"abs\",\"acos\",\"all\",\"any\",\"asin\",\"atan\",\"ceil\",\"clamp\",\"cos\",\"cross\",\"dFdx\",\"dFdy\",\"degrees\",\"distance\",\"dot\",\"equal\",\"exp\",\"exp2\",\"faceforward\",\"floor\",\"fract\",\"gl_BackColor\",\"gl_BackLightModelProduct\",\"gl_BackLightProduct\",\"gl_BackMaterial\",\"gl_BackSecondaryColor\",\"gl_ClipPlane\",\"gl_ClipVertex\",\"gl_Color\",\"gl_DepthRange\",\"gl_DepthRangeParameters\",\"gl_EyePlaneQ\",\"gl_EyePlaneR\",\"gl_EyePlaneS\",\"gl_EyePlaneT\",\"gl_Fog\",\"gl_FogCoord\",\"gl_FogFragCoord\",\"gl_FogParameters\",\"gl_FragColor\",\"gl_FragCoord\",\"gl_FragData\",\"gl_FragDepth\",\"gl_FragDepthEXT\",\"gl_FrontColor\",\"gl_FrontFacing\",\"gl_FrontLightModelProduct\",\"gl_FrontLightProduct\",\"gl_FrontMaterial\",\"gl_FrontSecondaryColor\",\"gl_LightModel\",\"gl_LightModelParameters\",\"gl_LightModelProducts\",\"gl_LightProducts\",\"gl_LightSource\",\"gl_LightSourceParameters\",\"gl_MaterialParameters\",\"gl_MaxClipPlanes\",\"gl_MaxCombinedTextureImageUnits\",\"gl_MaxDrawBuffers\",\"gl_MaxFragmentUniformComponents\",\"gl_MaxLights\",\"gl_MaxTextureCoords\",\"gl_MaxTextureImageUnits\",\"gl_MaxTextureUnits\",\"gl_MaxVaryingFloats\",\"gl_MaxVertexAttribs\",\"gl_MaxVertexTextureImageUnits\",\"gl_MaxVertexUniformComponents\",\"gl_ModelViewMatrix\",\"gl_ModelViewMatrixInverse\",\"gl_ModelViewMatrixInverseTranspose\",\"gl_ModelViewMatrixTranspose\",\"gl_ModelViewProjectionMatrix\",\"gl_ModelViewProjectionMatrixInverse\",\"gl_ModelViewProjectionMatrixInverseTranspose\",\"gl_ModelViewProjectionMatrixTranspose\",\"gl_MultiTexCoord0\",\"gl_MultiTexCoord1\",\"gl_MultiTexCoord2\",\"gl_MultiTexCoord3\",\"gl_MultiTexCoord4\",\"gl_MultiTexCoord5\",\"gl_MultiTexCoord6\",\"gl_MultiTexCoord7\",\"gl_Normal\",\"gl_NormalMatrix\",\"gl_NormalScale\",\"gl_ObjectPlaneQ\",\"gl_ObjectPlaneR\",\"gl_ObjectPlaneS\",\"gl_ObjectPlaneT\",\"gl_Point\",\"gl_PointCoord\",\"gl_PointParameters\",\"gl_PointSize\",\"gl_Position\",\"gl_ProjectionMatrix\",\"gl_ProjectionMatrixInverse\",\"gl_ProjectionMatrixInverseTranspose\",\"gl_ProjectionMatrixTranspose\",\"gl_SecondaryColor\",\"gl_TexCoord\",\"gl_TextureEnvColor\",\"gl_TextureMatrix\",\"gl_TextureMatrixInverse\",\"gl_TextureMatrixInverseTranspose\",\"gl_TextureMatrixTranspose\",\"gl_Vertex\",\"greaterThan\",\"greaterThanEqual\",\"inversesqrt\",\"length\",\"lessThan\",\"lessThanEqual\",\"log\",\"log2\",\"matrixCompMult\",\"max\",\"min\",\"mix\",\"mod\",\"normalize\",\"not\",\"notEqual\",\"pow\",\"radians\",\"reflect\",\"refract\",\"sign\",\"sin\",\"smoothstep\",\"sqrt\",\"step\",\"tan\",\"texture2D\",\"texture2DLod\",\"texture2DProj\",\"texture2DProjLod\",\"textureCube\",\"textureCubeLod\",\"texture2DLodEXT\",\"texture2DProjLodEXT\",\"textureCubeLodEXT\",\"texture2DGradEXT\",\"texture2DProjGradEXT\",\"textureCubeGradEXT\"]},{}],434:[function(t,e,r){var n=t(\"./literals\");e.exports=n.slice().concat([\"layout\",\"centroid\",\"smooth\",\"case\",\"mat2x2\",\"mat2x3\",\"mat2x4\",\"mat3x2\",\"mat3x3\",\"mat3x4\",\"mat4x2\",\"mat4x3\",\"mat4x4\",\"uvec2\",\"uvec3\",\"uvec4\",\"samplerCubeShadow\",\"sampler2DArray\",\"sampler2DArrayShadow\",\"isampler2D\",\"isampler3D\",\"isamplerCube\",\"isampler2DArray\",\"usampler2D\",\"usampler3D\",\"usamplerCube\",\"usampler2DArray\",\"coherent\",\"restrict\",\"readonly\",\"writeonly\",\"resource\",\"atomic_uint\",\"noperspective\",\"patch\",\"sample\",\"subroutine\",\"common\",\"partition\",\"active\",\"filter\",\"image1D\",\"image2D\",\"image3D\",\"imageCube\",\"iimage1D\",\"iimage2D\",\"iimage3D\",\"iimageCube\",\"uimage1D\",\"uimage2D\",\"uimage3D\",\"uimageCube\",\"image1DArray\",\"image2DArray\",\"iimage1DArray\",\"iimage2DArray\",\"uimage1DArray\",\"uimage2DArray\",\"image1DShadow\",\"image2DShadow\",\"image1DArrayShadow\",\"image2DArrayShadow\",\"imageBuffer\",\"iimageBuffer\",\"uimageBuffer\",\"sampler1DArray\",\"sampler1DArrayShadow\",\"isampler1D\",\"isampler1DArray\",\"usampler1D\",\"usampler1DArray\",\"isampler2DRect\",\"usampler2DRect\",\"samplerBuffer\",\"isamplerBuffer\",\"usamplerBuffer\",\"sampler2DMS\",\"isampler2DMS\",\"usampler2DMS\",\"sampler2DMSArray\",\"isampler2DMSArray\",\"usampler2DMSArray\"])},{\"./literals\":435}],435:[function(t,e,r){e.exports=[\"precision\",\"highp\",\"mediump\",\"lowp\",\"attribute\",\"const\",\"uniform\",\"varying\",\"break\",\"continue\",\"do\",\"for\",\"while\",\"if\",\"else\",\"in\",\"out\",\"inout\",\"float\",\"int\",\"uint\",\"void\",\"bool\",\"true\",\"false\",\"discard\",\"return\",\"mat2\",\"mat3\",\"mat4\",\"vec2\",\"vec3\",\"vec4\",\"ivec2\",\"ivec3\",\"ivec4\",\"bvec2\",\"bvec3\",\"bvec4\",\"sampler1D\",\"sampler2D\",\"sampler3D\",\"samplerCube\",\"sampler1DShadow\",\"sampler2DShadow\",\"struct\",\"asm\",\"class\",\"union\",\"enum\",\"typedef\",\"template\",\"this\",\"packed\",\"goto\",\"switch\",\"default\",\"inline\",\"noinline\",\"volatile\",\"public\",\"static\",\"extern\",\"external\",\"interface\",\"long\",\"short\",\"double\",\"half\",\"fixed\",\"unsigned\",\"input\",\"output\",\"hvec2\",\"hvec3\",\"hvec4\",\"dvec2\",\"dvec3\",\"dvec4\",\"fvec2\",\"fvec3\",\"fvec4\",\"sampler2DRect\",\"sampler3DRect\",\"sampler2DRectShadow\",\"sizeof\",\"cast\",\"namespace\",\"using\"]},{}],436:[function(t,e,r){e.exports=[\"<<=\",\">>=\",\"++\",\"--\",\"<<\",\">>\",\"<=\",\">=\",\"==\",\"!=\",\"&&\",\"||\",\"+=\",\"-=\",\"*=\",\"/=\",\"%=\",\"&=\",\"^^\",\"^=\",\"|=\",\"(\",\")\",\"[\",\"]\",\".\",\"!\",\"~\",\"*\",\"/\",\"%\",\"+\",\"-\",\"<\",\">\",\"&\",\"^\",\"|\",\"?\",\":\",\"=\",\",\",\";\",\"{\",\"}\"]},{}],437:[function(t,e,r){var n=t(\"./index\");e.exports=function(t,e){var r=n(e),i=[];return i=(i=i.concat(r(t))).concat(r(null))}},{\"./index\":431}],438:[function(t,e,r){arguments[4][261][0].apply(r,arguments)},{dup:261}],439:[function(t,e,r){(function(r){(function(){\"use strict\";var n,i=t(\"is-browser\");n=\"function\"==typeof r.matchMedia?!r.matchMedia(\"(hover: none)\").matches:i,e.exports=n}).call(this)}).call(this,\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{\"is-browser\":448}],440:[function(t,e,r){\"use strict\";var n=t(\"is-browser\");e.exports=n&&function(){var t=!1;try{var e=Object.defineProperty({},\"passive\",{get:function(){t=!0}});window.addEventListener(\"test\",null,e),window.removeEventListener(\"test\",null,e)}catch(e){t=!1}return t}()},{\"is-browser\":448}],441:[function(t,e,r){r.read=function(t,e,r,n,i){var a,o,s=8*i-n-1,l=(1<<s)-1,c=l>>1,u=-7,f=r?i-1:0,h=r?-1:1,p=t[e+f];for(f+=h,a=p&(1<<-u)-1,p>>=-u,u+=s;u>0;a=256*a+t[e+f],f+=h,u-=8);for(o=a&(1<<-u)-1,a>>=-u,u+=n;u>0;o=256*o+t[e+f],f+=h,u-=8);if(0===a)a=1-c;else{if(a===l)return o?NaN:1/0*(p?-1:1);o+=Math.pow(2,n),a-=c}return(p?-1:1)*o*Math.pow(2,a-n)},r.write=function(t,e,r,n,i,a){var o,s,l,c=8*a-i-1,u=(1<<c)-1,f=u>>1,h=23===i?Math.pow(2,-24)-Math.pow(2,-77):0,p=n?0:a-1,d=n?1:-1,m=e<0||0===e&&1/e<0?1:0;for(e=Math.abs(e),isNaN(e)||e===1/0?(s=isNaN(e)?1:0,o=u):(o=Math.floor(Math.log(e)/Math.LN2),e*(l=Math.pow(2,-o))<1&&(o--,l*=2),(e+=o+f>=1?h/l:h*Math.pow(2,1-f))*l>=2&&(o++,l/=2),o+f>=u?(s=0,o=u):o+f>=1?(s=(e*l-1)*Math.pow(2,i),o+=f):(s=e*Math.pow(2,f-1)*Math.pow(2,i),o=0));i>=8;t[r+p]=255&s,p+=d,s/=256,i-=8);for(o=o<<i|s,c+=i;c>0;t[r+p]=255&o,p+=d,o/=256,c-=8);t[r+p-d]|=128*m}},{}],442:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=t.length;if(0===r)throw new Error(\"Must have at least d+1 points\");var i=t[0].length;if(r<=i)throw new Error(\"Must input at least d+1 points\");var o=t.slice(0,i+1),s=n.apply(void 0,o);if(0===s)throw new Error(\"Input not in general position\");for(var l=new Array(i+1),u=0;u<=i;++u)l[u]=u;s<0&&(l[0]=1,l[1]=0);var f=new a(l,new Array(i+1),!1),h=f.adjacent,p=new Array(i+2);for(u=0;u<=i;++u){for(var d=l.slice(),m=0;m<=i;++m)m===u&&(d[m]=-1);var g=d[0];d[0]=d[1],d[1]=g;var v=new a(d,new Array(i+1),!0);h[u]=v,p[u]=v}p[i+1]=f;for(u=0;u<=i;++u){d=h[u].vertices;var y=h[u].adjacent;for(m=0;m<=i;++m){var x=d[m];if(x<0)y[m]=f;else for(var b=0;b<=i;++b)h[b].vertices.indexOf(x)<0&&(y[m]=h[b])}}var _=new c(i,o,p),w=!!e;for(u=i+1;u<r;++u)_.insert(t[u],w);return _.boundary()};var n=t(\"robust-orientation\"),i=t(\"simplicial-complex\").compareCells;function a(t,e,r){this.vertices=t,this.adjacent=e,this.boundary=r,this.lastVisited=-1}function o(t,e,r){this.vertices=t,this.cell=e,this.index=r}function s(t,e){return i(t.vertices,e.vertices)}a.prototype.flip=function(){var t=this.vertices[0];this.vertices[0]=this.vertices[1],this.vertices[1]=t;var e=this.adjacent[0];this.adjacent[0]=this.adjacent[1],this.adjacent[1]=e};var l=[];function c(t,e,r){this.dimension=t,this.vertices=e,this.simplices=r,this.interior=r.filter((function(t){return!t.boundary})),this.tuple=new Array(t+1);for(var i=0;i<=t;++i)this.tuple[i]=this.vertices[i];var a=l[t];a||(a=l[t]=function(t){for(var e=[\"function orient(){var tuple=this.tuple;return test(\"],r=0;r<=t;++r)r>0&&e.push(\",\"),e.push(\"tuple[\",r,\"]\");e.push(\")}return orient\");var i=new Function(\"test\",e.join(\"\")),a=n[t+1];return a||(a=n),i(a)}(t)),this.orient=a}var u=c.prototype;u.handleBoundaryDegeneracy=function(t,e){var r=this.dimension,n=this.vertices.length-1,i=this.tuple,a=this.vertices,o=[t];for(t.lastVisited=-n;o.length>0;){(t=o.pop()).vertices;for(var s=t.adjacent,l=0;l<=r;++l){var c=s[l];if(c.boundary&&!(c.lastVisited<=-n)){for(var u=c.vertices,f=0;f<=r;++f){var h=u[f];i[f]=h<0?e:a[h]}var p=this.orient();if(p>0)return c;c.lastVisited=-n,0===p&&o.push(c)}}}return null},u.walk=function(t,e){var r=this.vertices.length-1,n=this.dimension,i=this.vertices,a=this.tuple,o=e?this.interior.length*Math.random()|0:this.interior.length-1,s=this.interior[o];t:for(;!s.boundary;){for(var l=s.vertices,c=s.adjacent,u=0;u<=n;++u)a[u]=i[l[u]];s.lastVisited=r;for(u=0;u<=n;++u){var f=c[u];if(!(f.lastVisited>=r)){var h=a[u];a[u]=t;var p=this.orient();if(a[u]=h,p<0){s=f;continue t}f.boundary?f.lastVisited=-r:f.lastVisited=r}}return}return s},u.addPeaks=function(t,e){var r=this.vertices.length-1,n=this.dimension,i=this.vertices,l=this.tuple,c=this.interior,u=this.simplices,f=[e];e.lastVisited=r,e.vertices[e.vertices.indexOf(-1)]=r,e.boundary=!1,c.push(e);for(var h=[];f.length>0;){var p=(e=f.pop()).vertices,d=e.adjacent,m=p.indexOf(r);if(!(m<0))for(var g=0;g<=n;++g)if(g!==m){var v=d[g];if(v.boundary&&!(v.lastVisited>=r)){var y=v.vertices;if(v.lastVisited!==-r){for(var x=0,b=0;b<=n;++b)y[b]<0?(x=b,l[b]=t):l[b]=i[y[b]];if(this.orient()>0){y[x]=r,v.boundary=!1,c.push(v),f.push(v),v.lastVisited=r;continue}v.lastVisited=-r}var _=v.adjacent,w=p.slice(),T=d.slice(),k=new a(w,T,!0);u.push(k);var M=_.indexOf(e);if(!(M<0)){_[M]=k,T[m]=v,w[g]=-1,T[g]=e,d[g]=k,k.flip();for(b=0;b<=n;++b){var A=w[b];if(!(A<0||A===r)){for(var S=new Array(n-1),E=0,L=0;L<=n;++L){var C=w[L];C<0||L===b||(S[E++]=C)}h.push(new o(S,k,b))}}}}}}h.sort(s);for(g=0;g+1<h.length;g+=2){var P=h[g],I=h[g+1],O=P.index,z=I.index;O<0||z<0||(P.cell.adjacent[P.index]=I.cell,I.cell.adjacent[I.index]=P.cell)}},u.insert=function(t,e){var r=this.vertices;r.push(t);var n=this.walk(t,e);if(n){for(var i=this.dimension,a=this.tuple,o=0;o<=i;++o){var s=n.vertices[o];a[o]=s<0?t:r[s]}var l=this.orient(a);l<0||(0!==l||(n=this.handleBoundaryDegeneracy(n,t)))&&this.addPeaks(t,n)}},u.boundary=function(){for(var t=this.dimension,e=[],r=this.simplices,n=r.length,i=0;i<n;++i){var a=r[i];if(a.boundary){for(var o=new Array(t),s=a.vertices,l=0,c=0,u=0;u<=t;++u)s[u]>=0?o[l++]=s[u]:c=1&u;if(c===(1&t)){var f=o[0];o[0]=o[1],o[1]=f}e.push(o)}}return e}},{\"robust-orientation\":544,\"simplicial-complex\":555}],443:[function(t,e,r){\"function\"==typeof Object.create?e.exports=function(t,e){e&&(t.super_=e,t.prototype=Object.create(e.prototype,{constructor:{value:t,enumerable:!1,writable:!0,configurable:!0}}))}:e.exports=function(t,e){if(e){t.super_=e;var r=function(){};r.prototype=e.prototype,t.prototype=new r,t.prototype.constructor=t}}},{}],444:[function(t,e,r){\"use strict\";var n=t(\"binary-search-bounds\");function i(t,e,r,n,i){this.mid=t,this.left=e,this.right=r,this.leftPoints=n,this.rightPoints=i,this.count=(e?e.count:0)+(r?r.count:0)+n.length}e.exports=function(t){if(!t||0===t.length)return new v(null);return new v(g(t))};var a=i.prototype;function o(t,e){t.mid=e.mid,t.left=e.left,t.right=e.right,t.leftPoints=e.leftPoints,t.rightPoints=e.rightPoints,t.count=e.count}function s(t,e){var r=g(e);t.mid=r.mid,t.left=r.left,t.right=r.right,t.leftPoints=r.leftPoints,t.rightPoints=r.rightPoints,t.count=r.count}function l(t,e){var r=t.intervals([]);r.push(e),s(t,r)}function c(t,e){var r=t.intervals([]),n=r.indexOf(e);return n<0?0:(r.splice(n,1),s(t,r),1)}function u(t,e,r){for(var n=0;n<t.length&&t[n][0]<=e;++n){var i=r(t[n]);if(i)return i}}function f(t,e,r){for(var n=t.length-1;n>=0&&t[n][1]>=e;--n){var i=r(t[n]);if(i)return i}}function h(t,e){for(var r=0;r<t.length;++r){var n=e(t[r]);if(n)return n}}function p(t,e){return t-e}function d(t,e){var r=t[0]-e[0];return r||t[1]-e[1]}function m(t,e){var r=t[1]-e[1];return r||t[0]-e[0]}function g(t){if(0===t.length)return null;for(var e=[],r=0;r<t.length;++r)e.push(t[r][0],t[r][1]);e.sort(p);var n=e[e.length>>1],a=[],o=[],s=[];for(r=0;r<t.length;++r){var l=t[r];l[1]<n?a.push(l):n<l[0]?o.push(l):s.push(l)}var c=s,u=s.slice();return c.sort(d),u.sort(m),new i(n,g(a),g(o),c,u)}function v(t){this.root=t}a.intervals=function(t){return t.push.apply(t,this.leftPoints),this.left&&this.left.intervals(t),this.right&&this.right.intervals(t),t},a.insert=function(t){var e=this.count-this.leftPoints.length;if(this.count+=1,t[1]<this.mid)this.left?4*(this.left.count+1)>3*(e+1)?l(this,t):this.left.insert(t):this.left=g([t]);else if(t[0]>this.mid)this.right?4*(this.right.count+1)>3*(e+1)?l(this,t):this.right.insert(t):this.right=g([t]);else{var r=n.ge(this.leftPoints,t,d),i=n.ge(this.rightPoints,t,m);this.leftPoints.splice(r,0,t),this.rightPoints.splice(i,0,t)}},a.remove=function(t){var e=this.count-this.leftPoints;if(t[1]<this.mid)return this.left?4*(this.right?this.right.count:0)>3*(e-1)?c(this,t):2===(s=this.left.remove(t))?(this.left=null,this.count-=1,1):(1===s&&(this.count-=1),s):0;if(t[0]>this.mid)return this.right?4*(this.left?this.left.count:0)>3*(e-1)?c(this,t):2===(s=this.right.remove(t))?(this.right=null,this.count-=1,1):(1===s&&(this.count-=1),s):0;if(1===this.count)return this.leftPoints[0]===t?2:0;if(1===this.leftPoints.length&&this.leftPoints[0]===t){if(this.left&&this.right){for(var r=this,i=this.left;i.right;)r=i,i=i.right;if(r===this)i.right=this.right;else{var a=this.left,s=this.right;r.count-=i.count,r.right=i.left,i.left=a,i.right=s}o(this,i),this.count=(this.left?this.left.count:0)+(this.right?this.right.count:0)+this.leftPoints.length}else this.left?o(this,this.left):o(this,this.right);return 1}for(a=n.ge(this.leftPoints,t,d);a<this.leftPoints.length&&this.leftPoints[a][0]===t[0];++a)if(this.leftPoints[a]===t){this.count-=1,this.leftPoints.splice(a,1);for(s=n.ge(this.rightPoints,t,m);s<this.rightPoints.length&&this.rightPoints[s][1]===t[1];++s)if(this.rightPoints[s]===t)return this.rightPoints.splice(s,1),1}return 0},a.queryPoint=function(t,e){if(t<this.mid){if(this.left)if(r=this.left.queryPoint(t,e))return r;return u(this.leftPoints,t,e)}if(t>this.mid){var r;if(this.right)if(r=this.right.queryPoint(t,e))return r;return f(this.rightPoints,t,e)}return h(this.leftPoints,e)},a.queryInterval=function(t,e,r){var n;if(t<this.mid&&this.left&&(n=this.left.queryInterval(t,e,r)))return n;if(e>this.mid&&this.right&&(n=this.right.queryInterval(t,e,r)))return n;return e<this.mid?u(this.leftPoints,e,r):t>this.mid?f(this.rightPoints,t,r):h(this.leftPoints,r)};var y=v.prototype;y.insert=function(t){this.root?this.root.insert(t):this.root=new i(t[0],null,null,[t],[t])},y.remove=function(t){if(this.root){var e=this.root.remove(t);return 2===e&&(this.root=null),0!==e}return!1},y.queryPoint=function(t,e){if(this.root)return this.root.queryPoint(t,e)},y.queryInterval=function(t,e,r){if(t<=e&&this.root)return this.root.queryInterval(t,e,r)},Object.defineProperty(y,\"count\",{get:function(){return this.root?this.root.count:0}}),Object.defineProperty(y,\"intervals\",{get:function(){return this.root?this.root.intervals([]):[]}})},{\"binary-search-bounds\":445}],445:[function(t,e,r){arguments[4][247][0].apply(r,arguments)},{dup:247}],446:[function(t,e,r){\"use strict\";e.exports=function(t,e){e=e||new Array(t.length);for(var r=0;r<t.length;++r)e[t[r]]=r;return e}},{}],447:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=new Array(t),r=0;r<t;++r)e[r]=r;return e}},{}],448:[function(t,e,r){e.exports=!0},{}],449:[function(t,e,r){function n(t){return!!t.constructor&&\"function\"==typeof t.constructor.isBuffer&&t.constructor.isBuffer(t)}\n",
       "/*!\n",
       " * Determine if an object is a Buffer\n",
       " *\n",
       " * @author   Feross Aboukhadijeh <https://feross.org>\n",
       " * @license  MIT\n",
       " */\n",
       "e.exports=function(t){return null!=t&&(n(t)||function(t){return\"function\"==typeof t.readFloatLE&&\"function\"==typeof t.slice&&n(t.slice(0,0))}(t)||!!t._isBuffer)}},{}],450:[function(t,e,r){\"use strict\";e.exports=\"undefined\"!=typeof navigator&&(/MSIE/.test(navigator.userAgent)||/Trident\\//.test(navigator.appVersion))},{}],451:[function(t,e,r){\"use strict\";e.exports=a,e.exports.isMobile=a,e.exports.default=a;var n=/(android|bb\\d+|meego).+mobile|avantgo|bada\\/|blackberry|blazer|compal|elaine|fennec|hiptop|iemobile|ip(hone|od)|iris|kindle|lge |maemo|midp|mmp|mobile.+firefox|netfront|opera m(ob|in)i|palm( os)?|phone|p(ixi|re)\\/|plucker|pocket|psp|series[46]0|symbian|treo|up\\.(browser|link)|vodafone|wap|windows (ce|phone)|xda|xiino/i,i=/(android|bb\\d+|meego).+mobile|avantgo|bada\\/|blackberry|blazer|compal|elaine|fennec|hiptop|iemobile|ip(hone|od)|iris|kindle|lge |maemo|midp|mmp|mobile.+firefox|netfront|opera m(ob|in)i|palm( os)?|phone|p(ixi|re)\\/|plucker|pocket|psp|series[46]0|symbian|treo|up\\.(browser|link)|vodafone|wap|windows (ce|phone)|xda|xiino|android|ipad|playbook|silk/i;function a(t){t||(t={});var e=t.ua;if(e||\"undefined\"==typeof navigator||(e=navigator.userAgent),e&&e.headers&&\"string\"==typeof e.headers[\"user-agent\"]&&(e=e.headers[\"user-agent\"]),\"string\"!=typeof e)return!1;var r=t.tablet?i.test(e):n.test(e);return!r&&t.tablet&&t.featureDetect&&navigator&&navigator.maxTouchPoints>1&&-1!==e.indexOf(\"Macintosh\")&&-1!==e.indexOf(\"Safari\")&&(r=!0),r}},{}],452:[function(t,e,r){\"use strict\";e.exports=function(t){var e=typeof t;return null!==t&&(\"object\"===e||\"function\"===e)}},{}],453:[function(t,e,r){\"use strict\";var n=Object.prototype.toString;e.exports=function(t){var e;return\"[object Object]\"===n.call(t)&&(null===(e=Object.getPrototypeOf(t))||e===Object.getPrototypeOf({}))}},{}],454:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e,r=t.length,n=0;n<r;n++)if(((e=t.charCodeAt(n))<9||e>13)&&32!==e&&133!==e&&160!==e&&5760!==e&&6158!==e&&(e<8192||e>8205)&&8232!==e&&8233!==e&&8239!==e&&8287!==e&&8288!==e&&12288!==e&&65279!==e)return!1;return!0}},{}],455:[function(t,e,r){\"use strict\";e.exports=function(t){return\"string\"==typeof t&&(t=t.trim(),!!(/^[mzlhvcsqta]\\s*[-+.0-9][^mlhvzcsqta]+/i.test(t)&&/[\\dz]$/i.test(t)&&t.length>4))}},{}],456:[function(t,e,r){e.exports=function(t,e,r){return t*(1-r)+e*r}},{}],457:[function(t,e,r){!function(t,n){\"object\"==typeof r&&void 0!==e?e.exports=n():(t=t||self).mapboxgl=n()}(this,(function(){\"use strict\";var t,e,r;function n(n,i){if(t)if(e){var a=\"var sharedChunk = {}; (\"+t+\")(sharedChunk); (\"+e+\")(sharedChunk);\",o={};t(o),(r=i(o)).workerUrl=window.URL.createObjectURL(new Blob([a],{type:\"text/javascript\"}))}else e=i;else t=i}return n(0,(function(t){function e(t,e){return t(e={exports:{}},e.exports),e.exports}var r=n;function n(t,e,r,n){this.cx=3*t,this.bx=3*(r-t)-this.cx,this.ax=1-this.cx-this.bx,this.cy=3*e,this.by=3*(n-e)-this.cy,this.ay=1-this.cy-this.by,this.p1x=t,this.p1y=n,this.p2x=r,this.p2y=n}n.prototype.sampleCurveX=function(t){return((this.ax*t+this.bx)*t+this.cx)*t},n.prototype.sampleCurveY=function(t){return((this.ay*t+this.by)*t+this.cy)*t},n.prototype.sampleCurveDerivativeX=function(t){return(3*this.ax*t+2*this.bx)*t+this.cx},n.prototype.solveCurveX=function(t,e){var r,n,i,a,o;for(void 0===e&&(e=1e-6),i=t,o=0;o<8;o++){if(a=this.sampleCurveX(i)-t,Math.abs(a)<e)return i;var s=this.sampleCurveDerivativeX(i);if(Math.abs(s)<1e-6)break;i-=a/s}if((i=t)<(r=0))return r;if(i>(n=1))return n;for(;r<n;){if(a=this.sampleCurveX(i),Math.abs(a-t)<e)return i;t>a?r=i:n=i,i=.5*(n-r)+r}return i},n.prototype.solve=function(t,e){return this.sampleCurveY(this.solveCurveX(t,e))};var i=a;function a(t,e){this.x=t,this.y=e}function o(t,e,n,i){var a=new r(t,e,n,i);return function(t){return a.solve(t)}}a.prototype={clone:function(){return new a(this.x,this.y)},add:function(t){return this.clone()._add(t)},sub:function(t){return this.clone()._sub(t)},multByPoint:function(t){return this.clone()._multByPoint(t)},divByPoint:function(t){return this.clone()._divByPoint(t)},mult:function(t){return this.clone()._mult(t)},div:function(t){return this.clone()._div(t)},rotate:function(t){return this.clone()._rotate(t)},rotateAround:function(t,e){return this.clone()._rotateAround(t,e)},matMult:function(t){return this.clone()._matMult(t)},unit:function(){return this.clone()._unit()},perp:function(){return this.clone()._perp()},round:function(){return this.clone()._round()},mag:function(){return Math.sqrt(this.x*this.x+this.y*this.y)},equals:function(t){return this.x===t.x&&this.y===t.y},dist:function(t){return Math.sqrt(this.distSqr(t))},distSqr:function(t){var e=t.x-this.x,r=t.y-this.y;return e*e+r*r},angle:function(){return Math.atan2(this.y,this.x)},angleTo:function(t){return Math.atan2(this.y-t.y,this.x-t.x)},angleWith:function(t){return this.angleWithSep(t.x,t.y)},angleWithSep:function(t,e){return Math.atan2(this.x*e-this.y*t,this.x*t+this.y*e)},_matMult:function(t){var e=t[0]*this.x+t[1]*this.y,r=t[2]*this.x+t[3]*this.y;return this.x=e,this.y=r,this},_add:function(t){return this.x+=t.x,this.y+=t.y,this},_sub:function(t){return this.x-=t.x,this.y-=t.y,this},_mult:function(t){return this.x*=t,this.y*=t,this},_div:function(t){return this.x/=t,this.y/=t,this},_multByPoint:function(t){return this.x*=t.x,this.y*=t.y,this},_divByPoint:function(t){return this.x/=t.x,this.y/=t.y,this},_unit:function(){return this._div(this.mag()),this},_perp:function(){var t=this.y;return this.y=this.x,this.x=-t,this},_rotate:function(t){var e=Math.cos(t),r=Math.sin(t),n=e*this.x-r*this.y,i=r*this.x+e*this.y;return this.x=n,this.y=i,this},_rotateAround:function(t,e){var r=Math.cos(t),n=Math.sin(t),i=e.x+r*(this.x-e.x)-n*(this.y-e.y),a=e.y+n*(this.x-e.x)+r*(this.y-e.y);return this.x=i,this.y=a,this},_round:function(){return this.x=Math.round(this.x),this.y=Math.round(this.y),this}},a.convert=function(t){return t instanceof a?t:Array.isArray(t)?new a(t[0],t[1]):t};var s=o(.25,.1,.25,1);function l(t,e,r){return Math.min(r,Math.max(e,t))}function c(t,e,r){var n=r-e,i=((t-e)%n+n)%n+e;return i===e?r:i}function u(t){for(var e=[],r=arguments.length-1;r-- >0;)e[r]=arguments[r+1];for(var n=0,i=e;n<i.length;n+=1){var a=i[n];for(var o in a)t[o]=a[o]}return t}var f=1;function h(){return f++}function p(){return function t(e){return e?(e^16*Math.random()>>e/4).toString(16):([1e7]+-[1e3]+-4e3+-8e3+-1e11).replace(/[018]/g,t)}()}function d(t){return!!t&&/^[0-9a-f]{8}-[0-9a-f]{4}-[4][0-9a-f]{3}-[89ab][0-9a-f]{3}-[0-9a-f]{12}$/i.test(t)}function m(t,e){t.forEach((function(t){e[t]&&(e[t]=e[t].bind(e))}))}function g(t,e){return-1!==t.indexOf(e,t.length-e.length)}function v(t,e,r){var n={};for(var i in t)n[i]=e.call(r||this,t[i],i,t);return n}function y(t,e,r){var n={};for(var i in t)e.call(r||this,t[i],i,t)&&(n[i]=t[i]);return n}function x(t){return Array.isArray(t)?t.map(x):\"object\"==typeof t&&t?v(t,x):t}var b={};function _(t){b[t]||(\"undefined\"!=typeof console&&console.warn(t),b[t]=!0)}function w(t,e,r){return(r.y-t.y)*(e.x-t.x)>(e.y-t.y)*(r.x-t.x)}function T(t){for(var e=0,r=0,n=t.length,i=n-1,a=void 0,o=void 0;r<n;i=r++)a=t[r],e+=((o=t[i]).x-a.x)*(a.y+o.y);return e}function k(){return\"undefined\"!=typeof WorkerGlobalScope&&\"undefined\"!=typeof self&&self instanceof WorkerGlobalScope}function M(t){var e={};if(t.replace(/(?:^|(?:\\s*\\,\\s*))([^\\x00-\\x20\\(\\)<>@\\,;\\:\\\\\"\\/\\[\\]\\?\\=\\{\\}\\x7F]+)(?:\\=(?:([^\\x00-\\x20\\(\\)<>@\\,;\\:\\\\\"\\/\\[\\]\\?\\=\\{\\}\\x7F]+)|(?:\\\"((?:[^\"\\\\]|\\\\.)*)\\\")))?/g,(function(t,r,n,i){var a=n||i;return e[r]=!a||a.toLowerCase(),\"\"})),e[\"max-age\"]){var r=parseInt(e[\"max-age\"],10);isNaN(r)?delete e[\"max-age\"]:e[\"max-age\"]=r}return e}var A=null;function S(t){if(null==A){var e=t.navigator?t.navigator.userAgent:null;A=!!t.safari||!(!e||!(/\\b(iPad|iPhone|iPod)\\b/.test(e)||e.match(\"Safari\")&&!e.match(\"Chrome\")))}return A}function E(t){try{var e=self[t];return e.setItem(\"_mapbox_test_\",1),e.removeItem(\"_mapbox_test_\"),!0}catch(t){return!1}}var L,C,P,I,O=self.performance&&self.performance.now?self.performance.now.bind(self.performance):Date.now.bind(Date),z=self.requestAnimationFrame||self.mozRequestAnimationFrame||self.webkitRequestAnimationFrame||self.msRequestAnimationFrame,D=self.cancelAnimationFrame||self.mozCancelAnimationFrame||self.webkitCancelAnimationFrame||self.msCancelAnimationFrame,R={now:O,frame:function(t){var e=z(t);return{cancel:function(){return D(e)}}},getImageData:function(t,e){void 0===e&&(e=0);var r=self.document.createElement(\"canvas\"),n=r.getContext(\"2d\");if(!n)throw new Error(\"failed to create canvas 2d context\");return r.width=t.width,r.height=t.height,n.drawImage(t,0,0,t.width,t.height),n.getImageData(-e,-e,t.width+2*e,t.height+2*e)},resolveURL:function(t){return L||(L=self.document.createElement(\"a\")),L.href=t,L.href},hardwareConcurrency:self.navigator.hardwareConcurrency||4,get devicePixelRatio(){return self.devicePixelRatio},get prefersReducedMotion(){return!!self.matchMedia&&(null==C&&(C=self.matchMedia(\"(prefers-reduced-motion: reduce)\")),C.matches)}},F={API_URL:\"https://api.mapbox.com\",get EVENTS_URL(){return this.API_URL?0===this.API_URL.indexOf(\"https://api.mapbox.cn\")?\"https://events.mapbox.cn/events/v2\":0===this.API_URL.indexOf(\"https://api.mapbox.com\")?\"https://events.mapbox.com/events/v2\":null:null},FEEDBACK_URL:\"https://apps.mapbox.com/feedback\",REQUIRE_ACCESS_TOKEN:!0,ACCESS_TOKEN:null,MAX_PARALLEL_IMAGE_REQUESTS:16},B={supported:!1,testSupport:function(t){if(N||!I)return;j?U(t):P=t}},N=!1,j=!1;function U(t){var e=t.createTexture();t.bindTexture(t.TEXTURE_2D,e);try{if(t.texImage2D(t.TEXTURE_2D,0,t.RGBA,t.RGBA,t.UNSIGNED_BYTE,I),t.isContextLost())return;B.supported=!0}catch(t){}t.deleteTexture(e),N=!0}self.document&&((I=self.document.createElement(\"img\")).onload=function(){P&&U(P),P=null,j=!0},I.onerror=function(){N=!0,P=null},I.src=\"data:image/webp;base64,UklGRh4AAABXRUJQVlA4TBEAAAAvAQAAAAfQ//73v/+BiOh/AAA=\");var V=\"01\";var q=function(t,e){this._transformRequestFn=t,this._customAccessToken=e,this._createSkuToken()};function H(t){return 0===t.indexOf(\"mapbox:\")}q.prototype._createSkuToken=function(){var t=function(){for(var t=\"\",e=0;e<10;e++)t+=\"0123456789abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ\"[Math.floor(62*Math.random())];return{token:[\"1\",V,t].join(\"\"),tokenExpiresAt:Date.now()+432e5}}();this._skuToken=t.token,this._skuTokenExpiresAt=t.tokenExpiresAt},q.prototype._isSkuTokenExpired=function(){return Date.now()>this._skuTokenExpiresAt},q.prototype.transformRequest=function(t,e){return this._transformRequestFn&&this._transformRequestFn(t,e)||{url:t}},q.prototype.normalizeStyleURL=function(t,e){if(!H(t))return t;var r=X(t);return r.path=\"/styles/v1\"+r.path,this._makeAPIURL(r,this._customAccessToken||e)},q.prototype.normalizeGlyphsURL=function(t,e){if(!H(t))return t;var r=X(t);return r.path=\"/fonts/v1\"+r.path,this._makeAPIURL(r,this._customAccessToken||e)},q.prototype.normalizeSourceURL=function(t,e){if(!H(t))return t;var r=X(t);return r.path=\"/v4/\"+r.authority+\".json\",r.params.push(\"secure\"),this._makeAPIURL(r,this._customAccessToken||e)},q.prototype.normalizeSpriteURL=function(t,e,r,n){var i=X(t);return H(t)?(i.path=\"/styles/v1\"+i.path+\"/sprite\"+e+r,this._makeAPIURL(i,this._customAccessToken||n)):(i.path+=\"\"+e+r,Z(i))},q.prototype.normalizeTileURL=function(t,e){if(this._isSkuTokenExpired()&&this._createSkuToken(),t&&!H(t))return t;var r=X(t),n=R.devicePixelRatio>=2||512===e?\"@2x\":\"\",i=B.supported?\".webp\":\"$1\";r.path=r.path.replace(/(\\.(png|jpg)\\d*)(?=$)/,\"\"+n+i),r.path=r.path.replace(/^.+\\/v4\\//,\"/\"),r.path=\"/v4\"+r.path;var a=this._customAccessToken||function(t){for(var e=0,r=t;e<r.length;e+=1){var n=r[e].match(/^access_token=(.*)$/);if(n)return n[1]}return null}(r.params)||F.ACCESS_TOKEN;return F.REQUIRE_ACCESS_TOKEN&&a&&this._skuToken&&r.params.push(\"sku=\"+this._skuToken),this._makeAPIURL(r,a)},q.prototype.canonicalizeTileURL=function(t,e){var r=X(t);if(!r.path.match(/(^\\/v4\\/)/)||!r.path.match(/\\.[\\w]+$/))return t;var n=\"mapbox://tiles/\";n+=r.path.replace(\"/v4/\",\"\");var i=r.params;return e&&(i=i.filter((function(t){return!t.match(/^access_token=/)}))),i.length&&(n+=\"?\"+i.join(\"&\")),n},q.prototype.canonicalizeTileset=function(t,e){for(var r=!!e&&H(e),n=[],i=0,a=t.tiles||[];i<a.length;i+=1){var o=a[i];Y(o)?n.push(this.canonicalizeTileURL(o,r)):n.push(o)}return n},q.prototype._makeAPIURL=function(t,e){var r=\"See https://www.mapbox.com/api-documentation/#access-tokens-and-token-scopes\",n=X(F.API_URL);if(t.protocol=n.protocol,t.authority=n.authority,\"/\"!==n.path&&(t.path=\"\"+n.path+t.path),!F.REQUIRE_ACCESS_TOKEN)return Z(t);if(!(e=e||F.ACCESS_TOKEN))throw new Error(\"An API access token is required to use Mapbox GL. \"+r);if(\"s\"===e[0])throw new Error(\"Use a public access token (pk.*) with Mapbox GL, not a secret access token (sk.*). \"+r);return t.params=t.params.filter((function(t){return-1===t.indexOf(\"access_token\")})),t.params.push(\"access_token=\"+e),Z(t)};var G=/^((https?:)?\\/\\/)?([^\\/]+\\.)?mapbox\\.c(n|om)(\\/|\\?|$)/i;function Y(t){return G.test(t)}var W=/^(\\w+):\\/\\/([^/?]*)(\\/[^?]+)?\\??(.+)?/;function X(t){var e=t.match(W);if(!e)throw new Error(\"Unable to parse URL object\");return{protocol:e[1],authority:e[2],path:e[3]||\"/\",params:e[4]?e[4].split(\"&\"):[]}}function Z(t){var e=t.params.length?\"?\"+t.params.join(\"&\"):\"\";return t.protocol+\"://\"+t.authority+t.path+e}function J(t){if(!t)return null;var e,r=t.split(\".\");if(!r||3!==r.length)return null;try{return JSON.parse((e=r[1],decodeURIComponent(self.atob(e).split(\"\").map((function(t){return\"%\"+(\"00\"+t.charCodeAt(0).toString(16)).slice(-2)})).join(\"\"))))}catch(t){return null}}var K=function(t){this.type=t,this.anonId=null,this.eventData={},this.queue=[],this.pendingRequest=null};K.prototype.getStorageKey=function(t){var e,r=J(F.ACCESS_TOKEN),n=\"\";return r&&r.u?(e=r.u,n=self.btoa(encodeURIComponent(e).replace(/%([0-9A-F]{2})/g,(function(t,e){return String.fromCharCode(Number(\"0x\"+e))})))):n=F.ACCESS_TOKEN||\"\",t?\"mapbox.eventData.\"+t+\":\"+n:\"mapbox.eventData:\"+n},K.prototype.fetchEventData=function(){var t=E(\"localStorage\"),e=this.getStorageKey(),r=this.getStorageKey(\"uuid\");if(t)try{var n=self.localStorage.getItem(e);n&&(this.eventData=JSON.parse(n));var i=self.localStorage.getItem(r);i&&(this.anonId=i)}catch(t){_(\"Unable to read from LocalStorage\")}},K.prototype.saveEventData=function(){var t=E(\"localStorage\"),e=this.getStorageKey(),r=this.getStorageKey(\"uuid\");if(t)try{self.localStorage.setItem(r,this.anonId),Object.keys(this.eventData).length>=1&&self.localStorage.setItem(e,JSON.stringify(this.eventData))}catch(t){_(\"Unable to write to LocalStorage\")}},K.prototype.processRequests=function(t){},K.prototype.postEvent=function(t,e,r,n){var i=this;if(F.EVENTS_URL){var a=X(F.EVENTS_URL);a.params.push(\"access_token=\"+(n||F.ACCESS_TOKEN||\"\"));var o={event:this.type,created:new Date(t).toISOString(),sdkIdentifier:\"mapbox-gl-js\",sdkVersion:\"1.10.1\",skuId:V,userId:this.anonId},s=e?u(o,e):o,l={url:Z(a),headers:{\"Content-Type\":\"text/plain\"},body:JSON.stringify([s])};this.pendingRequest=bt(l,(function(t){i.pendingRequest=null,r(t),i.saveEventData(),i.processRequests(n)}))}},K.prototype.queueRequest=function(t,e){this.queue.push(t),this.processRequests(e)};var Q,$,tt=function(t){function e(){t.call(this,\"map.load\"),this.success={},this.skuToken=\"\"}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.postMapLoadEvent=function(t,e,r,n){this.skuToken=r,(F.EVENTS_URL&&n||F.ACCESS_TOKEN&&Array.isArray(t)&&t.some((function(t){return H(t)||Y(t)})))&&this.queueRequest({id:e,timestamp:Date.now()},n)},e.prototype.processRequests=function(t){var e=this;if(!this.pendingRequest&&0!==this.queue.length){var r=this.queue.shift(),n=r.id,i=r.timestamp;n&&this.success[n]||(this.anonId||this.fetchEventData(),d(this.anonId)||(this.anonId=p()),this.postEvent(i,{skuToken:this.skuToken},(function(t){t||n&&(e.success[n]=!0)}),t))}},e}(K),et=new(function(t){function e(e){t.call(this,\"appUserTurnstile\"),this._customAccessToken=e}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.postTurnstileEvent=function(t,e){F.EVENTS_URL&&F.ACCESS_TOKEN&&Array.isArray(t)&&t.some((function(t){return H(t)||Y(t)}))&&this.queueRequest(Date.now(),e)},e.prototype.processRequests=function(t){var e=this;if(!this.pendingRequest&&0!==this.queue.length){this.anonId&&this.eventData.lastSuccess&&this.eventData.tokenU||this.fetchEventData();var r=J(F.ACCESS_TOKEN),n=r?r.u:F.ACCESS_TOKEN,i=n!==this.eventData.tokenU;d(this.anonId)||(this.anonId=p(),i=!0);var a=this.queue.shift();if(this.eventData.lastSuccess){var o=new Date(this.eventData.lastSuccess),s=new Date(a),l=(a-this.eventData.lastSuccess)/864e5;i=i||l>=1||l<-1||o.getDate()!==s.getDate()}else i=!0;if(!i)return this.processRequests();this.postEvent(a,{\"enabled.telemetry\":!1},(function(t){t||(e.eventData.lastSuccess=a,e.eventData.tokenU=n)}),t)}},e}(K)),rt=et.postTurnstileEvent.bind(et),nt=new tt,it=nt.postMapLoadEvent.bind(nt),at=500,ot=50;function st(){self.caches&&!Q&&(Q=self.caches.open(\"mapbox-tiles\"))}function lt(t,e,r){if(st(),Q){var n={status:e.status,statusText:e.statusText,headers:new self.Headers};e.headers.forEach((function(t,e){return n.headers.set(e,t)}));var i=M(e.headers.get(\"Cache-Control\")||\"\");if(!i[\"no-store\"])i[\"max-age\"]&&n.headers.set(\"Expires\",new Date(r+1e3*i[\"max-age\"]).toUTCString()),new Date(n.headers.get(\"Expires\")).getTime()-r<42e4||function(t,e){if(void 0===$)try{new Response(new ReadableStream),$=!0}catch(t){$=!1}$?e(t.body):t.blob().then(e)}(e,(function(e){var r=new self.Response(e,n);st(),Q&&Q.then((function(e){return e.put(ct(t.url),r)})).catch((function(t){return _(t.message)}))}))}}function ct(t){var e=t.indexOf(\"?\");return e<0?t:t.slice(0,e)}function ut(t,e){if(st(),!Q)return e(null);var r=ct(t.url);Q.then((function(t){t.match(r).then((function(n){var i=function(t){if(!t)return!1;var e=new Date(t.headers.get(\"Expires\")||0),r=M(t.headers.get(\"Cache-Control\")||\"\");return e>Date.now()&&!r[\"no-cache\"]}(n);t.delete(r),i&&t.put(r,n.clone()),e(null,n,i)})).catch(e)})).catch(e)}var ft,ht=1/0;function pt(){return null==ft&&(ft=self.OffscreenCanvas&&new self.OffscreenCanvas(1,1).getContext(\"2d\")&&\"function\"==typeof self.createImageBitmap),ft}var dt={Unknown:\"Unknown\",Style:\"Style\",Source:\"Source\",Tile:\"Tile\",Glyphs:\"Glyphs\",SpriteImage:\"SpriteImage\",SpriteJSON:\"SpriteJSON\",Image:\"Image\"};\"function\"==typeof Object.freeze&&Object.freeze(dt);var mt=function(t){function e(e,r,n){401===r&&Y(n)&&(e+=\": you may have provided an invalid Mapbox access token. See https://www.mapbox.com/api-documentation/#access-tokens-and-token-scopes\"),t.call(this,e),this.status=r,this.url=n,this.name=this.constructor.name,this.message=e}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.toString=function(){return this.name+\": \"+this.message+\" (\"+this.status+\"): \"+this.url},e}(Error),gt=k()?function(){return self.worker&&self.worker.referrer}:function(){return(\"blob:\"===self.location.protocol?self.parent:self).location.href};function vt(t,e){var r,n=new self.AbortController,i=new self.Request(t.url,{method:t.method||\"GET\",body:t.body,credentials:t.credentials,headers:t.headers,referrer:gt(),signal:n.signal}),a=!1,o=!1,s=(r=i.url).indexOf(\"sku=\")>0&&Y(r);\"json\"===t.type&&i.headers.set(\"Accept\",\"application/json\");var l=function(r,n,a){if(!o){if(r&&\"SecurityError\"!==r.message&&_(r),n&&a)return c(n);var l=Date.now();self.fetch(i).then((function(r){if(r.ok){var n=s?r.clone():null;return c(r,n,l)}return e(new mt(r.statusText,r.status,t.url))})).catch((function(t){20!==t.code&&e(new Error(t.message))}))}},c=function(r,n,s){(\"arrayBuffer\"===t.type?r.arrayBuffer():\"json\"===t.type?r.json():r.text()).then((function(t){o||(n&&s&&lt(i,n,s),a=!0,e(null,t,r.headers.get(\"Cache-Control\"),r.headers.get(\"Expires\")))})).catch((function(t){o||e(new Error(t.message))}))};return s?ut(i,l):l(null,null),{cancel:function(){o=!0,a||n.abort()}}}var yt=function(t,e){if(r=t.url,!(/^file:/.test(r)||/^file:/.test(gt())&&!/^\\w+:/.test(r))){if(self.fetch&&self.Request&&self.AbortController&&self.Request.prototype.hasOwnProperty(\"signal\"))return vt(t,e);if(k()&&self.worker&&self.worker.actor){return self.worker.actor.send(\"getResource\",t,e,void 0,!0)}}var r;return function(t,e){var r=new self.XMLHttpRequest;for(var n in r.open(t.method||\"GET\",t.url,!0),\"arrayBuffer\"===t.type&&(r.responseType=\"arraybuffer\"),t.headers)r.setRequestHeader(n,t.headers[n]);return\"json\"===t.type&&(r.responseType=\"text\",r.setRequestHeader(\"Accept\",\"application/json\")),r.withCredentials=\"include\"===t.credentials,r.onerror=function(){e(new Error(r.statusText))},r.onload=function(){if((r.status>=200&&r.status<300||0===r.status)&&null!==r.response){var n=r.response;if(\"json\"===t.type)try{n=JSON.parse(r.response)}catch(t){return e(t)}e(null,n,r.getResponseHeader(\"Cache-Control\"),r.getResponseHeader(\"Expires\"))}else e(new mt(r.statusText,r.status,t.url))},r.send(t.body),{cancel:function(){return r.abort()}}}(t,e)},xt=function(t,e){return yt(u(t,{type:\"arrayBuffer\"}),e)},bt=function(t,e){return yt(u(t,{method:\"POST\"}),e)};var _t,wt;_t=[],wt=0;var Tt=function(t,e){if(B.supported&&(t.headers||(t.headers={}),t.headers.accept=\"image/webp,*/*\"),wt>=F.MAX_PARALLEL_IMAGE_REQUESTS){var r={requestParameters:t,callback:e,cancelled:!1,cancel:function(){this.cancelled=!0}};return _t.push(r),r}wt++;var n=!1,i=function(){if(!n)for(n=!0,wt--;_t.length&&wt<F.MAX_PARALLEL_IMAGE_REQUESTS;){var t=_t.shift(),e=t.requestParameters,r=t.callback;t.cancelled||(t.cancel=Tt(e,r).cancel)}},a=xt(t,(function(t,r,n,a){i(),t?e(t):r&&(pt()?function(t,e){var r=new self.Blob([new Uint8Array(t)],{type:\"image/png\"});self.createImageBitmap(r).then((function(t){e(null,t)})).catch((function(t){e(new Error(\"Could not load image because of \"+t.message+\". Please make sure to use a supported image type such as PNG or JPEG. Note that SVGs are not supported.\"))}))}(r,e):function(t,e,r,n){var i=new self.Image,a=self.URL;i.onload=function(){e(null,i),a.revokeObjectURL(i.src)},i.onerror=function(){return e(new Error(\"Could not load image. Please make sure to use a supported image type such as PNG or JPEG. Note that SVGs are not supported.\"))};var o=new self.Blob([new Uint8Array(t)],{type:\"image/png\"});i.cacheControl=r,i.expires=n,i.src=t.byteLength?a.createObjectURL(o):\"data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAEAAAABCAYAAAAfFcSJAAAAC0lEQVQYV2NgAAIAAAUAAarVyFEAAAAASUVORK5CYII=\"}(r,e,n,a))}));return{cancel:function(){a.cancel(),i()}}};function kt(t,e,r){r[t]&&-1!==r[t].indexOf(e)||(r[t]=r[t]||[],r[t].push(e))}function Mt(t,e,r){if(r&&r[t]){var n=r[t].indexOf(e);-1!==n&&r[t].splice(n,1)}}var At=function(t,e){void 0===e&&(e={}),u(this,e),this.type=t},St=function(t){function e(e,r){void 0===r&&(r={}),t.call(this,\"error\",u({error:e},r))}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e}(At),Et=function(){};Et.prototype.on=function(t,e){return this._listeners=this._listeners||{},kt(t,e,this._listeners),this},Et.prototype.off=function(t,e){return Mt(t,e,this._listeners),Mt(t,e,this._oneTimeListeners),this},Et.prototype.once=function(t,e){return this._oneTimeListeners=this._oneTimeListeners||{},kt(t,e,this._oneTimeListeners),this},Et.prototype.fire=function(t,e){\"string\"==typeof t&&(t=new At(t,e||{}));var r=t.type;if(this.listens(r)){t.target=this;for(var n=0,i=this._listeners&&this._listeners[r]?this._listeners[r].slice():[];n<i.length;n+=1){i[n].call(this,t)}for(var a=0,o=this._oneTimeListeners&&this._oneTimeListeners[r]?this._oneTimeListeners[r].slice():[];a<o.length;a+=1){var s=o[a];Mt(r,s,this._oneTimeListeners),s.call(this,t)}var l=this._eventedParent;l&&(u(t,\"function\"==typeof this._eventedParentData?this._eventedParentData():this._eventedParentData),l.fire(t))}else t instanceof St&&console.error(t.error);return this},Et.prototype.listens=function(t){return this._listeners&&this._listeners[t]&&this._listeners[t].length>0||this._oneTimeListeners&&this._oneTimeListeners[t]&&this._oneTimeListeners[t].length>0||this._eventedParent&&this._eventedParent.listens(t)},Et.prototype.setEventedParent=function(t,e){return this._eventedParent=t,this._eventedParentData=e,this};var Lt={$version:8,$root:{version:{required:!0,type:\"enum\",values:[8]},name:{type:\"string\"},metadata:{type:\"*\"},center:{type:\"array\",value:\"number\"},zoom:{type:\"number\"},bearing:{type:\"number\",default:0,period:360,units:\"degrees\"},pitch:{type:\"number\",default:0,units:\"degrees\"},light:{type:\"light\"},sources:{required:!0,type:\"sources\"},sprite:{type:\"string\"},glyphs:{type:\"string\"},transition:{type:\"transition\"},layers:{required:!0,type:\"array\",value:\"layer\"}},sources:{\"*\":{type:\"source\"}},source:[\"source_vector\",\"source_raster\",\"source_raster_dem\",\"source_geojson\",\"source_video\",\"source_image\"],source_vector:{type:{required:!0,type:\"enum\",values:{vector:{}}},url:{type:\"string\"},tiles:{type:\"array\",value:\"string\"},bounds:{type:\"array\",value:\"number\",length:4,default:[-180,-85.051129,180,85.051129]},scheme:{type:\"enum\",values:{xyz:{},tms:{}},default:\"xyz\"},minzoom:{type:\"number\",default:0},maxzoom:{type:\"number\",default:22},attribution:{type:\"string\"},promoteId:{type:\"promoteId\"},\"*\":{type:\"*\"}},source_raster:{type:{required:!0,type:\"enum\",values:{raster:{}}},url:{type:\"string\"},tiles:{type:\"array\",value:\"string\"},bounds:{type:\"array\",value:\"number\",length:4,default:[-180,-85.051129,180,85.051129]},minzoom:{type:\"number\",default:0},maxzoom:{type:\"number\",default:22},tileSize:{type:\"number\",default:512,units:\"pixels\"},scheme:{type:\"enum\",values:{xyz:{},tms:{}},default:\"xyz\"},attribution:{type:\"string\"},\"*\":{type:\"*\"}},source_raster_dem:{type:{required:!0,type:\"enum\",values:{\"raster-dem\":{}}},url:{type:\"string\"},tiles:{type:\"array\",value:\"string\"},bounds:{type:\"array\",value:\"number\",length:4,default:[-180,-85.051129,180,85.051129]},minzoom:{type:\"number\",default:0},maxzoom:{type:\"number\",default:22},tileSize:{type:\"number\",default:512,units:\"pixels\"},attribution:{type:\"string\"},encoding:{type:\"enum\",values:{terrarium:{},mapbox:{}},default:\"mapbox\"},\"*\":{type:\"*\"}},source_geojson:{type:{required:!0,type:\"enum\",values:{geojson:{}}},data:{type:\"*\"},maxzoom:{type:\"number\",default:18},attribution:{type:\"string\"},buffer:{type:\"number\",default:128,maximum:512,minimum:0},tolerance:{type:\"number\",default:.375},cluster:{type:\"boolean\",default:!1},clusterRadius:{type:\"number\",default:50,minimum:0},clusterMaxZoom:{type:\"number\"},clusterProperties:{type:\"*\"},lineMetrics:{type:\"boolean\",default:!1},generateId:{type:\"boolean\",default:!1},promoteId:{type:\"promoteId\"}},source_video:{type:{required:!0,type:\"enum\",values:{video:{}}},urls:{required:!0,type:\"array\",value:\"string\"},coordinates:{required:!0,type:\"array\",length:4,value:{type:\"array\",length:2,value:\"number\"}}},source_image:{type:{required:!0,type:\"enum\",values:{image:{}}},url:{required:!0,type:\"string\"},coordinates:{required:!0,type:\"array\",length:4,value:{type:\"array\",length:2,value:\"number\"}}},layer:{id:{type:\"string\",required:!0},type:{type:\"enum\",values:{fill:{},line:{},symbol:{},circle:{},heatmap:{},\"fill-extrusion\":{},raster:{},hillshade:{},background:{}},required:!0},metadata:{type:\"*\"},source:{type:\"string\"},\"source-layer\":{type:\"string\"},minzoom:{type:\"number\",minimum:0,maximum:24},maxzoom:{type:\"number\",minimum:0,maximum:24},filter:{type:\"filter\"},layout:{type:\"layout\"},paint:{type:\"paint\"}},layout:[\"layout_fill\",\"layout_line\",\"layout_circle\",\"layout_heatmap\",\"layout_fill-extrusion\",\"layout_symbol\",\"layout_raster\",\"layout_hillshade\",\"layout_background\"],layout_background:{visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},layout_fill:{\"fill-sort-key\":{type:\"number\",expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},layout_circle:{\"circle-sort-key\":{type:\"number\",expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},layout_heatmap:{visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},\"layout_fill-extrusion\":{visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},layout_line:{\"line-cap\":{type:\"enum\",values:{butt:{},round:{},square:{}},default:\"butt\",expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"line-join\":{type:\"enum\",values:{bevel:{},round:{},miter:{}},default:\"miter\",expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"line-miter-limit\":{type:\"number\",default:2,requires:[{\"line-join\":\"miter\"}],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"line-round-limit\":{type:\"number\",default:1.05,requires:[{\"line-join\":\"round\"}],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"line-sort-key\":{type:\"number\",expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},layout_symbol:{\"symbol-placement\":{type:\"enum\",values:{point:{},line:{},\"line-center\":{}},default:\"point\",expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"symbol-spacing\":{type:\"number\",default:250,minimum:1,units:\"pixels\",requires:[{\"symbol-placement\":\"line\"}],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"symbol-avoid-edges\":{type:\"boolean\",default:!1,expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"symbol-sort-key\":{type:\"number\",expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"symbol-z-order\":{type:\"enum\",values:{auto:{},\"viewport-y\":{},source:{}},default:\"auto\",expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-allow-overlap\":{type:\"boolean\",default:!1,requires:[\"icon-image\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-ignore-placement\":{type:\"boolean\",default:!1,requires:[\"icon-image\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-optional\":{type:\"boolean\",default:!1,requires:[\"icon-image\",\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-rotation-alignment\":{type:\"enum\",values:{map:{},viewport:{},auto:{}},default:\"auto\",requires:[\"icon-image\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-size\":{type:\"number\",default:1,minimum:0,units:\"factor of the original icon size\",requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"icon-text-fit\":{type:\"enum\",values:{none:{},width:{},height:{},both:{}},default:\"none\",requires:[\"icon-image\",\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-text-fit-padding\":{type:\"array\",value:\"number\",length:4,default:[0,0,0,0],units:\"pixels\",requires:[\"icon-image\",\"text-field\",{\"icon-text-fit\":[\"both\",\"width\",\"height\"]}],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-image\":{type:\"resolvedImage\",tokens:!0,expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"icon-rotate\":{type:\"number\",default:0,period:360,units:\"degrees\",requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"icon-padding\":{type:\"number\",default:2,minimum:0,units:\"pixels\",requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-keep-upright\":{type:\"boolean\",default:!1,requires:[\"icon-image\",{\"icon-rotation-alignment\":\"map\"},{\"symbol-placement\":[\"line\",\"line-center\"]}],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-offset\":{type:\"array\",value:\"number\",length:2,default:[0,0],requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"icon-anchor\":{type:\"enum\",values:{center:{},left:{},right:{},top:{},bottom:{},\"top-left\":{},\"top-right\":{},\"bottom-left\":{},\"bottom-right\":{}},default:\"center\",requires:[\"icon-image\"],expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"icon-pitch-alignment\":{type:\"enum\",values:{map:{},viewport:{},auto:{}},default:\"auto\",requires:[\"icon-image\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-pitch-alignment\":{type:\"enum\",values:{map:{},viewport:{},auto:{}},default:\"auto\",requires:[\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-rotation-alignment\":{type:\"enum\",values:{map:{},viewport:{},auto:{}},default:\"auto\",requires:[\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-field\":{type:\"formatted\",default:\"\",tokens:!0,expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-font\":{type:\"array\",value:\"string\",default:[\"Open Sans Regular\",\"Arial Unicode MS Regular\"],requires:[\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-size\":{type:\"number\",default:16,minimum:0,units:\"pixels\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-max-width\":{type:\"number\",default:10,minimum:0,units:\"ems\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-line-height\":{type:\"number\",default:1.2,units:\"ems\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-letter-spacing\":{type:\"number\",default:0,units:\"ems\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-justify\":{type:\"enum\",values:{auto:{},left:{},center:{},right:{}},default:\"center\",requires:[\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-radial-offset\":{type:\"number\",units:\"ems\",default:0,requires:[\"text-field\"],\"property-type\":\"data-driven\",expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]}},\"text-variable-anchor\":{type:\"array\",value:\"enum\",values:{center:{},left:{},right:{},top:{},bottom:{},\"top-left\":{},\"top-right\":{},\"bottom-left\":{},\"bottom-right\":{}},requires:[\"text-field\",{\"symbol-placement\":[\"point\"]}],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-anchor\":{type:\"enum\",values:{center:{},left:{},right:{},top:{},bottom:{},\"top-left\":{},\"top-right\":{},\"bottom-left\":{},\"bottom-right\":{}},default:\"center\",requires:[\"text-field\",{\"!\":\"text-variable-anchor\"}],expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-max-angle\":{type:\"number\",default:45,units:\"degrees\",requires:[\"text-field\",{\"symbol-placement\":[\"line\",\"line-center\"]}],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-writing-mode\":{type:\"array\",value:\"enum\",values:{horizontal:{},vertical:{}},requires:[\"text-field\",{\"symbol-placement\":[\"point\"]}],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-rotate\":{type:\"number\",default:0,period:360,units:\"degrees\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-padding\":{type:\"number\",default:2,minimum:0,units:\"pixels\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-keep-upright\":{type:\"boolean\",default:!0,requires:[\"text-field\",{\"text-rotation-alignment\":\"map\"},{\"symbol-placement\":[\"line\",\"line-center\"]}],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-transform\":{type:\"enum\",values:{none:{},uppercase:{},lowercase:{}},default:\"none\",requires:[\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-offset\":{type:\"array\",value:\"number\",units:\"ems\",length:2,default:[0,0],requires:[\"text-field\",{\"!\":\"text-radial-offset\"}],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-allow-overlap\":{type:\"boolean\",default:!1,requires:[\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-ignore-placement\":{type:\"boolean\",default:!1,requires:[\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-optional\":{type:\"boolean\",default:!1,requires:[\"text-field\",\"icon-image\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},layout_raster:{visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},layout_hillshade:{visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},filter:{type:\"array\",value:\"*\"},filter_operator:{type:\"enum\",values:{\"==\":{},\"!=\":{},\">\":{},\">=\":{},\"<\":{},\"<=\":{},in:{},\"!in\":{},all:{},any:{},none:{},has:{},\"!has\":{},within:{}}},geometry_type:{type:\"enum\",values:{Point:{},LineString:{},Polygon:{}}},function:{expression:{type:\"expression\"},stops:{type:\"array\",value:\"function_stop\"},base:{type:\"number\",default:1,minimum:0},property:{type:\"string\",default:\"$zoom\"},type:{type:\"enum\",values:{identity:{},exponential:{},interval:{},categorical:{}},default:\"exponential\"},colorSpace:{type:\"enum\",values:{rgb:{},lab:{},hcl:{}},default:\"rgb\"},default:{type:\"*\",required:!1}},function_stop:{type:\"array\",minimum:0,maximum:24,value:[\"number\",\"color\"],length:2},expression:{type:\"array\",value:\"*\",minimum:1},expression_name:{type:\"enum\",values:{let:{group:\"Variable binding\"},var:{group:\"Variable binding\"},literal:{group:\"Types\"},array:{group:\"Types\"},at:{group:\"Lookup\"},in:{group:\"Lookup\"},\"index-of\":{group:\"Lookup\"},slice:{group:\"Lookup\"},case:{group:\"Decision\"},match:{group:\"Decision\"},coalesce:{group:\"Decision\"},step:{group:\"Ramps, scales, curves\"},interpolate:{group:\"Ramps, scales, curves\"},\"interpolate-hcl\":{group:\"Ramps, scales, curves\"},\"interpolate-lab\":{group:\"Ramps, scales, curves\"},ln2:{group:\"Math\"},pi:{group:\"Math\"},e:{group:\"Math\"},typeof:{group:\"Types\"},string:{group:\"Types\"},number:{group:\"Types\"},boolean:{group:\"Types\"},object:{group:\"Types\"},collator:{group:\"Types\"},format:{group:\"Types\"},image:{group:\"Types\"},\"number-format\":{group:\"Types\"},\"to-string\":{group:\"Types\"},\"to-number\":{group:\"Types\"},\"to-boolean\":{group:\"Types\"},\"to-rgba\":{group:\"Color\"},\"to-color\":{group:\"Types\"},rgb:{group:\"Color\"},rgba:{group:\"Color\"},get:{group:\"Lookup\"},has:{group:\"Lookup\"},length:{group:\"Lookup\"},properties:{group:\"Feature data\"},\"feature-state\":{group:\"Feature data\"},\"geometry-type\":{group:\"Feature data\"},id:{group:\"Feature data\"},zoom:{group:\"Zoom\"},\"heatmap-density\":{group:\"Heatmap\"},\"line-progress\":{group:\"Feature data\"},accumulated:{group:\"Feature data\"},\"+\":{group:\"Math\"},\"*\":{group:\"Math\"},\"-\":{group:\"Math\"},\"/\":{group:\"Math\"},\"%\":{group:\"Math\"},\"^\":{group:\"Math\"},sqrt:{group:\"Math\"},log10:{group:\"Math\"},ln:{group:\"Math\"},log2:{group:\"Math\"},sin:{group:\"Math\"},cos:{group:\"Math\"},tan:{group:\"Math\"},asin:{group:\"Math\"},acos:{group:\"Math\"},atan:{group:\"Math\"},min:{group:\"Math\"},max:{group:\"Math\"},round:{group:\"Math\"},abs:{group:\"Math\"},ceil:{group:\"Math\"},floor:{group:\"Math\"},distance:{group:\"Math\"},\"==\":{group:\"Decision\"},\"!=\":{group:\"Decision\"},\">\":{group:\"Decision\"},\"<\":{group:\"Decision\"},\">=\":{group:\"Decision\"},\"<=\":{group:\"Decision\"},all:{group:\"Decision\"},any:{group:\"Decision\"},\"!\":{group:\"Decision\"},within:{group:\"Decision\"},\"is-supported-script\":{group:\"String\"},upcase:{group:\"String\"},downcase:{group:\"String\"},concat:{group:\"String\"},\"resolved-locale\":{group:\"String\"}}},light:{anchor:{type:\"enum\",default:\"viewport\",values:{map:{},viewport:{}},\"property-type\":\"data-constant\",transition:!1,expression:{interpolated:!1,parameters:[\"zoom\"]}},position:{type:\"array\",default:[1.15,210,30],length:3,value:\"number\",\"property-type\":\"data-constant\",transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]}},color:{type:\"color\",\"property-type\":\"data-constant\",default:\"#ffffff\",expression:{interpolated:!0,parameters:[\"zoom\"]},transition:!0},intensity:{type:\"number\",\"property-type\":\"data-constant\",default:.5,minimum:0,maximum:1,expression:{interpolated:!0,parameters:[\"zoom\"]},transition:!0}},paint:[\"paint_fill\",\"paint_line\",\"paint_circle\",\"paint_heatmap\",\"paint_fill-extrusion\",\"paint_symbol\",\"paint_raster\",\"paint_hillshade\",\"paint_background\"],paint_fill:{\"fill-antialias\":{type:\"boolean\",default:!0,expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"fill-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"fill-color\":{type:\"color\",default:\"#000000\",transition:!0,requires:[{\"!\":\"fill-pattern\"}],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"fill-outline-color\":{type:\"color\",transition:!0,requires:[{\"!\":\"fill-pattern\"},{\"fill-antialias\":!0}],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"fill-translate\":{type:\"array\",value:\"number\",length:2,default:[0,0],transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"fill-translate-anchor\":{type:\"enum\",values:{map:{},viewport:{}},default:\"map\",requires:[\"fill-translate\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"fill-pattern\":{type:\"resolvedImage\",transition:!0,expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"cross-faded-data-driven\"}},\"paint_fill-extrusion\":{\"fill-extrusion-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"fill-extrusion-color\":{type:\"color\",default:\"#000000\",transition:!0,requires:[{\"!\":\"fill-extrusion-pattern\"}],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"fill-extrusion-translate\":{type:\"array\",value:\"number\",length:2,default:[0,0],transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"fill-extrusion-translate-anchor\":{type:\"enum\",values:{map:{},viewport:{}},default:\"map\",requires:[\"fill-extrusion-translate\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"fill-extrusion-pattern\":{type:\"resolvedImage\",transition:!0,expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"cross-faded-data-driven\"},\"fill-extrusion-height\":{type:\"number\",default:0,minimum:0,units:\"meters\",transition:!0,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"fill-extrusion-base\":{type:\"number\",default:0,minimum:0,units:\"meters\",transition:!0,requires:[\"fill-extrusion-height\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"fill-extrusion-vertical-gradient\":{type:\"boolean\",default:!0,transition:!1,expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"}},paint_line:{\"line-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"line-color\":{type:\"color\",default:\"#000000\",transition:!0,requires:[{\"!\":\"line-pattern\"}],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"line-translate\":{type:\"array\",value:\"number\",length:2,default:[0,0],transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"line-translate-anchor\":{type:\"enum\",values:{map:{},viewport:{}},default:\"map\",requires:[\"line-translate\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"line-width\":{type:\"number\",default:1,minimum:0,transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"line-gap-width\":{type:\"number\",default:0,minimum:0,transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"line-offset\":{type:\"number\",default:0,transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"line-blur\":{type:\"number\",default:0,minimum:0,transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"line-dasharray\":{type:\"array\",value:\"number\",minimum:0,transition:!0,units:\"line widths\",requires:[{\"!\":\"line-pattern\"}],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"cross-faded\"},\"line-pattern\":{type:\"resolvedImage\",transition:!0,expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"cross-faded-data-driven\"},\"line-gradient\":{type:\"color\",transition:!1,requires:[{\"!\":\"line-dasharray\"},{\"!\":\"line-pattern\"},{source:\"geojson\",has:{lineMetrics:!0}}],expression:{interpolated:!0,parameters:[\"line-progress\"]},\"property-type\":\"color-ramp\"}},paint_circle:{\"circle-radius\":{type:\"number\",default:5,minimum:0,transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"circle-color\":{type:\"color\",default:\"#000000\",transition:!0,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"circle-blur\":{type:\"number\",default:0,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"circle-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"circle-translate\":{type:\"array\",value:\"number\",length:2,default:[0,0],transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"circle-translate-anchor\":{type:\"enum\",values:{map:{},viewport:{}},default:\"map\",requires:[\"circle-translate\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"circle-pitch-scale\":{type:\"enum\",values:{map:{},viewport:{}},default:\"map\",expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"circle-pitch-alignment\":{type:\"enum\",values:{map:{},viewport:{}},default:\"viewport\",expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"circle-stroke-width\":{type:\"number\",default:0,minimum:0,transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"circle-stroke-color\":{type:\"color\",default:\"#000000\",transition:!0,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"circle-stroke-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"}},paint_heatmap:{\"heatmap-radius\":{type:\"number\",default:30,minimum:1,transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"heatmap-weight\":{type:\"number\",default:1,minimum:0,transition:!1,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"heatmap-intensity\":{type:\"number\",default:1,minimum:0,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"heatmap-color\":{type:\"color\",default:[\"interpolate\",[\"linear\"],[\"heatmap-density\"],0,\"rgba(0, 0, 255, 0)\",.1,\"royalblue\",.3,\"cyan\",.5,\"lime\",.7,\"yellow\",1,\"red\"],transition:!1,expression:{interpolated:!0,parameters:[\"heatmap-density\"]},\"property-type\":\"color-ramp\"},\"heatmap-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"}},paint_symbol:{\"icon-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"icon-color\":{type:\"color\",default:\"#000000\",transition:!0,requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"icon-halo-color\":{type:\"color\",default:\"rgba(0, 0, 0, 0)\",transition:!0,requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"icon-halo-width\":{type:\"number\",default:0,minimum:0,transition:!0,units:\"pixels\",requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"icon-halo-blur\":{type:\"number\",default:0,minimum:0,transition:!0,units:\"pixels\",requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"icon-translate\":{type:\"array\",value:\"number\",length:2,default:[0,0],transition:!0,units:\"pixels\",requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-translate-anchor\":{type:\"enum\",values:{map:{},viewport:{}},default:\"map\",requires:[\"icon-image\",\"icon-translate\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"text-color\":{type:\"color\",default:\"#000000\",transition:!0,overridable:!0,requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"text-halo-color\":{type:\"color\",default:\"rgba(0, 0, 0, 0)\",transition:!0,requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"text-halo-width\":{type:\"number\",default:0,minimum:0,transition:!0,units:\"pixels\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"text-halo-blur\":{type:\"number\",default:0,minimum:0,transition:!0,units:\"pixels\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"text-translate\":{type:\"array\",value:\"number\",length:2,default:[0,0],transition:!0,units:\"pixels\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-translate-anchor\":{type:\"enum\",values:{map:{},viewport:{}},default:\"map\",requires:[\"text-field\",\"text-translate\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"}},paint_raster:{\"raster-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"raster-hue-rotate\":{type:\"number\",default:0,period:360,transition:!0,units:\"degrees\",expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"raster-brightness-min\":{type:\"number\",default:0,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"raster-brightness-max\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"raster-saturation\":{type:\"number\",default:0,minimum:-1,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"raster-contrast\":{type:\"number\",default:0,minimum:-1,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"raster-resampling\":{type:\"enum\",values:{linear:{},nearest:{}},default:\"linear\",expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"raster-fade-duration\":{type:\"number\",default:300,minimum:0,transition:!1,units:\"milliseconds\",expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"}},paint_hillshade:{\"hillshade-illumination-direction\":{type:\"number\",default:335,minimum:0,maximum:359,transition:!1,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"hillshade-illumination-anchor\":{type:\"enum\",values:{map:{},viewport:{}},default:\"viewport\",expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"hillshade-exaggeration\":{type:\"number\",default:.5,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"hillshade-shadow-color\":{type:\"color\",default:\"#000000\",transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"hillshade-highlight-color\":{type:\"color\",default:\"#FFFFFF\",transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"hillshade-accent-color\":{type:\"color\",default:\"#000000\",transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"}},paint_background:{\"background-color\":{type:\"color\",default:\"#000000\",transition:!0,requires:[{\"!\":\"background-pattern\"}],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"background-pattern\":{type:\"resolvedImage\",transition:!0,expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"cross-faded\"},\"background-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"}},transition:{duration:{type:\"number\",default:300,minimum:0,units:\"milliseconds\"},delay:{type:\"number\",default:0,minimum:0,units:\"milliseconds\"}},\"property-type\":{\"data-driven\":{type:\"property-type\"},\"cross-faded\":{type:\"property-type\"},\"cross-faded-data-driven\":{type:\"property-type\"},\"color-ramp\":{type:\"property-type\"},\"data-constant\":{type:\"property-type\"},constant:{type:\"property-type\"}},promoteId:{\"*\":{type:\"string\"}}},Ct=function(t,e,r,n){this.message=(t?t+\": \":\"\")+r,n&&(this.identifier=n),null!=e&&e.__line__&&(this.line=e.__line__)};function Pt(t){var e=t.key,r=t.value;return r?[new Ct(e,r,\"constants have been deprecated as of v8\")]:[]}function It(t){for(var e=[],r=arguments.length-1;r-- >0;)e[r]=arguments[r+1];for(var n=0,i=e;n<i.length;n+=1){var a=i[n];for(var o in a)t[o]=a[o]}return t}function Ot(t){return t instanceof Number||t instanceof String||t instanceof Boolean?t.valueOf():t}function zt(t){if(Array.isArray(t))return t.map(zt);if(t instanceof Object&&!(t instanceof Number||t instanceof String||t instanceof Boolean)){var e={};for(var r in t)e[r]=zt(t[r]);return e}return Ot(t)}var Dt=function(t){function e(e,r){t.call(this,r),this.message=r,this.key=e}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e}(Error),Rt=function(t,e){void 0===e&&(e=[]),this.parent=t,this.bindings={};for(var r=0,n=e;r<n.length;r+=1){var i=n[r],a=i[0],o=i[1];this.bindings[a]=o}};Rt.prototype.concat=function(t){return new Rt(this,t)},Rt.prototype.get=function(t){if(this.bindings[t])return this.bindings[t];if(this.parent)return this.parent.get(t);throw new Error(t+\" not found in scope.\")},Rt.prototype.has=function(t){return!!this.bindings[t]||!!this.parent&&this.parent.has(t)};var Ft={kind:\"null\"},Bt={kind:\"number\"},Nt={kind:\"string\"},jt={kind:\"boolean\"},Ut={kind:\"color\"},Vt={kind:\"object\"},qt={kind:\"value\"},Ht={kind:\"collator\"},Gt={kind:\"formatted\"},Yt={kind:\"resolvedImage\"};function Wt(t,e){return{kind:\"array\",itemType:t,N:e}}function Xt(t){if(\"array\"===t.kind){var e=Xt(t.itemType);return\"number\"==typeof t.N?\"array<\"+e+\", \"+t.N+\">\":\"value\"===t.itemType.kind?\"array\":\"array<\"+e+\">\"}return t.kind}var Zt=[Ft,Bt,Nt,jt,Ut,Gt,Vt,Wt(qt),Yt];function Jt(t,e){if(\"error\"===e.kind)return null;if(\"array\"===t.kind){if(\"array\"===e.kind&&(0===e.N&&\"value\"===e.itemType.kind||!Jt(t.itemType,e.itemType))&&(\"number\"!=typeof t.N||t.N===e.N))return null}else{if(t.kind===e.kind)return null;if(\"value\"===t.kind)for(var r=0,n=Zt;r<n.length;r+=1){if(!Jt(n[r],e))return null}}return\"Expected \"+Xt(t)+\" but found \"+Xt(e)+\" instead.\"}function Kt(t,e){return e.some((function(e){return e.kind===t.kind}))}function Qt(t,e){return e.some((function(e){return\"null\"===e?null===t:\"array\"===e?Array.isArray(t):\"object\"===e?t&&!Array.isArray(t)&&\"object\"==typeof t:e===typeof t}))}var $t=e((function(t,e){var r={transparent:[0,0,0,0],aliceblue:[240,248,255,1],antiquewhite:[250,235,215,1],aqua:[0,255,255,1],aquamarine:[127,255,212,1],azure:[240,255,255,1],beige:[245,245,220,1],bisque:[255,228,196,1],black:[0,0,0,1],blanchedalmond:[255,235,205,1],blue:[0,0,255,1],blueviolet:[138,43,226,1],brown:[165,42,42,1],burlywood:[222,184,135,1],cadetblue:[95,158,160,1],chartreuse:[127,255,0,1],chocolate:[210,105,30,1],coral:[255,127,80,1],cornflowerblue:[100,149,237,1],cornsilk:[255,248,220,1],crimson:[220,20,60,1],cyan:[0,255,255,1],darkblue:[0,0,139,1],darkcyan:[0,139,139,1],darkgoldenrod:[184,134,11,1],darkgray:[169,169,169,1],darkgreen:[0,100,0,1],darkgrey:[169,169,169,1],darkkhaki:[189,183,107,1],darkmagenta:[139,0,139,1],darkolivegreen:[85,107,47,1],darkorange:[255,140,0,1],darkorchid:[153,50,204,1],darkred:[139,0,0,1],darksalmon:[233,150,122,1],darkseagreen:[143,188,143,1],darkslateblue:[72,61,139,1],darkslategray:[47,79,79,1],darkslategrey:[47,79,79,1],darkturquoise:[0,206,209,1],darkviolet:[148,0,211,1],deeppink:[255,20,147,1],deepskyblue:[0,191,255,1],dimgray:[105,105,105,1],dimgrey:[105,105,105,1],dodgerblue:[30,144,255,1],firebrick:[178,34,34,1],floralwhite:[255,250,240,1],forestgreen:[34,139,34,1],fuchsia:[255,0,255,1],gainsboro:[220,220,220,1],ghostwhite:[248,248,255,1],gold:[255,215,0,1],goldenrod:[218,165,32,1],gray:[128,128,128,1],green:[0,128,0,1],greenyellow:[173,255,47,1],grey:[128,128,128,1],honeydew:[240,255,240,1],hotpink:[255,105,180,1],indianred:[205,92,92,1],indigo:[75,0,130,1],ivory:[255,255,240,1],khaki:[240,230,140,1],lavender:[230,230,250,1],lavenderblush:[255,240,245,1],lawngreen:[124,252,0,1],lemonchiffon:[255,250,205,1],lightblue:[173,216,230,1],lightcoral:[240,128,128,1],lightcyan:[224,255,255,1],lightgoldenrodyellow:[250,250,210,1],lightgray:[211,211,211,1],lightgreen:[144,238,144,1],lightgrey:[211,211,211,1],lightpink:[255,182,193,1],lightsalmon:[255,160,122,1],lightseagreen:[32,178,170,1],lightskyblue:[135,206,250,1],lightslategray:[119,136,153,1],lightslategrey:[119,136,153,1],lightsteelblue:[176,196,222,1],lightyellow:[255,255,224,1],lime:[0,255,0,1],limegreen:[50,205,50,1],linen:[250,240,230,1],magenta:[255,0,255,1],maroon:[128,0,0,1],mediumaquamarine:[102,205,170,1],mediumblue:[0,0,205,1],mediumorchid:[186,85,211,1],mediumpurple:[147,112,219,1],mediumseagreen:[60,179,113,1],mediumslateblue:[123,104,238,1],mediumspringgreen:[0,250,154,1],mediumturquoise:[72,209,204,1],mediumvioletred:[199,21,133,1],midnightblue:[25,25,112,1],mintcream:[245,255,250,1],mistyrose:[255,228,225,1],moccasin:[255,228,181,1],navajowhite:[255,222,173,1],navy:[0,0,128,1],oldlace:[253,245,230,1],olive:[128,128,0,1],olivedrab:[107,142,35,1],orange:[255,165,0,1],orangered:[255,69,0,1],orchid:[218,112,214,1],palegoldenrod:[238,232,170,1],palegreen:[152,251,152,1],paleturquoise:[175,238,238,1],palevioletred:[219,112,147,1],papayawhip:[255,239,213,1],peachpuff:[255,218,185,1],peru:[205,133,63,1],pink:[255,192,203,1],plum:[221,160,221,1],powderblue:[176,224,230,1],purple:[128,0,128,1],rebeccapurple:[102,51,153,1],red:[255,0,0,1],rosybrown:[188,143,143,1],royalblue:[65,105,225,1],saddlebrown:[139,69,19,1],salmon:[250,128,114,1],sandybrown:[244,164,96,1],seagreen:[46,139,87,1],seashell:[255,245,238,1],sienna:[160,82,45,1],silver:[192,192,192,1],skyblue:[135,206,235,1],slateblue:[106,90,205,1],slategray:[112,128,144,1],slategrey:[112,128,144,1],snow:[255,250,250,1],springgreen:[0,255,127,1],steelblue:[70,130,180,1],tan:[210,180,140,1],teal:[0,128,128,1],thistle:[216,191,216,1],tomato:[255,99,71,1],turquoise:[64,224,208,1],violet:[238,130,238,1],wheat:[245,222,179,1],white:[255,255,255,1],whitesmoke:[245,245,245,1],yellow:[255,255,0,1],yellowgreen:[154,205,50,1]};function n(t){return(t=Math.round(t))<0?0:t>255?255:t}function i(t){return t<0?0:t>1?1:t}function a(t){return\"%\"===t[t.length-1]?n(parseFloat(t)/100*255):n(parseInt(t))}function o(t){return\"%\"===t[t.length-1]?i(parseFloat(t)/100):i(parseFloat(t))}function s(t,e,r){return r<0?r+=1:r>1&&(r-=1),6*r<1?t+(e-t)*r*6:2*r<1?e:3*r<2?t+(e-t)*(2/3-r)*6:t}try{e.parseCSSColor=function(t){var e,i=t.replace(/ /g,\"\").toLowerCase();if(i in r)return r[i].slice();if(\"#\"===i[0])return 4===i.length?(e=parseInt(i.substr(1),16))>=0&&e<=4095?[(3840&e)>>4|(3840&e)>>8,240&e|(240&e)>>4,15&e|(15&e)<<4,1]:null:7===i.length&&(e=parseInt(i.substr(1),16))>=0&&e<=16777215?[(16711680&e)>>16,(65280&e)>>8,255&e,1]:null;var l=i.indexOf(\"(\"),c=i.indexOf(\")\");if(-1!==l&&c+1===i.length){var u=i.substr(0,l),f=i.substr(l+1,c-(l+1)).split(\",\"),h=1;switch(u){case\"rgba\":if(4!==f.length)return null;h=o(f.pop());case\"rgb\":return 3!==f.length?null:[a(f[0]),a(f[1]),a(f[2]),h];case\"hsla\":if(4!==f.length)return null;h=o(f.pop());case\"hsl\":if(3!==f.length)return null;var p=(parseFloat(f[0])%360+360)%360/360,d=o(f[1]),m=o(f[2]),g=m<=.5?m*(d+1):m+d-m*d,v=2*m-g;return[n(255*s(v,g,p+1/3)),n(255*s(v,g,p)),n(255*s(v,g,p-1/3)),h];default:return null}}return null}}catch(t){}})).parseCSSColor,te=function(t,e,r,n){void 0===n&&(n=1),this.r=t,this.g=e,this.b=r,this.a=n};te.parse=function(t){if(t){if(t instanceof te)return t;if(\"string\"==typeof t){var e=$t(t);if(e)return new te(e[0]/255*e[3],e[1]/255*e[3],e[2]/255*e[3],e[3])}}},te.prototype.toString=function(){var t=this.toArray(),e=t[0],r=t[1],n=t[2],i=t[3];return\"rgba(\"+Math.round(e)+\",\"+Math.round(r)+\",\"+Math.round(n)+\",\"+i+\")\"},te.prototype.toArray=function(){var t=this.r,e=this.g,r=this.b,n=this.a;return 0===n?[0,0,0,0]:[255*t/n,255*e/n,255*r/n,n]},te.black=new te(0,0,0,1),te.white=new te(1,1,1,1),te.transparent=new te(0,0,0,0),te.red=new te(1,0,0,1);var ee=function(t,e,r){this.sensitivity=t?e?\"variant\":\"case\":e?\"accent\":\"base\",this.locale=r,this.collator=new Intl.Collator(this.locale?this.locale:[],{sensitivity:this.sensitivity,usage:\"search\"})};ee.prototype.compare=function(t,e){return this.collator.compare(t,e)},ee.prototype.resolvedLocale=function(){return new Intl.Collator(this.locale?this.locale:[]).resolvedOptions().locale};var re=function(t,e,r,n,i){this.text=t,this.image=e,this.scale=r,this.fontStack=n,this.textColor=i},ne=function(t){this.sections=t};ne.fromString=function(t){return new ne([new re(t,null,null,null,null)])},ne.prototype.isEmpty=function(){return 0===this.sections.length||!this.sections.some((function(t){return 0!==t.text.length||t.image&&0!==t.image.name.length}))},ne.factory=function(t){return t instanceof ne?t:ne.fromString(t)},ne.prototype.toString=function(){return 0===this.sections.length?\"\":this.sections.map((function(t){return t.text})).join(\"\")},ne.prototype.serialize=function(){for(var t=[\"format\"],e=0,r=this.sections;e<r.length;e+=1){var n=r[e];if(n.image)t.push([\"image\",n.image.name]);else{t.push(n.text);var i={};n.fontStack&&(i[\"text-font\"]=[\"literal\",n.fontStack.split(\",\")]),n.scale&&(i[\"font-scale\"]=n.scale),n.textColor&&(i[\"text-color\"]=[\"rgba\"].concat(n.textColor.toArray())),t.push(i)}}return t};var ie=function(t){this.name=t.name,this.available=t.available};function ae(t,e,r,n){return\"number\"==typeof t&&t>=0&&t<=255&&\"number\"==typeof e&&e>=0&&e<=255&&\"number\"==typeof r&&r>=0&&r<=255?void 0===n||\"number\"==typeof n&&n>=0&&n<=1?null:\"Invalid rgba value [\"+[t,e,r,n].join(\", \")+\"]: 'a' must be between 0 and 1.\":\"Invalid rgba value [\"+(\"number\"==typeof n?[t,e,r,n]:[t,e,r]).join(\", \")+\"]: 'r', 'g', and 'b' must be between 0 and 255.\"}function oe(t){if(null===t)return!0;if(\"string\"==typeof t)return!0;if(\"boolean\"==typeof t)return!0;if(\"number\"==typeof t)return!0;if(t instanceof te)return!0;if(t instanceof ee)return!0;if(t instanceof ne)return!0;if(t instanceof ie)return!0;if(Array.isArray(t)){for(var e=0,r=t;e<r.length;e+=1){if(!oe(r[e]))return!1}return!0}if(\"object\"==typeof t){for(var n in t)if(!oe(t[n]))return!1;return!0}return!1}function se(t){if(null===t)return Ft;if(\"string\"==typeof t)return Nt;if(\"boolean\"==typeof t)return jt;if(\"number\"==typeof t)return Bt;if(t instanceof te)return Ut;if(t instanceof ee)return Ht;if(t instanceof ne)return Gt;if(t instanceof ie)return Yt;if(Array.isArray(t)){for(var e,r=t.length,n=0,i=t;n<i.length;n+=1){var a=se(i[n]);if(e){if(e===a)continue;e=qt;break}e=a}return Wt(e||qt,r)}return Vt}function le(t){var e=typeof t;return null===t?\"\":\"string\"===e||\"number\"===e||\"boolean\"===e?String(t):t instanceof te||t instanceof ne||t instanceof ie?t.toString():JSON.stringify(t)}ie.prototype.toString=function(){return this.name},ie.fromString=function(t){return t?new ie({name:t,available:!1}):null},ie.prototype.serialize=function(){return[\"image\",this.name]};var ce=function(t,e){this.type=t,this.value=e};ce.parse=function(t,e){if(2!==t.length)return e.error(\"'literal' expression requires exactly one argument, but found \"+(t.length-1)+\" instead.\");if(!oe(t[1]))return e.error(\"invalid value\");var r=t[1],n=se(r),i=e.expectedType;return\"array\"!==n.kind||0!==n.N||!i||\"array\"!==i.kind||\"number\"==typeof i.N&&0!==i.N||(n=i),new ce(n,r)},ce.prototype.evaluate=function(){return this.value},ce.prototype.eachChild=function(){},ce.prototype.outputDefined=function(){return!0},ce.prototype.serialize=function(){return\"array\"===this.type.kind||\"object\"===this.type.kind?[\"literal\",this.value]:this.value instanceof te?[\"rgba\"].concat(this.value.toArray()):this.value instanceof ne?this.value.serialize():this.value};var ue=function(t){this.name=\"ExpressionEvaluationError\",this.message=t};ue.prototype.toJSON=function(){return this.message};var fe={string:Nt,number:Bt,boolean:jt,object:Vt},he=function(t,e){this.type=t,this.args=e};he.parse=function(t,e){if(t.length<2)return e.error(\"Expected at least one argument.\");var r,n=1,i=t[0];if(\"array\"===i){var a,o;if(t.length>2){var s=t[1];if(\"string\"!=typeof s||!(s in fe)||\"object\"===s)return e.error('The item type argument of \"array\" must be one of string, number, boolean',1);a=fe[s],n++}else a=qt;if(t.length>3){if(null!==t[2]&&(\"number\"!=typeof t[2]||t[2]<0||t[2]!==Math.floor(t[2])))return e.error('The length argument to \"array\" must be a positive integer literal',2);o=t[2],n++}r=Wt(a,o)}else r=fe[i];for(var l=[];n<t.length;n++){var c=e.parse(t[n],n,qt);if(!c)return null;l.push(c)}return new he(r,l)},he.prototype.evaluate=function(t){for(var e=0;e<this.args.length;e++){var r=this.args[e].evaluate(t);if(!Jt(this.type,se(r)))return r;if(e===this.args.length-1)throw new ue(\"Expected value to be of type \"+Xt(this.type)+\", but found \"+Xt(se(r))+\" instead.\")}return null},he.prototype.eachChild=function(t){this.args.forEach(t)},he.prototype.outputDefined=function(){return this.args.every((function(t){return t.outputDefined()}))},he.prototype.serialize=function(){var t=this.type,e=[t.kind];if(\"array\"===t.kind){var r=t.itemType;if(\"string\"===r.kind||\"number\"===r.kind||\"boolean\"===r.kind){e.push(r.kind);var n=t.N;(\"number\"==typeof n||this.args.length>1)&&e.push(n)}}return e.concat(this.args.map((function(t){return t.serialize()})))};var pe=function(t){this.type=Gt,this.sections=t};pe.parse=function(t,e){if(t.length<2)return e.error(\"Expected at least one argument.\");var r=t[1];if(!Array.isArray(r)&&\"object\"==typeof r)return e.error(\"First argument must be an image or text section.\");for(var n=[],i=!1,a=1;a<=t.length-1;++a){var o=t[a];if(i&&\"object\"==typeof o&&!Array.isArray(o)){i=!1;var s=null;if(o[\"font-scale\"]&&!(s=e.parse(o[\"font-scale\"],1,Bt)))return null;var l=null;if(o[\"text-font\"]&&!(l=e.parse(o[\"text-font\"],1,Wt(Nt))))return null;var c=null;if(o[\"text-color\"]&&!(c=e.parse(o[\"text-color\"],1,Ut)))return null;var u=n[n.length-1];u.scale=s,u.font=l,u.textColor=c}else{var f=e.parse(t[a],1,qt);if(!f)return null;var h=f.type.kind;if(\"string\"!==h&&\"value\"!==h&&\"null\"!==h&&\"resolvedImage\"!==h)return e.error(\"Formatted text type must be 'string', 'value', 'image' or 'null'.\");i=!0,n.push({content:f,scale:null,font:null,textColor:null})}}return new pe(n)},pe.prototype.evaluate=function(t){return new ne(this.sections.map((function(e){var r=e.content.evaluate(t);return se(r)===Yt?new re(\"\",r,null,null,null):new re(le(r),null,e.scale?e.scale.evaluate(t):null,e.font?e.font.evaluate(t).join(\",\"):null,e.textColor?e.textColor.evaluate(t):null)})))},pe.prototype.eachChild=function(t){for(var e=0,r=this.sections;e<r.length;e+=1){var n=r[e];t(n.content),n.scale&&t(n.scale),n.font&&t(n.font),n.textColor&&t(n.textColor)}},pe.prototype.outputDefined=function(){return!1},pe.prototype.serialize=function(){for(var t=[\"format\"],e=0,r=this.sections;e<r.length;e+=1){var n=r[e];t.push(n.content.serialize());var i={};n.scale&&(i[\"font-scale\"]=n.scale.serialize()),n.font&&(i[\"text-font\"]=n.font.serialize()),n.textColor&&(i[\"text-color\"]=n.textColor.serialize()),t.push(i)}return t};var de=function(t){this.type=Yt,this.input=t};de.parse=function(t,e){if(2!==t.length)return e.error(\"Expected two arguments.\");var r=e.parse(t[1],1,Nt);return r?new de(r):e.error(\"No image name provided.\")},de.prototype.evaluate=function(t){var e=this.input.evaluate(t),r=ie.fromString(e);return r&&t.availableImages&&(r.available=t.availableImages.indexOf(e)>-1),r},de.prototype.eachChild=function(t){t(this.input)},de.prototype.outputDefined=function(){return!1},de.prototype.serialize=function(){return[\"image\",this.input.serialize()]};var me={\"to-boolean\":jt,\"to-color\":Ut,\"to-number\":Bt,\"to-string\":Nt},ge=function(t,e){this.type=t,this.args=e};ge.parse=function(t,e){if(t.length<2)return e.error(\"Expected at least one argument.\");var r=t[0];if((\"to-boolean\"===r||\"to-string\"===r)&&2!==t.length)return e.error(\"Expected one argument.\");for(var n=me[r],i=[],a=1;a<t.length;a++){var o=e.parse(t[a],a,qt);if(!o)return null;i.push(o)}return new ge(n,i)},ge.prototype.evaluate=function(t){if(\"boolean\"===this.type.kind)return Boolean(this.args[0].evaluate(t));if(\"color\"===this.type.kind){for(var e,r,n=0,i=this.args;n<i.length;n+=1){if(r=null,(e=i[n].evaluate(t))instanceof te)return e;if(\"string\"==typeof e){var a=t.parseColor(e);if(a)return a}else if(Array.isArray(e)&&!(r=e.length<3||e.length>4?\"Invalid rbga value \"+JSON.stringify(e)+\": expected an array containing either three or four numeric values.\":ae(e[0],e[1],e[2],e[3])))return new te(e[0]/255,e[1]/255,e[2]/255,e[3])}throw new ue(r||\"Could not parse color from value '\"+(\"string\"==typeof e?e:String(JSON.stringify(e)))+\"'\")}if(\"number\"===this.type.kind){for(var o=null,s=0,l=this.args;s<l.length;s+=1){if(null===(o=l[s].evaluate(t)))return 0;var c=Number(o);if(!isNaN(c))return c}throw new ue(\"Could not convert \"+JSON.stringify(o)+\" to number.\")}return\"formatted\"===this.type.kind?ne.fromString(le(this.args[0].evaluate(t))):\"resolvedImage\"===this.type.kind?ie.fromString(le(this.args[0].evaluate(t))):le(this.args[0].evaluate(t))},ge.prototype.eachChild=function(t){this.args.forEach(t)},ge.prototype.outputDefined=function(){return this.args.every((function(t){return t.outputDefined()}))},ge.prototype.serialize=function(){if(\"formatted\"===this.type.kind)return new pe([{content:this.args[0],scale:null,font:null,textColor:null}]).serialize();if(\"resolvedImage\"===this.type.kind)return new de(this.args[0]).serialize();var t=[\"to-\"+this.type.kind];return this.eachChild((function(e){t.push(e.serialize())})),t};var ve=[\"Unknown\",\"Point\",\"LineString\",\"Polygon\"],ye=function(){this.globals=null,this.feature=null,this.featureState=null,this.formattedSection=null,this._parseColorCache={},this.availableImages=null,this.canonical=null};ye.prototype.id=function(){return this.feature&&\"id\"in this.feature?this.feature.id:null},ye.prototype.geometryType=function(){return this.feature?\"number\"==typeof this.feature.type?ve[this.feature.type]:this.feature.type:null},ye.prototype.geometry=function(){return this.feature&&\"geometry\"in this.feature?this.feature.geometry:null},ye.prototype.canonicalID=function(){return this.canonical},ye.prototype.properties=function(){return this.feature&&this.feature.properties||{}},ye.prototype.parseColor=function(t){var e=this._parseColorCache[t];return e||(e=this._parseColorCache[t]=te.parse(t)),e};var xe=function(t,e,r,n){this.name=t,this.type=e,this._evaluate=r,this.args=n};xe.prototype.evaluate=function(t){return this._evaluate(t,this.args)},xe.prototype.eachChild=function(t){this.args.forEach(t)},xe.prototype.outputDefined=function(){return!1},xe.prototype.serialize=function(){return[this.name].concat(this.args.map((function(t){return t.serialize()})))},xe.parse=function(t,e){var r,n=t[0],i=xe.definitions[n];if(!i)return e.error('Unknown expression \"'+n+'\". If you wanted a literal array, use [\"literal\", [...]].',0);for(var a=Array.isArray(i)?i[0]:i.type,o=Array.isArray(i)?[[i[1],i[2]]]:i.overloads,s=o.filter((function(e){var r=e[0];return!Array.isArray(r)||r.length===t.length-1})),l=null,c=0,u=s;c<u.length;c+=1){var f=u[c],h=f[0],p=f[1];l=new Ue(e.registry,e.path,null,e.scope);for(var d=[],m=!1,g=1;g<t.length;g++){var v=t[g],y=Array.isArray(h)?h[g-1]:h.type,x=l.parse(v,1+d.length,y);if(!x){m=!0;break}d.push(x)}if(!m)if(Array.isArray(h)&&h.length!==d.length)l.error(\"Expected \"+h.length+\" arguments, but found \"+d.length+\" instead.\");else{for(var b=0;b<d.length;b++){var _=Array.isArray(h)?h[b]:h.type,w=d[b];l.concat(b+1).checkSubtype(_,w.type)}if(0===l.errors.length)return new xe(n,a,p,d)}}if(1===s.length)(r=e.errors).push.apply(r,l.errors);else{for(var T=(s.length?s:o).map((function(t){var e,r=t[0];return e=r,Array.isArray(e)?\"(\"+e.map(Xt).join(\", \")+\")\":\"(\"+Xt(e.type)+\"...)\"})).join(\" | \"),k=[],M=1;M<t.length;M++){var A=e.parse(t[M],1+k.length);if(!A)return null;k.push(Xt(A.type))}e.error(\"Expected arguments of type \"+T+\", but found (\"+k.join(\", \")+\") instead.\")}return null},xe.register=function(t,e){for(var r in xe.definitions=e,e)t[r]=xe};var be=function(t,e,r){this.type=Ht,this.locale=r,this.caseSensitive=t,this.diacriticSensitive=e};be.parse=function(t,e){if(2!==t.length)return e.error(\"Expected one argument.\");var r=t[1];if(\"object\"!=typeof r||Array.isArray(r))return e.error(\"Collator options argument must be an object.\");var n=e.parse(void 0!==r[\"case-sensitive\"]&&r[\"case-sensitive\"],1,jt);if(!n)return null;var i=e.parse(void 0!==r[\"diacritic-sensitive\"]&&r[\"diacritic-sensitive\"],1,jt);if(!i)return null;var a=null;return r.locale&&!(a=e.parse(r.locale,1,Nt))?null:new be(n,i,a)},be.prototype.evaluate=function(t){return new ee(this.caseSensitive.evaluate(t),this.diacriticSensitive.evaluate(t),this.locale?this.locale.evaluate(t):null)},be.prototype.eachChild=function(t){t(this.caseSensitive),t(this.diacriticSensitive),this.locale&&t(this.locale)},be.prototype.outputDefined=function(){return!1},be.prototype.serialize=function(){var t={};return t[\"case-sensitive\"]=this.caseSensitive.serialize(),t[\"diacritic-sensitive\"]=this.diacriticSensitive.serialize(),this.locale&&(t.locale=this.locale.serialize()),[\"collator\",t]};function _e(t,e){t[0]=Math.min(t[0],e[0]),t[1]=Math.min(t[1],e[1]),t[2]=Math.max(t[2],e[0]),t[3]=Math.max(t[3],e[1])}function we(t,e){return!(t[0]<=e[0])&&(!(t[2]>=e[2])&&(!(t[1]<=e[1])&&!(t[3]>=e[3])))}function Te(t,e){var r,n=(180+t[0])/360,i=(r=t[1],(180-180/Math.PI*Math.log(Math.tan(Math.PI/4+r*Math.PI/360)))/360),a=Math.pow(2,e.z);return[Math.round(n*a*8192),Math.round(i*a*8192)]}function ke(t,e,r){return e[1]>t[1]!=r[1]>t[1]&&t[0]<(r[0]-e[0])*(t[1]-e[1])/(r[1]-e[1])+e[0]}function Me(t,e){for(var r,n,i,a,o,s,l,c=!1,u=0,f=e.length;u<f;u++)for(var h=e[u],p=0,d=h.length;p<d-1;p++){if(r=t,n=h[p],i=h[p+1],a=void 0,o=void 0,s=void 0,l=void 0,a=r[0]-n[0],o=r[1]-n[1],s=r[0]-i[0],l=r[1]-i[1],a*l-s*o==0&&a*s<=0&&o*l<=0)return!1;ke(t,h[p],h[p+1])&&(c=!c)}return c}function Ae(t,e){for(var r=0;r<e.length;r++)if(Me(t,e[r]))return!0;return!1}function Se(t,e,r,n){var i=t[0]-r[0],a=t[1]-r[1],o=e[0]-r[0],s=e[1]-r[1],l=n[0]-r[0],c=n[1]-r[1],u=i*c-l*a,f=o*c-l*s;return u>0&&f<0||u<0&&f>0}function Ee(t,e,r){for(var n=0,i=r;n<i.length;n+=1)for(var a=i[n],o=0;o<a.length-1;++o)if(s=t,l=e,c=a[o],u=a[o+1],f=void 0,h=void 0,p=void 0,d=void 0,p=[l[0]-s[0],l[1]-s[1]],d=[u[0]-c[0],u[1]-c[1]],0!=(f=d)[0]*(h=p)[1]-f[1]*h[0]&&Se(s,l,c,u)&&Se(c,u,s,l))return!0;var s,l,c,u,f,h,p,d;return!1}function Le(t,e){for(var r=0;r<t.length;++r)if(!Me(t[r],e))return!1;for(var n=0;n<t.length-1;++n)if(Ee(t[n],t[n+1],e))return!1;return!0}function Ce(t,e){for(var r=0;r<e.length;r++)if(Le(t,e[r]))return!0;return!1}function Pe(t,e,r){for(var n=[],i=0;i<t.length;i++){for(var a=[],o=0;o<t[i].length;o++){var s=Te(t[i][o],r);_e(e,s),a.push(s)}n.push(a)}return n}function Ie(t,e,r){for(var n=[],i=0;i<t.length;i++){var a=Pe(t[i],e,r);n.push(a)}return n}function Oe(t,e,r,n){if(t[0]<r[0]||t[0]>r[2]){var i=.5*n,a=t[0]-r[0]>i?-n:r[0]-t[0]>i?n:0;0===a&&(a=t[0]-r[2]>i?-n:r[2]-t[0]>i?n:0),t[0]+=a}_e(e,t)}function ze(t,e,r,n){for(var i=8192*Math.pow(2,n.z),a=[8192*n.x,8192*n.y],o=[],s=0,l=t;s<l.length;s+=1)for(var c=0,u=l[s];c<u.length;c+=1){var f=u[c],h=[f.x+a[0],f.y+a[1]];Oe(h,e,r,i),o.push(h)}return o}function De(t,e,r,n){for(var i,a=8192*Math.pow(2,n.z),o=[8192*n.x,8192*n.y],s=[],l=0,c=t;l<c.length;l+=1){for(var u=[],f=0,h=c[l];f<h.length;f+=1){var p=h[f],d=[p.x+o[0],p.y+o[1]];_e(e,d),u.push(d)}s.push(u)}if(e[2]-e[0]<=a/2){(i=e)[0]=i[1]=1/0,i[2]=i[3]=-1/0;for(var m=0,g=s;m<g.length;m+=1)for(var v=0,y=g[m];v<y.length;v+=1){Oe(y[v],e,r,a)}}return s}var Re=function(t,e){this.type=jt,this.geojson=t,this.geometries=e};function Fe(t){if(t instanceof xe){if(\"get\"===t.name&&1===t.args.length)return!1;if(\"feature-state\"===t.name)return!1;if(\"has\"===t.name&&1===t.args.length)return!1;if(\"properties\"===t.name||\"geometry-type\"===t.name||\"id\"===t.name)return!1;if(/^filter-/.test(t.name))return!1}if(t instanceof Re)return!1;var e=!0;return t.eachChild((function(t){e&&!Fe(t)&&(e=!1)})),e}function Be(t){if(t instanceof xe&&\"feature-state\"===t.name)return!1;var e=!0;return t.eachChild((function(t){e&&!Be(t)&&(e=!1)})),e}function Ne(t,e){if(t instanceof xe&&e.indexOf(t.name)>=0)return!1;var r=!0;return t.eachChild((function(t){r&&!Ne(t,e)&&(r=!1)})),r}Re.parse=function(t,e){if(2!==t.length)return e.error(\"'within' expression requires exactly one argument, but found \"+(t.length-1)+\" instead.\");if(oe(t[1])){var r=t[1];if(\"FeatureCollection\"===r.type)for(var n=0;n<r.features.length;++n){var i=r.features[n].geometry.type;if(\"Polygon\"===i||\"MultiPolygon\"===i)return new Re(r,r.features[n].geometry)}else if(\"Feature\"===r.type){var a=r.geometry.type;if(\"Polygon\"===a||\"MultiPolygon\"===a)return new Re(r,r.geometry)}else if(\"Polygon\"===r.type||\"MultiPolygon\"===r.type)return new Re(r,r)}return e.error(\"'within' expression requires valid geojson object that contains polygon geometry type.\")},Re.prototype.evaluate=function(t){if(null!=t.geometry()&&null!=t.canonicalID()){if(\"Point\"===t.geometryType())return function(t,e){var r=[1/0,1/0,-1/0,-1/0],n=[1/0,1/0,-1/0,-1/0],i=t.canonicalID();if(\"Polygon\"===e.type){var a=Pe(e.coordinates,n,i),o=ze(t.geometry(),r,n,i);if(!we(r,n))return!1;for(var s=0,l=o;s<l.length;s+=1){if(!Me(l[s],a))return!1}}if(\"MultiPolygon\"===e.type){var c=Ie(e.coordinates,n,i),u=ze(t.geometry(),r,n,i);if(!we(r,n))return!1;for(var f=0,h=u;f<h.length;f+=1){if(!Ae(h[f],c))return!1}}return!0}(t,this.geometries);if(\"LineString\"===t.geometryType())return function(t,e){var r=[1/0,1/0,-1/0,-1/0],n=[1/0,1/0,-1/0,-1/0],i=t.canonicalID();if(\"Polygon\"===e.type){var a=Pe(e.coordinates,n,i),o=De(t.geometry(),r,n,i);if(!we(r,n))return!1;for(var s=0,l=o;s<l.length;s+=1){if(!Le(l[s],a))return!1}}if(\"MultiPolygon\"===e.type){var c=Ie(e.coordinates,n,i),u=De(t.geometry(),r,n,i);if(!we(r,n))return!1;for(var f=0,h=u;f<h.length;f+=1){if(!Ce(h[f],c))return!1}}return!0}(t,this.geometries)}return!1},Re.prototype.eachChild=function(){},Re.prototype.outputDefined=function(){return!0},Re.prototype.serialize=function(){return[\"within\",this.geojson]};var je=function(t,e){this.type=e.type,this.name=t,this.boundExpression=e};je.parse=function(t,e){if(2!==t.length||\"string\"!=typeof t[1])return e.error(\"'var' expression requires exactly one string literal argument.\");var r=t[1];return e.scope.has(r)?new je(r,e.scope.get(r)):e.error('Unknown variable \"'+r+'\". Make sure \"'+r+'\" has been bound in an enclosing \"let\" expression before using it.',1)},je.prototype.evaluate=function(t){return this.boundExpression.evaluate(t)},je.prototype.eachChild=function(){},je.prototype.outputDefined=function(){return!1},je.prototype.serialize=function(){return[\"var\",this.name]};var Ue=function(t,e,r,n,i){void 0===e&&(e=[]),void 0===n&&(n=new Rt),void 0===i&&(i=[]),this.registry=t,this.path=e,this.key=e.map((function(t){return\"[\"+t+\"]\"})).join(\"\"),this.scope=n,this.errors=i,this.expectedType=r};function Ve(t,e){for(var r,n,i=t.length-1,a=0,o=i,s=0;a<=o;)if(r=t[s=Math.floor((a+o)/2)],n=t[s+1],r<=e){if(s===i||e<n)return s;a=s+1}else{if(!(r>e))throw new ue(\"Input is not a number.\");o=s-1}return 0}Ue.prototype.parse=function(t,e,r,n,i){return void 0===i&&(i={}),e?this.concat(e,r,n)._parse(t,i):this._parse(t,i)},Ue.prototype._parse=function(t,e){function r(t,e,r){return\"assert\"===r?new he(e,[t]):\"coerce\"===r?new ge(e,[t]):t}if(null!==t&&\"string\"!=typeof t&&\"boolean\"!=typeof t&&\"number\"!=typeof t||(t=[\"literal\",t]),Array.isArray(t)){if(0===t.length)return this.error('Expected an array with at least one element. If you wanted a literal array, use [\"literal\", []].');var n=t[0];if(\"string\"!=typeof n)return this.error(\"Expression name must be a string, but found \"+typeof n+' instead. If you wanted a literal array, use [\"literal\", [...]].',0),null;var i=this.registry[n];if(i){var a=i.parse(t,this);if(!a)return null;if(this.expectedType){var o=this.expectedType,s=a.type;if(\"string\"!==o.kind&&\"number\"!==o.kind&&\"boolean\"!==o.kind&&\"object\"!==o.kind&&\"array\"!==o.kind||\"value\"!==s.kind)if(\"color\"!==o.kind&&\"formatted\"!==o.kind&&\"resolvedImage\"!==o.kind||\"value\"!==s.kind&&\"string\"!==s.kind){if(this.checkSubtype(o,s))return null}else a=r(a,o,e.typeAnnotation||\"coerce\");else a=r(a,o,e.typeAnnotation||\"assert\")}if(!(a instanceof ce)&&\"resolvedImage\"!==a.type.kind&&function t(e){if(e instanceof je)return t(e.boundExpression);if(e instanceof xe&&\"error\"===e.name)return!1;if(e instanceof be)return!1;if(e instanceof Re)return!1;var r=e instanceof ge||e instanceof he,n=!0;if(e.eachChild((function(e){n=r?n&&t(e):n&&e instanceof ce})),!n)return!1;return Fe(e)&&Ne(e,[\"zoom\",\"heatmap-density\",\"line-progress\",\"accumulated\",\"is-supported-script\"])}(a)){var l=new ye;try{a=new ce(a.type,a.evaluate(l))}catch(t){return this.error(t.message),null}}return a}return this.error('Unknown expression \"'+n+'\". If you wanted a literal array, use [\"literal\", [...]].',0)}return void 0===t?this.error(\"'undefined' value invalid. Use null instead.\"):\"object\"==typeof t?this.error('Bare objects invalid. Use [\"literal\", {...}] instead.'):this.error(\"Expected an array, but found \"+typeof t+\" instead.\")},Ue.prototype.concat=function(t,e,r){var n=\"number\"==typeof t?this.path.concat(t):this.path,i=r?this.scope.concat(r):this.scope;return new Ue(this.registry,n,e||null,i,this.errors)},Ue.prototype.error=function(t){for(var e=[],r=arguments.length-1;r-- >0;)e[r]=arguments[r+1];var n=\"\"+this.key+e.map((function(t){return\"[\"+t+\"]\"})).join(\"\");this.errors.push(new Dt(n,t))},Ue.prototype.checkSubtype=function(t,e){var r=Jt(t,e);return r&&this.error(r),r};var qe=function(t,e,r){this.type=t,this.input=e,this.labels=[],this.outputs=[];for(var n=0,i=r;n<i.length;n+=1){var a=i[n],o=a[0],s=a[1];this.labels.push(o),this.outputs.push(s)}};function He(t,e,r){return t*(1-r)+e*r}qe.parse=function(t,e){if(t.length-1<4)return e.error(\"Expected at least 4 arguments, but found only \"+(t.length-1)+\".\");if((t.length-1)%2!=0)return e.error(\"Expected an even number of arguments.\");var r=e.parse(t[1],1,Bt);if(!r)return null;var n=[],i=null;e.expectedType&&\"value\"!==e.expectedType.kind&&(i=e.expectedType);for(var a=1;a<t.length;a+=2){var o=1===a?-1/0:t[a],s=t[a+1],l=a,c=a+1;if(\"number\"!=typeof o)return e.error('Input/output pairs for \"step\" expressions must be defined using literal numeric values (not computed expressions) for the input values.',l);if(n.length&&n[n.length-1][0]>=o)return e.error('Input/output pairs for \"step\" expressions must be arranged with input values in strictly ascending order.',l);var u=e.parse(s,c,i);if(!u)return null;i=i||u.type,n.push([o,u])}return new qe(i,r,n)},qe.prototype.evaluate=function(t){var e=this.labels,r=this.outputs;if(1===e.length)return r[0].evaluate(t);var n=this.input.evaluate(t);if(n<=e[0])return r[0].evaluate(t);var i=e.length;return n>=e[i-1]?r[i-1].evaluate(t):r[Ve(e,n)].evaluate(t)},qe.prototype.eachChild=function(t){t(this.input);for(var e=0,r=this.outputs;e<r.length;e+=1){t(r[e])}},qe.prototype.outputDefined=function(){return this.outputs.every((function(t){return t.outputDefined()}))},qe.prototype.serialize=function(){for(var t=[\"step\",this.input.serialize()],e=0;e<this.labels.length;e++)e>0&&t.push(this.labels[e]),t.push(this.outputs[e].serialize());return t};var Ge=Object.freeze({__proto__:null,number:He,color:function(t,e,r){return new te(He(t.r,e.r,r),He(t.g,e.g,r),He(t.b,e.b,r),He(t.a,e.a,r))},array:function(t,e,r){return t.map((function(t,n){return He(t,e[n],r)}))}}),Ye=6/29,We=3*Ye*Ye,Xe=Math.PI/180,Ze=180/Math.PI;function Je(t){return t>.008856451679035631?Math.pow(t,1/3):t/We+4/29}function Ke(t){return t>Ye?t*t*t:We*(t-4/29)}function Qe(t){return 255*(t<=.0031308?12.92*t:1.055*Math.pow(t,1/2.4)-.055)}function $e(t){return(t/=255)<=.04045?t/12.92:Math.pow((t+.055)/1.055,2.4)}function tr(t){var e=$e(t.r),r=$e(t.g),n=$e(t.b),i=Je((.4124564*e+.3575761*r+.1804375*n)/.95047),a=Je((.2126729*e+.7151522*r+.072175*n)/1);return{l:116*a-16,a:500*(i-a),b:200*(a-Je((.0193339*e+.119192*r+.9503041*n)/1.08883)),alpha:t.a}}function er(t){var e=(t.l+16)/116,r=isNaN(t.a)?e:e+t.a/500,n=isNaN(t.b)?e:e-t.b/200;return e=1*Ke(e),r=.95047*Ke(r),n=1.08883*Ke(n),new te(Qe(3.2404542*r-1.5371385*e-.4985314*n),Qe(-.969266*r+1.8760108*e+.041556*n),Qe(.0556434*r-.2040259*e+1.0572252*n),t.alpha)}function rr(t,e,r){var n=e-t;return t+r*(n>180||n<-180?n-360*Math.round(n/360):n)}var nr={forward:tr,reverse:er,interpolate:function(t,e,r){return{l:He(t.l,e.l,r),a:He(t.a,e.a,r),b:He(t.b,e.b,r),alpha:He(t.alpha,e.alpha,r)}}},ir={forward:function(t){var e=tr(t),r=e.l,n=e.a,i=e.b,a=Math.atan2(i,n)*Ze;return{h:a<0?a+360:a,c:Math.sqrt(n*n+i*i),l:r,alpha:t.a}},reverse:function(t){var e=t.h*Xe,r=t.c;return er({l:t.l,a:Math.cos(e)*r,b:Math.sin(e)*r,alpha:t.alpha})},interpolate:function(t,e,r){return{h:rr(t.h,e.h,r),c:He(t.c,e.c,r),l:He(t.l,e.l,r),alpha:He(t.alpha,e.alpha,r)}}},ar=Object.freeze({__proto__:null,lab:nr,hcl:ir}),or=function(t,e,r,n,i){this.type=t,this.operator=e,this.interpolation=r,this.input=n,this.labels=[],this.outputs=[];for(var a=0,o=i;a<o.length;a+=1){var s=o[a],l=s[0],c=s[1];this.labels.push(l),this.outputs.push(c)}};function sr(t,e,r,n){var i=n-r,a=t-r;return 0===i?0:1===e?a/i:(Math.pow(e,a)-1)/(Math.pow(e,i)-1)}or.interpolationFactor=function(t,e,n,i){var a=0;if(\"exponential\"===t.name)a=sr(e,t.base,n,i);else if(\"linear\"===t.name)a=sr(e,1,n,i);else if(\"cubic-bezier\"===t.name){var o=t.controlPoints;a=new r(o[0],o[1],o[2],o[3]).solve(sr(e,1,n,i))}return a},or.parse=function(t,e){var r=t[0],n=t[1],i=t[2],a=t.slice(3);if(!Array.isArray(n)||0===n.length)return e.error(\"Expected an interpolation type expression.\",1);if(\"linear\"===n[0])n={name:\"linear\"};else if(\"exponential\"===n[0]){var o=n[1];if(\"number\"!=typeof o)return e.error(\"Exponential interpolation requires a numeric base.\",1,1);n={name:\"exponential\",base:o}}else{if(\"cubic-bezier\"!==n[0])return e.error(\"Unknown interpolation type \"+String(n[0]),1,0);var s=n.slice(1);if(4!==s.length||s.some((function(t){return\"number\"!=typeof t||t<0||t>1})))return e.error(\"Cubic bezier interpolation requires four numeric arguments with values between 0 and 1.\",1);n={name:\"cubic-bezier\",controlPoints:s}}if(t.length-1<4)return e.error(\"Expected at least 4 arguments, but found only \"+(t.length-1)+\".\");if((t.length-1)%2!=0)return e.error(\"Expected an even number of arguments.\");if(!(i=e.parse(i,2,Bt)))return null;var l=[],c=null;\"interpolate-hcl\"===r||\"interpolate-lab\"===r?c=Ut:e.expectedType&&\"value\"!==e.expectedType.kind&&(c=e.expectedType);for(var u=0;u<a.length;u+=2){var f=a[u],h=a[u+1],p=u+3,d=u+4;if(\"number\"!=typeof f)return e.error('Input/output pairs for \"interpolate\" expressions must be defined using literal numeric values (not computed expressions) for the input values.',p);if(l.length&&l[l.length-1][0]>=f)return e.error('Input/output pairs for \"interpolate\" expressions must be arranged with input values in strictly ascending order.',p);var m=e.parse(h,d,c);if(!m)return null;c=c||m.type,l.push([f,m])}return\"number\"===c.kind||\"color\"===c.kind||\"array\"===c.kind&&\"number\"===c.itemType.kind&&\"number\"==typeof c.N?new or(c,r,n,i,l):e.error(\"Type \"+Xt(c)+\" is not interpolatable.\")},or.prototype.evaluate=function(t){var e=this.labels,r=this.outputs;if(1===e.length)return r[0].evaluate(t);var n=this.input.evaluate(t);if(n<=e[0])return r[0].evaluate(t);var i=e.length;if(n>=e[i-1])return r[i-1].evaluate(t);var a=Ve(e,n),o=e[a],s=e[a+1],l=or.interpolationFactor(this.interpolation,n,o,s),c=r[a].evaluate(t),u=r[a+1].evaluate(t);return\"interpolate\"===this.operator?Ge[this.type.kind.toLowerCase()](c,u,l):\"interpolate-hcl\"===this.operator?ir.reverse(ir.interpolate(ir.forward(c),ir.forward(u),l)):nr.reverse(nr.interpolate(nr.forward(c),nr.forward(u),l))},or.prototype.eachChild=function(t){t(this.input);for(var e=0,r=this.outputs;e<r.length;e+=1){t(r[e])}},or.prototype.outputDefined=function(){return this.outputs.every((function(t){return t.outputDefined()}))},or.prototype.serialize=function(){var t;t=\"linear\"===this.interpolation.name?[\"linear\"]:\"exponential\"===this.interpolation.name?1===this.interpolation.base?[\"linear\"]:[\"exponential\",this.interpolation.base]:[\"cubic-bezier\"].concat(this.interpolation.controlPoints);for(var e=[this.operator,t,this.input.serialize()],r=0;r<this.labels.length;r++)e.push(this.labels[r],this.outputs[r].serialize());return e};var lr=function(t,e){this.type=t,this.args=e};lr.parse=function(t,e){if(t.length<2)return e.error(\"Expectected at least one argument.\");var r=null,n=e.expectedType;n&&\"value\"!==n.kind&&(r=n);for(var i=[],a=0,o=t.slice(1);a<o.length;a+=1){var s=o[a],l=e.parse(s,1+i.length,r,void 0,{typeAnnotation:\"omit\"});if(!l)return null;r=r||l.type,i.push(l)}var c=n&&i.some((function(t){return Jt(n,t.type)}));return new lr(c?qt:r,i)},lr.prototype.evaluate=function(t){for(var e,r=null,n=0,i=0,a=this.args;i<a.length;i+=1){if(n++,(r=a[i].evaluate(t))&&r instanceof ie&&!r.available&&(e||(e=r.name),r=null,n===this.args.length&&(r=e)),null!==r)break}return r},lr.prototype.eachChild=function(t){this.args.forEach(t)},lr.prototype.outputDefined=function(){return this.args.every((function(t){return t.outputDefined()}))},lr.prototype.serialize=function(){var t=[\"coalesce\"];return this.eachChild((function(e){t.push(e.serialize())})),t};var cr=function(t,e){this.type=e.type,this.bindings=[].concat(t),this.result=e};cr.prototype.evaluate=function(t){return this.result.evaluate(t)},cr.prototype.eachChild=function(t){for(var e=0,r=this.bindings;e<r.length;e+=1){t(r[e][1])}t(this.result)},cr.parse=function(t,e){if(t.length<4)return e.error(\"Expected at least 3 arguments, but found \"+(t.length-1)+\" instead.\");for(var r=[],n=1;n<t.length-1;n+=2){var i=t[n];if(\"string\"!=typeof i)return e.error(\"Expected string, but found \"+typeof i+\" instead.\",n);if(/[^a-zA-Z0-9_]/.test(i))return e.error(\"Variable names must contain only alphanumeric characters or '_'.\",n);var a=e.parse(t[n+1],n+1);if(!a)return null;r.push([i,a])}var o=e.parse(t[t.length-1],t.length-1,e.expectedType,r);return o?new cr(r,o):null},cr.prototype.outputDefined=function(){return this.result.outputDefined()},cr.prototype.serialize=function(){for(var t=[\"let\"],e=0,r=this.bindings;e<r.length;e+=1){var n=r[e],i=n[0],a=n[1];t.push(i,a.serialize())}return t.push(this.result.serialize()),t};var ur=function(t,e,r){this.type=t,this.index=e,this.input=r};ur.parse=function(t,e){if(3!==t.length)return e.error(\"Expected 2 arguments, but found \"+(t.length-1)+\" instead.\");var r=e.parse(t[1],1,Bt),n=e.parse(t[2],2,Wt(e.expectedType||qt));if(!r||!n)return null;var i=n.type;return new ur(i.itemType,r,n)},ur.prototype.evaluate=function(t){var e=this.index.evaluate(t),r=this.input.evaluate(t);if(e<0)throw new ue(\"Array index out of bounds: \"+e+\" < 0.\");if(e>=r.length)throw new ue(\"Array index out of bounds: \"+e+\" > \"+(r.length-1)+\".\");if(e!==Math.floor(e))throw new ue(\"Array index must be an integer, but found \"+e+\" instead.\");return r[e]},ur.prototype.eachChild=function(t){t(this.index),t(this.input)},ur.prototype.outputDefined=function(){return!1},ur.prototype.serialize=function(){return[\"at\",this.index.serialize(),this.input.serialize()]};var fr=function(t,e){this.type=jt,this.needle=t,this.haystack=e};fr.parse=function(t,e){if(3!==t.length)return e.error(\"Expected 2 arguments, but found \"+(t.length-1)+\" instead.\");var r=e.parse(t[1],1,qt),n=e.parse(t[2],2,qt);return r&&n?Kt(r.type,[jt,Nt,Bt,Ft,qt])?new fr(r,n):e.error(\"Expected first argument to be of type boolean, string, number or null, but found \"+Xt(r.type)+\" instead\"):null},fr.prototype.evaluate=function(t){var e=this.needle.evaluate(t),r=this.haystack.evaluate(t);if(!r)return!1;if(!Qt(e,[\"boolean\",\"string\",\"number\",\"null\"]))throw new ue(\"Expected first argument to be of type boolean, string, number or null, but found \"+Xt(se(e))+\" instead.\");if(!Qt(r,[\"string\",\"array\"]))throw new ue(\"Expected second argument to be of type array or string, but found \"+Xt(se(r))+\" instead.\");return r.indexOf(e)>=0},fr.prototype.eachChild=function(t){t(this.needle),t(this.haystack)},fr.prototype.outputDefined=function(){return!0},fr.prototype.serialize=function(){return[\"in\",this.needle.serialize(),this.haystack.serialize()]};var hr=function(t,e,r){this.type=Bt,this.needle=t,this.haystack=e,this.fromIndex=r};hr.parse=function(t,e){if(t.length<=2||t.length>=5)return e.error(\"Expected 3 or 4 arguments, but found \"+(t.length-1)+\" instead.\");var r=e.parse(t[1],1,qt),n=e.parse(t[2],2,qt);if(!r||!n)return null;if(!Kt(r.type,[jt,Nt,Bt,Ft,qt]))return e.error(\"Expected first argument to be of type boolean, string, number or null, but found \"+Xt(r.type)+\" instead\");if(4===t.length){var i=e.parse(t[3],3,Bt);return i?new hr(r,n,i):null}return new hr(r,n)},hr.prototype.evaluate=function(t){var e=this.needle.evaluate(t),r=this.haystack.evaluate(t);if(!Qt(e,[\"boolean\",\"string\",\"number\",\"null\"]))throw new ue(\"Expected first argument to be of type boolean, string, number or null, but found \"+Xt(se(e))+\" instead.\");if(!Qt(r,[\"string\",\"array\"]))throw new ue(\"Expected second argument to be of type array or string, but found \"+Xt(se(r))+\" instead.\");if(this.fromIndex){var n=this.fromIndex.evaluate(t);return r.indexOf(e,n)}return r.indexOf(e)},hr.prototype.eachChild=function(t){t(this.needle),t(this.haystack),this.fromIndex&&t(this.fromIndex)},hr.prototype.outputDefined=function(){return!1},hr.prototype.serialize=function(){if(null!=this.fromIndex&&void 0!==this.fromIndex){var t=this.fromIndex.serialize();return[\"index-of\",this.needle.serialize(),this.haystack.serialize(),t]}return[\"index-of\",this.needle.serialize(),this.haystack.serialize()]};var pr=function(t,e,r,n,i,a){this.inputType=t,this.type=e,this.input=r,this.cases=n,this.outputs=i,this.otherwise=a};pr.parse=function(t,e){if(t.length<5)return e.error(\"Expected at least 4 arguments, but found only \"+(t.length-1)+\".\");if(t.length%2!=1)return e.error(\"Expected an even number of arguments.\");var r,n;e.expectedType&&\"value\"!==e.expectedType.kind&&(n=e.expectedType);for(var i={},a=[],o=2;o<t.length-1;o+=2){var s=t[o],l=t[o+1];Array.isArray(s)||(s=[s]);var c=e.concat(o);if(0===s.length)return c.error(\"Expected at least one branch label.\");for(var u=0,f=s;u<f.length;u+=1){var h=f[u];if(\"number\"!=typeof h&&\"string\"!=typeof h)return c.error(\"Branch labels must be numbers or strings.\");if(\"number\"==typeof h&&Math.abs(h)>Number.MAX_SAFE_INTEGER)return c.error(\"Branch labels must be integers no larger than \"+Number.MAX_SAFE_INTEGER+\".\");if(\"number\"==typeof h&&Math.floor(h)!==h)return c.error(\"Numeric branch labels must be integer values.\");if(r){if(c.checkSubtype(r,se(h)))return null}else r=se(h);if(void 0!==i[String(h)])return c.error(\"Branch labels must be unique.\");i[String(h)]=a.length}var p=e.parse(l,o,n);if(!p)return null;n=n||p.type,a.push(p)}var d=e.parse(t[1],1,qt);if(!d)return null;var m=e.parse(t[t.length-1],t.length-1,n);return m?\"value\"!==d.type.kind&&e.concat(1).checkSubtype(r,d.type)?null:new pr(r,n,d,i,a,m):null},pr.prototype.evaluate=function(t){var e=this.input.evaluate(t);return(se(e)===this.inputType&&this.outputs[this.cases[e]]||this.otherwise).evaluate(t)},pr.prototype.eachChild=function(t){t(this.input),this.outputs.forEach(t),t(this.otherwise)},pr.prototype.outputDefined=function(){return this.outputs.every((function(t){return t.outputDefined()}))&&this.otherwise.outputDefined()},pr.prototype.serialize=function(){for(var t=this,e=[\"match\",this.input.serialize()],r=[],n={},i=0,a=Object.keys(this.cases).sort();i<a.length;i+=1){var o=a[i];void 0===(f=n[this.cases[o]])?(n[this.cases[o]]=r.length,r.push([this.cases[o],[o]])):r[f][1].push(o)}for(var s=function(e){return\"number\"===t.inputType.kind?Number(e):e},l=0,c=r;l<c.length;l+=1){var u=c[l],f=u[0],h=u[1];1===h.length?e.push(s(h[0])):e.push(h.map(s)),e.push(this.outputs[outputIndex$1].serialize())}return e.push(this.otherwise.serialize()),e};var dr=function(t,e,r){this.type=t,this.branches=e,this.otherwise=r};dr.parse=function(t,e){if(t.length<4)return e.error(\"Expected at least 3 arguments, but found only \"+(t.length-1)+\".\");if(t.length%2!=0)return e.error(\"Expected an odd number of arguments.\");var r;e.expectedType&&\"value\"!==e.expectedType.kind&&(r=e.expectedType);for(var n=[],i=1;i<t.length-1;i+=2){var a=e.parse(t[i],i,jt);if(!a)return null;var o=e.parse(t[i+1],i+1,r);if(!o)return null;n.push([a,o]),r=r||o.type}var s=e.parse(t[t.length-1],t.length-1,r);return s?new dr(r,n,s):null},dr.prototype.evaluate=function(t){for(var e=0,r=this.branches;e<r.length;e+=1){var n=r[e],i=n[0],a=n[1];if(i.evaluate(t))return a.evaluate(t)}return this.otherwise.evaluate(t)},dr.prototype.eachChild=function(t){for(var e=0,r=this.branches;e<r.length;e+=1){var n=r[e],i=n[0],a=n[1];t(i),t(a)}t(this.otherwise)},dr.prototype.outputDefined=function(){return this.branches.every((function(t){t[0];return t[1].outputDefined()}))&&this.otherwise.outputDefined()},dr.prototype.serialize=function(){var t=[\"case\"];return this.eachChild((function(e){t.push(e.serialize())})),t};var mr=function(t,e,r,n){this.type=t,this.input=e,this.beginIndex=r,this.endIndex=n};function gr(t,e){return\"==\"===t||\"!=\"===t?\"boolean\"===e.kind||\"string\"===e.kind||\"number\"===e.kind||\"null\"===e.kind||\"value\"===e.kind:\"string\"===e.kind||\"number\"===e.kind||\"value\"===e.kind}function vr(t,e,r,n){return 0===n.compare(e,r)}function yr(t,e,r){var n=\"==\"!==t&&\"!=\"!==t;return function(){function i(t,e,r){this.type=jt,this.lhs=t,this.rhs=e,this.collator=r,this.hasUntypedArgument=\"value\"===t.type.kind||\"value\"===e.type.kind}return i.parse=function(t,e){if(3!==t.length&&4!==t.length)return e.error(\"Expected two or three arguments.\");var r=t[0],a=e.parse(t[1],1,qt);if(!a)return null;if(!gr(r,a.type))return e.concat(1).error('\"'+r+\"\\\" comparisons are not supported for type '\"+Xt(a.type)+\"'.\");var o=e.parse(t[2],2,qt);if(!o)return null;if(!gr(r,o.type))return e.concat(2).error('\"'+r+\"\\\" comparisons are not supported for type '\"+Xt(o.type)+\"'.\");if(a.type.kind!==o.type.kind&&\"value\"!==a.type.kind&&\"value\"!==o.type.kind)return e.error(\"Cannot compare types '\"+Xt(a.type)+\"' and '\"+Xt(o.type)+\"'.\");n&&(\"value\"===a.type.kind&&\"value\"!==o.type.kind?a=new he(o.type,[a]):\"value\"!==a.type.kind&&\"value\"===o.type.kind&&(o=new he(a.type,[o])));var s=null;if(4===t.length){if(\"string\"!==a.type.kind&&\"string\"!==o.type.kind&&\"value\"!==a.type.kind&&\"value\"!==o.type.kind)return e.error(\"Cannot use collator to compare non-string types.\");if(!(s=e.parse(t[3],3,Ht)))return null}return new i(a,o,s)},i.prototype.evaluate=function(i){var a=this.lhs.evaluate(i),o=this.rhs.evaluate(i);if(n&&this.hasUntypedArgument){var s=se(a),l=se(o);if(s.kind!==l.kind||\"string\"!==s.kind&&\"number\"!==s.kind)throw new ue('Expected arguments for \"'+t+'\" to be (string, string) or (number, number), but found ('+s.kind+\", \"+l.kind+\") instead.\")}if(this.collator&&!n&&this.hasUntypedArgument){var c=se(a),u=se(o);if(\"string\"!==c.kind||\"string\"!==u.kind)return e(i,a,o)}return this.collator?r(i,a,o,this.collator.evaluate(i)):e(i,a,o)},i.prototype.eachChild=function(t){t(this.lhs),t(this.rhs),this.collator&&t(this.collator)},i.prototype.outputDefined=function(){return!0},i.prototype.serialize=function(){var e=[t];return this.eachChild((function(t){e.push(t.serialize())})),e},i}()}mr.parse=function(t,e){if(t.length<=2||t.length>=5)return e.error(\"Expected 3 or 4 arguments, but found \"+(t.length-1)+\" instead.\");var r=e.parse(t[1],1,qt),n=e.parse(t[2],2,Bt);if(!r||!n)return null;if(!Kt(r.type,[Wt(qt),Nt,qt]))return e.error(\"Expected first argument to be of type array or string, but found \"+Xt(r.type)+\" instead\");if(4===t.length){var i=e.parse(t[3],3,Bt);return i?new mr(r.type,r,n,i):null}return new mr(r.type,r,n)},mr.prototype.evaluate=function(t){var e=this.input.evaluate(t),r=this.beginIndex.evaluate(t);if(!Qt(e,[\"string\",\"array\"]))throw new ue(\"Expected first argument to be of type array or string, but found \"+Xt(se(e))+\" instead.\");if(this.endIndex){var n=this.endIndex.evaluate(t);return e.slice(r,n)}return e.slice(r)},mr.prototype.eachChild=function(t){t(this.input),t(this.beginIndex),this.endIndex&&t(this.endIndex)},mr.prototype.outputDefined=function(){return!1},mr.prototype.serialize=function(){if(null!=this.endIndex&&void 0!==this.endIndex){var t=this.endIndex.serialize();return[\"slice\",this.input.serialize(),this.beginIndex.serialize(),t]}return[\"slice\",this.input.serialize(),this.beginIndex.serialize()]};var xr=yr(\"==\",(function(t,e,r){return e===r}),vr),br=yr(\"!=\",(function(t,e,r){return e!==r}),(function(t,e,r,n){return!vr(0,e,r,n)})),_r=yr(\"<\",(function(t,e,r){return e<r}),(function(t,e,r,n){return n.compare(e,r)<0})),wr=yr(\">\",(function(t,e,r){return e>r}),(function(t,e,r,n){return n.compare(e,r)>0})),Tr=yr(\"<=\",(function(t,e,r){return e<=r}),(function(t,e,r,n){return n.compare(e,r)<=0})),kr=yr(\">=\",(function(t,e,r){return e>=r}),(function(t,e,r,n){return n.compare(e,r)>=0})),Mr=function(t,e,r,n,i){this.type=Nt,this.number=t,this.locale=e,this.currency=r,this.minFractionDigits=n,this.maxFractionDigits=i};Mr.parse=function(t,e){if(3!==t.length)return e.error(\"Expected two arguments.\");var r=e.parse(t[1],1,Bt);if(!r)return null;var n=t[2];if(\"object\"!=typeof n||Array.isArray(n))return e.error(\"NumberFormat options argument must be an object.\");var i=null;if(n.locale&&!(i=e.parse(n.locale,1,Nt)))return null;var a=null;if(n.currency&&!(a=e.parse(n.currency,1,Nt)))return null;var o=null;if(n[\"min-fraction-digits\"]&&!(o=e.parse(n[\"min-fraction-digits\"],1,Bt)))return null;var s=null;return n[\"max-fraction-digits\"]&&!(s=e.parse(n[\"max-fraction-digits\"],1,Bt))?null:new Mr(r,i,a,o,s)},Mr.prototype.evaluate=function(t){return new Intl.NumberFormat(this.locale?this.locale.evaluate(t):[],{style:this.currency?\"currency\":\"decimal\",currency:this.currency?this.currency.evaluate(t):void 0,minimumFractionDigits:this.minFractionDigits?this.minFractionDigits.evaluate(t):void 0,maximumFractionDigits:this.maxFractionDigits?this.maxFractionDigits.evaluate(t):void 0}).format(this.number.evaluate(t))},Mr.prototype.eachChild=function(t){t(this.number),this.locale&&t(this.locale),this.currency&&t(this.currency),this.minFractionDigits&&t(this.minFractionDigits),this.maxFractionDigits&&t(this.maxFractionDigits)},Mr.prototype.outputDefined=function(){return!1},Mr.prototype.serialize=function(){var t={};return this.locale&&(t.locale=this.locale.serialize()),this.currency&&(t.currency=this.currency.serialize()),this.minFractionDigits&&(t[\"min-fraction-digits\"]=this.minFractionDigits.serialize()),this.maxFractionDigits&&(t[\"max-fraction-digits\"]=this.maxFractionDigits.serialize()),[\"number-format\",this.number.serialize(),t]};var Ar=function(t){this.type=Bt,this.input=t};Ar.parse=function(t,e){if(2!==t.length)return e.error(\"Expected 1 argument, but found \"+(t.length-1)+\" instead.\");var r=e.parse(t[1],1);return r?\"array\"!==r.type.kind&&\"string\"!==r.type.kind&&\"value\"!==r.type.kind?e.error(\"Expected argument of type string or array, but found \"+Xt(r.type)+\" instead.\"):new Ar(r):null},Ar.prototype.evaluate=function(t){var e=this.input.evaluate(t);if(\"string\"==typeof e)return e.length;if(Array.isArray(e))return e.length;throw new ue(\"Expected value to be of type string or array, but found \"+Xt(se(e))+\" instead.\")},Ar.prototype.eachChild=function(t){t(this.input)},Ar.prototype.outputDefined=function(){return!1},Ar.prototype.serialize=function(){var t=[\"length\"];return this.eachChild((function(e){t.push(e.serialize())})),t};var Sr={\"==\":xr,\"!=\":br,\">\":wr,\"<\":_r,\">=\":kr,\"<=\":Tr,array:he,at:ur,boolean:he,case:dr,coalesce:lr,collator:be,format:pe,image:de,in:fr,\"index-of\":hr,interpolate:or,\"interpolate-hcl\":or,\"interpolate-lab\":or,length:Ar,let:cr,literal:ce,match:pr,number:he,\"number-format\":Mr,object:he,slice:mr,step:qe,string:he,\"to-boolean\":ge,\"to-color\":ge,\"to-number\":ge,\"to-string\":ge,var:je,within:Re};function Er(t,e){var r=e[0],n=e[1],i=e[2],a=e[3];r=r.evaluate(t),n=n.evaluate(t),i=i.evaluate(t);var o=a?a.evaluate(t):1,s=ae(r,n,i,o);if(s)throw new ue(s);return new te(r/255*o,n/255*o,i/255*o,o)}function Lr(t,e){return t in e}function Cr(t,e){var r=e[t];return void 0===r?null:r}function Pr(t){return{type:t}}function Ir(t){return{result:\"success\",value:t}}function Or(t){return{result:\"error\",value:t}}function zr(t){return\"data-driven\"===t[\"property-type\"]||\"cross-faded-data-driven\"===t[\"property-type\"]}function Dr(t){return!!t.expression&&t.expression.parameters.indexOf(\"zoom\")>-1}function Rr(t){return!!t.expression&&t.expression.interpolated}function Fr(t){return t instanceof Number?\"number\":t instanceof String?\"string\":t instanceof Boolean?\"boolean\":Array.isArray(t)?\"array\":null===t?\"null\":typeof t}function Br(t){return\"object\"==typeof t&&null!==t&&!Array.isArray(t)}function Nr(t){return t}function jr(t,e,r){return void 0!==t?t:void 0!==e?e:void 0!==r?r:void 0}function Ur(t,e,r,n,i){return jr(typeof r===i?n[r]:void 0,t.default,e.default)}function Vr(t,e,r){if(\"number\"!==Fr(r))return jr(t.default,e.default);var n=t.stops.length;if(1===n)return t.stops[0][1];if(r<=t.stops[0][0])return t.stops[0][1];if(r>=t.stops[n-1][0])return t.stops[n-1][1];var i=Ve(t.stops.map((function(t){return t[0]})),r);return t.stops[i][1]}function qr(t,e,r){var n=void 0!==t.base?t.base:1;if(\"number\"!==Fr(r))return jr(t.default,e.default);var i=t.stops.length;if(1===i)return t.stops[0][1];if(r<=t.stops[0][0])return t.stops[0][1];if(r>=t.stops[i-1][0])return t.stops[i-1][1];var a=Ve(t.stops.map((function(t){return t[0]})),r),o=function(t,e,r,n){var i=n-r,a=t-r;return 0===i?0:1===e?a/i:(Math.pow(e,a)-1)/(Math.pow(e,i)-1)}(r,n,t.stops[a][0],t.stops[a+1][0]),s=t.stops[a][1],l=t.stops[a+1][1],c=Ge[e.type]||Nr;if(t.colorSpace&&\"rgb\"!==t.colorSpace){var u=ar[t.colorSpace];c=function(t,e){return u.reverse(u.interpolate(u.forward(t),u.forward(e),o))}}return\"function\"==typeof s.evaluate?{evaluate:function(){for(var t=[],e=arguments.length;e--;)t[e]=arguments[e];var r=s.evaluate.apply(void 0,t),n=l.evaluate.apply(void 0,t);if(void 0!==r&&void 0!==n)return c(r,n,o)}}:c(s,l,o)}function Hr(t,e,r){return\"color\"===e.type?r=te.parse(r):\"formatted\"===e.type?r=ne.fromString(r.toString()):\"resolvedImage\"===e.type?r=ie.fromString(r.toString()):Fr(r)===e.type||\"enum\"===e.type&&e.values[r]||(r=void 0),jr(r,t.default,e.default)}xe.register(Sr,{error:[{kind:\"error\"},[Nt],function(t,e){var r=e[0];throw new ue(r.evaluate(t))}],typeof:[Nt,[qt],function(t,e){return Xt(se(e[0].evaluate(t)))}],\"to-rgba\":[Wt(Bt,4),[Ut],function(t,e){return e[0].evaluate(t).toArray()}],rgb:[Ut,[Bt,Bt,Bt],Er],rgba:[Ut,[Bt,Bt,Bt,Bt],Er],has:{type:jt,overloads:[[[Nt],function(t,e){return Lr(e[0].evaluate(t),t.properties())}],[[Nt,Vt],function(t,e){var r=e[0],n=e[1];return Lr(r.evaluate(t),n.evaluate(t))}]]},get:{type:qt,overloads:[[[Nt],function(t,e){return Cr(e[0].evaluate(t),t.properties())}],[[Nt,Vt],function(t,e){var r=e[0],n=e[1];return Cr(r.evaluate(t),n.evaluate(t))}]]},\"feature-state\":[qt,[Nt],function(t,e){return Cr(e[0].evaluate(t),t.featureState||{})}],properties:[Vt,[],function(t){return t.properties()}],\"geometry-type\":[Nt,[],function(t){return t.geometryType()}],id:[qt,[],function(t){return t.id()}],zoom:[Bt,[],function(t){return t.globals.zoom}],\"heatmap-density\":[Bt,[],function(t){return t.globals.heatmapDensity||0}],\"line-progress\":[Bt,[],function(t){return t.globals.lineProgress||0}],accumulated:[qt,[],function(t){return void 0===t.globals.accumulated?null:t.globals.accumulated}],\"+\":[Bt,Pr(Bt),function(t,e){for(var r=0,n=0,i=e;n<i.length;n+=1){r+=i[n].evaluate(t)}return r}],\"*\":[Bt,Pr(Bt),function(t,e){for(var r=1,n=0,i=e;n<i.length;n+=1){r*=i[n].evaluate(t)}return r}],\"-\":{type:Bt,overloads:[[[Bt,Bt],function(t,e){var r=e[0],n=e[1];return r.evaluate(t)-n.evaluate(t)}],[[Bt],function(t,e){return-e[0].evaluate(t)}]]},\"/\":[Bt,[Bt,Bt],function(t,e){var r=e[0],n=e[1];return r.evaluate(t)/n.evaluate(t)}],\"%\":[Bt,[Bt,Bt],function(t,e){var r=e[0],n=e[1];return r.evaluate(t)%n.evaluate(t)}],ln2:[Bt,[],function(){return Math.LN2}],pi:[Bt,[],function(){return Math.PI}],e:[Bt,[],function(){return Math.E}],\"^\":[Bt,[Bt,Bt],function(t,e){var r=e[0],n=e[1];return Math.pow(r.evaluate(t),n.evaluate(t))}],sqrt:[Bt,[Bt],function(t,e){var r=e[0];return Math.sqrt(r.evaluate(t))}],log10:[Bt,[Bt],function(t,e){var r=e[0];return Math.log(r.evaluate(t))/Math.LN10}],ln:[Bt,[Bt],function(t,e){var r=e[0];return Math.log(r.evaluate(t))}],log2:[Bt,[Bt],function(t,e){var r=e[0];return Math.log(r.evaluate(t))/Math.LN2}],sin:[Bt,[Bt],function(t,e){var r=e[0];return Math.sin(r.evaluate(t))}],cos:[Bt,[Bt],function(t,e){var r=e[0];return Math.cos(r.evaluate(t))}],tan:[Bt,[Bt],function(t,e){var r=e[0];return Math.tan(r.evaluate(t))}],asin:[Bt,[Bt],function(t,e){var r=e[0];return Math.asin(r.evaluate(t))}],acos:[Bt,[Bt],function(t,e){var r=e[0];return Math.acos(r.evaluate(t))}],atan:[Bt,[Bt],function(t,e){var r=e[0];return Math.atan(r.evaluate(t))}],min:[Bt,Pr(Bt),function(t,e){return Math.min.apply(Math,e.map((function(e){return e.evaluate(t)})))}],max:[Bt,Pr(Bt),function(t,e){return Math.max.apply(Math,e.map((function(e){return e.evaluate(t)})))}],abs:[Bt,[Bt],function(t,e){var r=e[0];return Math.abs(r.evaluate(t))}],round:[Bt,[Bt],function(t,e){var r=e[0].evaluate(t);return r<0?-Math.round(-r):Math.round(r)}],floor:[Bt,[Bt],function(t,e){var r=e[0];return Math.floor(r.evaluate(t))}],ceil:[Bt,[Bt],function(t,e){var r=e[0];return Math.ceil(r.evaluate(t))}],\"filter-==\":[jt,[Nt,qt],function(t,e){var r=e[0],n=e[1];return t.properties()[r.value]===n.value}],\"filter-id-==\":[jt,[qt],function(t,e){var r=e[0];return t.id()===r.value}],\"filter-type-==\":[jt,[Nt],function(t,e){var r=e[0];return t.geometryType()===r.value}],\"filter-<\":[jt,[Nt,qt],function(t,e){var r=e[0],n=e[1],i=t.properties()[r.value],a=n.value;return typeof i==typeof a&&i<a}],\"filter-id-<\":[jt,[qt],function(t,e){var r=e[0],n=t.id(),i=r.value;return typeof n==typeof i&&n<i}],\"filter->\":[jt,[Nt,qt],function(t,e){var r=e[0],n=e[1],i=t.properties()[r.value],a=n.value;return typeof i==typeof a&&i>a}],\"filter-id->\":[jt,[qt],function(t,e){var r=e[0],n=t.id(),i=r.value;return typeof n==typeof i&&n>i}],\"filter-<=\":[jt,[Nt,qt],function(t,e){var r=e[0],n=e[1],i=t.properties()[r.value],a=n.value;return typeof i==typeof a&&i<=a}],\"filter-id-<=\":[jt,[qt],function(t,e){var r=e[0],n=t.id(),i=r.value;return typeof n==typeof i&&n<=i}],\"filter->=\":[jt,[Nt,qt],function(t,e){var r=e[0],n=e[1],i=t.properties()[r.value],a=n.value;return typeof i==typeof a&&i>=a}],\"filter-id->=\":[jt,[qt],function(t,e){var r=e[0],n=t.id(),i=r.value;return typeof n==typeof i&&n>=i}],\"filter-has\":[jt,[qt],function(t,e){return e[0].value in t.properties()}],\"filter-has-id\":[jt,[],function(t){return null!==t.id()&&void 0!==t.id()}],\"filter-type-in\":[jt,[Wt(Nt)],function(t,e){return e[0].value.indexOf(t.geometryType())>=0}],\"filter-id-in\":[jt,[Wt(qt)],function(t,e){return e[0].value.indexOf(t.id())>=0}],\"filter-in-small\":[jt,[Nt,Wt(qt)],function(t,e){var r=e[0];return e[1].value.indexOf(t.properties()[r.value])>=0}],\"filter-in-large\":[jt,[Nt,Wt(qt)],function(t,e){var r=e[0],n=e[1];return function(t,e,r,n){for(;r<=n;){var i=r+n>>1;if(e[i]===t)return!0;e[i]>t?n=i-1:r=i+1}return!1}(t.properties()[r.value],n.value,0,n.value.length-1)}],all:{type:jt,overloads:[[[jt,jt],function(t,e){var r=e[0],n=e[1];return r.evaluate(t)&&n.evaluate(t)}],[Pr(jt),function(t,e){for(var r=0,n=e;r<n.length;r+=1){if(!n[r].evaluate(t))return!1}return!0}]]},any:{type:jt,overloads:[[[jt,jt],function(t,e){var r=e[0],n=e[1];return r.evaluate(t)||n.evaluate(t)}],[Pr(jt),function(t,e){for(var r=0,n=e;r<n.length;r+=1){if(n[r].evaluate(t))return!0}return!1}]]},\"!\":[jt,[jt],function(t,e){return!e[0].evaluate(t)}],\"is-supported-script\":[jt,[Nt],function(t,e){var r=e[0],n=t.globals&&t.globals.isSupportedScript;return!n||n(r.evaluate(t))}],upcase:[Nt,[Nt],function(t,e){return e[0].evaluate(t).toUpperCase()}],downcase:[Nt,[Nt],function(t,e){return e[0].evaluate(t).toLowerCase()}],concat:[Nt,Pr(qt),function(t,e){return e.map((function(e){return le(e.evaluate(t))})).join(\"\")}],\"resolved-locale\":[Nt,[Ht],function(t,e){return e[0].evaluate(t).resolvedLocale()}]});var Gr=function(t,e){this.expression=t,this._warningHistory={},this._evaluator=new ye,this._defaultValue=e?function(t){return\"color\"===t.type&&Br(t.default)?new te(0,0,0,0):\"color\"===t.type?te.parse(t.default)||null:void 0===t.default?null:t.default}(e):null,this._enumValues=e&&\"enum\"===e.type?e.values:null};function Yr(t){return Array.isArray(t)&&t.length>0&&\"string\"==typeof t[0]&&t[0]in Sr}function Wr(t,e){var r=new Ue(Sr,[],e?function(t){var e={color:Ut,string:Nt,number:Bt,enum:Nt,boolean:jt,formatted:Gt,resolvedImage:Yt};if(\"array\"===t.type)return Wt(e[t.value]||qt,t.length);return e[t.type]}(e):void 0),n=r.parse(t,void 0,void 0,void 0,e&&\"string\"===e.type?{typeAnnotation:\"coerce\"}:void 0);return n?Ir(new Gr(n,e)):Or(r.errors)}Gr.prototype.evaluateWithoutErrorHandling=function(t,e,r,n,i,a){return this._evaluator.globals=t,this._evaluator.feature=e,this._evaluator.featureState=r,this._evaluator.canonical=n,this._evaluator.availableImages=i||null,this._evaluator.formattedSection=a,this.expression.evaluate(this._evaluator)},Gr.prototype.evaluate=function(t,e,r,n,i,a){this._evaluator.globals=t,this._evaluator.feature=e||null,this._evaluator.featureState=r||null,this._evaluator.canonical=n,this._evaluator.availableImages=i||null,this._evaluator.formattedSection=a||null;try{var o=this.expression.evaluate(this._evaluator);if(null==o||\"number\"==typeof o&&o!=o)return this._defaultValue;if(this._enumValues&&!(o in this._enumValues))throw new ue(\"Expected value to be one of \"+Object.keys(this._enumValues).map((function(t){return JSON.stringify(t)})).join(\", \")+\", but found \"+JSON.stringify(o)+\" instead.\");return o}catch(t){return this._warningHistory[t.message]||(this._warningHistory[t.message]=!0,\"undefined\"!=typeof console&&console.warn(t.message)),this._defaultValue}};var Xr=function(t,e){this.kind=t,this._styleExpression=e,this.isStateDependent=\"constant\"!==t&&!Be(e.expression)};Xr.prototype.evaluateWithoutErrorHandling=function(t,e,r,n,i,a){return this._styleExpression.evaluateWithoutErrorHandling(t,e,r,n,i,a)},Xr.prototype.evaluate=function(t,e,r,n,i,a){return this._styleExpression.evaluate(t,e,r,n,i,a)};var Zr=function(t,e,r,n){this.kind=t,this.zoomStops=r,this._styleExpression=e,this.isStateDependent=\"camera\"!==t&&!Be(e.expression),this.interpolationType=n};function Jr(t,e){if(\"error\"===(t=Wr(t,e)).result)return t;var r=t.value.expression,n=Fe(r);if(!n&&!zr(e))return Or([new Dt(\"\",\"data expressions not supported\")]);var i=Ne(r,[\"zoom\"]);if(!i&&!Dr(e))return Or([new Dt(\"\",\"zoom expressions not supported\")]);var a=function t(e){var r=null;if(e instanceof cr)r=t(e.result);else if(e instanceof lr)for(var n=0,i=e.args;n<i.length;n+=1){var a=i[n];if(r=t(a))break}else(e instanceof qe||e instanceof or)&&e.input instanceof xe&&\"zoom\"===e.input.name&&(r=e);if(r instanceof Dt)return r;return e.eachChild((function(e){var n=t(e);n instanceof Dt?r=n:!r&&n?r=new Dt(\"\",'\"zoom\" expression may only be used as input to a top-level \"step\" or \"interpolate\" expression.'):r&&n&&r!==n&&(r=new Dt(\"\",'Only one zoom-based \"step\" or \"interpolate\" subexpression may be used in an expression.'))})),r}(r);if(!a&&!i)return Or([new Dt(\"\",'\"zoom\" expression may only be used as input to a top-level \"step\" or \"interpolate\" expression.')]);if(a instanceof Dt)return Or([a]);if(a instanceof or&&!Rr(e))return Or([new Dt(\"\",'\"interpolate\" expressions cannot be used with this property')]);if(!a)return Ir(new Xr(n?\"constant\":\"source\",t.value));var o=a instanceof or?a.interpolation:void 0;return Ir(new Zr(n?\"camera\":\"composite\",t.value,a.labels,o))}Zr.prototype.evaluateWithoutErrorHandling=function(t,e,r,n,i,a){return this._styleExpression.evaluateWithoutErrorHandling(t,e,r,n,i,a)},Zr.prototype.evaluate=function(t,e,r,n,i,a){return this._styleExpression.evaluate(t,e,r,n,i,a)},Zr.prototype.interpolationFactor=function(t,e,r){return this.interpolationType?or.interpolationFactor(this.interpolationType,t,e,r):0};var Kr=function(t,e){this._parameters=t,this._specification=e,It(this,function t(e,r){var n,i,a,o=\"color\"===r.type,s=e.stops&&\"object\"==typeof e.stops[0][0],l=s||void 0!==e.property,c=s||!l,u=e.type||(Rr(r)?\"exponential\":\"interval\");if(o&&((e=It({},e)).stops&&(e.stops=e.stops.map((function(t){return[t[0],te.parse(t[1])]}))),e.default?e.default=te.parse(e.default):e.default=te.parse(r.default)),e.colorSpace&&\"rgb\"!==e.colorSpace&&!ar[e.colorSpace])throw new Error(\"Unknown color space: \"+e.colorSpace);if(\"exponential\"===u)n=qr;else if(\"interval\"===u)n=Vr;else if(\"categorical\"===u){n=Ur,i=Object.create(null);for(var f=0,h=e.stops;f<h.length;f+=1){var p=h[f];i[p[0]]=p[1]}a=typeof e.stops[0][0]}else{if(\"identity\"!==u)throw new Error('Unknown function type \"'+u+'\"');n=Hr}if(s){for(var d={},m=[],g=0;g<e.stops.length;g++){var v=e.stops[g],y=v[0].zoom;void 0===d[y]&&(d[y]={zoom:y,type:e.type,property:e.property,default:e.default,stops:[]},m.push(y)),d[y].stops.push([v[0].value,v[1]])}for(var x=[],b=0,_=m;b<_.length;b+=1){var w=_[b];x.push([d[w].zoom,t(d[w],r)])}var T={name:\"linear\"};return{kind:\"composite\",interpolationType:T,interpolationFactor:or.interpolationFactor.bind(void 0,T),zoomStops:x.map((function(t){return t[0]})),evaluate:function(t,n){var i=t.zoom;return qr({stops:x,base:e.base},r,i).evaluate(i,n)}}}if(c){var k=\"exponential\"===u?{name:\"exponential\",base:void 0!==e.base?e.base:1}:null;return{kind:\"camera\",interpolationType:k,interpolationFactor:or.interpolationFactor.bind(void 0,k),zoomStops:e.stops.map((function(t){return t[0]})),evaluate:function(t){var o=t.zoom;return n(e,r,o,i,a)}}}return{kind:\"source\",evaluate:function(t,o){var s=o&&o.properties?o.properties[e.property]:void 0;return void 0===s?jr(e.default,r.default):n(e,r,s,i,a)}}}(this._parameters,this._specification))};function Qr(t){var e=t.key,r=t.value,n=t.valueSpec||{},i=t.objectElementValidators||{},a=t.style,o=t.styleSpec,s=[],l=Fr(r);if(\"object\"!==l)return[new Ct(e,r,\"object expected, \"+l+\" found\")];for(var c in r){var u=c.split(\".\")[0],f=n[u]||n[\"*\"],h=void 0;if(i[u])h=i[u];else if(n[u])h=kn;else if(i[\"*\"])h=i[\"*\"];else{if(!n[\"*\"]){s.push(new Ct(e,r[c],'unknown property \"'+c+'\"'));continue}h=kn}s=s.concat(h({key:(e?e+\".\":e)+c,value:r[c],valueSpec:f,style:a,styleSpec:o,object:r,objectKey:c},r))}for(var p in n)i[p]||n[p].required&&void 0===n[p].default&&void 0===r[p]&&s.push(new Ct(e,r,'missing required property \"'+p+'\"'));return s}function $r(t){var e=t.value,r=t.valueSpec,n=t.style,i=t.styleSpec,a=t.key,o=t.arrayElementValidator||kn;if(\"array\"!==Fr(e))return[new Ct(a,e,\"array expected, \"+Fr(e)+\" found\")];if(r.length&&e.length!==r.length)return[new Ct(a,e,\"array length \"+r.length+\" expected, length \"+e.length+\" found\")];if(r[\"min-length\"]&&e.length<r[\"min-length\"])return[new Ct(a,e,\"array length at least \"+r[\"min-length\"]+\" expected, length \"+e.length+\" found\")];var s={type:r.value,values:r.values};i.$version<7&&(s.function=r.function),\"object\"===Fr(r.value)&&(s=r.value);for(var l=[],c=0;c<e.length;c++)l=l.concat(o({array:e,arrayIndex:c,value:e[c],valueSpec:s,style:n,styleSpec:i,key:a+\"[\"+c+\"]\"}));return l}function tn(t){var e=t.key,r=t.value,n=t.valueSpec,i=Fr(r);return\"number\"===i&&r!=r&&(i=\"NaN\"),\"number\"!==i?[new Ct(e,r,\"number expected, \"+i+\" found\")]:\"minimum\"in n&&r<n.minimum?[new Ct(e,r,r+\" is less than the minimum value \"+n.minimum)]:\"maximum\"in n&&r>n.maximum?[new Ct(e,r,r+\" is greater than the maximum value \"+n.maximum)]:[]}function en(t){var e,r,n,i=t.valueSpec,a=Ot(t.value.type),o={},s=\"categorical\"!==a&&void 0===t.value.property,l=!s,c=\"array\"===Fr(t.value.stops)&&\"array\"===Fr(t.value.stops[0])&&\"object\"===Fr(t.value.stops[0][0]),u=Qr({key:t.key,value:t.value,valueSpec:t.styleSpec.function,style:t.style,styleSpec:t.styleSpec,objectElementValidators:{stops:function(t){if(\"identity\"===a)return[new Ct(t.key,t.value,'identity function may not have a \"stops\" property')];var e=[],r=t.value;e=e.concat($r({key:t.key,value:r,valueSpec:t.valueSpec,style:t.style,styleSpec:t.styleSpec,arrayElementValidator:f})),\"array\"===Fr(r)&&0===r.length&&e.push(new Ct(t.key,r,\"array must have at least one stop\"));return e},default:function(t){return kn({key:t.key,value:t.value,valueSpec:i,style:t.style,styleSpec:t.styleSpec})}}});return\"identity\"===a&&s&&u.push(new Ct(t.key,t.value,'missing required property \"property\"')),\"identity\"===a||t.value.stops||u.push(new Ct(t.key,t.value,'missing required property \"stops\"')),\"exponential\"===a&&t.valueSpec.expression&&!Rr(t.valueSpec)&&u.push(new Ct(t.key,t.value,\"exponential functions not supported\")),t.styleSpec.$version>=8&&(l&&!zr(t.valueSpec)?u.push(new Ct(t.key,t.value,\"property functions not supported\")):s&&!Dr(t.valueSpec)&&u.push(new Ct(t.key,t.value,\"zoom functions not supported\"))),\"categorical\"!==a&&!c||void 0!==t.value.property||u.push(new Ct(t.key,t.value,'\"property\" property is required')),u;function f(t){var e=[],a=t.value,s=t.key;if(\"array\"!==Fr(a))return[new Ct(s,a,\"array expected, \"+Fr(a)+\" found\")];if(2!==a.length)return[new Ct(s,a,\"array length 2 expected, length \"+a.length+\" found\")];if(c){if(\"object\"!==Fr(a[0]))return[new Ct(s,a,\"object expected, \"+Fr(a[0])+\" found\")];if(void 0===a[0].zoom)return[new Ct(s,a,\"object stop key must have zoom\")];if(void 0===a[0].value)return[new Ct(s,a,\"object stop key must have value\")];if(n&&n>Ot(a[0].zoom))return[new Ct(s,a[0].zoom,\"stop zoom values must appear in ascending order\")];Ot(a[0].zoom)!==n&&(n=Ot(a[0].zoom),r=void 0,o={}),e=e.concat(Qr({key:s+\"[0]\",value:a[0],valueSpec:{zoom:{}},style:t.style,styleSpec:t.styleSpec,objectElementValidators:{zoom:tn,value:h}}))}else e=e.concat(h({key:s+\"[0]\",value:a[0],valueSpec:{},style:t.style,styleSpec:t.styleSpec},a));return Yr(zt(a[1]))?e.concat([new Ct(s+\"[1]\",a[1],\"expressions are not allowed in function stops.\")]):e.concat(kn({key:s+\"[1]\",value:a[1],valueSpec:i,style:t.style,styleSpec:t.styleSpec}))}function h(t,n){var s=Fr(t.value),l=Ot(t.value),c=null!==t.value?t.value:n;if(e){if(s!==e)return[new Ct(t.key,c,s+\" stop domain type must match previous stop domain type \"+e)]}else e=s;if(\"number\"!==s&&\"string\"!==s&&\"boolean\"!==s)return[new Ct(t.key,c,\"stop domain value must be a number, string, or boolean\")];if(\"number\"!==s&&\"categorical\"!==a){var u=\"number expected, \"+s+\" found\";return zr(i)&&void 0===a&&(u+='\\nIf you intended to use a categorical function, specify `\"type\": \"categorical\"`.'),[new Ct(t.key,c,u)]}return\"categorical\"!==a||\"number\"!==s||isFinite(l)&&Math.floor(l)===l?\"categorical\"!==a&&\"number\"===s&&void 0!==r&&l<r?[new Ct(t.key,c,\"stop domain values must appear in ascending order\")]:(r=l,\"categorical\"===a&&l in o?[new Ct(t.key,c,\"stop domain values must be unique\")]:(o[l]=!0,[])):[new Ct(t.key,c,\"integer expected, found \"+l)]}}function rn(t){var e=(\"property\"===t.expressionContext?Jr:Wr)(zt(t.value),t.valueSpec);if(\"error\"===e.result)return e.value.map((function(e){return new Ct(\"\"+t.key+e.key,t.value,e.message)}));var r=e.value.expression||e.value._styleExpression.expression;if(\"property\"===t.expressionContext&&\"text-font\"===t.propertyKey&&!r.outputDefined())return[new Ct(t.key,t.value,'Invalid data expression for \"'+t.propertyKey+'\". Output values must be contained as literals within the expression.')];if(\"property\"===t.expressionContext&&\"layout\"===t.propertyType&&!Be(r))return[new Ct(t.key,t.value,'\"feature-state\" data expressions are not supported with layout properties.')];if(\"filter\"===t.expressionContext&&!Be(r))return[new Ct(t.key,t.value,'\"feature-state\" data expressions are not supported with filters.')];if(t.expressionContext&&0===t.expressionContext.indexOf(\"cluster\")){if(!Ne(r,[\"zoom\",\"feature-state\"]))return[new Ct(t.key,t.value,'\"zoom\" and \"feature-state\" expressions are not supported with cluster properties.')];if(\"cluster-initial\"===t.expressionContext&&!Fe(r))return[new Ct(t.key,t.value,\"Feature data expressions are not supported with initial expression part of cluster properties.\")]}return[]}function nn(t){var e=t.key,r=t.value,n=t.valueSpec,i=[];return Array.isArray(n.values)?-1===n.values.indexOf(Ot(r))&&i.push(new Ct(e,r,\"expected one of [\"+n.values.join(\", \")+\"], \"+JSON.stringify(r)+\" found\")):-1===Object.keys(n.values).indexOf(Ot(r))&&i.push(new Ct(e,r,\"expected one of [\"+Object.keys(n.values).join(\", \")+\"], \"+JSON.stringify(r)+\" found\")),i}function an(t){if(!0===t||!1===t)return!0;if(!Array.isArray(t)||0===t.length)return!1;switch(t[0]){case\"has\":return t.length>=2&&\"$id\"!==t[1]&&\"$type\"!==t[1];case\"in\":return t.length>=3&&(\"string\"!=typeof t[1]||Array.isArray(t[2]));case\"!in\":case\"!has\":case\"none\":return!1;case\"==\":case\"!=\":case\">\":case\">=\":case\"<\":case\"<=\":return 3!==t.length||Array.isArray(t[1])||Array.isArray(t[2]);case\"any\":case\"all\":for(var e=0,r=t.slice(1);e<r.length;e+=1){var n=r[e];if(!an(n)&&\"boolean\"!=typeof n)return!1}return!0;default:return!0}}Kr.deserialize=function(t){return new Kr(t._parameters,t._specification)},Kr.serialize=function(t){return{_parameters:t._parameters,_specification:t._specification}};var on={type:\"boolean\",default:!1,transition:!1,\"property-type\":\"data-driven\",expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]}};function sn(t){if(null==t)return{filter:function(){return!0},needGeometry:!1};an(t)||(t=cn(t));var e=Wr(t,on);if(\"error\"===e.result)throw new Error(e.value.map((function(t){return t.key+\": \"+t.message})).join(\", \"));return{filter:function(t,r,n){return e.value.evaluate(t,r,{},n)},needGeometry:function t(e){if(!Array.isArray(e))return!1;if(\"within\"===e[0])return!0;for(var r=1;r<e.length;r++)if(t(e[r]))return!0;return!1}(t)}}function ln(t,e){return t<e?-1:t>e?1:0}function cn(t){if(!t)return!0;var e,r=t[0];return t.length<=1?\"any\"!==r:\"==\"===r?un(t[1],t[2],\"==\"):\"!=\"===r?pn(un(t[1],t[2],\"==\")):\"<\"===r||\">\"===r||\"<=\"===r||\">=\"===r?un(t[1],t[2],r):\"any\"===r?(e=t.slice(1),[\"any\"].concat(e.map(cn))):\"all\"===r?[\"all\"].concat(t.slice(1).map(cn)):\"none\"===r?[\"all\"].concat(t.slice(1).map(cn).map(pn)):\"in\"===r?fn(t[1],t.slice(2)):\"!in\"===r?pn(fn(t[1],t.slice(2))):\"has\"===r?hn(t[1]):\"!has\"===r?pn(hn(t[1])):\"within\"!==r||t}function un(t,e,r){switch(t){case\"$type\":return[\"filter-type-\"+r,e];case\"$id\":return[\"filter-id-\"+r,e];default:return[\"filter-\"+r,t,e]}}function fn(t,e){if(0===e.length)return!1;switch(t){case\"$type\":return[\"filter-type-in\",[\"literal\",e]];case\"$id\":return[\"filter-id-in\",[\"literal\",e]];default:return e.length>200&&!e.some((function(t){return typeof t!=typeof e[0]}))?[\"filter-in-large\",t,[\"literal\",e.sort(ln)]]:[\"filter-in-small\",t,[\"literal\",e]]}}function hn(t){switch(t){case\"$type\":return!0;case\"$id\":return[\"filter-has-id\"];default:return[\"filter-has\",t]}}function pn(t){return[\"!\",t]}function dn(t){return an(zt(t.value))?rn(It({},t,{expressionContext:\"filter\",valueSpec:{value:\"boolean\"}})):function t(e){var r=e.value,n=e.key;if(\"array\"!==Fr(r))return[new Ct(n,r,\"array expected, \"+Fr(r)+\" found\")];var i,a=e.styleSpec,o=[];if(r.length<1)return[new Ct(n,r,\"filter array must have at least 1 element\")];switch(o=o.concat(nn({key:n+\"[0]\",value:r[0],valueSpec:a.filter_operator,style:e.style,styleSpec:e.styleSpec})),Ot(r[0])){case\"<\":case\"<=\":case\">\":case\">=\":r.length>=2&&\"$type\"===Ot(r[1])&&o.push(new Ct(n,r,'\"$type\" cannot be use with operator \"'+r[0]+'\"'));case\"==\":case\"!=\":3!==r.length&&o.push(new Ct(n,r,'filter array for operator \"'+r[0]+'\" must have 3 elements'));case\"in\":case\"!in\":r.length>=2&&\"string\"!==(i=Fr(r[1]))&&o.push(new Ct(n+\"[1]\",r[1],\"string expected, \"+i+\" found\"));for(var s=2;s<r.length;s++)i=Fr(r[s]),\"$type\"===Ot(r[1])?o=o.concat(nn({key:n+\"[\"+s+\"]\",value:r[s],valueSpec:a.geometry_type,style:e.style,styleSpec:e.styleSpec})):\"string\"!==i&&\"number\"!==i&&\"boolean\"!==i&&o.push(new Ct(n+\"[\"+s+\"]\",r[s],\"string, number, or boolean expected, \"+i+\" found\"));break;case\"any\":case\"all\":case\"none\":for(var l=1;l<r.length;l++)o=o.concat(t({key:n+\"[\"+l+\"]\",value:r[l],style:e.style,styleSpec:e.styleSpec}));break;case\"has\":case\"!has\":i=Fr(r[1]),2!==r.length?o.push(new Ct(n,r,'filter array for \"'+r[0]+'\" operator must have 2 elements')):\"string\"!==i&&o.push(new Ct(n+\"[1]\",r[1],\"string expected, \"+i+\" found\"));break;case\"within\":i=Fr(r[1]),2!==r.length?o.push(new Ct(n,r,'filter array for \"'+r[0]+'\" operator must have 2 elements')):\"object\"!==i&&o.push(new Ct(n+\"[1]\",r[1],\"object expected, \"+i+\" found\"))}return o}(t)}function mn(t,e){var r=t.key,n=t.style,i=t.styleSpec,a=t.value,o=t.objectKey,s=i[e+\"_\"+t.layerType];if(!s)return[];var l=o.match(/^(.*)-transition$/);if(\"paint\"===e&&l&&s[l[1]]&&s[l[1]].transition)return kn({key:r,value:a,valueSpec:i.transition,style:n,styleSpec:i});var c,u=t.valueSpec||s[o];if(!u)return[new Ct(r,a,'unknown property \"'+o+'\"')];if(\"string\"===Fr(a)&&zr(u)&&!u.tokens&&(c=/^{([^}]+)}$/.exec(a)))return[new Ct(r,a,'\"'+o+'\" does not support interpolation syntax\\nUse an identity property function instead: `{ \"type\": \"identity\", \"property\": '+JSON.stringify(c[1])+\" }`.\")];var f=[];return\"symbol\"===t.layerType&&(\"text-field\"===o&&n&&!n.glyphs&&f.push(new Ct(r,a,'use of \"text-field\" requires a style \"glyphs\" property')),\"text-font\"===o&&Br(zt(a))&&\"identity\"===Ot(a.type)&&f.push(new Ct(r,a,'\"text-font\" does not support identity functions'))),f.concat(kn({key:t.key,value:a,valueSpec:u,style:n,styleSpec:i,expressionContext:\"property\",propertyType:e,propertyKey:o}))}function gn(t){return mn(t,\"paint\")}function vn(t){return mn(t,\"layout\")}function yn(t){var e=[],r=t.value,n=t.key,i=t.style,a=t.styleSpec;r.type||r.ref||e.push(new Ct(n,r,'either \"type\" or \"ref\" is required'));var o,s=Ot(r.type),l=Ot(r.ref);if(r.id)for(var c=Ot(r.id),u=0;u<t.arrayIndex;u++){var f=i.layers[u];Ot(f.id)===c&&e.push(new Ct(n,r.id,'duplicate layer id \"'+r.id+'\", previously used at line '+f.id.__line__))}if(\"ref\"in r)[\"type\",\"source\",\"source-layer\",\"filter\",\"layout\"].forEach((function(t){t in r&&e.push(new Ct(n,r[t],'\"'+t+'\" is prohibited for ref layers'))})),i.layers.forEach((function(t){Ot(t.id)===l&&(o=t)})),o?o.ref?e.push(new Ct(n,r.ref,\"ref cannot reference another ref layer\")):s=Ot(o.type):e.push(new Ct(n,r.ref,'ref layer \"'+l+'\" not found'));else if(\"background\"!==s)if(r.source){var h=i.sources&&i.sources[r.source],p=h&&Ot(h.type);h?\"vector\"===p&&\"raster\"===s?e.push(new Ct(n,r.source,'layer \"'+r.id+'\" requires a raster source')):\"raster\"===p&&\"raster\"!==s?e.push(new Ct(n,r.source,'layer \"'+r.id+'\" requires a vector source')):\"vector\"!==p||r[\"source-layer\"]?\"raster-dem\"===p&&\"hillshade\"!==s?e.push(new Ct(n,r.source,\"raster-dem source can only be used with layer type 'hillshade'.\")):\"line\"!==s||!r.paint||!r.paint[\"line-gradient\"]||\"geojson\"===p&&h.lineMetrics||e.push(new Ct(n,r,'layer \"'+r.id+'\" specifies a line-gradient, which requires a GeoJSON source with `lineMetrics` enabled.')):e.push(new Ct(n,r,'layer \"'+r.id+'\" must specify a \"source-layer\"')):e.push(new Ct(n,r.source,'source \"'+r.source+'\" not found'))}else e.push(new Ct(n,r,'missing required property \"source\"'));return e=e.concat(Qr({key:n,value:r,valueSpec:a.layer,style:t.style,styleSpec:t.styleSpec,objectElementValidators:{\"*\":function(){return[]},type:function(){return kn({key:n+\".type\",value:r.type,valueSpec:a.layer.type,style:t.style,styleSpec:t.styleSpec,object:r,objectKey:\"type\"})},filter:dn,layout:function(t){return Qr({layer:r,key:t.key,value:t.value,style:t.style,styleSpec:t.styleSpec,objectElementValidators:{\"*\":function(t){return vn(It({layerType:s},t))}}})},paint:function(t){return Qr({layer:r,key:t.key,value:t.value,style:t.style,styleSpec:t.styleSpec,objectElementValidators:{\"*\":function(t){return gn(It({layerType:s},t))}}})}}}))}function xn(t){var e=t.value,r=t.key,n=Fr(e);return\"string\"!==n?[new Ct(r,e,\"string expected, \"+n+\" found\")]:[]}var bn={promoteId:function(t){var e=t.key,r=t.value;if(\"string\"===Fr(r))return xn({key:e,value:r});var n=[];for(var i in r)n.push.apply(n,xn({key:e+\".\"+i,value:r[i]}));return n}};function _n(t){var e=t.value,r=t.key,n=t.styleSpec,i=t.style;if(!e.type)return[new Ct(r,e,'\"type\" is required')];var a,o=Ot(e.type);switch(o){case\"vector\":case\"raster\":case\"raster-dem\":return a=Qr({key:r,value:e,valueSpec:n[\"source_\"+o.replace(\"-\",\"_\")],style:t.style,styleSpec:n,objectElementValidators:bn});case\"geojson\":if(a=Qr({key:r,value:e,valueSpec:n.source_geojson,style:i,styleSpec:n,objectElementValidators:bn}),e.cluster)for(var s in e.clusterProperties){var l=e.clusterProperties[s],c=l[0],u=l[1],f=\"string\"==typeof c?[c,[\"accumulated\"],[\"get\",s]]:c;a.push.apply(a,rn({key:r+\".\"+s+\".map\",value:u,expressionContext:\"cluster-map\"})),a.push.apply(a,rn({key:r+\".\"+s+\".reduce\",value:f,expressionContext:\"cluster-reduce\"}))}return a;case\"video\":return Qr({key:r,value:e,valueSpec:n.source_video,style:i,styleSpec:n});case\"image\":return Qr({key:r,value:e,valueSpec:n.source_image,style:i,styleSpec:n});case\"canvas\":return[new Ct(r,null,\"Please use runtime APIs to add canvas sources, rather than including them in stylesheets.\",\"source.canvas\")];default:return nn({key:r+\".type\",value:e.type,valueSpec:{values:[\"vector\",\"raster\",\"raster-dem\",\"geojson\",\"video\",\"image\"]},style:i,styleSpec:n})}}function wn(t){var e=t.value,r=t.styleSpec,n=r.light,i=t.style,a=[],o=Fr(e);if(void 0===e)return a;if(\"object\"!==o)return a=a.concat([new Ct(\"light\",e,\"object expected, \"+o+\" found\")]);for(var s in e){var l=s.match(/^(.*)-transition$/);a=l&&n[l[1]]&&n[l[1]].transition?a.concat(kn({key:s,value:e[s],valueSpec:r.transition,style:i,styleSpec:r})):n[s]?a.concat(kn({key:s,value:e[s],valueSpec:n[s],style:i,styleSpec:r})):a.concat([new Ct(s,e[s],'unknown property \"'+s+'\"')])}return a}var Tn={\"*\":function(){return[]},array:$r,boolean:function(t){var e=t.value,r=t.key,n=Fr(e);return\"boolean\"!==n?[new Ct(r,e,\"boolean expected, \"+n+\" found\")]:[]},number:tn,color:function(t){var e=t.key,r=t.value,n=Fr(r);return\"string\"!==n?[new Ct(e,r,\"color expected, \"+n+\" found\")]:null===$t(r)?[new Ct(e,r,'color expected, \"'+r+'\" found')]:[]},constants:Pt,enum:nn,filter:dn,function:en,layer:yn,object:Qr,source:_n,light:wn,string:xn,formatted:function(t){return 0===xn(t).length?[]:rn(t)},resolvedImage:function(t){return 0===xn(t).length?[]:rn(t)}};function kn(t){var e=t.value,r=t.valueSpec,n=t.styleSpec;return r.expression&&Br(Ot(e))?en(t):r.expression&&Yr(zt(e))?rn(t):r.type&&Tn[r.type]?Tn[r.type](t):Qr(It({},t,{valueSpec:r.type?n[r.type]:r}))}function Mn(t){var e=t.value,r=t.key,n=xn(t);return n.length||(-1===e.indexOf(\"{fontstack}\")&&n.push(new Ct(r,e,'\"glyphs\" url must include a \"{fontstack}\" token')),-1===e.indexOf(\"{range}\")&&n.push(new Ct(r,e,'\"glyphs\" url must include a \"{range}\" token'))),n}function An(t,e){void 0===e&&(e=Lt);var r=[];return r=r.concat(kn({key:\"\",value:t,valueSpec:e.$root,styleSpec:e,style:t,objectElementValidators:{glyphs:Mn,\"*\":function(){return[]}}})),t.constants&&(r=r.concat(Pt({key:\"constants\",value:t.constants,style:t,styleSpec:e}))),Sn(r)}function Sn(t){return[].concat(t).sort((function(t,e){return t.line-e.line}))}function En(t){return function(){for(var e=[],r=arguments.length;r--;)e[r]=arguments[r];return Sn(t.apply(this,e))}}An.source=En(_n),An.light=En(wn),An.layer=En(yn),An.filter=En(dn),An.paintProperty=En(gn),An.layoutProperty=En(vn);var Ln=An,Cn=Ln.light,Pn=Ln.paintProperty,In=Ln.layoutProperty;function On(t,e){var r=!1;if(e&&e.length)for(var n=0,i=e;n<i.length;n+=1){var a=i[n];t.fire(new St(new Error(a.message))),r=!0}return r}var zn=Dn;function Dn(t,e,r){var n=this.cells=[];if(t instanceof ArrayBuffer){this.arrayBuffer=t;var i=new Int32Array(this.arrayBuffer);t=i[0],e=i[1],r=i[2],this.d=e+2*r;for(var a=0;a<this.d*this.d;a++){var o=i[3+a],s=i[3+a+1];n.push(o===s?null:i.subarray(o,s))}var l=i[3+n.length],c=i[3+n.length+1];this.keys=i.subarray(l,c),this.bboxes=i.subarray(c),this.insert=this._insertReadonly}else{this.d=e+2*r;for(var u=0;u<this.d*this.d;u++)n.push([]);this.keys=[],this.bboxes=[]}this.n=e,this.extent=t,this.padding=r,this.scale=e/t,this.uid=0;var f=r/e*t;this.min=-f,this.max=t+f}Dn.prototype.insert=function(t,e,r,n,i){this._forEachCell(e,r,n,i,this._insertCell,this.uid++),this.keys.push(t),this.bboxes.push(e),this.bboxes.push(r),this.bboxes.push(n),this.bboxes.push(i)},Dn.prototype._insertReadonly=function(){throw\"Cannot insert into a GridIndex created from an ArrayBuffer.\"},Dn.prototype._insertCell=function(t,e,r,n,i,a){this.cells[i].push(a)},Dn.prototype.query=function(t,e,r,n,i){var a=this.min,o=this.max;if(t<=a&&e<=a&&o<=r&&o<=n&&!i)return Array.prototype.slice.call(this.keys);var s=[];return this._forEachCell(t,e,r,n,this._queryCell,s,{},i),s},Dn.prototype._queryCell=function(t,e,r,n,i,a,o,s){var l=this.cells[i];if(null!==l)for(var c=this.keys,u=this.bboxes,f=0;f<l.length;f++){var h=l[f];if(void 0===o[h]){var p=4*h;(s?s(u[p+0],u[p+1],u[p+2],u[p+3]):t<=u[p+2]&&e<=u[p+3]&&r>=u[p+0]&&n>=u[p+1])?(o[h]=!0,a.push(c[h])):o[h]=!1}}},Dn.prototype._forEachCell=function(t,e,r,n,i,a,o,s){for(var l=this._convertToCellCoord(t),c=this._convertToCellCoord(e),u=this._convertToCellCoord(r),f=this._convertToCellCoord(n),h=l;h<=u;h++)for(var p=c;p<=f;p++){var d=this.d*p+h;if((!s||s(this._convertFromCellCoord(h),this._convertFromCellCoord(p),this._convertFromCellCoord(h+1),this._convertFromCellCoord(p+1)))&&i.call(this,t,e,r,n,d,a,o,s))return}},Dn.prototype._convertFromCellCoord=function(t){return(t-this.padding)/this.scale},Dn.prototype._convertToCellCoord=function(t){return Math.max(0,Math.min(this.d-1,Math.floor(t*this.scale)+this.padding))},Dn.prototype.toArrayBuffer=function(){if(this.arrayBuffer)return this.arrayBuffer;for(var t=this.cells,e=3+this.cells.length+1+1,r=0,n=0;n<this.cells.length;n++)r+=this.cells[n].length;var i=new Int32Array(e+r+this.keys.length+this.bboxes.length);i[0]=this.extent,i[1]=this.n,i[2]=this.padding;for(var a=e,o=0;o<t.length;o++){var s=t[o];i[3+o]=a,i.set(s,a),a+=s.length}return i[3+t.length]=a,i.set(this.keys,a),a+=this.keys.length,i[3+t.length+1]=a,i.set(this.bboxes,a),a+=this.bboxes.length,i.buffer};var Rn=self.ImageData,Fn=self.ImageBitmap,Bn={};function Nn(t,e,r){void 0===r&&(r={}),Object.defineProperty(e,\"_classRegistryKey\",{value:t,writeable:!1}),Bn[t]={klass:e,omit:r.omit||[],shallow:r.shallow||[]}}for(var jn in Nn(\"Object\",Object),zn.serialize=function(t,e){var r=t.toArrayBuffer();return e&&e.push(r),{buffer:r}},zn.deserialize=function(t){return new zn(t.buffer)},Nn(\"Grid\",zn),Nn(\"Color\",te),Nn(\"Error\",Error),Nn(\"ResolvedImage\",ie),Nn(\"StylePropertyFunction\",Kr),Nn(\"StyleExpression\",Gr,{omit:[\"_evaluator\"]}),Nn(\"ZoomDependentExpression\",Zr),Nn(\"ZoomConstantExpression\",Xr),Nn(\"CompoundExpression\",xe,{omit:[\"_evaluate\"]}),Sr)Sr[jn]._classRegistryKey||Nn(\"Expression_\"+jn,Sr[jn]);function Un(t){return t&&\"undefined\"!=typeof ArrayBuffer&&(t instanceof ArrayBuffer||t.constructor&&\"ArrayBuffer\"===t.constructor.name)}function Vn(t){return Fn&&t instanceof Fn}function qn(t,e){if(null==t||\"boolean\"==typeof t||\"number\"==typeof t||\"string\"==typeof t||t instanceof Boolean||t instanceof Number||t instanceof String||t instanceof Date||t instanceof RegExp)return t;if(Un(t)||Vn(t))return e&&e.push(t),t;if(ArrayBuffer.isView(t)){var r=t;return e&&e.push(r.buffer),r}if(t instanceof Rn)return e&&e.push(t.data.buffer),t;if(Array.isArray(t)){for(var n=[],i=0,a=t;i<a.length;i+=1){var o=a[i];n.push(qn(o,e))}return n}if(\"object\"==typeof t){var s=t.constructor,l=s._classRegistryKey;if(!l)throw new Error(\"can't serialize object of unregistered class\");var c=s.serialize?s.serialize(t,e):{};if(!s.serialize){for(var u in t)if(t.hasOwnProperty(u)&&!(Bn[l].omit.indexOf(u)>=0)){var f=t[u];c[u]=Bn[l].shallow.indexOf(u)>=0?f:qn(f,e)}t instanceof Error&&(c.message=t.message)}if(c.$name)throw new Error(\"$name property is reserved for worker serialization logic.\");return\"Object\"!==l&&(c.$name=l),c}throw new Error(\"can't serialize object of type \"+typeof t)}function Hn(t){if(null==t||\"boolean\"==typeof t||\"number\"==typeof t||\"string\"==typeof t||t instanceof Boolean||t instanceof Number||t instanceof String||t instanceof Date||t instanceof RegExp||Un(t)||Vn(t)||ArrayBuffer.isView(t)||t instanceof Rn)return t;if(Array.isArray(t))return t.map(Hn);if(\"object\"==typeof t){var e=t.$name||\"Object\",r=Bn[e].klass;if(!r)throw new Error(\"can't deserialize unregistered class \"+e);if(r.deserialize)return r.deserialize(t);for(var n=Object.create(r.prototype),i=0,a=Object.keys(t);i<a.length;i+=1){var o=a[i];if(\"$name\"!==o){var s=t[o];n[o]=Bn[e].shallow.indexOf(o)>=0?s:Hn(s)}}return n}throw new Error(\"can't deserialize object of type \"+typeof t)}var Gn=function(){this.first=!0};Gn.prototype.update=function(t,e){var r=Math.floor(t);return this.first?(this.first=!1,this.lastIntegerZoom=r,this.lastIntegerZoomTime=0,this.lastZoom=t,this.lastFloorZoom=r,!0):(this.lastFloorZoom>r?(this.lastIntegerZoom=r+1,this.lastIntegerZoomTime=e):this.lastFloorZoom<r&&(this.lastIntegerZoom=r,this.lastIntegerZoomTime=e),t!==this.lastZoom&&(this.lastZoom=t,this.lastFloorZoom=r,!0))};var Yn={\"Latin-1 Supplement\":function(t){return t>=128&&t<=255},Arabic:function(t){return t>=1536&&t<=1791},\"Arabic Supplement\":function(t){return t>=1872&&t<=1919},\"Arabic Extended-A\":function(t){return t>=2208&&t<=2303},\"Hangul Jamo\":function(t){return t>=4352&&t<=4607},\"Unified Canadian Aboriginal Syllabics\":function(t){return t>=5120&&t<=5759},Khmer:function(t){return t>=6016&&t<=6143},\"Unified Canadian Aboriginal Syllabics Extended\":function(t){return t>=6320&&t<=6399},\"General Punctuation\":function(t){return t>=8192&&t<=8303},\"Letterlike Symbols\":function(t){return t>=8448&&t<=8527},\"Number Forms\":function(t){return t>=8528&&t<=8591},\"Miscellaneous Technical\":function(t){return t>=8960&&t<=9215},\"Control Pictures\":function(t){return t>=9216&&t<=9279},\"Optical Character Recognition\":function(t){return t>=9280&&t<=9311},\"Enclosed Alphanumerics\":function(t){return t>=9312&&t<=9471},\"Geometric Shapes\":function(t){return t>=9632&&t<=9727},\"Miscellaneous Symbols\":function(t){return t>=9728&&t<=9983},\"Miscellaneous Symbols and Arrows\":function(t){return t>=11008&&t<=11263},\"CJK Radicals Supplement\":function(t){return t>=11904&&t<=12031},\"Kangxi Radicals\":function(t){return t>=12032&&t<=12255},\"Ideographic Description Characters\":function(t){return t>=12272&&t<=12287},\"CJK Symbols and Punctuation\":function(t){return t>=12288&&t<=12351},Hiragana:function(t){return t>=12352&&t<=12447},Katakana:function(t){return t>=12448&&t<=12543},Bopomofo:function(t){return t>=12544&&t<=12591},\"Hangul Compatibility Jamo\":function(t){return t>=12592&&t<=12687},Kanbun:function(t){return t>=12688&&t<=12703},\"Bopomofo Extended\":function(t){return t>=12704&&t<=12735},\"CJK Strokes\":function(t){return t>=12736&&t<=12783},\"Katakana Phonetic Extensions\":function(t){return t>=12784&&t<=12799},\"Enclosed CJK Letters and Months\":function(t){return t>=12800&&t<=13055},\"CJK Compatibility\":function(t){return t>=13056&&t<=13311},\"CJK Unified Ideographs Extension A\":function(t){return t>=13312&&t<=19903},\"Yijing Hexagram Symbols\":function(t){return t>=19904&&t<=19967},\"CJK Unified Ideographs\":function(t){return t>=19968&&t<=40959},\"Yi Syllables\":function(t){return t>=40960&&t<=42127},\"Yi Radicals\":function(t){return t>=42128&&t<=42191},\"Hangul Jamo Extended-A\":function(t){return t>=43360&&t<=43391},\"Hangul Syllables\":function(t){return t>=44032&&t<=55215},\"Hangul Jamo Extended-B\":function(t){return t>=55216&&t<=55295},\"Private Use Area\":function(t){return t>=57344&&t<=63743},\"CJK Compatibility Ideographs\":function(t){return t>=63744&&t<=64255},\"Arabic Presentation Forms-A\":function(t){return t>=64336&&t<=65023},\"Vertical Forms\":function(t){return t>=65040&&t<=65055},\"CJK Compatibility Forms\":function(t){return t>=65072&&t<=65103},\"Small Form Variants\":function(t){return t>=65104&&t<=65135},\"Arabic Presentation Forms-B\":function(t){return t>=65136&&t<=65279},\"Halfwidth and Fullwidth Forms\":function(t){return t>=65280&&t<=65519}};function Wn(t){for(var e=0,r=t;e<r.length;e+=1){if(Zn(r[e].charCodeAt(0)))return!0}return!1}function Xn(t){return!Yn.Arabic(t)&&(!Yn[\"Arabic Supplement\"](t)&&(!Yn[\"Arabic Extended-A\"](t)&&(!Yn[\"Arabic Presentation Forms-A\"](t)&&!Yn[\"Arabic Presentation Forms-B\"](t))))}function Zn(t){return 746===t||747===t||!(t<4352)&&(!!Yn[\"Bopomofo Extended\"](t)||(!!Yn.Bopomofo(t)||(!(!Yn[\"CJK Compatibility Forms\"](t)||t>=65097&&t<=65103)||(!!Yn[\"CJK Compatibility Ideographs\"](t)||(!!Yn[\"CJK Compatibility\"](t)||(!!Yn[\"CJK Radicals Supplement\"](t)||(!!Yn[\"CJK Strokes\"](t)||(!(!Yn[\"CJK Symbols and Punctuation\"](t)||t>=12296&&t<=12305||t>=12308&&t<=12319||12336===t)||(!!Yn[\"CJK Unified Ideographs Extension A\"](t)||(!!Yn[\"CJK Unified Ideographs\"](t)||(!!Yn[\"Enclosed CJK Letters and Months\"](t)||(!!Yn[\"Hangul Compatibility Jamo\"](t)||(!!Yn[\"Hangul Jamo Extended-A\"](t)||(!!Yn[\"Hangul Jamo Extended-B\"](t)||(!!Yn[\"Hangul Jamo\"](t)||(!!Yn[\"Hangul Syllables\"](t)||(!!Yn.Hiragana(t)||(!!Yn[\"Ideographic Description Characters\"](t)||(!!Yn.Kanbun(t)||(!!Yn[\"Kangxi Radicals\"](t)||(!!Yn[\"Katakana Phonetic Extensions\"](t)||(!(!Yn.Katakana(t)||12540===t)||(!(!Yn[\"Halfwidth and Fullwidth Forms\"](t)||65288===t||65289===t||65293===t||t>=65306&&t<=65310||65339===t||65341===t||65343===t||t>=65371&&t<=65503||65507===t||t>=65512&&t<=65519)||(!(!Yn[\"Small Form Variants\"](t)||t>=65112&&t<=65118||t>=65123&&t<=65126)||(!!Yn[\"Unified Canadian Aboriginal Syllabics\"](t)||(!!Yn[\"Unified Canadian Aboriginal Syllabics Extended\"](t)||(!!Yn[\"Vertical Forms\"](t)||(!!Yn[\"Yijing Hexagram Symbols\"](t)||(!!Yn[\"Yi Syllables\"](t)||!!Yn[\"Yi Radicals\"](t))))))))))))))))))))))))))))))}function Jn(t){return!(Zn(t)||function(t){return!(!Yn[\"Latin-1 Supplement\"](t)||167!==t&&169!==t&&174!==t&&177!==t&&188!==t&&189!==t&&190!==t&&215!==t&&247!==t)||(!(!Yn[\"General Punctuation\"](t)||8214!==t&&8224!==t&&8225!==t&&8240!==t&&8241!==t&&8251!==t&&8252!==t&&8258!==t&&8263!==t&&8264!==t&&8265!==t&&8273!==t)||(!!Yn[\"Letterlike Symbols\"](t)||(!!Yn[\"Number Forms\"](t)||(!(!Yn[\"Miscellaneous Technical\"](t)||!(t>=8960&&t<=8967||t>=8972&&t<=8991||t>=8996&&t<=9e3||9003===t||t>=9085&&t<=9114||t>=9150&&t<=9165||9167===t||t>=9169&&t<=9179||t>=9186&&t<=9215))||(!(!Yn[\"Control Pictures\"](t)||9251===t)||(!!Yn[\"Optical Character Recognition\"](t)||(!!Yn[\"Enclosed Alphanumerics\"](t)||(!!Yn[\"Geometric Shapes\"](t)||(!(!Yn[\"Miscellaneous Symbols\"](t)||t>=9754&&t<=9759)||(!(!Yn[\"Miscellaneous Symbols and Arrows\"](t)||!(t>=11026&&t<=11055||t>=11088&&t<=11097||t>=11192&&t<=11243))||(!!Yn[\"CJK Symbols and Punctuation\"](t)||(!!Yn.Katakana(t)||(!!Yn[\"Private Use Area\"](t)||(!!Yn[\"CJK Compatibility Forms\"](t)||(!!Yn[\"Small Form Variants\"](t)||(!!Yn[\"Halfwidth and Fullwidth Forms\"](t)||(8734===t||8756===t||8757===t||t>=9984&&t<=10087||t>=10102&&t<=10131||65532===t||65533===t)))))))))))))))))}(t))}function Kn(t){return t>=1424&&t<=2303||Yn[\"Arabic Presentation Forms-A\"](t)||Yn[\"Arabic Presentation Forms-B\"](t)}function Qn(t,e){return!(!e&&Kn(t))&&!(t>=2304&&t<=3583||t>=3840&&t<=4255||Yn.Khmer(t))}function $n(t){for(var e=0,r=t;e<r.length;e+=1){if(Kn(r[e].charCodeAt(0)))return!0}return!1}var ti=\"deferred\",ei=\"loading\",ri=\"loaded\",ni=\"error\",ii=null,ai=\"unavailable\",oi=null,si=function(t){t&&\"string\"==typeof t&&t.indexOf(\"NetworkError\")>-1&&(ai=ni),ii&&ii(t)};function li(){ci.fire(new At(\"pluginStateChange\",{pluginStatus:ai,pluginURL:oi}))}var ci=new Et,ui=function(){return ai},fi=function(){if(ai!==ti||!oi)throw new Error(\"rtl-text-plugin cannot be downloaded unless a pluginURL is specified\");ai=ei,li(),oi&&xt({url:oi},(function(t){t?si(t):(ai=ri,li())}))},hi={applyArabicShaping:null,processBidirectionalText:null,processStyledBidirectionalText:null,isLoaded:function(){return ai===ri||null!=hi.applyArabicShaping},isLoading:function(){return ai===ei},setState:function(t){ai=t.pluginStatus,oi=t.pluginURL},isParsed:function(){return null!=hi.applyArabicShaping&&null!=hi.processBidirectionalText&&null!=hi.processStyledBidirectionalText},getPluginURL:function(){return oi}},pi=function(t,e){this.zoom=t,e?(this.now=e.now,this.fadeDuration=e.fadeDuration,this.zoomHistory=e.zoomHistory,this.transition=e.transition):(this.now=0,this.fadeDuration=0,this.zoomHistory=new Gn,this.transition={})};pi.prototype.isSupportedScript=function(t){return function(t,e){for(var r=0,n=t;r<n.length;r+=1){if(!Qn(n[r].charCodeAt(0),e))return!1}return!0}(t,hi.isLoaded())},pi.prototype.crossFadingFactor=function(){return 0===this.fadeDuration?1:Math.min((this.now-this.zoomHistory.lastIntegerZoomTime)/this.fadeDuration,1)},pi.prototype.getCrossfadeParameters=function(){var t=this.zoom,e=t-Math.floor(t),r=this.crossFadingFactor();return t>this.zoomHistory.lastIntegerZoom?{fromScale:2,toScale:1,t:e+(1-e)*r}:{fromScale:.5,toScale:1,t:1-(1-r)*e}};var di=function(t,e){this.property=t,this.value=e,this.expression=function(t,e){if(Br(t))return new Kr(t,e);if(Yr(t)){var r=Jr(t,e);if(\"error\"===r.result)throw new Error(r.value.map((function(t){return t.key+\": \"+t.message})).join(\", \"));return r.value}var n=t;return\"string\"==typeof t&&\"color\"===e.type&&(n=te.parse(t)),{kind:\"constant\",evaluate:function(){return n}}}(void 0===e?t.specification.default:e,t.specification)};di.prototype.isDataDriven=function(){return\"source\"===this.expression.kind||\"composite\"===this.expression.kind},di.prototype.possiblyEvaluate=function(t,e,r){return this.property.possiblyEvaluate(this,t,e,r)};var mi=function(t){this.property=t,this.value=new di(t,void 0)};mi.prototype.transitioned=function(t,e){return new vi(this.property,this.value,e,u({},t.transition,this.transition),t.now)},mi.prototype.untransitioned=function(){return new vi(this.property,this.value,null,{},0)};var gi=function(t){this._properties=t,this._values=Object.create(t.defaultTransitionablePropertyValues)};gi.prototype.getValue=function(t){return x(this._values[t].value.value)},gi.prototype.setValue=function(t,e){this._values.hasOwnProperty(t)||(this._values[t]=new mi(this._values[t].property)),this._values[t].value=new di(this._values[t].property,null===e?void 0:x(e))},gi.prototype.getTransition=function(t){return x(this._values[t].transition)},gi.prototype.setTransition=function(t,e){this._values.hasOwnProperty(t)||(this._values[t]=new mi(this._values[t].property)),this._values[t].transition=x(e)||void 0},gi.prototype.serialize=function(){for(var t={},e=0,r=Object.keys(this._values);e<r.length;e+=1){var n=r[e],i=this.getValue(n);void 0!==i&&(t[n]=i);var a=this.getTransition(n);void 0!==a&&(t[n+\"-transition\"]=a)}return t},gi.prototype.transitioned=function(t,e){for(var r=new yi(this._properties),n=0,i=Object.keys(this._values);n<i.length;n+=1){var a=i[n];r._values[a]=this._values[a].transitioned(t,e._values[a])}return r},gi.prototype.untransitioned=function(){for(var t=new yi(this._properties),e=0,r=Object.keys(this._values);e<r.length;e+=1){var n=r[e];t._values[n]=this._values[n].untransitioned()}return t};var vi=function(t,e,r,n,i){this.property=t,this.value=e,this.begin=i+n.delay||0,this.end=this.begin+n.duration||0,t.specification.transition&&(n.delay||n.duration)&&(this.prior=r)};vi.prototype.possiblyEvaluate=function(t,e,r){var n=t.now||0,i=this.value.possiblyEvaluate(t,e,r),a=this.prior;if(a){if(n>this.end)return this.prior=null,i;if(this.value.isDataDriven())return this.prior=null,i;if(n<this.begin)return a.possiblyEvaluate(t,e,r);var o=(n-this.begin)/(this.end-this.begin);return this.property.interpolate(a.possiblyEvaluate(t,e,r),i,function(t){if(t<=0)return 0;if(t>=1)return 1;var e=t*t,r=e*t;return 4*(t<.5?r:3*(t-e)+r-.75)}(o))}return i};var yi=function(t){this._properties=t,this._values=Object.create(t.defaultTransitioningPropertyValues)};yi.prototype.possiblyEvaluate=function(t,e,r){for(var n=new _i(this._properties),i=0,a=Object.keys(this._values);i<a.length;i+=1){var o=a[i];n._values[o]=this._values[o].possiblyEvaluate(t,e,r)}return n},yi.prototype.hasTransition=function(){for(var t=0,e=Object.keys(this._values);t<e.length;t+=1){var r=e[t];if(this._values[r].prior)return!0}return!1};var xi=function(t){this._properties=t,this._values=Object.create(t.defaultPropertyValues)};xi.prototype.getValue=function(t){return x(this._values[t].value)},xi.prototype.setValue=function(t,e){this._values[t]=new di(this._values[t].property,null===e?void 0:x(e))},xi.prototype.serialize=function(){for(var t={},e=0,r=Object.keys(this._values);e<r.length;e+=1){var n=r[e],i=this.getValue(n);void 0!==i&&(t[n]=i)}return t},xi.prototype.possiblyEvaluate=function(t,e,r){for(var n=new _i(this._properties),i=0,a=Object.keys(this._values);i<a.length;i+=1){var o=a[i];n._values[o]=this._values[o].possiblyEvaluate(t,e,r)}return n};var bi=function(t,e,r){this.property=t,this.value=e,this.parameters=r};bi.prototype.isConstant=function(){return\"constant\"===this.value.kind},bi.prototype.constantOr=function(t){return\"constant\"===this.value.kind?this.value.value:t},bi.prototype.evaluate=function(t,e,r,n){return this.property.evaluate(this.value,this.parameters,t,e,r,n)};var _i=function(t){this._properties=t,this._values=Object.create(t.defaultPossiblyEvaluatedValues)};_i.prototype.get=function(t){return this._values[t]};var wi=function(t){this.specification=t};wi.prototype.possiblyEvaluate=function(t,e){return t.expression.evaluate(e)},wi.prototype.interpolate=function(t,e,r){var n=Ge[this.specification.type];return n?n(t,e,r):t};var Ti=function(t,e){this.specification=t,this.overrides=e};Ti.prototype.possiblyEvaluate=function(t,e,r,n){return\"constant\"===t.expression.kind||\"camera\"===t.expression.kind?new bi(this,{kind:\"constant\",value:t.expression.evaluate(e,null,{},r,n)},e):new bi(this,t.expression,e)},Ti.prototype.interpolate=function(t,e,r){if(\"constant\"!==t.value.kind||\"constant\"!==e.value.kind)return t;if(void 0===t.value.value||void 0===e.value.value)return new bi(this,{kind:\"constant\",value:void 0},t.parameters);var n=Ge[this.specification.type];return n?new bi(this,{kind:\"constant\",value:n(t.value.value,e.value.value,r)},t.parameters):t},Ti.prototype.evaluate=function(t,e,r,n,i,a){return\"constant\"===t.kind?t.value:t.evaluate(e,r,n,i,a)};var ki=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.possiblyEvaluate=function(t,e,r,n){if(void 0===t.value)return new bi(this,{kind:\"constant\",value:void 0},e);if(\"constant\"===t.expression.kind){var i=t.expression.evaluate(e,null,{},r,n),a=\"resolvedImage\"===t.property.specification.type&&\"string\"!=typeof i?i.name:i,o=this._calculate(a,a,a,e);return new bi(this,{kind:\"constant\",value:o},e)}if(\"camera\"===t.expression.kind){var s=this._calculate(t.expression.evaluate({zoom:e.zoom-1}),t.expression.evaluate({zoom:e.zoom}),t.expression.evaluate({zoom:e.zoom+1}),e);return new bi(this,{kind:\"constant\",value:s},e)}return new bi(this,t.expression,e)},e.prototype.evaluate=function(t,e,r,n,i,a){if(\"source\"===t.kind){var o=t.evaluate(e,r,n,i,a);return this._calculate(o,o,o,e)}return\"composite\"===t.kind?this._calculate(t.evaluate({zoom:Math.floor(e.zoom)-1},r,n),t.evaluate({zoom:Math.floor(e.zoom)},r,n),t.evaluate({zoom:Math.floor(e.zoom)+1},r,n),e):t.value},e.prototype._calculate=function(t,e,r,n){return n.zoom>n.zoomHistory.lastIntegerZoom?{from:t,to:e}:{from:r,to:e}},e.prototype.interpolate=function(t){return t},e}(Ti),Mi=function(t){this.specification=t};Mi.prototype.possiblyEvaluate=function(t,e,r,n){if(void 0!==t.value){if(\"constant\"===t.expression.kind){var i=t.expression.evaluate(e,null,{},r,n);return this._calculate(i,i,i,e)}return this._calculate(t.expression.evaluate(new pi(Math.floor(e.zoom-1),e)),t.expression.evaluate(new pi(Math.floor(e.zoom),e)),t.expression.evaluate(new pi(Math.floor(e.zoom+1),e)),e)}},Mi.prototype._calculate=function(t,e,r,n){return n.zoom>n.zoomHistory.lastIntegerZoom?{from:t,to:e}:{from:r,to:e}},Mi.prototype.interpolate=function(t){return t};var Ai=function(t){this.specification=t};Ai.prototype.possiblyEvaluate=function(t,e,r,n){return!!t.expression.evaluate(e,null,{},r,n)},Ai.prototype.interpolate=function(){return!1};var Si=function(t){for(var e in this.properties=t,this.defaultPropertyValues={},this.defaultTransitionablePropertyValues={},this.defaultTransitioningPropertyValues={},this.defaultPossiblyEvaluatedValues={},this.overridableProperties=[],t){var r=t[e];r.specification.overridable&&this.overridableProperties.push(e);var n=this.defaultPropertyValues[e]=new di(r,void 0),i=this.defaultTransitionablePropertyValues[e]=new mi(r);this.defaultTransitioningPropertyValues[e]=i.untransitioned(),this.defaultPossiblyEvaluatedValues[e]=n.possiblyEvaluate({})}};Nn(\"DataDrivenProperty\",Ti),Nn(\"DataConstantProperty\",wi),Nn(\"CrossFadedDataDrivenProperty\",ki),Nn(\"CrossFadedProperty\",Mi),Nn(\"ColorRampProperty\",Ai);var Ei=function(t){function e(e,r){if(t.call(this),this.id=e.id,this.type=e.type,this._featureFilter={filter:function(){return!0},needGeometry:!1},\"custom\"!==e.type&&(e=e,this.metadata=e.metadata,this.minzoom=e.minzoom,this.maxzoom=e.maxzoom,\"background\"!==e.type&&(this.source=e.source,this.sourceLayer=e[\"source-layer\"],this.filter=e.filter),r.layout&&(this._unevaluatedLayout=new xi(r.layout)),r.paint)){for(var n in this._transitionablePaint=new gi(r.paint),e.paint)this.setPaintProperty(n,e.paint[n],{validate:!1});for(var i in e.layout)this.setLayoutProperty(i,e.layout[i],{validate:!1});this._transitioningPaint=this._transitionablePaint.untransitioned(),this.paint=new _i(r.paint)}}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getCrossfadeParameters=function(){return this._crossfadeParameters},e.prototype.getLayoutProperty=function(t){return\"visibility\"===t?this.visibility:this._unevaluatedLayout.getValue(t)},e.prototype.setLayoutProperty=function(t,e,r){if(void 0===r&&(r={}),null!=e){var n=\"layers.\"+this.id+\".layout.\"+t;if(this._validate(In,n,t,e,r))return}\"visibility\"!==t?this._unevaluatedLayout.setValue(t,e):this.visibility=e},e.prototype.getPaintProperty=function(t){return g(t,\"-transition\")?this._transitionablePaint.getTransition(t.slice(0,-\"-transition\".length)):this._transitionablePaint.getValue(t)},e.prototype.setPaintProperty=function(t,e,r){if(void 0===r&&(r={}),null!=e){var n=\"layers.\"+this.id+\".paint.\"+t;if(this._validate(Pn,n,t,e,r))return!1}if(g(t,\"-transition\"))return this._transitionablePaint.setTransition(t.slice(0,-\"-transition\".length),e||void 0),!1;var i=this._transitionablePaint._values[t],a=\"cross-faded-data-driven\"===i.property.specification[\"property-type\"],o=i.value.isDataDriven(),s=i.value;this._transitionablePaint.setValue(t,e),this._handleSpecialPaintPropertyUpdate(t);var l=this._transitionablePaint._values[t].value;return l.isDataDriven()||o||a||this._handleOverridablePaintPropertyUpdate(t,s,l)},e.prototype._handleSpecialPaintPropertyUpdate=function(t){},e.prototype._handleOverridablePaintPropertyUpdate=function(t,e,r){return!1},e.prototype.isHidden=function(t){return!!(this.minzoom&&t<this.minzoom)||(!!(this.maxzoom&&t>=this.maxzoom)||\"none\"===this.visibility)},e.prototype.updateTransitions=function(t){this._transitioningPaint=this._transitionablePaint.transitioned(t,this._transitioningPaint)},e.prototype.hasTransition=function(){return this._transitioningPaint.hasTransition()},e.prototype.recalculate=function(t,e){t.getCrossfadeParameters&&(this._crossfadeParameters=t.getCrossfadeParameters()),this._unevaluatedLayout&&(this.layout=this._unevaluatedLayout.possiblyEvaluate(t,void 0,e)),this.paint=this._transitioningPaint.possiblyEvaluate(t,void 0,e)},e.prototype.serialize=function(){var t={id:this.id,type:this.type,source:this.source,\"source-layer\":this.sourceLayer,metadata:this.metadata,minzoom:this.minzoom,maxzoom:this.maxzoom,filter:this.filter,layout:this._unevaluatedLayout&&this._unevaluatedLayout.serialize(),paint:this._transitionablePaint&&this._transitionablePaint.serialize()};return this.visibility&&(t.layout=t.layout||{},t.layout.visibility=this.visibility),y(t,(function(t,e){return!(void 0===t||\"layout\"===e&&!Object.keys(t).length||\"paint\"===e&&!Object.keys(t).length)}))},e.prototype._validate=function(t,e,r,n,i){return void 0===i&&(i={}),(!i||!1!==i.validate)&&On(this,t.call(Ln,{key:e,layerType:this.type,objectKey:r,value:n,styleSpec:Lt,style:{glyphs:!0,sprite:!0}}))},e.prototype.is3D=function(){return!1},e.prototype.isTileClipped=function(){return!1},e.prototype.hasOffscreenPass=function(){return!1},e.prototype.resize=function(){},e.prototype.isStateDependent=function(){for(var t in this.paint._values){var e=this.paint.get(t);if(e instanceof bi&&zr(e.property.specification)&&((\"source\"===e.value.kind||\"composite\"===e.value.kind)&&e.value.isStateDependent))return!0}return!1},e}(Et),Li={Int8:Int8Array,Uint8:Uint8Array,Int16:Int16Array,Uint16:Uint16Array,Int32:Int32Array,Uint32:Uint32Array,Float32:Float32Array},Ci=function(t,e){this._structArray=t,this._pos1=e*this.size,this._pos2=this._pos1/2,this._pos4=this._pos1/4,this._pos8=this._pos1/8},Pi=function(){this.isTransferred=!1,this.capacity=-1,this.resize(0)};function Ii(t,e){void 0===e&&(e=1);var r=0,n=0;return{members:t.map((function(t){var i,a=(i=t.type,Li[i].BYTES_PER_ELEMENT),o=r=Oi(r,Math.max(e,a)),s=t.components||1;return n=Math.max(n,a),r+=a*s,{name:t.name,type:t.type,components:s,offset:o}})),size:Oi(r,Math.max(n,e)),alignment:e}}function Oi(t,e){return Math.ceil(t/e)*e}Pi.serialize=function(t,e){return t._trim(),e&&(t.isTransferred=!0,e.push(t.arrayBuffer)),{length:t.length,arrayBuffer:t.arrayBuffer}},Pi.deserialize=function(t){var e=Object.create(this.prototype);return e.arrayBuffer=t.arrayBuffer,e.length=t.length,e.capacity=t.arrayBuffer.byteLength/e.bytesPerElement,e._refreshViews(),e},Pi.prototype._trim=function(){this.length!==this.capacity&&(this.capacity=this.length,this.arrayBuffer=this.arrayBuffer.slice(0,this.length*this.bytesPerElement),this._refreshViews())},Pi.prototype.clear=function(){this.length=0},Pi.prototype.resize=function(t){this.reserve(t),this.length=t},Pi.prototype.reserve=function(t){if(t>this.capacity){this.capacity=Math.max(t,Math.floor(5*this.capacity),128),this.arrayBuffer=new ArrayBuffer(this.capacity*this.bytesPerElement);var e=this.uint8;this._refreshViews(),e&&this.uint8.set(e)}},Pi.prototype._refreshViews=function(){throw new Error(\"_refreshViews() must be implemented by each concrete StructArray layout\")};var zi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e){var r=this.length;return this.resize(r+1),this.emplace(r,t,e)},e.prototype.emplace=function(t,e,r){var n=2*t;return this.int16[n+0]=e,this.int16[n+1]=r,t},e}(Pi);zi.prototype.bytesPerElement=4,Nn(\"StructArrayLayout2i4\",zi);var Di=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n){var i=this.length;return this.resize(i+1),this.emplace(i,t,e,r,n)},e.prototype.emplace=function(t,e,r,n,i){var a=4*t;return this.int16[a+0]=e,this.int16[a+1]=r,this.int16[a+2]=n,this.int16[a+3]=i,t},e}(Pi);Di.prototype.bytesPerElement=8,Nn(\"StructArrayLayout4i8\",Di);var Ri=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,i,a){var o=this.length;return this.resize(o+1),this.emplace(o,t,e,r,n,i,a)},e.prototype.emplace=function(t,e,r,n,i,a,o){var s=6*t;return this.int16[s+0]=e,this.int16[s+1]=r,this.int16[s+2]=n,this.int16[s+3]=i,this.int16[s+4]=a,this.int16[s+5]=o,t},e}(Pi);Ri.prototype.bytesPerElement=12,Nn(\"StructArrayLayout2i4i12\",Ri);var Fi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,i,a){var o=this.length;return this.resize(o+1),this.emplace(o,t,e,r,n,i,a)},e.prototype.emplace=function(t,e,r,n,i,a,o){var s=4*t,l=8*t;return this.int16[s+0]=e,this.int16[s+1]=r,this.uint8[l+4]=n,this.uint8[l+5]=i,this.uint8[l+6]=a,this.uint8[l+7]=o,t},e}(Pi);Fi.prototype.bytesPerElement=8,Nn(\"StructArrayLayout2i4ub8\",Fi);var Bi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,i,a,o,s,l,c){var u=this.length;return this.resize(u+1),this.emplace(u,t,e,r,n,i,a,o,s,l,c)},e.prototype.emplace=function(t,e,r,n,i,a,o,s,l,c,u){var f=9*t,h=18*t;return this.uint16[f+0]=e,this.uint16[f+1]=r,this.uint16[f+2]=n,this.uint16[f+3]=i,this.uint16[f+4]=a,this.uint16[f+5]=o,this.uint16[f+6]=s,this.uint16[f+7]=l,this.uint8[h+16]=c,this.uint8[h+17]=u,t},e}(Pi);Bi.prototype.bytesPerElement=18,Nn(\"StructArrayLayout8ui2ub18\",Bi);var Ni=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,i,a,o,s,l,c,u,f){var h=this.length;return this.resize(h+1),this.emplace(h,t,e,r,n,i,a,o,s,l,c,u,f)},e.prototype.emplace=function(t,e,r,n,i,a,o,s,l,c,u,f,h){var p=12*t;return this.int16[p+0]=e,this.int16[p+1]=r,this.int16[p+2]=n,this.int16[p+3]=i,this.uint16[p+4]=a,this.uint16[p+5]=o,this.uint16[p+6]=s,this.uint16[p+7]=l,this.int16[p+8]=c,this.int16[p+9]=u,this.int16[p+10]=f,this.int16[p+11]=h,t},e}(Pi);Ni.prototype.bytesPerElement=24,Nn(\"StructArrayLayout4i4ui4i24\",Ni);var ji=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r){var n=this.length;return this.resize(n+1),this.emplace(n,t,e,r)},e.prototype.emplace=function(t,e,r,n){var i=3*t;return this.float32[i+0]=e,this.float32[i+1]=r,this.float32[i+2]=n,t},e}(Pi);ji.prototype.bytesPerElement=12,Nn(\"StructArrayLayout3f12\",ji);var Ui=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.uint32=new Uint32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t){var e=this.length;return this.resize(e+1),this.emplace(e,t)},e.prototype.emplace=function(t,e){var r=1*t;return this.uint32[r+0]=e,t},e}(Pi);Ui.prototype.bytesPerElement=4,Nn(\"StructArrayLayout1ul4\",Ui);var Vi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer),this.uint32=new Uint32Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,i,a,o,s,l){var c=this.length;return this.resize(c+1),this.emplace(c,t,e,r,n,i,a,o,s,l)},e.prototype.emplace=function(t,e,r,n,i,a,o,s,l,c){var u=10*t,f=5*t;return this.int16[u+0]=e,this.int16[u+1]=r,this.int16[u+2]=n,this.int16[u+3]=i,this.int16[u+4]=a,this.int16[u+5]=o,this.uint32[f+3]=s,this.uint16[u+8]=l,this.uint16[u+9]=c,t},e}(Pi);Vi.prototype.bytesPerElement=20,Nn(\"StructArrayLayout6i1ul2ui20\",Vi);var qi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,i,a){var o=this.length;return this.resize(o+1),this.emplace(o,t,e,r,n,i,a)},e.prototype.emplace=function(t,e,r,n,i,a,o){var s=6*t;return this.int16[s+0]=e,this.int16[s+1]=r,this.int16[s+2]=n,this.int16[s+3]=i,this.int16[s+4]=a,this.int16[s+5]=o,t},e}(Pi);qi.prototype.bytesPerElement=12,Nn(\"StructArrayLayout2i2i2i12\",qi);var Hi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,i){var a=this.length;return this.resize(a+1),this.emplace(a,t,e,r,n,i)},e.prototype.emplace=function(t,e,r,n,i,a){var o=4*t,s=8*t;return this.float32[o+0]=e,this.float32[o+1]=r,this.float32[o+2]=n,this.int16[s+6]=i,this.int16[s+7]=a,t},e}(Pi);Hi.prototype.bytesPerElement=16,Nn(\"StructArrayLayout2f1f2i16\",Hi);var Gi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n){var i=this.length;return this.resize(i+1),this.emplace(i,t,e,r,n)},e.prototype.emplace=function(t,e,r,n,i){var a=12*t,o=3*t;return this.uint8[a+0]=e,this.uint8[a+1]=r,this.float32[o+1]=n,this.float32[o+2]=i,t},e}(Pi);Gi.prototype.bytesPerElement=12,Nn(\"StructArrayLayout2ub2f12\",Gi);var Yi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r){var n=this.length;return this.resize(n+1),this.emplace(n,t,e,r)},e.prototype.emplace=function(t,e,r,n){var i=3*t;return this.uint16[i+0]=e,this.uint16[i+1]=r,this.uint16[i+2]=n,t},e}(Pi);Yi.prototype.bytesPerElement=6,Nn(\"StructArrayLayout3ui6\",Yi);var Wi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer),this.uint32=new Uint32Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,i,a,o,s,l,c,u,f,h,p,d,m,g){var v=this.length;return this.resize(v+1),this.emplace(v,t,e,r,n,i,a,o,s,l,c,u,f,h,p,d,m,g)},e.prototype.emplace=function(t,e,r,n,i,a,o,s,l,c,u,f,h,p,d,m,g,v){var y=24*t,x=12*t,b=48*t;return this.int16[y+0]=e,this.int16[y+1]=r,this.uint16[y+2]=n,this.uint16[y+3]=i,this.uint32[x+2]=a,this.uint32[x+3]=o,this.uint32[x+4]=s,this.uint16[y+10]=l,this.uint16[y+11]=c,this.uint16[y+12]=u,this.float32[x+7]=f,this.float32[x+8]=h,this.uint8[b+36]=p,this.uint8[b+37]=d,this.uint8[b+38]=m,this.uint32[x+10]=g,this.int16[y+22]=v,t},e}(Pi);Wi.prototype.bytesPerElement=48,Nn(\"StructArrayLayout2i2ui3ul3ui2f3ub1ul1i48\",Wi);var Xi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer),this.uint32=new Uint32Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,i,a,o,s,l,c,u,f,h,p,d,m,g,v,y,x,b,_,w,T,k,M,A,S){var E=this.length;return this.resize(E+1),this.emplace(E,t,e,r,n,i,a,o,s,l,c,u,f,h,p,d,m,g,v,y,x,b,_,w,T,k,M,A,S)},e.prototype.emplace=function(t,e,r,n,i,a,o,s,l,c,u,f,h,p,d,m,g,v,y,x,b,_,w,T,k,M,A,S,E){var L=34*t,C=17*t;return this.int16[L+0]=e,this.int16[L+1]=r,this.int16[L+2]=n,this.int16[L+3]=i,this.int16[L+4]=a,this.int16[L+5]=o,this.int16[L+6]=s,this.int16[L+7]=l,this.uint16[L+8]=c,this.uint16[L+9]=u,this.uint16[L+10]=f,this.uint16[L+11]=h,this.uint16[L+12]=p,this.uint16[L+13]=d,this.uint16[L+14]=m,this.uint16[L+15]=g,this.uint16[L+16]=v,this.uint16[L+17]=y,this.uint16[L+18]=x,this.uint16[L+19]=b,this.uint16[L+20]=_,this.uint16[L+21]=w,this.uint16[L+22]=T,this.uint32[C+12]=k,this.float32[C+13]=M,this.float32[C+14]=A,this.float32[C+15]=S,this.float32[C+16]=E,t},e}(Pi);Xi.prototype.bytesPerElement=68,Nn(\"StructArrayLayout8i15ui1ul4f68\",Xi);var Zi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t){var e=this.length;return this.resize(e+1),this.emplace(e,t)},e.prototype.emplace=function(t,e){var r=1*t;return this.float32[r+0]=e,t},e}(Pi);Zi.prototype.bytesPerElement=4,Nn(\"StructArrayLayout1f4\",Zi);var Ji=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r){var n=this.length;return this.resize(n+1),this.emplace(n,t,e,r)},e.prototype.emplace=function(t,e,r,n){var i=3*t;return this.int16[i+0]=e,this.int16[i+1]=r,this.int16[i+2]=n,t},e}(Pi);Ji.prototype.bytesPerElement=6,Nn(\"StructArrayLayout3i6\",Ji);var Ki=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.uint32=new Uint32Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r){var n=this.length;return this.resize(n+1),this.emplace(n,t,e,r)},e.prototype.emplace=function(t,e,r,n){var i=2*t,a=4*t;return this.uint32[i+0]=e,this.uint16[a+2]=r,this.uint16[a+3]=n,t},e}(Pi);Ki.prototype.bytesPerElement=8,Nn(\"StructArrayLayout1ul2ui8\",Ki);var Qi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e){var r=this.length;return this.resize(r+1),this.emplace(r,t,e)},e.prototype.emplace=function(t,e,r){var n=2*t;return this.uint16[n+0]=e,this.uint16[n+1]=r,t},e}(Pi);Qi.prototype.bytesPerElement=4,Nn(\"StructArrayLayout2ui4\",Qi);var $i=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t){var e=this.length;return this.resize(e+1),this.emplace(e,t)},e.prototype.emplace=function(t,e){var r=1*t;return this.uint16[r+0]=e,t},e}(Pi);$i.prototype.bytesPerElement=2,Nn(\"StructArrayLayout1ui2\",$i);var ta=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e){var r=this.length;return this.resize(r+1),this.emplace(r,t,e)},e.prototype.emplace=function(t,e,r){var n=2*t;return this.float32[n+0]=e,this.float32[n+1]=r,t},e}(Pi);ta.prototype.bytesPerElement=8,Nn(\"StructArrayLayout2f8\",ta);var ea=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n){var i=this.length;return this.resize(i+1),this.emplace(i,t,e,r,n)},e.prototype.emplace=function(t,e,r,n,i){var a=4*t;return this.float32[a+0]=e,this.float32[a+1]=r,this.float32[a+2]=n,this.float32[a+3]=i,t},e}(Pi);ea.prototype.bytesPerElement=16,Nn(\"StructArrayLayout4f16\",ea);var ra=function(t){function e(){t.apply(this,arguments)}t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e;var r={anchorPointX:{configurable:!0},anchorPointY:{configurable:!0},x1:{configurable:!0},y1:{configurable:!0},x2:{configurable:!0},y2:{configurable:!0},featureIndex:{configurable:!0},sourceLayerIndex:{configurable:!0},bucketIndex:{configurable:!0},anchorPoint:{configurable:!0}};return r.anchorPointX.get=function(){return this._structArray.int16[this._pos2+0]},r.anchorPointY.get=function(){return this._structArray.int16[this._pos2+1]},r.x1.get=function(){return this._structArray.int16[this._pos2+2]},r.y1.get=function(){return this._structArray.int16[this._pos2+3]},r.x2.get=function(){return this._structArray.int16[this._pos2+4]},r.y2.get=function(){return this._structArray.int16[this._pos2+5]},r.featureIndex.get=function(){return this._structArray.uint32[this._pos4+3]},r.sourceLayerIndex.get=function(){return this._structArray.uint16[this._pos2+8]},r.bucketIndex.get=function(){return this._structArray.uint16[this._pos2+9]},r.anchorPoint.get=function(){return new i(this.anchorPointX,this.anchorPointY)},Object.defineProperties(e.prototype,r),e}(Ci);ra.prototype.size=20;var na=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.get=function(t){return new ra(this,t)},e}(Vi);Nn(\"CollisionBoxArray\",na);var ia=function(t){function e(){t.apply(this,arguments)}t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e;var r={anchorX:{configurable:!0},anchorY:{configurable:!0},glyphStartIndex:{configurable:!0},numGlyphs:{configurable:!0},vertexStartIndex:{configurable:!0},lineStartIndex:{configurable:!0},lineLength:{configurable:!0},segment:{configurable:!0},lowerSize:{configurable:!0},upperSize:{configurable:!0},lineOffsetX:{configurable:!0},lineOffsetY:{configurable:!0},writingMode:{configurable:!0},placedOrientation:{configurable:!0},hidden:{configurable:!0},crossTileID:{configurable:!0},associatedIconIndex:{configurable:!0}};return r.anchorX.get=function(){return this._structArray.int16[this._pos2+0]},r.anchorY.get=function(){return this._structArray.int16[this._pos2+1]},r.glyphStartIndex.get=function(){return this._structArray.uint16[this._pos2+2]},r.numGlyphs.get=function(){return this._structArray.uint16[this._pos2+3]},r.vertexStartIndex.get=function(){return this._structArray.uint32[this._pos4+2]},r.lineStartIndex.get=function(){return this._structArray.uint32[this._pos4+3]},r.lineLength.get=function(){return this._structArray.uint32[this._pos4+4]},r.segment.get=function(){return this._structArray.uint16[this._pos2+10]},r.lowerSize.get=function(){return this._structArray.uint16[this._pos2+11]},r.upperSize.get=function(){return this._structArray.uint16[this._pos2+12]},r.lineOffsetX.get=function(){return this._structArray.float32[this._pos4+7]},r.lineOffsetY.get=function(){return this._structArray.float32[this._pos4+8]},r.writingMode.get=function(){return this._structArray.uint8[this._pos1+36]},r.placedOrientation.get=function(){return this._structArray.uint8[this._pos1+37]},r.placedOrientation.set=function(t){this._structArray.uint8[this._pos1+37]=t},r.hidden.get=function(){return this._structArray.uint8[this._pos1+38]},r.hidden.set=function(t){this._structArray.uint8[this._pos1+38]=t},r.crossTileID.get=function(){return this._structArray.uint32[this._pos4+10]},r.crossTileID.set=function(t){this._structArray.uint32[this._pos4+10]=t},r.associatedIconIndex.get=function(){return this._structArray.int16[this._pos2+22]},Object.defineProperties(e.prototype,r),e}(Ci);ia.prototype.size=48;var aa=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.get=function(t){return new ia(this,t)},e}(Wi);Nn(\"PlacedSymbolArray\",aa);var oa=function(t){function e(){t.apply(this,arguments)}t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e;var r={anchorX:{configurable:!0},anchorY:{configurable:!0},rightJustifiedTextSymbolIndex:{configurable:!0},centerJustifiedTextSymbolIndex:{configurable:!0},leftJustifiedTextSymbolIndex:{configurable:!0},verticalPlacedTextSymbolIndex:{configurable:!0},placedIconSymbolIndex:{configurable:!0},verticalPlacedIconSymbolIndex:{configurable:!0},key:{configurable:!0},textBoxStartIndex:{configurable:!0},textBoxEndIndex:{configurable:!0},verticalTextBoxStartIndex:{configurable:!0},verticalTextBoxEndIndex:{configurable:!0},iconBoxStartIndex:{configurable:!0},iconBoxEndIndex:{configurable:!0},verticalIconBoxStartIndex:{configurable:!0},verticalIconBoxEndIndex:{configurable:!0},featureIndex:{configurable:!0},numHorizontalGlyphVertices:{configurable:!0},numVerticalGlyphVertices:{configurable:!0},numIconVertices:{configurable:!0},numVerticalIconVertices:{configurable:!0},useRuntimeCollisionCircles:{configurable:!0},crossTileID:{configurable:!0},textBoxScale:{configurable:!0},textOffset0:{configurable:!0},textOffset1:{configurable:!0},collisionCircleDiameter:{configurable:!0}};return r.anchorX.get=function(){return this._structArray.int16[this._pos2+0]},r.anchorY.get=function(){return this._structArray.int16[this._pos2+1]},r.rightJustifiedTextSymbolIndex.get=function(){return this._structArray.int16[this._pos2+2]},r.centerJustifiedTextSymbolIndex.get=function(){return this._structArray.int16[this._pos2+3]},r.leftJustifiedTextSymbolIndex.get=function(){return this._structArray.int16[this._pos2+4]},r.verticalPlacedTextSymbolIndex.get=function(){return this._structArray.int16[this._pos2+5]},r.placedIconSymbolIndex.get=function(){return this._structArray.int16[this._pos2+6]},r.verticalPlacedIconSymbolIndex.get=function(){return this._structArray.int16[this._pos2+7]},r.key.get=function(){return this._structArray.uint16[this._pos2+8]},r.textBoxStartIndex.get=function(){return this._structArray.uint16[this._pos2+9]},r.textBoxEndIndex.get=function(){return this._structArray.uint16[this._pos2+10]},r.verticalTextBoxStartIndex.get=function(){return this._structArray.uint16[this._pos2+11]},r.verticalTextBoxEndIndex.get=function(){return this._structArray.uint16[this._pos2+12]},r.iconBoxStartIndex.get=function(){return this._structArray.uint16[this._pos2+13]},r.iconBoxEndIndex.get=function(){return this._structArray.uint16[this._pos2+14]},r.verticalIconBoxStartIndex.get=function(){return this._structArray.uint16[this._pos2+15]},r.verticalIconBoxEndIndex.get=function(){return this._structArray.uint16[this._pos2+16]},r.featureIndex.get=function(){return this._structArray.uint16[this._pos2+17]},r.numHorizontalGlyphVertices.get=function(){return this._structArray.uint16[this._pos2+18]},r.numVerticalGlyphVertices.get=function(){return this._structArray.uint16[this._pos2+19]},r.numIconVertices.get=function(){return this._structArray.uint16[this._pos2+20]},r.numVerticalIconVertices.get=function(){return this._structArray.uint16[this._pos2+21]},r.useRuntimeCollisionCircles.get=function(){return this._structArray.uint16[this._pos2+22]},r.crossTileID.get=function(){return this._structArray.uint32[this._pos4+12]},r.crossTileID.set=function(t){this._structArray.uint32[this._pos4+12]=t},r.textBoxScale.get=function(){return this._structArray.float32[this._pos4+13]},r.textOffset0.get=function(){return this._structArray.float32[this._pos4+14]},r.textOffset1.get=function(){return this._structArray.float32[this._pos4+15]},r.collisionCircleDiameter.get=function(){return this._structArray.float32[this._pos4+16]},Object.defineProperties(e.prototype,r),e}(Ci);oa.prototype.size=68;var sa=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.get=function(t){return new oa(this,t)},e}(Xi);Nn(\"SymbolInstanceArray\",sa);var la=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getoffsetX=function(t){return this.float32[1*t+0]},e}(Zi);Nn(\"GlyphOffsetArray\",la);var ca=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getx=function(t){return this.int16[3*t+0]},e.prototype.gety=function(t){return this.int16[3*t+1]},e.prototype.gettileUnitDistanceFromAnchor=function(t){return this.int16[3*t+2]},e}(Ji);Nn(\"SymbolLineVertexArray\",ca);var ua=function(t){function e(){t.apply(this,arguments)}t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e;var r={featureIndex:{configurable:!0},sourceLayerIndex:{configurable:!0},bucketIndex:{configurable:!0}};return r.featureIndex.get=function(){return this._structArray.uint32[this._pos4+0]},r.sourceLayerIndex.get=function(){return this._structArray.uint16[this._pos2+2]},r.bucketIndex.get=function(){return this._structArray.uint16[this._pos2+3]},Object.defineProperties(e.prototype,r),e}(Ci);ua.prototype.size=8;var fa=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.get=function(t){return new ua(this,t)},e}(Ki);Nn(\"FeatureIndexArray\",fa);var ha=Ii([{name:\"a_pos\",components:2,type:\"Int16\"}],4).members,pa=function(t){void 0===t&&(t=[]),this.segments=t};function da(t,e){return 256*(t=l(Math.floor(t),0,255))+(e=l(Math.floor(e),0,255))}pa.prototype.prepareSegment=function(t,e,r,n){var i=this.segments[this.segments.length-1];return t>pa.MAX_VERTEX_ARRAY_LENGTH&&_(\"Max vertices per segment is \"+pa.MAX_VERTEX_ARRAY_LENGTH+\": bucket requested \"+t),(!i||i.vertexLength+t>pa.MAX_VERTEX_ARRAY_LENGTH||i.sortKey!==n)&&(i={vertexOffset:e.length,primitiveOffset:r.length,vertexLength:0,primitiveLength:0},void 0!==n&&(i.sortKey=n),this.segments.push(i)),i},pa.prototype.get=function(){return this.segments},pa.prototype.destroy=function(){for(var t=0,e=this.segments;t<e.length;t+=1){var r=e[t];for(var n in r.vaos)r.vaos[n].destroy()}},pa.simpleSegment=function(t,e,r,n){return new pa([{vertexOffset:t,primitiveOffset:e,vertexLength:r,primitiveLength:n,vaos:{},sortKey:0}])},pa.MAX_VERTEX_ARRAY_LENGTH=Math.pow(2,16)-1,Nn(\"SegmentVector\",pa);var ma=Ii([{name:\"a_pattern_from\",components:4,type:\"Uint16\"},{name:\"a_pattern_to\",components:4,type:\"Uint16\"},{name:\"a_pixel_ratio_from\",components:1,type:\"Uint8\"},{name:\"a_pixel_ratio_to\",components:1,type:\"Uint8\"}]),ga=e((function(t){t.exports=function(t,e){var r,n,i,a,o,s,l,c;for(r=3&t.length,n=t.length-r,i=e,o=3432918353,s=461845907,c=0;c<n;)l=255&t.charCodeAt(c)|(255&t.charCodeAt(++c))<<8|(255&t.charCodeAt(++c))<<16|(255&t.charCodeAt(++c))<<24,++c,i=27492+(65535&(a=5*(65535&(i=(i^=l=(65535&(l=(l=(65535&l)*o+(((l>>>16)*o&65535)<<16)&4294967295)<<15|l>>>17))*s+(((l>>>16)*s&65535)<<16)&4294967295)<<13|i>>>19))+((5*(i>>>16)&65535)<<16)&4294967295))+((58964+(a>>>16)&65535)<<16);switch(l=0,r){case 3:l^=(255&t.charCodeAt(c+2))<<16;case 2:l^=(255&t.charCodeAt(c+1))<<8;case 1:i^=l=(65535&(l=(l=(65535&(l^=255&t.charCodeAt(c)))*o+(((l>>>16)*o&65535)<<16)&4294967295)<<15|l>>>17))*s+(((l>>>16)*s&65535)<<16)&4294967295}return i^=t.length,i=2246822507*(65535&(i^=i>>>16))+((2246822507*(i>>>16)&65535)<<16)&4294967295,i=3266489909*(65535&(i^=i>>>13))+((3266489909*(i>>>16)&65535)<<16)&4294967295,(i^=i>>>16)>>>0}})),va=e((function(t){t.exports=function(t,e){for(var r,n=t.length,i=e^n,a=0;n>=4;)r=1540483477*(65535&(r=255&t.charCodeAt(a)|(255&t.charCodeAt(++a))<<8|(255&t.charCodeAt(++a))<<16|(255&t.charCodeAt(++a))<<24))+((1540483477*(r>>>16)&65535)<<16),i=1540483477*(65535&i)+((1540483477*(i>>>16)&65535)<<16)^(r=1540483477*(65535&(r^=r>>>24))+((1540483477*(r>>>16)&65535)<<16)),n-=4,++a;switch(n){case 3:i^=(255&t.charCodeAt(a+2))<<16;case 2:i^=(255&t.charCodeAt(a+1))<<8;case 1:i=1540483477*(65535&(i^=255&t.charCodeAt(a)))+((1540483477*(i>>>16)&65535)<<16)}return i=1540483477*(65535&(i^=i>>>13))+((1540483477*(i>>>16)&65535)<<16),(i^=i>>>15)>>>0}})),ya=ga,xa=ga,ba=va;ya.murmur3=xa,ya.murmur2=ba;var _a=function(){this.ids=[],this.positions=[],this.indexed=!1};_a.prototype.add=function(t,e,r,n){this.ids.push(Ta(t)),this.positions.push(e,r,n)},_a.prototype.getPositions=function(t){for(var e=Ta(t),r=0,n=this.ids.length-1;r<n;){var i=r+n>>1;this.ids[i]>=e?n=i:r=i+1}for(var a=[];this.ids[r]===e;){var o=this.positions[3*r],s=this.positions[3*r+1],l=this.positions[3*r+2];a.push({index:o,start:s,end:l}),r++}return a},_a.serialize=function(t,e){var r=new Float64Array(t.ids),n=new Uint32Array(t.positions);return function t(e,r,n,i){for(;n<i;){for(var a=e[n+i>>1],o=n-1,s=i+1;;){do{o++}while(e[o]<a);do{s--}while(e[s]>a);if(o>=s)break;ka(e,o,s),ka(r,3*o,3*s),ka(r,3*o+1,3*s+1),ka(r,3*o+2,3*s+2)}s-n<i-s?(t(e,r,n,s),n=s+1):(t(e,r,s+1,i),i=s)}}(r,n,0,r.length-1),e&&e.push(r.buffer,n.buffer),{ids:r,positions:n}},_a.deserialize=function(t){var e=new _a;return e.ids=t.ids,e.positions=t.positions,e.indexed=!0,e};var wa=Math.pow(2,53)-1;function Ta(t){var e=+t;return!isNaN(e)&&e<=wa?e:ya(String(t))}function ka(t,e,r){var n=t[e];t[e]=t[r],t[r]=n}Nn(\"FeaturePositionMap\",_a);var Ma=function(t,e){this.gl=t.gl,this.location=e},Aa=function(t){function e(e,r){t.call(this,e,r),this.current=0}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.set=function(t){this.current!==t&&(this.current=t,this.gl.uniform1i(this.location,t))},e}(Ma),Sa=function(t){function e(e,r){t.call(this,e,r),this.current=0}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.set=function(t){this.current!==t&&(this.current=t,this.gl.uniform1f(this.location,t))},e}(Ma),Ea=function(t){function e(e,r){t.call(this,e,r),this.current=[0,0]}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.set=function(t){t[0]===this.current[0]&&t[1]===this.current[1]||(this.current=t,this.gl.uniform2f(this.location,t[0],t[1]))},e}(Ma),La=function(t){function e(e,r){t.call(this,e,r),this.current=[0,0,0]}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.set=function(t){t[0]===this.current[0]&&t[1]===this.current[1]&&t[2]===this.current[2]||(this.current=t,this.gl.uniform3f(this.location,t[0],t[1],t[2]))},e}(Ma),Ca=function(t){function e(e,r){t.call(this,e,r),this.current=[0,0,0,0]}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.set=function(t){t[0]===this.current[0]&&t[1]===this.current[1]&&t[2]===this.current[2]&&t[3]===this.current[3]||(this.current=t,this.gl.uniform4f(this.location,t[0],t[1],t[2],t[3]))},e}(Ma),Pa=function(t){function e(e,r){t.call(this,e,r),this.current=te.transparent}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.set=function(t){t.r===this.current.r&&t.g===this.current.g&&t.b===this.current.b&&t.a===this.current.a||(this.current=t,this.gl.uniform4f(this.location,t.r,t.g,t.b,t.a))},e}(Ma),Ia=new Float32Array(16),Oa=function(t){function e(e,r){t.call(this,e,r),this.current=Ia}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.set=function(t){if(t[12]!==this.current[12]||t[0]!==this.current[0])return this.current=t,void this.gl.uniformMatrix4fv(this.location,!1,t);for(var e=1;e<16;e++)if(t[e]!==this.current[e]){this.current=t,this.gl.uniformMatrix4fv(this.location,!1,t);break}},e}(Ma);function za(t){return[da(255*t.r,255*t.g),da(255*t.b,255*t.a)]}var Da=function(t,e,r){this.value=t,this.uniformNames=e.map((function(t){return\"u_\"+t})),this.type=r};Da.prototype.setUniform=function(t,e,r){t.set(r.constantOr(this.value))},Da.prototype.getBinding=function(t,e,r){return\"color\"===this.type?new Pa(t,e):new Sa(t,e)};var Ra=function(t,e){this.uniformNames=e.map((function(t){return\"u_\"+t})),this.patternFrom=null,this.patternTo=null,this.pixelRatioFrom=1,this.pixelRatioTo=1};Ra.prototype.setConstantPatternPositions=function(t,e){this.pixelRatioFrom=e.pixelRatio,this.pixelRatioTo=t.pixelRatio,this.patternFrom=e.tlbr,this.patternTo=t.tlbr},Ra.prototype.setUniform=function(t,e,r,n){var i=\"u_pattern_to\"===n?this.patternTo:\"u_pattern_from\"===n?this.patternFrom:\"u_pixel_ratio_to\"===n?this.pixelRatioTo:\"u_pixel_ratio_from\"===n?this.pixelRatioFrom:null;i&&t.set(i)},Ra.prototype.getBinding=function(t,e,r){return\"u_pattern\"===r.substr(0,9)?new Ca(t,e):new Sa(t,e)};var Fa=function(t,e,r,n){this.expression=t,this.type=r,this.maxValue=0,this.paintVertexAttributes=e.map((function(t){return{name:\"a_\"+t,type:\"Float32\",components:\"color\"===r?2:1,offset:0}})),this.paintVertexArray=new n};Fa.prototype.populatePaintArray=function(t,e,r,n,i){var a=this.paintVertexArray.length,o=this.expression.evaluate(new pi(0),e,{},n,[],i);this.paintVertexArray.resize(t),this._setPaintValue(a,t,o)},Fa.prototype.updatePaintArray=function(t,e,r,n){var i=this.expression.evaluate({zoom:0},r,n);this._setPaintValue(t,e,i)},Fa.prototype._setPaintValue=function(t,e,r){if(\"color\"===this.type)for(var n=za(r),i=t;i<e;i++)this.paintVertexArray.emplace(i,n[0],n[1]);else{for(var a=t;a<e;a++)this.paintVertexArray.emplace(a,r);this.maxValue=Math.max(this.maxValue,Math.abs(r))}},Fa.prototype.upload=function(t){this.paintVertexArray&&this.paintVertexArray.arrayBuffer&&(this.paintVertexBuffer&&this.paintVertexBuffer.buffer?this.paintVertexBuffer.updateData(this.paintVertexArray):this.paintVertexBuffer=t.createVertexBuffer(this.paintVertexArray,this.paintVertexAttributes,this.expression.isStateDependent))},Fa.prototype.destroy=function(){this.paintVertexBuffer&&this.paintVertexBuffer.destroy()};var Ba=function(t,e,r,n,i,a){this.expression=t,this.uniformNames=e.map((function(t){return\"u_\"+t+\"_t\"})),this.type=r,this.useIntegerZoom=n,this.zoom=i,this.maxValue=0,this.paintVertexAttributes=e.map((function(t){return{name:\"a_\"+t,type:\"Float32\",components:\"color\"===r?4:2,offset:0}})),this.paintVertexArray=new a};Ba.prototype.populatePaintArray=function(t,e,r,n,i){var a=this.expression.evaluate(new pi(this.zoom),e,{},n,[],i),o=this.expression.evaluate(new pi(this.zoom+1),e,{},n,[],i),s=this.paintVertexArray.length;this.paintVertexArray.resize(t),this._setPaintValue(s,t,a,o)},Ba.prototype.updatePaintArray=function(t,e,r,n){var i=this.expression.evaluate({zoom:this.zoom},r,n),a=this.expression.evaluate({zoom:this.zoom+1},r,n);this._setPaintValue(t,e,i,a)},Ba.prototype._setPaintValue=function(t,e,r,n){if(\"color\"===this.type)for(var i=za(r),a=za(n),o=t;o<e;o++)this.paintVertexArray.emplace(o,i[0],i[1],a[0],a[1]);else{for(var s=t;s<e;s++)this.paintVertexArray.emplace(s,r,n);this.maxValue=Math.max(this.maxValue,Math.abs(r),Math.abs(n))}},Ba.prototype.upload=function(t){this.paintVertexArray&&this.paintVertexArray.arrayBuffer&&(this.paintVertexBuffer&&this.paintVertexBuffer.buffer?this.paintVertexBuffer.updateData(this.paintVertexArray):this.paintVertexBuffer=t.createVertexBuffer(this.paintVertexArray,this.paintVertexAttributes,this.expression.isStateDependent))},Ba.prototype.destroy=function(){this.paintVertexBuffer&&this.paintVertexBuffer.destroy()},Ba.prototype.setUniform=function(t,e){var r=this.useIntegerZoom?Math.floor(e.zoom):e.zoom,n=l(this.expression.interpolationFactor(r,this.zoom,this.zoom+1),0,1);t.set(n)},Ba.prototype.getBinding=function(t,e,r){return new Sa(t,e)};var Na=function(t,e,r,n,i,a){this.expression=t,this.type=e,this.useIntegerZoom=r,this.zoom=n,this.layerId=a,this.zoomInPaintVertexArray=new i,this.zoomOutPaintVertexArray=new i};Na.prototype.populatePaintArray=function(t,e,r){var n=this.zoomInPaintVertexArray.length;this.zoomInPaintVertexArray.resize(t),this.zoomOutPaintVertexArray.resize(t),this._setPaintValues(n,t,e.patterns&&e.patterns[this.layerId],r)},Na.prototype.updatePaintArray=function(t,e,r,n,i){this._setPaintValues(t,e,r.patterns&&r.patterns[this.layerId],i)},Na.prototype._setPaintValues=function(t,e,r,n){if(n&&r){var i=r.min,a=r.mid,o=r.max,s=n[i],l=n[a],c=n[o];if(s&&l&&c)for(var u=t;u<e;u++)this.zoomInPaintVertexArray.emplace(u,l.tl[0],l.tl[1],l.br[0],l.br[1],s.tl[0],s.tl[1],s.br[0],s.br[1],l.pixelRatio,s.pixelRatio),this.zoomOutPaintVertexArray.emplace(u,l.tl[0],l.tl[1],l.br[0],l.br[1],c.tl[0],c.tl[1],c.br[0],c.br[1],l.pixelRatio,c.pixelRatio)}},Na.prototype.upload=function(t){this.zoomInPaintVertexArray&&this.zoomInPaintVertexArray.arrayBuffer&&this.zoomOutPaintVertexArray&&this.zoomOutPaintVertexArray.arrayBuffer&&(this.zoomInPaintVertexBuffer=t.createVertexBuffer(this.zoomInPaintVertexArray,ma.members,this.expression.isStateDependent),this.zoomOutPaintVertexBuffer=t.createVertexBuffer(this.zoomOutPaintVertexArray,ma.members,this.expression.isStateDependent))},Na.prototype.destroy=function(){this.zoomOutPaintVertexBuffer&&this.zoomOutPaintVertexBuffer.destroy(),this.zoomInPaintVertexBuffer&&this.zoomInPaintVertexBuffer.destroy()};var ja=function(t,e,r,n){this.binders={},this.layoutAttributes=n,this._buffers=[];var i=[];for(var a in t.paint._values)if(r(a)){var o=t.paint.get(a);if(o instanceof bi&&zr(o.property.specification)){var s=Va(a,t.type),l=o.value,c=o.property.specification.type,u=o.property.useIntegerZoom,f=o.property.specification[\"property-type\"],h=\"cross-faded\"===f||\"cross-faded-data-driven\"===f;if(\"constant\"===l.kind)this.binders[a]=h?new Ra(l.value,s):new Da(l.value,s,c),i.push(\"/u_\"+a);else if(\"source\"===l.kind||h){var p=qa(a,c,\"source\");this.binders[a]=h?new Na(l,c,u,e,p,t.id):new Fa(l,s,c,p),i.push(\"/a_\"+a)}else{var d=qa(a,c,\"composite\");this.binders[a]=new Ba(l,s,c,u,e,d),i.push(\"/z_\"+a)}}}this.cacheKey=i.sort().join(\"\")};ja.prototype.getMaxValue=function(t){var e=this.binders[t];return e instanceof Fa||e instanceof Ba?e.maxValue:0},ja.prototype.populatePaintArrays=function(t,e,r,n,i){for(var a in this.binders){var o=this.binders[a];(o instanceof Fa||o instanceof Ba||o instanceof Na)&&o.populatePaintArray(t,e,r,n,i)}},ja.prototype.setConstantPatternPositions=function(t,e){for(var r in this.binders){var n=this.binders[r];n instanceof Ra&&n.setConstantPatternPositions(t,e)}},ja.prototype.updatePaintArrays=function(t,e,r,n,i){var a=!1;for(var o in t)for(var s=0,l=e.getPositions(o);s<l.length;s+=1){var c=l[s],u=r.feature(c.index);for(var f in this.binders){var h=this.binders[f];if((h instanceof Fa||h instanceof Ba||h instanceof Na)&&!0===h.expression.isStateDependent){var p=n.paint.get(f);h.expression=p.value,h.updatePaintArray(c.start,c.end,u,t[o],i),a=!0}}}return a},ja.prototype.defines=function(){var t=[];for(var e in this.binders){var r=this.binders[e];(r instanceof Da||r instanceof Ra)&&t.push.apply(t,r.uniformNames.map((function(t){return\"#define HAS_UNIFORM_\"+t})))}return t},ja.prototype.getPaintVertexBuffers=function(){return this._buffers},ja.prototype.getUniforms=function(t,e){var r=[];for(var n in this.binders){var i=this.binders[n];if(i instanceof Da||i instanceof Ra||i instanceof Ba)for(var a=0,o=i.uniformNames;a<o.length;a+=1){var s=o[a];if(e[s]){var l=i.getBinding(t,e[s],s);r.push({name:s,property:n,binding:l})}}}return r},ja.prototype.setUniforms=function(t,e,r,n){for(var i=0,a=e;i<a.length;i+=1){var o=a[i],s=o.name,l=o.property,c=o.binding;this.binders[l].setUniform(c,n,r.get(l),s)}},ja.prototype.updatePaintBuffers=function(t){for(var e in this._buffers=[],this.binders){var r=this.binders[e];if(t&&r instanceof Na){var n=2===t.fromScale?r.zoomInPaintVertexBuffer:r.zoomOutPaintVertexBuffer;n&&this._buffers.push(n)}else(r instanceof Fa||r instanceof Ba)&&r.paintVertexBuffer&&this._buffers.push(r.paintVertexBuffer)}},ja.prototype.upload=function(t){for(var e in this.binders){var r=this.binders[e];(r instanceof Fa||r instanceof Ba||r instanceof Na)&&r.upload(t)}this.updatePaintBuffers()},ja.prototype.destroy=function(){for(var t in this.binders){var e=this.binders[t];(e instanceof Fa||e instanceof Ba||e instanceof Na)&&e.destroy()}};var Ua=function(t,e,r,n){void 0===n&&(n=function(){return!0}),this.programConfigurations={};for(var i=0,a=e;i<a.length;i+=1){var o=a[i];this.programConfigurations[o.id]=new ja(o,r,n,t)}this.needsUpload=!1,this._featureMap=new _a,this._bufferOffset=0};function Va(t,e){return{\"text-opacity\":[\"opacity\"],\"icon-opacity\":[\"opacity\"],\"text-color\":[\"fill_color\"],\"icon-color\":[\"fill_color\"],\"text-halo-color\":[\"halo_color\"],\"icon-halo-color\":[\"halo_color\"],\"text-halo-blur\":[\"halo_blur\"],\"icon-halo-blur\":[\"halo_blur\"],\"text-halo-width\":[\"halo_width\"],\"icon-halo-width\":[\"halo_width\"],\"line-gap-width\":[\"gapwidth\"],\"line-pattern\":[\"pattern_to\",\"pattern_from\",\"pixel_ratio_to\",\"pixel_ratio_from\"],\"fill-pattern\":[\"pattern_to\",\"pattern_from\",\"pixel_ratio_to\",\"pixel_ratio_from\"],\"fill-extrusion-pattern\":[\"pattern_to\",\"pattern_from\",\"pixel_ratio_to\",\"pixel_ratio_from\"]}[t]||[t.replace(e+\"-\",\"\").replace(/-/g,\"_\")]}function qa(t,e,r){var n={color:{source:ta,composite:ea},number:{source:Zi,composite:ta}},i=function(t){return{\"line-pattern\":{source:Bi,composite:Bi},\"fill-pattern\":{source:Bi,composite:Bi},\"fill-extrusion-pattern\":{source:Bi,composite:Bi}}[t]}(t);return i&&i[r]||n[e][r]}Ua.prototype.populatePaintArrays=function(t,e,r,n,i,a){for(var o in this.programConfigurations)this.programConfigurations[o].populatePaintArrays(t,e,n,i,a);void 0!==e.id&&this._featureMap.add(e.id,r,this._bufferOffset,t),this._bufferOffset=t,this.needsUpload=!0},Ua.prototype.updatePaintArrays=function(t,e,r,n){for(var i=0,a=r;i<a.length;i+=1){var o=a[i];this.needsUpload=this.programConfigurations[o.id].updatePaintArrays(t,this._featureMap,e,o,n)||this.needsUpload}},Ua.prototype.get=function(t){return this.programConfigurations[t]},Ua.prototype.upload=function(t){if(this.needsUpload){for(var e in this.programConfigurations)this.programConfigurations[e].upload(t);this.needsUpload=!1}},Ua.prototype.destroy=function(){for(var t in this.programConfigurations)this.programConfigurations[t].destroy()},Nn(\"ConstantBinder\",Da),Nn(\"CrossFadedConstantBinder\",Ra),Nn(\"SourceExpressionBinder\",Fa),Nn(\"CrossFadedCompositeBinder\",Na),Nn(\"CompositeExpressionBinder\",Ba),Nn(\"ProgramConfiguration\",ja,{omit:[\"_buffers\"]}),Nn(\"ProgramConfigurationSet\",Ua);var Ha,Ga=(Ha=15,{min:-1*Math.pow(2,Ha-1),max:Math.pow(2,Ha-1)-1});function Ya(t){for(var e=8192/t.extent,r=t.loadGeometry(),n=0;n<r.length;n++)for(var i=r[n],a=0;a<i.length;a++){var o=i[a];o.x=Math.round(o.x*e),o.y=Math.round(o.y*e),(o.x<Ga.min||o.x>Ga.max||o.y<Ga.min||o.y>Ga.max)&&(_(\"Geometry exceeds allowed extent, reduce your vector tile buffer size\"),o.x=l(o.x,Ga.min,Ga.max),o.y=l(o.y,Ga.min,Ga.max))}return r}function Wa(t,e,r,n,i){t.emplaceBack(2*e+(n+1)/2,2*r+(i+1)/2)}var Xa=function(t){this.zoom=t.zoom,this.overscaling=t.overscaling,this.layers=t.layers,this.layerIds=this.layers.map((function(t){return t.id})),this.index=t.index,this.hasPattern=!1,this.layoutVertexArray=new zi,this.indexArray=new Yi,this.segments=new pa,this.programConfigurations=new Ua(ha,t.layers,t.zoom),this.stateDependentLayerIds=this.layers.filter((function(t){return t.isStateDependent()})).map((function(t){return t.id}))};function Za(t,e){for(var r=0;r<t.length;r++)if(io(e,t[r]))return!0;for(var n=0;n<e.length;n++)if(io(t,e[n]))return!0;return!!$a(t,e)}function Ja(t,e,r){return!!io(t,e)||!!eo(e,t,r)}function Ka(t,e){if(1===t.length)return no(e,t[0]);for(var r=0;r<e.length;r++)for(var n=e[r],i=0;i<n.length;i++)if(io(t,n[i]))return!0;for(var a=0;a<t.length;a++)if(no(e,t[a]))return!0;for(var o=0;o<e.length;o++)if($a(t,e[o]))return!0;return!1}function Qa(t,e,r){if(t.length>1){if($a(t,e))return!0;for(var n=0;n<e.length;n++)if(eo(e[n],t,r))return!0}for(var i=0;i<t.length;i++)if(eo(t[i],e,r))return!0;return!1}function $a(t,e){if(0===t.length||0===e.length)return!1;for(var r=0;r<t.length-1;r++)for(var n=t[r],i=t[r+1],a=0;a<e.length-1;a++){if(to(n,i,e[a],e[a+1]))return!0}return!1}function to(t,e,r,n){return w(t,r,n)!==w(e,r,n)&&w(t,e,r)!==w(t,e,n)}function eo(t,e,r){var n=r*r;if(1===e.length)return t.distSqr(e[0])<n;for(var i=1;i<e.length;i++){if(ro(t,e[i-1],e[i])<n)return!0}return!1}function ro(t,e,r){var n=e.distSqr(r);if(0===n)return t.distSqr(e);var i=((t.x-e.x)*(r.x-e.x)+(t.y-e.y)*(r.y-e.y))/n;return i<0?t.distSqr(e):i>1?t.distSqr(r):t.distSqr(r.sub(e)._mult(i)._add(e))}function no(t,e){for(var r,n,i,a=!1,o=0;o<t.length;o++)for(var s=0,l=(r=t[o]).length-1;s<r.length;l=s++)n=r[s],i=r[l],n.y>e.y!=i.y>e.y&&e.x<(i.x-n.x)*(e.y-n.y)/(i.y-n.y)+n.x&&(a=!a);return a}function io(t,e){for(var r=!1,n=0,i=t.length-1;n<t.length;i=n++){var a=t[n],o=t[i];a.y>e.y!=o.y>e.y&&e.x<(o.x-a.x)*(e.y-a.y)/(o.y-a.y)+a.x&&(r=!r)}return r}function ao(t,e,r){var n=r[0],i=r[2];if(t.x<n.x&&e.x<n.x||t.x>i.x&&e.x>i.x||t.y<n.y&&e.y<n.y||t.y>i.y&&e.y>i.y)return!1;var a=w(t,e,r[0]);return a!==w(t,e,r[1])||a!==w(t,e,r[2])||a!==w(t,e,r[3])}function oo(t,e,r){var n=e.paint.get(t).value;return\"constant\"===n.kind?n.value:r.programConfigurations.get(e.id).getMaxValue(t)}function so(t){return Math.sqrt(t[0]*t[0]+t[1]*t[1])}function lo(t,e,r,n,a){if(!e[0]&&!e[1])return t;var o=i.convert(e)._mult(a);\"viewport\"===r&&o._rotate(-n);for(var s=[],l=0;l<t.length;l++){var c=t[l];s.push(c.sub(o))}return s}Xa.prototype.populate=function(t,e,r){var n=this.layers[0],i=[],a=null;\"circle\"===n.type&&(a=n.layout.get(\"circle-sort-key\"));for(var o=0,s=t;o<s.length;o+=1){var l=s[o],c=l.feature,u=l.id,f=l.index,h=l.sourceLayerIndex,p=this.layers[0]._featureFilter.needGeometry,d={type:c.type,id:u,properties:c.properties,geometry:p?Ya(c):[]};if(this.layers[0]._featureFilter.filter(new pi(this.zoom),d,r)){p||(d.geometry=Ya(c));var m=a?a.evaluate(d,{},r):void 0,g={id:u,properties:c.properties,type:c.type,sourceLayerIndex:h,index:f,geometry:d.geometry,patterns:{},sortKey:m};i.push(g)}}a&&i.sort((function(t,e){return t.sortKey-e.sortKey}));for(var v=0,y=i;v<y.length;v+=1){var x=y[v],b=x,_=b.geometry,w=b.index,T=b.sourceLayerIndex,k=t[w].feature;this.addFeature(x,_,w,r),e.featureIndex.insert(k,_,w,T,this.index)}},Xa.prototype.update=function(t,e,r){this.stateDependentLayers.length&&this.programConfigurations.updatePaintArrays(t,e,this.stateDependentLayers,r)},Xa.prototype.isEmpty=function(){return 0===this.layoutVertexArray.length},Xa.prototype.uploadPending=function(){return!this.uploaded||this.programConfigurations.needsUpload},Xa.prototype.upload=function(t){this.uploaded||(this.layoutVertexBuffer=t.createVertexBuffer(this.layoutVertexArray,ha),this.indexBuffer=t.createIndexBuffer(this.indexArray)),this.programConfigurations.upload(t),this.uploaded=!0},Xa.prototype.destroy=function(){this.layoutVertexBuffer&&(this.layoutVertexBuffer.destroy(),this.indexBuffer.destroy(),this.programConfigurations.destroy(),this.segments.destroy())},Xa.prototype.addFeature=function(t,e,r,n){for(var i=0,a=e;i<a.length;i+=1)for(var o=0,s=a[i];o<s.length;o+=1){var l=s[o],c=l.x,u=l.y;if(!(c<0||c>=8192||u<0||u>=8192)){var f=this.segments.prepareSegment(4,this.layoutVertexArray,this.indexArray,t.sortKey),h=f.vertexLength;Wa(this.layoutVertexArray,c,u,-1,-1),Wa(this.layoutVertexArray,c,u,1,-1),Wa(this.layoutVertexArray,c,u,1,1),Wa(this.layoutVertexArray,c,u,-1,1),this.indexArray.emplaceBack(h,h+1,h+2),this.indexArray.emplaceBack(h,h+3,h+2),f.vertexLength+=4,f.primitiveLength+=2}}this.programConfigurations.populatePaintArrays(this.layoutVertexArray.length,t,r,{},n)},Nn(\"CircleBucket\",Xa,{omit:[\"layers\"]});var co=new Si({\"circle-sort-key\":new Ti(Lt.layout_circle[\"circle-sort-key\"])}),uo={paint:new Si({\"circle-radius\":new Ti(Lt.paint_circle[\"circle-radius\"]),\"circle-color\":new Ti(Lt.paint_circle[\"circle-color\"]),\"circle-blur\":new Ti(Lt.paint_circle[\"circle-blur\"]),\"circle-opacity\":new Ti(Lt.paint_circle[\"circle-opacity\"]),\"circle-translate\":new wi(Lt.paint_circle[\"circle-translate\"]),\"circle-translate-anchor\":new wi(Lt.paint_circle[\"circle-translate-anchor\"]),\"circle-pitch-scale\":new wi(Lt.paint_circle[\"circle-pitch-scale\"]),\"circle-pitch-alignment\":new wi(Lt.paint_circle[\"circle-pitch-alignment\"]),\"circle-stroke-width\":new Ti(Lt.paint_circle[\"circle-stroke-width\"]),\"circle-stroke-color\":new Ti(Lt.paint_circle[\"circle-stroke-color\"]),\"circle-stroke-opacity\":new Ti(Lt.paint_circle[\"circle-stroke-opacity\"])}),layout:co},fo=\"undefined\"!=typeof Float32Array?Float32Array:Array;function ho(t){return t[0]=1,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=1,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[10]=1,t[11]=0,t[12]=0,t[13]=0,t[14]=0,t[15]=1,t}function po(t,e,r){var n=e[0],i=e[1],a=e[2],o=e[3],s=e[4],l=e[5],c=e[6],u=e[7],f=e[8],h=e[9],p=e[10],d=e[11],m=e[12],g=e[13],v=e[14],y=e[15],x=r[0],b=r[1],_=r[2],w=r[3];return t[0]=x*n+b*s+_*f+w*m,t[1]=x*i+b*l+_*h+w*g,t[2]=x*a+b*c+_*p+w*v,t[3]=x*o+b*u+_*d+w*y,x=r[4],b=r[5],_=r[6],w=r[7],t[4]=x*n+b*s+_*f+w*m,t[5]=x*i+b*l+_*h+w*g,t[6]=x*a+b*c+_*p+w*v,t[7]=x*o+b*u+_*d+w*y,x=r[8],b=r[9],_=r[10],w=r[11],t[8]=x*n+b*s+_*f+w*m,t[9]=x*i+b*l+_*h+w*g,t[10]=x*a+b*c+_*p+w*v,t[11]=x*o+b*u+_*d+w*y,x=r[12],b=r[13],_=r[14],w=r[15],t[12]=x*n+b*s+_*f+w*m,t[13]=x*i+b*l+_*h+w*g,t[14]=x*a+b*c+_*p+w*v,t[15]=x*o+b*u+_*d+w*y,t}Math.hypot||(Math.hypot=function(){for(var t=arguments,e=0,r=arguments.length;r--;)e+=t[r]*t[r];return Math.sqrt(e)});var mo=po;var go,vo,yo=function(t,e,r){return t[0]=e[0]-r[0],t[1]=e[1]-r[1],t[2]=e[2]-r[2],t};go=new fo(3),fo!=Float32Array&&(go[0]=0,go[1]=0,go[2]=0),vo=go;function xo(t,e,r){var n=e[0],i=e[1],a=e[2],o=e[3];return t[0]=r[0]*n+r[4]*i+r[8]*a+r[12]*o,t[1]=r[1]*n+r[5]*i+r[9]*a+r[13]*o,t[2]=r[2]*n+r[6]*i+r[10]*a+r[14]*o,t[3]=r[3]*n+r[7]*i+r[11]*a+r[15]*o,t}!function(){var t=function(){var t=new fo(4);return fo!=Float32Array&&(t[0]=0,t[1]=0,t[2]=0,t[3]=0),t}()}();var bo=function(t){var e=t[0],r=t[1];return e*e+r*r},_o=(function(){var t=function(){var t=new fo(2);return fo!=Float32Array&&(t[0]=0,t[1]=0),t}()}(),function(t){function e(e){t.call(this,e,uo)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.createBucket=function(t){return new Xa(t)},e.prototype.queryRadius=function(t){var e=t;return oo(\"circle-radius\",this,e)+oo(\"circle-stroke-width\",this,e)+so(this.paint.get(\"circle-translate\"))},e.prototype.queryIntersectsFeature=function(t,e,r,n,i,a,o,s){for(var l=lo(t,this.paint.get(\"circle-translate\"),this.paint.get(\"circle-translate-anchor\"),a.angle,o),c=this.paint.get(\"circle-radius\").evaluate(e,r)+this.paint.get(\"circle-stroke-width\").evaluate(e,r),u=\"map\"===this.paint.get(\"circle-pitch-alignment\"),f=u?l:function(t,e){return t.map((function(t){return wo(t,e)}))}(l,s),h=u?c*o:c,p=0,d=n;p<d.length;p+=1)for(var m=0,g=d[p];m<g.length;m+=1){var v=g[m],y=u?v:wo(v,s),x=h,b=xo([],[v.x,v.y,0,1],s);if(\"viewport\"===this.paint.get(\"circle-pitch-scale\")&&\"map\"===this.paint.get(\"circle-pitch-alignment\")?x*=b[3]/a.cameraToCenterDistance:\"map\"===this.paint.get(\"circle-pitch-scale\")&&\"viewport\"===this.paint.get(\"circle-pitch-alignment\")&&(x*=a.cameraToCenterDistance/b[3]),Ja(f,y,x))return!0}return!1},e}(Ei));function wo(t,e){var r=xo([],[t.x,t.y,0,1],e);return new i(r[0]/r[3],r[1]/r[3])}var To=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e}(Xa);function ko(t,e,r,n){var i=e.width,a=e.height;if(n){if(n instanceof Uint8ClampedArray)n=new Uint8Array(n.buffer);else if(n.length!==i*a*r)throw new RangeError(\"mismatched image size\")}else n=new Uint8Array(i*a*r);return t.width=i,t.height=a,t.data=n,t}function Mo(t,e,r){var n=e.width,i=e.height;if(n!==t.width||i!==t.height){var a=ko({},{width:n,height:i},r);Ao(t,a,{x:0,y:0},{x:0,y:0},{width:Math.min(t.width,n),height:Math.min(t.height,i)},r),t.width=n,t.height=i,t.data=a.data}}function Ao(t,e,r,n,i,a){if(0===i.width||0===i.height)return e;if(i.width>t.width||i.height>t.height||r.x>t.width-i.width||r.y>t.height-i.height)throw new RangeError(\"out of range source coordinates for image copy\");if(i.width>e.width||i.height>e.height||n.x>e.width-i.width||n.y>e.height-i.height)throw new RangeError(\"out of range destination coordinates for image copy\");for(var o=t.data,s=e.data,l=0;l<i.height;l++)for(var c=((r.y+l)*t.width+r.x)*a,u=((n.y+l)*e.width+n.x)*a,f=0;f<i.width*a;f++)s[u+f]=o[c+f];return e}Nn(\"HeatmapBucket\",To,{omit:[\"layers\"]});var So=function(t,e){ko(this,t,1,e)};So.prototype.resize=function(t){Mo(this,t,1)},So.prototype.clone=function(){return new So({width:this.width,height:this.height},new Uint8Array(this.data))},So.copy=function(t,e,r,n,i){Ao(t,e,r,n,i,1)};var Eo=function(t,e){ko(this,t,4,e)};Eo.prototype.resize=function(t){Mo(this,t,4)},Eo.prototype.replace=function(t,e){e?this.data.set(t):t instanceof Uint8ClampedArray?this.data=new Uint8Array(t.buffer):this.data=t},Eo.prototype.clone=function(){return new Eo({width:this.width,height:this.height},new Uint8Array(this.data))},Eo.copy=function(t,e,r,n,i){Ao(t,e,r,n,i,4)},Nn(\"AlphaImage\",So),Nn(\"RGBAImage\",Eo);var Lo={paint:new Si({\"heatmap-radius\":new Ti(Lt.paint_heatmap[\"heatmap-radius\"]),\"heatmap-weight\":new Ti(Lt.paint_heatmap[\"heatmap-weight\"]),\"heatmap-intensity\":new wi(Lt.paint_heatmap[\"heatmap-intensity\"]),\"heatmap-color\":new Ai(Lt.paint_heatmap[\"heatmap-color\"]),\"heatmap-opacity\":new wi(Lt.paint_heatmap[\"heatmap-opacity\"])})};function Co(t,e){for(var r=new Uint8Array(1024),n={},i=0,a=0;i<256;i++,a+=4){n[e]=i/255;var o=t.evaluate(n);r[a+0]=Math.floor(255*o.r/o.a),r[a+1]=Math.floor(255*o.g/o.a),r[a+2]=Math.floor(255*o.b/o.a),r[a+3]=Math.floor(255*o.a)}return new Eo({width:256,height:1},r)}var Po=function(t){function e(e){t.call(this,e,Lo),this._updateColorRamp()}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.createBucket=function(t){return new To(t)},e.prototype._handleSpecialPaintPropertyUpdate=function(t){\"heatmap-color\"===t&&this._updateColorRamp()},e.prototype._updateColorRamp=function(){var t=this._transitionablePaint._values[\"heatmap-color\"].value.expression;this.colorRamp=Co(t,\"heatmapDensity\"),this.colorRampTexture=null},e.prototype.resize=function(){this.heatmapFbo&&(this.heatmapFbo.destroy(),this.heatmapFbo=null)},e.prototype.queryRadius=function(){return 0},e.prototype.queryIntersectsFeature=function(){return!1},e.prototype.hasOffscreenPass=function(){return 0!==this.paint.get(\"heatmap-opacity\")&&\"none\"!==this.visibility},e}(Ei),Io={paint:new Si({\"hillshade-illumination-direction\":new wi(Lt.paint_hillshade[\"hillshade-illumination-direction\"]),\"hillshade-illumination-anchor\":new wi(Lt.paint_hillshade[\"hillshade-illumination-anchor\"]),\"hillshade-exaggeration\":new wi(Lt.paint_hillshade[\"hillshade-exaggeration\"]),\"hillshade-shadow-color\":new wi(Lt.paint_hillshade[\"hillshade-shadow-color\"]),\"hillshade-highlight-color\":new wi(Lt.paint_hillshade[\"hillshade-highlight-color\"]),\"hillshade-accent-color\":new wi(Lt.paint_hillshade[\"hillshade-accent-color\"])})},Oo=function(t){function e(e){t.call(this,e,Io)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.hasOffscreenPass=function(){return 0!==this.paint.get(\"hillshade-exaggeration\")&&\"none\"!==this.visibility},e}(Ei),zo=Ii([{name:\"a_pos\",components:2,type:\"Int16\"}],4).members,Do=Fo,Ro=Fo;function Fo(t,e,r){r=r||2;var n,i,a,o,s,l,c,u=e&&e.length,f=u?e[0]*r:t.length,h=Bo(t,0,f,r,!0),p=[];if(!h||h.next===h.prev)return p;if(u&&(h=function(t,e,r,n){var i,a,o,s,l,c=[];for(i=0,a=e.length;i<a;i++)o=e[i]*n,s=i<a-1?e[i+1]*n:t.length,(l=Bo(t,o,s,n,!1))===l.next&&(l.steiner=!0),c.push(Zo(l));for(c.sort(Go),i=0;i<c.length;i++)Yo(c[i],r),r=No(r,r.next);return r}(t,e,h,r)),t.length>80*r){n=a=t[0],i=o=t[1];for(var d=r;d<f;d+=r)(s=t[d])<n&&(n=s),(l=t[d+1])<i&&(i=l),s>a&&(a=s),l>o&&(o=l);c=0!==(c=Math.max(a-n,o-i))?1/c:0}return jo(h,p,r,n,i,c),p}function Bo(t,e,r,n,i){var a,o;if(i===ls(t,e,r,n)>0)for(a=e;a<r;a+=n)o=as(a,t[a],t[a+1],o);else for(a=r-n;a>=e;a-=n)o=as(a,t[a],t[a+1],o);return o&&$o(o,o.next)&&(os(o),o=o.next),o}function No(t,e){if(!t)return t;e||(e=t);var r,n=t;do{if(r=!1,n.steiner||!$o(n,n.next)&&0!==Qo(n.prev,n,n.next))n=n.next;else{if(os(n),(n=e=n.prev)===n.next)break;r=!0}}while(r||n!==e);return e}function jo(t,e,r,n,i,a,o){if(t){!o&&a&&function(t,e,r,n){var i=t;do{null===i.z&&(i.z=Xo(i.x,i.y,e,r,n)),i.prevZ=i.prev,i.nextZ=i.next,i=i.next}while(i!==t);i.prevZ.nextZ=null,i.prevZ=null,function(t){var e,r,n,i,a,o,s,l,c=1;do{for(r=t,t=null,a=null,o=0;r;){for(o++,n=r,s=0,e=0;e<c&&(s++,n=n.nextZ);e++);for(l=c;s>0||l>0&&n;)0!==s&&(0===l||!n||r.z<=n.z)?(i=r,r=r.nextZ,s--):(i=n,n=n.nextZ,l--),a?a.nextZ=i:t=i,i.prevZ=a,a=i;r=n}a.nextZ=null,c*=2}while(o>1)}(i)}(t,n,i,a);for(var s,l,c=t;t.prev!==t.next;)if(s=t.prev,l=t.next,a?Vo(t,n,i,a):Uo(t))e.push(s.i/r),e.push(t.i/r),e.push(l.i/r),os(t),t=l.next,c=l.next;else if((t=l)===c){o?1===o?jo(t=qo(No(t),e,r),e,r,n,i,a,2):2===o&&Ho(t,e,r,n,i,a):jo(No(t),e,r,n,i,a,1);break}}}function Uo(t){var e=t.prev,r=t,n=t.next;if(Qo(e,r,n)>=0)return!1;for(var i=t.next.next;i!==t.prev;){if(Jo(e.x,e.y,r.x,r.y,n.x,n.y,i.x,i.y)&&Qo(i.prev,i,i.next)>=0)return!1;i=i.next}return!0}function Vo(t,e,r,n){var i=t.prev,a=t,o=t.next;if(Qo(i,a,o)>=0)return!1;for(var s=i.x<a.x?i.x<o.x?i.x:o.x:a.x<o.x?a.x:o.x,l=i.y<a.y?i.y<o.y?i.y:o.y:a.y<o.y?a.y:o.y,c=i.x>a.x?i.x>o.x?i.x:o.x:a.x>o.x?a.x:o.x,u=i.y>a.y?i.y>o.y?i.y:o.y:a.y>o.y?a.y:o.y,f=Xo(s,l,e,r,n),h=Xo(c,u,e,r,n),p=t.prevZ,d=t.nextZ;p&&p.z>=f&&d&&d.z<=h;){if(p!==t.prev&&p!==t.next&&Jo(i.x,i.y,a.x,a.y,o.x,o.y,p.x,p.y)&&Qo(p.prev,p,p.next)>=0)return!1;if(p=p.prevZ,d!==t.prev&&d!==t.next&&Jo(i.x,i.y,a.x,a.y,o.x,o.y,d.x,d.y)&&Qo(d.prev,d,d.next)>=0)return!1;d=d.nextZ}for(;p&&p.z>=f;){if(p!==t.prev&&p!==t.next&&Jo(i.x,i.y,a.x,a.y,o.x,o.y,p.x,p.y)&&Qo(p.prev,p,p.next)>=0)return!1;p=p.prevZ}for(;d&&d.z<=h;){if(d!==t.prev&&d!==t.next&&Jo(i.x,i.y,a.x,a.y,o.x,o.y,d.x,d.y)&&Qo(d.prev,d,d.next)>=0)return!1;d=d.nextZ}return!0}function qo(t,e,r){var n=t;do{var i=n.prev,a=n.next.next;!$o(i,a)&&ts(i,n,n.next,a)&&ns(i,a)&&ns(a,i)&&(e.push(i.i/r),e.push(n.i/r),e.push(a.i/r),os(n),os(n.next),n=t=a),n=n.next}while(n!==t);return No(n)}function Ho(t,e,r,n,i,a){var o=t;do{for(var s=o.next.next;s!==o.prev;){if(o.i!==s.i&&Ko(o,s)){var l=is(o,s);return o=No(o,o.next),l=No(l,l.next),jo(o,e,r,n,i,a),void jo(l,e,r,n,i,a)}s=s.next}o=o.next}while(o!==t)}function Go(t,e){return t.x-e.x}function Yo(t,e){if(e=function(t,e){var r,n=e,i=t.x,a=t.y,o=-1/0;do{if(a<=n.y&&a>=n.next.y&&n.next.y!==n.y){var s=n.x+(a-n.y)*(n.next.x-n.x)/(n.next.y-n.y);if(s<=i&&s>o){if(o=s,s===i){if(a===n.y)return n;if(a===n.next.y)return n.next}r=n.x<n.next.x?n:n.next}}n=n.next}while(n!==e);if(!r)return null;if(i===o)return r;var l,c=r,u=r.x,f=r.y,h=1/0;n=r;do{i>=n.x&&n.x>=u&&i!==n.x&&Jo(a<f?i:o,a,u,f,a<f?o:i,a,n.x,n.y)&&(l=Math.abs(a-n.y)/(i-n.x),ns(n,t)&&(l<h||l===h&&(n.x>r.x||n.x===r.x&&Wo(r,n)))&&(r=n,h=l)),n=n.next}while(n!==c);return r}(t,e)){var r=is(e,t);No(e,e.next),No(r,r.next)}}function Wo(t,e){return Qo(t.prev,t,e.prev)<0&&Qo(e.next,t,t.next)<0}function Xo(t,e,r,n,i){return(t=1431655765&((t=858993459&((t=252645135&((t=16711935&((t=32767*(t-r)*i)|t<<8))|t<<4))|t<<2))|t<<1))|(e=1431655765&((e=858993459&((e=252645135&((e=16711935&((e=32767*(e-n)*i)|e<<8))|e<<4))|e<<2))|e<<1))<<1}function Zo(t){var e=t,r=t;do{(e.x<r.x||e.x===r.x&&e.y<r.y)&&(r=e),e=e.next}while(e!==t);return r}function Jo(t,e,r,n,i,a,o,s){return(i-o)*(e-s)-(t-o)*(a-s)>=0&&(t-o)*(n-s)-(r-o)*(e-s)>=0&&(r-o)*(a-s)-(i-o)*(n-s)>=0}function Ko(t,e){return t.next.i!==e.i&&t.prev.i!==e.i&&!function(t,e){var r=t;do{if(r.i!==t.i&&r.next.i!==t.i&&r.i!==e.i&&r.next.i!==e.i&&ts(r,r.next,t,e))return!0;r=r.next}while(r!==t);return!1}(t,e)&&(ns(t,e)&&ns(e,t)&&function(t,e){var r=t,n=!1,i=(t.x+e.x)/2,a=(t.y+e.y)/2;do{r.y>a!=r.next.y>a&&r.next.y!==r.y&&i<(r.next.x-r.x)*(a-r.y)/(r.next.y-r.y)+r.x&&(n=!n),r=r.next}while(r!==t);return n}(t,e)&&(Qo(t.prev,t,e.prev)||Qo(t,e.prev,e))||$o(t,e)&&Qo(t.prev,t,t.next)>0&&Qo(e.prev,e,e.next)>0)}function Qo(t,e,r){return(e.y-t.y)*(r.x-e.x)-(e.x-t.x)*(r.y-e.y)}function $o(t,e){return t.x===e.x&&t.y===e.y}function ts(t,e,r,n){var i=rs(Qo(t,e,r)),a=rs(Qo(t,e,n)),o=rs(Qo(r,n,t)),s=rs(Qo(r,n,e));return i!==a&&o!==s||(!(0!==i||!es(t,r,e))||(!(0!==a||!es(t,n,e))||(!(0!==o||!es(r,t,n))||!(0!==s||!es(r,e,n)))))}function es(t,e,r){return e.x<=Math.max(t.x,r.x)&&e.x>=Math.min(t.x,r.x)&&e.y<=Math.max(t.y,r.y)&&e.y>=Math.min(t.y,r.y)}function rs(t){return t>0?1:t<0?-1:0}function ns(t,e){return Qo(t.prev,t,t.next)<0?Qo(t,e,t.next)>=0&&Qo(t,t.prev,e)>=0:Qo(t,e,t.prev)<0||Qo(t,t.next,e)<0}function is(t,e){var r=new ss(t.i,t.x,t.y),n=new ss(e.i,e.x,e.y),i=t.next,a=e.prev;return t.next=e,e.prev=t,r.next=i,i.prev=r,n.next=r,r.prev=n,a.next=n,n.prev=a,n}function as(t,e,r,n){var i=new ss(t,e,r);return n?(i.next=n.next,i.prev=n,n.next.prev=i,n.next=i):(i.prev=i,i.next=i),i}function os(t){t.next.prev=t.prev,t.prev.next=t.next,t.prevZ&&(t.prevZ.nextZ=t.nextZ),t.nextZ&&(t.nextZ.prevZ=t.prevZ)}function ss(t,e,r){this.i=t,this.x=e,this.y=r,this.prev=null,this.next=null,this.z=null,this.prevZ=null,this.nextZ=null,this.steiner=!1}function ls(t,e,r,n){for(var i=0,a=e,o=r-n;a<r;a+=n)i+=(t[o]-t[a])*(t[a+1]+t[o+1]),o=a;return i}function cs(t,e,r,n,i){!function t(e,r,n,i,a){for(;i>n;){if(i-n>600){var o=i-n+1,s=r-n+1,l=Math.log(o),c=.5*Math.exp(2*l/3),u=.5*Math.sqrt(l*c*(o-c)/o)*(s-o/2<0?-1:1),f=Math.max(n,Math.floor(r-s*c/o+u)),h=Math.min(i,Math.floor(r+(o-s)*c/o+u));t(e,r,f,h,a)}var p=e[r],d=n,m=i;for(us(e,n,r),a(e[i],p)>0&&us(e,n,i);d<m;){for(us(e,d,m),d++,m--;a(e[d],p)<0;)d++;for(;a(e[m],p)>0;)m--}0===a(e[n],p)?us(e,n,m):(m++,us(e,m,i)),m<=r&&(n=m+1),r<=m&&(i=m-1)}}(t,e,r||0,n||t.length-1,i||fs)}function us(t,e,r){var n=t[e];t[e]=t[r],t[r]=n}function fs(t,e){return t<e?-1:t>e?1:0}function hs(t,e){var r=t.length;if(r<=1)return[t];for(var n,i,a=[],o=0;o<r;o++){var s=T(t[o]);0!==s&&(t[o].area=Math.abs(s),void 0===i&&(i=s<0),i===s<0?(n&&a.push(n),n=[t[o]]):n.push(t[o]))}if(n&&a.push(n),e>1)for(var l=0;l<a.length;l++)a[l].length<=e||(cs(a[l],e,1,a[l].length-1,ps),a[l]=a[l].slice(0,e));return a}function ps(t,e){return e.area-t.area}function ds(t,e,r){for(var n=r.patternDependencies,i=!1,a=0,o=e;a<o.length;a+=1){var s=o[a].paint.get(t+\"-pattern\");s.isConstant()||(i=!0);var l=s.constantOr(null);l&&(i=!0,n[l.to]=!0,n[l.from]=!0)}return i}function ms(t,e,r,n,i){for(var a=i.patternDependencies,o=0,s=e;o<s.length;o+=1){var l=s[o],c=l.paint.get(t+\"-pattern\").value;if(\"constant\"!==c.kind){var u=c.evaluate({zoom:n-1},r,{},i.availableImages),f=c.evaluate({zoom:n},r,{},i.availableImages),h=c.evaluate({zoom:n+1},r,{},i.availableImages);u=u&&u.name?u.name:u,f=f&&f.name?f.name:f,h=h&&h.name?h.name:h,a[u]=!0,a[f]=!0,a[h]=!0,r.patterns[l.id]={min:u,mid:f,max:h}}}return r}Fo.deviation=function(t,e,r,n){var i=e&&e.length,a=i?e[0]*r:t.length,o=Math.abs(ls(t,0,a,r));if(i)for(var s=0,l=e.length;s<l;s++){var c=e[s]*r,u=s<l-1?e[s+1]*r:t.length;o-=Math.abs(ls(t,c,u,r))}var f=0;for(s=0;s<n.length;s+=3){var h=n[s]*r,p=n[s+1]*r,d=n[s+2]*r;f+=Math.abs((t[h]-t[d])*(t[p+1]-t[h+1])-(t[h]-t[p])*(t[d+1]-t[h+1]))}return 0===o&&0===f?0:Math.abs((f-o)/o)},Fo.flatten=function(t){for(var e=t[0][0].length,r={vertices:[],holes:[],dimensions:e},n=0,i=0;i<t.length;i++){for(var a=0;a<t[i].length;a++)for(var o=0;o<e;o++)r.vertices.push(t[i][a][o]);i>0&&(n+=t[i-1].length,r.holes.push(n))}return r},Do.default=Ro;var gs=function(t){this.zoom=t.zoom,this.overscaling=t.overscaling,this.layers=t.layers,this.layerIds=this.layers.map((function(t){return t.id})),this.index=t.index,this.hasPattern=!1,this.patternFeatures=[],this.layoutVertexArray=new zi,this.indexArray=new Yi,this.indexArray2=new Qi,this.programConfigurations=new Ua(zo,t.layers,t.zoom),this.segments=new pa,this.segments2=new pa,this.stateDependentLayerIds=this.layers.filter((function(t){return t.isStateDependent()})).map((function(t){return t.id}))};gs.prototype.populate=function(t,e,r){this.hasPattern=ds(\"fill\",this.layers,e);for(var n=this.layers[0].layout.get(\"fill-sort-key\"),i=[],a=0,o=t;a<o.length;a+=1){var s=o[a],l=s.feature,c=s.id,u=s.index,f=s.sourceLayerIndex,h=this.layers[0]._featureFilter.needGeometry,p={type:l.type,id:c,properties:l.properties,geometry:h?Ya(l):[]};if(this.layers[0]._featureFilter.filter(new pi(this.zoom),p,r)){h||(p.geometry=Ya(l));var d=n?n.evaluate(p,{},r,e.availableImages):void 0,m={id:c,properties:l.properties,type:l.type,sourceLayerIndex:f,index:u,geometry:p.geometry,patterns:{},sortKey:d};i.push(m)}}n&&i.sort((function(t,e){return t.sortKey-e.sortKey}));for(var g=0,v=i;g<v.length;g+=1){var y=v[g],x=y,b=x.geometry,_=x.index,w=x.sourceLayerIndex;if(this.hasPattern){var T=ms(\"fill\",this.layers,y,this.zoom,e);this.patternFeatures.push(T)}else this.addFeature(y,b,_,r,{});var k=t[_].feature;e.featureIndex.insert(k,b,_,w,this.index)}},gs.prototype.update=function(t,e,r){this.stateDependentLayers.length&&this.programConfigurations.updatePaintArrays(t,e,this.stateDependentLayers,r)},gs.prototype.addFeatures=function(t,e,r){for(var n=0,i=this.patternFeatures;n<i.length;n+=1){var a=i[n];this.addFeature(a,a.geometry,a.index,e,r)}},gs.prototype.isEmpty=function(){return 0===this.layoutVertexArray.length},gs.prototype.uploadPending=function(){return!this.uploaded||this.programConfigurations.needsUpload},gs.prototype.upload=function(t){this.uploaded||(this.layoutVertexBuffer=t.createVertexBuffer(this.layoutVertexArray,zo),this.indexBuffer=t.createIndexBuffer(this.indexArray),this.indexBuffer2=t.createIndexBuffer(this.indexArray2)),this.programConfigurations.upload(t),this.uploaded=!0},gs.prototype.destroy=function(){this.layoutVertexBuffer&&(this.layoutVertexBuffer.destroy(),this.indexBuffer.destroy(),this.indexBuffer2.destroy(),this.programConfigurations.destroy(),this.segments.destroy(),this.segments2.destroy())},gs.prototype.addFeature=function(t,e,r,n,i){for(var a=0,o=hs(e,500);a<o.length;a+=1){for(var s=o[a],l=0,c=0,u=s;c<u.length;c+=1){l+=u[c].length}for(var f=this.segments.prepareSegment(l,this.layoutVertexArray,this.indexArray),h=f.vertexLength,p=[],d=[],m=0,g=s;m<g.length;m+=1){var v=g[m];if(0!==v.length){v!==s[0]&&d.push(p.length/2);var y=this.segments2.prepareSegment(v.length,this.layoutVertexArray,this.indexArray2),x=y.vertexLength;this.layoutVertexArray.emplaceBack(v[0].x,v[0].y),this.indexArray2.emplaceBack(x+v.length-1,x),p.push(v[0].x),p.push(v[0].y);for(var b=1;b<v.length;b++)this.layoutVertexArray.emplaceBack(v[b].x,v[b].y),this.indexArray2.emplaceBack(x+b-1,x+b),p.push(v[b].x),p.push(v[b].y);y.vertexLength+=v.length,y.primitiveLength+=v.length}}for(var _=Do(p,d),w=0;w<_.length;w+=3)this.indexArray.emplaceBack(h+_[w],h+_[w+1],h+_[w+2]);f.vertexLength+=l,f.primitiveLength+=_.length/3}this.programConfigurations.populatePaintArrays(this.layoutVertexArray.length,t,r,i,n)},Nn(\"FillBucket\",gs,{omit:[\"layers\",\"patternFeatures\"]});var vs=new Si({\"fill-sort-key\":new Ti(Lt.layout_fill[\"fill-sort-key\"])}),ys={paint:new Si({\"fill-antialias\":new wi(Lt.paint_fill[\"fill-antialias\"]),\"fill-opacity\":new Ti(Lt.paint_fill[\"fill-opacity\"]),\"fill-color\":new Ti(Lt.paint_fill[\"fill-color\"]),\"fill-outline-color\":new Ti(Lt.paint_fill[\"fill-outline-color\"]),\"fill-translate\":new wi(Lt.paint_fill[\"fill-translate\"]),\"fill-translate-anchor\":new wi(Lt.paint_fill[\"fill-translate-anchor\"]),\"fill-pattern\":new ki(Lt.paint_fill[\"fill-pattern\"])}),layout:vs},xs=function(t){function e(e){t.call(this,e,ys)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.recalculate=function(e,r){t.prototype.recalculate.call(this,e,r);var n=this.paint._values[\"fill-outline-color\"];\"constant\"===n.value.kind&&void 0===n.value.value&&(this.paint._values[\"fill-outline-color\"]=this.paint._values[\"fill-color\"])},e.prototype.createBucket=function(t){return new gs(t)},e.prototype.queryRadius=function(){return so(this.paint.get(\"fill-translate\"))},e.prototype.queryIntersectsFeature=function(t,e,r,n,i,a,o){return Ka(lo(t,this.paint.get(\"fill-translate\"),this.paint.get(\"fill-translate-anchor\"),a.angle,o),n)},e.prototype.isTileClipped=function(){return!0},e}(Ei),bs=Ii([{name:\"a_pos\",components:2,type:\"Int16\"},{name:\"a_normal_ed\",components:4,type:\"Int16\"}],4).members,_s=ws;function ws(t,e,r,n,i){this.properties={},this.extent=r,this.type=0,this._pbf=t,this._geometry=-1,this._keys=n,this._values=i,t.readFields(Ts,this,e)}function Ts(t,e,r){1==t?e.id=r.readVarint():2==t?function(t,e){var r=t.readVarint()+t.pos;for(;t.pos<r;){var n=e._keys[t.readVarint()],i=e._values[t.readVarint()];e.properties[n]=i}}(r,e):3==t?e.type=r.readVarint():4==t&&(e._geometry=r.pos)}function ks(t){for(var e,r,n=0,i=0,a=t.length,o=a-1;i<a;o=i++)e=t[i],n+=((r=t[o]).x-e.x)*(e.y+r.y);return n}ws.types=[\"Unknown\",\"Point\",\"LineString\",\"Polygon\"],ws.prototype.loadGeometry=function(){var t=this._pbf;t.pos=this._geometry;for(var e,r=t.readVarint()+t.pos,n=1,a=0,o=0,s=0,l=[];t.pos<r;){if(a<=0){var c=t.readVarint();n=7&c,a=c>>3}if(a--,1===n||2===n)o+=t.readSVarint(),s+=t.readSVarint(),1===n&&(e&&l.push(e),e=[]),e.push(new i(o,s));else{if(7!==n)throw new Error(\"unknown command \"+n);e&&e.push(e[0].clone())}}return e&&l.push(e),l},ws.prototype.bbox=function(){var t=this._pbf;t.pos=this._geometry;for(var e=t.readVarint()+t.pos,r=1,n=0,i=0,a=0,o=1/0,s=-1/0,l=1/0,c=-1/0;t.pos<e;){if(n<=0){var u=t.readVarint();r=7&u,n=u>>3}if(n--,1===r||2===r)(i+=t.readSVarint())<o&&(o=i),i>s&&(s=i),(a+=t.readSVarint())<l&&(l=a),a>c&&(c=a);else if(7!==r)throw new Error(\"unknown command \"+r)}return[o,l,s,c]},ws.prototype.toGeoJSON=function(t,e,r){var n,i,a=this.extent*Math.pow(2,r),o=this.extent*t,s=this.extent*e,l=this.loadGeometry(),c=ws.types[this.type];function u(t){for(var e=0;e<t.length;e++){var r=t[e],n=180-360*(r.y+s)/a;t[e]=[360*(r.x+o)/a-180,360/Math.PI*Math.atan(Math.exp(n*Math.PI/180))-90]}}switch(this.type){case 1:var f=[];for(n=0;n<l.length;n++)f[n]=l[n][0];u(l=f);break;case 2:for(n=0;n<l.length;n++)u(l[n]);break;case 3:for(l=function(t){var e=t.length;if(e<=1)return[t];for(var r,n,i=[],a=0;a<e;a++){var o=ks(t[a]);0!==o&&(void 0===n&&(n=o<0),n===o<0?(r&&i.push(r),r=[t[a]]):r.push(t[a]))}r&&i.push(r);return i}(l),n=0;n<l.length;n++)for(i=0;i<l[n].length;i++)u(l[n][i])}1===l.length?l=l[0]:c=\"Multi\"+c;var h={type:\"Feature\",geometry:{type:c,coordinates:l},properties:this.properties};return\"id\"in this&&(h.id=this.id),h};var Ms=As;function As(t,e){this.version=1,this.name=null,this.extent=4096,this.length=0,this._pbf=t,this._keys=[],this._values=[],this._features=[],t.readFields(Ss,this,e),this.length=this._features.length}function Ss(t,e,r){15===t?e.version=r.readVarint():1===t?e.name=r.readString():5===t?e.extent=r.readVarint():2===t?e._features.push(r.pos):3===t?e._keys.push(r.readString()):4===t&&e._values.push(function(t){var e=null,r=t.readVarint()+t.pos;for(;t.pos<r;){var n=t.readVarint()>>3;e=1===n?t.readString():2===n?t.readFloat():3===n?t.readDouble():4===n?t.readVarint64():5===n?t.readVarint():6===n?t.readSVarint():7===n?t.readBoolean():null}return e}(r))}function Es(t,e,r){if(3===t){var n=new Ms(r,r.readVarint()+r.pos);n.length&&(e[n.name]=n)}}As.prototype.feature=function(t){if(t<0||t>=this._features.length)throw new Error(\"feature index out of bounds\");this._pbf.pos=this._features[t];var e=this._pbf.readVarint()+this._pbf.pos;return new _s(this._pbf,e,this.extent,this._keys,this._values)};var Ls={VectorTile:function(t,e){this.layers=t.readFields(Es,{},e)},VectorTileFeature:_s,VectorTileLayer:Ms},Cs=Ls.VectorTileFeature.types,Ps=Math.pow(2,13);function Is(t,e,r,n,i,a,o,s){t.emplaceBack(e,r,2*Math.floor(n*Ps)+o,i*Ps*2,a*Ps*2,Math.round(s))}var Os=function(t){this.zoom=t.zoom,this.overscaling=t.overscaling,this.layers=t.layers,this.layerIds=this.layers.map((function(t){return t.id})),this.index=t.index,this.hasPattern=!1,this.layoutVertexArray=new Ri,this.indexArray=new Yi,this.programConfigurations=new Ua(bs,t.layers,t.zoom),this.segments=new pa,this.stateDependentLayerIds=this.layers.filter((function(t){return t.isStateDependent()})).map((function(t){return t.id}))};function zs(t,e){return t.x===e.x&&(t.x<0||t.x>8192)||t.y===e.y&&(t.y<0||t.y>8192)}function Ds(t){return t.every((function(t){return t.x<0}))||t.every((function(t){return t.x>8192}))||t.every((function(t){return t.y<0}))||t.every((function(t){return t.y>8192}))}Os.prototype.populate=function(t,e,r){this.features=[],this.hasPattern=ds(\"fill-extrusion\",this.layers,e);for(var n=0,i=t;n<i.length;n+=1){var a=i[n],o=a.feature,s=a.id,l=a.index,c=a.sourceLayerIndex,u=this.layers[0]._featureFilter.needGeometry,f={type:o.type,id:s,properties:o.properties,geometry:u?Ya(o):[]};if(this.layers[0]._featureFilter.filter(new pi(this.zoom),f,r)){var h={id:s,sourceLayerIndex:c,index:l,geometry:u?f.geometry:Ya(o),properties:o.properties,type:o.type,patterns:{}};void 0!==o.id&&(h.id=o.id),this.hasPattern?this.features.push(ms(\"fill-extrusion\",this.layers,h,this.zoom,e)):this.addFeature(h,h.geometry,l,r,{}),e.featureIndex.insert(o,h.geometry,l,c,this.index,!0)}}},Os.prototype.addFeatures=function(t,e,r){for(var n=0,i=this.features;n<i.length;n+=1){var a=i[n],o=a.geometry;this.addFeature(a,o,a.index,e,r)}},Os.prototype.update=function(t,e,r){this.stateDependentLayers.length&&this.programConfigurations.updatePaintArrays(t,e,this.stateDependentLayers,r)},Os.prototype.isEmpty=function(){return 0===this.layoutVertexArray.length},Os.prototype.uploadPending=function(){return!this.uploaded||this.programConfigurations.needsUpload},Os.prototype.upload=function(t){this.uploaded||(this.layoutVertexBuffer=t.createVertexBuffer(this.layoutVertexArray,bs),this.indexBuffer=t.createIndexBuffer(this.indexArray)),this.programConfigurations.upload(t),this.uploaded=!0},Os.prototype.destroy=function(){this.layoutVertexBuffer&&(this.layoutVertexBuffer.destroy(),this.indexBuffer.destroy(),this.programConfigurations.destroy(),this.segments.destroy())},Os.prototype.addFeature=function(t,e,r,n,i){for(var a=0,o=hs(e,500);a<o.length;a+=1){for(var s=o[a],l=0,c=0,u=s;c<u.length;c+=1){l+=u[c].length}for(var f=this.segments.prepareSegment(4,this.layoutVertexArray,this.indexArray),h=0,p=s;h<p.length;h+=1){var d=p[h];if(0!==d.length&&!Ds(d))for(var m=0,g=0;g<d.length;g++){var v=d[g];if(g>=1){var y=d[g-1];if(!zs(v,y)){f.vertexLength+4>pa.MAX_VERTEX_ARRAY_LENGTH&&(f=this.segments.prepareSegment(4,this.layoutVertexArray,this.indexArray));var x=v.sub(y)._perp()._unit(),b=y.dist(v);m+b>32768&&(m=0),Is(this.layoutVertexArray,v.x,v.y,x.x,x.y,0,0,m),Is(this.layoutVertexArray,v.x,v.y,x.x,x.y,0,1,m),m+=b,Is(this.layoutVertexArray,y.x,y.y,x.x,x.y,0,0,m),Is(this.layoutVertexArray,y.x,y.y,x.x,x.y,0,1,m);var _=f.vertexLength;this.indexArray.emplaceBack(_,_+2,_+1),this.indexArray.emplaceBack(_+1,_+2,_+3),f.vertexLength+=4,f.primitiveLength+=2}}}}if(f.vertexLength+l>pa.MAX_VERTEX_ARRAY_LENGTH&&(f=this.segments.prepareSegment(l,this.layoutVertexArray,this.indexArray)),\"Polygon\"===Cs[t.type]){for(var w=[],T=[],k=f.vertexLength,M=0,A=s;M<A.length;M+=1){var S=A[M];if(0!==S.length){S!==s[0]&&T.push(w.length/2);for(var E=0;E<S.length;E++){var L=S[E];Is(this.layoutVertexArray,L.x,L.y,0,0,1,1,0),w.push(L.x),w.push(L.y)}}}for(var C=Do(w,T),P=0;P<C.length;P+=3)this.indexArray.emplaceBack(k+C[P],k+C[P+2],k+C[P+1]);f.primitiveLength+=C.length/3,f.vertexLength+=l}}this.programConfigurations.populatePaintArrays(this.layoutVertexArray.length,t,r,i,n)},Nn(\"FillExtrusionBucket\",Os,{omit:[\"layers\",\"features\"]});var Rs={paint:new Si({\"fill-extrusion-opacity\":new wi(Lt[\"paint_fill-extrusion\"][\"fill-extrusion-opacity\"]),\"fill-extrusion-color\":new Ti(Lt[\"paint_fill-extrusion\"][\"fill-extrusion-color\"]),\"fill-extrusion-translate\":new wi(Lt[\"paint_fill-extrusion\"][\"fill-extrusion-translate\"]),\"fill-extrusion-translate-anchor\":new wi(Lt[\"paint_fill-extrusion\"][\"fill-extrusion-translate-anchor\"]),\"fill-extrusion-pattern\":new ki(Lt[\"paint_fill-extrusion\"][\"fill-extrusion-pattern\"]),\"fill-extrusion-height\":new Ti(Lt[\"paint_fill-extrusion\"][\"fill-extrusion-height\"]),\"fill-extrusion-base\":new Ti(Lt[\"paint_fill-extrusion\"][\"fill-extrusion-base\"]),\"fill-extrusion-vertical-gradient\":new wi(Lt[\"paint_fill-extrusion\"][\"fill-extrusion-vertical-gradient\"])})},Fs=function(t){function e(e){t.call(this,e,Rs)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.createBucket=function(t){return new Os(t)},e.prototype.queryRadius=function(){return so(this.paint.get(\"fill-extrusion-translate\"))},e.prototype.is3D=function(){return!0},e.prototype.queryIntersectsFeature=function(t,e,r,n,a,o,s,l){var c=lo(t,this.paint.get(\"fill-extrusion-translate\"),this.paint.get(\"fill-extrusion-translate-anchor\"),o.angle,s),u=this.paint.get(\"fill-extrusion-height\").evaluate(e,r),f=this.paint.get(\"fill-extrusion-base\").evaluate(e,r),h=function(t,e,r,n){for(var a=[],o=0,s=t;o<s.length;o+=1){var l=s[o],c=[l.x,l.y,n,1];xo(c,c,e),a.push(new i(c[0]/c[3],c[1]/c[3]))}return a}(c,l,0,0),p=function(t,e,r,n){for(var a=[],o=[],s=n[8]*e,l=n[9]*e,c=n[10]*e,u=n[11]*e,f=n[8]*r,h=n[9]*r,p=n[10]*r,d=n[11]*r,m=0,g=t;m<g.length;m+=1){for(var v=g[m],y=[],x=[],b=0,_=v;b<_.length;b+=1){var w=_[b],T=w.x,k=w.y,M=n[0]*T+n[4]*k+n[12],A=n[1]*T+n[5]*k+n[13],S=n[2]*T+n[6]*k+n[14],E=n[3]*T+n[7]*k+n[15],L=S+c,C=E+u,P=M+f,I=A+h,O=S+p,z=E+d,D=new i((M+s)/C,(A+l)/C);D.z=L/C,y.push(D);var R=new i(P/z,I/z);R.z=O/z,x.push(R)}a.push(y),o.push(x)}return[a,o]}(n,f,u,l);return function(t,e,r){var n=1/0;Ka(r,e)&&(n=Ns(r,e[0]));for(var i=0;i<e.length;i++)for(var a=e[i],o=t[i],s=0;s<a.length-1;s++){var l=a[s],c=a[s+1],u=o[s],f=o[s+1],h=[l,c,f,u,l];Za(r,h)&&(n=Math.min(n,Ns(r,h)))}return n!==1/0&&n}(p[0],p[1],h)},e}(Ei);function Bs(t,e){return t.x*e.x+t.y*e.y}function Ns(t,e){if(1===t.length){for(var r,n=0,i=e[n++];!r||i.equals(r);)if(!(r=e[n++]))return 1/0;for(;n<e.length;n++){var a=e[n],o=t[0],s=r.sub(i),l=a.sub(i),c=o.sub(i),u=Bs(s,s),f=Bs(s,l),h=Bs(l,l),p=Bs(c,s),d=Bs(c,l),m=u*h-f*f,g=(h*p-f*d)/m,v=(u*d-f*p)/m,y=1-g-v,x=i.z*y+r.z*g+a.z*v;if(isFinite(x))return x}return 1/0}for(var b=1/0,_=0,w=e;_<w.length;_+=1){var T=w[_];b=Math.min(b,T.z)}return b}var js=Ii([{name:\"a_pos_normal\",components:2,type:\"Int16\"},{name:\"a_data\",components:4,type:\"Uint8\"}],4).members,Us=Ls.VectorTileFeature.types,Vs=Math.cos(Math.PI/180*37.5),qs=Math.pow(2,14)/.5,Hs=function(t){this.zoom=t.zoom,this.overscaling=t.overscaling,this.layers=t.layers,this.layerIds=this.layers.map((function(t){return t.id})),this.index=t.index,this.hasPattern=!1,this.patternFeatures=[],this.layoutVertexArray=new Fi,this.indexArray=new Yi,this.programConfigurations=new Ua(js,t.layers,t.zoom),this.segments=new pa,this.stateDependentLayerIds=this.layers.filter((function(t){return t.isStateDependent()})).map((function(t){return t.id}))};Hs.prototype.populate=function(t,e,r){this.hasPattern=ds(\"line\",this.layers,e);for(var n=this.layers[0].layout.get(\"line-sort-key\"),i=[],a=0,o=t;a<o.length;a+=1){var s=o[a],l=s.feature,c=s.id,u=s.index,f=s.sourceLayerIndex,h=this.layers[0]._featureFilter.needGeometry,p={type:l.type,id:c,properties:l.properties,geometry:h?Ya(l):[]};if(this.layers[0]._featureFilter.filter(new pi(this.zoom),p,r)){h||(p.geometry=Ya(l));var d=n?n.evaluate(p,{},r):void 0,m={id:c,properties:l.properties,type:l.type,sourceLayerIndex:f,index:u,geometry:p.geometry,patterns:{},sortKey:d};i.push(m)}}n&&i.sort((function(t,e){return t.sortKey-e.sortKey}));for(var g=0,v=i;g<v.length;g+=1){var y=v[g],x=y,b=x.geometry,_=x.index,w=x.sourceLayerIndex;if(this.hasPattern){var T=ms(\"line\",this.layers,y,this.zoom,e);this.patternFeatures.push(T)}else this.addFeature(y,b,_,r,{});var k=t[_].feature;e.featureIndex.insert(k,b,_,w,this.index)}},Hs.prototype.update=function(t,e,r){this.stateDependentLayers.length&&this.programConfigurations.updatePaintArrays(t,e,this.stateDependentLayers,r)},Hs.prototype.addFeatures=function(t,e,r){for(var n=0,i=this.patternFeatures;n<i.length;n+=1){var a=i[n];this.addFeature(a,a.geometry,a.index,e,r)}},Hs.prototype.isEmpty=function(){return 0===this.layoutVertexArray.length},Hs.prototype.uploadPending=function(){return!this.uploaded||this.programConfigurations.needsUpload},Hs.prototype.upload=function(t){this.uploaded||(this.layoutVertexBuffer=t.createVertexBuffer(this.layoutVertexArray,js),this.indexBuffer=t.createIndexBuffer(this.indexArray)),this.programConfigurations.upload(t),this.uploaded=!0},Hs.prototype.destroy=function(){this.layoutVertexBuffer&&(this.layoutVertexBuffer.destroy(),this.indexBuffer.destroy(),this.programConfigurations.destroy(),this.segments.destroy())},Hs.prototype.addFeature=function(t,e,r,n,i){for(var a=this.layers[0].layout,o=a.get(\"line-join\").evaluate(t,{}),s=a.get(\"line-cap\"),l=a.get(\"line-miter-limit\"),c=a.get(\"line-round-limit\"),u=0,f=e;u<f.length;u+=1){var h=f[u];this.addLine(h,t,o,s,l,c)}this.programConfigurations.populatePaintArrays(this.layoutVertexArray.length,t,r,i,n)},Hs.prototype.addLine=function(t,e,r,n,i,a){if(this.distance=0,this.scaledDistance=0,this.totalDistance=0,e.properties&&e.properties.hasOwnProperty(\"mapbox_clip_start\")&&e.properties.hasOwnProperty(\"mapbox_clip_end\")){this.clipStart=+e.properties.mapbox_clip_start,this.clipEnd=+e.properties.mapbox_clip_end;for(var o=0;o<t.length-1;o++)this.totalDistance+=t[o].dist(t[o+1]);this.updateScaledDistance()}for(var s=\"Polygon\"===Us[e.type],l=t.length;l>=2&&t[l-1].equals(t[l-2]);)l--;for(var c=0;c<l-1&&t[c].equals(t[c+1]);)c++;if(!(l<(s?3:2))){\"bevel\"===r&&(i=1.05);var u,f=this.overscaling<=16?122880/(512*this.overscaling):0,h=this.segments.prepareSegment(10*l,this.layoutVertexArray,this.indexArray),p=void 0,d=void 0,m=void 0,g=void 0;this.e1=this.e2=-1,s&&(u=t[l-2],g=t[c].sub(u)._unit()._perp());for(var v=c;v<l;v++)if(!(d=v===l-1?s?t[c+1]:void 0:t[v+1])||!t[v].equals(d)){g&&(m=g),u&&(p=u),u=t[v],g=d?d.sub(u)._unit()._perp():m;var y=(m=m||g).add(g);0===y.x&&0===y.y||y._unit();var x=m.x*g.x+m.y*g.y,b=y.x*g.x+y.y*g.y,_=0!==b?1/b:1/0,w=2*Math.sqrt(2-2*b),T=b<Vs&&p&&d,k=m.x*g.y-m.y*g.x>0;if(T&&v>c){var M=u.dist(p);if(M>2*f){var A=u.sub(u.sub(p)._mult(f/M)._round());this.updateDistance(p,A),this.addCurrentVertex(A,m,0,0,h),p=A}}var S=p&&d,E=S?r:s?\"butt\":n;if(S&&\"round\"===E&&(_<a?E=\"miter\":_<=2&&(E=\"fakeround\")),\"miter\"===E&&_>i&&(E=\"bevel\"),\"bevel\"===E&&(_>2&&(E=\"flipbevel\"),_<i&&(E=\"miter\")),p&&this.updateDistance(p,u),\"miter\"===E)y._mult(_),this.addCurrentVertex(u,y,0,0,h);else if(\"flipbevel\"===E){if(_>100)y=g.mult(-1);else{var L=_*m.add(g).mag()/m.sub(g).mag();y._perp()._mult(L*(k?-1:1))}this.addCurrentVertex(u,y,0,0,h),this.addCurrentVertex(u,y.mult(-1),0,0,h)}else if(\"bevel\"===E||\"fakeround\"===E){var C=-Math.sqrt(_*_-1),P=k?C:0,I=k?0:C;if(p&&this.addCurrentVertex(u,m,P,I,h),\"fakeround\"===E)for(var O=Math.round(180*w/Math.PI/20),z=1;z<O;z++){var D=z/O;if(.5!==D){var R=D-.5;D+=D*R*(D-1)*((1.0904+x*(x*(3.55645-1.43519*x)-3.2452))*R*R+(.848013+x*(.215638*x-1.06021)))}var F=g.sub(m)._mult(D)._add(m)._unit()._mult(k?-1:1);this.addHalfVertex(u,F.x,F.y,!1,k,0,h)}d&&this.addCurrentVertex(u,g,-P,-I,h)}else if(\"butt\"===E)this.addCurrentVertex(u,y,0,0,h);else if(\"square\"===E){var B=p?1:-1;this.addCurrentVertex(u,y,B,B,h)}else\"round\"===E&&(p&&(this.addCurrentVertex(u,m,0,0,h),this.addCurrentVertex(u,m,1,1,h,!0)),d&&(this.addCurrentVertex(u,g,-1,-1,h,!0),this.addCurrentVertex(u,g,0,0,h)));if(T&&v<l-1){var N=u.dist(d);if(N>2*f){var j=u.add(d.sub(u)._mult(f/N)._round());this.updateDistance(u,j),this.addCurrentVertex(j,g,0,0,h),u=j}}}}},Hs.prototype.addCurrentVertex=function(t,e,r,n,i,a){void 0===a&&(a=!1);var o=e.x+e.y*r,s=e.y-e.x*r,l=-e.x+e.y*n,c=-e.y-e.x*n;this.addHalfVertex(t,o,s,a,!1,r,i),this.addHalfVertex(t,l,c,a,!0,-n,i),this.distance>qs/2&&0===this.totalDistance&&(this.distance=0,this.addCurrentVertex(t,e,r,n,i,a))},Hs.prototype.addHalfVertex=function(t,e,r,n,i,a,o){var s=t.x,l=t.y,c=.5*this.scaledDistance;this.layoutVertexArray.emplaceBack((s<<1)+(n?1:0),(l<<1)+(i?1:0),Math.round(63*e)+128,Math.round(63*r)+128,1+(0===a?0:a<0?-1:1)|(63&c)<<2,c>>6);var u=o.vertexLength++;this.e1>=0&&this.e2>=0&&(this.indexArray.emplaceBack(this.e1,this.e2,u),o.primitiveLength++),i?this.e2=u:this.e1=u},Hs.prototype.updateScaledDistance=function(){this.scaledDistance=this.totalDistance>0?(this.clipStart+(this.clipEnd-this.clipStart)*this.distance/this.totalDistance)*(qs-1):this.distance},Hs.prototype.updateDistance=function(t,e){this.distance+=t.dist(e),this.updateScaledDistance()},Nn(\"LineBucket\",Hs,{omit:[\"layers\",\"patternFeatures\"]});var Gs=new Si({\"line-cap\":new wi(Lt.layout_line[\"line-cap\"]),\"line-join\":new Ti(Lt.layout_line[\"line-join\"]),\"line-miter-limit\":new wi(Lt.layout_line[\"line-miter-limit\"]),\"line-round-limit\":new wi(Lt.layout_line[\"line-round-limit\"]),\"line-sort-key\":new Ti(Lt.layout_line[\"line-sort-key\"])}),Ys={paint:new Si({\"line-opacity\":new Ti(Lt.paint_line[\"line-opacity\"]),\"line-color\":new Ti(Lt.paint_line[\"line-color\"]),\"line-translate\":new wi(Lt.paint_line[\"line-translate\"]),\"line-translate-anchor\":new wi(Lt.paint_line[\"line-translate-anchor\"]),\"line-width\":new Ti(Lt.paint_line[\"line-width\"]),\"line-gap-width\":new Ti(Lt.paint_line[\"line-gap-width\"]),\"line-offset\":new Ti(Lt.paint_line[\"line-offset\"]),\"line-blur\":new Ti(Lt.paint_line[\"line-blur\"]),\"line-dasharray\":new Mi(Lt.paint_line[\"line-dasharray\"]),\"line-pattern\":new ki(Lt.paint_line[\"line-pattern\"]),\"line-gradient\":new Ai(Lt.paint_line[\"line-gradient\"])}),layout:Gs},Ws=new(function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.possiblyEvaluate=function(e,r){return r=new pi(Math.floor(r.zoom),{now:r.now,fadeDuration:r.fadeDuration,zoomHistory:r.zoomHistory,transition:r.transition}),t.prototype.possiblyEvaluate.call(this,e,r)},e.prototype.evaluate=function(e,r,n,i){return r=u({},r,{zoom:Math.floor(r.zoom)}),t.prototype.evaluate.call(this,e,r,n,i)},e}(Ti))(Ys.paint.properties[\"line-width\"].specification);Ws.useIntegerZoom=!0;var Xs=function(t){function e(e){t.call(this,e,Ys)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._handleSpecialPaintPropertyUpdate=function(t){\"line-gradient\"===t&&this._updateGradient()},e.prototype._updateGradient=function(){var t=this._transitionablePaint._values[\"line-gradient\"].value.expression;this.gradient=Co(t,\"lineProgress\"),this.gradientTexture=null},e.prototype.recalculate=function(e,r){t.prototype.recalculate.call(this,e,r),this.paint._values[\"line-floorwidth\"]=Ws.possiblyEvaluate(this._transitioningPaint._values[\"line-width\"].value,e)},e.prototype.createBucket=function(t){return new Hs(t)},e.prototype.queryRadius=function(t){var e=t,r=Zs(oo(\"line-width\",this,e),oo(\"line-gap-width\",this,e)),n=oo(\"line-offset\",this,e);return r/2+Math.abs(n)+so(this.paint.get(\"line-translate\"))},e.prototype.queryIntersectsFeature=function(t,e,r,n,a,o,s){var l=lo(t,this.paint.get(\"line-translate\"),this.paint.get(\"line-translate-anchor\"),o.angle,s),c=s/2*Zs(this.paint.get(\"line-width\").evaluate(e,r),this.paint.get(\"line-gap-width\").evaluate(e,r)),u=this.paint.get(\"line-offset\").evaluate(e,r);return u&&(n=function(t,e){for(var r=[],n=new i(0,0),a=0;a<t.length;a++){for(var o=t[a],s=[],l=0;l<o.length;l++){var c=o[l-1],u=o[l],f=o[l+1],h=0===l?n:u.sub(c)._unit()._perp(),p=l===o.length-1?n:f.sub(u)._unit()._perp(),d=h._add(p)._unit(),m=d.x*p.x+d.y*p.y;d._mult(1/m),s.push(d._mult(e)._add(u))}r.push(s)}return r}(n,u*s)),function(t,e,r){for(var n=0;n<e.length;n++){var i=e[n];if(t.length>=3)for(var a=0;a<i.length;a++)if(io(t,i[a]))return!0;if(Qa(t,i,r))return!0}return!1}(l,n,c)},e.prototype.isTileClipped=function(){return!0},e}(Ei);function Zs(t,e){return e>0?e+2*t:t}var Js=Ii([{name:\"a_pos_offset\",components:4,type:\"Int16\"},{name:\"a_data\",components:4,type:\"Uint16\"},{name:\"a_pixeloffset\",components:4,type:\"Int16\"}],4),Ks=Ii([{name:\"a_projected_pos\",components:3,type:\"Float32\"}],4),Qs=(Ii([{name:\"a_fade_opacity\",components:1,type:\"Uint32\"}],4),Ii([{name:\"a_placed\",components:2,type:\"Uint8\"},{name:\"a_shift\",components:2,type:\"Float32\"}])),$s=(Ii([{type:\"Int16\",name:\"anchorPointX\"},{type:\"Int16\",name:\"anchorPointY\"},{type:\"Int16\",name:\"x1\"},{type:\"Int16\",name:\"y1\"},{type:\"Int16\",name:\"x2\"},{type:\"Int16\",name:\"y2\"},{type:\"Uint32\",name:\"featureIndex\"},{type:\"Uint16\",name:\"sourceLayerIndex\"},{type:\"Uint16\",name:\"bucketIndex\"}]),Ii([{name:\"a_pos\",components:2,type:\"Int16\"},{name:\"a_anchor_pos\",components:2,type:\"Int16\"},{name:\"a_extrude\",components:2,type:\"Int16\"}],4)),tl=Ii([{name:\"a_pos\",components:2,type:\"Float32\"},{name:\"a_radius\",components:1,type:\"Float32\"},{name:\"a_flags\",components:2,type:\"Int16\"}],4);Ii([{name:\"triangle\",components:3,type:\"Uint16\"}]),Ii([{type:\"Int16\",name:\"anchorX\"},{type:\"Int16\",name:\"anchorY\"},{type:\"Uint16\",name:\"glyphStartIndex\"},{type:\"Uint16\",name:\"numGlyphs\"},{type:\"Uint32\",name:\"vertexStartIndex\"},{type:\"Uint32\",name:\"lineStartIndex\"},{type:\"Uint32\",name:\"lineLength\"},{type:\"Uint16\",name:\"segment\"},{type:\"Uint16\",name:\"lowerSize\"},{type:\"Uint16\",name:\"upperSize\"},{type:\"Float32\",name:\"lineOffsetX\"},{type:\"Float32\",name:\"lineOffsetY\"},{type:\"Uint8\",name:\"writingMode\"},{type:\"Uint8\",name:\"placedOrientation\"},{type:\"Uint8\",name:\"hidden\"},{type:\"Uint32\",name:\"crossTileID\"},{type:\"Int16\",name:\"associatedIconIndex\"}]),Ii([{type:\"Int16\",name:\"anchorX\"},{type:\"Int16\",name:\"anchorY\"},{type:\"Int16\",name:\"rightJustifiedTextSymbolIndex\"},{type:\"Int16\",name:\"centerJustifiedTextSymbolIndex\"},{type:\"Int16\",name:\"leftJustifiedTextSymbolIndex\"},{type:\"Int16\",name:\"verticalPlacedTextSymbolIndex\"},{type:\"Int16\",name:\"placedIconSymbolIndex\"},{type:\"Int16\",name:\"verticalPlacedIconSymbolIndex\"},{type:\"Uint16\",name:\"key\"},{type:\"Uint16\",name:\"textBoxStartIndex\"},{type:\"Uint16\",name:\"textBoxEndIndex\"},{type:\"Uint16\",name:\"verticalTextBoxStartIndex\"},{type:\"Uint16\",name:\"verticalTextBoxEndIndex\"},{type:\"Uint16\",name:\"iconBoxStartIndex\"},{type:\"Uint16\",name:\"iconBoxEndIndex\"},{type:\"Uint16\",name:\"verticalIconBoxStartIndex\"},{type:\"Uint16\",name:\"verticalIconBoxEndIndex\"},{type:\"Uint16\",name:\"featureIndex\"},{type:\"Uint16\",name:\"numHorizontalGlyphVertices\"},{type:\"Uint16\",name:\"numVerticalGlyphVertices\"},{type:\"Uint16\",name:\"numIconVertices\"},{type:\"Uint16\",name:\"numVerticalIconVertices\"},{type:\"Uint16\",name:\"useRuntimeCollisionCircles\"},{type:\"Uint32\",name:\"crossTileID\"},{type:\"Float32\",name:\"textBoxScale\"},{type:\"Float32\",components:2,name:\"textOffset\"},{type:\"Float32\",name:\"collisionCircleDiameter\"}]),Ii([{type:\"Float32\",name:\"offsetX\"}]),Ii([{type:\"Int16\",name:\"x\"},{type:\"Int16\",name:\"y\"},{type:\"Int16\",name:\"tileUnitDistanceFromAnchor\"}]);function el(t,e,r){return t.sections.forEach((function(t){t.text=function(t,e,r){var n=e.layout.get(\"text-transform\").evaluate(r,{});return\"uppercase\"===n?t=t.toLocaleUpperCase():\"lowercase\"===n&&(t=t.toLocaleLowerCase()),hi.applyArabicShaping&&(t=hi.applyArabicShaping(t)),t}(t.text,e,r)})),t}var rl={\"!\":\"\\ufe15\",\"#\":\"\\uff03\",$:\"\\uff04\",\"%\":\"\\uff05\",\"&\":\"\\uff06\",\"(\":\"\\ufe35\",\")\":\"\\ufe36\",\"*\":\"\\uff0a\",\"+\":\"\\uff0b\",\",\":\"\\ufe10\",\"-\":\"\\ufe32\",\".\":\"\\u30fb\",\"/\":\"\\uff0f\",\":\":\"\\ufe13\",\";\":\"\\ufe14\",\"<\":\"\\ufe3f\",\"=\":\"\\uff1d\",\">\":\"\\ufe40\",\"?\":\"\\ufe16\",\"@\":\"\\uff20\",\"[\":\"\\ufe47\",\"\\\\\":\"\\uff3c\",\"]\":\"\\ufe48\",\"^\":\"\\uff3e\",_:\"\\ufe33\",\"`\":\"\\uff40\",\"{\":\"\\ufe37\",\"|\":\"\\u2015\",\"}\":\"\\ufe38\",\"~\":\"\\uff5e\",\"\\xa2\":\"\\uffe0\",\"\\xa3\":\"\\uffe1\",\"\\xa5\":\"\\uffe5\",\"\\xa6\":\"\\uffe4\",\"\\xac\":\"\\uffe2\",\"\\xaf\":\"\\uffe3\",\"\\u2013\":\"\\ufe32\",\"\\u2014\":\"\\ufe31\",\"\\u2018\":\"\\ufe43\",\"\\u2019\":\"\\ufe44\",\"\\u201c\":\"\\ufe41\",\"\\u201d\":\"\\ufe42\",\"\\u2026\":\"\\ufe19\",\"\\u2027\":\"\\u30fb\",\"\\u20a9\":\"\\uffe6\",\"\\u3001\":\"\\ufe11\",\"\\u3002\":\"\\ufe12\",\"\\u3008\":\"\\ufe3f\",\"\\u3009\":\"\\ufe40\",\"\\u300a\":\"\\ufe3d\",\"\\u300b\":\"\\ufe3e\",\"\\u300c\":\"\\ufe41\",\"\\u300d\":\"\\ufe42\",\"\\u300e\":\"\\ufe43\",\"\\u300f\":\"\\ufe44\",\"\\u3010\":\"\\ufe3b\",\"\\u3011\":\"\\ufe3c\",\"\\u3014\":\"\\ufe39\",\"\\u3015\":\"\\ufe3a\",\"\\u3016\":\"\\ufe17\",\"\\u3017\":\"\\ufe18\",\"\\uff01\":\"\\ufe15\",\"\\uff08\":\"\\ufe35\",\"\\uff09\":\"\\ufe36\",\"\\uff0c\":\"\\ufe10\",\"\\uff0d\":\"\\ufe32\",\"\\uff0e\":\"\\u30fb\",\"\\uff1a\":\"\\ufe13\",\"\\uff1b\":\"\\ufe14\",\"\\uff1c\":\"\\ufe3f\",\"\\uff1e\":\"\\ufe40\",\"\\uff1f\":\"\\ufe16\",\"\\uff3b\":\"\\ufe47\",\"\\uff3d\":\"\\ufe48\",\"\\uff3f\":\"\\ufe33\",\"\\uff5b\":\"\\ufe37\",\"\\uff5c\":\"\\u2015\",\"\\uff5d\":\"\\ufe38\",\"\\uff5f\":\"\\ufe35\",\"\\uff60\":\"\\ufe36\",\"\\uff61\":\"\\ufe12\",\"\\uff62\":\"\\ufe41\",\"\\uff63\":\"\\ufe42\"};var nl=function(t,e,r,n,i){var a,o,s=8*i-n-1,l=(1<<s)-1,c=l>>1,u=-7,f=r?i-1:0,h=r?-1:1,p=t[e+f];for(f+=h,a=p&(1<<-u)-1,p>>=-u,u+=s;u>0;a=256*a+t[e+f],f+=h,u-=8);for(o=a&(1<<-u)-1,a>>=-u,u+=n;u>0;o=256*o+t[e+f],f+=h,u-=8);if(0===a)a=1-c;else{if(a===l)return o?NaN:1/0*(p?-1:1);o+=Math.pow(2,n),a-=c}return(p?-1:1)*o*Math.pow(2,a-n)},il=function(t,e,r,n,i,a){var o,s,l,c=8*a-i-1,u=(1<<c)-1,f=u>>1,h=23===i?Math.pow(2,-24)-Math.pow(2,-77):0,p=n?0:a-1,d=n?1:-1,m=e<0||0===e&&1/e<0?1:0;for(e=Math.abs(e),isNaN(e)||e===1/0?(s=isNaN(e)?1:0,o=u):(o=Math.floor(Math.log(e)/Math.LN2),e*(l=Math.pow(2,-o))<1&&(o--,l*=2),(e+=o+f>=1?h/l:h*Math.pow(2,1-f))*l>=2&&(o++,l/=2),o+f>=u?(s=0,o=u):o+f>=1?(s=(e*l-1)*Math.pow(2,i),o+=f):(s=e*Math.pow(2,f-1)*Math.pow(2,i),o=0));i>=8;t[r+p]=255&s,p+=d,s/=256,i-=8);for(o=o<<i|s,c+=i;c>0;t[r+p]=255&o,p+=d,o/=256,c-=8);t[r+p-d]|=128*m},al=ol;function ol(t){this.buf=ArrayBuffer.isView&&ArrayBuffer.isView(t)?t:new Uint8Array(t||0),this.pos=0,this.type=0,this.length=this.buf.length}ol.Varint=0,ol.Fixed64=1,ol.Bytes=2,ol.Fixed32=5;var sl=\"undefined\"==typeof TextDecoder?null:new TextDecoder(\"utf8\");function ll(t){return t.type===ol.Bytes?t.readVarint()+t.pos:t.pos+1}function cl(t,e,r){return r?4294967296*e+(t>>>0):4294967296*(e>>>0)+(t>>>0)}function ul(t,e,r){var n=e<=16383?1:e<=2097151?2:e<=268435455?3:Math.floor(Math.log(e)/(7*Math.LN2));r.realloc(n);for(var i=r.pos-1;i>=t;i--)r.buf[i+n]=r.buf[i]}function fl(t,e){for(var r=0;r<t.length;r++)e.writeVarint(t[r])}function hl(t,e){for(var r=0;r<t.length;r++)e.writeSVarint(t[r])}function pl(t,e){for(var r=0;r<t.length;r++)e.writeFloat(t[r])}function dl(t,e){for(var r=0;r<t.length;r++)e.writeDouble(t[r])}function ml(t,e){for(var r=0;r<t.length;r++)e.writeBoolean(t[r])}function gl(t,e){for(var r=0;r<t.length;r++)e.writeFixed32(t[r])}function vl(t,e){for(var r=0;r<t.length;r++)e.writeSFixed32(t[r])}function yl(t,e){for(var r=0;r<t.length;r++)e.writeFixed64(t[r])}function xl(t,e){for(var r=0;r<t.length;r++)e.writeSFixed64(t[r])}function bl(t,e){return(t[e]|t[e+1]<<8|t[e+2]<<16)+16777216*t[e+3]}function _l(t,e,r){t[r]=e,t[r+1]=e>>>8,t[r+2]=e>>>16,t[r+3]=e>>>24}function wl(t,e){return(t[e]|t[e+1]<<8|t[e+2]<<16)+(t[e+3]<<24)}ol.prototype={destroy:function(){this.buf=null},readFields:function(t,e,r){for(r=r||this.length;this.pos<r;){var n=this.readVarint(),i=n>>3,a=this.pos;this.type=7&n,t(i,e,this),this.pos===a&&this.skip(n)}return e},readMessage:function(t,e){return this.readFields(t,e,this.readVarint()+this.pos)},readFixed32:function(){var t=bl(this.buf,this.pos);return this.pos+=4,t},readSFixed32:function(){var t=wl(this.buf,this.pos);return this.pos+=4,t},readFixed64:function(){var t=bl(this.buf,this.pos)+4294967296*bl(this.buf,this.pos+4);return this.pos+=8,t},readSFixed64:function(){var t=bl(this.buf,this.pos)+4294967296*wl(this.buf,this.pos+4);return this.pos+=8,t},readFloat:function(){var t=nl(this.buf,this.pos,!0,23,4);return this.pos+=4,t},readDouble:function(){var t=nl(this.buf,this.pos,!0,52,8);return this.pos+=8,t},readVarint:function(t){var e,r,n=this.buf;return e=127&(r=n[this.pos++]),r<128?e:(e|=(127&(r=n[this.pos++]))<<7,r<128?e:(e|=(127&(r=n[this.pos++]))<<14,r<128?e:(e|=(127&(r=n[this.pos++]))<<21,r<128?e:function(t,e,r){var n,i,a=r.buf;if(i=a[r.pos++],n=(112&i)>>4,i<128)return cl(t,n,e);if(i=a[r.pos++],n|=(127&i)<<3,i<128)return cl(t,n,e);if(i=a[r.pos++],n|=(127&i)<<10,i<128)return cl(t,n,e);if(i=a[r.pos++],n|=(127&i)<<17,i<128)return cl(t,n,e);if(i=a[r.pos++],n|=(127&i)<<24,i<128)return cl(t,n,e);if(i=a[r.pos++],n|=(1&i)<<31,i<128)return cl(t,n,e);throw new Error(\"Expected varint not more than 10 bytes\")}(e|=(15&(r=n[this.pos]))<<28,t,this))))},readVarint64:function(){return this.readVarint(!0)},readSVarint:function(){var t=this.readVarint();return t%2==1?(t+1)/-2:t/2},readBoolean:function(){return Boolean(this.readVarint())},readString:function(){var t=this.readVarint()+this.pos,e=this.pos;return this.pos=t,t-e>=12&&sl?function(t,e,r){return sl.decode(t.subarray(e,r))}(this.buf,e,t):function(t,e,r){var n=\"\",i=e;for(;i<r;){var a,o,s,l=t[i],c=null,u=l>239?4:l>223?3:l>191?2:1;if(i+u>r)break;1===u?l<128&&(c=l):2===u?128==(192&(a=t[i+1]))&&(c=(31&l)<<6|63&a)<=127&&(c=null):3===u?(a=t[i+1],o=t[i+2],128==(192&a)&&128==(192&o)&&((c=(15&l)<<12|(63&a)<<6|63&o)<=2047||c>=55296&&c<=57343)&&(c=null)):4===u&&(a=t[i+1],o=t[i+2],s=t[i+3],128==(192&a)&&128==(192&o)&&128==(192&s)&&((c=(15&l)<<18|(63&a)<<12|(63&o)<<6|63&s)<=65535||c>=1114112)&&(c=null)),null===c?(c=65533,u=1):c>65535&&(c-=65536,n+=String.fromCharCode(c>>>10&1023|55296),c=56320|1023&c),n+=String.fromCharCode(c),i+=u}return n}(this.buf,e,t)},readBytes:function(){var t=this.readVarint()+this.pos,e=this.buf.subarray(this.pos,t);return this.pos=t,e},readPackedVarint:function(t,e){if(this.type!==ol.Bytes)return t.push(this.readVarint(e));var r=ll(this);for(t=t||[];this.pos<r;)t.push(this.readVarint(e));return t},readPackedSVarint:function(t){if(this.type!==ol.Bytes)return t.push(this.readSVarint());var e=ll(this);for(t=t||[];this.pos<e;)t.push(this.readSVarint());return t},readPackedBoolean:function(t){if(this.type!==ol.Bytes)return t.push(this.readBoolean());var e=ll(this);for(t=t||[];this.pos<e;)t.push(this.readBoolean());return t},readPackedFloat:function(t){if(this.type!==ol.Bytes)return t.push(this.readFloat());var e=ll(this);for(t=t||[];this.pos<e;)t.push(this.readFloat());return t},readPackedDouble:function(t){if(this.type!==ol.Bytes)return t.push(this.readDouble());var e=ll(this);for(t=t||[];this.pos<e;)t.push(this.readDouble());return t},readPackedFixed32:function(t){if(this.type!==ol.Bytes)return t.push(this.readFixed32());var e=ll(this);for(t=t||[];this.pos<e;)t.push(this.readFixed32());return t},readPackedSFixed32:function(t){if(this.type!==ol.Bytes)return t.push(this.readSFixed32());var e=ll(this);for(t=t||[];this.pos<e;)t.push(this.readSFixed32());return t},readPackedFixed64:function(t){if(this.type!==ol.Bytes)return t.push(this.readFixed64());var e=ll(this);for(t=t||[];this.pos<e;)t.push(this.readFixed64());return t},readPackedSFixed64:function(t){if(this.type!==ol.Bytes)return t.push(this.readSFixed64());var e=ll(this);for(t=t||[];this.pos<e;)t.push(this.readSFixed64());return t},skip:function(t){var e=7&t;if(e===ol.Varint)for(;this.buf[this.pos++]>127;);else if(e===ol.Bytes)this.pos=this.readVarint()+this.pos;else if(e===ol.Fixed32)this.pos+=4;else{if(e!==ol.Fixed64)throw new Error(\"Unimplemented type: \"+e);this.pos+=8}},writeTag:function(t,e){this.writeVarint(t<<3|e)},realloc:function(t){for(var e=this.length||16;e<this.pos+t;)e*=2;if(e!==this.length){var r=new Uint8Array(e);r.set(this.buf),this.buf=r,this.length=e}},finish:function(){return this.length=this.pos,this.pos=0,this.buf.subarray(0,this.length)},writeFixed32:function(t){this.realloc(4),_l(this.buf,t,this.pos),this.pos+=4},writeSFixed32:function(t){this.realloc(4),_l(this.buf,t,this.pos),this.pos+=4},writeFixed64:function(t){this.realloc(8),_l(this.buf,-1&t,this.pos),_l(this.buf,Math.floor(t*(1/4294967296)),this.pos+4),this.pos+=8},writeSFixed64:function(t){this.realloc(8),_l(this.buf,-1&t,this.pos),_l(this.buf,Math.floor(t*(1/4294967296)),this.pos+4),this.pos+=8},writeVarint:function(t){(t=+t||0)>268435455||t<0?function(t,e){var r,n;t>=0?(r=t%4294967296|0,n=t/4294967296|0):(n=~(-t/4294967296),4294967295^(r=~(-t%4294967296))?r=r+1|0:(r=0,n=n+1|0));if(t>=0x10000000000000000||t<-0x10000000000000000)throw new Error(\"Given varint doesn't fit into 10 bytes\");e.realloc(10),function(t,e,r){r.buf[r.pos++]=127&t|128,t>>>=7,r.buf[r.pos++]=127&t|128,t>>>=7,r.buf[r.pos++]=127&t|128,t>>>=7,r.buf[r.pos++]=127&t|128,t>>>=7,r.buf[r.pos]=127&t}(r,0,e),function(t,e){var r=(7&t)<<4;if(e.buf[e.pos++]|=r|((t>>>=3)?128:0),!t)return;if(e.buf[e.pos++]=127&t|((t>>>=7)?128:0),!t)return;if(e.buf[e.pos++]=127&t|((t>>>=7)?128:0),!t)return;if(e.buf[e.pos++]=127&t|((t>>>=7)?128:0),!t)return;if(e.buf[e.pos++]=127&t|((t>>>=7)?128:0),!t)return;e.buf[e.pos++]=127&t}(n,e)}(t,this):(this.realloc(4),this.buf[this.pos++]=127&t|(t>127?128:0),t<=127||(this.buf[this.pos++]=127&(t>>>=7)|(t>127?128:0),t<=127||(this.buf[this.pos++]=127&(t>>>=7)|(t>127?128:0),t<=127||(this.buf[this.pos++]=t>>>7&127))))},writeSVarint:function(t){this.writeVarint(t<0?2*-t-1:2*t)},writeBoolean:function(t){this.writeVarint(Boolean(t))},writeString:function(t){t=String(t),this.realloc(4*t.length),this.pos++;var e=this.pos;this.pos=function(t,e,r){for(var n,i,a=0;a<e.length;a++){if((n=e.charCodeAt(a))>55295&&n<57344){if(!i){n>56319||a+1===e.length?(t[r++]=239,t[r++]=191,t[r++]=189):i=n;continue}if(n<56320){t[r++]=239,t[r++]=191,t[r++]=189,i=n;continue}n=i-55296<<10|n-56320|65536,i=null}else i&&(t[r++]=239,t[r++]=191,t[r++]=189,i=null);n<128?t[r++]=n:(n<2048?t[r++]=n>>6|192:(n<65536?t[r++]=n>>12|224:(t[r++]=n>>18|240,t[r++]=n>>12&63|128),t[r++]=n>>6&63|128),t[r++]=63&n|128)}return r}(this.buf,t,this.pos);var r=this.pos-e;r>=128&&ul(e,r,this),this.pos=e-1,this.writeVarint(r),this.pos+=r},writeFloat:function(t){this.realloc(4),il(this.buf,t,this.pos,!0,23,4),this.pos+=4},writeDouble:function(t){this.realloc(8),il(this.buf,t,this.pos,!0,52,8),this.pos+=8},writeBytes:function(t){var e=t.length;this.writeVarint(e),this.realloc(e);for(var r=0;r<e;r++)this.buf[this.pos++]=t[r]},writeRawMessage:function(t,e){this.pos++;var r=this.pos;t(e,this);var n=this.pos-r;n>=128&&ul(r,n,this),this.pos=r-1,this.writeVarint(n),this.pos+=n},writeMessage:function(t,e,r){this.writeTag(t,ol.Bytes),this.writeRawMessage(e,r)},writePackedVarint:function(t,e){e.length&&this.writeMessage(t,fl,e)},writePackedSVarint:function(t,e){e.length&&this.writeMessage(t,hl,e)},writePackedBoolean:function(t,e){e.length&&this.writeMessage(t,ml,e)},writePackedFloat:function(t,e){e.length&&this.writeMessage(t,pl,e)},writePackedDouble:function(t,e){e.length&&this.writeMessage(t,dl,e)},writePackedFixed32:function(t,e){e.length&&this.writeMessage(t,gl,e)},writePackedSFixed32:function(t,e){e.length&&this.writeMessage(t,vl,e)},writePackedFixed64:function(t,e){e.length&&this.writeMessage(t,yl,e)},writePackedSFixed64:function(t,e){e.length&&this.writeMessage(t,xl,e)},writeBytesField:function(t,e){this.writeTag(t,ol.Bytes),this.writeBytes(e)},writeFixed32Field:function(t,e){this.writeTag(t,ol.Fixed32),this.writeFixed32(e)},writeSFixed32Field:function(t,e){this.writeTag(t,ol.Fixed32),this.writeSFixed32(e)},writeFixed64Field:function(t,e){this.writeTag(t,ol.Fixed64),this.writeFixed64(e)},writeSFixed64Field:function(t,e){this.writeTag(t,ol.Fixed64),this.writeSFixed64(e)},writeVarintField:function(t,e){this.writeTag(t,ol.Varint),this.writeVarint(e)},writeSVarintField:function(t,e){this.writeTag(t,ol.Varint),this.writeSVarint(e)},writeStringField:function(t,e){this.writeTag(t,ol.Bytes),this.writeString(e)},writeFloatField:function(t,e){this.writeTag(t,ol.Fixed32),this.writeFloat(e)},writeDoubleField:function(t,e){this.writeTag(t,ol.Fixed64),this.writeDouble(e)},writeBooleanField:function(t,e){this.writeVarintField(t,Boolean(e))}};function Tl(t,e,r){1===t&&r.readMessage(kl,e)}function kl(t,e,r){if(3===t){var n=r.readMessage(Ml,{}),i=n.id,a=n.bitmap,o=n.width,s=n.height,l=n.left,c=n.top,u=n.advance;e.push({id:i,bitmap:new So({width:o+6,height:s+6},a),metrics:{width:o,height:s,left:l,top:c,advance:u}})}}function Ml(t,e,r){1===t?e.id=r.readVarint():2===t?e.bitmap=r.readBytes():3===t?e.width=r.readVarint():4===t?e.height=r.readVarint():5===t?e.left=r.readSVarint():6===t?e.top=r.readSVarint():7===t&&(e.advance=r.readVarint())}function Al(t){for(var e=0,r=0,n=0,i=t;n<i.length;n+=1){var a=i[n];e+=a.w*a.h,r=Math.max(r,a.w)}t.sort((function(t,e){return e.h-t.h}));for(var o=[{x:0,y:0,w:Math.max(Math.ceil(Math.sqrt(e/.95)),r),h:1/0}],s=0,l=0,c=0,u=t;c<u.length;c+=1)for(var f=u[c],h=o.length-1;h>=0;h--){var p=o[h];if(!(f.w>p.w||f.h>p.h)){if(f.x=p.x,f.y=p.y,l=Math.max(l,f.y+f.h),s=Math.max(s,f.x+f.w),f.w===p.w&&f.h===p.h){var d=o.pop();h<o.length&&(o[h]=d)}else f.h===p.h?(p.x+=f.w,p.w-=f.w):f.w===p.w?(p.y+=f.h,p.h-=f.h):(o.push({x:p.x+f.w,y:p.y,w:p.w-f.w,h:f.h}),p.y+=f.h,p.h-=f.h);break}}return{w:s,h:l,fill:e/(s*l)||0}}var Sl=function(t,e){var r=e.pixelRatio,n=e.version,i=e.stretchX,a=e.stretchY,o=e.content;this.paddedRect=t,this.pixelRatio=r,this.stretchX=i,this.stretchY=a,this.content=o,this.version=n},El={tl:{configurable:!0},br:{configurable:!0},tlbr:{configurable:!0},displaySize:{configurable:!0}};El.tl.get=function(){return[this.paddedRect.x+1,this.paddedRect.y+1]},El.br.get=function(){return[this.paddedRect.x+this.paddedRect.w-1,this.paddedRect.y+this.paddedRect.h-1]},El.tlbr.get=function(){return this.tl.concat(this.br)},El.displaySize.get=function(){return[(this.paddedRect.w-2)/this.pixelRatio,(this.paddedRect.h-2)/this.pixelRatio]},Object.defineProperties(Sl.prototype,El);var Ll=function(t,e){var r={},n={};this.haveRenderCallbacks=[];var i=[];this.addImages(t,r,i),this.addImages(e,n,i);var a=Al(i),o=a.w,s=a.h,l=new Eo({width:o||1,height:s||1});for(var c in t){var u=t[c],f=r[c].paddedRect;Eo.copy(u.data,l,{x:0,y:0},{x:f.x+1,y:f.y+1},u.data)}for(var h in e){var p=e[h],d=n[h].paddedRect,m=d.x+1,g=d.y+1,v=p.data.width,y=p.data.height;Eo.copy(p.data,l,{x:0,y:0},{x:m,y:g},p.data),Eo.copy(p.data,l,{x:0,y:y-1},{x:m,y:g-1},{width:v,height:1}),Eo.copy(p.data,l,{x:0,y:0},{x:m,y:g+y},{width:v,height:1}),Eo.copy(p.data,l,{x:v-1,y:0},{x:m-1,y:g},{width:1,height:y}),Eo.copy(p.data,l,{x:0,y:0},{x:m+v,y:g},{width:1,height:y})}this.image=l,this.iconPositions=r,this.patternPositions=n};Ll.prototype.addImages=function(t,e,r){for(var n in t){var i=t[n],a={x:0,y:0,w:i.data.width+2,h:i.data.height+2};r.push(a),e[n]=new Sl(a,i),i.hasRenderCallback&&this.haveRenderCallbacks.push(n)}},Ll.prototype.patchUpdatedImages=function(t,e){for(var r in t.dispatchRenderCallbacks(this.haveRenderCallbacks),t.updatedImages)this.patchUpdatedImage(this.iconPositions[r],t.getImage(r),e),this.patchUpdatedImage(this.patternPositions[r],t.getImage(r),e)},Ll.prototype.patchUpdatedImage=function(t,e,r){if(t&&e&&t.version!==e.version){t.version=e.version;var n=t.tl,i=n[0],a=n[1];r.update(e.data,void 0,{x:i,y:a})}},Nn(\"ImagePosition\",Sl),Nn(\"ImageAtlas\",Ll);var Cl={horizontal:1,vertical:2,horizontalOnly:3};var Pl=function(){this.scale=1,this.fontStack=\"\",this.imageName=null};Pl.forText=function(t,e){var r=new Pl;return r.scale=t||1,r.fontStack=e,r},Pl.forImage=function(t){var e=new Pl;return e.imageName=t,e};var Il=function(){this.text=\"\",this.sectionIndex=[],this.sections=[],this.imageSectionID=null};function Ol(t,e,r,n,i,a,o,s,l,c,u,f,h,p,d,m){var g,v=Il.fromFeature(t,i);f===Cl.vertical&&v.verticalizePunctuation();var y=hi.processBidirectionalText,x=hi.processStyledBidirectionalText;if(y&&1===v.sections.length){g=[];for(var b=0,_=y(v.toString(),jl(v,c,a,e,n,p,d));b<_.length;b+=1){var w=_[b],T=new Il;T.text=w,T.sections=v.sections;for(var k=0;k<w.length;k++)T.sectionIndex.push(0);g.push(T)}}else if(x){g=[];for(var M=0,A=x(v.text,v.sectionIndex,jl(v,c,a,e,n,p,d));M<A.length;M+=1){var S=A[M],E=new Il;E.text=S[0],E.sectionIndex=S[1],E.sections=v.sections,g.push(E)}}else g=function(t,e){for(var r=[],n=t.text,i=0,a=0,o=e;a<o.length;a+=1){var s=o[a];r.push(t.substring(i,s)),i=s}return i<n.length&&r.push(t.substring(i,n.length)),r}(v,jl(v,c,a,e,n,p,d));var L=[],C={positionedLines:L,text:v.toString(),top:u[1],bottom:u[1],left:u[0],right:u[0],writingMode:f,iconsInText:!1,verticalizable:!1};return function(t,e,r,n,i,a,o,s,l,c,u,f){for(var h=0,p=-17,d=0,m=0,g=\"right\"===s?1:\"left\"===s?0:.5,v=0,y=0,x=i;y<x.length;y+=1){var b=x[y];b.trim();var _=b.getMaxScale(),w=24*(_-1),T={positionedGlyphs:[],lineOffset:0};t.positionedLines[v]=T;var k=T.positionedGlyphs,M=0;if(b.length()){for(var A=0;A<b.length();A++){var S=b.getSection(A),E=b.getSectionIndex(A),L=b.getCharCode(A),C=0,P=null,I=null,O=null,z=24,D=!(l===Cl.horizontal||!u&&!Zn(L)||u&&(zl[L]||(Y=L,Yn.Arabic(Y)||Yn[\"Arabic Supplement\"](Y)||Yn[\"Arabic Extended-A\"](Y)||Yn[\"Arabic Presentation Forms-A\"](Y)||Yn[\"Arabic Presentation Forms-B\"](Y))));if(S.imageName){var R=n[S.imageName];if(!R)continue;O=S.imageName,t.iconsInText=t.iconsInText||!0,I=R.paddedRect;var F=R.displaySize;S.scale=24*S.scale/f,P={width:F[0],height:F[1],left:1,top:-3,advance:D?F[1]:F[0]};var B=24-F[1]*S.scale;C=w+B,z=P.advance;var N=D?F[0]*S.scale-24*_:F[1]*S.scale-24*_;N>0&&N>M&&(M=N)}else{var j=r[S.fontStack],U=j&&j[L];if(U&&U.rect)I=U.rect,P=U.metrics;else{var V=e[S.fontStack],q=V&&V[L];if(!q)continue;P=q.metrics}C=24*(_-S.scale)}D?(t.verticalizable=!0,k.push({glyph:L,imageName:O,x:h,y:p+C,vertical:D,scale:S.scale,fontStack:S.fontStack,sectionIndex:E,metrics:P,rect:I}),h+=z*S.scale+c):(k.push({glyph:L,imageName:O,x:h,y:p+C,vertical:D,scale:S.scale,fontStack:S.fontStack,sectionIndex:E,metrics:P,rect:I}),h+=P.advance*S.scale+c)}if(0!==k.length){var H=h-c;d=Math.max(H,d),Vl(k,0,k.length-1,g,M)}h=0;var G=a*_+M;T.lineOffset=Math.max(M,w),p+=G,m=Math.max(G,m),++v}else p+=a,++v}var Y;var W=p- -17,X=Ul(o),Z=X.horizontalAlign,J=X.verticalAlign;(function(t,e,r,n,i,a,o,s,l){var c=(e-r)*i,u=0;u=a!==o?-s*n- -17:(-n*l+.5)*o;for(var f=0,h=t;f<h.length;f+=1)for(var p=h[f],d=0,m=p.positionedGlyphs;d<m.length;d+=1){var g=m[d];g.x+=c,g.y+=u}})(t.positionedLines,g,Z,J,d,m,a,W,i.length),t.top+=-J*W,t.bottom=t.top+W,t.left+=-Z*d,t.right=t.left+d}(C,e,r,n,g,o,s,l,f,c,h,m),!function(t){for(var e=0,r=t;e<r.length;e+=1){if(0!==r[e].positionedGlyphs.length)return!1}return!0}(L)&&C}Il.fromFeature=function(t,e){for(var r=new Il,n=0;n<t.sections.length;n++){var i=t.sections[n];i.image?r.addImageSection(i):r.addTextSection(i,e)}return r},Il.prototype.length=function(){return this.text.length},Il.prototype.getSection=function(t){return this.sections[this.sectionIndex[t]]},Il.prototype.getSectionIndex=function(t){return this.sectionIndex[t]},Il.prototype.getCharCode=function(t){return this.text.charCodeAt(t)},Il.prototype.verticalizePunctuation=function(){this.text=function(t){for(var e=\"\",r=0;r<t.length;r++){var n=t.charCodeAt(r+1)||null,i=t.charCodeAt(r-1)||null;(!n||!Jn(n)||rl[t[r+1]])&&(!i||!Jn(i)||rl[t[r-1]])&&rl[t[r]]?e+=rl[t[r]]:e+=t[r]}return e}(this.text)},Il.prototype.trim=function(){for(var t=0,e=0;e<this.text.length&&zl[this.text.charCodeAt(e)];e++)t++;for(var r=this.text.length,n=this.text.length-1;n>=0&&n>=t&&zl[this.text.charCodeAt(n)];n--)r--;this.text=this.text.substring(t,r),this.sectionIndex=this.sectionIndex.slice(t,r)},Il.prototype.substring=function(t,e){var r=new Il;return r.text=this.text.substring(t,e),r.sectionIndex=this.sectionIndex.slice(t,e),r.sections=this.sections,r},Il.prototype.toString=function(){return this.text},Il.prototype.getMaxScale=function(){var t=this;return this.sectionIndex.reduce((function(e,r){return Math.max(e,t.sections[r].scale)}),0)},Il.prototype.addTextSection=function(t,e){this.text+=t.text,this.sections.push(Pl.forText(t.scale,t.fontStack||e));for(var r=this.sections.length-1,n=0;n<t.text.length;++n)this.sectionIndex.push(r)},Il.prototype.addImageSection=function(t){var e=t.image?t.image.name:\"\";if(0!==e.length){var r=this.getNextImageSectionCharCode();r?(this.text+=String.fromCharCode(r),this.sections.push(Pl.forImage(e)),this.sectionIndex.push(this.sections.length-1)):_(\"Reached maximum number of images 6401\")}else _(\"Can't add FormattedSection with an empty image.\")},Il.prototype.getNextImageSectionCharCode=function(){return this.imageSectionID?this.imageSectionID>=63743?null:++this.imageSectionID:(this.imageSectionID=57344,this.imageSectionID)};var zl={9:!0,10:!0,11:!0,12:!0,13:!0,32:!0},Dl={};function Rl(t,e,r,n,i,a){if(e.imageName){var o=n[e.imageName];return o?o.displaySize[0]*e.scale*24/a+i:0}var s=r[e.fontStack],l=s&&s[t];return l?l.metrics.advance*e.scale+i:0}function Fl(t,e,r,n){var i=Math.pow(t-e,2);return n?t<e?i/2:2*i:i+Math.abs(r)*r}function Bl(t,e,r){var n=0;return 10===t&&(n-=1e4),r&&(n+=150),40!==t&&65288!==t||(n+=50),41!==e&&65289!==e||(n+=50),n}function Nl(t,e,r,n,i,a){for(var o=null,s=Fl(e,r,i,a),l=0,c=n;l<c.length;l+=1){var u=c[l],f=Fl(e-u.x,r,i,a)+u.badness;f<=s&&(o=u,s=f)}return{index:t,x:e,priorBreak:o,badness:s}}function jl(t,e,r,n,i,a,o){if(\"point\"!==a)return[];if(!t)return[];for(var s,l=[],c=function(t,e,r,n,i,a){for(var o=0,s=0;s<t.length();s++){var l=t.getSection(s);o+=Rl(t.getCharCode(s),l,n,i,e,a)}return o/Math.max(1,Math.ceil(o/r))}(t,e,r,n,i,o),u=t.text.indexOf(\"\\u200b\")>=0,f=0,h=0;h<t.length();h++){var p=t.getSection(h),d=t.getCharCode(h);if(zl[d]||(f+=Rl(d,p,n,i,e,o)),h<t.length()-1){var m=!!(!((s=d)<11904)&&(Yn[\"Bopomofo Extended\"](s)||Yn.Bopomofo(s)||Yn[\"CJK Compatibility Forms\"](s)||Yn[\"CJK Compatibility Ideographs\"](s)||Yn[\"CJK Compatibility\"](s)||Yn[\"CJK Radicals Supplement\"](s)||Yn[\"CJK Strokes\"](s)||Yn[\"CJK Symbols and Punctuation\"](s)||Yn[\"CJK Unified Ideographs Extension A\"](s)||Yn[\"CJK Unified Ideographs\"](s)||Yn[\"Enclosed CJK Letters and Months\"](s)||Yn[\"Halfwidth and Fullwidth Forms\"](s)||Yn.Hiragana(s)||Yn[\"Ideographic Description Characters\"](s)||Yn[\"Kangxi Radicals\"](s)||Yn[\"Katakana Phonetic Extensions\"](s)||Yn.Katakana(s)||Yn[\"Vertical Forms\"](s)||Yn[\"Yi Radicals\"](s)||Yn[\"Yi Syllables\"](s)));(Dl[d]||m||p.imageName)&&l.push(Nl(h+1,f,c,l,Bl(d,t.getCharCode(h+1),m&&u),!1))}}return function t(e){return e?t(e.priorBreak).concat(e.index):[]}(Nl(t.length(),f,c,l,0,!0))}function Ul(t){var e=.5,r=.5;switch(t){case\"right\":case\"top-right\":case\"bottom-right\":e=1;break;case\"left\":case\"top-left\":case\"bottom-left\":e=0}switch(t){case\"bottom\":case\"bottom-right\":case\"bottom-left\":r=1;break;case\"top\":case\"top-right\":case\"top-left\":r=0}return{horizontalAlign:e,verticalAlign:r}}function Vl(t,e,r,n,i){if(n||i)for(var a=t[r],o=a.metrics.advance*a.scale,s=(t[r].x+o)*n,l=e;l<=r;l++)t[l].x-=s,t[l].y+=i}function ql(t,e,r,n,i,a){var o,s=t.image;if(s.content){var l=s.content,c=s.pixelRatio||1;o=[l[0]/c,l[1]/c,s.displaySize[0]-l[2]/c,s.displaySize[1]-l[3]/c]}var u,f,h,p,d=e.left*a,m=e.right*a;\"width\"===r||\"both\"===r?(p=i[0]+d-n[3],f=i[0]+m+n[1]):f=(p=i[0]+(d+m-s.displaySize[0])/2)+s.displaySize[0];var g=e.top*a,v=e.bottom*a;return\"height\"===r||\"both\"===r?(u=i[1]+g-n[0],h=i[1]+v+n[2]):h=(u=i[1]+(g+v-s.displaySize[1])/2)+s.displaySize[1],{image:s,top:u,right:f,bottom:h,left:p,collisionPadding:o}}Dl[10]=!0,Dl[32]=!0,Dl[38]=!0,Dl[40]=!0,Dl[41]=!0,Dl[43]=!0,Dl[45]=!0,Dl[47]=!0,Dl[173]=!0,Dl[183]=!0,Dl[8203]=!0,Dl[8208]=!0,Dl[8211]=!0,Dl[8231]=!0;var Hl=function(t){function e(e,r,n,i){t.call(this,e,r),this.angle=n,void 0!==i&&(this.segment=i)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.clone=function(){return new e(this.x,this.y,this.angle,this.segment)},e}(i);Nn(\"Anchor\",Hl);function Gl(t,e){var r=e.expression;if(\"constant\"===r.kind)return{kind:\"constant\",layoutSize:r.evaluate(new pi(t+1))};if(\"source\"===r.kind)return{kind:\"source\"};for(var n=r.zoomStops,i=r.interpolationType,a=0;a<n.length&&n[a]<=t;)a++;for(var o=a=Math.max(0,a-1);o<n.length&&n[o]<t+1;)o++;o=Math.min(n.length-1,o);var s=n[a],l=n[o];return\"composite\"===r.kind?{kind:\"composite\",minZoom:s,maxZoom:l,interpolationType:i}:{kind:\"camera\",minZoom:s,maxZoom:l,minSize:r.evaluate(new pi(s)),maxSize:r.evaluate(new pi(l)),interpolationType:i}}function Yl(t,e,r){var n=e.uSize,i=e.uSizeT,a=r.lowerSize,o=r.upperSize;return\"source\"===t.kind?a/128:\"composite\"===t.kind?He(a/128,o/128,i):n}function Wl(t,e){var r=0,n=0;if(\"constant\"===t.kind)n=t.layoutSize;else if(\"source\"!==t.kind){var i=t.interpolationType,a=t.minZoom,o=t.maxZoom,s=i?l(or.interpolationFactor(i,e,a,o),0,1):0;\"camera\"===t.kind?n=He(t.minSize,t.maxSize,s):r=s}return{uSizeT:r,uSize:n}}var Xl=Object.freeze({__proto__:null,getSizeData:Gl,evaluateSizeForFeature:Yl,evaluateSizeForZoom:Wl,SIZE_PACK_FACTOR:128});function Zl(t,e,r,n,i){if(void 0===e.segment)return!0;for(var a=e,o=e.segment+1,s=0;s>-r/2;){if(--o<0)return!1;s-=t[o].dist(a),a=t[o]}s+=t[o].dist(t[o+1]),o++;for(var l=[],c=0;s<r/2;){var u=t[o-1],f=t[o],h=t[o+1];if(!h)return!1;var p=u.angleTo(f)-f.angleTo(h);for(p=Math.abs((p+3*Math.PI)%(2*Math.PI)-Math.PI),l.push({distance:s,angleDelta:p}),c+=p;s-l[0].distance>n;)c-=l.shift().angleDelta;if(c>i)return!1;o++,s+=f.dist(h)}return!0}function Jl(t){for(var e=0,r=0;r<t.length-1;r++)e+=t[r].dist(t[r+1]);return e}function Kl(t,e,r){return t?.6*e*r:0}function Ql(t,e){return Math.max(t?t.right-t.left:0,e?e.right-e.left:0)}function $l(t,e,r,n,i,a){for(var o=Kl(r,i,a),s=Ql(r,n)*a,l=0,c=Jl(t)/2,u=0;u<t.length-1;u++){var f=t[u],h=t[u+1],p=f.dist(h);if(l+p>c){var d=(c-l)/p,m=He(f.x,h.x,d),g=He(f.y,h.y,d),v=new Hl(m,g,h.angleTo(f),u);return v._round(),!o||Zl(t,v,s,o,e)?v:void 0}l+=p}}function tc(t,e,r,n,i,a,o,s,l){var c=Kl(n,a,o),u=Ql(n,i),f=u*o,h=0===t[0].x||t[0].x===l||0===t[0].y||t[0].y===l;return e-f<e/4&&(e=f+e/4),function t(e,r,n,i,a,o,s,l,c){for(var u=o/2,f=Jl(e),h=0,p=r-n,d=[],m=0;m<e.length-1;m++){for(var g=e[m],v=e[m+1],y=g.dist(v),x=v.angleTo(g);p+n<h+y;){var b=((p+=n)-h)/y,_=He(g.x,v.x,b),w=He(g.y,v.y,b);if(_>=0&&_<c&&w>=0&&w<c&&p-u>=0&&p+u<=f){var T=new Hl(_,w,x,m);T._round(),i&&!Zl(e,T,o,i,a)||d.push(T)}}h+=y}l||d.length||s||(d=t(e,h/2,n,i,a,o,s,!0,c));return d}(t,h?e/2*s%e:(u/2+2*a)*o*s%e,e,c,r,f,h,!1,l)}function ec(t,e,r,n,a){for(var o=[],s=0;s<t.length;s++)for(var l=t[s],c=void 0,u=0;u<l.length-1;u++){var f=l[u],h=l[u+1];f.x<e&&h.x<e||(f.x<e?f=new i(e,f.y+(h.y-f.y)*((e-f.x)/(h.x-f.x)))._round():h.x<e&&(h=new i(e,f.y+(h.y-f.y)*((e-f.x)/(h.x-f.x)))._round()),f.y<r&&h.y<r||(f.y<r?f=new i(f.x+(h.x-f.x)*((r-f.y)/(h.y-f.y)),r)._round():h.y<r&&(h=new i(f.x+(h.x-f.x)*((r-f.y)/(h.y-f.y)),r)._round()),f.x>=n&&h.x>=n||(f.x>=n?f=new i(n,f.y+(h.y-f.y)*((n-f.x)/(h.x-f.x)))._round():h.x>=n&&(h=new i(n,f.y+(h.y-f.y)*((n-f.x)/(h.x-f.x)))._round()),f.y>=a&&h.y>=a||(f.y>=a?f=new i(f.x+(h.x-f.x)*((a-f.y)/(h.y-f.y)),a)._round():h.y>=a&&(h=new i(f.x+(h.x-f.x)*((a-f.y)/(h.y-f.y)),a)._round()),c&&f.equals(c[c.length-1])||(c=[f],o.push(c)),c.push(h)))))}return o}function rc(t,e,r,n){var a=[],o=t.image,s=o.pixelRatio,l=o.paddedRect.w-2,c=o.paddedRect.h-2,u=t.right-t.left,f=t.bottom-t.top,h=o.stretchX||[[0,l]],p=o.stretchY||[[0,c]],d=function(t,e){return t+e[1]-e[0]},m=h.reduce(d,0),g=p.reduce(d,0),v=l-m,y=c-g,x=0,b=m,_=0,w=g,T=0,k=v,M=0,A=y;if(o.content&&n){var S=o.content;x=nc(h,0,S[0]),_=nc(p,0,S[1]),b=nc(h,S[0],S[2]),w=nc(p,S[1],S[3]),T=S[0]-x,M=S[1]-_,k=S[2]-S[0]-b,A=S[3]-S[1]-w}var E=function(n,a,l,c){var h=ac(n.stretch-x,b,u,t.left),p=oc(n.fixed-T,k,n.stretch,m),d=ac(a.stretch-_,w,f,t.top),v=oc(a.fixed-M,A,a.stretch,g),y=ac(l.stretch-x,b,u,t.left),S=oc(l.fixed-T,k,l.stretch,m),E=ac(c.stretch-_,w,f,t.top),L=oc(c.fixed-M,A,c.stretch,g),C=new i(h,d),P=new i(y,d),I=new i(y,E),O=new i(h,E),z=new i(p/s,v/s),D=new i(S/s,L/s),R=e*Math.PI/180;if(R){var F=Math.sin(R),B=Math.cos(R),N=[B,-F,F,B];C._matMult(N),P._matMult(N),O._matMult(N),I._matMult(N)}var j=n.stretch+n.fixed,U=l.stretch+l.fixed,V=a.stretch+a.fixed,q=c.stretch+c.fixed;return{tl:C,tr:P,bl:O,br:I,tex:{x:o.paddedRect.x+1+j,y:o.paddedRect.y+1+V,w:U-j,h:q-V},writingMode:void 0,glyphOffset:[0,0],sectionIndex:0,pixelOffsetTL:z,pixelOffsetBR:D,minFontScaleX:k/s/u,minFontScaleY:A/s/f,isSDF:r}};if(n&&(o.stretchX||o.stretchY))for(var L=ic(h,v,m),C=ic(p,y,g),P=0;P<L.length-1;P++)for(var I=L[P],O=L[P+1],z=0;z<C.length-1;z++){var D=C[z],R=C[z+1];a.push(E(I,D,O,R))}else a.push(E({fixed:0,stretch:-1},{fixed:0,stretch:-1},{fixed:0,stretch:l+1},{fixed:0,stretch:c+1}));return a}function nc(t,e,r){for(var n=0,i=0,a=t;i<a.length;i+=1){var o=a[i];n+=Math.max(e,Math.min(r,o[1]))-Math.max(e,Math.min(r,o[0]))}return n}function ic(t,e,r){for(var n=[{fixed:-1,stretch:0}],i=0,a=t;i<a.length;i+=1){var o=a[i],s=o[0],l=o[1],c=n[n.length-1];n.push({fixed:s-c.stretch,stretch:c.stretch}),n.push({fixed:s-c.stretch,stretch:c.stretch+(l-s)})}return n.push({fixed:e+1,stretch:r}),n}function ac(t,e,r,n){return t/e*r+n}function oc(t,e,r,n){return t-e*r/n}var sc=function(t,e,r,n,a,o,s,l,c,u){if(this.boxStartIndex=t.length,c){var f=o.top,h=o.bottom,p=o.collisionPadding;p&&(f-=p[1],h+=p[3]);var d=h-f;d>0&&(d=Math.max(10,d),this.circleDiameter=d)}else{var m=o.top*s-l,g=o.bottom*s+l,v=o.left*s-l,y=o.right*s+l,x=o.collisionPadding;if(x&&(v-=x[0]*s,m-=x[1]*s,y+=x[2]*s,g+=x[3]*s),u){var b=new i(v,m),_=new i(y,m),w=new i(v,g),T=new i(y,g),k=u*Math.PI/180;b._rotate(k),_._rotate(k),w._rotate(k),T._rotate(k),v=Math.min(b.x,_.x,w.x,T.x),y=Math.max(b.x,_.x,w.x,T.x),m=Math.min(b.y,_.y,w.y,T.y),g=Math.max(b.y,_.y,w.y,T.y)}t.emplaceBack(e.x,e.y,v,m,y,g,r,n,a)}this.boxEndIndex=t.length},lc=function(t,e){if(void 0===t&&(t=[]),void 0===e&&(e=cc),this.data=t,this.length=this.data.length,this.compare=e,this.length>0)for(var r=(this.length>>1)-1;r>=0;r--)this._down(r)};function cc(t,e){return t<e?-1:t>e?1:0}function uc(t,e,r){void 0===e&&(e=1),void 0===r&&(r=!1);for(var n=1/0,a=1/0,o=-1/0,s=-1/0,l=t[0],c=0;c<l.length;c++){var u=l[c];(!c||u.x<n)&&(n=u.x),(!c||u.y<a)&&(a=u.y),(!c||u.x>o)&&(o=u.x),(!c||u.y>s)&&(s=u.y)}var f=o-n,h=s-a,p=Math.min(f,h),d=p/2,m=new lc([],fc);if(0===p)return new i(n,a);for(var g=n;g<o;g+=p)for(var v=a;v<s;v+=p)m.push(new hc(g+d,v+d,d,t));for(var y=function(t){for(var e=0,r=0,n=0,i=t[0],a=0,o=i.length,s=o-1;a<o;s=a++){var l=i[a],c=i[s],u=l.x*c.y-c.x*l.y;r+=(l.x+c.x)*u,n+=(l.y+c.y)*u,e+=3*u}return new hc(r/e,n/e,0,t)}(t),x=m.length;m.length;){var b=m.pop();(b.d>y.d||!y.d)&&(y=b,r&&console.log(\"found best %d after %d probes\",Math.round(1e4*b.d)/1e4,x)),b.max-y.d<=e||(d=b.h/2,m.push(new hc(b.p.x-d,b.p.y-d,d,t)),m.push(new hc(b.p.x+d,b.p.y-d,d,t)),m.push(new hc(b.p.x-d,b.p.y+d,d,t)),m.push(new hc(b.p.x+d,b.p.y+d,d,t)),x+=4)}return r&&(console.log(\"num probes: \"+x),console.log(\"best distance: \"+y.d)),y.p}function fc(t,e){return e.max-t.max}function hc(t,e,r,n){this.p=new i(t,e),this.h=r,this.d=function(t,e){for(var r=!1,n=1/0,i=0;i<e.length;i++)for(var a=e[i],o=0,s=a.length,l=s-1;o<s;l=o++){var c=a[o],u=a[l];c.y>t.y!=u.y>t.y&&t.x<(u.x-c.x)*(t.y-c.y)/(u.y-c.y)+c.x&&(r=!r),n=Math.min(n,ro(t,c,u))}return(r?1:-1)*Math.sqrt(n)}(this.p,n),this.max=this.d+this.h*Math.SQRT2}lc.prototype.push=function(t){this.data.push(t),this.length++,this._up(this.length-1)},lc.prototype.pop=function(){if(0!==this.length){var t=this.data[0],e=this.data.pop();return this.length--,this.length>0&&(this.data[0]=e,this._down(0)),t}},lc.prototype.peek=function(){return this.data[0]},lc.prototype._up=function(t){for(var e=this.data,r=this.compare,n=e[t];t>0;){var i=t-1>>1,a=e[i];if(r(n,a)>=0)break;e[t]=a,t=i}e[t]=n},lc.prototype._down=function(t){for(var e=this.data,r=this.compare,n=this.length>>1,i=e[t];t<n;){var a=1+(t<<1),o=e[a],s=a+1;if(s<this.length&&r(e[s],o)<0&&(a=s,o=e[s]),r(o,i)>=0)break;e[t]=o,t=a}e[t]=i};var pc=Number.POSITIVE_INFINITY;function dc(t,e){return e[1]!==pc?function(t,e,r){var n=0,i=0;switch(e=Math.abs(e),r=Math.abs(r),t){case\"top-right\":case\"top-left\":case\"top\":i=r-7;break;case\"bottom-right\":case\"bottom-left\":case\"bottom\":i=7-r}switch(t){case\"top-right\":case\"bottom-right\":case\"right\":n=-e;break;case\"top-left\":case\"bottom-left\":case\"left\":n=e}return[n,i]}(t,e[0],e[1]):function(t,e){var r=0,n=0;e<0&&(e=0);var i=e/Math.sqrt(2);switch(t){case\"top-right\":case\"top-left\":n=i-7;break;case\"bottom-right\":case\"bottom-left\":n=7-i;break;case\"bottom\":n=7-e;break;case\"top\":n=e-7}switch(t){case\"top-right\":case\"bottom-right\":r=-i;break;case\"top-left\":case\"bottom-left\":r=i;break;case\"left\":r=e;break;case\"right\":r=-e}return[r,n]}(t,e[0])}function mc(t){switch(t){case\"right\":case\"top-right\":case\"bottom-right\":return\"right\";case\"left\":case\"top-left\":case\"bottom-left\":return\"left\"}return\"center\"}function gc(t,e,r,n,a,o,s,l,c,u,f,h,p,d,m){var g=function(t,e,r,n,a,o,s,l){for(var c=n.layout.get(\"text-rotate\").evaluate(o,{})*Math.PI/180,u=[],f=0,h=e.positionedLines;f<h.length;f+=1)for(var p=h[f],d=0,m=p.positionedGlyphs;d<m.length;d+=1){var g=m[d];if(g.rect){var v=g.rect||{},y=4,x=!0,b=1,_=0,w=(a||l)&&g.vertical,T=g.metrics.advance*g.scale/2;if(l&&e.verticalizable){var k=24*(g.scale-1),M=(24-g.metrics.width*g.scale)/2;_=p.lineOffset/2-(g.imageName?-M:k)}if(g.imageName){var A=s[g.imageName];x=A.sdf,y=1/(b=A.pixelRatio)}var S=a?[g.x+T,g.y]:[0,0],E=a?[0,0]:[g.x+T+r[0],g.y+r[1]-_],L=[0,0];w&&(L=E,E=[0,0]);var C=(g.metrics.left-y)*g.scale-T+E[0],P=(-g.metrics.top-y)*g.scale+E[1],I=C+v.w*g.scale/b,O=P+v.h*g.scale/b,z=new i(C,P),D=new i(I,P),R=new i(C,O),F=new i(I,O);if(w){var B=new i(-T,T- -17),N=-Math.PI/2,j=12-T,U=g.imageName?j:0,V=new i(22-j,-U),q=new(Function.prototype.bind.apply(i,[null].concat(L)));z._rotateAround(N,B)._add(V)._add(q),D._rotateAround(N,B)._add(V)._add(q),R._rotateAround(N,B)._add(V)._add(q),F._rotateAround(N,B)._add(V)._add(q)}if(c){var H=Math.sin(c),G=Math.cos(c),Y=[G,-H,H,G];z._matMult(Y),D._matMult(Y),R._matMult(Y),F._matMult(Y)}var W=new i(0,0),X=new i(0,0);u.push({tl:z,tr:D,bl:R,br:F,tex:v,writingMode:e.writingMode,glyphOffset:S,sectionIndex:g.sectionIndex,isSDF:x,pixelOffsetTL:W,pixelOffsetBR:X,minFontScaleX:0,minFontScaleY:0})}}return u}(0,r,l,a,o,s,n,t.allowVerticalPlacement),v=t.textSizeData,y=null;\"source\"===v.kind?(y=[128*a.layout.get(\"text-size\").evaluate(s,{})])[0]>32640&&_(t.layerIds[0]+': Value for \"text-size\" is >= 255. Reduce your \"text-size\".'):\"composite\"===v.kind&&((y=[128*d.compositeTextSizes[0].evaluate(s,{},m),128*d.compositeTextSizes[1].evaluate(s,{},m)])[0]>32640||y[1]>32640)&&_(t.layerIds[0]+': Value for \"text-size\" is >= 255. Reduce your \"text-size\".'),t.addSymbols(t.text,g,y,l,o,s,u,e,c.lineStartIndex,c.lineLength,p,m);for(var x=0,b=f;x<b.length;x+=1){h[b[x]]=t.text.placedSymbolArray.length-1}return 4*g.length}function vc(t){for(var e in t)return t[e];return null}function yc(t,e,r,n){var i=t.compareText;if(e in i){for(var a=i[e],o=a.length-1;o>=0;o--)if(n.dist(a[o])<r)return!0}else i[e]=[];return i[e].push(n),!1}var xc=Ls.VectorTileFeature.types,bc=[{name:\"a_fade_opacity\",components:1,type:\"Uint8\",offset:0}];function _c(t,e,r,n,i,a,o,s,l,c,u,f,h){var p=s?Math.min(32640,Math.round(s[0])):0,d=s?Math.min(32640,Math.round(s[1])):0;t.emplaceBack(e,r,Math.round(32*n),Math.round(32*i),a,o,(p<<1)+(l?1:0),d,16*c,16*u,256*f,256*h)}function wc(t,e,r){t.emplaceBack(e.x,e.y,r),t.emplaceBack(e.x,e.y,r),t.emplaceBack(e.x,e.y,r),t.emplaceBack(e.x,e.y,r)}function Tc(t){for(var e=0,r=t.sections;e<r.length;e+=1){if($n(r[e].text))return!0}return!1}var kc=function(t){this.layoutVertexArray=new Ni,this.indexArray=new Yi,this.programConfigurations=t,this.segments=new pa,this.dynamicLayoutVertexArray=new ji,this.opacityVertexArray=new Ui,this.placedSymbolArray=new aa};kc.prototype.isEmpty=function(){return 0===this.layoutVertexArray.length&&0===this.indexArray.length&&0===this.dynamicLayoutVertexArray.length&&0===this.opacityVertexArray.length},kc.prototype.upload=function(t,e,r,n){this.isEmpty()||(r&&(this.layoutVertexBuffer=t.createVertexBuffer(this.layoutVertexArray,Js.members),this.indexBuffer=t.createIndexBuffer(this.indexArray,e),this.dynamicLayoutVertexBuffer=t.createVertexBuffer(this.dynamicLayoutVertexArray,Ks.members,!0),this.opacityVertexBuffer=t.createVertexBuffer(this.opacityVertexArray,bc,!0),this.opacityVertexBuffer.itemSize=1),(r||n)&&this.programConfigurations.upload(t))},kc.prototype.destroy=function(){this.layoutVertexBuffer&&(this.layoutVertexBuffer.destroy(),this.indexBuffer.destroy(),this.programConfigurations.destroy(),this.segments.destroy(),this.dynamicLayoutVertexBuffer.destroy(),this.opacityVertexBuffer.destroy())},Nn(\"SymbolBuffers\",kc);var Mc=function(t,e,r){this.layoutVertexArray=new t,this.layoutAttributes=e,this.indexArray=new r,this.segments=new pa,this.collisionVertexArray=new Gi};Mc.prototype.upload=function(t){this.layoutVertexBuffer=t.createVertexBuffer(this.layoutVertexArray,this.layoutAttributes),this.indexBuffer=t.createIndexBuffer(this.indexArray),this.collisionVertexBuffer=t.createVertexBuffer(this.collisionVertexArray,Qs.members,!0)},Mc.prototype.destroy=function(){this.layoutVertexBuffer&&(this.layoutVertexBuffer.destroy(),this.indexBuffer.destroy(),this.segments.destroy(),this.collisionVertexBuffer.destroy())},Nn(\"CollisionBuffers\",Mc);var Ac=function(t){this.collisionBoxArray=t.collisionBoxArray,this.zoom=t.zoom,this.overscaling=t.overscaling,this.layers=t.layers,this.layerIds=this.layers.map((function(t){return t.id})),this.index=t.index,this.pixelRatio=t.pixelRatio,this.sourceLayerIndex=t.sourceLayerIndex,this.hasPattern=!1,this.hasRTLText=!1,this.sortKeyRanges=[],this.collisionCircleArray=[],this.placementInvProjMatrix=ho([]),this.placementViewportMatrix=ho([]);var e=this.layers[0]._unevaluatedLayout._values;this.textSizeData=Gl(this.zoom,e[\"text-size\"]),this.iconSizeData=Gl(this.zoom,e[\"icon-size\"]);var r=this.layers[0].layout,n=r.get(\"symbol-sort-key\"),i=r.get(\"symbol-z-order\");this.sortFeaturesByKey=\"viewport-y\"!==i&&void 0!==n.constantOr(1);var a=\"viewport-y\"===i||\"auto\"===i&&!this.sortFeaturesByKey;this.sortFeaturesByY=a&&(r.get(\"text-allow-overlap\")||r.get(\"icon-allow-overlap\")||r.get(\"text-ignore-placement\")||r.get(\"icon-ignore-placement\")),\"point\"===r.get(\"symbol-placement\")&&(this.writingModes=r.get(\"text-writing-mode\").map((function(t){return Cl[t]}))),this.stateDependentLayerIds=this.layers.filter((function(t){return t.isStateDependent()})).map((function(t){return t.id})),this.sourceID=t.sourceID};Ac.prototype.createArrays=function(){this.text=new kc(new Ua(Js.members,this.layers,this.zoom,(function(t){return/^text/.test(t)}))),this.icon=new kc(new Ua(Js.members,this.layers,this.zoom,(function(t){return/^icon/.test(t)}))),this.glyphOffsetArray=new la,this.lineVertexArray=new ca,this.symbolInstances=new sa},Ac.prototype.calculateGlyphDependencies=function(t,e,r,n,i){for(var a=0;a<t.length;a++)if(e[t.charCodeAt(a)]=!0,(r||n)&&i){var o=rl[t.charAt(a)];o&&(e[o.charCodeAt(0)]=!0)}},Ac.prototype.populate=function(t,e,r){var n=this.layers[0],i=n.layout,a=i.get(\"text-font\"),o=i.get(\"text-field\"),s=i.get(\"icon-image\"),l=(\"constant\"!==o.value.kind||o.value.value instanceof ne&&!o.value.value.isEmpty()||o.value.value.toString().length>0)&&(\"constant\"!==a.value.kind||a.value.value.length>0),c=\"constant\"!==s.value.kind||!!s.value.value||Object.keys(s.parameters).length>0,u=i.get(\"symbol-sort-key\");if(this.features=[],l||c){for(var f=e.iconDependencies,h=e.glyphDependencies,p=e.availableImages,d=new pi(this.zoom),m=0,g=t;m<g.length;m+=1){var v=g[m],y=v.feature,x=v.id,b=v.index,_=v.sourceLayerIndex,w=n._featureFilter.needGeometry,T={type:y.type,id:x,properties:y.properties,geometry:w?Ya(y):[]};if(n._featureFilter.filter(d,T,r)){w||(T.geometry=Ya(y));var k=void 0;if(l){var M=n.getValueAndResolveTokens(\"text-field\",T,r,p),A=ne.factory(M);Tc(A)&&(this.hasRTLText=!0),(!this.hasRTLText||\"unavailable\"===ui()||this.hasRTLText&&hi.isParsed())&&(k=el(A,n,T))}var S=void 0;if(c){var E=n.getValueAndResolveTokens(\"icon-image\",T,r,p);S=E instanceof ie?E:ie.fromString(E)}if(k||S){var L=this.sortFeaturesByKey?u.evaluate(T,{},r):void 0,C={id:x,text:k,icon:S,index:b,sourceLayerIndex:_,geometry:Ya(y),properties:y.properties,type:xc[y.type],sortKey:L};if(this.features.push(C),S&&(f[S.name]=!0),k){var P=a.evaluate(T,{},r).join(\",\"),I=\"map\"===i.get(\"text-rotation-alignment\")&&\"point\"!==i.get(\"symbol-placement\");this.allowVerticalPlacement=this.writingModes&&this.writingModes.indexOf(Cl.vertical)>=0;for(var O=0,z=k.sections;O<z.length;O+=1){var D=z[O];if(D.image)f[D.image.name]=!0;else{var R=Wn(k.toString()),F=D.fontStack||P,B=h[F]=h[F]||{};this.calculateGlyphDependencies(D.text,B,I,this.allowVerticalPlacement,R)}}}}}}\"line\"===i.get(\"symbol-placement\")&&(this.features=function(t){var e={},r={},n=[],i=0;function a(e){n.push(t[e]),i++}function o(t,e,i){var a=r[t];return delete r[t],r[e]=a,n[a].geometry[0].pop(),n[a].geometry[0]=n[a].geometry[0].concat(i[0]),a}function s(t,r,i){var a=e[r];return delete e[r],e[t]=a,n[a].geometry[0].shift(),n[a].geometry[0]=i[0].concat(n[a].geometry[0]),a}function l(t,e,r){var n=r?e[0][e[0].length-1]:e[0][0];return t+\":\"+n.x+\":\"+n.y}for(var c=0;c<t.length;c++){var u=t[c],f=u.geometry,h=u.text?u.text.toString():null;if(h){var p=l(h,f),d=l(h,f,!0);if(p in r&&d in e&&r[p]!==e[d]){var m=s(p,d,f),g=o(p,d,n[m].geometry);delete e[p],delete r[d],r[l(h,n[g].geometry,!0)]=g,n[m].geometry=null}else p in r?o(p,d,f):d in e?s(p,d,f):(a(c),e[p]=i-1,r[d]=i-1)}else a(c)}return n.filter((function(t){return t.geometry}))}(this.features)),this.sortFeaturesByKey&&this.features.sort((function(t,e){return t.sortKey-e.sortKey}))}},Ac.prototype.update=function(t,e,r){this.stateDependentLayers.length&&(this.text.programConfigurations.updatePaintArrays(t,e,this.layers,r),this.icon.programConfigurations.updatePaintArrays(t,e,this.layers,r))},Ac.prototype.isEmpty=function(){return 0===this.symbolInstances.length&&!this.hasRTLText},Ac.prototype.uploadPending=function(){return!this.uploaded||this.text.programConfigurations.needsUpload||this.icon.programConfigurations.needsUpload},Ac.prototype.upload=function(t){!this.uploaded&&this.hasDebugData()&&(this.textCollisionBox.upload(t),this.iconCollisionBox.upload(t)),this.text.upload(t,this.sortFeaturesByY,!this.uploaded,this.text.programConfigurations.needsUpload),this.icon.upload(t,this.sortFeaturesByY,!this.uploaded,this.icon.programConfigurations.needsUpload),this.uploaded=!0},Ac.prototype.destroyDebugData=function(){this.textCollisionBox.destroy(),this.iconCollisionBox.destroy()},Ac.prototype.destroy=function(){this.text.destroy(),this.icon.destroy(),this.hasDebugData()&&this.destroyDebugData()},Ac.prototype.addToLineVertexArray=function(t,e){var r=this.lineVertexArray.length;if(void 0!==t.segment){for(var n=t.dist(e[t.segment+1]),i=t.dist(e[t.segment]),a={},o=t.segment+1;o<e.length;o++)a[o]={x:e[o].x,y:e[o].y,tileUnitDistanceFromAnchor:n},o<e.length-1&&(n+=e[o+1].dist(e[o]));for(var s=t.segment||0;s>=0;s--)a[s]={x:e[s].x,y:e[s].y,tileUnitDistanceFromAnchor:i},s>0&&(i+=e[s-1].dist(e[s]));for(var l=0;l<e.length;l++){var c=a[l];this.lineVertexArray.emplaceBack(c.x,c.y,c.tileUnitDistanceFromAnchor)}}return{lineStartIndex:r,lineLength:this.lineVertexArray.length-r}},Ac.prototype.addSymbols=function(t,e,r,n,i,a,o,s,l,c,u,f){for(var h=t.indexArray,p=t.layoutVertexArray,d=t.segments.prepareSegment(4*e.length,p,h,a.sortKey),m=this.glyphOffsetArray.length,g=d.vertexLength,v=this.allowVerticalPlacement&&o===Cl.vertical?Math.PI/2:0,y=a.text&&a.text.sections,x=0;x<e.length;x++){var b=e[x],_=b.tl,w=b.tr,T=b.bl,k=b.br,M=b.tex,A=b.pixelOffsetTL,S=b.pixelOffsetBR,E=b.minFontScaleX,L=b.minFontScaleY,C=b.glyphOffset,P=b.isSDF,I=b.sectionIndex,O=d.vertexLength,z=C[1];_c(p,s.x,s.y,_.x,z+_.y,M.x,M.y,r,P,A.x,A.y,E,L),_c(p,s.x,s.y,w.x,z+w.y,M.x+M.w,M.y,r,P,S.x,A.y,E,L),_c(p,s.x,s.y,T.x,z+T.y,M.x,M.y+M.h,r,P,A.x,S.y,E,L),_c(p,s.x,s.y,k.x,z+k.y,M.x+M.w,M.y+M.h,r,P,S.x,S.y,E,L),wc(t.dynamicLayoutVertexArray,s,v),h.emplaceBack(O,O+1,O+2),h.emplaceBack(O+1,O+2,O+3),d.vertexLength+=4,d.primitiveLength+=2,this.glyphOffsetArray.emplaceBack(C[0]),x!==e.length-1&&I===e[x+1].sectionIndex||t.programConfigurations.populatePaintArrays(p.length,a,a.index,{},f,y&&y[I])}t.placedSymbolArray.emplaceBack(s.x,s.y,m,this.glyphOffsetArray.length-m,g,l,c,s.segment,r?r[0]:0,r?r[1]:0,n[0],n[1],o,0,!1,0,u)},Ac.prototype._addCollisionDebugVertex=function(t,e,r,n,i,a){return e.emplaceBack(0,0),t.emplaceBack(r.x,r.y,n,i,Math.round(a.x),Math.round(a.y))},Ac.prototype.addCollisionDebugVertices=function(t,e,r,n,a,o,s){var l=a.segments.prepareSegment(4,a.layoutVertexArray,a.indexArray),c=l.vertexLength,u=a.layoutVertexArray,f=a.collisionVertexArray,h=s.anchorX,p=s.anchorY;this._addCollisionDebugVertex(u,f,o,h,p,new i(t,e)),this._addCollisionDebugVertex(u,f,o,h,p,new i(r,e)),this._addCollisionDebugVertex(u,f,o,h,p,new i(r,n)),this._addCollisionDebugVertex(u,f,o,h,p,new i(t,n)),l.vertexLength+=4;var d=a.indexArray;d.emplaceBack(c,c+1),d.emplaceBack(c+1,c+2),d.emplaceBack(c+2,c+3),d.emplaceBack(c+3,c),l.primitiveLength+=4},Ac.prototype.addDebugCollisionBoxes=function(t,e,r,n){for(var i=t;i<e;i++){var a=this.collisionBoxArray.get(i),o=a.x1,s=a.y1,l=a.x2,c=a.y2;this.addCollisionDebugVertices(o,s,l,c,n?this.textCollisionBox:this.iconCollisionBox,a.anchorPoint,r)}},Ac.prototype.generateCollisionDebugBuffers=function(){this.hasDebugData()&&this.destroyDebugData(),this.textCollisionBox=new Mc(qi,$s.members,Qi),this.iconCollisionBox=new Mc(qi,$s.members,Qi);for(var t=0;t<this.symbolInstances.length;t++){var e=this.symbolInstances.get(t);this.addDebugCollisionBoxes(e.textBoxStartIndex,e.textBoxEndIndex,e,!0),this.addDebugCollisionBoxes(e.verticalTextBoxStartIndex,e.verticalTextBoxEndIndex,e,!0),this.addDebugCollisionBoxes(e.iconBoxStartIndex,e.iconBoxEndIndex,e,!1),this.addDebugCollisionBoxes(e.verticalIconBoxStartIndex,e.verticalIconBoxEndIndex,e,!1)}},Ac.prototype._deserializeCollisionBoxesForSymbol=function(t,e,r,n,i,a,o,s,l){for(var c={},u=e;u<r;u++){var f=t.get(u);c.textBox={x1:f.x1,y1:f.y1,x2:f.x2,y2:f.y2,anchorPointX:f.anchorPointX,anchorPointY:f.anchorPointY},c.textFeatureIndex=f.featureIndex;break}for(var h=n;h<i;h++){var p=t.get(h);c.verticalTextBox={x1:p.x1,y1:p.y1,x2:p.x2,y2:p.y2,anchorPointX:p.anchorPointX,anchorPointY:p.anchorPointY},c.verticalTextFeatureIndex=p.featureIndex;break}for(var d=a;d<o;d++){var m=t.get(d);c.iconBox={x1:m.x1,y1:m.y1,x2:m.x2,y2:m.y2,anchorPointX:m.anchorPointX,anchorPointY:m.anchorPointY},c.iconFeatureIndex=m.featureIndex;break}for(var g=s;g<l;g++){var v=t.get(g);c.verticalIconBox={x1:v.x1,y1:v.y1,x2:v.x2,y2:v.y2,anchorPointX:v.anchorPointX,anchorPointY:v.anchorPointY},c.verticalIconFeatureIndex=v.featureIndex;break}return c},Ac.prototype.deserializeCollisionBoxes=function(t){this.collisionArrays=[];for(var e=0;e<this.symbolInstances.length;e++){var r=this.symbolInstances.get(e);this.collisionArrays.push(this._deserializeCollisionBoxesForSymbol(t,r.textBoxStartIndex,r.textBoxEndIndex,r.verticalTextBoxStartIndex,r.verticalTextBoxEndIndex,r.iconBoxStartIndex,r.iconBoxEndIndex,r.verticalIconBoxStartIndex,r.verticalIconBoxEndIndex))}},Ac.prototype.hasTextData=function(){return this.text.segments.get().length>0},Ac.prototype.hasIconData=function(){return this.icon.segments.get().length>0},Ac.prototype.hasDebugData=function(){return this.textCollisionBox&&this.iconCollisionBox},Ac.prototype.hasTextCollisionBoxData=function(){return this.hasDebugData()&&this.textCollisionBox.segments.get().length>0},Ac.prototype.hasIconCollisionBoxData=function(){return this.hasDebugData()&&this.iconCollisionBox.segments.get().length>0},Ac.prototype.addIndicesForPlacedSymbol=function(t,e){for(var r=t.placedSymbolArray.get(e),n=r.vertexStartIndex+4*r.numGlyphs,i=r.vertexStartIndex;i<n;i+=4)t.indexArray.emplaceBack(i,i+1,i+2),t.indexArray.emplaceBack(i+1,i+2,i+3)},Ac.prototype.getSortedSymbolIndexes=function(t){if(this.sortedAngle===t&&void 0!==this.symbolInstanceIndexes)return this.symbolInstanceIndexes;for(var e=Math.sin(t),r=Math.cos(t),n=[],i=[],a=[],o=0;o<this.symbolInstances.length;++o){a.push(o);var s=this.symbolInstances.get(o);n.push(0|Math.round(e*s.anchorX+r*s.anchorY)),i.push(s.featureIndex)}return a.sort((function(t,e){return n[t]-n[e]||i[e]-i[t]})),a},Ac.prototype.addToSortKeyRanges=function(t,e){var r=this.sortKeyRanges[this.sortKeyRanges.length-1];r&&r.sortKey===e?r.symbolInstanceEnd=t+1:this.sortKeyRanges.push({sortKey:e,symbolInstanceStart:t,symbolInstanceEnd:t+1})},Ac.prototype.sortFeatures=function(t){var e=this;if(this.sortFeaturesByY&&this.sortedAngle!==t&&!(this.text.segments.get().length>1||this.icon.segments.get().length>1)){this.symbolInstanceIndexes=this.getSortedSymbolIndexes(t),this.sortedAngle=t,this.text.indexArray.clear(),this.icon.indexArray.clear(),this.featureSortOrder=[];for(var r=0,n=this.symbolInstanceIndexes;r<n.length;r+=1){var i=n[r],a=this.symbolInstances.get(i);this.featureSortOrder.push(a.featureIndex),[a.rightJustifiedTextSymbolIndex,a.centerJustifiedTextSymbolIndex,a.leftJustifiedTextSymbolIndex].forEach((function(t,r,n){t>=0&&n.indexOf(t)===r&&e.addIndicesForPlacedSymbol(e.text,t)})),a.verticalPlacedTextSymbolIndex>=0&&this.addIndicesForPlacedSymbol(this.text,a.verticalPlacedTextSymbolIndex),a.placedIconSymbolIndex>=0&&this.addIndicesForPlacedSymbol(this.icon,a.placedIconSymbolIndex),a.verticalPlacedIconSymbolIndex>=0&&this.addIndicesForPlacedSymbol(this.icon,a.verticalPlacedIconSymbolIndex)}this.text.indexBuffer&&this.text.indexBuffer.updateData(this.text.indexArray),this.icon.indexBuffer&&this.icon.indexBuffer.updateData(this.icon.indexArray)}},Nn(\"SymbolBucket\",Ac,{omit:[\"layers\",\"collisionBoxArray\",\"features\",\"compareText\"]}),Ac.MAX_GLYPHS=65535,Ac.addDynamicAttributes=wc;var Sc=new Si({\"symbol-placement\":new wi(Lt.layout_symbol[\"symbol-placement\"]),\"symbol-spacing\":new wi(Lt.layout_symbol[\"symbol-spacing\"]),\"symbol-avoid-edges\":new wi(Lt.layout_symbol[\"symbol-avoid-edges\"]),\"symbol-sort-key\":new Ti(Lt.layout_symbol[\"symbol-sort-key\"]),\"symbol-z-order\":new wi(Lt.layout_symbol[\"symbol-z-order\"]),\"icon-allow-overlap\":new wi(Lt.layout_symbol[\"icon-allow-overlap\"]),\"icon-ignore-placement\":new wi(Lt.layout_symbol[\"icon-ignore-placement\"]),\"icon-optional\":new wi(Lt.layout_symbol[\"icon-optional\"]),\"icon-rotation-alignment\":new wi(Lt.layout_symbol[\"icon-rotation-alignment\"]),\"icon-size\":new Ti(Lt.layout_symbol[\"icon-size\"]),\"icon-text-fit\":new wi(Lt.layout_symbol[\"icon-text-fit\"]),\"icon-text-fit-padding\":new wi(Lt.layout_symbol[\"icon-text-fit-padding\"]),\"icon-image\":new Ti(Lt.layout_symbol[\"icon-image\"]),\"icon-rotate\":new Ti(Lt.layout_symbol[\"icon-rotate\"]),\"icon-padding\":new wi(Lt.layout_symbol[\"icon-padding\"]),\"icon-keep-upright\":new wi(Lt.layout_symbol[\"icon-keep-upright\"]),\"icon-offset\":new Ti(Lt.layout_symbol[\"icon-offset\"]),\"icon-anchor\":new Ti(Lt.layout_symbol[\"icon-anchor\"]),\"icon-pitch-alignment\":new wi(Lt.layout_symbol[\"icon-pitch-alignment\"]),\"text-pitch-alignment\":new wi(Lt.layout_symbol[\"text-pitch-alignment\"]),\"text-rotation-alignment\":new wi(Lt.layout_symbol[\"text-rotation-alignment\"]),\"text-field\":new Ti(Lt.layout_symbol[\"text-field\"]),\"text-font\":new Ti(Lt.layout_symbol[\"text-font\"]),\"text-size\":new Ti(Lt.layout_symbol[\"text-size\"]),\"text-max-width\":new Ti(Lt.layout_symbol[\"text-max-width\"]),\"text-line-height\":new wi(Lt.layout_symbol[\"text-line-height\"]),\"text-letter-spacing\":new Ti(Lt.layout_symbol[\"text-letter-spacing\"]),\"text-justify\":new Ti(Lt.layout_symbol[\"text-justify\"]),\"text-radial-offset\":new Ti(Lt.layout_symbol[\"text-radial-offset\"]),\"text-variable-anchor\":new wi(Lt.layout_symbol[\"text-variable-anchor\"]),\"text-anchor\":new Ti(Lt.layout_symbol[\"text-anchor\"]),\"text-max-angle\":new wi(Lt.layout_symbol[\"text-max-angle\"]),\"text-writing-mode\":new wi(Lt.layout_symbol[\"text-writing-mode\"]),\"text-rotate\":new Ti(Lt.layout_symbol[\"text-rotate\"]),\"text-padding\":new wi(Lt.layout_symbol[\"text-padding\"]),\"text-keep-upright\":new wi(Lt.layout_symbol[\"text-keep-upright\"]),\"text-transform\":new Ti(Lt.layout_symbol[\"text-transform\"]),\"text-offset\":new Ti(Lt.layout_symbol[\"text-offset\"]),\"text-allow-overlap\":new wi(Lt.layout_symbol[\"text-allow-overlap\"]),\"text-ignore-placement\":new wi(Lt.layout_symbol[\"text-ignore-placement\"]),\"text-optional\":new wi(Lt.layout_symbol[\"text-optional\"])}),Ec={paint:new Si({\"icon-opacity\":new Ti(Lt.paint_symbol[\"icon-opacity\"]),\"icon-color\":new Ti(Lt.paint_symbol[\"icon-color\"]),\"icon-halo-color\":new Ti(Lt.paint_symbol[\"icon-halo-color\"]),\"icon-halo-width\":new Ti(Lt.paint_symbol[\"icon-halo-width\"]),\"icon-halo-blur\":new Ti(Lt.paint_symbol[\"icon-halo-blur\"]),\"icon-translate\":new wi(Lt.paint_symbol[\"icon-translate\"]),\"icon-translate-anchor\":new wi(Lt.paint_symbol[\"icon-translate-anchor\"]),\"text-opacity\":new Ti(Lt.paint_symbol[\"text-opacity\"]),\"text-color\":new Ti(Lt.paint_symbol[\"text-color\"],{runtimeType:Ut,getOverride:function(t){return t.textColor},hasOverride:function(t){return!!t.textColor}}),\"text-halo-color\":new Ti(Lt.paint_symbol[\"text-halo-color\"]),\"text-halo-width\":new Ti(Lt.paint_symbol[\"text-halo-width\"]),\"text-halo-blur\":new Ti(Lt.paint_symbol[\"text-halo-blur\"]),\"text-translate\":new wi(Lt.paint_symbol[\"text-translate\"]),\"text-translate-anchor\":new wi(Lt.paint_symbol[\"text-translate-anchor\"])}),layout:Sc},Lc=function(t){this.type=t.property.overrides?t.property.overrides.runtimeType:Ft,this.defaultValue=t};Lc.prototype.evaluate=function(t){if(t.formattedSection){var e=this.defaultValue.property.overrides;if(e&&e.hasOverride(t.formattedSection))return e.getOverride(t.formattedSection)}return t.feature&&t.featureState?this.defaultValue.evaluate(t.feature,t.featureState):this.defaultValue.property.specification.default},Lc.prototype.eachChild=function(t){this.defaultValue.isConstant()||t(this.defaultValue.value._styleExpression.expression)},Lc.prototype.outputDefined=function(){return!1},Lc.prototype.serialize=function(){return null},Nn(\"FormatSectionOverride\",Lc,{omit:[\"defaultValue\"]});var Cc=function(t){function e(e){t.call(this,e,Ec)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.recalculate=function(e,r){if(t.prototype.recalculate.call(this,e,r),\"auto\"===this.layout.get(\"icon-rotation-alignment\")&&(\"point\"!==this.layout.get(\"symbol-placement\")?this.layout._values[\"icon-rotation-alignment\"]=\"map\":this.layout._values[\"icon-rotation-alignment\"]=\"viewport\"),\"auto\"===this.layout.get(\"text-rotation-alignment\")&&(\"point\"!==this.layout.get(\"symbol-placement\")?this.layout._values[\"text-rotation-alignment\"]=\"map\":this.layout._values[\"text-rotation-alignment\"]=\"viewport\"),\"auto\"===this.layout.get(\"text-pitch-alignment\")&&(this.layout._values[\"text-pitch-alignment\"]=this.layout.get(\"text-rotation-alignment\")),\"auto\"===this.layout.get(\"icon-pitch-alignment\")&&(this.layout._values[\"icon-pitch-alignment\"]=this.layout.get(\"icon-rotation-alignment\")),\"point\"===this.layout.get(\"symbol-placement\")){var n=this.layout.get(\"text-writing-mode\");if(n){for(var i=[],a=0,o=n;a<o.length;a+=1){var s=o[a];i.indexOf(s)<0&&i.push(s)}this.layout._values[\"text-writing-mode\"]=i}else this.layout._values[\"text-writing-mode\"]=[\"horizontal\"]}this._setPaintOverrides()},e.prototype.getValueAndResolveTokens=function(t,e,r,n){var i=this.layout.get(t).evaluate(e,{},r,n),a=this._unevaluatedLayout._values[t];return a.isDataDriven()||Yr(a.value)||!i?i:function(t,e){return e.replace(/{([^{}]+)}/g,(function(e,r){return r in t?String(t[r]):\"\"}))}(e.properties,i)},e.prototype.createBucket=function(t){return new Ac(t)},e.prototype.queryRadius=function(){return 0},e.prototype.queryIntersectsFeature=function(){return!1},e.prototype._setPaintOverrides=function(){for(var t=0,r=Ec.paint.overridableProperties;t<r.length;t+=1){var n=r[t];if(e.hasPaintOverride(this.layout,n)){var i=this.paint.get(n),a=new Lc(i),o=new Gr(a,i.property.specification),s=null;s=\"constant\"===i.value.kind||\"source\"===i.value.kind?new Xr(\"source\",o):new Zr(\"composite\",o,i.value.zoomStops,i.value._interpolationType),this.paint._values[n]=new bi(i.property,s,i.parameters)}}},e.prototype._handleOverridablePaintPropertyUpdate=function(t,r,n){return!(!this.layout||r.isDataDriven()||n.isDataDriven())&&e.hasPaintOverride(this.layout,t)},e.hasPaintOverride=function(t,e){var r=t.get(\"text-field\"),n=Ec.paint.properties[e],i=!1,a=function(t){for(var e=0,r=t;e<r.length;e+=1){var a=r[e];if(n.overrides&&n.overrides.hasOverride(a))return void(i=!0)}};if(\"constant\"===r.value.kind&&r.value.value instanceof ne)a(r.value.value.sections);else if(\"source\"===r.value.kind){var o=function(t){if(!i)if(t instanceof ce&&se(t.value)===Gt){var e=t.value;a(e.sections)}else t instanceof pe?a(t.sections):t.eachChild(o)},s=r.value;s._styleExpression&&o(s._styleExpression.expression)}return i},e}(Ei),Pc={paint:new Si({\"background-color\":new wi(Lt.paint_background[\"background-color\"]),\"background-pattern\":new Mi(Lt.paint_background[\"background-pattern\"]),\"background-opacity\":new wi(Lt.paint_background[\"background-opacity\"])})},Ic=function(t){function e(e){t.call(this,e,Pc)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e}(Ei),Oc={paint:new Si({\"raster-opacity\":new wi(Lt.paint_raster[\"raster-opacity\"]),\"raster-hue-rotate\":new wi(Lt.paint_raster[\"raster-hue-rotate\"]),\"raster-brightness-min\":new wi(Lt.paint_raster[\"raster-brightness-min\"]),\"raster-brightness-max\":new wi(Lt.paint_raster[\"raster-brightness-max\"]),\"raster-saturation\":new wi(Lt.paint_raster[\"raster-saturation\"]),\"raster-contrast\":new wi(Lt.paint_raster[\"raster-contrast\"]),\"raster-resampling\":new wi(Lt.paint_raster[\"raster-resampling\"]),\"raster-fade-duration\":new wi(Lt.paint_raster[\"raster-fade-duration\"])})},zc=function(t){function e(e){t.call(this,e,Oc)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e}(Ei);var Dc=function(t){function e(e){t.call(this,e,{}),this.implementation=e}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.is3D=function(){return\"3d\"===this.implementation.renderingMode},e.prototype.hasOffscreenPass=function(){return void 0!==this.implementation.prerender},e.prototype.recalculate=function(){},e.prototype.updateTransitions=function(){},e.prototype.hasTransition=function(){},e.prototype.serialize=function(){},e.prototype.onAdd=function(t){this.implementation.onAdd&&this.implementation.onAdd(t,t.painter.context.gl)},e.prototype.onRemove=function(t){this.implementation.onRemove&&this.implementation.onRemove(t,t.painter.context.gl)},e}(Ei),Rc={circle:_o,heatmap:Po,hillshade:Oo,fill:xs,\"fill-extrusion\":Fs,line:Xs,symbol:Cc,background:Ic,raster:zc};var Fc=self.HTMLImageElement,Bc=self.HTMLCanvasElement,Nc=self.HTMLVideoElement,jc=self.ImageData,Uc=self.ImageBitmap,Vc=function(t,e,r,n){this.context=t,this.format=r,this.texture=t.gl.createTexture(),this.update(e,n)};Vc.prototype.update=function(t,e,r){var n=t.width,i=t.height,a=!(this.size&&this.size[0]===n&&this.size[1]===i||r),o=this.context,s=o.gl;if(this.useMipmap=Boolean(e&&e.useMipmap),s.bindTexture(s.TEXTURE_2D,this.texture),o.pixelStoreUnpackFlipY.set(!1),o.pixelStoreUnpack.set(1),o.pixelStoreUnpackPremultiplyAlpha.set(this.format===s.RGBA&&(!e||!1!==e.premultiply)),a)this.size=[n,i],t instanceof Fc||t instanceof Bc||t instanceof Nc||t instanceof jc||Uc&&t instanceof Uc?s.texImage2D(s.TEXTURE_2D,0,this.format,this.format,s.UNSIGNED_BYTE,t):s.texImage2D(s.TEXTURE_2D,0,this.format,n,i,0,this.format,s.UNSIGNED_BYTE,t.data);else{var l=r||{x:0,y:0},c=l.x,u=l.y;t instanceof Fc||t instanceof Bc||t instanceof Nc||t instanceof jc||Uc&&t instanceof Uc?s.texSubImage2D(s.TEXTURE_2D,0,c,u,s.RGBA,s.UNSIGNED_BYTE,t):s.texSubImage2D(s.TEXTURE_2D,0,c,u,n,i,s.RGBA,s.UNSIGNED_BYTE,t.data)}this.useMipmap&&this.isSizePowerOfTwo()&&s.generateMipmap(s.TEXTURE_2D)},Vc.prototype.bind=function(t,e,r){var n=this.context.gl;n.bindTexture(n.TEXTURE_2D,this.texture),r!==n.LINEAR_MIPMAP_NEAREST||this.isSizePowerOfTwo()||(r=n.LINEAR),t!==this.filter&&(n.texParameteri(n.TEXTURE_2D,n.TEXTURE_MAG_FILTER,t),n.texParameteri(n.TEXTURE_2D,n.TEXTURE_MIN_FILTER,r||t),this.filter=t),e!==this.wrap&&(n.texParameteri(n.TEXTURE_2D,n.TEXTURE_WRAP_S,e),n.texParameteri(n.TEXTURE_2D,n.TEXTURE_WRAP_T,e),this.wrap=e)},Vc.prototype.isSizePowerOfTwo=function(){return this.size[0]===this.size[1]&&Math.log(this.size[0])/Math.LN2%1==0},Vc.prototype.destroy=function(){this.context.gl.deleteTexture(this.texture),this.texture=null};var qc=function(t){var e=this;this._callback=t,this._triggered=!1,\"undefined\"!=typeof MessageChannel&&(this._channel=new MessageChannel,this._channel.port2.onmessage=function(){e._triggered=!1,e._callback()})};qc.prototype.trigger=function(){var t=this;this._triggered||(this._triggered=!0,this._channel?this._channel.port1.postMessage(!0):setTimeout((function(){t._triggered=!1,t._callback()}),0))},qc.prototype.remove=function(){delete this._channel,this._callback=function(){}};var Hc=function(t,e,r){this.target=t,this.parent=e,this.mapId=r,this.callbacks={},this.tasks={},this.taskQueue=[],this.cancelCallbacks={},m([\"receive\",\"process\"],this),this.invoker=new qc(this.process),this.target.addEventListener(\"message\",this.receive,!1),this.globalScope=k()?t:self};function Gc(t,e,r){var n=2*Math.PI*6378137/256/Math.pow(2,r);return[t*n-2*Math.PI*6378137/2,e*n-2*Math.PI*6378137/2]}Hc.prototype.send=function(t,e,r,n,i){var a=this;void 0===i&&(i=!1);var o=Math.round(1e18*Math.random()).toString(36).substring(0,10);r&&(this.callbacks[o]=r);var s=S(this.globalScope)?void 0:[];return this.target.postMessage({id:o,type:t,hasCallback:!!r,targetMapId:n,mustQueue:i,sourceMapId:this.mapId,data:qn(e,s)},s),{cancel:function(){r&&delete a.callbacks[o],a.target.postMessage({id:o,type:\"<cancel>\",targetMapId:n,sourceMapId:a.mapId})}}},Hc.prototype.receive=function(t){var e=t.data,r=e.id;if(r&&(!e.targetMapId||this.mapId===e.targetMapId))if(\"<cancel>\"===e.type){delete this.tasks[r];var n=this.cancelCallbacks[r];delete this.cancelCallbacks[r],n&&n()}else k()||e.mustQueue?(this.tasks[r]=e,this.taskQueue.push(r),this.invoker.trigger()):this.processTask(r,e)},Hc.prototype.process=function(){if(this.taskQueue.length){var t=this.taskQueue.shift(),e=this.tasks[t];delete this.tasks[t],this.taskQueue.length&&this.invoker.trigger(),e&&this.processTask(t,e)}},Hc.prototype.processTask=function(t,e){var r=this;if(\"<response>\"===e.type){var n=this.callbacks[t];delete this.callbacks[t],n&&(e.error?n(Hn(e.error)):n(null,Hn(e.data)))}else{var i=!1,a=S(this.globalScope)?void 0:[],o=e.hasCallback?function(e,n){i=!0,delete r.cancelCallbacks[t],r.target.postMessage({id:t,type:\"<response>\",sourceMapId:r.mapId,error:e?qn(e):null,data:qn(n,a)},a)}:function(t){i=!0},s=null,l=Hn(e.data);if(this.parent[e.type])s=this.parent[e.type](e.sourceMapId,l,o);else if(this.parent.getWorkerSource){var c=e.type.split(\".\");s=this.parent.getWorkerSource(e.sourceMapId,c[0],l.source)[c[1]](l,o)}else o(new Error(\"Could not find function \"+e.type));!i&&s&&s.cancel&&(this.cancelCallbacks[t]=s.cancel)}},Hc.prototype.remove=function(){this.invoker.remove(),this.target.removeEventListener(\"message\",this.receive,!1)};var Yc=function(t,e){t&&(e?this.setSouthWest(t).setNorthEast(e):4===t.length?this.setSouthWest([t[0],t[1]]).setNorthEast([t[2],t[3]]):this.setSouthWest(t[0]).setNorthEast(t[1]))};Yc.prototype.setNorthEast=function(t){return this._ne=t instanceof Wc?new Wc(t.lng,t.lat):Wc.convert(t),this},Yc.prototype.setSouthWest=function(t){return this._sw=t instanceof Wc?new Wc(t.lng,t.lat):Wc.convert(t),this},Yc.prototype.extend=function(t){var e,r,n=this._sw,i=this._ne;if(t instanceof Wc)e=t,r=t;else{if(!(t instanceof Yc)){if(Array.isArray(t)){if(4===t.length||t.every(Array.isArray)){var a=t;return this.extend(Yc.convert(a))}var o=t;return this.extend(Wc.convert(o))}return this}if(e=t._sw,r=t._ne,!e||!r)return this}return n||i?(n.lng=Math.min(e.lng,n.lng),n.lat=Math.min(e.lat,n.lat),i.lng=Math.max(r.lng,i.lng),i.lat=Math.max(r.lat,i.lat)):(this._sw=new Wc(e.lng,e.lat),this._ne=new Wc(r.lng,r.lat)),this},Yc.prototype.getCenter=function(){return new Wc((this._sw.lng+this._ne.lng)/2,(this._sw.lat+this._ne.lat)/2)},Yc.prototype.getSouthWest=function(){return this._sw},Yc.prototype.getNorthEast=function(){return this._ne},Yc.prototype.getNorthWest=function(){return new Wc(this.getWest(),this.getNorth())},Yc.prototype.getSouthEast=function(){return new Wc(this.getEast(),this.getSouth())},Yc.prototype.getWest=function(){return this._sw.lng},Yc.prototype.getSouth=function(){return this._sw.lat},Yc.prototype.getEast=function(){return this._ne.lng},Yc.prototype.getNorth=function(){return this._ne.lat},Yc.prototype.toArray=function(){return[this._sw.toArray(),this._ne.toArray()]},Yc.prototype.toString=function(){return\"LngLatBounds(\"+this._sw.toString()+\", \"+this._ne.toString()+\")\"},Yc.prototype.isEmpty=function(){return!(this._sw&&this._ne)},Yc.prototype.contains=function(t){var e=Wc.convert(t),r=e.lng,n=e.lat,i=this._sw.lat<=n&&n<=this._ne.lat,a=this._sw.lng<=r&&r<=this._ne.lng;return this._sw.lng>this._ne.lng&&(a=this._sw.lng>=r&&r>=this._ne.lng),i&&a},Yc.convert=function(t){return!t||t instanceof Yc?t:new Yc(t)};var Wc=function(t,e){if(isNaN(t)||isNaN(e))throw new Error(\"Invalid LngLat object: (\"+t+\", \"+e+\")\");if(this.lng=+t,this.lat=+e,this.lat>90||this.lat<-90)throw new Error(\"Invalid LngLat latitude value: must be between -90 and 90\")};Wc.prototype.wrap=function(){return new Wc(c(this.lng,-180,180),this.lat)},Wc.prototype.toArray=function(){return[this.lng,this.lat]},Wc.prototype.toString=function(){return\"LngLat(\"+this.lng+\", \"+this.lat+\")\"},Wc.prototype.distanceTo=function(t){var e=Math.PI/180,r=this.lat*e,n=t.lat*e,i=Math.sin(r)*Math.sin(n)+Math.cos(r)*Math.cos(n)*Math.cos((t.lng-this.lng)*e);return 6371008.8*Math.acos(Math.min(i,1))},Wc.prototype.toBounds=function(t){void 0===t&&(t=0);var e=360*t/40075017,r=e/Math.cos(Math.PI/180*this.lat);return new Yc(new Wc(this.lng-r,this.lat-e),new Wc(this.lng+r,this.lat+e))},Wc.convert=function(t){if(t instanceof Wc)return t;if(Array.isArray(t)&&(2===t.length||3===t.length))return new Wc(Number(t[0]),Number(t[1]));if(!Array.isArray(t)&&\"object\"==typeof t&&null!==t)return new Wc(Number(\"lng\"in t?t.lng:t.lon),Number(t.lat));throw new Error(\"`LngLatLike` argument must be specified as a LngLat instance, an object {lng: <lng>, lat: <lat>}, an object {lon: <lng>, lat: <lat>}, or an array of [<lng>, <lat>]\")};var Xc=2*Math.PI*6371008.8;function Zc(t){return Xc*Math.cos(t*Math.PI/180)}function Jc(t){return(180+t)/360}function Kc(t){return(180-180/Math.PI*Math.log(Math.tan(Math.PI/4+t*Math.PI/360)))/360}function Qc(t,e){return t/Zc(e)}function $c(t){var e=180-360*t;return 360/Math.PI*Math.atan(Math.exp(e*Math.PI/180))-90}var tu=function(t,e,r){void 0===r&&(r=0),this.x=+t,this.y=+e,this.z=+r};tu.fromLngLat=function(t,e){void 0===e&&(e=0);var r=Wc.convert(t);return new tu(Jc(r.lng),Kc(r.lat),Qc(e,r.lat))},tu.prototype.toLngLat=function(){return new Wc(360*this.x-180,$c(this.y))},tu.prototype.toAltitude=function(){return t=this.z,e=this.y,t*Zc($c(e));var t,e},tu.prototype.meterInMercatorCoordinateUnits=function(){return 1/Xc*(t=$c(this.y),1/Math.cos(t*Math.PI/180));var t};var eu=function(t,e,r){this.z=t,this.x=e,this.y=r,this.key=iu(0,t,t,e,r)};eu.prototype.equals=function(t){return this.z===t.z&&this.x===t.x&&this.y===t.y},eu.prototype.url=function(t,e){var r,n,i,a,o,s=(r=this.x,n=this.y,i=this.z,a=Gc(256*r,256*(n=Math.pow(2,i)-n-1),i),o=Gc(256*(r+1),256*(n+1),i),a[0]+\",\"+a[1]+\",\"+o[0]+\",\"+o[1]),l=function(t,e,r){for(var n,i=\"\",a=t;a>0;a--)i+=(e&(n=1<<a-1)?1:0)+(r&n?2:0);return i}(this.z,this.x,this.y);return t[(this.x+this.y)%t.length].replace(\"{prefix}\",(this.x%16).toString(16)+(this.y%16).toString(16)).replace(\"{z}\",String(this.z)).replace(\"{x}\",String(this.x)).replace(\"{y}\",String(\"tms\"===e?Math.pow(2,this.z)-this.y-1:this.y)).replace(\"{quadkey}\",l).replace(\"{bbox-epsg-3857}\",s)},eu.prototype.getTilePoint=function(t){var e=Math.pow(2,this.z);return new i(8192*(t.x*e-this.x),8192*(t.y*e-this.y))},eu.prototype.toString=function(){return this.z+\"/\"+this.x+\"/\"+this.y};var ru=function(t,e){this.wrap=t,this.canonical=e,this.key=iu(t,e.z,e.z,e.x,e.y)},nu=function(t,e,r,n,i){this.overscaledZ=t,this.wrap=e,this.canonical=new eu(r,+n,+i),this.key=iu(e,t,r,n,i)};function iu(t,e,r,n,i){(t*=2)<0&&(t=-1*t-1);var a=1<<r;return(a*a*t+a*i+n).toString(36)+r.toString(36)+e.toString(36)}nu.prototype.equals=function(t){return this.overscaledZ===t.overscaledZ&&this.wrap===t.wrap&&this.canonical.equals(t.canonical)},nu.prototype.scaledTo=function(t){var e=this.canonical.z-t;return t>this.canonical.z?new nu(t,this.wrap,this.canonical.z,this.canonical.x,this.canonical.y):new nu(t,this.wrap,t,this.canonical.x>>e,this.canonical.y>>e)},nu.prototype.calculateScaledKey=function(t,e){var r=this.canonical.z-t;return t>this.canonical.z?iu(this.wrap*+e,t,this.canonical.z,this.canonical.x,this.canonical.y):iu(this.wrap*+e,t,t,this.canonical.x>>r,this.canonical.y>>r)},nu.prototype.isChildOf=function(t){if(t.wrap!==this.wrap)return!1;var e=this.canonical.z-t.canonical.z;return 0===t.overscaledZ||t.overscaledZ<this.overscaledZ&&t.canonical.x===this.canonical.x>>e&&t.canonical.y===this.canonical.y>>e},nu.prototype.children=function(t){if(this.overscaledZ>=t)return[new nu(this.overscaledZ+1,this.wrap,this.canonical.z,this.canonical.x,this.canonical.y)];var e=this.canonical.z+1,r=2*this.canonical.x,n=2*this.canonical.y;return[new nu(e,this.wrap,e,r,n),new nu(e,this.wrap,e,r+1,n),new nu(e,this.wrap,e,r,n+1),new nu(e,this.wrap,e,r+1,n+1)]},nu.prototype.isLessThan=function(t){return this.wrap<t.wrap||!(this.wrap>t.wrap)&&(this.overscaledZ<t.overscaledZ||!(this.overscaledZ>t.overscaledZ)&&(this.canonical.x<t.canonical.x||!(this.canonical.x>t.canonical.x)&&this.canonical.y<t.canonical.y))},nu.prototype.wrapped=function(){return new nu(this.overscaledZ,0,this.canonical.z,this.canonical.x,this.canonical.y)},nu.prototype.unwrapTo=function(t){return new nu(this.overscaledZ,t,this.canonical.z,this.canonical.x,this.canonical.y)},nu.prototype.overscaleFactor=function(){return Math.pow(2,this.overscaledZ-this.canonical.z)},nu.prototype.toUnwrapped=function(){return new ru(this.wrap,this.canonical)},nu.prototype.toString=function(){return this.overscaledZ+\"/\"+this.canonical.x+\"/\"+this.canonical.y},nu.prototype.getTilePoint=function(t){return this.canonical.getTilePoint(new tu(t.x-this.wrap,t.y))},Nn(\"CanonicalTileID\",eu),Nn(\"OverscaledTileID\",nu,{omit:[\"posMatrix\"]});var au=function(t,e,r){if(this.uid=t,e.height!==e.width)throw new RangeError(\"DEM tiles must be square\");if(r&&\"mapbox\"!==r&&\"terrarium\"!==r)return _('\"'+r+'\" is not a valid encoding type. Valid types include \"mapbox\" and \"terrarium\".');this.stride=e.height;var n=this.dim=e.height-2;this.data=new Uint32Array(e.data.buffer),this.encoding=r||\"mapbox\";for(var i=0;i<n;i++)this.data[this._idx(-1,i)]=this.data[this._idx(0,i)],this.data[this._idx(n,i)]=this.data[this._idx(n-1,i)],this.data[this._idx(i,-1)]=this.data[this._idx(i,0)],this.data[this._idx(i,n)]=this.data[this._idx(i,n-1)];this.data[this._idx(-1,-1)]=this.data[this._idx(0,0)],this.data[this._idx(n,-1)]=this.data[this._idx(n-1,0)],this.data[this._idx(-1,n)]=this.data[this._idx(0,n-1)],this.data[this._idx(n,n)]=this.data[this._idx(n-1,n-1)]};au.prototype.get=function(t,e){var r=new Uint8Array(this.data.buffer),n=4*this._idx(t,e);return(\"terrarium\"===this.encoding?this._unpackTerrarium:this._unpackMapbox)(r[n],r[n+1],r[n+2])},au.prototype.getUnpackVector=function(){return\"terrarium\"===this.encoding?[256,1,1/256,32768]:[6553.6,25.6,.1,1e4]},au.prototype._idx=function(t,e){if(t<-1||t>=this.dim+1||e<-1||e>=this.dim+1)throw new RangeError(\"out of range source coordinates for DEM data\");return(e+1)*this.stride+(t+1)},au.prototype._unpackMapbox=function(t,e,r){return(256*t*256+256*e+r)/10-1e4},au.prototype._unpackTerrarium=function(t,e,r){return 256*t+e+r/256-32768},au.prototype.getPixels=function(){return new Eo({width:this.stride,height:this.stride},new Uint8Array(this.data.buffer))},au.prototype.backfillBorder=function(t,e,r){if(this.dim!==t.dim)throw new Error(\"dem dimension mismatch\");var n=e*this.dim,i=e*this.dim+this.dim,a=r*this.dim,o=r*this.dim+this.dim;switch(e){case-1:n=i-1;break;case 1:i=n+1}switch(r){case-1:a=o-1;break;case 1:o=a+1}for(var s=-e*this.dim,l=-r*this.dim,c=a;c<o;c++)for(var u=n;u<i;u++)this.data[this._idx(u,c)]=t.data[this._idx(u+s,c+l)]},Nn(\"DEMData\",au);var ou=function(t){this._stringToNumber={},this._numberToString=[];for(var e=0;e<t.length;e++){var r=t[e];this._stringToNumber[r]=e,this._numberToString[e]=r}};ou.prototype.encode=function(t){return this._stringToNumber[t]},ou.prototype.decode=function(t){return this._numberToString[t]};var su=function(t,e,r,n,i){this.type=\"Feature\",this._vectorTileFeature=t,t._z=e,t._x=r,t._y=n,this.properties=t.properties,this.id=i},lu={geometry:{configurable:!0}};lu.geometry.get=function(){return void 0===this._geometry&&(this._geometry=this._vectorTileFeature.toGeoJSON(this._vectorTileFeature._x,this._vectorTileFeature._y,this._vectorTileFeature._z).geometry),this._geometry},lu.geometry.set=function(t){this._geometry=t},su.prototype.toJSON=function(){var t={geometry:this.geometry};for(var e in this)\"_geometry\"!==e&&\"_vectorTileFeature\"!==e&&(t[e]=this[e]);return t},Object.defineProperties(su.prototype,lu);var cu=function(){this.state={},this.stateChanges={},this.deletedStates={}};cu.prototype.updateState=function(t,e,r){var n=String(e);if(this.stateChanges[t]=this.stateChanges[t]||{},this.stateChanges[t][n]=this.stateChanges[t][n]||{},u(this.stateChanges[t][n],r),null===this.deletedStates[t])for(var i in this.deletedStates[t]={},this.state[t])i!==n&&(this.deletedStates[t][i]=null);else if(this.deletedStates[t]&&null===this.deletedStates[t][n])for(var a in this.deletedStates[t][n]={},this.state[t][n])r[a]||(this.deletedStates[t][n][a]=null);else for(var o in r){this.deletedStates[t]&&this.deletedStates[t][n]&&null===this.deletedStates[t][n][o]&&delete this.deletedStates[t][n][o]}},cu.prototype.removeFeatureState=function(t,e,r){if(!(null===this.deletedStates[t])){var n=String(e);if(this.deletedStates[t]=this.deletedStates[t]||{},r&&void 0!==e)null!==this.deletedStates[t][n]&&(this.deletedStates[t][n]=this.deletedStates[t][n]||{},this.deletedStates[t][n][r]=null);else if(void 0!==e){if(this.stateChanges[t]&&this.stateChanges[t][n])for(r in this.deletedStates[t][n]={},this.stateChanges[t][n])this.deletedStates[t][n][r]=null;else this.deletedStates[t][n]=null}else this.deletedStates[t]=null}},cu.prototype.getState=function(t,e){var r=String(e),n=this.state[t]||{},i=this.stateChanges[t]||{},a=u({},n[r],i[r]);if(null===this.deletedStates[t])return{};if(this.deletedStates[t]){var o=this.deletedStates[t][e];if(null===o)return{};for(var s in o)delete a[s]}return a},cu.prototype.initializeTileState=function(t,e){t.setFeatureState(this.state,e)},cu.prototype.coalesceChanges=function(t,e){var r={};for(var n in this.stateChanges){this.state[n]=this.state[n]||{};var i={};for(var a in this.stateChanges[n])this.state[n][a]||(this.state[n][a]={}),u(this.state[n][a],this.stateChanges[n][a]),i[a]=this.state[n][a];r[n]=i}for(var o in this.deletedStates){this.state[o]=this.state[o]||{};var s={};if(null===this.deletedStates[o])for(var l in this.state[o])s[l]={},this.state[o][l]={};else for(var c in this.deletedStates[o]){if(null===this.deletedStates[o][c])this.state[o][c]={};else for(var f=0,h=Object.keys(this.deletedStates[o][c]);f<h.length;f+=1){var p=h[f];delete this.state[o][c][p]}s[c]=this.state[o][c]}r[o]=r[o]||{},u(r[o],s)}if(this.stateChanges={},this.deletedStates={},0!==Object.keys(r).length)for(var d in t){t[d].setFeatureState(r,e)}};var uu=function(t,e){this.tileID=t,this.x=t.canonical.x,this.y=t.canonical.y,this.z=t.canonical.z,this.grid=new zn(8192,16,0),this.grid3D=new zn(8192,16,0),this.featureIndexArray=new fa,this.promoteId=e};function fu(t,e,r,n,i){return v(t,(function(t,a){var o=e instanceof _i?e.get(a):null;return o&&o.evaluate?o.evaluate(r,n,i):o}))}function hu(t){for(var e=1/0,r=1/0,n=-1/0,i=-1/0,a=0,o=t;a<o.length;a+=1){var s=o[a];e=Math.min(e,s.x),r=Math.min(r,s.y),n=Math.max(n,s.x),i=Math.max(i,s.y)}return{minX:e,minY:r,maxX:n,maxY:i}}function pu(t,e){return e-t}uu.prototype.insert=function(t,e,r,n,i,a){var o=this.featureIndexArray.length;this.featureIndexArray.emplaceBack(r,n,i);for(var s=a?this.grid3D:this.grid,l=0;l<e.length;l++){for(var c=e[l],u=[1/0,1/0,-1/0,-1/0],f=0;f<c.length;f++){var h=c[f];u[0]=Math.min(u[0],h.x),u[1]=Math.min(u[1],h.y),u[2]=Math.max(u[2],h.x),u[3]=Math.max(u[3],h.y)}u[0]<8192&&u[1]<8192&&u[2]>=0&&u[3]>=0&&s.insert(o,u[0],u[1],u[2],u[3])}},uu.prototype.loadVTLayers=function(){return this.vtLayers||(this.vtLayers=new Ls.VectorTile(new al(this.rawTileData)).layers,this.sourceLayerCoder=new ou(this.vtLayers?Object.keys(this.vtLayers).sort():[\"_geojsonTileLayer\"])),this.vtLayers},uu.prototype.query=function(t,e,r,n){var a=this;this.loadVTLayers();for(var o=t.params||{},s=8192/t.tileSize/t.scale,l=sn(o.filter),c=t.queryGeometry,u=t.queryPadding*s,f=hu(c),h=this.grid.query(f.minX-u,f.minY-u,f.maxX+u,f.maxY+u),p=hu(t.cameraQueryGeometry),d=this.grid3D.query(p.minX-u,p.minY-u,p.maxX+u,p.maxY+u,(function(e,r,n,a){return function(t,e,r,n,a){for(var o=0,s=t;o<s.length;o+=1){var l=s[o];if(e<=l.x&&r<=l.y&&n>=l.x&&a>=l.y)return!0}var c=[new i(e,r),new i(e,a),new i(n,a),new i(n,r)];if(t.length>2)for(var u=0,f=c;u<f.length;u+=1){if(io(t,f[u]))return!0}for(var h=0;h<t.length-1;h++){if(ao(t[h],t[h+1],c))return!0}return!1}(t.cameraQueryGeometry,e-u,r-u,n+u,a+u)})),m=0,g=d;m<g.length;m+=1){var v=g[m];h.push(v)}h.sort(pu);for(var y,x={},b=function(i){var u=h[i];if(u!==y){y=u;var f=a.featureIndexArray.get(u),p=null;a.loadMatchingFeature(x,f.bucketIndex,f.sourceLayerIndex,f.featureIndex,l,o.layers,o.availableImages,e,r,n,(function(e,r,n){return p||(p=Ya(e)),r.queryIntersectsFeature(c,e,n,p,a.z,t.transform,s,t.pixelPosMatrix)}))}},_=0;_<h.length;_++)b(_);return x},uu.prototype.loadMatchingFeature=function(t,e,r,n,i,a,o,s,l,c,u){var f=this.bucketLayerIDs[e];if(!a||function(t,e){for(var r=0;r<t.length;r++)if(e.indexOf(t[r])>=0)return!0;return!1}(a,f)){var h=this.sourceLayerCoder.decode(r),p=this.vtLayers[h].feature(n);if(i.filter(new pi(this.tileID.overscaledZ),p))for(var d=this.getId(p,h),m=0;m<f.length;m++){var g=f[m];if(!(a&&a.indexOf(g)<0)){var v=s[g];if(v){var y={};void 0!==d&&c&&(y=c.getState(v.sourceLayer||\"_geojsonTileLayer\",d));var x=l[g];x.paint=fu(x.paint,v.paint,p,y,o),x.layout=fu(x.layout,v.layout,p,y,o);var b=!u||u(p,v,y);if(b){var _=new su(p,this.z,this.x,this.y,d);_.layer=x;var w=t[g];void 0===w&&(w=t[g]=[]),w.push({featureIndex:n,feature:_,intersectionZ:b})}}}}}},uu.prototype.lookupSymbolFeatures=function(t,e,r,n,i,a,o,s){var l={};this.loadVTLayers();for(var c=sn(i),u=0,f=t;u<f.length;u+=1){var h=f[u];this.loadMatchingFeature(l,r,n,h,c,a,o,s,e)}return l},uu.prototype.hasLayer=function(t){for(var e=0,r=this.bucketLayerIDs;e<r.length;e+=1)for(var n=0,i=r[e];n<i.length;n+=1){if(t===i[n])return!0}return!1},uu.prototype.getId=function(t,e){var r=t.id;if(this.promoteId){var n=\"string\"==typeof this.promoteId?this.promoteId:this.promoteId[e];\"boolean\"==typeof(r=t.properties[n])&&(r=Number(r))}return r},Nn(\"FeatureIndex\",uu,{omit:[\"rawTileData\",\"sourceLayerCoder\"]});var du=function(t,e){this.tileID=t,this.uid=h(),this.uses=0,this.tileSize=e,this.buckets={},this.expirationTime=null,this.queryPadding=0,this.hasSymbolBuckets=!1,this.hasRTLText=!1,this.dependencies={},this.expiredRequestCount=0,this.state=\"loading\"};du.prototype.registerFadeDuration=function(t){var e=t+this.timeAdded;e<R.now()||this.fadeEndTime&&e<this.fadeEndTime||(this.fadeEndTime=e)},du.prototype.wasRequested=function(){return\"errored\"===this.state||\"loaded\"===this.state||\"reloading\"===this.state},du.prototype.loadVectorData=function(t,e,r){if(this.hasData()&&this.unloadVectorData(),this.state=\"loaded\",t){for(var n in t.featureIndex&&(this.latestFeatureIndex=t.featureIndex,t.rawTileData?(this.latestRawTileData=t.rawTileData,this.latestFeatureIndex.rawTileData=t.rawTileData):this.latestRawTileData&&(this.latestFeatureIndex.rawTileData=this.latestRawTileData)),this.collisionBoxArray=t.collisionBoxArray,this.buckets=function(t,e){var r={};if(!e)return r;for(var n=function(){var t=a[i],n=t.layerIds.map((function(t){return e.getLayer(t)})).filter(Boolean);if(0!==n.length){t.layers=n,t.stateDependentLayerIds&&(t.stateDependentLayers=t.stateDependentLayerIds.map((function(t){return n.filter((function(e){return e.id===t}))[0]})));for(var o=0,s=n;o<s.length;o+=1){var l=s[o];r[l.id]=t}}},i=0,a=t;i<a.length;i+=1)n();return r}(t.buckets,e.style),this.hasSymbolBuckets=!1,this.buckets){var i=this.buckets[n];if(i instanceof Ac){if(this.hasSymbolBuckets=!0,!r)break;i.justReloaded=!0}}if(this.hasRTLText=!1,this.hasSymbolBuckets)for(var a in this.buckets){var o=this.buckets[a];if(o instanceof Ac&&o.hasRTLText){this.hasRTLText=!0,hi.isLoading()||hi.isLoaded()||\"deferred\"!==ui()||fi();break}}for(var s in this.queryPadding=0,this.buckets){var l=this.buckets[s];this.queryPadding=Math.max(this.queryPadding,e.style.getLayer(s).queryRadius(l))}t.imageAtlas&&(this.imageAtlas=t.imageAtlas),t.glyphAtlasImage&&(this.glyphAtlasImage=t.glyphAtlasImage)}else this.collisionBoxArray=new na},du.prototype.unloadVectorData=function(){for(var t in this.buckets)this.buckets[t].destroy();this.buckets={},this.imageAtlasTexture&&this.imageAtlasTexture.destroy(),this.imageAtlas&&(this.imageAtlas=null),this.glyphAtlasTexture&&this.glyphAtlasTexture.destroy(),this.latestFeatureIndex=null,this.state=\"unloaded\"},du.prototype.getBucket=function(t){return this.buckets[t.id]},du.prototype.upload=function(t){for(var e in this.buckets){var r=this.buckets[e];r.uploadPending()&&r.upload(t)}var n=t.gl;this.imageAtlas&&!this.imageAtlas.uploaded&&(this.imageAtlasTexture=new Vc(t,this.imageAtlas.image,n.RGBA),this.imageAtlas.uploaded=!0),this.glyphAtlasImage&&(this.glyphAtlasTexture=new Vc(t,this.glyphAtlasImage,n.ALPHA),this.glyphAtlasImage=null)},du.prototype.prepare=function(t){this.imageAtlas&&this.imageAtlas.patchUpdatedImages(t,this.imageAtlasTexture)},du.prototype.queryRenderedFeatures=function(t,e,r,n,i,a,o,s,l,c){return this.latestFeatureIndex&&this.latestFeatureIndex.rawTileData?this.latestFeatureIndex.query({queryGeometry:n,cameraQueryGeometry:i,scale:a,tileSize:this.tileSize,pixelPosMatrix:c,transform:s,params:o,queryPadding:this.queryPadding*l},t,e,r):{}},du.prototype.querySourceFeatures=function(t,e){var r=this.latestFeatureIndex;if(r&&r.rawTileData){var n=r.loadVTLayers(),i=e?e.sourceLayer:\"\",a=n._geojsonTileLayer||n[i];if(a)for(var o=sn(e&&e.filter),s=this.tileID.canonical,l=s.z,c=s.x,u=s.y,f={z:l,x:c,y:u},h=0;h<a.length;h++){var p=a.feature(h);if(o.filter(new pi(this.tileID.overscaledZ),p)){var d=r.getId(p,i),m=new su(p,l,c,u,d);m.tile=f,t.push(m)}}}},du.prototype.hasData=function(){return\"loaded\"===this.state||\"reloading\"===this.state||\"expired\"===this.state},du.prototype.patternsLoaded=function(){return this.imageAtlas&&!!Object.keys(this.imageAtlas.patternPositions).length},du.prototype.setExpiryData=function(t){var e=this.expirationTime;if(t.cacheControl){var r=M(t.cacheControl);r[\"max-age\"]&&(this.expirationTime=Date.now()+1e3*r[\"max-age\"])}else t.expires&&(this.expirationTime=new Date(t.expires).getTime());if(this.expirationTime){var n=Date.now(),i=!1;if(this.expirationTime>n)i=!1;else if(e)if(this.expirationTime<e)i=!0;else{var a=this.expirationTime-e;a?this.expirationTime=n+Math.max(a,3e4):i=!0}else i=!0;i?(this.expiredRequestCount++,this.state=\"expired\"):this.expiredRequestCount=0}},du.prototype.getExpiryTimeout=function(){if(this.expirationTime)return this.expiredRequestCount?1e3*(1<<Math.min(this.expiredRequestCount-1,31)):Math.min(this.expirationTime-(new Date).getTime(),Math.pow(2,31)-1)},du.prototype.setFeatureState=function(t,e){if(this.latestFeatureIndex&&this.latestFeatureIndex.rawTileData&&0!==Object.keys(t).length){var r=this.latestFeatureIndex.loadVTLayers();for(var n in this.buckets)if(e.style.hasLayer(n)){var i=this.buckets[n],a=i.layers[0].sourceLayer||\"_geojsonTileLayer\",o=r[a],s=t[a];if(o&&s&&0!==Object.keys(s).length){i.update(s,o,this.imageAtlas&&this.imageAtlas.patternPositions||{});var l=e&&e.style&&e.style.getLayer(n);l&&(this.queryPadding=Math.max(this.queryPadding,l.queryRadius(i)))}}}},du.prototype.holdingForFade=function(){return void 0!==this.symbolFadeHoldUntil},du.prototype.symbolFadeFinished=function(){return!this.symbolFadeHoldUntil||this.symbolFadeHoldUntil<R.now()},du.prototype.clearFadeHold=function(){this.symbolFadeHoldUntil=void 0},du.prototype.setHoldDuration=function(t){this.symbolFadeHoldUntil=R.now()+t},du.prototype.setDependencies=function(t,e){for(var r={},n=0,i=e;n<i.length;n+=1){r[i[n]]=!0}this.dependencies[t]=r},du.prototype.hasDependency=function(t,e){for(var r=0,n=t;r<n.length;r+=1){var i=n[r],a=this.dependencies[i];if(a)for(var o=0,s=e;o<s.length;o+=1){if(a[s[o]])return!0}}return!1};var mu=self.performance,gu=function(t){this._marks={start:[t.url,\"start\"].join(\"#\"),end:[t.url,\"end\"].join(\"#\"),measure:t.url.toString()},mu.mark(this._marks.start)};gu.prototype.finish=function(){mu.mark(this._marks.end);var t=mu.getEntriesByName(this._marks.measure);return 0===t.length&&(mu.measure(this._marks.measure,this._marks.start,this._marks.end),t=mu.getEntriesByName(this._marks.measure),mu.clearMarks(this._marks.start),mu.clearMarks(this._marks.end),mu.clearMeasures(this._marks.measure)),t},t.Actor=Hc,t.AlphaImage=So,t.CanonicalTileID=eu,t.CollisionBoxArray=na,t.Color=te,t.DEMData=au,t.DataConstantProperty=wi,t.DictionaryCoder=ou,t.EXTENT=8192,t.ErrorEvent=St,t.EvaluationParameters=pi,t.Event=At,t.Evented=Et,t.FeatureIndex=uu,t.FillBucket=gs,t.FillExtrusionBucket=Os,t.ImageAtlas=Ll,t.ImagePosition=Sl,t.LineBucket=Hs,t.LngLat=Wc,t.LngLatBounds=Yc,t.MercatorCoordinate=tu,t.ONE_EM=24,t.OverscaledTileID=nu,t.Point=i,t.Point$1=i,t.Properties=Si,t.Protobuf=al,t.RGBAImage=Eo,t.RequestManager=q,t.RequestPerformance=gu,t.ResourceType=dt,t.SegmentVector=pa,t.SourceFeatureState=cu,t.StructArrayLayout1ui2=$i,t.StructArrayLayout2f1f2i16=Hi,t.StructArrayLayout2i4=zi,t.StructArrayLayout3ui6=Yi,t.StructArrayLayout4i8=Di,t.SymbolBucket=Ac,t.Texture=Vc,t.Tile=du,t.Transitionable=gi,t.Uniform1f=Sa,t.Uniform1i=Aa,t.Uniform2f=Ea,t.Uniform3f=La,t.Uniform4f=Ca,t.UniformColor=Pa,t.UniformMatrix4f=Oa,t.UnwrappedTileID=ru,t.ValidationError=Ct,t.WritingMode=Cl,t.ZoomHistory=Gn,t.add=function(t,e,r){return t[0]=e[0]+r[0],t[1]=e[1]+r[1],t[2]=e[2]+r[2],t},t.addDynamicAttributes=wc,t.asyncAll=function(t,e,r){if(!t.length)return r(null,[]);var n=t.length,i=new Array(t.length),a=null;t.forEach((function(t,o){e(t,(function(t,e){t&&(a=t),i[o]=e,0==--n&&r(a,i)}))}))},t.bezier=o,t.bindAll=m,t.browser=R,t.cacheEntryPossiblyAdded=function(t){++ht>ot&&(t.getActor().send(\"enforceCacheSizeLimit\",at),ht=0)},t.clamp=l,t.clearTileCache=function(t){var e=self.caches.delete(\"mapbox-tiles\");t&&e.catch(t).then((function(){return t()}))},t.clipLine=ec,t.clone=function(t){var e=new fo(16);return e[0]=t[0],e[1]=t[1],e[2]=t[2],e[3]=t[3],e[4]=t[4],e[5]=t[5],e[6]=t[6],e[7]=t[7],e[8]=t[8],e[9]=t[9],e[10]=t[10],e[11]=t[11],e[12]=t[12],e[13]=t[13],e[14]=t[14],e[15]=t[15],e},t.clone$1=x,t.clone$2=function(t){var e=new fo(3);return e[0]=t[0],e[1]=t[1],e[2]=t[2],e},t.collisionCircleLayout=tl,t.config=F,t.create=function(){var t=new fo(16);return fo!=Float32Array&&(t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[11]=0,t[12]=0,t[13]=0,t[14]=0),t[0]=1,t[5]=1,t[10]=1,t[15]=1,t},t.create$1=function(){var t=new fo(9);return fo!=Float32Array&&(t[1]=0,t[2]=0,t[3]=0,t[5]=0,t[6]=0,t[7]=0),t[0]=1,t[4]=1,t[8]=1,t},t.create$2=function(){var t=new fo(4);return fo!=Float32Array&&(t[1]=0,t[2]=0),t[0]=1,t[3]=1,t},t.createCommonjsModule=e,t.createExpression=Wr,t.createLayout=Ii,t.createStyleLayer=function(t){return\"custom\"===t.type?new Dc(t):new Rc[t.type](t)},t.cross=function(t,e,r){var n=e[0],i=e[1],a=e[2],o=r[0],s=r[1],l=r[2];return t[0]=i*l-a*s,t[1]=a*o-n*l,t[2]=n*s-i*o,t},t.deepEqual=function t(e,r){if(Array.isArray(e)){if(!Array.isArray(r)||e.length!==r.length)return!1;for(var n=0;n<e.length;n++)if(!t(e[n],r[n]))return!1;return!0}if(\"object\"==typeof e&&null!==e&&null!==r){if(\"object\"!=typeof r)return!1;if(Object.keys(e).length!==Object.keys(r).length)return!1;for(var i in e)if(!t(e[i],r[i]))return!1;return!0}return e===r},t.dot=function(t,e){return t[0]*e[0]+t[1]*e[1]+t[2]*e[2]},t.dot$1=function(t,e){return t[0]*e[0]+t[1]*e[1]+t[2]*e[2]+t[3]*e[3]},t.ease=s,t.emitValidationErrors=On,t.endsWith=g,t.enforceCacheSizeLimit=function(t){st(),Q&&Q.then((function(e){e.keys().then((function(r){for(var n=0;n<r.length-t;n++)e.delete(r[n])}))}))},t.evaluateSizeForFeature=Yl,t.evaluateSizeForZoom=Wl,t.evaluateVariableOffset=dc,t.evented=ci,t.extend=u,t.featureFilter=sn,t.filterObject=y,t.fromRotation=function(t,e){var r=Math.sin(e),n=Math.cos(e);return t[0]=n,t[1]=r,t[2]=0,t[3]=-r,t[4]=n,t[5]=0,t[6]=0,t[7]=0,t[8]=1,t},t.getAnchorAlignment=Ul,t.getAnchorJustification=mc,t.getArrayBuffer=xt,t.getImage=Tt,t.getJSON=function(t,e){return yt(u(t,{type:\"json\"}),e)},t.getRTLTextPluginStatus=ui,t.getReferrer=gt,t.getVideo=function(t,e){var r,n,i=self.document.createElement(\"video\");i.muted=!0,i.onloadstart=function(){e(null,i)};for(var a=0;a<t.length;a++){var o=self.document.createElement(\"source\");r=t[a],n=void 0,(n=self.document.createElement(\"a\")).href=r,(n.protocol!==self.document.location.protocol||n.host!==self.document.location.host)&&(i.crossOrigin=\"Anonymous\"),o.src=t[a],i.appendChild(o)}return{cancel:function(){}}},t.identity=ho,t.invert=function(t,e){var r=e[0],n=e[1],i=e[2],a=e[3],o=e[4],s=e[5],l=e[6],c=e[7],u=e[8],f=e[9],h=e[10],p=e[11],d=e[12],m=e[13],g=e[14],v=e[15],y=r*s-n*o,x=r*l-i*o,b=r*c-a*o,_=n*l-i*s,w=n*c-a*s,T=i*c-a*l,k=u*m-f*d,M=u*g-h*d,A=u*v-p*d,S=f*g-h*m,E=f*v-p*m,L=h*v-p*g,C=y*L-x*E+b*S+_*A-w*M+T*k;return C?(C=1/C,t[0]=(s*L-l*E+c*S)*C,t[1]=(i*E-n*L-a*S)*C,t[2]=(m*T-g*w+v*_)*C,t[3]=(h*w-f*T-p*_)*C,t[4]=(l*A-o*L-c*M)*C,t[5]=(r*L-i*A+a*M)*C,t[6]=(g*b-d*T-v*x)*C,t[7]=(u*T-h*b+p*x)*C,t[8]=(o*E-s*A+c*k)*C,t[9]=(n*A-r*E-a*k)*C,t[10]=(d*w-m*b+v*y)*C,t[11]=(f*b-u*w-p*y)*C,t[12]=(s*M-o*S-l*k)*C,t[13]=(r*S-n*M+i*k)*C,t[14]=(m*x-d*_-g*y)*C,t[15]=(u*_-f*x+h*y)*C,t):null},t.isChar=Yn,t.isMapboxURL=H,t.keysDifference=function(t,e){var r=[];for(var n in t)n in e||r.push(n);return r},t.makeRequest=yt,t.mapObject=v,t.mercatorXfromLng=Jc,t.mercatorYfromLat=Kc,t.mercatorZfromAltitude=Qc,t.mul=mo,t.multiply=po,t.mvt=Ls,t.normalize=function(t,e){var r=e[0],n=e[1],i=e[2],a=r*r+n*n+i*i;return a>0&&(a=1/Math.sqrt(a)),t[0]=e[0]*a,t[1]=e[1]*a,t[2]=e[2]*a,t},t.number=He,t.offscreenCanvasSupported=pt,t.ortho=function(t,e,r,n,i,a,o){var s=1/(e-r),l=1/(n-i),c=1/(a-o);return t[0]=-2*s,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=-2*l,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[10]=2*c,t[11]=0,t[12]=(e+r)*s,t[13]=(i+n)*l,t[14]=(o+a)*c,t[15]=1,t},t.parseGlyphPBF=function(t){return new al(t).readFields(Tl,[])},t.pbf=al,t.performSymbolLayout=function(t,e,r,n,i,a,o){t.createArrays();var s=512*t.overscaling;t.tilePixelRatio=8192/s,t.compareText={},t.iconsNeedLinear=!1;var l=t.layers[0].layout,c=t.layers[0]._unevaluatedLayout._values,u={};if(\"composite\"===t.textSizeData.kind){var f=t.textSizeData,h=f.minZoom,p=f.maxZoom;u.compositeTextSizes=[c[\"text-size\"].possiblyEvaluate(new pi(h),o),c[\"text-size\"].possiblyEvaluate(new pi(p),o)]}if(\"composite\"===t.iconSizeData.kind){var d=t.iconSizeData,m=d.minZoom,g=d.maxZoom;u.compositeIconSizes=[c[\"icon-size\"].possiblyEvaluate(new pi(m),o),c[\"icon-size\"].possiblyEvaluate(new pi(g),o)]}u.layoutTextSize=c[\"text-size\"].possiblyEvaluate(new pi(t.zoom+1),o),u.layoutIconSize=c[\"icon-size\"].possiblyEvaluate(new pi(t.zoom+1),o),u.textMaxSize=c[\"text-size\"].possiblyEvaluate(new pi(18));for(var v=24*l.get(\"text-line-height\"),y=\"map\"===l.get(\"text-rotation-alignment\")&&\"point\"!==l.get(\"symbol-placement\"),x=l.get(\"text-keep-upright\"),b=l.get(\"text-size\"),w=function(){var a=k[T],s=l.get(\"text-font\").evaluate(a,{},o).join(\",\"),c=b.evaluate(a,{},o),f=u.layoutTextSize.evaluate(a,{},o),h=u.layoutIconSize.evaluate(a,{},o),p={horizontal:{},vertical:void 0},d=a.text,m=[0,0];if(d){var g=d.toString(),w=24*l.get(\"text-letter-spacing\").evaluate(a,{},o),M=function(t){for(var e=0,r=t;e<r.length;e+=1){if(!Xn(r[e].charCodeAt(0)))return!1}return!0}(g)?w:0,A=l.get(\"text-anchor\").evaluate(a,{},o),S=l.get(\"text-variable-anchor\");if(!S){var E=l.get(\"text-radial-offset\").evaluate(a,{},o);m=E?dc(A,[24*E,pc]):l.get(\"text-offset\").evaluate(a,{},o).map((function(t){return 24*t}))}var L=y?\"center\":l.get(\"text-justify\").evaluate(a,{},o),C=l.get(\"symbol-placement\"),P=\"point\"===C?24*l.get(\"text-max-width\").evaluate(a,{},o):0,I=function(){t.allowVerticalPlacement&&Wn(g)&&(p.vertical=Ol(d,e,r,i,s,P,v,A,\"left\",M,m,Cl.vertical,!0,C,f,c))};if(!y&&S){for(var O=\"auto\"===L?S.map((function(t){return mc(t)})):[L],z=!1,D=0;D<O.length;D++){var R=O[D];if(!p.horizontal[R])if(z)p.horizontal[R]=p.horizontal[0];else{var F=Ol(d,e,r,i,s,P,v,\"center\",R,M,m,Cl.horizontal,!1,C,f,c);F&&(p.horizontal[R]=F,z=1===F.positionedLines.length)}}I()}else{\"auto\"===L&&(L=mc(A));var B=Ol(d,e,r,i,s,P,v,A,L,M,m,Cl.horizontal,!1,C,f,c);B&&(p.horizontal[L]=B),I(),Wn(g)&&y&&x&&(p.vertical=Ol(d,e,r,i,s,P,v,A,L,M,m,Cl.vertical,!1,C,f,c))}}var N=void 0,j=!1;if(a.icon&&a.icon.name){var U=n[a.icon.name];U&&(N=function(t,e,r){var n=Ul(r),i=n.horizontalAlign,a=n.verticalAlign,o=e[0],s=e[1],l=o-t.displaySize[0]*i,c=l+t.displaySize[0],u=s-t.displaySize[1]*a;return{image:t,top:u,bottom:u+t.displaySize[1],left:l,right:c}}(i[a.icon.name],l.get(\"icon-offset\").evaluate(a,{},o),l.get(\"icon-anchor\").evaluate(a,{},o)),j=U.sdf,void 0===t.sdfIcons?t.sdfIcons=U.sdf:t.sdfIcons!==U.sdf&&_(\"Style sheet warning: Cannot mix SDF and non-SDF icons in one buffer\"),(U.pixelRatio!==t.pixelRatio||0!==l.get(\"icon-rotate\").constantOr(1))&&(t.iconsNeedLinear=!0))}var V=vc(p.horizontal)||p.vertical;t.iconsInText=!!V&&V.iconsInText,(V||N)&&function(t,e,r,n,i,a,o,s,l,c,u){var f=a.textMaxSize.evaluate(e,{});void 0===f&&(f=o);var h,p=t.layers[0].layout,d=p.get(\"icon-offset\").evaluate(e,{},u),m=vc(r.horizontal),g=o/24,v=t.tilePixelRatio*g,y=t.tilePixelRatio*f/24,x=t.tilePixelRatio*s,b=t.tilePixelRatio*p.get(\"symbol-spacing\"),w=p.get(\"text-padding\")*t.tilePixelRatio,T=p.get(\"icon-padding\")*t.tilePixelRatio,k=p.get(\"text-max-angle\")/180*Math.PI,M=\"map\"===p.get(\"text-rotation-alignment\")&&\"point\"!==p.get(\"symbol-placement\"),A=\"map\"===p.get(\"icon-rotation-alignment\")&&\"point\"!==p.get(\"symbol-placement\"),S=p.get(\"symbol-placement\"),E=b/2,L=p.get(\"icon-text-fit\");n&&\"none\"!==L&&(t.allowVerticalPlacement&&r.vertical&&(h=ql(n,r.vertical,L,p.get(\"icon-text-fit-padding\"),d,g)),m&&(n=ql(n,m,L,p.get(\"icon-text-fit-padding\"),d,g)));var C=function(s,f){f.x<0||f.x>=8192||f.y<0||f.y>=8192||function(t,e,r,n,i,a,o,s,l,c,u,f,h,p,d,m,g,v,y,x,b,w,T,k,M){var A,S,E,L,C,P=t.addToLineVertexArray(e,r),I=0,O=0,z=0,D=0,R=-1,F=-1,B={},N=ya(\"\"),j=0,U=0;void 0===s._unevaluatedLayout.getValue(\"text-radial-offset\")?(A=s.layout.get(\"text-offset\").evaluate(b,{},k).map((function(t){return 24*t})),j=A[0],U=A[1]):(j=24*s.layout.get(\"text-radial-offset\").evaluate(b,{},k),U=pc);if(t.allowVerticalPlacement&&n.vertical){var V=s.layout.get(\"text-rotate\").evaluate(b,{},k)+90,q=n.vertical;L=new sc(l,e,c,u,f,q,h,p,d,V),o&&(C=new sc(l,e,c,u,f,o,g,v,d,V))}if(i){var H=s.layout.get(\"icon-rotate\").evaluate(b,{}),G=\"none\"!==s.layout.get(\"icon-text-fit\"),Y=rc(i,H,T,G),W=o?rc(o,H,T,G):void 0;E=new sc(l,e,c,u,f,i,g,v,!1,H),I=4*Y.length;var X=t.iconSizeData,Z=null;\"source\"===X.kind?(Z=[128*s.layout.get(\"icon-size\").evaluate(b,{})])[0]>32640&&_(t.layerIds[0]+': Value for \"icon-size\" is >= 255. Reduce your \"icon-size\".'):\"composite\"===X.kind&&((Z=[128*w.compositeIconSizes[0].evaluate(b,{},k),128*w.compositeIconSizes[1].evaluate(b,{},k)])[0]>32640||Z[1]>32640)&&_(t.layerIds[0]+': Value for \"icon-size\" is >= 255. Reduce your \"icon-size\".'),t.addSymbols(t.icon,Y,Z,x,y,b,!1,e,P.lineStartIndex,P.lineLength,-1,k),R=t.icon.placedSymbolArray.length-1,W&&(O=4*W.length,t.addSymbols(t.icon,W,Z,x,y,b,Cl.vertical,e,P.lineStartIndex,P.lineLength,-1,k),F=t.icon.placedSymbolArray.length-1)}for(var J in n.horizontal){var K=n.horizontal[J];if(!S){N=ya(K.text);var Q=s.layout.get(\"text-rotate\").evaluate(b,{},k);S=new sc(l,e,c,u,f,K,h,p,d,Q)}var $=1===K.positionedLines.length;if(z+=gc(t,e,K,a,s,d,b,m,P,n.vertical?Cl.horizontal:Cl.horizontalOnly,$?Object.keys(n.horizontal):[J],B,R,w,k),$)break}n.vertical&&(D+=gc(t,e,n.vertical,a,s,d,b,m,P,Cl.vertical,[\"vertical\"],B,F,w,k));var tt=S?S.boxStartIndex:t.collisionBoxArray.length,et=S?S.boxEndIndex:t.collisionBoxArray.length,rt=L?L.boxStartIndex:t.collisionBoxArray.length,nt=L?L.boxEndIndex:t.collisionBoxArray.length,it=E?E.boxStartIndex:t.collisionBoxArray.length,at=E?E.boxEndIndex:t.collisionBoxArray.length,ot=C?C.boxStartIndex:t.collisionBoxArray.length,st=C?C.boxEndIndex:t.collisionBoxArray.length,lt=-1,ct=function(t,e){return t&&t.circleDiameter?Math.max(t.circleDiameter,e):e};lt=ct(S,lt),lt=ct(L,lt),lt=ct(E,lt);var ut=(lt=ct(C,lt))>-1?1:0;ut&&(lt*=M/24);t.glyphOffsetArray.length>=Ac.MAX_GLYPHS&&_(\"Too many glyphs being rendered in a tile. See https://github.com/mapbox/mapbox-gl-js/issues/2907\");void 0!==b.sortKey&&t.addToSortKeyRanges(t.symbolInstances.length,b.sortKey);t.symbolInstances.emplaceBack(e.x,e.y,B.right>=0?B.right:-1,B.center>=0?B.center:-1,B.left>=0?B.left:-1,B.vertical||-1,R,F,N,tt,et,rt,nt,it,at,ot,st,c,z,D,I,O,ut,0,h,j,U,lt)}(t,f,s,r,n,i,h,t.layers[0],t.collisionBoxArray,e.index,e.sourceLayerIndex,t.index,v,w,M,l,x,T,A,d,e,a,c,u,o)};if(\"line\"===S)for(var P=0,I=ec(e.geometry,0,0,8192,8192);P<I.length;P+=1)for(var O=I[P],z=tc(O,b,k,r.vertical||m,n,24,y,t.overscaling,8192),D=0,R=z;D<R.length;D+=1){var F=R[D],B=m;B&&yc(t,B.text,E,F)||C(O,F)}else if(\"line-center\"===S)for(var N=0,j=e.geometry;N<j.length;N+=1){var U=j[N];if(U.length>1){var V=$l(U,k,r.vertical||m,n,24,y);V&&C(U,V)}}else if(\"Polygon\"===e.type)for(var q=0,H=hs(e.geometry,0);q<H.length;q+=1){var G=H[q],Y=uc(G,16);C(G[0],new Hl(Y.x,Y.y,0))}else if(\"LineString\"===e.type)for(var W=0,X=e.geometry;W<X.length;W+=1){var Z=X[W];C(Z,new Hl(Z[0].x,Z[0].y,0))}else if(\"Point\"===e.type)for(var J=0,K=e.geometry;J<K.length;J+=1)for(var Q=K[J],$=0,tt=Q;$<tt.length;$+=1){var et=tt[$];C([et],new Hl(et.x,et.y,0))}}(t,a,p,N,n,u,f,h,m,j,o)},T=0,k=t.features;T<k.length;T+=1)w();a&&t.generateCollisionDebugBuffers()},t.perspective=function(t,e,r,n,i){var a,o=1/Math.tan(e/2);return t[0]=o/r,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=o,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[11]=-1,t[12]=0,t[13]=0,t[15]=0,null!=i&&i!==1/0?(a=1/(n-i),t[10]=(i+n)*a,t[14]=2*i*n*a):(t[10]=-1,t[14]=-2*n),t},t.pick=function(t,e){for(var r={},n=0;n<e.length;n++){var i=e[n];i in t&&(r[i]=t[i])}return r},t.plugin=hi,t.polygonIntersectsPolygon=Za,t.postMapLoadEvent=it,t.postTurnstileEvent=rt,t.potpack=Al,t.refProperties=[\"type\",\"source\",\"source-layer\",\"minzoom\",\"maxzoom\",\"filter\",\"layout\"],t.register=Nn,t.registerForPluginStateChange=function(t){return t({pluginStatus:ai,pluginURL:oi}),ci.on(\"pluginStateChange\",t),t},t.rotate=function(t,e,r){var n=e[0],i=e[1],a=e[2],o=e[3],s=Math.sin(r),l=Math.cos(r);return t[0]=n*l+a*s,t[1]=i*l+o*s,t[2]=n*-s+a*l,t[3]=i*-s+o*l,t},t.rotateX=function(t,e,r){var n=Math.sin(r),i=Math.cos(r),a=e[4],o=e[5],s=e[6],l=e[7],c=e[8],u=e[9],f=e[10],h=e[11];return e!==t&&(t[0]=e[0],t[1]=e[1],t[2]=e[2],t[3]=e[3],t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15]),t[4]=a*i+c*n,t[5]=o*i+u*n,t[6]=s*i+f*n,t[7]=l*i+h*n,t[8]=c*i-a*n,t[9]=u*i-o*n,t[10]=f*i-s*n,t[11]=h*i-l*n,t},t.rotateZ=function(t,e,r){var n=Math.sin(r),i=Math.cos(r),a=e[0],o=e[1],s=e[2],l=e[3],c=e[4],u=e[5],f=e[6],h=e[7];return e!==t&&(t[8]=e[8],t[9]=e[9],t[10]=e[10],t[11]=e[11],t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15]),t[0]=a*i+c*n,t[1]=o*i+u*n,t[2]=s*i+f*n,t[3]=l*i+h*n,t[4]=c*i-a*n,t[5]=u*i-o*n,t[6]=f*i-s*n,t[7]=h*i-l*n,t},t.scale=function(t,e,r){var n=r[0],i=r[1],a=r[2];return t[0]=e[0]*n,t[1]=e[1]*n,t[2]=e[2]*n,t[3]=e[3]*n,t[4]=e[4]*i,t[5]=e[5]*i,t[6]=e[6]*i,t[7]=e[7]*i,t[8]=e[8]*a,t[9]=e[9]*a,t[10]=e[10]*a,t[11]=e[11]*a,t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15],t},t.scale$1=function(t,e,r){return t[0]=e[0]*r,t[1]=e[1]*r,t[2]=e[2]*r,t[3]=e[3]*r,t},t.scale$2=function(t,e,r){return t[0]=e[0]*r,t[1]=e[1]*r,t[2]=e[2]*r,t},t.setCacheLimits=function(t,e){at=t,ot=e},t.setRTLTextPlugin=function(t,e,r){if(void 0===r&&(r=!1),ai===ti||ai===ei||ai===ri)throw new Error(\"setRTLTextPlugin cannot be called multiple times.\");oi=R.resolveURL(t),ai=ti,ii=e,li(),r||fi()},t.sphericalToCartesian=function(t){var e=t[0],r=t[1],n=t[2];return r+=90,r*=Math.PI/180,n*=Math.PI/180,{x:e*Math.cos(r)*Math.sin(n),y:e*Math.sin(r)*Math.sin(n),z:e*Math.cos(n)}},t.sqrLen=bo,t.styleSpec=Lt,t.sub=yo,t.symbolSize=Xl,t.transformMat3=function(t,e,r){var n=e[0],i=e[1],a=e[2];return t[0]=n*r[0]+i*r[3]+a*r[6],t[1]=n*r[1]+i*r[4]+a*r[7],t[2]=n*r[2]+i*r[5]+a*r[8],t},t.transformMat4=xo,t.translate=function(t,e,r){var n,i,a,o,s,l,c,u,f,h,p,d,m=r[0],g=r[1],v=r[2];return e===t?(t[12]=e[0]*m+e[4]*g+e[8]*v+e[12],t[13]=e[1]*m+e[5]*g+e[9]*v+e[13],t[14]=e[2]*m+e[6]*g+e[10]*v+e[14],t[15]=e[3]*m+e[7]*g+e[11]*v+e[15]):(n=e[0],i=e[1],a=e[2],o=e[3],s=e[4],l=e[5],c=e[6],u=e[7],f=e[8],h=e[9],p=e[10],d=e[11],t[0]=n,t[1]=i,t[2]=a,t[3]=o,t[4]=s,t[5]=l,t[6]=c,t[7]=u,t[8]=f,t[9]=h,t[10]=p,t[11]=d,t[12]=n*m+s*g+f*v+e[12],t[13]=i*m+l*g+h*v+e[13],t[14]=a*m+c*g+p*v+e[14],t[15]=o*m+u*g+d*v+e[15]),t},t.triggerPluginCompletionEvent=si,t.uniqueId=h,t.validateCustomStyleLayer=function(t){var e=[],r=t.id;return void 0===r&&e.push({message:\"layers.\"+r+': missing required property \"id\"'}),void 0===t.render&&e.push({message:\"layers.\"+r+': missing required method \"render\"'}),t.renderingMode&&\"2d\"!==t.renderingMode&&\"3d\"!==t.renderingMode&&e.push({message:\"layers.\"+r+': property \"renderingMode\" must be either \"2d\" or \"3d\"'}),e},t.validateLight=Cn,t.validateStyle=Ln,t.values=function(t){var e=[];for(var r in t)e.push(t[r]);return e},t.vectorTile=Ls,t.version=\"1.10.1\",t.warnOnce=_,t.webpSupported=B,t.window=self,t.wrap=c})),n(0,(function(t){function e(t){var r=typeof t;if(\"number\"===r||\"boolean\"===r||\"string\"===r||null==t)return JSON.stringify(t);if(Array.isArray(t)){for(var n=\"[\",i=0,a=t;i<a.length;i+=1){n+=e(a[i])+\",\"}return n+\"]\"}for(var o=Object.keys(t).sort(),s=\"{\",l=0;l<o.length;l++)s+=JSON.stringify(o[l])+\":\"+e(t[o[l]])+\",\";return s+\"}\"}function r(r){for(var n=\"\",i=0,a=t.refProperties;i<a.length;i+=1){n+=\"/\"+e(r[a[i]])}return n}var n=function(t){this.keyCache={},t&&this.replace(t)};n.prototype.replace=function(t){this._layerConfigs={},this._layers={},this.update(t,[])},n.prototype.update=function(e,n){for(var i=this,a=0,o=e;a<o.length;a+=1){var s=o[a];this._layerConfigs[s.id]=s;var l=this._layers[s.id]=t.createStyleLayer(s);l._featureFilter=t.featureFilter(l.filter),this.keyCache[s.id]&&delete this.keyCache[s.id]}for(var c=0,u=n;c<u.length;c+=1){var f=u[c];delete this.keyCache[f],delete this._layerConfigs[f],delete this._layers[f]}this.familiesBySource={};for(var h=0,p=function(t,e){for(var n={},i=0;i<t.length;i++){var a=e&&e[t[i].id]||r(t[i]);e&&(e[t[i].id]=a);var o=n[a];o||(o=n[a]=[]),o.push(t[i])}var s=[];for(var l in n)s.push(n[l]);return s}(t.values(this._layerConfigs),this.keyCache);h<p.length;h+=1){var d=p[h].map((function(t){return i._layers[t.id]})),m=d[0];if(\"none\"!==m.visibility){var g=m.source||\"\",v=this.familiesBySource[g];v||(v=this.familiesBySource[g]={});var y=m.sourceLayer||\"_geojsonTileLayer\",x=v[y];x||(x=v[y]=[]),x.push(d)}}};var i=function(e){var r={},n=[];for(var i in e){var a=e[i],o=r[i]={};for(var s in a){var l=a[+s];if(l&&0!==l.bitmap.width&&0!==l.bitmap.height){var c={x:0,y:0,w:l.bitmap.width+2,h:l.bitmap.height+2};n.push(c),o[s]={rect:c,metrics:l.metrics}}}}var u=t.potpack(n),f=u.w,h=u.h,p=new t.AlphaImage({width:f||1,height:h||1});for(var d in e){var m=e[d];for(var g in m){var v=m[+g];if(v&&0!==v.bitmap.width&&0!==v.bitmap.height){var y=r[d][g].rect;t.AlphaImage.copy(v.bitmap,p,{x:0,y:0},{x:y.x+1,y:y.y+1},v.bitmap)}}}this.image=p,this.positions=r};t.register(\"GlyphAtlas\",i);var a=function(e){this.tileID=new t.OverscaledTileID(e.tileID.overscaledZ,e.tileID.wrap,e.tileID.canonical.z,e.tileID.canonical.x,e.tileID.canonical.y),this.uid=e.uid,this.zoom=e.zoom,this.pixelRatio=e.pixelRatio,this.tileSize=e.tileSize,this.source=e.source,this.overscaling=this.tileID.overscaleFactor(),this.showCollisionBoxes=e.showCollisionBoxes,this.collectResourceTiming=!!e.collectResourceTiming,this.returnDependencies=!!e.returnDependencies,this.promoteId=e.promoteId};function o(e,r,n){for(var i=new t.EvaluationParameters(r),a=0,o=e;a<o.length;a+=1){o[a].recalculate(i,n)}}function s(e,r){var n=t.getArrayBuffer(e.request,(function(e,n,i,a){e?r(e):n&&r(null,{vectorTile:new t.vectorTile.VectorTile(new t.pbf(n)),rawData:n,cacheControl:i,expires:a})}));return function(){n.cancel(),r()}}a.prototype.parse=function(e,r,n,a,s){var l=this;this.status=\"parsing\",this.data=e,this.collisionBoxArray=new t.CollisionBoxArray;var c=new t.DictionaryCoder(Object.keys(e.layers).sort()),u=new t.FeatureIndex(this.tileID,this.promoteId);u.bucketLayerIDs=[];var f,h,p,d,m={},g={featureIndex:u,iconDependencies:{},patternDependencies:{},glyphDependencies:{},availableImages:n},v=r.familiesBySource[this.source];for(var y in v){var x=e.layers[y];if(x){1===x.version&&t.warnOnce('Vector tile source \"'+this.source+'\" layer \"'+y+'\" does not use vector tile spec v2 and therefore may have some rendering errors.');for(var b=c.encode(y),_=[],w=0;w<x.length;w++){var T=x.feature(w),k=u.getId(T,y);_.push({feature:T,id:k,index:w,sourceLayerIndex:b})}for(var M=0,A=v[y];M<A.length;M+=1){var S=A[M],E=S[0];if(!(E.minzoom&&this.zoom<Math.floor(E.minzoom)))if(!(E.maxzoom&&this.zoom>=E.maxzoom))if(\"none\"!==E.visibility)o(S,this.zoom,n),(m[E.id]=E.createBucket({index:u.bucketLayerIDs.length,layers:S,zoom:this.zoom,pixelRatio:this.pixelRatio,overscaling:this.overscaling,collisionBoxArray:this.collisionBoxArray,sourceLayerIndex:b,sourceID:this.source})).populate(_,g,this.tileID.canonical),u.bucketLayerIDs.push(S.map((function(t){return t.id})))}}}var L=t.mapObject(g.glyphDependencies,(function(t){return Object.keys(t).map(Number)}));Object.keys(L).length?a.send(\"getGlyphs\",{uid:this.uid,stacks:L},(function(t,e){f||(f=t,h=e,I.call(l))})):h={};var C=Object.keys(g.iconDependencies);C.length?a.send(\"getImages\",{icons:C,source:this.source,tileID:this.tileID,type:\"icons\"},(function(t,e){f||(f=t,p=e,I.call(l))})):p={};var P=Object.keys(g.patternDependencies);function I(){if(f)return s(f);if(h&&p&&d){var e=new i(h),r=new t.ImageAtlas(p,d);for(var a in m){var l=m[a];l instanceof t.SymbolBucket?(o(l.layers,this.zoom,n),t.performSymbolLayout(l,h,e.positions,p,r.iconPositions,this.showCollisionBoxes,this.tileID.canonical)):l.hasPattern&&(l instanceof t.LineBucket||l instanceof t.FillBucket||l instanceof t.FillExtrusionBucket)&&(o(l.layers,this.zoom,n),l.addFeatures(g,this.tileID.canonical,r.patternPositions))}this.status=\"done\",s(null,{buckets:t.values(m).filter((function(t){return!t.isEmpty()})),featureIndex:u,collisionBoxArray:this.collisionBoxArray,glyphAtlasImage:e.image,imageAtlas:r,glyphMap:this.returnDependencies?h:null,iconMap:this.returnDependencies?p:null,glyphPositions:this.returnDependencies?e.positions:null})}}P.length?a.send(\"getImages\",{icons:P,source:this.source,tileID:this.tileID,type:\"patterns\"},(function(t,e){f||(f=t,d=e,I.call(l))})):d={},I.call(this)};var l=function(t,e,r,n){this.actor=t,this.layerIndex=e,this.availableImages=r,this.loadVectorData=n||s,this.loading={},this.loaded={}};l.prototype.loadTile=function(e,r){var n=this,i=e.uid;this.loading||(this.loading={});var o=!!(e&&e.request&&e.request.collectResourceTiming)&&new t.RequestPerformance(e.request),s=this.loading[i]=new a(e);s.abort=this.loadVectorData(e,(function(e,a){if(delete n.loading[i],e||!a)return s.status=\"done\",n.loaded[i]=s,r(e);var l=a.rawData,c={};a.expires&&(c.expires=a.expires),a.cacheControl&&(c.cacheControl=a.cacheControl);var u={};if(o){var f=o.finish();f&&(u.resourceTiming=JSON.parse(JSON.stringify(f)))}s.vectorTile=a.vectorTile,s.parse(a.vectorTile,n.layerIndex,n.availableImages,n.actor,(function(e,n){if(e||!n)return r(e);r(null,t.extend({rawTileData:l.slice(0)},n,c,u))})),n.loaded=n.loaded||{},n.loaded[i]=s}))},l.prototype.reloadTile=function(t,e){var r=this,n=this.loaded,i=t.uid,a=this;if(n&&n[i]){var o=n[i];o.showCollisionBoxes=t.showCollisionBoxes;var s=function(t,n){var i=o.reloadCallback;i&&(delete o.reloadCallback,o.parse(o.vectorTile,a.layerIndex,r.availableImages,a.actor,i)),e(t,n)};\"parsing\"===o.status?o.reloadCallback=s:\"done\"===o.status&&(o.vectorTile?o.parse(o.vectorTile,this.layerIndex,this.availableImages,this.actor,s):s())}},l.prototype.abortTile=function(t,e){var r=this.loading,n=t.uid;r&&r[n]&&r[n].abort&&(r[n].abort(),delete r[n]),e()},l.prototype.removeTile=function(t,e){var r=this.loaded,n=t.uid;r&&r[n]&&delete r[n],e()};var c=t.window.ImageBitmap,u=function(){this.loaded={}};u.prototype.loadTile=function(e,r){var n=e.uid,i=e.encoding,a=e.rawImageData,o=c&&a instanceof c?this.getImageData(a):a,s=new t.DEMData(n,o,i);this.loaded=this.loaded||{},this.loaded[n]=s,r(null,s)},u.prototype.getImageData=function(e){this.offscreenCanvas&&this.offscreenCanvasContext||(this.offscreenCanvas=new OffscreenCanvas(e.width,e.height),this.offscreenCanvasContext=this.offscreenCanvas.getContext(\"2d\")),this.offscreenCanvas.width=e.width,this.offscreenCanvas.height=e.height,this.offscreenCanvasContext.drawImage(e,0,0,e.width,e.height);var r=this.offscreenCanvasContext.getImageData(-1,-1,e.width+2,e.height+2);return this.offscreenCanvasContext.clearRect(0,0,this.offscreenCanvas.width,this.offscreenCanvas.height),new t.RGBAImage({width:r.width,height:r.height},r.data)},u.prototype.removeTile=function(t){var e=this.loaded,r=t.uid;e&&e[r]&&delete e[r]};var f=function t(e,r){var n,i=e&&e.type;if(\"FeatureCollection\"===i)for(n=0;n<e.features.length;n++)t(e.features[n],r);else if(\"GeometryCollection\"===i)for(n=0;n<e.geometries.length;n++)t(e.geometries[n],r);else if(\"Feature\"===i)t(e.geometry,r);else if(\"Polygon\"===i)h(e.coordinates,r);else if(\"MultiPolygon\"===i)for(n=0;n<e.coordinates.length;n++)h(e.coordinates[n],r);return e};function h(t,e){if(0!==t.length){p(t[0],e);for(var r=1;r<t.length;r++)p(t[r],!e)}}function p(t,e){for(var r=0,n=0,i=t.length,a=i-1;n<i;a=n++)r+=(t[n][0]-t[a][0])*(t[a][1]+t[n][1]);r>=0!=!!e&&t.reverse()}var d=t.vectorTile.VectorTileFeature.prototype.toGeoJSON,m=function(e){this._feature=e,this.extent=t.EXTENT,this.type=e.type,this.properties=e.tags,\"id\"in e&&!isNaN(e.id)&&(this.id=parseInt(e.id,10))};m.prototype.loadGeometry=function(){if(1===this._feature.type){for(var e=[],r=0,n=this._feature.geometry;r<n.length;r+=1){var i=n[r];e.push([new t.Point$1(i[0],i[1])])}return e}for(var a=[],o=0,s=this._feature.geometry;o<s.length;o+=1){for(var l=[],c=0,u=s[o];c<u.length;c+=1){var f=u[c];l.push(new t.Point$1(f[0],f[1]))}a.push(l)}return a},m.prototype.toGeoJSON=function(t,e,r){return d.call(this,t,e,r)};var g=function(e){this.layers={_geojsonTileLayer:this},this.name=\"_geojsonTileLayer\",this.extent=t.EXTENT,this.length=e.length,this._features=e};g.prototype.feature=function(t){return new m(this._features[t])};var v=t.vectorTile.VectorTileFeature,y=x;function x(t,e){this.options=e||{},this.features=t,this.length=t.length}function b(t,e){this.id=\"number\"==typeof t.id?t.id:void 0,this.type=t.type,this.rawGeometry=1===t.type?[t.geometry]:t.geometry,this.properties=t.tags,this.extent=e||4096}x.prototype.feature=function(t){return new b(this.features[t],this.options.extent)},b.prototype.loadGeometry=function(){var e=this.rawGeometry;this.geometry=[];for(var r=0;r<e.length;r++){for(var n=e[r],i=[],a=0;a<n.length;a++)i.push(new t.Point$1(n[a][0],n[a][1]));this.geometry.push(i)}return this.geometry},b.prototype.bbox=function(){this.geometry||this.loadGeometry();for(var t=this.geometry,e=1/0,r=-1/0,n=1/0,i=-1/0,a=0;a<t.length;a++)for(var o=t[a],s=0;s<o.length;s++){var l=o[s];e=Math.min(e,l.x),r=Math.max(r,l.x),n=Math.min(n,l.y),i=Math.max(i,l.y)}return[e,n,r,i]},b.prototype.toGeoJSON=v.prototype.toGeoJSON;var _=M,w=M,T=function(t,e){e=e||{};var r={};for(var n in t)r[n]=new y(t[n].features,e),r[n].name=n,r[n].version=e.version,r[n].extent=e.extent;return M({layers:r})},k=y;function M(e){var r=new t.pbf;return function(t,e){for(var r in t.layers)e.writeMessage(3,A,t.layers[r])}(e,r),r.finish()}function A(t,e){var r;e.writeVarintField(15,t.version||1),e.writeStringField(1,t.name||\"\"),e.writeVarintField(5,t.extent||4096);var n={keys:[],values:[],keycache:{},valuecache:{}};for(r=0;r<t.length;r++)n.feature=t.feature(r),e.writeMessage(2,S,n);var i=n.keys;for(r=0;r<i.length;r++)e.writeStringField(3,i[r]);var a=n.values;for(r=0;r<a.length;r++)e.writeMessage(4,I,a[r])}function S(t,e){var r=t.feature;void 0!==r.id&&e.writeVarintField(1,r.id),e.writeMessage(2,E,t),e.writeVarintField(3,r.type),e.writeMessage(4,P,r)}function E(t,e){var r=t.feature,n=t.keys,i=t.values,a=t.keycache,o=t.valuecache;for(var s in r.properties){var l=a[s];void 0===l&&(n.push(s),l=n.length-1,a[s]=l),e.writeVarint(l);var c=r.properties[s],u=typeof c;\"string\"!==u&&\"boolean\"!==u&&\"number\"!==u&&(c=JSON.stringify(c));var f=u+\":\"+c,h=o[f];void 0===h&&(i.push(c),h=i.length-1,o[f]=h),e.writeVarint(h)}}function L(t,e){return(e<<3)+(7&t)}function C(t){return t<<1^t>>31}function P(t,e){for(var r=t.loadGeometry(),n=t.type,i=0,a=0,o=r.length,s=0;s<o;s++){var l=r[s],c=1;1===n&&(c=l.length),e.writeVarint(L(1,c));for(var u=3===n?l.length-1:l.length,f=0;f<u;f++){1===f&&1!==n&&e.writeVarint(L(2,u-1));var h=l[f].x-i,p=l[f].y-a;e.writeVarint(C(h)),e.writeVarint(C(p)),i+=h,a+=p}3===n&&e.writeVarint(L(7,1))}}function I(t,e){var r=typeof t;\"string\"===r?e.writeStringField(1,t):\"boolean\"===r?e.writeBooleanField(7,t):\"number\"===r&&(t%1!=0?e.writeDoubleField(3,t):t<0?e.writeSVarintField(6,t):e.writeVarintField(5,t))}function O(t,e,r,n,i,a){if(!(i-n<=r)){var o=n+i>>1;!function t(e,r,n,i,a,o){for(;a>i;){if(a-i>600){var s=a-i+1,l=n-i+1,c=Math.log(s),u=.5*Math.exp(2*c/3),f=.5*Math.sqrt(c*u*(s-u)/s)*(l-s/2<0?-1:1),h=Math.max(i,Math.floor(n-l*u/s+f)),p=Math.min(a,Math.floor(n+(s-l)*u/s+f));t(e,r,n,h,p,o)}var d=r[2*n+o],m=i,g=a;for(z(e,r,i,n),r[2*a+o]>d&&z(e,r,i,a);m<g;){for(z(e,r,m,g),m++,g--;r[2*m+o]<d;)m++;for(;r[2*g+o]>d;)g--}r[2*i+o]===d?z(e,r,i,g):(g++,z(e,r,g,a)),g<=n&&(i=g+1),n<=g&&(a=g-1)}}(t,e,o,n,i,a%2),O(t,e,r,n,o-1,a+1),O(t,e,r,o+1,i,a+1)}}function z(t,e,r,n){D(t,r,n),D(e,2*r,2*n),D(e,2*r+1,2*n+1)}function D(t,e,r){var n=t[e];t[e]=t[r],t[r]=n}function R(t,e,r,n){var i=t-r,a=e-n;return i*i+a*a}_.fromVectorTileJs=w,_.fromGeojsonVt=T,_.GeoJSONWrapper=k;var F=function(t){return t[0]},B=function(t){return t[1]},N=function(t,e,r,n,i){void 0===e&&(e=F),void 0===r&&(r=B),void 0===n&&(n=64),void 0===i&&(i=Float64Array),this.nodeSize=n,this.points=t;for(var a=t.length<65536?Uint16Array:Uint32Array,o=this.ids=new a(t.length),s=this.coords=new i(2*t.length),l=0;l<t.length;l++)o[l]=l,s[2*l]=e(t[l]),s[2*l+1]=r(t[l]);O(o,s,n,0,o.length-1,0)};N.prototype.range=function(t,e,r,n){return function(t,e,r,n,i,a,o){for(var s,l,c=[0,t.length-1,0],u=[];c.length;){var f=c.pop(),h=c.pop(),p=c.pop();if(h-p<=o)for(var d=p;d<=h;d++)s=e[2*d],l=e[2*d+1],s>=r&&s<=i&&l>=n&&l<=a&&u.push(t[d]);else{var m=Math.floor((p+h)/2);s=e[2*m],l=e[2*m+1],s>=r&&s<=i&&l>=n&&l<=a&&u.push(t[m]);var g=(f+1)%2;(0===f?r<=s:n<=l)&&(c.push(p),c.push(m-1),c.push(g)),(0===f?i>=s:a>=l)&&(c.push(m+1),c.push(h),c.push(g))}}return u}(this.ids,this.coords,t,e,r,n,this.nodeSize)},N.prototype.within=function(t,e,r){return function(t,e,r,n,i,a){for(var o=[0,t.length-1,0],s=[],l=i*i;o.length;){var c=o.pop(),u=o.pop(),f=o.pop();if(u-f<=a)for(var h=f;h<=u;h++)R(e[2*h],e[2*h+1],r,n)<=l&&s.push(t[h]);else{var p=Math.floor((f+u)/2),d=e[2*p],m=e[2*p+1];R(d,m,r,n)<=l&&s.push(t[p]);var g=(c+1)%2;(0===c?r-i<=d:n-i<=m)&&(o.push(f),o.push(p-1),o.push(g)),(0===c?r+i>=d:n+i>=m)&&(o.push(p+1),o.push(u),o.push(g))}}return s}(this.ids,this.coords,t,e,r,this.nodeSize)};var j={minZoom:0,maxZoom:16,radius:40,extent:512,nodeSize:64,log:!1,generateId:!1,reduce:null,map:function(t){return t}},U=function(t){this.options=X(Object.create(j),t),this.trees=new Array(this.options.maxZoom+1)};function V(t,e,r,n,i){return{x:t,y:e,zoom:1/0,id:r,parentId:-1,numPoints:n,properties:i}}function q(t,e){var r=t.geometry.coordinates,n=r[0],i=r[1];return{x:Y(n),y:W(i),zoom:1/0,index:e,parentId:-1}}function H(t){return{type:\"Feature\",id:t.id,properties:G(t),geometry:{type:\"Point\",coordinates:[(n=t.x,360*(n-.5)),(e=t.y,r=(180-360*e)*Math.PI/180,360*Math.atan(Math.exp(r))/Math.PI-90)]}};var e,r,n}function G(t){var e=t.numPoints,r=e>=1e4?Math.round(e/1e3)+\"k\":e>=1e3?Math.round(e/100)/10+\"k\":e;return X(X({},t.properties),{cluster:!0,cluster_id:t.id,point_count:e,point_count_abbreviated:r})}function Y(t){return t/360+.5}function W(t){var e=Math.sin(t*Math.PI/180),r=.5-.25*Math.log((1+e)/(1-e))/Math.PI;return r<0?0:r>1?1:r}function X(t,e){for(var r in e)t[r]=e[r];return t}function Z(t){return t.x}function J(t){return t.y}function K(t,e,r,n,i,a){var o=i-r,s=a-n;if(0!==o||0!==s){var l=((t-r)*o+(e-n)*s)/(o*o+s*s);l>1?(r=i,n=a):l>0&&(r+=o*l,n+=s*l)}return(o=t-r)*o+(s=e-n)*s}function Q(t,e,r,n){var i={id:void 0===t?null:t,type:e,geometry:r,tags:n,minX:1/0,minY:1/0,maxX:-1/0,maxY:-1/0};return function(t){var e=t.geometry,r=t.type;if(\"Point\"===r||\"MultiPoint\"===r||\"LineString\"===r)$(t,e);else if(\"Polygon\"===r||\"MultiLineString\"===r)for(var n=0;n<e.length;n++)$(t,e[n]);else if(\"MultiPolygon\"===r)for(n=0;n<e.length;n++)for(var i=0;i<e[n].length;i++)$(t,e[n][i])}(i),i}function $(t,e){for(var r=0;r<e.length;r+=3)t.minX=Math.min(t.minX,e[r]),t.minY=Math.min(t.minY,e[r+1]),t.maxX=Math.max(t.maxX,e[r]),t.maxY=Math.max(t.maxY,e[r+1])}function tt(t,e,r,n){if(e.geometry){var i=e.geometry.coordinates,a=e.geometry.type,o=Math.pow(r.tolerance/((1<<r.maxZoom)*r.extent),2),s=[],l=e.id;if(r.promoteId?l=e.properties[r.promoteId]:r.generateId&&(l=n||0),\"Point\"===a)et(i,s);else if(\"MultiPoint\"===a)for(var c=0;c<i.length;c++)et(i[c],s);else if(\"LineString\"===a)rt(i,s,o,!1);else if(\"MultiLineString\"===a){if(r.lineMetrics){for(c=0;c<i.length;c++)s=[],rt(i[c],s,o,!1),t.push(Q(l,\"LineString\",s,e.properties));return}nt(i,s,o,!1)}else if(\"Polygon\"===a)nt(i,s,o,!0);else{if(\"MultiPolygon\"!==a){if(\"GeometryCollection\"===a){for(c=0;c<e.geometry.geometries.length;c++)tt(t,{id:l,geometry:e.geometry.geometries[c],properties:e.properties},r,n);return}throw new Error(\"Input data is not a valid GeoJSON object.\")}for(c=0;c<i.length;c++){var u=[];nt(i[c],u,o,!0),s.push(u)}}t.push(Q(l,a,s,e.properties))}}function et(t,e){e.push(it(t[0])),e.push(at(t[1])),e.push(0)}function rt(t,e,r,n){for(var i,a,o=0,s=0;s<t.length;s++){var l=it(t[s][0]),c=at(t[s][1]);e.push(l),e.push(c),e.push(0),s>0&&(o+=n?(i*c-l*a)/2:Math.sqrt(Math.pow(l-i,2)+Math.pow(c-a,2))),i=l,a=c}var u=e.length-3;e[2]=1,function t(e,r,n,i){for(var a,o=i,s=n-r>>1,l=n-r,c=e[r],u=e[r+1],f=e[n],h=e[n+1],p=r+3;p<n;p+=3){var d=K(e[p],e[p+1],c,u,f,h);if(d>o)a=p,o=d;else if(d===o){var m=Math.abs(p-s);m<l&&(a=p,l=m)}}o>i&&(a-r>3&&t(e,r,a,i),e[a+2]=o,n-a>3&&t(e,a,n,i))}(e,0,u,r),e[u+2]=1,e.size=Math.abs(o),e.start=0,e.end=e.size}function nt(t,e,r,n){for(var i=0;i<t.length;i++){var a=[];rt(t[i],a,r,n),e.push(a)}}function it(t){return t/360+.5}function at(t){var e=Math.sin(t*Math.PI/180),r=.5-.25*Math.log((1+e)/(1-e))/Math.PI;return r<0?0:r>1?1:r}function ot(t,e,r,n,i,a,o,s){if(n/=e,a>=(r/=e)&&o<n)return t;if(o<r||a>=n)return null;for(var l=[],c=0;c<t.length;c++){var u=t[c],f=u.geometry,h=u.type,p=0===i?u.minX:u.minY,d=0===i?u.maxX:u.maxY;if(p>=r&&d<n)l.push(u);else if(!(d<r||p>=n)){var m=[];if(\"Point\"===h||\"MultiPoint\"===h)st(f,m,r,n,i);else if(\"LineString\"===h)lt(f,m,r,n,i,!1,s.lineMetrics);else if(\"MultiLineString\"===h)ut(f,m,r,n,i,!1);else if(\"Polygon\"===h)ut(f,m,r,n,i,!0);else if(\"MultiPolygon\"===h)for(var g=0;g<f.length;g++){var v=[];ut(f[g],v,r,n,i,!0),v.length&&m.push(v)}if(m.length){if(s.lineMetrics&&\"LineString\"===h){for(g=0;g<m.length;g++)l.push(Q(u.id,h,m[g],u.tags));continue}\"LineString\"!==h&&\"MultiLineString\"!==h||(1===m.length?(h=\"LineString\",m=m[0]):h=\"MultiLineString\"),\"Point\"!==h&&\"MultiPoint\"!==h||(h=3===m.length?\"Point\":\"MultiPoint\"),l.push(Q(u.id,h,m,u.tags))}}}return l.length?l:null}function st(t,e,r,n,i){for(var a=0;a<t.length;a+=3){var o=t[a+i];o>=r&&o<=n&&(e.push(t[a]),e.push(t[a+1]),e.push(t[a+2]))}}function lt(t,e,r,n,i,a,o){for(var s,l,c=ct(t),u=0===i?ht:pt,f=t.start,h=0;h<t.length-3;h+=3){var p=t[h],d=t[h+1],m=t[h+2],g=t[h+3],v=t[h+4],y=0===i?p:d,x=0===i?g:v,b=!1;o&&(s=Math.sqrt(Math.pow(p-g,2)+Math.pow(d-v,2))),y<r?x>r&&(l=u(c,p,d,g,v,r),o&&(c.start=f+s*l)):y>n?x<n&&(l=u(c,p,d,g,v,n),o&&(c.start=f+s*l)):ft(c,p,d,m),x<r&&y>=r&&(l=u(c,p,d,g,v,r),b=!0),x>n&&y<=n&&(l=u(c,p,d,g,v,n),b=!0),!a&&b&&(o&&(c.end=f+s*l),e.push(c),c=ct(t)),o&&(f+=s)}var _=t.length-3;p=t[_],d=t[_+1],m=t[_+2],(y=0===i?p:d)>=r&&y<=n&&ft(c,p,d,m),_=c.length-3,a&&_>=3&&(c[_]!==c[0]||c[_+1]!==c[1])&&ft(c,c[0],c[1],c[2]),c.length&&e.push(c)}function ct(t){var e=[];return e.size=t.size,e.start=t.start,e.end=t.end,e}function ut(t,e,r,n,i,a){for(var o=0;o<t.length;o++)lt(t[o],e,r,n,i,a,!1)}function ft(t,e,r,n){t.push(e),t.push(r),t.push(n)}function ht(t,e,r,n,i,a){var o=(a-e)/(n-e);return t.push(a),t.push(r+(i-r)*o),t.push(1),o}function pt(t,e,r,n,i,a){var o=(a-r)/(i-r);return t.push(e+(n-e)*o),t.push(a),t.push(1),o}function dt(t,e){for(var r=[],n=0;n<t.length;n++){var i,a=t[n],o=a.type;if(\"Point\"===o||\"MultiPoint\"===o||\"LineString\"===o)i=mt(a.geometry,e);else if(\"MultiLineString\"===o||\"Polygon\"===o){i=[];for(var s=0;s<a.geometry.length;s++)i.push(mt(a.geometry[s],e))}else if(\"MultiPolygon\"===o)for(i=[],s=0;s<a.geometry.length;s++){for(var l=[],c=0;c<a.geometry[s].length;c++)l.push(mt(a.geometry[s][c],e));i.push(l)}r.push(Q(a.id,o,i,a.tags))}return r}function mt(t,e){var r=[];r.size=t.size,void 0!==t.start&&(r.start=t.start,r.end=t.end);for(var n=0;n<t.length;n+=3)r.push(t[n]+e,t[n+1],t[n+2]);return r}function gt(t,e){if(t.transformed)return t;var r,n,i,a=1<<t.z,o=t.x,s=t.y;for(r=0;r<t.features.length;r++){var l=t.features[r],c=l.geometry,u=l.type;if(l.geometry=[],1===u)for(n=0;n<c.length;n+=2)l.geometry.push(vt(c[n],c[n+1],e,a,o,s));else for(n=0;n<c.length;n++){var f=[];for(i=0;i<c[n].length;i+=2)f.push(vt(c[n][i],c[n][i+1],e,a,o,s));l.geometry.push(f)}}return t.transformed=!0,t}function vt(t,e,r,n,i,a){return[Math.round(r*(t*n-i)),Math.round(r*(e*n-a))]}function yt(t,e,r,n,i){for(var a=e===i.maxZoom?0:i.tolerance/((1<<e)*i.extent),o={features:[],numPoints:0,numSimplified:0,numFeatures:0,source:null,x:r,y:n,z:e,transformed:!1,minX:2,minY:1,maxX:-1,maxY:0},s=0;s<t.length;s++){o.numFeatures++,xt(o,t[s],a,i);var l=t[s].minX,c=t[s].minY,u=t[s].maxX,f=t[s].maxY;l<o.minX&&(o.minX=l),c<o.minY&&(o.minY=c),u>o.maxX&&(o.maxX=u),f>o.maxY&&(o.maxY=f)}return o}function xt(t,e,r,n){var i=e.geometry,a=e.type,o=[];if(\"Point\"===a||\"MultiPoint\"===a)for(var s=0;s<i.length;s+=3)o.push(i[s]),o.push(i[s+1]),t.numPoints++,t.numSimplified++;else if(\"LineString\"===a)bt(o,i,t,r,!1,!1);else if(\"MultiLineString\"===a||\"Polygon\"===a)for(s=0;s<i.length;s++)bt(o,i[s],t,r,\"Polygon\"===a,0===s);else if(\"MultiPolygon\"===a)for(var l=0;l<i.length;l++){var c=i[l];for(s=0;s<c.length;s++)bt(o,c[s],t,r,!0,0===s)}if(o.length){var u=e.tags||null;if(\"LineString\"===a&&n.lineMetrics){for(var f in u={},e.tags)u[f]=e.tags[f];u.mapbox_clip_start=i.start/i.size,u.mapbox_clip_end=i.end/i.size}var h={geometry:o,type:\"Polygon\"===a||\"MultiPolygon\"===a?3:\"LineString\"===a||\"MultiLineString\"===a?2:1,tags:u};null!==e.id&&(h.id=e.id),t.features.push(h)}}function bt(t,e,r,n,i,a){var o=n*n;if(n>0&&e.size<(i?o:n))r.numPoints+=e.length/3;else{for(var s=[],l=0;l<e.length;l+=3)(0===n||e[l+2]>o)&&(r.numSimplified++,s.push(e[l]),s.push(e[l+1])),r.numPoints++;i&&function(t,e){for(var r=0,n=0,i=t.length,a=i-2;n<i;a=n,n+=2)r+=(t[n]-t[a])*(t[n+1]+t[a+1]);if(r>0===e)for(n=0,i=t.length;n<i/2;n+=2){var o=t[n],s=t[n+1];t[n]=t[i-2-n],t[n+1]=t[i-1-n],t[i-2-n]=o,t[i-1-n]=s}}(s,a),t.push(s)}}function _t(t,e){var r=(e=this.options=function(t,e){for(var r in e)t[r]=e[r];return t}(Object.create(this.options),e)).debug;if(r&&console.time(\"preprocess data\"),e.maxZoom<0||e.maxZoom>24)throw new Error(\"maxZoom should be in the 0-24 range\");if(e.promoteId&&e.generateId)throw new Error(\"promoteId and generateId cannot be used together.\");var n=function(t,e){var r=[];if(\"FeatureCollection\"===t.type)for(var n=0;n<t.features.length;n++)tt(r,t.features[n],e,n);else\"Feature\"===t.type?tt(r,t,e):tt(r,{geometry:t},e);return r}(t,e);this.tiles={},this.tileCoords=[],r&&(console.timeEnd(\"preprocess data\"),console.log(\"index: maxZoom: %d, maxPoints: %d\",e.indexMaxZoom,e.indexMaxPoints),console.time(\"generate tiles\"),this.stats={},this.total=0),(n=function(t,e){var r=e.buffer/e.extent,n=t,i=ot(t,1,-1-r,r,0,-1,2,e),a=ot(t,1,1-r,2+r,0,-1,2,e);return(i||a)&&(n=ot(t,1,-r,1+r,0,-1,2,e)||[],i&&(n=dt(i,1).concat(n)),a&&(n=n.concat(dt(a,-1)))),n}(n,e)).length&&this.splitTile(n,0,0,0),r&&(n.length&&console.log(\"features: %d, points: %d\",this.tiles[0].numFeatures,this.tiles[0].numPoints),console.timeEnd(\"generate tiles\"),console.log(\"tiles generated:\",this.total,JSON.stringify(this.stats)))}function wt(t,e,r){return 32*((1<<t)*r+e)+t}function Tt(t,e){var r=t.tileID.canonical;if(!this._geoJSONIndex)return e(null,null);var n=this._geoJSONIndex.getTile(r.z,r.x,r.y);if(!n)return e(null,null);var i=new g(n.features),a=_(i);0===a.byteOffset&&a.byteLength===a.buffer.byteLength||(a=new Uint8Array(a)),e(null,{vectorTile:i,rawData:a.buffer})}U.prototype.load=function(t){var e=this.options,r=e.log,n=e.minZoom,i=e.maxZoom,a=e.nodeSize;r&&console.time(\"total time\");var o=\"prepare \"+t.length+\" points\";r&&console.time(o),this.points=t;for(var s=[],l=0;l<t.length;l++)t[l].geometry&&s.push(q(t[l],l));this.trees[i+1]=new N(s,Z,J,a,Float32Array),r&&console.timeEnd(o);for(var c=i;c>=n;c--){var u=+Date.now();s=this._cluster(s,c),this.trees[c]=new N(s,Z,J,a,Float32Array),r&&console.log(\"z%d: %d clusters in %dms\",c,s.length,+Date.now()-u)}return r&&console.timeEnd(\"total time\"),this},U.prototype.getClusters=function(t,e){var r=((t[0]+180)%360+360)%360-180,n=Math.max(-90,Math.min(90,t[1])),i=180===t[2]?180:((t[2]+180)%360+360)%360-180,a=Math.max(-90,Math.min(90,t[3]));if(t[2]-t[0]>=360)r=-180,i=180;else if(r>i){var o=this.getClusters([r,n,180,a],e),s=this.getClusters([-180,n,i,a],e);return o.concat(s)}for(var l=this.trees[this._limitZoom(e)],c=[],u=0,f=l.range(Y(r),W(a),Y(i),W(n));u<f.length;u+=1){var h=f[u],p=l.points[h];c.push(p.numPoints?H(p):this.points[p.index])}return c},U.prototype.getChildren=function(t){var e=this._getOriginId(t),r=this._getOriginZoom(t),n=\"No cluster with the specified id.\",i=this.trees[r];if(!i)throw new Error(n);var a=i.points[e];if(!a)throw new Error(n);for(var o=this.options.radius/(this.options.extent*Math.pow(2,r-1)),s=[],l=0,c=i.within(a.x,a.y,o);l<c.length;l+=1){var u=c[l],f=i.points[u];f.parentId===t&&s.push(f.numPoints?H(f):this.points[f.index])}if(0===s.length)throw new Error(n);return s},U.prototype.getLeaves=function(t,e,r){e=e||10,r=r||0;var n=[];return this._appendLeaves(n,t,e,r,0),n},U.prototype.getTile=function(t,e,r){var n=this.trees[this._limitZoom(t)],i=Math.pow(2,t),a=this.options,o=a.extent,s=a.radius/o,l=(r-s)/i,c=(r+1+s)/i,u={features:[]};return this._addTileFeatures(n.range((e-s)/i,l,(e+1+s)/i,c),n.points,e,r,i,u),0===e&&this._addTileFeatures(n.range(1-s/i,l,1,c),n.points,i,r,i,u),e===i-1&&this._addTileFeatures(n.range(0,l,s/i,c),n.points,-1,r,i,u),u.features.length?u:null},U.prototype.getClusterExpansionZoom=function(t){for(var e=this._getOriginZoom(t)-1;e<=this.options.maxZoom;){var r=this.getChildren(t);if(e++,1!==r.length)break;t=r[0].properties.cluster_id}return e},U.prototype._appendLeaves=function(t,e,r,n,i){for(var a=0,o=this.getChildren(e);a<o.length;a+=1){var s=o[a],l=s.properties;if(l&&l.cluster?i+l.point_count<=n?i+=l.point_count:i=this._appendLeaves(t,l.cluster_id,r,n,i):i<n?i++:t.push(s),t.length===r)break}return i},U.prototype._addTileFeatures=function(t,e,r,n,i,a){for(var o=0,s=t;o<s.length;o+=1){var l=e[s[o]],c=l.numPoints,u={type:1,geometry:[[Math.round(this.options.extent*(l.x*i-r)),Math.round(this.options.extent*(l.y*i-n))]],tags:c?G(l):this.points[l.index].properties},f=void 0;c?f=l.id:this.options.generateId?f=l.index:this.points[l.index].id&&(f=this.points[l.index].id),void 0!==f&&(u.id=f),a.features.push(u)}},U.prototype._limitZoom=function(t){return Math.max(this.options.minZoom,Math.min(t,this.options.maxZoom+1))},U.prototype._cluster=function(t,e){for(var r=[],n=this.options,i=n.radius,a=n.extent,o=n.reduce,s=i/(a*Math.pow(2,e)),l=0;l<t.length;l++){var c=t[l];if(!(c.zoom<=e)){c.zoom=e;for(var u=this.trees[e+1],f=u.within(c.x,c.y,s),h=c.numPoints||1,p=c.x*h,d=c.y*h,m=o&&h>1?this._map(c,!0):null,g=(l<<5)+(e+1)+this.points.length,v=0,y=f;v<y.length;v+=1){var x=y[v],b=u.points[x];if(!(b.zoom<=e)){b.zoom=e;var _=b.numPoints||1;p+=b.x*_,d+=b.y*_,h+=_,b.parentId=g,o&&(m||(m=this._map(c,!0)),o(m,this._map(b)))}}1===h?r.push(c):(c.parentId=g,r.push(V(p/h,d/h,g,h,m)))}}return r},U.prototype._getOriginId=function(t){return t-this.points.length>>5},U.prototype._getOriginZoom=function(t){return(t-this.points.length)%32},U.prototype._map=function(t,e){if(t.numPoints)return e?X({},t.properties):t.properties;var r=this.points[t.index].properties,n=this.options.map(r);return e&&n===r?X({},n):n},_t.prototype.options={maxZoom:14,indexMaxZoom:5,indexMaxPoints:1e5,tolerance:3,extent:4096,buffer:64,lineMetrics:!1,promoteId:null,generateId:!1,debug:0},_t.prototype.splitTile=function(t,e,r,n,i,a,o){for(var s=[t,e,r,n],l=this.options,c=l.debug;s.length;){n=s.pop(),r=s.pop(),e=s.pop(),t=s.pop();var u=1<<e,f=wt(e,r,n),h=this.tiles[f];if(!h&&(c>1&&console.time(\"creation\"),h=this.tiles[f]=yt(t,e,r,n,l),this.tileCoords.push({z:e,x:r,y:n}),c)){c>1&&(console.log(\"tile z%d-%d-%d (features: %d, points: %d, simplified: %d)\",e,r,n,h.numFeatures,h.numPoints,h.numSimplified),console.timeEnd(\"creation\"));var p=\"z\"+e;this.stats[p]=(this.stats[p]||0)+1,this.total++}if(h.source=t,i){if(e===l.maxZoom||e===i)continue;var d=1<<i-e;if(r!==Math.floor(a/d)||n!==Math.floor(o/d))continue}else if(e===l.indexMaxZoom||h.numPoints<=l.indexMaxPoints)continue;if(h.source=null,0!==t.length){c>1&&console.time(\"clipping\");var m,g,v,y,x,b,_=.5*l.buffer/l.extent,w=.5-_,T=.5+_,k=1+_;m=g=v=y=null,x=ot(t,u,r-_,r+T,0,h.minX,h.maxX,l),b=ot(t,u,r+w,r+k,0,h.minX,h.maxX,l),t=null,x&&(m=ot(x,u,n-_,n+T,1,h.minY,h.maxY,l),g=ot(x,u,n+w,n+k,1,h.minY,h.maxY,l),x=null),b&&(v=ot(b,u,n-_,n+T,1,h.minY,h.maxY,l),y=ot(b,u,n+w,n+k,1,h.minY,h.maxY,l),b=null),c>1&&console.timeEnd(\"clipping\"),s.push(m||[],e+1,2*r,2*n),s.push(g||[],e+1,2*r,2*n+1),s.push(v||[],e+1,2*r+1,2*n),s.push(y||[],e+1,2*r+1,2*n+1)}}},_t.prototype.getTile=function(t,e,r){var n=this.options,i=n.extent,a=n.debug;if(t<0||t>24)return null;var o=1<<t,s=wt(t,e=(e%o+o)%o,r);if(this.tiles[s])return gt(this.tiles[s],i);a>1&&console.log(\"drilling down to z%d-%d-%d\",t,e,r);for(var l,c=t,u=e,f=r;!l&&c>0;)c--,u=Math.floor(u/2),f=Math.floor(f/2),l=this.tiles[wt(c,u,f)];return l&&l.source?(a>1&&console.log(\"found parent tile z%d-%d-%d\",c,u,f),a>1&&console.time(\"drilling down\"),this.splitTile(l.source,c,u,f,t,e,r),a>1&&console.timeEnd(\"drilling down\"),this.tiles[s]?gt(this.tiles[s],i):null):null};var kt=function(e){function r(t,r,n,i){e.call(this,t,r,n,Tt),i&&(this.loadGeoJSON=i)}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.loadData=function(t,e){this._pendingCallback&&this._pendingCallback(null,{abandoned:!0}),this._pendingCallback=e,this._pendingLoadDataParams=t,this._state&&\"Idle\"!==this._state?this._state=\"NeedsLoadData\":(this._state=\"Coalescing\",this._loadData())},r.prototype._loadData=function(){var e=this;if(this._pendingCallback&&this._pendingLoadDataParams){var r=this._pendingCallback,n=this._pendingLoadDataParams;delete this._pendingCallback,delete this._pendingLoadDataParams;var i=!!(n&&n.request&&n.request.collectResourceTiming)&&new t.RequestPerformance(n.request);this.loadGeoJSON(n,(function(a,o){if(a||!o)return r(a);if(\"object\"!=typeof o)return r(new Error(\"Input data given to '\"+n.source+\"' is not a valid GeoJSON object.\"));f(o,!0);try{e._geoJSONIndex=n.cluster?new U(function(e){var r=e.superclusterOptions,n=e.clusterProperties;if(!n||!r)return r;for(var i={},a={},o={accumulated:null,zoom:0},s={properties:null},l=Object.keys(n),c=0,u=l;c<u.length;c+=1){var f=u[c],h=n[f],p=h[0],d=h[1],m=t.createExpression(d),g=t.createExpression(\"string\"==typeof p?[p,[\"accumulated\"],[\"get\",f]]:p);i[f]=m.value,a[f]=g.value}return r.map=function(t){s.properties=t;for(var e={},r=0,n=l;r<n.length;r+=1){var a=n[r];e[a]=i[a].evaluate(o,s)}return e},r.reduce=function(t,e){s.properties=e;for(var r=0,n=l;r<n.length;r+=1){var i=n[r];o.accumulated=t[i],t[i]=a[i].evaluate(o,s)}},r}(n)).load(o.features):function(t,e){return new _t(t,e)}(o,n.geojsonVtOptions)}catch(a){return r(a)}e.loaded={};var s={};if(i){var l=i.finish();l&&(s.resourceTiming={},s.resourceTiming[n.source]=JSON.parse(JSON.stringify(l)))}r(null,s)}))}},r.prototype.coalesce=function(){\"Coalescing\"===this._state?this._state=\"Idle\":\"NeedsLoadData\"===this._state&&(this._state=\"Coalescing\",this._loadData())},r.prototype.reloadTile=function(t,r){var n=this.loaded,i=t.uid;return n&&n[i]?e.prototype.reloadTile.call(this,t,r):this.loadTile(t,r)},r.prototype.loadGeoJSON=function(e,r){if(e.request)t.getJSON(e.request,r);else{if(\"string\"!=typeof e.data)return r(new Error(\"Input data given to '\"+e.source+\"' is not a valid GeoJSON object.\"));try{return r(null,JSON.parse(e.data))}catch(t){return r(new Error(\"Input data given to '\"+e.source+\"' is not a valid GeoJSON object.\"))}}},r.prototype.removeSource=function(t,e){this._pendingCallback&&this._pendingCallback(null,{abandoned:!0}),e()},r.prototype.getClusterExpansionZoom=function(t,e){try{e(null,this._geoJSONIndex.getClusterExpansionZoom(t.clusterId))}catch(t){e(t)}},r.prototype.getClusterChildren=function(t,e){try{e(null,this._geoJSONIndex.getChildren(t.clusterId))}catch(t){e(t)}},r.prototype.getClusterLeaves=function(t,e){try{e(null,this._geoJSONIndex.getLeaves(t.clusterId,t.limit,t.offset))}catch(t){e(t)}},r}(l);var Mt=function(e){var r=this;this.self=e,this.actor=new t.Actor(e,this),this.layerIndexes={},this.availableImages={},this.workerSourceTypes={vector:l,geojson:kt},this.workerSources={},this.demWorkerSources={},this.self.registerWorkerSource=function(t,e){if(r.workerSourceTypes[t])throw new Error('Worker source with name \"'+t+'\" already registered.');r.workerSourceTypes[t]=e},this.self.registerRTLTextPlugin=function(e){if(t.plugin.isParsed())throw new Error(\"RTL text plugin already registered.\");t.plugin.applyArabicShaping=e.applyArabicShaping,t.plugin.processBidirectionalText=e.processBidirectionalText,t.plugin.processStyledBidirectionalText=e.processStyledBidirectionalText}};return Mt.prototype.setReferrer=function(t,e){this.referrer=e},Mt.prototype.setImages=function(t,e,r){for(var n in this.availableImages[t]=e,this.workerSources[t]){var i=this.workerSources[t][n];for(var a in i)i[a].availableImages=e}r()},Mt.prototype.setLayers=function(t,e,r){this.getLayerIndex(t).replace(e),r()},Mt.prototype.updateLayers=function(t,e,r){this.getLayerIndex(t).update(e.layers,e.removedIds),r()},Mt.prototype.loadTile=function(t,e,r){this.getWorkerSource(t,e.type,e.source).loadTile(e,r)},Mt.prototype.loadDEMTile=function(t,e,r){this.getDEMWorkerSource(t,e.source).loadTile(e,r)},Mt.prototype.reloadTile=function(t,e,r){this.getWorkerSource(t,e.type,e.source).reloadTile(e,r)},Mt.prototype.abortTile=function(t,e,r){this.getWorkerSource(t,e.type,e.source).abortTile(e,r)},Mt.prototype.removeTile=function(t,e,r){this.getWorkerSource(t,e.type,e.source).removeTile(e,r)},Mt.prototype.removeDEMTile=function(t,e){this.getDEMWorkerSource(t,e.source).removeTile(e)},Mt.prototype.removeSource=function(t,e,r){if(this.workerSources[t]&&this.workerSources[t][e.type]&&this.workerSources[t][e.type][e.source]){var n=this.workerSources[t][e.type][e.source];delete this.workerSources[t][e.type][e.source],void 0!==n.removeSource?n.removeSource(e,r):r()}},Mt.prototype.loadWorkerSource=function(t,e,r){try{this.self.importScripts(e.url),r()}catch(t){r(t.toString())}},Mt.prototype.syncRTLPluginState=function(e,r,n){try{t.plugin.setState(r);var i=t.plugin.getPluginURL();if(t.plugin.isLoaded()&&!t.plugin.isParsed()&&null!=i){this.self.importScripts(i);var a=t.plugin.isParsed();n(a?void 0:new Error(\"RTL Text Plugin failed to import scripts from \"+i),a)}}catch(t){n(t.toString())}},Mt.prototype.getAvailableImages=function(t){var e=this.availableImages[t];return e||(e=[]),e},Mt.prototype.getLayerIndex=function(t){var e=this.layerIndexes[t];return e||(e=this.layerIndexes[t]=new n),e},Mt.prototype.getWorkerSource=function(t,e,r){var n=this;if(this.workerSources[t]||(this.workerSources[t]={}),this.workerSources[t][e]||(this.workerSources[t][e]={}),!this.workerSources[t][e][r]){var i={send:function(e,r,i){n.actor.send(e,r,i,t)}};this.workerSources[t][e][r]=new this.workerSourceTypes[e](i,this.getLayerIndex(t),this.getAvailableImages(t))}return this.workerSources[t][e][r]},Mt.prototype.getDEMWorkerSource=function(t,e){return this.demWorkerSources[t]||(this.demWorkerSources[t]={}),this.demWorkerSources[t][e]||(this.demWorkerSources[t][e]=new u),this.demWorkerSources[t][e]},Mt.prototype.enforceCacheSizeLimit=function(e,r){t.enforceCacheSizeLimit(r)},\"undefined\"!=typeof WorkerGlobalScope&&void 0!==t.window&&t.window instanceof WorkerGlobalScope&&(t.window.worker=new Mt(t.window)),Mt})),n(0,(function(t){var e=t.createCommonjsModule((function(t){function e(t){return!r(t)}function r(t){return\"undefined\"==typeof window||\"undefined\"==typeof document?\"not a browser\":Array.prototype&&Array.prototype.every&&Array.prototype.filter&&Array.prototype.forEach&&Array.prototype.indexOf&&Array.prototype.lastIndexOf&&Array.prototype.map&&Array.prototype.some&&Array.prototype.reduce&&Array.prototype.reduceRight&&Array.isArray?Function.prototype&&Function.prototype.bind?Object.keys&&Object.create&&Object.getPrototypeOf&&Object.getOwnPropertyNames&&Object.isSealed&&Object.isFrozen&&Object.isExtensible&&Object.getOwnPropertyDescriptor&&Object.defineProperty&&Object.defineProperties&&Object.seal&&Object.freeze&&Object.preventExtensions?\"JSON\"in window&&\"parse\"in JSON&&\"stringify\"in JSON?function(){if(!(\"Worker\"in window&&\"Blob\"in window&&\"URL\"in window))return!1;var t,e,r=new Blob([\"\"],{type:\"text/javascript\"}),n=URL.createObjectURL(r);try{e=new Worker(n),t=!0}catch(e){t=!1}e&&e.terminate();return URL.revokeObjectURL(n),t}()?\"Uint8ClampedArray\"in window?ArrayBuffer.isView?function(){var t=document.createElement(\"canvas\");t.width=t.height=1;var e=t.getContext(\"2d\");if(!e)return!1;var r=e.getImageData(0,0,1,1);return r&&r.width===t.width}()?function(t){void 0===n[t]&&(n[t]=function(t){var r=function(t){var r=document.createElement(\"canvas\"),n=Object.create(e.webGLContextAttributes);return n.failIfMajorPerformanceCaveat=t,r.probablySupportsContext?r.probablySupportsContext(\"webgl\",n)||r.probablySupportsContext(\"experimental-webgl\",n):r.supportsContext?r.supportsContext(\"webgl\",n)||r.supportsContext(\"experimental-webgl\",n):r.getContext(\"webgl\",n)||r.getContext(\"experimental-webgl\",n)}(t);if(!r)return!1;var n=r.createShader(r.VERTEX_SHADER);if(!n||r.isContextLost())return!1;return r.shaderSource(n,\"void main() {}\"),r.compileShader(n),!0===r.getShaderParameter(n,r.COMPILE_STATUS)}(t));return n[t]}(t&&t.failIfMajorPerformanceCaveat)?void 0:\"insufficient WebGL support\":\"insufficient Canvas/getImageData support\":\"insufficient ArrayBuffer support\":\"insufficient Uint8ClampedArray support\":\"insufficient worker support\":\"insufficient JSON support\":\"insufficient Object support\":\"insufficient Function support\":\"insufficent Array support\"}t.exports?t.exports=e:window&&(window.mapboxgl=window.mapboxgl||{},window.mapboxgl.supported=e,window.mapboxgl.notSupportedReason=r);var n={};e.webGLContextAttributes={antialias:!1,alpha:!0,stencil:!0,depth:!0}})),r={create:function(e,r,n){var i=t.window.document.createElement(e);return void 0!==r&&(i.className=r),n&&n.appendChild(i),i},createNS:function(e,r){return t.window.document.createElementNS(e,r)}},n=t.window.document.documentElement.style;function i(t){if(!n)return t[0];for(var e=0;e<t.length;e++)if(t[e]in n)return t[e];return t[0]}var a,o=i([\"userSelect\",\"MozUserSelect\",\"WebkitUserSelect\",\"msUserSelect\"]);r.disableDrag=function(){n&&o&&(a=n[o],n[o]=\"none\")},r.enableDrag=function(){n&&o&&(n[o]=a)};var s=i([\"transform\",\"WebkitTransform\"]);r.setTransform=function(t,e){t.style[s]=e};var l=!1;try{var c=Object.defineProperty({},\"passive\",{get:function(){l=!0}});t.window.addEventListener(\"test\",c,c),t.window.removeEventListener(\"test\",c,c)}catch(t){l=!1}r.addEventListener=function(t,e,r,n){void 0===n&&(n={}),\"passive\"in n&&l?t.addEventListener(e,r,n):t.addEventListener(e,r,n.capture)},r.removeEventListener=function(t,e,r,n){void 0===n&&(n={}),\"passive\"in n&&l?t.removeEventListener(e,r,n):t.removeEventListener(e,r,n.capture)};var u=function(e){e.preventDefault(),e.stopPropagation(),t.window.removeEventListener(\"click\",u,!0)};function f(t){var e=t.userImage;if(e&&e.render&&e.render())return t.data.replace(new Uint8Array(e.data.buffer)),!0;return!1}r.suppressClick=function(){t.window.addEventListener(\"click\",u,!0),t.window.setTimeout((function(){t.window.removeEventListener(\"click\",u,!0)}),0)},r.mousePos=function(e,r){var n=e.getBoundingClientRect();return new t.Point(r.clientX-n.left-e.clientLeft,r.clientY-n.top-e.clientTop)},r.touchPos=function(e,r){for(var n=e.getBoundingClientRect(),i=[],a=0;a<r.length;a++)i.push(new t.Point(r[a].clientX-n.left-e.clientLeft,r[a].clientY-n.top-e.clientTop));return i},r.mouseButton=function(e){return void 0!==t.window.InstallTrigger&&2===e.button&&e.ctrlKey&&t.window.navigator.platform.toUpperCase().indexOf(\"MAC\")>=0?0:e.button},r.remove=function(t){t.parentNode&&t.parentNode.removeChild(t)};var h=function(e){function r(){e.call(this),this.images={},this.updatedImages={},this.callbackDispatchedThisFrame={},this.loaded=!1,this.requestors=[],this.patterns={},this.atlasImage=new t.RGBAImage({width:1,height:1}),this.dirty=!0}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.isLoaded=function(){return this.loaded},r.prototype.setLoaded=function(t){if(this.loaded!==t&&(this.loaded=t,t)){for(var e=0,r=this.requestors;e<r.length;e+=1){var n=r[e],i=n.ids,a=n.callback;this._notify(i,a)}this.requestors=[]}},r.prototype.getImage=function(t){return this.images[t]},r.prototype.addImage=function(t,e){this._validate(t,e)&&(this.images[t]=e)},r.prototype._validate=function(e,r){var n=!0;return this._validateStretch(r.stretchX,r.data&&r.data.width)||(this.fire(new t.ErrorEvent(new Error('Image \"'+e+'\" has invalid \"stretchX\" value'))),n=!1),this._validateStretch(r.stretchY,r.data&&r.data.height)||(this.fire(new t.ErrorEvent(new Error('Image \"'+e+'\" has invalid \"stretchY\" value'))),n=!1),this._validateContent(r.content,r)||(this.fire(new t.ErrorEvent(new Error('Image \"'+e+'\" has invalid \"content\" value'))),n=!1),n},r.prototype._validateStretch=function(t,e){if(!t)return!0;for(var r=0,n=0,i=t;n<i.length;n+=1){var a=i[n];if(a[0]<r||a[1]<a[0]||e<a[1])return!1;r=a[1]}return!0},r.prototype._validateContent=function(t,e){return!t||4===t.length&&(!(t[0]<0||e.data.width<t[0])&&(!(t[1]<0||e.data.height<t[1])&&(!(t[2]<0||e.data.width<t[2])&&(!(t[3]<0||e.data.height<t[3])&&(!(t[2]<t[0])&&!(t[3]<t[1]))))))},r.prototype.updateImage=function(t,e){var r=this.images[t];e.version=r.version+1,this.images[t]=e,this.updatedImages[t]=!0},r.prototype.removeImage=function(t){var e=this.images[t];delete this.images[t],delete this.patterns[t],e.userImage&&e.userImage.onRemove&&e.userImage.onRemove()},r.prototype.listImages=function(){return Object.keys(this.images)},r.prototype.getImages=function(t,e){var r=!0;if(!this.isLoaded())for(var n=0,i=t;n<i.length;n+=1){var a=i[n];this.images[a]||(r=!1)}this.isLoaded()||r?this._notify(t,e):this.requestors.push({ids:t,callback:e})},r.prototype._notify=function(e,r){for(var n={},i=0,a=e;i<a.length;i+=1){var o=a[i];this.images[o]||this.fire(new t.Event(\"styleimagemissing\",{id:o}));var s=this.images[o];s?n[o]={data:s.data.clone(),pixelRatio:s.pixelRatio,sdf:s.sdf,version:s.version,stretchX:s.stretchX,stretchY:s.stretchY,content:s.content,hasRenderCallback:Boolean(s.userImage&&s.userImage.render)}:t.warnOnce('Image \"'+o+'\" could not be loaded. Please make sure you have added the image with map.addImage() or a \"sprite\" property in your style. You can provide missing images by listening for the \"styleimagemissing\" map event.')}r(null,n)},r.prototype.getPixelSize=function(){var t=this.atlasImage;return{width:t.width,height:t.height}},r.prototype.getPattern=function(e){var r=this.patterns[e],n=this.getImage(e);if(!n)return null;if(r&&r.position.version===n.version)return r.position;if(r)r.position.version=n.version;else{var i={w:n.data.width+2,h:n.data.height+2,x:0,y:0},a=new t.ImagePosition(i,n);this.patterns[e]={bin:i,position:a}}return this._updatePatternAtlas(),this.patterns[e].position},r.prototype.bind=function(e){var r=e.gl;this.atlasTexture?this.dirty&&(this.atlasTexture.update(this.atlasImage),this.dirty=!1):this.atlasTexture=new t.Texture(e,this.atlasImage,r.RGBA),this.atlasTexture.bind(r.LINEAR,r.CLAMP_TO_EDGE)},r.prototype._updatePatternAtlas=function(){var e=[];for(var r in this.patterns)e.push(this.patterns[r].bin);var n=t.potpack(e),i=n.w,a=n.h,o=this.atlasImage;for(var s in o.resize({width:i||1,height:a||1}),this.patterns){var l=this.patterns[s].bin,c=l.x+1,u=l.y+1,f=this.images[s].data,h=f.width,p=f.height;t.RGBAImage.copy(f,o,{x:0,y:0},{x:c,y:u},{width:h,height:p}),t.RGBAImage.copy(f,o,{x:0,y:p-1},{x:c,y:u-1},{width:h,height:1}),t.RGBAImage.copy(f,o,{x:0,y:0},{x:c,y:u+p},{width:h,height:1}),t.RGBAImage.copy(f,o,{x:h-1,y:0},{x:c-1,y:u},{width:1,height:p}),t.RGBAImage.copy(f,o,{x:0,y:0},{x:c+h,y:u},{width:1,height:p})}this.dirty=!0},r.prototype.beginFrame=function(){this.callbackDispatchedThisFrame={}},r.prototype.dispatchRenderCallbacks=function(t){for(var e=0,r=t;e<r.length;e+=1){var n=r[e];if(!this.callbackDispatchedThisFrame[n]){this.callbackDispatchedThisFrame[n]=!0;var i=this.images[n];f(i)&&this.updateImage(n,i)}}},r}(t.Evented);var p=g,d=g,m=1e20;function g(t,e,r,n,i,a){this.fontSize=t||24,this.buffer=void 0===e?3:e,this.cutoff=n||.25,this.fontFamily=i||\"sans-serif\",this.fontWeight=a||\"normal\",this.radius=r||8;var o=this.size=this.fontSize+2*this.buffer;this.canvas=document.createElement(\"canvas\"),this.canvas.width=this.canvas.height=o,this.ctx=this.canvas.getContext(\"2d\"),this.ctx.font=this.fontWeight+\" \"+this.fontSize+\"px \"+this.fontFamily,this.ctx.textBaseline=\"middle\",this.ctx.fillStyle=\"black\",this.gridOuter=new Float64Array(o*o),this.gridInner=new Float64Array(o*o),this.f=new Float64Array(o),this.d=new Float64Array(o),this.z=new Float64Array(o+1),this.v=new Int16Array(o),this.middle=Math.round(o/2*(navigator.userAgent.indexOf(\"Gecko/\")>=0?1.2:1))}function v(t,e,r,n,i,a,o){for(var s=0;s<e;s++){for(var l=0;l<r;l++)n[l]=t[l*e+s];for(y(n,i,a,o,r),l=0;l<r;l++)t[l*e+s]=i[l]}for(l=0;l<r;l++){for(s=0;s<e;s++)n[s]=t[l*e+s];for(y(n,i,a,o,e),s=0;s<e;s++)t[l*e+s]=Math.sqrt(i[s])}}function y(t,e,r,n,i){r[0]=0,n[0]=-m,n[1]=+m;for(var a=1,o=0;a<i;a++){for(var s=(t[a]+a*a-(t[r[o]]+r[o]*r[o]))/(2*a-2*r[o]);s<=n[o];)o--,s=(t[a]+a*a-(t[r[o]]+r[o]*r[o]))/(2*a-2*r[o]);r[++o]=a,n[o]=s,n[o+1]=+m}for(a=0,o=0;a<i;a++){for(;n[o+1]<a;)o++;e[a]=(a-r[o])*(a-r[o])+t[r[o]]}}g.prototype.draw=function(t){this.ctx.clearRect(0,0,this.size,this.size),this.ctx.fillText(t,this.buffer,this.middle);for(var e=this.ctx.getImageData(0,0,this.size,this.size),r=new Uint8ClampedArray(this.size*this.size),n=0;n<this.size*this.size;n++){var i=e.data[4*n+3]/255;this.gridOuter[n]=1===i?0:0===i?m:Math.pow(Math.max(0,.5-i),2),this.gridInner[n]=1===i?m:0===i?0:Math.pow(Math.max(0,i-.5),2)}for(v(this.gridOuter,this.size,this.size,this.f,this.d,this.v,this.z),v(this.gridInner,this.size,this.size,this.f,this.d,this.v,this.z),n=0;n<this.size*this.size;n++){var a=this.gridOuter[n]-this.gridInner[n];r[n]=Math.max(0,Math.min(255,Math.round(255-255*(a/this.radius+this.cutoff))))}return r},p.default=d;var x=function(t,e){this.requestManager=t,this.localIdeographFontFamily=e,this.entries={}};x.prototype.setURL=function(t){this.url=t},x.prototype.getGlyphs=function(e,r){var n=this,i=[];for(var a in e)for(var o=0,s=e[a];o<s.length;o+=1){var l=s[o];i.push({stack:a,id:l})}t.asyncAll(i,(function(t,e){var r=t.stack,i=t.id,a=n.entries[r];a||(a=n.entries[r]={glyphs:{},requests:{},ranges:{}});var o=a.glyphs[i];if(void 0===o){if(o=n._tinySDF(a,r,i))return a.glyphs[i]=o,void e(null,{stack:r,id:i,glyph:o});var s=Math.floor(i/256);if(256*s>65535)e(new Error(\"glyphs > 65535 not supported\"));else if(a.ranges[s])e(null,{stack:r,id:i,glyph:o});else{var l=a.requests[s];l||(l=a.requests[s]=[],x.loadGlyphRange(r,s,n.url,n.requestManager,(function(t,e){if(e){for(var r in e)n._doesCharSupportLocalGlyph(+r)||(a.glyphs[+r]=e[+r]);a.ranges[s]=!0}for(var i=0,o=l;i<o.length;i+=1){(0,o[i])(t,e)}delete a.requests[s]}))),l.push((function(t,n){t?e(t):n&&e(null,{stack:r,id:i,glyph:n[i]||null})}))}}else e(null,{stack:r,id:i,glyph:o})}),(function(t,e){if(t)r(t);else if(e){for(var n={},i=0,a=e;i<a.length;i+=1){var o=a[i],s=o.stack,l=o.id,c=o.glyph;(n[s]||(n[s]={}))[l]=c&&{id:c.id,bitmap:c.bitmap.clone(),metrics:c.metrics}}r(null,n)}}))},x.prototype._doesCharSupportLocalGlyph=function(e){return!!this.localIdeographFontFamily&&(t.isChar[\"CJK Unified Ideographs\"](e)||t.isChar[\"Hangul Syllables\"](e)||t.isChar.Hiragana(e)||t.isChar.Katakana(e))},x.prototype._tinySDF=function(e,r,n){var i=this.localIdeographFontFamily;if(i&&this._doesCharSupportLocalGlyph(n)){var a=e.tinySDF;if(!a){var o=\"400\";/bold/i.test(r)?o=\"900\":/medium/i.test(r)?o=\"500\":/light/i.test(r)&&(o=\"200\"),a=e.tinySDF=new x.TinySDF(24,3,8,.25,i,o)}return{id:n,bitmap:new t.AlphaImage({width:30,height:30},a.draw(String.fromCharCode(n))),metrics:{width:24,height:24,left:0,top:-8,advance:24}}}},x.loadGlyphRange=function(e,r,n,i,a){var o=256*r,s=o+255,l=i.transformRequest(i.normalizeGlyphsURL(n).replace(\"{fontstack}\",e).replace(\"{range}\",o+\"-\"+s),t.ResourceType.Glyphs);t.getArrayBuffer(l,(function(e,r){if(e)a(e);else if(r){for(var n={},i=0,o=t.parseGlyphPBF(r);i<o.length;i+=1){var s=o[i];n[s.id]=s}a(null,n)}}))},x.TinySDF=p;var b=function(){this.specification=t.styleSpec.light.position};b.prototype.possiblyEvaluate=function(e,r){return t.sphericalToCartesian(e.expression.evaluate(r))},b.prototype.interpolate=function(e,r,n){return{x:t.number(e.x,r.x,n),y:t.number(e.y,r.y,n),z:t.number(e.z,r.z,n)}};var _=new t.Properties({anchor:new t.DataConstantProperty(t.styleSpec.light.anchor),position:new b,color:new t.DataConstantProperty(t.styleSpec.light.color),intensity:new t.DataConstantProperty(t.styleSpec.light.intensity)}),w=function(e){function r(r){e.call(this),this._transitionable=new t.Transitionable(_),this.setLight(r),this._transitioning=this._transitionable.untransitioned()}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.getLight=function(){return this._transitionable.serialize()},r.prototype.setLight=function(e,r){if(void 0===r&&(r={}),!this._validate(t.validateLight,e,r))for(var n in e){var i=e[n];t.endsWith(n,\"-transition\")?this._transitionable.setTransition(n.slice(0,-\"-transition\".length),i):this._transitionable.setValue(n,i)}},r.prototype.updateTransitions=function(t){this._transitioning=this._transitionable.transitioned(t,this._transitioning)},r.prototype.hasTransition=function(){return this._transitioning.hasTransition()},r.prototype.recalculate=function(t){this.properties=this._transitioning.possiblyEvaluate(t)},r.prototype._validate=function(e,r,n){return(!n||!1!==n.validate)&&t.emitValidationErrors(this,e.call(t.validateStyle,t.extend({value:r,style:{glyphs:!0,sprite:!0},styleSpec:t.styleSpec})))},r}(t.Evented),T=function(t,e){this.width=t,this.height=e,this.nextRow=0,this.data=new Uint8Array(this.width*this.height),this.dashEntry={}};T.prototype.getDash=function(t,e){var r=t.join(\",\")+String(e);return this.dashEntry[r]||(this.dashEntry[r]=this.addDash(t,e)),this.dashEntry[r]},T.prototype.getDashRanges=function(t,e,r){var n=[],i=t.length%2==1?-t[t.length-1]*r:0,a=t[0]*r,o=!0;n.push({left:i,right:a,isDash:o,zeroLength:0===t[0]});for(var s=t[0],l=1;l<t.length;l++){o=!o;var c=t[l];i=s*r,a=(s+=c)*r,n.push({left:i,right:a,isDash:o,zeroLength:0===c})}return n},T.prototype.addRoundDash=function(t,e,r){for(var n=e/2,i=-r;i<=r;i++)for(var a=this.nextRow+r+i,o=this.width*a,s=0,l=t[s],c=0;c<this.width;c++){c/l.right>1&&(l=t[++s]);var u=Math.abs(c-l.left),f=Math.abs(c-l.right),h=Math.min(u,f),p=void 0,d=i/r*(n+1);if(l.isDash){var m=n-Math.abs(d);p=Math.sqrt(h*h+m*m)}else p=n-Math.sqrt(h*h+d*d);this.data[o+c]=Math.max(0,Math.min(255,p+128))}},T.prototype.addRegularDash=function(t){for(var e=t.length-1;e>=0;--e){var r=t[e],n=t[e+1];r.zeroLength?t.splice(e,1):n&&n.isDash===r.isDash&&(n.left=r.left,t.splice(e,1))}var i=t[0],a=t[t.length-1];i.isDash===a.isDash&&(i.left=a.left-this.width,a.right=i.right+this.width);for(var o=this.width*this.nextRow,s=0,l=t[s],c=0;c<this.width;c++){c/l.right>1&&(l=t[++s]);var u=Math.abs(c-l.left),f=Math.abs(c-l.right),h=Math.min(u,f),p=l.isDash?h:-h;this.data[o+c]=Math.max(0,Math.min(255,p+128))}},T.prototype.addDash=function(e,r){var n=r?7:0,i=2*n+1;if(this.nextRow+i>this.height)return t.warnOnce(\"LineAtlas out of space\"),null;for(var a=0,o=0;o<e.length;o++)a+=e[o];if(0!==a){var s=this.width/a,l=this.getDashRanges(e,this.width,s);r?this.addRoundDash(l,s,n):this.addRegularDash(l)}var c={y:(this.nextRow+n+.5)/this.height,height:2*n/this.height,width:a};return this.nextRow+=i,this.dirty=!0,c},T.prototype.bind=function(t){var e=t.gl;this.texture?(e.bindTexture(e.TEXTURE_2D,this.texture),this.dirty&&(this.dirty=!1,e.texSubImage2D(e.TEXTURE_2D,0,0,0,this.width,this.height,e.ALPHA,e.UNSIGNED_BYTE,this.data))):(this.texture=e.createTexture(),e.bindTexture(e.TEXTURE_2D,this.texture),e.texParameteri(e.TEXTURE_2D,e.TEXTURE_WRAP_S,e.REPEAT),e.texParameteri(e.TEXTURE_2D,e.TEXTURE_WRAP_T,e.REPEAT),e.texParameteri(e.TEXTURE_2D,e.TEXTURE_MIN_FILTER,e.LINEAR),e.texParameteri(e.TEXTURE_2D,e.TEXTURE_MAG_FILTER,e.LINEAR),e.texImage2D(e.TEXTURE_2D,0,e.ALPHA,this.width,this.height,0,e.ALPHA,e.UNSIGNED_BYTE,this.data))};var k=function e(r,n){this.workerPool=r,this.actors=[],this.currentActor=0,this.id=t.uniqueId();for(var i=this.workerPool.acquire(this.id),a=0;a<i.length;a++){var o=i[a],s=new e.Actor(o,n,this.id);s.name=\"Worker \"+a,this.actors.push(s)}};function M(e,r,n){var i=function(i,a){if(i)return n(i);if(a){var o=t.pick(t.extend(a,e),[\"tiles\",\"minzoom\",\"maxzoom\",\"attribution\",\"mapbox_logo\",\"bounds\",\"scheme\",\"tileSize\",\"encoding\"]);a.vector_layers&&(o.vectorLayers=a.vector_layers,o.vectorLayerIds=o.vectorLayers.map((function(t){return t.id}))),o.tiles=r.canonicalizeTileset(o,e.url),n(null,o)}};return e.url?t.getJSON(r.transformRequest(r.normalizeSourceURL(e.url),t.ResourceType.Source),i):t.browser.frame((function(){return i(null,e)}))}k.prototype.broadcast=function(e,r,n){n=n||function(){},t.asyncAll(this.actors,(function(t,n){t.send(e,r,n)}),n)},k.prototype.getActor=function(){return this.currentActor=(this.currentActor+1)%this.actors.length,this.actors[this.currentActor]},k.prototype.remove=function(){this.actors.forEach((function(t){t.remove()})),this.actors=[],this.workerPool.release(this.id)},k.Actor=t.Actor;var A=function(e,r,n){this.bounds=t.LngLatBounds.convert(this.validateBounds(e)),this.minzoom=r||0,this.maxzoom=n||24};A.prototype.validateBounds=function(t){return Array.isArray(t)&&4===t.length?[Math.max(-180,t[0]),Math.max(-90,t[1]),Math.min(180,t[2]),Math.min(90,t[3])]:[-180,-90,180,90]},A.prototype.contains=function(e){var r=Math.pow(2,e.z),n=Math.floor(t.mercatorXfromLng(this.bounds.getWest())*r),i=Math.floor(t.mercatorYfromLat(this.bounds.getNorth())*r),a=Math.ceil(t.mercatorXfromLng(this.bounds.getEast())*r),o=Math.ceil(t.mercatorYfromLat(this.bounds.getSouth())*r);return e.x>=n&&e.x<a&&e.y>=i&&e.y<o};var S=function(e){function r(r,n,i,a){if(e.call(this),this.id=r,this.dispatcher=i,this.type=\"vector\",this.minzoom=0,this.maxzoom=22,this.scheme=\"xyz\",this.tileSize=512,this.reparseOverscaled=!0,this.isTileClipped=!0,this._loaded=!1,t.extend(this,t.pick(n,[\"url\",\"scheme\",\"tileSize\",\"promoteId\"])),this._options=t.extend({type:\"vector\"},n),this._collectResourceTiming=n.collectResourceTiming,512!==this.tileSize)throw new Error(\"vector tile sources must have a tileSize of 512\");this.setEventedParent(a)}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.load=function(){var e=this;this._loaded=!1,this.fire(new t.Event(\"dataloading\",{dataType:\"source\"})),this._tileJSONRequest=M(this._options,this.map._requestManager,(function(r,n){e._tileJSONRequest=null,e._loaded=!0,r?e.fire(new t.ErrorEvent(r)):n&&(t.extend(e,n),n.bounds&&(e.tileBounds=new A(n.bounds,e.minzoom,e.maxzoom)),t.postTurnstileEvent(n.tiles,e.map._requestManager._customAccessToken),t.postMapLoadEvent(n.tiles,e.map._getMapId(),e.map._requestManager._skuToken,e.map._requestManager._customAccessToken),e.fire(new t.Event(\"data\",{dataType:\"source\",sourceDataType:\"metadata\"})),e.fire(new t.Event(\"data\",{dataType:\"source\",sourceDataType:\"content\"})))}))},r.prototype.loaded=function(){return this._loaded},r.prototype.hasTile=function(t){return!this.tileBounds||this.tileBounds.contains(t.canonical)},r.prototype.onAdd=function(t){this.map=t,this.load()},r.prototype.onRemove=function(){this._tileJSONRequest&&(this._tileJSONRequest.cancel(),this._tileJSONRequest=null)},r.prototype.serialize=function(){return t.extend({},this._options)},r.prototype.loadTile=function(e,r){var n=this.map._requestManager.normalizeTileURL(e.tileID.canonical.url(this.tiles,this.scheme)),i={request:this.map._requestManager.transformRequest(n,t.ResourceType.Tile),uid:e.uid,tileID:e.tileID,zoom:e.tileID.overscaledZ,tileSize:this.tileSize*e.tileID.overscaleFactor(),type:this.type,source:this.id,pixelRatio:t.browser.devicePixelRatio,showCollisionBoxes:this.map.showCollisionBoxes,promoteId:this.promoteId};function a(n,i){return delete e.request,e.aborted?r(null):n&&404!==n.status?r(n):(i&&i.resourceTiming&&(e.resourceTiming=i.resourceTiming),this.map._refreshExpiredTiles&&i&&e.setExpiryData(i),e.loadVectorData(i,this.map.painter),t.cacheEntryPossiblyAdded(this.dispatcher),r(null),void(e.reloadCallback&&(this.loadTile(e,e.reloadCallback),e.reloadCallback=null)))}i.request.collectResourceTiming=this._collectResourceTiming,e.actor&&\"expired\"!==e.state?\"loading\"===e.state?e.reloadCallback=r:e.request=e.actor.send(\"reloadTile\",i,a.bind(this)):(e.actor=this.dispatcher.getActor(),e.request=e.actor.send(\"loadTile\",i,a.bind(this)))},r.prototype.abortTile=function(t){t.request&&(t.request.cancel(),delete t.request),t.actor&&t.actor.send(\"abortTile\",{uid:t.uid,type:this.type,source:this.id},void 0)},r.prototype.unloadTile=function(t){t.unloadVectorData(),t.actor&&t.actor.send(\"removeTile\",{uid:t.uid,type:this.type,source:this.id},void 0)},r.prototype.hasTransition=function(){return!1},r}(t.Evented),E=function(e){function r(r,n,i,a){e.call(this),this.id=r,this.dispatcher=i,this.setEventedParent(a),this.type=\"raster\",this.minzoom=0,this.maxzoom=22,this.roundZoom=!0,this.scheme=\"xyz\",this.tileSize=512,this._loaded=!1,this._options=t.extend({type:\"raster\"},n),t.extend(this,t.pick(n,[\"url\",\"scheme\",\"tileSize\"]))}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.load=function(){var e=this;this._loaded=!1,this.fire(new t.Event(\"dataloading\",{dataType:\"source\"})),this._tileJSONRequest=M(this._options,this.map._requestManager,(function(r,n){e._tileJSONRequest=null,e._loaded=!0,r?e.fire(new t.ErrorEvent(r)):n&&(t.extend(e,n),n.bounds&&(e.tileBounds=new A(n.bounds,e.minzoom,e.maxzoom)),t.postTurnstileEvent(n.tiles),t.postMapLoadEvent(n.tiles,e.map._getMapId(),e.map._requestManager._skuToken),e.fire(new t.Event(\"data\",{dataType:\"source\",sourceDataType:\"metadata\"})),e.fire(new t.Event(\"data\",{dataType:\"source\",sourceDataType:\"content\"})))}))},r.prototype.loaded=function(){return this._loaded},r.prototype.onAdd=function(t){this.map=t,this.load()},r.prototype.onRemove=function(){this._tileJSONRequest&&(this._tileJSONRequest.cancel(),this._tileJSONRequest=null)},r.prototype.serialize=function(){return t.extend({},this._options)},r.prototype.hasTile=function(t){return!this.tileBounds||this.tileBounds.contains(t.canonical)},r.prototype.loadTile=function(e,r){var n=this,i=this.map._requestManager.normalizeTileURL(e.tileID.canonical.url(this.tiles,this.scheme),this.tileSize);e.request=t.getImage(this.map._requestManager.transformRequest(i,t.ResourceType.Tile),(function(i,a){if(delete e.request,e.aborted)e.state=\"unloaded\",r(null);else if(i)e.state=\"errored\",r(i);else if(a){n.map._refreshExpiredTiles&&e.setExpiryData(a),delete a.cacheControl,delete a.expires;var o=n.map.painter.context,s=o.gl;e.texture=n.map.painter.getTileTexture(a.width),e.texture?e.texture.update(a,{useMipmap:!0}):(e.texture=new t.Texture(o,a,s.RGBA,{useMipmap:!0}),e.texture.bind(s.LINEAR,s.CLAMP_TO_EDGE,s.LINEAR_MIPMAP_NEAREST),o.extTextureFilterAnisotropic&&s.texParameterf(s.TEXTURE_2D,o.extTextureFilterAnisotropic.TEXTURE_MAX_ANISOTROPY_EXT,o.extTextureFilterAnisotropicMax)),e.state=\"loaded\",t.cacheEntryPossiblyAdded(n.dispatcher),r(null)}}))},r.prototype.abortTile=function(t,e){t.request&&(t.request.cancel(),delete t.request),e()},r.prototype.unloadTile=function(t,e){t.texture&&this.map.painter.saveTileTexture(t.texture),e()},r.prototype.hasTransition=function(){return!1},r}(t.Evented),L=function(e){function r(r,n,i,a){e.call(this,r,n,i,a),this.type=\"raster-dem\",this.maxzoom=22,this._options=t.extend({type:\"raster-dem\"},n),this.encoding=n.encoding||\"mapbox\"}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.serialize=function(){return{type:\"raster-dem\",url:this.url,tileSize:this.tileSize,tiles:this.tiles,bounds:this.bounds,encoding:this.encoding}},r.prototype.loadTile=function(e,r){var n=this.map._requestManager.normalizeTileURL(e.tileID.canonical.url(this.tiles,this.scheme),this.tileSize);function i(t,n){t&&(e.state=\"errored\",r(t)),n&&(e.dem=n,e.needsHillshadePrepare=!0,e.state=\"loaded\",r(null))}e.request=t.getImage(this.map._requestManager.transformRequest(n,t.ResourceType.Tile),function(n,a){if(delete e.request,e.aborted)e.state=\"unloaded\",r(null);else if(n)e.state=\"errored\",r(n);else if(a){this.map._refreshExpiredTiles&&e.setExpiryData(a),delete a.cacheControl,delete a.expires;var o=t.window.ImageBitmap&&a instanceof t.window.ImageBitmap&&t.offscreenCanvasSupported()?a:t.browser.getImageData(a,1),s={uid:e.uid,coord:e.tileID,source:this.id,rawImageData:o,encoding:this.encoding};e.actor&&\"expired\"!==e.state||(e.actor=this.dispatcher.getActor(),e.actor.send(\"loadDEMTile\",s,i.bind(this)))}}.bind(this)),e.neighboringTiles=this._getNeighboringTiles(e.tileID)},r.prototype._getNeighboringTiles=function(e){var r=e.canonical,n=Math.pow(2,r.z),i=(r.x-1+n)%n,a=0===r.x?e.wrap-1:e.wrap,o=(r.x+1+n)%n,s=r.x+1===n?e.wrap+1:e.wrap,l={};return l[new t.OverscaledTileID(e.overscaledZ,a,r.z,i,r.y).key]={backfilled:!1},l[new t.OverscaledTileID(e.overscaledZ,s,r.z,o,r.y).key]={backfilled:!1},r.y>0&&(l[new t.OverscaledTileID(e.overscaledZ,a,r.z,i,r.y-1).key]={backfilled:!1},l[new t.OverscaledTileID(e.overscaledZ,e.wrap,r.z,r.x,r.y-1).key]={backfilled:!1},l[new t.OverscaledTileID(e.overscaledZ,s,r.z,o,r.y-1).key]={backfilled:!1}),r.y+1<n&&(l[new t.OverscaledTileID(e.overscaledZ,a,r.z,i,r.y+1).key]={backfilled:!1},l[new t.OverscaledTileID(e.overscaledZ,e.wrap,r.z,r.x,r.y+1).key]={backfilled:!1},l[new t.OverscaledTileID(e.overscaledZ,s,r.z,o,r.y+1).key]={backfilled:!1}),l},r.prototype.unloadTile=function(t){t.demTexture&&this.map.painter.saveTileTexture(t.demTexture),t.fbo&&(t.fbo.destroy(),delete t.fbo),t.dem&&delete t.dem,delete t.neighboringTiles,t.state=\"unloaded\",t.actor&&t.actor.send(\"removeDEMTile\",{uid:t.uid,source:this.id})},r}(E),C=function(e){function r(r,n,i,a){e.call(this),this.id=r,this.type=\"geojson\",this.minzoom=0,this.maxzoom=18,this.tileSize=512,this.isTileClipped=!0,this.reparseOverscaled=!0,this._removed=!1,this._loaded=!1,this.actor=i.getActor(),this.setEventedParent(a),this._data=n.data,this._options=t.extend({},n),this._collectResourceTiming=n.collectResourceTiming,this._resourceTiming=[],void 0!==n.maxzoom&&(this.maxzoom=n.maxzoom),n.type&&(this.type=n.type),n.attribution&&(this.attribution=n.attribution),this.promoteId=n.promoteId;var o=t.EXTENT/this.tileSize;this.workerOptions=t.extend({source:this.id,cluster:n.cluster||!1,geojsonVtOptions:{buffer:(void 0!==n.buffer?n.buffer:128)*o,tolerance:(void 0!==n.tolerance?n.tolerance:.375)*o,extent:t.EXTENT,maxZoom:this.maxzoom,lineMetrics:n.lineMetrics||!1,generateId:n.generateId||!1},superclusterOptions:{maxZoom:void 0!==n.clusterMaxZoom?Math.min(n.clusterMaxZoom,this.maxzoom-1):this.maxzoom-1,extent:t.EXTENT,radius:(n.clusterRadius||50)*o,log:!1,generateId:n.generateId||!1},clusterProperties:n.clusterProperties},n.workerOptions)}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.load=function(){var e=this;this.fire(new t.Event(\"dataloading\",{dataType:\"source\"})),this._updateWorkerData((function(r){if(r)e.fire(new t.ErrorEvent(r));else{var n={dataType:\"source\",sourceDataType:\"metadata\"};e._collectResourceTiming&&e._resourceTiming&&e._resourceTiming.length>0&&(n.resourceTiming=e._resourceTiming,e._resourceTiming=[]),e.fire(new t.Event(\"data\",n))}}))},r.prototype.onAdd=function(t){this.map=t,this.load()},r.prototype.setData=function(e){var r=this;return this._data=e,this.fire(new t.Event(\"dataloading\",{dataType:\"source\"})),this._updateWorkerData((function(e){if(e)r.fire(new t.ErrorEvent(e));else{var n={dataType:\"source\",sourceDataType:\"content\"};r._collectResourceTiming&&r._resourceTiming&&r._resourceTiming.length>0&&(n.resourceTiming=r._resourceTiming,r._resourceTiming=[]),r.fire(new t.Event(\"data\",n))}})),this},r.prototype.getClusterExpansionZoom=function(t,e){return this.actor.send(\"geojson.getClusterExpansionZoom\",{clusterId:t,source:this.id},e),this},r.prototype.getClusterChildren=function(t,e){return this.actor.send(\"geojson.getClusterChildren\",{clusterId:t,source:this.id},e),this},r.prototype.getClusterLeaves=function(t,e,r,n){return this.actor.send(\"geojson.getClusterLeaves\",{source:this.id,clusterId:t,limit:e,offset:r},n),this},r.prototype._updateWorkerData=function(e){var r=this;this._loaded=!1;var n=t.extend({},this.workerOptions),i=this._data;\"string\"==typeof i?(n.request=this.map._requestManager.transformRequest(t.browser.resolveURL(i),t.ResourceType.Source),n.request.collectResourceTiming=this._collectResourceTiming):n.data=JSON.stringify(i),this.actor.send(this.type+\".loadData\",n,(function(t,i){r._removed||i&&i.abandoned||(r._loaded=!0,i&&i.resourceTiming&&i.resourceTiming[r.id]&&(r._resourceTiming=i.resourceTiming[r.id].slice(0)),r.actor.send(r.type+\".coalesce\",{source:n.source},null),e(t))}))},r.prototype.loaded=function(){return this._loaded},r.prototype.loadTile=function(e,r){var n=this,i=e.actor?\"reloadTile\":\"loadTile\";e.actor=this.actor;var a={type:this.type,uid:e.uid,tileID:e.tileID,zoom:e.tileID.overscaledZ,maxZoom:this.maxzoom,tileSize:this.tileSize,source:this.id,pixelRatio:t.browser.devicePixelRatio,showCollisionBoxes:this.map.showCollisionBoxes,promoteId:this.promoteId};e.request=this.actor.send(i,a,(function(t,a){return delete e.request,e.unloadVectorData(),e.aborted?r(null):t?r(t):(e.loadVectorData(a,n.map.painter,\"reloadTile\"===i),r(null))}))},r.prototype.abortTile=function(t){t.request&&(t.request.cancel(),delete t.request),t.aborted=!0},r.prototype.unloadTile=function(t){t.unloadVectorData(),this.actor.send(\"removeTile\",{uid:t.uid,type:this.type,source:this.id})},r.prototype.onRemove=function(){this._removed=!0,this.actor.send(\"removeSource\",{type:this.type,source:this.id})},r.prototype.serialize=function(){return t.extend({},this._options,{type:this.type,data:this._data})},r.prototype.hasTransition=function(){return!1},r}(t.Evented),P=t.createLayout([{name:\"a_pos\",type:\"Int16\",components:2},{name:\"a_texture_pos\",type:\"Int16\",components:2}]),I=function(e){function r(t,r,n,i){e.call(this),this.id=t,this.dispatcher=n,this.coordinates=r.coordinates,this.type=\"image\",this.minzoom=0,this.maxzoom=22,this.tileSize=512,this.tiles={},this._loaded=!1,this.setEventedParent(i),this.options=r}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.load=function(e,r){var n=this;this._loaded=!1,this.fire(new t.Event(\"dataloading\",{dataType:\"source\"})),this.url=this.options.url,t.getImage(this.map._requestManager.transformRequest(this.url,t.ResourceType.Image),(function(i,a){n._loaded=!0,i?n.fire(new t.ErrorEvent(i)):a&&(n.image=a,e&&(n.coordinates=e),r&&r(),n._finishLoading())}))},r.prototype.loaded=function(){return this._loaded},r.prototype.updateImage=function(t){var e=this;return this.image&&t.url?(this.options.url=t.url,this.load(t.coordinates,(function(){e.texture=null})),this):this},r.prototype._finishLoading=function(){this.map&&(this.setCoordinates(this.coordinates),this.fire(new t.Event(\"data\",{dataType:\"source\",sourceDataType:\"metadata\"})))},r.prototype.onAdd=function(t){this.map=t,this.load()},r.prototype.setCoordinates=function(e){var r=this;this.coordinates=e;var n=e.map(t.MercatorCoordinate.fromLngLat);this.tileID=function(e){for(var r=1/0,n=1/0,i=-1/0,a=-1/0,o=0,s=e;o<s.length;o+=1){var l=s[o];r=Math.min(r,l.x),n=Math.min(n,l.y),i=Math.max(i,l.x),a=Math.max(a,l.y)}var c=i-r,u=a-n,f=Math.max(c,u),h=Math.max(0,Math.floor(-Math.log(f)/Math.LN2)),p=Math.pow(2,h);return new t.CanonicalTileID(h,Math.floor((r+i)/2*p),Math.floor((n+a)/2*p))}(n),this.minzoom=this.maxzoom=this.tileID.z;var i=n.map((function(t){return r.tileID.getTilePoint(t)._round()}));return this._boundsArray=new t.StructArrayLayout4i8,this._boundsArray.emplaceBack(i[0].x,i[0].y,0,0),this._boundsArray.emplaceBack(i[1].x,i[1].y,t.EXTENT,0),this._boundsArray.emplaceBack(i[3].x,i[3].y,0,t.EXTENT),this._boundsArray.emplaceBack(i[2].x,i[2].y,t.EXTENT,t.EXTENT),this.boundsBuffer&&(this.boundsBuffer.destroy(),delete this.boundsBuffer),this.fire(new t.Event(\"data\",{dataType:\"source\",sourceDataType:\"content\"})),this},r.prototype.prepare=function(){if(0!==Object.keys(this.tiles).length&&this.image){var e=this.map.painter.context,r=e.gl;for(var n in this.boundsBuffer||(this.boundsBuffer=e.createVertexBuffer(this._boundsArray,P.members)),this.boundsSegments||(this.boundsSegments=t.SegmentVector.simpleSegment(0,0,4,2)),this.texture||(this.texture=new t.Texture(e,this.image,r.RGBA),this.texture.bind(r.LINEAR,r.CLAMP_TO_EDGE)),this.tiles){var i=this.tiles[n];\"loaded\"!==i.state&&(i.state=\"loaded\",i.texture=this.texture)}}},r.prototype.loadTile=function(t,e){this.tileID&&this.tileID.equals(t.tileID.canonical)?(this.tiles[String(t.tileID.wrap)]=t,t.buckets={},e(null)):(t.state=\"errored\",e(null))},r.prototype.serialize=function(){return{type:\"image\",url:this.options.url,coordinates:this.coordinates}},r.prototype.hasTransition=function(){return!1},r}(t.Evented);var O=function(e){function r(t,r,n,i){e.call(this,t,r,n,i),this.roundZoom=!0,this.type=\"video\",this.options=r}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.load=function(){var e=this;this._loaded=!1;var r=this.options;this.urls=[];for(var n=0,i=r.urls;n<i.length;n+=1){var a=i[n];this.urls.push(this.map._requestManager.transformRequest(a,t.ResourceType.Source).url)}t.getVideo(this.urls,(function(r,n){e._loaded=!0,r?e.fire(new t.ErrorEvent(r)):n&&(e.video=n,e.video.loop=!0,e.video.addEventListener(\"playing\",(function(){e.map.triggerRepaint()})),e.map&&e.video.play(),e._finishLoading())}))},r.prototype.pause=function(){this.video&&this.video.pause()},r.prototype.play=function(){this.video&&this.video.play()},r.prototype.seek=function(e){if(this.video){var r=this.video.seekable;e<r.start(0)||e>r.end(0)?this.fire(new t.ErrorEvent(new t.ValidationError(\"sources.\"+this.id,null,\"Playback for this video can be set only between the \"+r.start(0)+\" and \"+r.end(0)+\"-second mark.\"))):this.video.currentTime=e}},r.prototype.getVideo=function(){return this.video},r.prototype.onAdd=function(t){this.map||(this.map=t,this.load(),this.video&&(this.video.play(),this.setCoordinates(this.coordinates)))},r.prototype.prepare=function(){if(!(0===Object.keys(this.tiles).length||this.video.readyState<2)){var e=this.map.painter.context,r=e.gl;for(var n in this.boundsBuffer||(this.boundsBuffer=e.createVertexBuffer(this._boundsArray,P.members)),this.boundsSegments||(this.boundsSegments=t.SegmentVector.simpleSegment(0,0,4,2)),this.texture?this.video.paused||(this.texture.bind(r.LINEAR,r.CLAMP_TO_EDGE),r.texSubImage2D(r.TEXTURE_2D,0,0,0,r.RGBA,r.UNSIGNED_BYTE,this.video)):(this.texture=new t.Texture(e,this.video,r.RGBA),this.texture.bind(r.LINEAR,r.CLAMP_TO_EDGE)),this.tiles){var i=this.tiles[n];\"loaded\"!==i.state&&(i.state=\"loaded\",i.texture=this.texture)}}},r.prototype.serialize=function(){return{type:\"video\",urls:this.urls,coordinates:this.coordinates}},r.prototype.hasTransition=function(){return this.video&&!this.video.paused},r}(I),z=function(e){function r(r,n,i,a){e.call(this,r,n,i,a),n.coordinates?Array.isArray(n.coordinates)&&4===n.coordinates.length&&!n.coordinates.some((function(t){return!Array.isArray(t)||2!==t.length||t.some((function(t){return\"number\"!=typeof t}))}))||this.fire(new t.ErrorEvent(new t.ValidationError(\"sources.\"+r,null,'\"coordinates\" property must be an array of 4 longitude/latitude array pairs'))):this.fire(new t.ErrorEvent(new t.ValidationError(\"sources.\"+r,null,'missing required property \"coordinates\"'))),n.animate&&\"boolean\"!=typeof n.animate&&this.fire(new t.ErrorEvent(new t.ValidationError(\"sources.\"+r,null,'optional \"animate\" property must be a boolean value'))),n.canvas?\"string\"==typeof n.canvas||n.canvas instanceof t.window.HTMLCanvasElement||this.fire(new t.ErrorEvent(new t.ValidationError(\"sources.\"+r,null,'\"canvas\" must be either a string representing the ID of the canvas element from which to read, or an HTMLCanvasElement instance'))):this.fire(new t.ErrorEvent(new t.ValidationError(\"sources.\"+r,null,'missing required property \"canvas\"'))),this.options=n,this.animate=void 0===n.animate||n.animate}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.load=function(){this._loaded=!0,this.canvas||(this.canvas=this.options.canvas instanceof t.window.HTMLCanvasElement?this.options.canvas:t.window.document.getElementById(this.options.canvas)),this.width=this.canvas.width,this.height=this.canvas.height,this._hasInvalidDimensions()?this.fire(new t.ErrorEvent(new Error(\"Canvas dimensions cannot be less than or equal to zero.\"))):(this.play=function(){this._playing=!0,this.map.triggerRepaint()},this.pause=function(){this._playing&&(this.prepare(),this._playing=!1)},this._finishLoading())},r.prototype.getCanvas=function(){return this.canvas},r.prototype.onAdd=function(t){this.map=t,this.load(),this.canvas&&this.animate&&this.play()},r.prototype.onRemove=function(){this.pause()},r.prototype.prepare=function(){var e=!1;if(this.canvas.width!==this.width&&(this.width=this.canvas.width,e=!0),this.canvas.height!==this.height&&(this.height=this.canvas.height,e=!0),!this._hasInvalidDimensions()&&0!==Object.keys(this.tiles).length){var r=this.map.painter.context,n=r.gl;for(var i in this.boundsBuffer||(this.boundsBuffer=r.createVertexBuffer(this._boundsArray,P.members)),this.boundsSegments||(this.boundsSegments=t.SegmentVector.simpleSegment(0,0,4,2)),this.texture?(e||this._playing)&&this.texture.update(this.canvas,{premultiply:!0}):this.texture=new t.Texture(r,this.canvas,n.RGBA,{premultiply:!0}),this.tiles){var a=this.tiles[i];\"loaded\"!==a.state&&(a.state=\"loaded\",a.texture=this.texture)}}},r.prototype.serialize=function(){return{type:\"canvas\",coordinates:this.coordinates}},r.prototype.hasTransition=function(){return this._playing},r.prototype._hasInvalidDimensions=function(){for(var t=0,e=[this.canvas.width,this.canvas.height];t<e.length;t+=1){var r=e[t];if(isNaN(r)||r<=0)return!0}return!1},r}(I),D={vector:S,raster:E,\"raster-dem\":L,geojson:C,video:O,image:I,canvas:z};function R(e,r){var n=t.identity([]);return t.translate(n,n,[1,1,0]),t.scale(n,n,[.5*e.width,.5*e.height,1]),t.multiply(n,n,e.calculatePosMatrix(r.toUnwrapped()))}function F(t,e,r,n,i,a){var o=function(t,e,r){if(t)for(var n=0,i=t;n<i.length;n+=1){var a=e[i[n]];if(a&&a.source===r&&\"fill-extrusion\"===a.type)return!0}else for(var o in e){var s=e[o];if(s.source===r&&\"fill-extrusion\"===s.type)return!0}return!1}(i&&i.layers,e,t.id),s=a.maxPitchScaleFactor(),l=t.tilesIn(n,s,o);l.sort(B);for(var c=[],u=0,f=l;u<f.length;u+=1){var h=f[u];c.push({wrappedTileID:h.tileID.wrapped().key,queryResults:h.tile.queryRenderedFeatures(e,r,t._state,h.queryGeometry,h.cameraQueryGeometry,h.scale,i,a,s,R(t.transform,h.tileID))})}var p=function(t){for(var e={},r={},n=0,i=t;n<i.length;n+=1){var a=i[n],o=a.queryResults,s=a.wrappedTileID,l=r[s]=r[s]||{};for(var c in o)for(var u=o[c],f=l[c]=l[c]||{},h=e[c]=e[c]||[],p=0,d=u;p<d.length;p+=1){var m=d[p];f[m.featureIndex]||(f[m.featureIndex]=!0,h.push(m))}}return e}(c);for(var d in p)p[d].forEach((function(e){var r=e.feature,n=t.getFeatureState(r.layer[\"source-layer\"],r.id);r.source=r.layer.source,r.layer[\"source-layer\"]&&(r.sourceLayer=r.layer[\"source-layer\"]),r.state=n}));return p}function B(t,e){var r=t.tileID,n=e.tileID;return r.overscaledZ-n.overscaledZ||r.canonical.y-n.canonical.y||r.wrap-n.wrap||r.canonical.x-n.canonical.x}var N=function(t,e){this.max=t,this.onRemove=e,this.reset()};N.prototype.reset=function(){for(var t in this.data)for(var e=0,r=this.data[t];e<r.length;e+=1){var n=r[e];n.timeout&&clearTimeout(n.timeout),this.onRemove(n.value)}return this.data={},this.order=[],this},N.prototype.add=function(t,e,r){var n=this,i=t.wrapped().key;void 0===this.data[i]&&(this.data[i]=[]);var a={value:e,timeout:void 0};if(void 0!==r&&(a.timeout=setTimeout((function(){n.remove(t,a)}),r)),this.data[i].push(a),this.order.push(i),this.order.length>this.max){var o=this._getAndRemoveByKey(this.order[0]);o&&this.onRemove(o)}return this},N.prototype.has=function(t){return t.wrapped().key in this.data},N.prototype.getAndRemove=function(t){return this.has(t)?this._getAndRemoveByKey(t.wrapped().key):null},N.prototype._getAndRemoveByKey=function(t){var e=this.data[t].shift();return e.timeout&&clearTimeout(e.timeout),0===this.data[t].length&&delete this.data[t],this.order.splice(this.order.indexOf(t),1),e.value},N.prototype.getByKey=function(t){var e=this.data[t];return e?e[0].value:null},N.prototype.get=function(t){return this.has(t)?this.data[t.wrapped().key][0].value:null},N.prototype.remove=function(t,e){if(!this.has(t))return this;var r=t.wrapped().key,n=void 0===e?0:this.data[r].indexOf(e),i=this.data[r][n];return this.data[r].splice(n,1),i.timeout&&clearTimeout(i.timeout),0===this.data[r].length&&delete this.data[r],this.onRemove(i.value),this.order.splice(this.order.indexOf(r),1),this},N.prototype.setMaxSize=function(t){for(this.max=t;this.order.length>this.max;){var e=this._getAndRemoveByKey(this.order[0]);e&&this.onRemove(e)}return this},N.prototype.filter=function(t){var e=[];for(var r in this.data)for(var n=0,i=this.data[r];n<i.length;n+=1){var a=i[n];t(a.value)||e.push(a)}for(var o=0,s=e;o<s.length;o+=1){var l=s[o];this.remove(l.value.tileID,l)}};var j=function(t,e,r){this.context=t;var n=t.gl;this.buffer=n.createBuffer(),this.dynamicDraw=Boolean(r),this.context.unbindVAO(),t.bindElementBuffer.set(this.buffer),n.bufferData(n.ELEMENT_ARRAY_BUFFER,e.arrayBuffer,this.dynamicDraw?n.DYNAMIC_DRAW:n.STATIC_DRAW),this.dynamicDraw||delete e.arrayBuffer};j.prototype.bind=function(){this.context.bindElementBuffer.set(this.buffer)},j.prototype.updateData=function(t){var e=this.context.gl;this.context.unbindVAO(),this.bind(),e.bufferSubData(e.ELEMENT_ARRAY_BUFFER,0,t.arrayBuffer)},j.prototype.destroy=function(){var t=this.context.gl;this.buffer&&(t.deleteBuffer(this.buffer),delete this.buffer)};var U={Int8:\"BYTE\",Uint8:\"UNSIGNED_BYTE\",Int16:\"SHORT\",Uint16:\"UNSIGNED_SHORT\",Int32:\"INT\",Uint32:\"UNSIGNED_INT\",Float32:\"FLOAT\"},V=function(t,e,r,n){this.length=e.length,this.attributes=r,this.itemSize=e.bytesPerElement,this.dynamicDraw=n,this.context=t;var i=t.gl;this.buffer=i.createBuffer(),t.bindVertexBuffer.set(this.buffer),i.bufferData(i.ARRAY_BUFFER,e.arrayBuffer,this.dynamicDraw?i.DYNAMIC_DRAW:i.STATIC_DRAW),this.dynamicDraw||delete e.arrayBuffer};V.prototype.bind=function(){this.context.bindVertexBuffer.set(this.buffer)},V.prototype.updateData=function(t){var e=this.context.gl;this.bind(),e.bufferSubData(e.ARRAY_BUFFER,0,t.arrayBuffer)},V.prototype.enableAttributes=function(t,e){for(var r=0;r<this.attributes.length;r++){var n=this.attributes[r],i=e.attributes[n.name];void 0!==i&&t.enableVertexAttribArray(i)}},V.prototype.setVertexAttribPointers=function(t,e,r){for(var n=0;n<this.attributes.length;n++){var i=this.attributes[n],a=e.attributes[i.name];void 0!==a&&t.vertexAttribPointer(a,i.components,t[U[i.type]],!1,this.itemSize,i.offset+this.itemSize*(r||0))}},V.prototype.destroy=function(){var t=this.context.gl;this.buffer&&(t.deleteBuffer(this.buffer),delete this.buffer)};var q=function(t){this.gl=t.gl,this.default=this.getDefault(),this.current=this.default,this.dirty=!1};q.prototype.get=function(){return this.current},q.prototype.set=function(t){},q.prototype.getDefault=function(){return this.default},q.prototype.setDefault=function(){this.set(this.default)};var H=function(e){function r(){e.apply(this,arguments)}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.getDefault=function(){return t.Color.transparent},r.prototype.set=function(t){var e=this.current;(t.r!==e.r||t.g!==e.g||t.b!==e.b||t.a!==e.a||this.dirty)&&(this.gl.clearColor(t.r,t.g,t.b,t.a),this.current=t,this.dirty=!1)},r}(q),G=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return 1},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.clearDepth(t),this.current=t,this.dirty=!1)},e}(q),Y=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return 0},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.clearStencil(t),this.current=t,this.dirty=!1)},e}(q),W=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return[!0,!0,!0,!0]},e.prototype.set=function(t){var e=this.current;(t[0]!==e[0]||t[1]!==e[1]||t[2]!==e[2]||t[3]!==e[3]||this.dirty)&&(this.gl.colorMask(t[0],t[1],t[2],t[3]),this.current=t,this.dirty=!1)},e}(q),X=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return!0},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.depthMask(t),this.current=t,this.dirty=!1)},e}(q),Z=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return 255},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.stencilMask(t),this.current=t,this.dirty=!1)},e}(q),J=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return{func:this.gl.ALWAYS,ref:0,mask:255}},e.prototype.set=function(t){var e=this.current;(t.func!==e.func||t.ref!==e.ref||t.mask!==e.mask||this.dirty)&&(this.gl.stencilFunc(t.func,t.ref,t.mask),this.current=t,this.dirty=!1)},e}(q),K=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){var t=this.gl;return[t.KEEP,t.KEEP,t.KEEP]},e.prototype.set=function(t){var e=this.current;(t[0]!==e[0]||t[1]!==e[1]||t[2]!==e[2]||this.dirty)&&(this.gl.stencilOp(t[0],t[1],t[2]),this.current=t,this.dirty=!1)},e}(q),Q=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return!1},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;t?e.enable(e.STENCIL_TEST):e.disable(e.STENCIL_TEST),this.current=t,this.dirty=!1}},e}(q),$=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return[0,1]},e.prototype.set=function(t){var e=this.current;(t[0]!==e[0]||t[1]!==e[1]||this.dirty)&&(this.gl.depthRange(t[0],t[1]),this.current=t,this.dirty=!1)},e}(q),tt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return!1},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;t?e.enable(e.DEPTH_TEST):e.disable(e.DEPTH_TEST),this.current=t,this.dirty=!1}},e}(q),et=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return this.gl.LESS},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.depthFunc(t),this.current=t,this.dirty=!1)},e}(q),rt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return!1},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;t?e.enable(e.BLEND):e.disable(e.BLEND),this.current=t,this.dirty=!1}},e}(q),nt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){var t=this.gl;return[t.ONE,t.ZERO]},e.prototype.set=function(t){var e=this.current;(t[0]!==e[0]||t[1]!==e[1]||this.dirty)&&(this.gl.blendFunc(t[0],t[1]),this.current=t,this.dirty=!1)},e}(q),it=function(e){function r(){e.apply(this,arguments)}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.getDefault=function(){return t.Color.transparent},r.prototype.set=function(t){var e=this.current;(t.r!==e.r||t.g!==e.g||t.b!==e.b||t.a!==e.a||this.dirty)&&(this.gl.blendColor(t.r,t.g,t.b,t.a),this.current=t,this.dirty=!1)},r}(q),at=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return this.gl.FUNC_ADD},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.blendEquation(t),this.current=t,this.dirty=!1)},e}(q),ot=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return!1},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;t?e.enable(e.CULL_FACE):e.disable(e.CULL_FACE),this.current=t,this.dirty=!1}},e}(q),st=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return this.gl.BACK},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.cullFace(t),this.current=t,this.dirty=!1)},e}(q),lt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return this.gl.CCW},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.frontFace(t),this.current=t,this.dirty=!1)},e}(q),ct=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return null},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.useProgram(t),this.current=t,this.dirty=!1)},e}(q),ut=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return this.gl.TEXTURE0},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.activeTexture(t),this.current=t,this.dirty=!1)},e}(q),ft=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){var t=this.gl;return[0,0,t.drawingBufferWidth,t.drawingBufferHeight]},e.prototype.set=function(t){var e=this.current;(t[0]!==e[0]||t[1]!==e[1]||t[2]!==e[2]||t[3]!==e[3]||this.dirty)&&(this.gl.viewport(t[0],t[1],t[2],t[3]),this.current=t,this.dirty=!1)},e}(q),ht=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return null},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;e.bindFramebuffer(e.FRAMEBUFFER,t),this.current=t,this.dirty=!1}},e}(q),pt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return null},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;e.bindRenderbuffer(e.RENDERBUFFER,t),this.current=t,this.dirty=!1}},e}(q),dt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return null},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;e.bindTexture(e.TEXTURE_2D,t),this.current=t,this.dirty=!1}},e}(q),mt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return null},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;e.bindBuffer(e.ARRAY_BUFFER,t),this.current=t,this.dirty=!1}},e}(q),gt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return null},e.prototype.set=function(t){var e=this.gl;e.bindBuffer(e.ELEMENT_ARRAY_BUFFER,t),this.current=t,this.dirty=!1},e}(q),vt=function(t){function e(e){t.call(this,e),this.vao=e.extVertexArrayObject}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return null},e.prototype.set=function(t){this.vao&&(t!==this.current||this.dirty)&&(this.vao.bindVertexArrayOES(t),this.current=t,this.dirty=!1)},e}(q),yt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return 4},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;e.pixelStorei(e.UNPACK_ALIGNMENT,t),this.current=t,this.dirty=!1}},e}(q),xt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return!1},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;e.pixelStorei(e.UNPACK_PREMULTIPLY_ALPHA_WEBGL,t),this.current=t,this.dirty=!1}},e}(q),bt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return!1},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;e.pixelStorei(e.UNPACK_FLIP_Y_WEBGL,t),this.current=t,this.dirty=!1}},e}(q),_t=function(t){function e(e,r){t.call(this,e),this.context=e,this.parent=r}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.getDefault=function(){return null},e}(q),wt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.setDirty=function(){this.dirty=!0},e.prototype.set=function(t){if(t!==this.current||this.dirty){this.context.bindFramebuffer.set(this.parent);var e=this.gl;e.framebufferTexture2D(e.FRAMEBUFFER,e.COLOR_ATTACHMENT0,e.TEXTURE_2D,t,0),this.current=t,this.dirty=!1}},e}(_t),Tt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.set=function(t){if(t!==this.current||this.dirty){this.context.bindFramebuffer.set(this.parent);var e=this.gl;e.framebufferRenderbuffer(e.FRAMEBUFFER,e.DEPTH_ATTACHMENT,e.RENDERBUFFER,t),this.current=t,this.dirty=!1}},e}(_t),kt=function(t,e,r,n){this.context=t,this.width=e,this.height=r;var i=t.gl,a=this.framebuffer=i.createFramebuffer();this.colorAttachment=new wt(t,a),n&&(this.depthAttachment=new Tt(t,a))};kt.prototype.destroy=function(){var t=this.context.gl,e=this.colorAttachment.get();if(e&&t.deleteTexture(e),this.depthAttachment){var r=this.depthAttachment.get();r&&t.deleteRenderbuffer(r)}t.deleteFramebuffer(this.framebuffer)};var Mt=function(t,e,r){this.func=t,this.mask=e,this.range=r};Mt.ReadOnly=!1,Mt.ReadWrite=!0,Mt.disabled=new Mt(519,Mt.ReadOnly,[0,1]);var At=function(t,e,r,n,i,a){this.test=t,this.ref=e,this.mask=r,this.fail=n,this.depthFail=i,this.pass=a};At.disabled=new At({func:519,mask:0},0,0,7680,7680,7680);var St=function(t,e,r){this.blendFunction=t,this.blendColor=e,this.mask=r};St.disabled=new St(St.Replace=[1,0],t.Color.transparent,[!1,!1,!1,!1]),St.unblended=new St(St.Replace,t.Color.transparent,[!0,!0,!0,!0]),St.alphaBlended=new St([1,771],t.Color.transparent,[!0,!0,!0,!0]);var Et=function(t,e,r){this.enable=t,this.mode=e,this.frontFace=r};Et.disabled=new Et(!1,1029,2305),Et.backCCW=new Et(!0,1029,2305);var Lt=function(t){this.gl=t,this.extVertexArrayObject=this.gl.getExtension(\"OES_vertex_array_object\"),this.clearColor=new H(this),this.clearDepth=new G(this),this.clearStencil=new Y(this),this.colorMask=new W(this),this.depthMask=new X(this),this.stencilMask=new Z(this),this.stencilFunc=new J(this),this.stencilOp=new K(this),this.stencilTest=new Q(this),this.depthRange=new $(this),this.depthTest=new tt(this),this.depthFunc=new et(this),this.blend=new rt(this),this.blendFunc=new nt(this),this.blendColor=new it(this),this.blendEquation=new at(this),this.cullFace=new ot(this),this.cullFaceSide=new st(this),this.frontFace=new lt(this),this.program=new ct(this),this.activeTexture=new ut(this),this.viewport=new ft(this),this.bindFramebuffer=new ht(this),this.bindRenderbuffer=new pt(this),this.bindTexture=new dt(this),this.bindVertexBuffer=new mt(this),this.bindElementBuffer=new gt(this),this.bindVertexArrayOES=this.extVertexArrayObject&&new vt(this),this.pixelStoreUnpack=new yt(this),this.pixelStoreUnpackPremultiplyAlpha=new xt(this),this.pixelStoreUnpackFlipY=new bt(this),this.extTextureFilterAnisotropic=t.getExtension(\"EXT_texture_filter_anisotropic\")||t.getExtension(\"MOZ_EXT_texture_filter_anisotropic\")||t.getExtension(\"WEBKIT_EXT_texture_filter_anisotropic\"),this.extTextureFilterAnisotropic&&(this.extTextureFilterAnisotropicMax=t.getParameter(this.extTextureFilterAnisotropic.MAX_TEXTURE_MAX_ANISOTROPY_EXT)),this.extTextureHalfFloat=t.getExtension(\"OES_texture_half_float\"),this.extTextureHalfFloat&&(t.getExtension(\"OES_texture_half_float_linear\"),this.extRenderToTextureHalfFloat=t.getExtension(\"EXT_color_buffer_half_float\")),this.extTimerQuery=t.getExtension(\"EXT_disjoint_timer_query\")};Lt.prototype.setDefault=function(){this.unbindVAO(),this.clearColor.setDefault(),this.clearDepth.setDefault(),this.clearStencil.setDefault(),this.colorMask.setDefault(),this.depthMask.setDefault(),this.stencilMask.setDefault(),this.stencilFunc.setDefault(),this.stencilOp.setDefault(),this.stencilTest.setDefault(),this.depthRange.setDefault(),this.depthTest.setDefault(),this.depthFunc.setDefault(),this.blend.setDefault(),this.blendFunc.setDefault(),this.blendColor.setDefault(),this.blendEquation.setDefault(),this.cullFace.setDefault(),this.cullFaceSide.setDefault(),this.frontFace.setDefault(),this.program.setDefault(),this.activeTexture.setDefault(),this.bindFramebuffer.setDefault(),this.pixelStoreUnpack.setDefault(),this.pixelStoreUnpackPremultiplyAlpha.setDefault(),this.pixelStoreUnpackFlipY.setDefault()},Lt.prototype.setDirty=function(){this.clearColor.dirty=!0,this.clearDepth.dirty=!0,this.clearStencil.dirty=!0,this.colorMask.dirty=!0,this.depthMask.dirty=!0,this.stencilMask.dirty=!0,this.stencilFunc.dirty=!0,this.stencilOp.dirty=!0,this.stencilTest.dirty=!0,this.depthRange.dirty=!0,this.depthTest.dirty=!0,this.depthFunc.dirty=!0,this.blend.dirty=!0,this.blendFunc.dirty=!0,this.blendColor.dirty=!0,this.blendEquation.dirty=!0,this.cullFace.dirty=!0,this.cullFaceSide.dirty=!0,this.frontFace.dirty=!0,this.program.dirty=!0,this.activeTexture.dirty=!0,this.viewport.dirty=!0,this.bindFramebuffer.dirty=!0,this.bindRenderbuffer.dirty=!0,this.bindTexture.dirty=!0,this.bindVertexBuffer.dirty=!0,this.bindElementBuffer.dirty=!0,this.extVertexArrayObject&&(this.bindVertexArrayOES.dirty=!0),this.pixelStoreUnpack.dirty=!0,this.pixelStoreUnpackPremultiplyAlpha.dirty=!0,this.pixelStoreUnpackFlipY.dirty=!0},Lt.prototype.createIndexBuffer=function(t,e){return new j(this,t,e)},Lt.prototype.createVertexBuffer=function(t,e,r){return new V(this,t,e,r)},Lt.prototype.createRenderbuffer=function(t,e,r){var n=this.gl,i=n.createRenderbuffer();return this.bindRenderbuffer.set(i),n.renderbufferStorage(n.RENDERBUFFER,t,e,r),this.bindRenderbuffer.set(null),i},Lt.prototype.createFramebuffer=function(t,e,r){return new kt(this,t,e,r)},Lt.prototype.clear=function(t){var e=t.color,r=t.depth,n=this.gl,i=0;e&&(i|=n.COLOR_BUFFER_BIT,this.clearColor.set(e),this.colorMask.set([!0,!0,!0,!0])),void 0!==r&&(i|=n.DEPTH_BUFFER_BIT,this.depthRange.set([0,1]),this.clearDepth.set(r),this.depthMask.set(!0)),n.clear(i)},Lt.prototype.setCullFace=function(t){!1===t.enable?this.cullFace.set(!1):(this.cullFace.set(!0),this.cullFaceSide.set(t.mode),this.frontFace.set(t.frontFace))},Lt.prototype.setDepthMode=function(t){t.func!==this.gl.ALWAYS||t.mask?(this.depthTest.set(!0),this.depthFunc.set(t.func),this.depthMask.set(t.mask),this.depthRange.set(t.range)):this.depthTest.set(!1)},Lt.prototype.setStencilMode=function(t){t.test.func!==this.gl.ALWAYS||t.mask?(this.stencilTest.set(!0),this.stencilMask.set(t.mask),this.stencilOp.set([t.fail,t.depthFail,t.pass]),this.stencilFunc.set({func:t.test.func,ref:t.ref,mask:t.test.mask})):this.stencilTest.set(!1)},Lt.prototype.setColorMode=function(e){t.deepEqual(e.blendFunction,St.Replace)?this.blend.set(!1):(this.blend.set(!0),this.blendFunc.set(e.blendFunction),this.blendColor.set(e.blendColor)),this.colorMask.set(e.mask)},Lt.prototype.unbindVAO=function(){this.extVertexArrayObject&&this.bindVertexArrayOES.set(null)};var Ct=function(e){function r(r,n,i){var a=this;e.call(this),this.id=r,this.dispatcher=i,this.on(\"data\",(function(t){\"source\"===t.dataType&&\"metadata\"===t.sourceDataType&&(a._sourceLoaded=!0),a._sourceLoaded&&!a._paused&&\"source\"===t.dataType&&\"content\"===t.sourceDataType&&(a.reload(),a.transform&&a.update(a.transform))})),this.on(\"error\",(function(){a._sourceErrored=!0})),this._source=function(e,r,n,i){var a=new D[r.type](e,r,n,i);if(a.id!==e)throw new Error(\"Expected Source id to be \"+e+\" instead of \"+a.id);return t.bindAll([\"load\",\"abort\",\"unload\",\"serialize\",\"prepare\"],a),a}(r,n,i,this),this._tiles={},this._cache=new N(0,this._unloadTile.bind(this)),this._timers={},this._cacheTimers={},this._maxTileCacheSize=null,this._loadedParentTiles={},this._coveredTiles={},this._state=new t.SourceFeatureState}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.onAdd=function(t){this.map=t,this._maxTileCacheSize=t?t._maxTileCacheSize:null,this._source&&this._source.onAdd&&this._source.onAdd(t)},r.prototype.onRemove=function(t){this._source&&this._source.onRemove&&this._source.onRemove(t)},r.prototype.loaded=function(){if(this._sourceErrored)return!0;if(!this._sourceLoaded)return!1;if(!this._source.loaded())return!1;for(var t in this._tiles){var e=this._tiles[t];if(\"loaded\"!==e.state&&\"errored\"!==e.state)return!1}return!0},r.prototype.getSource=function(){return this._source},r.prototype.pause=function(){this._paused=!0},r.prototype.resume=function(){if(this._paused){var t=this._shouldReloadOnResume;this._paused=!1,this._shouldReloadOnResume=!1,t&&this.reload(),this.transform&&this.update(this.transform)}},r.prototype._loadTile=function(t,e){return this._source.loadTile(t,e)},r.prototype._unloadTile=function(t){if(this._source.unloadTile)return this._source.unloadTile(t,(function(){}))},r.prototype._abortTile=function(t){if(this._source.abortTile)return this._source.abortTile(t,(function(){}))},r.prototype.serialize=function(){return this._source.serialize()},r.prototype.prepare=function(t){for(var e in this._source.prepare&&this._source.prepare(),this._state.coalesceChanges(this._tiles,this.map?this.map.painter:null),this._tiles){var r=this._tiles[e];r.upload(t),r.prepare(this.map.style.imageManager)}},r.prototype.getIds=function(){return t.values(this._tiles).map((function(t){return t.tileID})).sort(Pt).map((function(t){return t.key}))},r.prototype.getRenderableIds=function(e){var r=this,n=[];for(var i in this._tiles)this._isIdRenderable(i,e)&&n.push(this._tiles[i]);return e?n.sort((function(e,n){var i=e.tileID,a=n.tileID,o=new t.Point(i.canonical.x,i.canonical.y)._rotate(r.transform.angle),s=new t.Point(a.canonical.x,a.canonical.y)._rotate(r.transform.angle);return i.overscaledZ-a.overscaledZ||s.y-o.y||s.x-o.x})).map((function(t){return t.tileID.key})):n.map((function(t){return t.tileID})).sort(Pt).map((function(t){return t.key}))},r.prototype.hasRenderableParent=function(t){var e=this.findLoadedParent(t,0);return!!e&&this._isIdRenderable(e.tileID.key)},r.prototype._isIdRenderable=function(t,e){return this._tiles[t]&&this._tiles[t].hasData()&&!this._coveredTiles[t]&&(e||!this._tiles[t].holdingForFade())},r.prototype.reload=function(){if(this._paused)this._shouldReloadOnResume=!0;else for(var t in this._cache.reset(),this._tiles)\"errored\"!==this._tiles[t].state&&this._reloadTile(t,\"reloading\")},r.prototype._reloadTile=function(t,e){var r=this._tiles[t];r&&(\"loading\"!==r.state&&(r.state=e),this._loadTile(r,this._tileLoaded.bind(this,r,t,e)))},r.prototype._tileLoaded=function(e,r,n,i){if(i)return e.state=\"errored\",void(404!==i.status?this._source.fire(new t.ErrorEvent(i,{tile:e})):this.update(this.transform));e.timeAdded=t.browser.now(),\"expired\"===n&&(e.refreshedUponExpiration=!0),this._setTileReloadTimer(r,e),\"raster-dem\"===this.getSource().type&&e.dem&&this._backfillDEM(e),this._state.initializeTileState(e,this.map?this.map.painter:null),this._source.fire(new t.Event(\"data\",{dataType:\"source\",tile:e,coord:e.tileID}))},r.prototype._backfillDEM=function(t){for(var e=this.getRenderableIds(),r=0;r<e.length;r++){var n=e[r];if(t.neighboringTiles&&t.neighboringTiles[n]){var i=this.getTileByID(n);a(t,i),a(i,t)}}function a(t,e){t.needsHillshadePrepare=!0;var r=e.tileID.canonical.x-t.tileID.canonical.x,n=e.tileID.canonical.y-t.tileID.canonical.y,i=Math.pow(2,t.tileID.canonical.z),a=e.tileID.key;0===r&&0===n||Math.abs(n)>1||(Math.abs(r)>1&&(1===Math.abs(r+i)?r+=i:1===Math.abs(r-i)&&(r-=i)),e.dem&&t.dem&&(t.dem.backfillBorder(e.dem,r,n),t.neighboringTiles&&t.neighboringTiles[a]&&(t.neighboringTiles[a].backfilled=!0)))}},r.prototype.getTile=function(t){return this.getTileByID(t.key)},r.prototype.getTileByID=function(t){return this._tiles[t]},r.prototype._retainLoadedChildren=function(t,e,r,n){for(var i in this._tiles){var a=this._tiles[i];if(!(n[i]||!a.hasData()||a.tileID.overscaledZ<=e||a.tileID.overscaledZ>r)){for(var o=a.tileID;a&&a.tileID.overscaledZ>e+1;){var s=a.tileID.scaledTo(a.tileID.overscaledZ-1);(a=this._tiles[s.key])&&a.hasData()&&(o=s)}for(var l=o;l.overscaledZ>e;)if(t[(l=l.scaledTo(l.overscaledZ-1)).key]){n[o.key]=o;break}}}},r.prototype.findLoadedParent=function(t,e){if(t.key in this._loadedParentTiles){var r=this._loadedParentTiles[t.key];return r&&r.tileID.overscaledZ>=e?r:null}for(var n=t.overscaledZ-1;n>=e;n--){var i=t.scaledTo(n),a=this._getLoadedTile(i);if(a)return a}},r.prototype._getLoadedTile=function(t){var e=this._tiles[t.key];return e&&e.hasData()?e:this._cache.getByKey(t.wrapped().key)},r.prototype.updateCacheSize=function(t){var e=(Math.ceil(t.width/this._source.tileSize)+1)*(Math.ceil(t.height/this._source.tileSize)+1),r=Math.floor(5*e),n=\"number\"==typeof this._maxTileCacheSize?Math.min(this._maxTileCacheSize,r):r;this._cache.setMaxSize(n)},r.prototype.handleWrapJump=function(t){var e=(t-(void 0===this._prevLng?t:this._prevLng))/360,r=Math.round(e);if(this._prevLng=t,r){var n={};for(var i in this._tiles){var a=this._tiles[i];a.tileID=a.tileID.unwrapTo(a.tileID.wrap+r),n[a.tileID.key]=a}for(var o in this._tiles=n,this._timers)clearTimeout(this._timers[o]),delete this._timers[o];for(var s in this._tiles){var l=this._tiles[s];this._setTileReloadTimer(s,l)}}},r.prototype.update=function(e){var n=this;if(this.transform=e,this._sourceLoaded&&!this._paused){var i;this.updateCacheSize(e),this.handleWrapJump(this.transform.center.lng),this._coveredTiles={},this.used?this._source.tileID?i=e.getVisibleUnwrappedCoordinates(this._source.tileID).map((function(e){return new t.OverscaledTileID(e.canonical.z,e.wrap,e.canonical.z,e.canonical.x,e.canonical.y)})):(i=e.coveringTiles({tileSize:this._source.tileSize,minzoom:this._source.minzoom,maxzoom:this._source.maxzoom,roundZoom:this._source.roundZoom,reparseOverscaled:this._source.reparseOverscaled}),this._source.hasTile&&(i=i.filter((function(t){return n._source.hasTile(t)})))):i=[];var a=e.coveringZoomLevel(this._source),o=Math.max(a-r.maxOverzooming,this._source.minzoom),s=Math.max(a+r.maxUnderzooming,this._source.minzoom),l=this._updateRetainedTiles(i,a);if(It(this._source.type)){for(var c={},u={},f=0,h=Object.keys(l);f<h.length;f+=1){var p=h[f],d=l[p],m=this._tiles[p];if(m&&!(m.fadeEndTime&&m.fadeEndTime<=t.browser.now())){var g=this.findLoadedParent(d,o);g&&(this._addTile(g.tileID),c[g.tileID.key]=g.tileID),u[p]=d}}for(var v in this._retainLoadedChildren(u,a,s,l),c)l[v]||(this._coveredTiles[v]=!0,l[v]=c[v])}for(var y in l)this._tiles[y].clearFadeHold();for(var x=0,b=t.keysDifference(this._tiles,l);x<b.length;x+=1){var _=b[x],w=this._tiles[_];w.hasSymbolBuckets&&!w.holdingForFade()?w.setHoldDuration(this.map._fadeDuration):w.hasSymbolBuckets&&!w.symbolFadeFinished()||this._removeTile(_)}this._updateLoadedParentTileCache()}},r.prototype.releaseSymbolFadeTiles=function(){for(var t in this._tiles)this._tiles[t].holdingForFade()&&this._removeTile(t)},r.prototype._updateRetainedTiles=function(t,e){for(var n={},i={},a=Math.max(e-r.maxOverzooming,this._source.minzoom),o=Math.max(e+r.maxUnderzooming,this._source.minzoom),s={},l=0,c=t;l<c.length;l+=1){var u=c[l],f=this._addTile(u);n[u.key]=u,f.hasData()||e<this._source.maxzoom&&(s[u.key]=u)}this._retainLoadedChildren(s,e,o,n);for(var h=0,p=t;h<p.length;h+=1){var d=p[h],m=this._tiles[d.key];if(!m.hasData()){if(e+1>this._source.maxzoom){var g=d.children(this._source.maxzoom)[0],v=this.getTile(g);if(v&&v.hasData()){n[g.key]=g;continue}}else{var y=d.children(this._source.maxzoom);if(n[y[0].key]&&n[y[1].key]&&n[y[2].key]&&n[y[3].key])continue}for(var x=m.wasRequested(),b=d.overscaledZ-1;b>=a;--b){var _=d.scaledTo(b);if(i[_.key])break;if(i[_.key]=!0,!(m=this.getTile(_))&&x&&(m=this._addTile(_)),m&&(n[_.key]=_,x=m.wasRequested(),m.hasData()))break}}}return n},r.prototype._updateLoadedParentTileCache=function(){for(var t in this._loadedParentTiles={},this._tiles){for(var e=[],r=void 0,n=this._tiles[t].tileID;n.overscaledZ>0;){if(n.key in this._loadedParentTiles){r=this._loadedParentTiles[n.key];break}e.push(n.key);var i=n.scaledTo(n.overscaledZ-1);if(r=this._getLoadedTile(i))break;n=i}for(var a=0,o=e;a<o.length;a+=1){var s=o[a];this._loadedParentTiles[s]=r}}},r.prototype._addTile=function(e){var r=this._tiles[e.key];if(r)return r;(r=this._cache.getAndRemove(e))&&(this._setTileReloadTimer(e.key,r),r.tileID=e,this._state.initializeTileState(r,this.map?this.map.painter:null),this._cacheTimers[e.key]&&(clearTimeout(this._cacheTimers[e.key]),delete this._cacheTimers[e.key],this._setTileReloadTimer(e.key,r)));var n=Boolean(r);return n||(r=new t.Tile(e,this._source.tileSize*e.overscaleFactor()),this._loadTile(r,this._tileLoaded.bind(this,r,e.key,r.state))),r?(r.uses++,this._tiles[e.key]=r,n||this._source.fire(new t.Event(\"dataloading\",{tile:r,coord:r.tileID,dataType:\"source\"})),r):null},r.prototype._setTileReloadTimer=function(t,e){var r=this;t in this._timers&&(clearTimeout(this._timers[t]),delete this._timers[t]);var n=e.getExpiryTimeout();n&&(this._timers[t]=setTimeout((function(){r._reloadTile(t,\"expired\"),delete r._timers[t]}),n))},r.prototype._removeTile=function(t){var e=this._tiles[t];e&&(e.uses--,delete this._tiles[t],this._timers[t]&&(clearTimeout(this._timers[t]),delete this._timers[t]),e.uses>0||(e.hasData()&&\"reloading\"!==e.state?this._cache.add(e.tileID,e,e.getExpiryTimeout()):(e.aborted=!0,this._abortTile(e),this._unloadTile(e))))},r.prototype.clearTiles=function(){for(var t in this._shouldReloadOnResume=!1,this._paused=!1,this._tiles)this._removeTile(t);this._cache.reset()},r.prototype.tilesIn=function(e,r,n){var i=this,a=[],o=this.transform;if(!o)return a;for(var s=n?o.getCameraQueryGeometry(e):e,l=e.map((function(t){return o.pointCoordinate(t)})),c=s.map((function(t){return o.pointCoordinate(t)})),u=this.getIds(),f=1/0,h=1/0,p=-1/0,d=-1/0,m=0,g=c;m<g.length;m+=1){var v=g[m];f=Math.min(f,v.x),h=Math.min(h,v.y),p=Math.max(p,v.x),d=Math.max(d,v.y)}for(var y=function(e){var n=i._tiles[u[e]];if(!n.holdingForFade()){var s=n.tileID,m=Math.pow(2,o.zoom-n.tileID.overscaledZ),g=r*n.queryPadding*t.EXTENT/n.tileSize/m,v=[s.getTilePoint(new t.MercatorCoordinate(f,h)),s.getTilePoint(new t.MercatorCoordinate(p,d))];if(v[0].x-g<t.EXTENT&&v[0].y-g<t.EXTENT&&v[1].x+g>=0&&v[1].y+g>=0){var y=l.map((function(t){return s.getTilePoint(t)})),x=c.map((function(t){return s.getTilePoint(t)}));a.push({tile:n,tileID:s,queryGeometry:y,cameraQueryGeometry:x,scale:m})}}},x=0;x<u.length;x++)y(x);return a},r.prototype.getVisibleCoordinates=function(t){for(var e=this,r=this.getRenderableIds(t).map((function(t){return e._tiles[t].tileID})),n=0,i=r;n<i.length;n+=1){var a=i[n];a.posMatrix=this.transform.calculatePosMatrix(a.toUnwrapped())}return r},r.prototype.hasTransition=function(){if(this._source.hasTransition())return!0;if(It(this._source.type))for(var e in this._tiles){var r=this._tiles[e];if(void 0!==r.fadeEndTime&&r.fadeEndTime>=t.browser.now())return!0}return!1},r.prototype.setFeatureState=function(t,e,r){t=t||\"_geojsonTileLayer\",this._state.updateState(t,e,r)},r.prototype.removeFeatureState=function(t,e,r){t=t||\"_geojsonTileLayer\",this._state.removeFeatureState(t,e,r)},r.prototype.getFeatureState=function(t,e){return t=t||\"_geojsonTileLayer\",this._state.getState(t,e)},r.prototype.setDependencies=function(t,e,r){var n=this._tiles[t];n&&n.setDependencies(e,r)},r.prototype.reloadTilesForDependencies=function(t,e){for(var r in this._tiles){this._tiles[r].hasDependency(t,e)&&this._reloadTile(r,\"reloading\")}this._cache.filter((function(r){return!r.hasDependency(t,e)}))},r}(t.Evented);function Pt(t,e){var r=Math.abs(2*t.wrap)-+(t.wrap<0),n=Math.abs(2*e.wrap)-+(e.wrap<0);return t.overscaledZ-e.overscaledZ||n-r||e.canonical.y-t.canonical.y||e.canonical.x-t.canonical.x}function It(t){return\"raster\"===t||\"image\"===t||\"video\"===t}function Ot(){return new t.window.Worker(Zi.workerUrl)}Ct.maxOverzooming=10,Ct.maxUnderzooming=3;var zt=\"mapboxgl_preloaded_worker_pool\",Dt=function(){this.active={}};Dt.prototype.acquire=function(t){if(!this.workers)for(this.workers=[];this.workers.length<Dt.workerCount;)this.workers.push(new Ot);return this.active[t]=!0,this.workers.slice()},Dt.prototype.release=function(t){delete this.active[t],0===this.numActive()&&(this.workers.forEach((function(t){t.terminate()})),this.workers=null)},Dt.prototype.isPreloaded=function(){return!!this.active[zt]},Dt.prototype.numActive=function(){return Object.keys(this.active).length};var Rt,Ft=Math.floor(t.browser.hardwareConcurrency/2);function Bt(){return Rt||(Rt=new Dt),Rt}function Nt(e,r){var n={};for(var i in e)\"ref\"!==i&&(n[i]=e[i]);return t.refProperties.forEach((function(t){t in r&&(n[t]=r[t])})),n}function jt(t){t=t.slice();for(var e=Object.create(null),r=0;r<t.length;r++)e[t[r].id]=t[r];for(var n=0;n<t.length;n++)\"ref\"in t[n]&&(t[n]=Nt(t[n],e[t[n].ref]));return t}Dt.workerCount=Math.max(Math.min(Ft,6),1);var Ut={setStyle:\"setStyle\",addLayer:\"addLayer\",removeLayer:\"removeLayer\",setPaintProperty:\"setPaintProperty\",setLayoutProperty:\"setLayoutProperty\",setFilter:\"setFilter\",addSource:\"addSource\",removeSource:\"removeSource\",setGeoJSONSourceData:\"setGeoJSONSourceData\",setLayerZoomRange:\"setLayerZoomRange\",setLayerProperty:\"setLayerProperty\",setCenter:\"setCenter\",setZoom:\"setZoom\",setBearing:\"setBearing\",setPitch:\"setPitch\",setSprite:\"setSprite\",setGlyphs:\"setGlyphs\",setTransition:\"setTransition\",setLight:\"setLight\"};function Vt(t,e,r){r.push({command:Ut.addSource,args:[t,e[t]]})}function qt(t,e,r){e.push({command:Ut.removeSource,args:[t]}),r[t]=!0}function Ht(t,e,r,n){qt(t,r,n),Vt(t,e,r)}function Gt(e,r,n){var i;for(i in e[n])if(e[n].hasOwnProperty(i)&&\"data\"!==i&&!t.deepEqual(e[n][i],r[n][i]))return!1;for(i in r[n])if(r[n].hasOwnProperty(i)&&\"data\"!==i&&!t.deepEqual(e[n][i],r[n][i]))return!1;return!0}function Yt(e,r,n,i,a,o){var s;for(s in r=r||{},e=e||{})e.hasOwnProperty(s)&&(t.deepEqual(e[s],r[s])||n.push({command:o,args:[i,s,r[s],a]}));for(s in r)r.hasOwnProperty(s)&&!e.hasOwnProperty(s)&&(t.deepEqual(e[s],r[s])||n.push({command:o,args:[i,s,r[s],a]}))}function Wt(t){return t.id}function Xt(t,e){return t[e.id]=e,t}function Zt(e,r){if(!e)return[{command:Ut.setStyle,args:[r]}];var n=[];try{if(!t.deepEqual(e.version,r.version))return[{command:Ut.setStyle,args:[r]}];t.deepEqual(e.center,r.center)||n.push({command:Ut.setCenter,args:[r.center]}),t.deepEqual(e.zoom,r.zoom)||n.push({command:Ut.setZoom,args:[r.zoom]}),t.deepEqual(e.bearing,r.bearing)||n.push({command:Ut.setBearing,args:[r.bearing]}),t.deepEqual(e.pitch,r.pitch)||n.push({command:Ut.setPitch,args:[r.pitch]}),t.deepEqual(e.sprite,r.sprite)||n.push({command:Ut.setSprite,args:[r.sprite]}),t.deepEqual(e.glyphs,r.glyphs)||n.push({command:Ut.setGlyphs,args:[r.glyphs]}),t.deepEqual(e.transition,r.transition)||n.push({command:Ut.setTransition,args:[r.transition]}),t.deepEqual(e.light,r.light)||n.push({command:Ut.setLight,args:[r.light]});var i={},a=[];!function(e,r,n,i){var a;for(a in r=r||{},e=e||{})e.hasOwnProperty(a)&&(r.hasOwnProperty(a)||qt(a,n,i));for(a in r)r.hasOwnProperty(a)&&(e.hasOwnProperty(a)?t.deepEqual(e[a],r[a])||(\"geojson\"===e[a].type&&\"geojson\"===r[a].type&&Gt(e,r,a)?n.push({command:Ut.setGeoJSONSourceData,args:[a,r[a].data]}):Ht(a,r,n,i)):Vt(a,r,n))}(e.sources,r.sources,a,i);var o=[];e.layers&&e.layers.forEach((function(t){i[t.source]?n.push({command:Ut.removeLayer,args:[t.id]}):o.push(t)})),n=n.concat(a),function(e,r,n){r=r||[];var i,a,o,s,l,c,u,f=(e=e||[]).map(Wt),h=r.map(Wt),p=e.reduce(Xt,{}),d=r.reduce(Xt,{}),m=f.slice(),g=Object.create(null);for(i=0,a=0;i<f.length;i++)o=f[i],d.hasOwnProperty(o)?a++:(n.push({command:Ut.removeLayer,args:[o]}),m.splice(m.indexOf(o,a),1));for(i=0,a=0;i<h.length;i++)o=h[h.length-1-i],m[m.length-1-i]!==o&&(p.hasOwnProperty(o)?(n.push({command:Ut.removeLayer,args:[o]}),m.splice(m.lastIndexOf(o,m.length-a),1)):a++,c=m[m.length-i],n.push({command:Ut.addLayer,args:[d[o],c]}),m.splice(m.length-i,0,o),g[o]=!0);for(i=0;i<h.length;i++)if(s=p[o=h[i]],l=d[o],!g[o]&&!t.deepEqual(s,l))if(t.deepEqual(s.source,l.source)&&t.deepEqual(s[\"source-layer\"],l[\"source-layer\"])&&t.deepEqual(s.type,l.type)){for(u in Yt(s.layout,l.layout,n,o,null,Ut.setLayoutProperty),Yt(s.paint,l.paint,n,o,null,Ut.setPaintProperty),t.deepEqual(s.filter,l.filter)||n.push({command:Ut.setFilter,args:[o,l.filter]}),t.deepEqual(s.minzoom,l.minzoom)&&t.deepEqual(s.maxzoom,l.maxzoom)||n.push({command:Ut.setLayerZoomRange,args:[o,l.minzoom,l.maxzoom]}),s)s.hasOwnProperty(u)&&\"layout\"!==u&&\"paint\"!==u&&\"filter\"!==u&&\"metadata\"!==u&&\"minzoom\"!==u&&\"maxzoom\"!==u&&(0===u.indexOf(\"paint.\")?Yt(s[u],l[u],n,o,u.slice(6),Ut.setPaintProperty):t.deepEqual(s[u],l[u])||n.push({command:Ut.setLayerProperty,args:[o,u,l[u]]}));for(u in l)l.hasOwnProperty(u)&&!s.hasOwnProperty(u)&&\"layout\"!==u&&\"paint\"!==u&&\"filter\"!==u&&\"metadata\"!==u&&\"minzoom\"!==u&&\"maxzoom\"!==u&&(0===u.indexOf(\"paint.\")?Yt(s[u],l[u],n,o,u.slice(6),Ut.setPaintProperty):t.deepEqual(s[u],l[u])||n.push({command:Ut.setLayerProperty,args:[o,u,l[u]]}))}else n.push({command:Ut.removeLayer,args:[o]}),c=m[m.lastIndexOf(o)+1],n.push({command:Ut.addLayer,args:[l,c]})}(o,r.layers,n)}catch(t){console.warn(\"Unable to compute style diff:\",t),n=[{command:Ut.setStyle,args:[r]}]}return n}var Jt=function(t,e){this.reset(t,e)};Jt.prototype.reset=function(t,e){this.points=t||[],this._distances=[0];for(var r=1;r<this.points.length;r++)this._distances[r]=this._distances[r-1]+this.points[r].dist(this.points[r-1]);this.length=this._distances[this._distances.length-1],this.padding=Math.min(e||0,.5*this.length),this.paddedLength=this.length-2*this.padding},Jt.prototype.lerp=function(e){if(1===this.points.length)return this.points[0];e=t.clamp(e,0,1);for(var r=1,n=this._distances[r],i=e*this.paddedLength+this.padding;n<i&&r<this._distances.length;)n=this._distances[++r];var a=r-1,o=this._distances[a],s=n-o,l=s>0?(i-o)/s:0;return this.points[a].mult(1-l).add(this.points[r].mult(l))};var Kt=function(t,e,r){var n=this.boxCells=[],i=this.circleCells=[];this.xCellCount=Math.ceil(t/r),this.yCellCount=Math.ceil(e/r);for(var a=0;a<this.xCellCount*this.yCellCount;a++)n.push([]),i.push([]);this.circleKeys=[],this.boxKeys=[],this.bboxes=[],this.circles=[],this.width=t,this.height=e,this.xScale=this.xCellCount/t,this.yScale=this.yCellCount/e,this.boxUid=0,this.circleUid=0};function Qt(e,r,n,i,a){var o=t.create();return r?(t.scale(o,o,[1/a,1/a,1]),n||t.rotateZ(o,o,i.angle)):t.multiply(o,i.labelPlaneMatrix,e),o}function $t(e,r,n,i,a){if(r){var o=t.clone(e);return t.scale(o,o,[a,a,1]),n||t.rotateZ(o,o,-i.angle),o}return i.glCoordMatrix}function te(e,r){var n=[e.x,e.y,0,1];fe(n,n,r);var i=n[3];return{point:new t.Point(n[0]/i,n[1]/i),signedDistanceFromCamera:i}}function ee(t,e){return.5+t/e*.5}function re(t,e){var r=t[0]/t[3],n=t[1]/t[3];return r>=-e[0]&&r<=e[0]&&n>=-e[1]&&n<=e[1]}function ne(e,r,n,i,a,o,s,l){var c=i?e.textSizeData:e.iconSizeData,u=t.evaluateSizeForZoom(c,n.transform.zoom),f=[256/n.width*2+1,256/n.height*2+1],h=i?e.text.dynamicLayoutVertexArray:e.icon.dynamicLayoutVertexArray;h.clear();for(var p=e.lineVertexArray,d=i?e.text.placedSymbolArray:e.icon.placedSymbolArray,m=n.transform.width/n.transform.height,g=!1,v=0;v<d.length;v++){var y=d.get(v);if(y.hidden||y.writingMode===t.WritingMode.vertical&&!g)ue(y.numGlyphs,h);else{g=!1;var x=[y.anchorX,y.anchorY,0,1];if(t.transformMat4(x,x,r),re(x,f)){var b=x[3],_=ee(n.transform.cameraToCenterDistance,b),w=t.evaluateSizeForFeature(c,u,y),T=s?w/_:w*_,k=new t.Point(y.anchorX,y.anchorY),M=te(k,a).point,A={},S=oe(y,T,!1,l,r,a,o,e.glyphOffsetArray,p,h,M,k,A,m);g=S.useVertical,(S.notEnoughRoom||g||S.needsFlipping&&oe(y,T,!0,l,r,a,o,e.glyphOffsetArray,p,h,M,k,A,m).notEnoughRoom)&&ue(y.numGlyphs,h)}else ue(y.numGlyphs,h)}}i?e.text.dynamicLayoutVertexBuffer.updateData(h):e.icon.dynamicLayoutVertexBuffer.updateData(h)}function ie(t,e,r,n,i,a,o,s,l,c,u){var f=s.glyphStartIndex+s.numGlyphs,h=s.lineStartIndex,p=s.lineStartIndex+s.lineLength,d=e.getoffsetX(s.glyphStartIndex),m=e.getoffsetX(f-1),g=le(t*d,r,n,i,a,o,s.segment,h,p,l,c,u);if(!g)return null;var v=le(t*m,r,n,i,a,o,s.segment,h,p,l,c,u);return v?{first:g,last:v}:null}function ae(e,r,n,i){if(e===t.WritingMode.horizontal&&Math.abs(n.y-r.y)>Math.abs(n.x-r.x)*i)return{useVertical:!0};return(e===t.WritingMode.vertical?r.y<n.y:r.x>n.x)?{needsFlipping:!0}:null}function oe(e,r,n,i,a,o,s,l,c,u,f,h,p,d){var m,g=r/24,v=e.lineOffsetX*g,y=e.lineOffsetY*g;if(e.numGlyphs>1){var x=e.glyphStartIndex+e.numGlyphs,b=e.lineStartIndex,_=e.lineStartIndex+e.lineLength,w=ie(g,l,v,y,n,f,h,e,c,o,p);if(!w)return{notEnoughRoom:!0};var T=te(w.first.point,s).point,k=te(w.last.point,s).point;if(i&&!n){var M=ae(e.writingMode,T,k,d);if(M)return M}m=[w.first];for(var A=e.glyphStartIndex+1;A<x-1;A++)m.push(le(g*l.getoffsetX(A),v,y,n,f,h,e.segment,b,_,c,o,p));m.push(w.last)}else{if(i&&!n){var S=te(h,a).point,E=e.lineStartIndex+e.segment+1,L=new t.Point(c.getx(E),c.gety(E)),C=te(L,a),P=C.signedDistanceFromCamera>0?C.point:se(h,L,S,1,a),I=ae(e.writingMode,S,P,d);if(I)return I}var O=le(g*l.getoffsetX(e.glyphStartIndex),v,y,n,f,h,e.segment,e.lineStartIndex,e.lineStartIndex+e.lineLength,c,o,p);if(!O)return{notEnoughRoom:!0};m=[O]}for(var z=0,D=m;z<D.length;z+=1){var R=D[z];t.addDynamicAttributes(u,R.point,R.angle)}return{}}function se(t,e,r,n,i){var a=te(t.add(t.sub(e)._unit()),i).point,o=r.sub(a);return r.add(o._mult(n/o.mag()))}function le(e,r,n,i,a,o,s,l,c,u,f,h){var p=i?e-r:e+r,d=p>0?1:-1,m=0;i&&(d*=-1,m=Math.PI),d<0&&(m+=Math.PI);for(var g=d>0?l+s:l+s+1,v=a,y=a,x=0,b=0,_=Math.abs(p),w=[];x+b<=_;){if((g+=d)<l||g>=c)return null;if(y=v,w.push(v),void 0===(v=h[g])){var T=new t.Point(u.getx(g),u.gety(g)),k=te(T,f);if(k.signedDistanceFromCamera>0)v=h[g]=k.point;else{var M=g-d;v=se(0===x?o:new t.Point(u.getx(M),u.gety(M)),T,y,_-x+1,f)}}x+=b,b=y.dist(v)}var A=(_-x)/b,S=v.sub(y),E=S.mult(A)._add(y);E._add(S._unit()._perp()._mult(n*d));var L=m+Math.atan2(v.y-y.y,v.x-y.x);return w.push(E),{point:E,angle:L,path:w}}Kt.prototype.keysLength=function(){return this.boxKeys.length+this.circleKeys.length},Kt.prototype.insert=function(t,e,r,n,i){this._forEachCell(e,r,n,i,this._insertBoxCell,this.boxUid++),this.boxKeys.push(t),this.bboxes.push(e),this.bboxes.push(r),this.bboxes.push(n),this.bboxes.push(i)},Kt.prototype.insertCircle=function(t,e,r,n){this._forEachCell(e-n,r-n,e+n,r+n,this._insertCircleCell,this.circleUid++),this.circleKeys.push(t),this.circles.push(e),this.circles.push(r),this.circles.push(n)},Kt.prototype._insertBoxCell=function(t,e,r,n,i,a){this.boxCells[i].push(a)},Kt.prototype._insertCircleCell=function(t,e,r,n,i,a){this.circleCells[i].push(a)},Kt.prototype._query=function(t,e,r,n,i,a){if(r<0||t>this.width||n<0||e>this.height)return!i&&[];var o=[];if(t<=0&&e<=0&&this.width<=r&&this.height<=n){if(i)return!0;for(var s=0;s<this.boxKeys.length;s++)o.push({key:this.boxKeys[s],x1:this.bboxes[4*s],y1:this.bboxes[4*s+1],x2:this.bboxes[4*s+2],y2:this.bboxes[4*s+3]});for(var l=0;l<this.circleKeys.length;l++){var c=this.circles[3*l],u=this.circles[3*l+1],f=this.circles[3*l+2];o.push({key:this.circleKeys[l],x1:c-f,y1:u-f,x2:c+f,y2:u+f})}return a?o.filter(a):o}var h={hitTest:i,seenUids:{box:{},circle:{}}};return this._forEachCell(t,e,r,n,this._queryCell,o,h,a),i?o.length>0:o},Kt.prototype._queryCircle=function(t,e,r,n,i){var a=t-r,o=t+r,s=e-r,l=e+r;if(o<0||a>this.width||l<0||s>this.height)return!n&&[];var c=[],u={hitTest:n,circle:{x:t,y:e,radius:r},seenUids:{box:{},circle:{}}};return this._forEachCell(a,s,o,l,this._queryCellCircle,c,u,i),n?c.length>0:c},Kt.prototype.query=function(t,e,r,n,i){return this._query(t,e,r,n,!1,i)},Kt.prototype.hitTest=function(t,e,r,n,i){return this._query(t,e,r,n,!0,i)},Kt.prototype.hitTestCircle=function(t,e,r,n){return this._queryCircle(t,e,r,!0,n)},Kt.prototype._queryCell=function(t,e,r,n,i,a,o,s){var l=o.seenUids,c=this.boxCells[i];if(null!==c)for(var u=this.bboxes,f=0,h=c;f<h.length;f+=1){var p=h[f];if(!l.box[p]){l.box[p]=!0;var d=4*p;if(t<=u[d+2]&&e<=u[d+3]&&r>=u[d+0]&&n>=u[d+1]&&(!s||s(this.boxKeys[p]))){if(o.hitTest)return a.push(!0),!0;a.push({key:this.boxKeys[p],x1:u[d],y1:u[d+1],x2:u[d+2],y2:u[d+3]})}}}var m=this.circleCells[i];if(null!==m)for(var g=this.circles,v=0,y=m;v<y.length;v+=1){var x=y[v];if(!l.circle[x]){l.circle[x]=!0;var b=3*x;if(this._circleAndRectCollide(g[b],g[b+1],g[b+2],t,e,r,n)&&(!s||s(this.circleKeys[x]))){if(o.hitTest)return a.push(!0),!0;var _=g[b],w=g[b+1],T=g[b+2];a.push({key:this.circleKeys[x],x1:_-T,y1:w-T,x2:_+T,y2:w+T})}}}},Kt.prototype._queryCellCircle=function(t,e,r,n,i,a,o,s){var l=o.circle,c=o.seenUids,u=this.boxCells[i];if(null!==u)for(var f=this.bboxes,h=0,p=u;h<p.length;h+=1){var d=p[h];if(!c.box[d]){c.box[d]=!0;var m=4*d;if(this._circleAndRectCollide(l.x,l.y,l.radius,f[m+0],f[m+1],f[m+2],f[m+3])&&(!s||s(this.boxKeys[d])))return a.push(!0),!0}}var g=this.circleCells[i];if(null!==g)for(var v=this.circles,y=0,x=g;y<x.length;y+=1){var b=x[y];if(!c.circle[b]){c.circle[b]=!0;var _=3*b;if(this._circlesCollide(v[_],v[_+1],v[_+2],l.x,l.y,l.radius)&&(!s||s(this.circleKeys[b])))return a.push(!0),!0}}},Kt.prototype._forEachCell=function(t,e,r,n,i,a,o,s){for(var l=this._convertToXCellCoord(t),c=this._convertToYCellCoord(e),u=this._convertToXCellCoord(r),f=this._convertToYCellCoord(n),h=l;h<=u;h++)for(var p=c;p<=f;p++){var d=this.xCellCount*p+h;if(i.call(this,t,e,r,n,d,a,o,s))return}},Kt.prototype._convertToXCellCoord=function(t){return Math.max(0,Math.min(this.xCellCount-1,Math.floor(t*this.xScale)))},Kt.prototype._convertToYCellCoord=function(t){return Math.max(0,Math.min(this.yCellCount-1,Math.floor(t*this.yScale)))},Kt.prototype._circlesCollide=function(t,e,r,n,i,a){var o=n-t,s=i-e,l=r+a;return l*l>o*o+s*s},Kt.prototype._circleAndRectCollide=function(t,e,r,n,i,a,o){var s=(a-n)/2,l=Math.abs(t-(n+s));if(l>s+r)return!1;var c=(o-i)/2,u=Math.abs(e-(i+c));if(u>c+r)return!1;if(l<=s||u<=c)return!0;var f=l-s,h=u-c;return f*f+h*h<=r*r};var ce=new Float32Array([-1/0,-1/0,0,-1/0,-1/0,0,-1/0,-1/0,0,-1/0,-1/0,0]);function ue(t,e){for(var r=0;r<t;r++){var n=e.length;e.resize(n+4),e.float32.set(ce,3*n)}}function fe(t,e,r){var n=e[0],i=e[1];return t[0]=r[0]*n+r[4]*i+r[12],t[1]=r[1]*n+r[5]*i+r[13],t[3]=r[3]*n+r[7]*i+r[15],t}var he=function(t,e,r){void 0===e&&(e=new Kt(t.width+200,t.height+200,25)),void 0===r&&(r=new Kt(t.width+200,t.height+200,25)),this.transform=t,this.grid=e,this.ignoredGrid=r,this.pitchfactor=Math.cos(t._pitch)*t.cameraToCenterDistance,this.screenRightBoundary=t.width+100,this.screenBottomBoundary=t.height+100,this.gridRightBoundary=t.width+200,this.gridBottomBoundary=t.height+200};function pe(e,r,n){return r*(t.EXTENT/(e.tileSize*Math.pow(2,n-e.tileID.overscaledZ)))}he.prototype.placeCollisionBox=function(t,e,r,n,i){var a=this.projectAndGetPerspectiveRatio(n,t.anchorPointX,t.anchorPointY),o=r*a.perspectiveRatio,s=t.x1*o+a.point.x,l=t.y1*o+a.point.y,c=t.x2*o+a.point.x,u=t.y2*o+a.point.y;return!this.isInsideGrid(s,l,c,u)||!e&&this.grid.hitTest(s,l,c,u,i)?{box:[],offscreen:!1}:{box:[s,l,c,u],offscreen:this.isOffscreen(s,l,c,u)}},he.prototype.placeCollisionCircles=function(e,r,n,i,a,o,s,l,c,u,f,h,p){var d=[],m=new t.Point(r.anchorX,r.anchorY),g=te(m,o),v=ee(this.transform.cameraToCenterDistance,g.signedDistanceFromCamera),y=(u?a/v:a*v)/t.ONE_EM,x=te(m,s).point,b=ie(y,i,r.lineOffsetX*y,r.lineOffsetY*y,!1,x,m,r,n,s,{}),_=!1,w=!1,T=!0;if(b){for(var k=.5*h*v+p,M=new t.Point(-100,-100),A=new t.Point(this.screenRightBoundary,this.screenBottomBoundary),S=new Jt,E=b.first,L=b.last,C=[],P=E.path.length-1;P>=1;P--)C.push(E.path[P]);for(var I=1;I<L.path.length;I++)C.push(L.path[I]);var O=2.5*k;if(l){var z=C.map((function(t){return te(t,l)}));C=z.some((function(t){return t.signedDistanceFromCamera<=0}))?[]:z.map((function(t){return t.point}))}var D=[];if(C.length>0){for(var R=C[0].clone(),F=C[0].clone(),B=1;B<C.length;B++)R.x=Math.min(R.x,C[B].x),R.y=Math.min(R.y,C[B].y),F.x=Math.max(F.x,C[B].x),F.y=Math.max(F.y,C[B].y);D=R.x>=M.x&&F.x<=A.x&&R.y>=M.y&&F.y<=A.y?[C]:F.x<M.x||R.x>A.x||F.y<M.y||R.y>A.y?[]:t.clipLine([C],M.x,M.y,A.x,A.y)}for(var N=0,j=D;N<j.length;N+=1){var U=j[N];S.reset(U,.25*k);var V=0;V=S.length<=.5*k?1:Math.ceil(S.paddedLength/O)+1;for(var q=0;q<V;q++){var H=q/Math.max(V-1,1),G=S.lerp(H),Y=G.x+100,W=G.y+100;d.push(Y,W,k,0);var X=Y-k,Z=W-k,J=Y+k,K=W+k;if(T=T&&this.isOffscreen(X,Z,J,K),w=w||this.isInsideGrid(X,Z,J,K),!e&&this.grid.hitTestCircle(Y,W,k,f)&&(_=!0,!c))return{circles:[],offscreen:!1,collisionDetected:_}}}}return{circles:!c&&_||!w?[]:d,offscreen:T,collisionDetected:_}},he.prototype.queryRenderedSymbols=function(e){if(0===e.length||0===this.grid.keysLength()&&0===this.ignoredGrid.keysLength())return{};for(var r=[],n=1/0,i=1/0,a=-1/0,o=-1/0,s=0,l=e;s<l.length;s+=1){var c=l[s],u=new t.Point(c.x+100,c.y+100);n=Math.min(n,u.x),i=Math.min(i,u.y),a=Math.max(a,u.x),o=Math.max(o,u.y),r.push(u)}for(var f={},h={},p=0,d=this.grid.query(n,i,a,o).concat(this.ignoredGrid.query(n,i,a,o));p<d.length;p+=1){var m=d[p],g=m.key;if(void 0===f[g.bucketInstanceId]&&(f[g.bucketInstanceId]={}),!f[g.bucketInstanceId][g.featureIndex]){var v=[new t.Point(m.x1,m.y1),new t.Point(m.x2,m.y1),new t.Point(m.x2,m.y2),new t.Point(m.x1,m.y2)];t.polygonIntersectsPolygon(r,v)&&(f[g.bucketInstanceId][g.featureIndex]=!0,void 0===h[g.bucketInstanceId]&&(h[g.bucketInstanceId]=[]),h[g.bucketInstanceId].push(g.featureIndex))}}return h},he.prototype.insertCollisionBox=function(t,e,r,n,i){var a={bucketInstanceId:r,featureIndex:n,collisionGroupID:i};(e?this.ignoredGrid:this.grid).insert(a,t[0],t[1],t[2],t[3])},he.prototype.insertCollisionCircles=function(t,e,r,n,i){for(var a=e?this.ignoredGrid:this.grid,o={bucketInstanceId:r,featureIndex:n,collisionGroupID:i},s=0;s<t.length;s+=4)a.insertCircle(o,t[s],t[s+1],t[s+2])},he.prototype.projectAndGetPerspectiveRatio=function(e,r,n){var i=[r,n,0,1];return fe(i,i,e),{point:new t.Point((i[0]/i[3]+1)/2*this.transform.width+100,(-i[1]/i[3]+1)/2*this.transform.height+100),perspectiveRatio:.5+this.transform.cameraToCenterDistance/i[3]*.5}},he.prototype.isOffscreen=function(t,e,r,n){return r<100||t>=this.screenRightBoundary||n<100||e>this.screenBottomBoundary},he.prototype.isInsideGrid=function(t,e,r,n){return r>=0&&t<this.gridRightBoundary&&n>=0&&e<this.gridBottomBoundary},he.prototype.getViewportMatrix=function(){var e=t.identity([]);return t.translate(e,e,[-100,-100,0]),e};var de=function(t,e,r,n){this.opacity=t?Math.max(0,Math.min(1,t.opacity+(t.placed?e:-e))):n&&r?1:0,this.placed=r};de.prototype.isHidden=function(){return 0===this.opacity&&!this.placed};var me=function(t,e,r,n,i){this.text=new de(t?t.text:null,e,r,i),this.icon=new de(t?t.icon:null,e,n,i)};me.prototype.isHidden=function(){return this.text.isHidden()&&this.icon.isHidden()};var ge=function(t,e,r){this.text=t,this.icon=e,this.skipFade=r},ve=function(){this.invProjMatrix=t.create(),this.viewportMatrix=t.create(),this.circles=[]},ye=function(t,e,r,n,i){this.bucketInstanceId=t,this.featureIndex=e,this.sourceLayerIndex=r,this.bucketIndex=n,this.tileID=i},xe=function(t){this.crossSourceCollisions=t,this.maxGroupID=0,this.collisionGroups={}};function be(e,r,n,i,a){var o=t.getAnchorAlignment(e),s=-(o.horizontalAlign-.5)*r,l=-(o.verticalAlign-.5)*n,c=t.evaluateVariableOffset(e,i);return new t.Point(s+c[0]*a,l+c[1]*a)}function _e(e,r,n,i,a,o){var s=e.x1,l=e.x2,c=e.y1,u=e.y2,f=e.anchorPointX,h=e.anchorPointY,p=new t.Point(r,n);return i&&p._rotate(a?o:-o),{x1:s+p.x,y1:c+p.y,x2:l+p.x,y2:u+p.y,anchorPointX:f,anchorPointY:h}}xe.prototype.get=function(t){if(this.crossSourceCollisions)return{ID:0,predicate:null};if(!this.collisionGroups[t]){var e=++this.maxGroupID;this.collisionGroups[t]={ID:e,predicate:function(t){return t.collisionGroupID===e}}}return this.collisionGroups[t]};var we=function(t,e,r,n){this.transform=t.clone(),this.collisionIndex=new he(this.transform),this.placements={},this.opacities={},this.variableOffsets={},this.stale=!1,this.commitTime=0,this.fadeDuration=e,this.retainedQueryData={},this.collisionGroups=new xe(r),this.collisionCircleArrays={},this.prevPlacement=n,n&&(n.prevPlacement=void 0),this.placedOrientations={}};function Te(t,e,r,n,i){t.emplaceBack(e?1:0,r?1:0,n||0,i||0),t.emplaceBack(e?1:0,r?1:0,n||0,i||0),t.emplaceBack(e?1:0,r?1:0,n||0,i||0),t.emplaceBack(e?1:0,r?1:0,n||0,i||0)}we.prototype.getBucketParts=function(e,r,n,i){var a=n.getBucket(r),o=n.latestFeatureIndex;if(a&&o&&r.id===a.layerIds[0]){var s=n.collisionBoxArray,l=a.layers[0].layout,c=Math.pow(2,this.transform.zoom-n.tileID.overscaledZ),u=n.tileSize/t.EXTENT,f=this.transform.calculatePosMatrix(n.tileID.toUnwrapped()),h=\"map\"===l.get(\"text-pitch-alignment\"),p=\"map\"===l.get(\"text-rotation-alignment\"),d=pe(n,1,this.transform.zoom),m=Qt(f,h,p,this.transform,d),g=null;if(h){var v=$t(f,h,p,this.transform,d);g=t.multiply([],this.transform.labelPlaneMatrix,v)}this.retainedQueryData[a.bucketInstanceId]=new ye(a.bucketInstanceId,o,a.sourceLayerIndex,a.index,n.tileID);var y={bucket:a,layout:l,posMatrix:f,textLabelPlaneMatrix:m,labelToScreenMatrix:g,scale:c,textPixelRatio:u,holdingForFade:n.holdingForFade(),collisionBoxArray:s,partiallyEvaluatedTextSize:t.evaluateSizeForZoom(a.textSizeData,this.transform.zoom),collisionGroup:this.collisionGroups.get(a.sourceID)};if(i)for(var x=0,b=a.sortKeyRanges;x<b.length;x+=1){var _=b[x],w=_.sortKey,T=_.symbolInstanceStart,k=_.symbolInstanceEnd;e.push({sortKey:w,symbolInstanceStart:T,symbolInstanceEnd:k,parameters:y})}else e.push({symbolInstanceStart:0,symbolInstanceEnd:a.symbolInstances.length,parameters:y})}},we.prototype.attemptAnchorPlacement=function(t,e,r,n,i,a,o,s,l,c,u,f,h,p,d){var m,g=[f.textOffset0,f.textOffset1],v=be(t,r,n,g,i),y=this.collisionIndex.placeCollisionBox(_e(e,v.x,v.y,a,o,this.transform.angle),u,s,l,c.predicate);if(d&&0===this.collisionIndex.placeCollisionBox(_e(d,v.x,v.y,a,o,this.transform.angle),u,s,l,c.predicate).box.length)return;if(y.box.length>0)return this.prevPlacement&&this.prevPlacement.variableOffsets[f.crossTileID]&&this.prevPlacement.placements[f.crossTileID]&&this.prevPlacement.placements[f.crossTileID].text&&(m=this.prevPlacement.variableOffsets[f.crossTileID].anchor),this.variableOffsets[f.crossTileID]={textOffset:g,width:r,height:n,anchor:t,textBoxScale:i,prevAnchor:m},this.markUsedJustification(h,t,f,p),h.allowVerticalPlacement&&(this.markUsedOrientation(h,p,f),this.placedOrientations[f.crossTileID]=p),{shift:v,placedGlyphBoxes:y}},we.prototype.placeLayerBucketPart=function(e,r,n){var i=this,a=e.parameters,o=a.bucket,s=a.layout,l=a.posMatrix,c=a.textLabelPlaneMatrix,u=a.labelToScreenMatrix,f=a.textPixelRatio,h=a.holdingForFade,p=a.collisionBoxArray,d=a.partiallyEvaluatedTextSize,m=a.collisionGroup,g=s.get(\"text-optional\"),v=s.get(\"icon-optional\"),y=s.get(\"text-allow-overlap\"),x=s.get(\"icon-allow-overlap\"),b=\"map\"===s.get(\"text-rotation-alignment\"),_=\"map\"===s.get(\"text-pitch-alignment\"),w=\"none\"!==s.get(\"icon-text-fit\"),T=\"viewport-y\"===s.get(\"symbol-z-order\"),k=y&&(x||!o.hasIconData()||v),M=x&&(y||!o.hasTextData()||g);!o.collisionArrays&&p&&o.deserializeCollisionBoxes(p);var A=function(e,a){if(!r[e.crossTileID])if(h)i.placements[e.crossTileID]=new ge(!1,!1,!1);else{var p,T=!1,A=!1,S=!0,E=null,L={box:null,offscreen:null},C={box:null,offscreen:null},P=null,I=null,O=0,z=0,D=0;a.textFeatureIndex?O=a.textFeatureIndex:e.useRuntimeCollisionCircles&&(O=e.featureIndex),a.verticalTextFeatureIndex&&(z=a.verticalTextFeatureIndex);var R=a.textBox;if(R){var F=function(r){var n=t.WritingMode.horizontal;if(o.allowVerticalPlacement&&!r&&i.prevPlacement){var a=i.prevPlacement.placedOrientations[e.crossTileID];a&&(i.placedOrientations[e.crossTileID]=a,n=a,i.markUsedOrientation(o,n,e))}return n},B=function(r,n){if(o.allowVerticalPlacement&&e.numVerticalGlyphVertices>0&&a.verticalTextBox)for(var i=0,s=o.writingModes;i<s.length;i+=1){if(s[i]===t.WritingMode.vertical?(L=n(),C=L):L=r(),L&&L.box&&L.box.length)break}else L=r()};if(s.get(\"text-variable-anchor\")){var N=s.get(\"text-variable-anchor\");if(i.prevPlacement&&i.prevPlacement.variableOffsets[e.crossTileID]){var j=i.prevPlacement.variableOffsets[e.crossTileID];N.indexOf(j.anchor)>0&&(N=N.filter((function(t){return t!==j.anchor}))).unshift(j.anchor)}var U=function(t,r,n){for(var a=t.x2-t.x1,s=t.y2-t.y1,c=e.textBoxScale,u=w&&!x?r:null,h={box:[],offscreen:!1},p=y?2*N.length:N.length,d=0;d<p;++d){var g=N[d%N.length],v=d>=N.length,k=i.attemptAnchorPlacement(g,t,a,s,c,b,_,f,l,m,v,e,o,n,u);if(k&&(h=k.placedGlyphBoxes)&&h.box&&h.box.length){T=!0,E=k.shift;break}}return h};B((function(){return U(R,a.iconBox,t.WritingMode.horizontal)}),(function(){var r=a.verticalTextBox,n=L&&L.box&&L.box.length;return o.allowVerticalPlacement&&!n&&e.numVerticalGlyphVertices>0&&r?U(r,a.verticalIconBox,t.WritingMode.vertical):{box:null,offscreen:null}})),L&&(T=L.box,S=L.offscreen);var V=F(L&&L.box);if(!T&&i.prevPlacement){var q=i.prevPlacement.variableOffsets[e.crossTileID];q&&(i.variableOffsets[e.crossTileID]=q,i.markUsedJustification(o,q.anchor,e,V))}}else{var H=function(t,r){var n=i.collisionIndex.placeCollisionBox(t,y,f,l,m.predicate);return n&&n.box&&n.box.length&&(i.markUsedOrientation(o,r,e),i.placedOrientations[e.crossTileID]=r),n};B((function(){return H(R,t.WritingMode.horizontal)}),(function(){var r=a.verticalTextBox;return o.allowVerticalPlacement&&e.numVerticalGlyphVertices>0&&r?H(r,t.WritingMode.vertical):{box:null,offscreen:null}})),F(L&&L.box&&L.box.length)}}if(T=(p=L)&&p.box&&p.box.length>0,S=p&&p.offscreen,e.useRuntimeCollisionCircles){var G=o.text.placedSymbolArray.get(e.centerJustifiedTextSymbolIndex),Y=t.evaluateSizeForFeature(o.textSizeData,d,G),W=s.get(\"text-padding\"),X=e.collisionCircleDiameter;P=i.collisionIndex.placeCollisionCircles(y,G,o.lineVertexArray,o.glyphOffsetArray,Y,l,c,u,n,_,m.predicate,X,W),T=y||P.circles.length>0&&!P.collisionDetected,S=S&&P.offscreen}if(a.iconFeatureIndex&&(D=a.iconFeatureIndex),a.iconBox){var Z=function(t){var e=w&&E?_e(t,E.x,E.y,b,_,i.transform.angle):t;return i.collisionIndex.placeCollisionBox(e,x,f,l,m.predicate)};A=C&&C.box&&C.box.length&&a.verticalIconBox?(I=Z(a.verticalIconBox)).box.length>0:(I=Z(a.iconBox)).box.length>0,S=S&&I.offscreen}var J=g||0===e.numHorizontalGlyphVertices&&0===e.numVerticalGlyphVertices,K=v||0===e.numIconVertices;if(J||K?K?J||(A=A&&T):T=A&&T:A=T=A&&T,T&&p&&p.box&&(C&&C.box&&z?i.collisionIndex.insertCollisionBox(p.box,s.get(\"text-ignore-placement\"),o.bucketInstanceId,z,m.ID):i.collisionIndex.insertCollisionBox(p.box,s.get(\"text-ignore-placement\"),o.bucketInstanceId,O,m.ID)),A&&I&&i.collisionIndex.insertCollisionBox(I.box,s.get(\"icon-ignore-placement\"),o.bucketInstanceId,D,m.ID),P&&(T&&i.collisionIndex.insertCollisionCircles(P.circles,s.get(\"text-ignore-placement\"),o.bucketInstanceId,O,m.ID),n)){var Q=o.bucketInstanceId,$=i.collisionCircleArrays[Q];void 0===$&&($=i.collisionCircleArrays[Q]=new ve);for(var tt=0;tt<P.circles.length;tt+=4)$.circles.push(P.circles[tt+0]),$.circles.push(P.circles[tt+1]),$.circles.push(P.circles[tt+2]),$.circles.push(P.collisionDetected?1:0)}i.placements[e.crossTileID]=new ge(T||k,A||M,S||o.justReloaded),r[e.crossTileID]=!0}};if(T)for(var S=o.getSortedSymbolIndexes(this.transform.angle),E=S.length-1;E>=0;--E){var L=S[E];A(o.symbolInstances.get(L),o.collisionArrays[L])}else for(var C=e.symbolInstanceStart;C<e.symbolInstanceEnd;C++)A(o.symbolInstances.get(C),o.collisionArrays[C]);if(n&&o.bucketInstanceId in this.collisionCircleArrays){var P=this.collisionCircleArrays[o.bucketInstanceId];t.invert(P.invProjMatrix,l),P.viewportMatrix=this.collisionIndex.getViewportMatrix()}o.justReloaded=!1},we.prototype.markUsedJustification=function(e,r,n,i){var a,o={left:n.leftJustifiedTextSymbolIndex,center:n.centerJustifiedTextSymbolIndex,right:n.rightJustifiedTextSymbolIndex};a=i===t.WritingMode.vertical?n.verticalPlacedTextSymbolIndex:o[t.getAnchorJustification(r)];for(var s=0,l=[n.leftJustifiedTextSymbolIndex,n.centerJustifiedTextSymbolIndex,n.rightJustifiedTextSymbolIndex,n.verticalPlacedTextSymbolIndex];s<l.length;s+=1){var c=l[s];c>=0&&(e.text.placedSymbolArray.get(c).crossTileID=a>=0&&c!==a?0:n.crossTileID)}},we.prototype.markUsedOrientation=function(e,r,n){for(var i=r===t.WritingMode.horizontal||r===t.WritingMode.horizontalOnly?r:0,a=r===t.WritingMode.vertical?r:0,o=0,s=[n.leftJustifiedTextSymbolIndex,n.centerJustifiedTextSymbolIndex,n.rightJustifiedTextSymbolIndex];o<s.length;o+=1){var l=s[o];e.text.placedSymbolArray.get(l).placedOrientation=i}n.verticalPlacedTextSymbolIndex&&(e.text.placedSymbolArray.get(n.verticalPlacedTextSymbolIndex).placedOrientation=a)},we.prototype.commit=function(t){this.commitTime=t,this.zoomAtLastRecencyCheck=this.transform.zoom;var e=this.prevPlacement,r=!1;this.prevZoomAdjustment=e?e.zoomAdjustment(this.transform.zoom):0;var n=e?e.symbolFadeChange(t):1,i=e?e.opacities:{},a=e?e.variableOffsets:{},o=e?e.placedOrientations:{};for(var s in this.placements){var l=this.placements[s],c=i[s];c?(this.opacities[s]=new me(c,n,l.text,l.icon),r=r||l.text!==c.text.placed||l.icon!==c.icon.placed):(this.opacities[s]=new me(null,n,l.text,l.icon,l.skipFade),r=r||l.text||l.icon)}for(var u in i){var f=i[u];if(!this.opacities[u]){var h=new me(f,n,!1,!1);h.isHidden()||(this.opacities[u]=h,r=r||f.text.placed||f.icon.placed)}}for(var p in a)this.variableOffsets[p]||!this.opacities[p]||this.opacities[p].isHidden()||(this.variableOffsets[p]=a[p]);for(var d in o)this.placedOrientations[d]||!this.opacities[d]||this.opacities[d].isHidden()||(this.placedOrientations[d]=o[d]);r?this.lastPlacementChangeTime=t:\"number\"!=typeof this.lastPlacementChangeTime&&(this.lastPlacementChangeTime=e?e.lastPlacementChangeTime:t)},we.prototype.updateLayerOpacities=function(t,e){for(var r={},n=0,i=e;n<i.length;n+=1){var a=i[n],o=a.getBucket(t);o&&a.latestFeatureIndex&&t.id===o.layerIds[0]&&this.updateBucketOpacities(o,r,a.collisionBoxArray)}},we.prototype.updateBucketOpacities=function(e,r,n){var i=this;e.hasTextData()&&e.text.opacityVertexArray.clear(),e.hasIconData()&&e.icon.opacityVertexArray.clear(),e.hasIconCollisionBoxData()&&e.iconCollisionBox.collisionVertexArray.clear(),e.hasTextCollisionBoxData()&&e.textCollisionBox.collisionVertexArray.clear();var a=e.layers[0].layout,o=new me(null,0,!1,!1,!0),s=a.get(\"text-allow-overlap\"),l=a.get(\"icon-allow-overlap\"),c=a.get(\"text-variable-anchor\"),u=\"map\"===a.get(\"text-rotation-alignment\"),f=\"map\"===a.get(\"text-pitch-alignment\"),h=\"none\"!==a.get(\"icon-text-fit\"),p=new me(null,0,s&&(l||!e.hasIconData()||a.get(\"icon-optional\")),l&&(s||!e.hasTextData()||a.get(\"text-optional\")),!0);!e.collisionArrays&&n&&(e.hasIconCollisionBoxData()||e.hasTextCollisionBoxData())&&e.deserializeCollisionBoxes(n);for(var d=function(t,e,r){for(var n=0;n<e/4;n++)t.opacityVertexArray.emplaceBack(r)},m=function(n){var a=e.symbolInstances.get(n),s=a.numHorizontalGlyphVertices,l=a.numVerticalGlyphVertices,m=a.crossTileID,g=r[m],v=i.opacities[m];g?v=o:v||(v=p,i.opacities[m]=v),r[m]=!0;var y=s>0||l>0,x=a.numIconVertices>0,b=i.placedOrientations[a.crossTileID],_=b===t.WritingMode.vertical,w=b===t.WritingMode.horizontal||b===t.WritingMode.horizontalOnly;if(y){var T=Pe(v.text),k=_?Ie:T;d(e.text,s,k);var M=w?Ie:T;d(e.text,l,M);var A=v.text.isHidden();[a.rightJustifiedTextSymbolIndex,a.centerJustifiedTextSymbolIndex,a.leftJustifiedTextSymbolIndex].forEach((function(t){t>=0&&(e.text.placedSymbolArray.get(t).hidden=A||_?1:0)})),a.verticalPlacedTextSymbolIndex>=0&&(e.text.placedSymbolArray.get(a.verticalPlacedTextSymbolIndex).hidden=A||w?1:0);var S=i.variableOffsets[a.crossTileID];S&&i.markUsedJustification(e,S.anchor,a,b);var E=i.placedOrientations[a.crossTileID];E&&(i.markUsedJustification(e,\"left\",a,E),i.markUsedOrientation(e,E,a))}if(x){var L=Pe(v.icon),C=!(h&&a.verticalPlacedIconSymbolIndex&&_);if(a.placedIconSymbolIndex>=0){var P=C?L:Ie;d(e.icon,a.numIconVertices,P),e.icon.placedSymbolArray.get(a.placedIconSymbolIndex).hidden=v.icon.isHidden()}if(a.verticalPlacedIconSymbolIndex>=0){var I=C?Ie:L;d(e.icon,a.numVerticalIconVertices,I),e.icon.placedSymbolArray.get(a.verticalPlacedIconSymbolIndex).hidden=v.icon.isHidden()}}if(e.hasIconCollisionBoxData()||e.hasTextCollisionBoxData()){var O=e.collisionArrays[n];if(O){var z=new t.Point(0,0);if(O.textBox||O.verticalTextBox){var D=!0;if(c){var R=i.variableOffsets[m];R?(z=be(R.anchor,R.width,R.height,R.textOffset,R.textBoxScale),u&&z._rotate(f?i.transform.angle:-i.transform.angle)):D=!1}O.textBox&&Te(e.textCollisionBox.collisionVertexArray,v.text.placed,!D||_,z.x,z.y),O.verticalTextBox&&Te(e.textCollisionBox.collisionVertexArray,v.text.placed,!D||w,z.x,z.y)}var F=Boolean(!w&&O.verticalIconBox);O.iconBox&&Te(e.iconCollisionBox.collisionVertexArray,v.icon.placed,F,h?z.x:0,h?z.y:0),O.verticalIconBox&&Te(e.iconCollisionBox.collisionVertexArray,v.icon.placed,!F,h?z.x:0,h?z.y:0)}}},g=0;g<e.symbolInstances.length;g++)m(g);if(e.sortFeatures(this.transform.angle),this.retainedQueryData[e.bucketInstanceId]&&(this.retainedQueryData[e.bucketInstanceId].featureSortOrder=e.featureSortOrder),e.hasTextData()&&e.text.opacityVertexBuffer&&e.text.opacityVertexBuffer.updateData(e.text.opacityVertexArray),e.hasIconData()&&e.icon.opacityVertexBuffer&&e.icon.opacityVertexBuffer.updateData(e.icon.opacityVertexArray),e.hasIconCollisionBoxData()&&e.iconCollisionBox.collisionVertexBuffer&&e.iconCollisionBox.collisionVertexBuffer.updateData(e.iconCollisionBox.collisionVertexArray),e.hasTextCollisionBoxData()&&e.textCollisionBox.collisionVertexBuffer&&e.textCollisionBox.collisionVertexBuffer.updateData(e.textCollisionBox.collisionVertexArray),e.bucketInstanceId in this.collisionCircleArrays){var v=this.collisionCircleArrays[e.bucketInstanceId];e.placementInvProjMatrix=v.invProjMatrix,e.placementViewportMatrix=v.viewportMatrix,e.collisionCircleArray=v.circles,delete this.collisionCircleArrays[e.bucketInstanceId]}},we.prototype.symbolFadeChange=function(t){return 0===this.fadeDuration?1:(t-this.commitTime)/this.fadeDuration+this.prevZoomAdjustment},we.prototype.zoomAdjustment=function(t){return Math.max(0,(this.transform.zoom-t)/1.5)},we.prototype.hasTransitions=function(t){return this.stale||t-this.lastPlacementChangeTime<this.fadeDuration},we.prototype.stillRecent=function(t,e){var r=this.zoomAtLastRecencyCheck===e?1-this.zoomAdjustment(e):1;return this.zoomAtLastRecencyCheck=e,this.commitTime+this.fadeDuration*r>t},we.prototype.setStale=function(){this.stale=!0};var ke=Math.pow(2,25),Me=Math.pow(2,24),Ae=Math.pow(2,17),Se=Math.pow(2,16),Ee=Math.pow(2,9),Le=Math.pow(2,8),Ce=Math.pow(2,1);function Pe(t){if(0===t.opacity&&!t.placed)return 0;if(1===t.opacity&&t.placed)return 4294967295;var e=t.placed?1:0,r=Math.floor(127*t.opacity);return r*ke+e*Me+r*Ae+e*Se+r*Ee+e*Le+r*Ce+e}var Ie=0,Oe=function(t){this._sortAcrossTiles=\"viewport-y\"!==t.layout.get(\"symbol-z-order\")&&void 0!==t.layout.get(\"symbol-sort-key\").constantOr(1),this._currentTileIndex=0,this._currentPartIndex=0,this._seenCrossTileIDs={},this._bucketParts=[]};Oe.prototype.continuePlacement=function(t,e,r,n,i){for(var a=this._bucketParts;this._currentTileIndex<t.length;){var o=t[this._currentTileIndex];if(e.getBucketParts(a,n,o,this._sortAcrossTiles),this._currentTileIndex++,i())return!0}for(this._sortAcrossTiles&&(this._sortAcrossTiles=!1,a.sort((function(t,e){return t.sortKey-e.sortKey})));this._currentPartIndex<a.length;){var s=a[this._currentPartIndex];if(e.placeLayerBucketPart(s,this._seenCrossTileIDs,r),this._currentPartIndex++,i())return!0}return!1};var ze=function(t,e,r,n,i,a,o){this.placement=new we(t,i,a,o),this._currentPlacementIndex=e.length-1,this._forceFullPlacement=r,this._showCollisionBoxes=n,this._done=!1};ze.prototype.isDone=function(){return this._done},ze.prototype.continuePlacement=function(e,r,n){for(var i=this,a=t.browser.now(),o=function(){var e=t.browser.now()-a;return!i._forceFullPlacement&&e>2};this._currentPlacementIndex>=0;){var s=r[e[this._currentPlacementIndex]],l=this.placement.collisionIndex.transform.zoom;if(\"symbol\"===s.type&&(!s.minzoom||s.minzoom<=l)&&(!s.maxzoom||s.maxzoom>l)){if(this._inProgressLayer||(this._inProgressLayer=new Oe(s)),this._inProgressLayer.continuePlacement(n[s.source],this.placement,this._showCollisionBoxes,s,o))return;delete this._inProgressLayer}this._currentPlacementIndex--}this._done=!0},ze.prototype.commit=function(t){return this.placement.commit(t),this.placement};var De=512/t.EXTENT/2,Re=function(t,e,r){this.tileID=t,this.indexedSymbolInstances={},this.bucketInstanceId=r;for(var n=0;n<e.length;n++){var i=e.get(n),a=i.key;this.indexedSymbolInstances[a]||(this.indexedSymbolInstances[a]=[]),this.indexedSymbolInstances[a].push({crossTileID:i.crossTileID,coord:this.getScaledCoordinates(i,t)})}};Re.prototype.getScaledCoordinates=function(e,r){var n=r.canonical.z-this.tileID.canonical.z,i=De/Math.pow(2,n);return{x:Math.floor((r.canonical.x*t.EXTENT+e.anchorX)*i),y:Math.floor((r.canonical.y*t.EXTENT+e.anchorY)*i)}},Re.prototype.findMatches=function(t,e,r){for(var n=this.tileID.canonical.z<e.canonical.z?1:Math.pow(2,this.tileID.canonical.z-e.canonical.z),i=0;i<t.length;i++){var a=t.get(i);if(!a.crossTileID){var o=this.indexedSymbolInstances[a.key];if(o)for(var s=this.getScaledCoordinates(a,e),l=0,c=o;l<c.length;l+=1){var u=c[l];if(Math.abs(u.coord.x-s.x)<=n&&Math.abs(u.coord.y-s.y)<=n&&!r[u.crossTileID]){r[u.crossTileID]=!0,a.crossTileID=u.crossTileID;break}}}}};var Fe=function(){this.maxCrossTileID=0};Fe.prototype.generate=function(){return++this.maxCrossTileID};var Be=function(){this.indexes={},this.usedCrossTileIDs={},this.lng=0};Be.prototype.handleWrapJump=function(t){var e=Math.round((t-this.lng)/360);if(0!==e)for(var r in this.indexes){var n=this.indexes[r],i={};for(var a in n){var o=n[a];o.tileID=o.tileID.unwrapTo(o.tileID.wrap+e),i[o.tileID.key]=o}this.indexes[r]=i}this.lng=t},Be.prototype.addBucket=function(t,e,r){if(this.indexes[t.overscaledZ]&&this.indexes[t.overscaledZ][t.key]){if(this.indexes[t.overscaledZ][t.key].bucketInstanceId===e.bucketInstanceId)return!1;this.removeBucketCrossTileIDs(t.overscaledZ,this.indexes[t.overscaledZ][t.key])}for(var n=0;n<e.symbolInstances.length;n++){e.symbolInstances.get(n).crossTileID=0}this.usedCrossTileIDs[t.overscaledZ]||(this.usedCrossTileIDs[t.overscaledZ]={});var i=this.usedCrossTileIDs[t.overscaledZ];for(var a in this.indexes){var o=this.indexes[a];if(Number(a)>t.overscaledZ)for(var s in o){var l=o[s];l.tileID.isChildOf(t)&&l.findMatches(e.symbolInstances,t,i)}else{var c=o[t.scaledTo(Number(a)).key];c&&c.findMatches(e.symbolInstances,t,i)}}for(var u=0;u<e.symbolInstances.length;u++){var f=e.symbolInstances.get(u);f.crossTileID||(f.crossTileID=r.generate(),i[f.crossTileID]=!0)}return void 0===this.indexes[t.overscaledZ]&&(this.indexes[t.overscaledZ]={}),this.indexes[t.overscaledZ][t.key]=new Re(t,e.symbolInstances,e.bucketInstanceId),!0},Be.prototype.removeBucketCrossTileIDs=function(t,e){for(var r in e.indexedSymbolInstances)for(var n=0,i=e.indexedSymbolInstances[r];n<i.length;n+=1){var a=i[n];delete this.usedCrossTileIDs[t][a.crossTileID]}},Be.prototype.removeStaleBuckets=function(t){var e=!1;for(var r in this.indexes){var n=this.indexes[r];for(var i in n)t[n[i].bucketInstanceId]||(this.removeBucketCrossTileIDs(r,n[i]),delete n[i],e=!0)}return e};var Ne=function(){this.layerIndexes={},this.crossTileIDs=new Fe,this.maxBucketInstanceId=0,this.bucketsInCurrentPlacement={}};Ne.prototype.addLayer=function(t,e,r){var n=this.layerIndexes[t.id];void 0===n&&(n=this.layerIndexes[t.id]=new Be);var i=!1,a={};n.handleWrapJump(r);for(var o=0,s=e;o<s.length;o+=1){var l=s[o],c=l.getBucket(t);c&&t.id===c.layerIds[0]&&(c.bucketInstanceId||(c.bucketInstanceId=++this.maxBucketInstanceId),n.addBucket(l.tileID,c,this.crossTileIDs)&&(i=!0),a[c.bucketInstanceId]=!0)}return n.removeStaleBuckets(a)&&(i=!0),i},Ne.prototype.pruneUnusedLayers=function(t){var e={};for(var r in t.forEach((function(t){e[t]=!0})),this.layerIndexes)e[r]||delete this.layerIndexes[r]};var je=function(e,r){return t.emitValidationErrors(e,r&&r.filter((function(t){return\"source.canvas\"!==t.identifier})))},Ue=t.pick(Ut,[\"addLayer\",\"removeLayer\",\"setPaintProperty\",\"setLayoutProperty\",\"setFilter\",\"addSource\",\"removeSource\",\"setLayerZoomRange\",\"setLight\",\"setTransition\",\"setGeoJSONSourceData\"]),Ve=t.pick(Ut,[\"setCenter\",\"setZoom\",\"setBearing\",\"setPitch\"]),qe=function(){var e={},r=t.styleSpec.$version;for(var n in t.styleSpec.$root){var i=t.styleSpec.$root[n];if(i.required){var a=null;null!=(a=\"version\"===n?r:\"array\"===i.type?[]:{})&&(e[n]=a)}}return e}(),He=function(e){function r(n,i){var a=this;void 0===i&&(i={}),e.call(this),this.map=n,this.dispatcher=new k(Bt(),this),this.imageManager=new h,this.imageManager.setEventedParent(this),this.glyphManager=new x(n._requestManager,i.localIdeographFontFamily),this.lineAtlas=new T(256,512),this.crossTileSymbolIndex=new Ne,this._layers={},this._serializedLayers={},this._order=[],this.sourceCaches={},this.zoomHistory=new t.ZoomHistory,this._loaded=!1,this._availableImages=[],this._resetUpdates(),this.dispatcher.broadcast(\"setReferrer\",t.getReferrer());var o=this;this._rtlTextPluginCallback=r.registerForPluginStateChange((function(e){var r={pluginStatus:e.pluginStatus,pluginURL:e.pluginURL};o.dispatcher.broadcast(\"syncRTLPluginState\",r,(function(e,r){if((t.triggerPluginCompletionEvent(e),r)&&r.every((function(t){return t})))for(var n in o.sourceCaches)o.sourceCaches[n].reload()}))})),this.on(\"data\",(function(t){if(\"source\"===t.dataType&&\"metadata\"===t.sourceDataType){var e=a.sourceCaches[t.sourceId];if(e){var r=e.getSource();if(r&&r.vectorLayerIds)for(var n in a._layers){var i=a._layers[n];i.source===r.id&&a._validateLayer(i)}}}}))}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.loadURL=function(e,r){var n=this;void 0===r&&(r={}),this.fire(new t.Event(\"dataloading\",{dataType:\"style\"}));var i=\"boolean\"==typeof r.validate?r.validate:!t.isMapboxURL(e);e=this.map._requestManager.normalizeStyleURL(e,r.accessToken);var a=this.map._requestManager.transformRequest(e,t.ResourceType.Style);this._request=t.getJSON(a,(function(e,r){n._request=null,e?n.fire(new t.ErrorEvent(e)):r&&n._load(r,i)}))},r.prototype.loadJSON=function(e,r){var n=this;void 0===r&&(r={}),this.fire(new t.Event(\"dataloading\",{dataType:\"style\"})),this._request=t.browser.frame((function(){n._request=null,n._load(e,!1!==r.validate)}))},r.prototype.loadEmpty=function(){this.fire(new t.Event(\"dataloading\",{dataType:\"style\"})),this._load(qe,!1)},r.prototype._load=function(e,r){if(!r||!je(this,t.validateStyle(e))){for(var n in this._loaded=!0,this.stylesheet=e,e.sources)this.addSource(n,e.sources[n],{validate:!1});e.sprite?this._loadSprite(e.sprite):this.imageManager.setLoaded(!0),this.glyphManager.setURL(e.glyphs);var i=jt(this.stylesheet.layers);this._order=i.map((function(t){return t.id})),this._layers={},this._serializedLayers={};for(var a=0,o=i;a<o.length;a+=1){var s=o[a];(s=t.createStyleLayer(s)).setEventedParent(this,{layer:{id:s.id}}),this._layers[s.id]=s,this._serializedLayers[s.id]=s.serialize()}this.dispatcher.broadcast(\"setLayers\",this._serializeLayers(this._order)),this.light=new w(this.stylesheet.light),this.fire(new t.Event(\"data\",{dataType:\"style\"})),this.fire(new t.Event(\"style.load\"))}},r.prototype._loadSprite=function(e){var r=this;this._spriteRequest=function(e,r,n){var i,a,o,s=t.browser.devicePixelRatio>1?\"@2x\":\"\",l=t.getJSON(r.transformRequest(r.normalizeSpriteURL(e,s,\".json\"),t.ResourceType.SpriteJSON),(function(t,e){l=null,o||(o=t,i=e,u())})),c=t.getImage(r.transformRequest(r.normalizeSpriteURL(e,s,\".png\"),t.ResourceType.SpriteImage),(function(t,e){c=null,o||(o=t,a=e,u())}));function u(){if(o)n(o);else if(i&&a){var e=t.browser.getImageData(a),r={};for(var s in i){var l=i[s],c=l.width,u=l.height,f=l.x,h=l.y,p=l.sdf,d=l.pixelRatio,m=l.stretchX,g=l.stretchY,v=l.content,y=new t.RGBAImage({width:c,height:u});t.RGBAImage.copy(e,y,{x:f,y:h},{x:0,y:0},{width:c,height:u}),r[s]={data:y,pixelRatio:d,sdf:p,stretchX:m,stretchY:g,content:v}}n(null,r)}}return{cancel:function(){l&&(l.cancel(),l=null),c&&(c.cancel(),c=null)}}}(e,this.map._requestManager,(function(e,n){if(r._spriteRequest=null,e)r.fire(new t.ErrorEvent(e));else if(n)for(var i in n)r.imageManager.addImage(i,n[i]);r.imageManager.setLoaded(!0),r._availableImages=r.imageManager.listImages(),r.dispatcher.broadcast(\"setImages\",r._availableImages),r.fire(new t.Event(\"data\",{dataType:\"style\"}))}))},r.prototype._validateLayer=function(e){var r=this.sourceCaches[e.source];if(r){var n=e.sourceLayer;if(n){var i=r.getSource();(\"geojson\"===i.type||i.vectorLayerIds&&-1===i.vectorLayerIds.indexOf(n))&&this.fire(new t.ErrorEvent(new Error('Source layer \"'+n+'\" does not exist on source \"'+i.id+'\" as specified by style layer \"'+e.id+'\"')))}}},r.prototype.loaded=function(){if(!this._loaded)return!1;if(Object.keys(this._updatedSources).length)return!1;for(var t in this.sourceCaches)if(!this.sourceCaches[t].loaded())return!1;return!!this.imageManager.isLoaded()},r.prototype._serializeLayers=function(t){for(var e=[],r=0,n=t;r<n.length;r+=1){var i=n[r],a=this._layers[i];\"custom\"!==a.type&&e.push(a.serialize())}return e},r.prototype.hasTransitions=function(){if(this.light&&this.light.hasTransition())return!0;for(var t in this.sourceCaches)if(this.sourceCaches[t].hasTransition())return!0;for(var e in this._layers)if(this._layers[e].hasTransition())return!0;return!1},r.prototype._checkLoaded=function(){if(!this._loaded)throw new Error(\"Style is not done loading\")},r.prototype.update=function(e){if(this._loaded){var r=this._changed;if(this._changed){var n=Object.keys(this._updatedLayers),i=Object.keys(this._removedLayers);for(var a in(n.length||i.length)&&this._updateWorkerLayers(n,i),this._updatedSources){var o=this._updatedSources[a];\"reload\"===o?this._reloadSource(a):\"clear\"===o&&this._clearSource(a)}for(var s in this._updateTilesForChangedImages(),this._updatedPaintProps)this._layers[s].updateTransitions(e);this.light.updateTransitions(e),this._resetUpdates()}for(var l in this.sourceCaches)this.sourceCaches[l].used=!1;for(var c=0,u=this._order;c<u.length;c+=1){var f=u[c],h=this._layers[f];h.recalculate(e,this._availableImages),!h.isHidden(e.zoom)&&h.source&&(this.sourceCaches[h.source].used=!0)}this.light.recalculate(e),this.z=e.zoom,r&&this.fire(new t.Event(\"data\",{dataType:\"style\"}))}},r.prototype._updateTilesForChangedImages=function(){var t=Object.keys(this._changedImages);if(t.length){for(var e in this.sourceCaches)this.sourceCaches[e].reloadTilesForDependencies([\"icons\",\"patterns\"],t);this._changedImages={}}},r.prototype._updateWorkerLayers=function(t,e){this.dispatcher.broadcast(\"updateLayers\",{layers:this._serializeLayers(t),removedIds:e})},r.prototype._resetUpdates=function(){this._changed=!1,this._updatedLayers={},this._removedLayers={},this._updatedSources={},this._updatedPaintProps={},this._changedImages={}},r.prototype.setState=function(e){var r=this;if(this._checkLoaded(),je(this,t.validateStyle(e)))return!1;(e=t.clone$1(e)).layers=jt(e.layers);var n=Zt(this.serialize(),e).filter((function(t){return!(t.command in Ve)}));if(0===n.length)return!1;var i=n.filter((function(t){return!(t.command in Ue)}));if(i.length>0)throw new Error(\"Unimplemented: \"+i.map((function(t){return t.command})).join(\", \")+\".\");return n.forEach((function(t){\"setTransition\"!==t.command&&r[t.command].apply(r,t.args)})),this.stylesheet=e,!0},r.prototype.addImage=function(e,r){if(this.getImage(e))return this.fire(new t.ErrorEvent(new Error(\"An image with this name already exists.\")));this.imageManager.addImage(e,r),this._availableImages=this.imageManager.listImages(),this._changedImages[e]=!0,this._changed=!0,this.fire(new t.Event(\"data\",{dataType:\"style\"}))},r.prototype.updateImage=function(t,e){this.imageManager.updateImage(t,e)},r.prototype.getImage=function(t){return this.imageManager.getImage(t)},r.prototype.removeImage=function(e){if(!this.getImage(e))return this.fire(new t.ErrorEvent(new Error(\"No image with this name exists.\")));this.imageManager.removeImage(e),this._availableImages=this.imageManager.listImages(),this._changedImages[e]=!0,this._changed=!0,this.fire(new t.Event(\"data\",{dataType:\"style\"}))},r.prototype.listImages=function(){return this._checkLoaded(),this.imageManager.listImages()},r.prototype.addSource=function(e,r,n){var i=this;if(void 0===n&&(n={}),this._checkLoaded(),void 0!==this.sourceCaches[e])throw new Error(\"There is already a source with this ID\");if(!r.type)throw new Error(\"The type property must be defined, but the only the following properties were given: \"+Object.keys(r).join(\", \")+\".\");if(!([\"vector\",\"raster\",\"geojson\",\"video\",\"image\"].indexOf(r.type)>=0)||!this._validate(t.validateStyle.source,\"sources.\"+e,r,null,n)){this.map&&this.map._collectResourceTiming&&(r.collectResourceTiming=!0);var a=this.sourceCaches[e]=new Ct(e,r,this.dispatcher);a.style=this,a.setEventedParent(this,(function(){return{isSourceLoaded:i.loaded(),source:a.serialize(),sourceId:e}})),a.onAdd(this.map),this._changed=!0}},r.prototype.removeSource=function(e){if(this._checkLoaded(),void 0===this.sourceCaches[e])throw new Error(\"There is no source with this ID\");for(var r in this._layers)if(this._layers[r].source===e)return this.fire(new t.ErrorEvent(new Error('Source \"'+e+'\" cannot be removed while layer \"'+r+'\" is using it.')));var n=this.sourceCaches[e];delete this.sourceCaches[e],delete this._updatedSources[e],n.fire(new t.Event(\"data\",{sourceDataType:\"metadata\",dataType:\"source\",sourceId:e})),n.setEventedParent(null),n.clearTiles(),n.onRemove&&n.onRemove(this.map),this._changed=!0},r.prototype.setGeoJSONSourceData=function(t,e){this._checkLoaded(),this.sourceCaches[t].getSource().setData(e),this._changed=!0},r.prototype.getSource=function(t){return this.sourceCaches[t]&&this.sourceCaches[t].getSource()},r.prototype.addLayer=function(e,r,n){void 0===n&&(n={}),this._checkLoaded();var i=e.id;if(this.getLayer(i))this.fire(new t.ErrorEvent(new Error('Layer with id \"'+i+'\" already exists on this map')));else{var a;if(\"custom\"===e.type){if(je(this,t.validateCustomStyleLayer(e)))return;a=t.createStyleLayer(e)}else{if(\"object\"==typeof e.source&&(this.addSource(i,e.source),e=t.clone$1(e),e=t.extend(e,{source:i})),this._validate(t.validateStyle.layer,\"layers.\"+i,e,{arrayIndex:-1},n))return;a=t.createStyleLayer(e),this._validateLayer(a),a.setEventedParent(this,{layer:{id:i}}),this._serializedLayers[a.id]=a.serialize()}var o=r?this._order.indexOf(r):this._order.length;if(r&&-1===o)this.fire(new t.ErrorEvent(new Error('Layer with id \"'+r+'\" does not exist on this map.')));else{if(this._order.splice(o,0,i),this._layerOrderChanged=!0,this._layers[i]=a,this._removedLayers[i]&&a.source&&\"custom\"!==a.type){var s=this._removedLayers[i];delete this._removedLayers[i],s.type!==a.type?this._updatedSources[a.source]=\"clear\":(this._updatedSources[a.source]=\"reload\",this.sourceCaches[a.source].pause())}this._updateLayer(a),a.onAdd&&a.onAdd(this.map)}}},r.prototype.moveLayer=function(e,r){if(this._checkLoaded(),this._changed=!0,this._layers[e]){if(e!==r){var n=this._order.indexOf(e);this._order.splice(n,1);var i=r?this._order.indexOf(r):this._order.length;r&&-1===i?this.fire(new t.ErrorEvent(new Error('Layer with id \"'+r+'\" does not exist on this map.'))):(this._order.splice(i,0,e),this._layerOrderChanged=!0)}}else this.fire(new t.ErrorEvent(new Error(\"The layer '\"+e+\"' does not exist in the map's style and cannot be moved.\")))},r.prototype.removeLayer=function(e){this._checkLoaded();var r=this._layers[e];if(r){r.setEventedParent(null);var n=this._order.indexOf(e);this._order.splice(n,1),this._layerOrderChanged=!0,this._changed=!0,this._removedLayers[e]=r,delete this._layers[e],delete this._serializedLayers[e],delete this._updatedLayers[e],delete this._updatedPaintProps[e],r.onRemove&&r.onRemove(this.map)}else this.fire(new t.ErrorEvent(new Error(\"The layer '\"+e+\"' does not exist in the map's style and cannot be removed.\")))},r.prototype.getLayer=function(t){return this._layers[t]},r.prototype.hasLayer=function(t){return t in this._layers},r.prototype.setLayerZoomRange=function(e,r,n){this._checkLoaded();var i=this.getLayer(e);i?i.minzoom===r&&i.maxzoom===n||(null!=r&&(i.minzoom=r),null!=n&&(i.maxzoom=n),this._updateLayer(i)):this.fire(new t.ErrorEvent(new Error(\"The layer '\"+e+\"' does not exist in the map's style and cannot have zoom extent.\")))},r.prototype.setFilter=function(e,r,n){void 0===n&&(n={}),this._checkLoaded();var i=this.getLayer(e);if(i){if(!t.deepEqual(i.filter,r))return null==r?(i.filter=void 0,void this._updateLayer(i)):void(this._validate(t.validateStyle.filter,\"layers.\"+i.id+\".filter\",r,null,n)||(i.filter=t.clone$1(r),this._updateLayer(i)))}else this.fire(new t.ErrorEvent(new Error(\"The layer '\"+e+\"' does not exist in the map's style and cannot be filtered.\")))},r.prototype.getFilter=function(e){return t.clone$1(this.getLayer(e).filter)},r.prototype.setLayoutProperty=function(e,r,n,i){void 0===i&&(i={}),this._checkLoaded();var a=this.getLayer(e);a?t.deepEqual(a.getLayoutProperty(r),n)||(a.setLayoutProperty(r,n,i),this._updateLayer(a)):this.fire(new t.ErrorEvent(new Error(\"The layer '\"+e+\"' does not exist in the map's style and cannot be styled.\")))},r.prototype.getLayoutProperty=function(e,r){var n=this.getLayer(e);if(n)return n.getLayoutProperty(r);this.fire(new t.ErrorEvent(new Error(\"The layer '\"+e+\"' does not exist in the map's style.\")))},r.prototype.setPaintProperty=function(e,r,n,i){void 0===i&&(i={}),this._checkLoaded();var a=this.getLayer(e);a?t.deepEqual(a.getPaintProperty(r),n)||(a.setPaintProperty(r,n,i)&&this._updateLayer(a),this._changed=!0,this._updatedPaintProps[e]=!0):this.fire(new t.ErrorEvent(new Error(\"The layer '\"+e+\"' does not exist in the map's style and cannot be styled.\")))},r.prototype.getPaintProperty=function(t,e){return this.getLayer(t).getPaintProperty(e)},r.prototype.setFeatureState=function(e,r){this._checkLoaded();var n=e.source,i=e.sourceLayer,a=this.sourceCaches[n];if(void 0!==a){var o=a.getSource().type;\"geojson\"===o&&i?this.fire(new t.ErrorEvent(new Error(\"GeoJSON sources cannot have a sourceLayer parameter.\"))):\"vector\"!==o||i?(void 0===e.id&&this.fire(new t.ErrorEvent(new Error(\"The feature id parameter must be provided.\"))),a.setFeatureState(i,e.id,r)):this.fire(new t.ErrorEvent(new Error(\"The sourceLayer parameter must be provided for vector source types.\")))}else this.fire(new t.ErrorEvent(new Error(\"The source '\"+n+\"' does not exist in the map's style.\")))},r.prototype.removeFeatureState=function(e,r){this._checkLoaded();var n=e.source,i=this.sourceCaches[n];if(void 0!==i){var a=i.getSource().type,o=\"vector\"===a?e.sourceLayer:void 0;\"vector\"!==a||o?r&&\"string\"!=typeof e.id&&\"number\"!=typeof e.id?this.fire(new t.ErrorEvent(new Error(\"A feature id is requred to remove its specific state property.\"))):i.removeFeatureState(o,e.id,r):this.fire(new t.ErrorEvent(new Error(\"The sourceLayer parameter must be provided for vector source types.\")))}else this.fire(new t.ErrorEvent(new Error(\"The source '\"+n+\"' does not exist in the map's style.\")))},r.prototype.getFeatureState=function(e){this._checkLoaded();var r=e.source,n=e.sourceLayer,i=this.sourceCaches[r];if(void 0!==i){if(\"vector\"!==i.getSource().type||n)return void 0===e.id&&this.fire(new t.ErrorEvent(new Error(\"The feature id parameter must be provided.\"))),i.getFeatureState(n,e.id);this.fire(new t.ErrorEvent(new Error(\"The sourceLayer parameter must be provided for vector source types.\")))}else this.fire(new t.ErrorEvent(new Error(\"The source '\"+r+\"' does not exist in the map's style.\")))},r.prototype.getTransition=function(){return t.extend({duration:300,delay:0},this.stylesheet&&this.stylesheet.transition)},r.prototype.serialize=function(){return t.filterObject({version:this.stylesheet.version,name:this.stylesheet.name,metadata:this.stylesheet.metadata,light:this.stylesheet.light,center:this.stylesheet.center,zoom:this.stylesheet.zoom,bearing:this.stylesheet.bearing,pitch:this.stylesheet.pitch,sprite:this.stylesheet.sprite,glyphs:this.stylesheet.glyphs,transition:this.stylesheet.transition,sources:t.mapObject(this.sourceCaches,(function(t){return t.serialize()})),layers:this._serializeLayers(this._order)},(function(t){return void 0!==t}))},r.prototype._updateLayer=function(t){this._updatedLayers[t.id]=!0,t.source&&!this._updatedSources[t.source]&&\"raster\"!==this.sourceCaches[t.source].getSource().type&&(this._updatedSources[t.source]=\"reload\",this.sourceCaches[t.source].pause()),this._changed=!0},r.prototype._flattenAndSortRenderedFeatures=function(t){for(var e=this,r=function(t){return\"fill-extrusion\"===e._layers[t].type},n={},i=[],a=this._order.length-1;a>=0;a--){var o=this._order[a];if(r(o)){n[o]=a;for(var s=0,l=t;s<l.length;s+=1){var c=l[s][o];if(c)for(var u=0,f=c;u<f.length;u+=1){var h=f[u];i.push(h)}}}}i.sort((function(t,e){return e.intersectionZ-t.intersectionZ}));for(var p=[],d=this._order.length-1;d>=0;d--){var m=this._order[d];if(r(m))for(var g=i.length-1;g>=0;g--){var v=i[g].feature;if(n[v.layer.id]<d)break;p.push(v),i.pop()}else for(var y=0,x=t;y<x.length;y+=1){var b=x[y][m];if(b)for(var _=0,w=b;_<w.length;_+=1){var T=w[_];p.push(T.feature)}}}return p},r.prototype.queryRenderedFeatures=function(e,r,n){r&&r.filter&&this._validate(t.validateStyle.filter,\"queryRenderedFeatures.filter\",r.filter,null,r);var i={};if(r&&r.layers){if(!Array.isArray(r.layers))return this.fire(new t.ErrorEvent(new Error(\"parameters.layers must be an Array.\"))),[];for(var a=0,o=r.layers;a<o.length;a+=1){var s=o[a],l=this._layers[s];if(!l)return this.fire(new t.ErrorEvent(new Error(\"The layer '\"+s+\"' does not exist in the map's style and cannot be queried for features.\"))),[];i[l.source]=!0}}var c=[];for(var u in r.availableImages=this._availableImages,this.sourceCaches)r.layers&&!i[u]||c.push(F(this.sourceCaches[u],this._layers,this._serializedLayers,e,r,n));return this.placement&&c.push(function(t,e,r,n,i,a,o){for(var s={},l=a.queryRenderedSymbols(n),c=[],u=0,f=Object.keys(l).map(Number);u<f.length;u+=1){var h=f[u];c.push(o[h])}c.sort(B);for(var p=function(){var r=m[d],n=r.featureIndex.lookupSymbolFeatures(l[r.bucketInstanceId],e,r.bucketIndex,r.sourceLayerIndex,i.filter,i.layers,i.availableImages,t);for(var a in n){var o=s[a]=s[a]||[],c=n[a];c.sort((function(t,e){var n=r.featureSortOrder;if(n){var i=n.indexOf(t.featureIndex);return n.indexOf(e.featureIndex)-i}return e.featureIndex-t.featureIndex}));for(var u=0,f=c;u<f.length;u+=1){var h=f[u];o.push(h)}}},d=0,m=c;d<m.length;d+=1)p();var g=function(e){s[e].forEach((function(n){var i=n.feature,a=t[e],o=r[a.source].getFeatureState(i.layer[\"source-layer\"],i.id);i.source=i.layer.source,i.layer[\"source-layer\"]&&(i.sourceLayer=i.layer[\"source-layer\"]),i.state=o}))};for(var v in s)g(v);return s}(this._layers,this._serializedLayers,this.sourceCaches,e,r,this.placement.collisionIndex,this.placement.retainedQueryData)),this._flattenAndSortRenderedFeatures(c)},r.prototype.querySourceFeatures=function(e,r){r&&r.filter&&this._validate(t.validateStyle.filter,\"querySourceFeatures.filter\",r.filter,null,r);var n=this.sourceCaches[e];return n?function(t,e){for(var r=t.getRenderableIds().map((function(e){return t.getTileByID(e)})),n=[],i={},a=0;a<r.length;a++){var o=r[a],s=o.tileID.canonical.key;i[s]||(i[s]=!0,o.querySourceFeatures(n,e))}return n}(n,r):[]},r.prototype.addSourceType=function(t,e,n){return r.getSourceType(t)?n(new Error('A source type called \"'+t+'\" already exists.')):(r.setSourceType(t,e),e.workerSourceURL?void this.dispatcher.broadcast(\"loadWorkerSource\",{name:t,url:e.workerSourceURL},n):n(null,null))},r.prototype.getLight=function(){return this.light.getLight()},r.prototype.setLight=function(e,r){void 0===r&&(r={}),this._checkLoaded();var n=this.light.getLight(),i=!1;for(var a in e)if(!t.deepEqual(e[a],n[a])){i=!0;break}if(i){var o={now:t.browser.now(),transition:t.extend({duration:300,delay:0},this.stylesheet.transition)};this.light.setLight(e,r),this.light.updateTransitions(o)}},r.prototype._validate=function(e,r,n,i,a){return void 0===a&&(a={}),(!a||!1!==a.validate)&&je(this,e.call(t.validateStyle,t.extend({key:r,style:this.serialize(),value:n,styleSpec:t.styleSpec},i)))},r.prototype._remove=function(){for(var e in this._request&&(this._request.cancel(),this._request=null),this._spriteRequest&&(this._spriteRequest.cancel(),this._spriteRequest=null),t.evented.off(\"pluginStateChange\",this._rtlTextPluginCallback),this._layers){this._layers[e].setEventedParent(null)}for(var r in this.sourceCaches)this.sourceCaches[r].clearTiles(),this.sourceCaches[r].setEventedParent(null);this.imageManager.setEventedParent(null),this.setEventedParent(null),this.dispatcher.remove()},r.prototype._clearSource=function(t){this.sourceCaches[t].clearTiles()},r.prototype._reloadSource=function(t){this.sourceCaches[t].resume(),this.sourceCaches[t].reload()},r.prototype._updateSources=function(t){for(var e in this.sourceCaches)this.sourceCaches[e].update(t)},r.prototype._generateCollisionBoxes=function(){for(var t in this.sourceCaches)this._reloadSource(t)},r.prototype._updatePlacement=function(e,r,n,i,a){void 0===a&&(a=!1);for(var o=!1,s=!1,l={},c=0,u=this._order;c<u.length;c+=1){var f=u[c],h=this._layers[f];if(\"symbol\"===h.type){if(!l[h.source]){var p=this.sourceCaches[h.source];l[h.source]=p.getRenderableIds(!0).map((function(t){return p.getTileByID(t)})).sort((function(t,e){return e.tileID.overscaledZ-t.tileID.overscaledZ||(t.tileID.isLessThan(e.tileID)?-1:1)}))}var d=this.crossTileSymbolIndex.addLayer(h,l[h.source],e.center.lng);o=o||d}}if(this.crossTileSymbolIndex.pruneUnusedLayers(this._order),((a=a||this._layerOrderChanged||0===n)||!this.pauseablePlacement||this.pauseablePlacement.isDone()&&!this.placement.stillRecent(t.browser.now(),e.zoom))&&(this.pauseablePlacement=new ze(e,this._order,a,r,n,i,this.placement),this._layerOrderChanged=!1),this.pauseablePlacement.isDone()?this.placement.setStale():(this.pauseablePlacement.continuePlacement(this._order,this._layers,l),this.pauseablePlacement.isDone()&&(this.placement=this.pauseablePlacement.commit(t.browser.now()),s=!0),o&&this.pauseablePlacement.placement.setStale()),s||o)for(var m=0,g=this._order;m<g.length;m+=1){var v=g[m],y=this._layers[v];\"symbol\"===y.type&&this.placement.updateLayerOpacities(y,l[y.source])}return!this.pauseablePlacement.isDone()||this.placement.hasTransitions(t.browser.now())},r.prototype._releaseSymbolFadeTiles=function(){for(var t in this.sourceCaches)this.sourceCaches[t].releaseSymbolFadeTiles()},r.prototype.getImages=function(t,e,r){this.imageManager.getImages(e.icons,r),this._updateTilesForChangedImages();var n=this.sourceCaches[e.source];n&&n.setDependencies(e.tileID.key,e.type,e.icons)},r.prototype.getGlyphs=function(t,e,r){this.glyphManager.getGlyphs(e.stacks,r)},r.prototype.getResource=function(e,r,n){return t.makeRequest(r,n)},r}(t.Evented);He.getSourceType=function(t){return D[t]},He.setSourceType=function(t,e){D[t]=e},He.registerForPluginStateChange=t.registerForPluginStateChange;var Ge=t.createLayout([{name:\"a_pos\",type:\"Int16\",components:2}]),Ye=yr(\"#ifdef GL_ES\\nprecision mediump float;\\n#else\\n#if !defined(lowp)\\n#define lowp\\n#endif\\n#if !defined(mediump)\\n#define mediump\\n#endif\\n#if !defined(highp)\\n#define highp\\n#endif\\n#endif\",\"#ifdef GL_ES\\nprecision highp float;\\n#else\\n#if !defined(lowp)\\n#define lowp\\n#endif\\n#if !defined(mediump)\\n#define mediump\\n#endif\\n#if !defined(highp)\\n#define highp\\n#endif\\n#endif\\nvec2 unpack_float(const float packedValue) {int packedIntValue=int(packedValue);int v0=packedIntValue/256;return vec2(v0,packedIntValue-v0*256);}vec2 unpack_opacity(const float packedOpacity) {int intOpacity=int(packedOpacity)/2;return vec2(float(intOpacity)/127.0,mod(packedOpacity,2.0));}vec4 decode_color(const vec2 encodedColor) {return vec4(unpack_float(encodedColor[0])/255.0,unpack_float(encodedColor[1])/255.0\\n);}float unpack_mix_vec2(const vec2 packedValue,const float t) {return mix(packedValue[0],packedValue[1],t);}vec4 unpack_mix_color(const vec4 packedColors,const float t) {vec4 minColor=decode_color(vec2(packedColors[0],packedColors[1]));vec4 maxColor=decode_color(vec2(packedColors[2],packedColors[3]));return mix(minColor,maxColor,t);}vec2 get_pattern_pos(const vec2 pixel_coord_upper,const vec2 pixel_coord_lower,const vec2 pattern_size,const float tile_units_to_pixels,const vec2 pos) {vec2 offset=mod(mod(mod(pixel_coord_upper,pattern_size)*256.0,pattern_size)*256.0+pixel_coord_lower,pattern_size);return (tile_units_to_pixels*pos+offset)/pattern_size;}\"),We=yr(\"uniform vec4 u_color;uniform float u_opacity;void main() {gl_FragColor=u_color*u_opacity;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"attribute vec2 a_pos;uniform mat4 u_matrix;void main() {gl_Position=u_matrix*vec4(a_pos,0,1);}\"),Xe=yr(\"uniform vec2 u_pattern_tl_a;uniform vec2 u_pattern_br_a;uniform vec2 u_pattern_tl_b;uniform vec2 u_pattern_br_b;uniform vec2 u_texsize;uniform float u_mix;uniform float u_opacity;uniform sampler2D u_image;varying vec2 v_pos_a;varying vec2 v_pos_b;void main() {vec2 imagecoord=mod(v_pos_a,1.0);vec2 pos=mix(u_pattern_tl_a/u_texsize,u_pattern_br_a/u_texsize,imagecoord);vec4 color1=texture2D(u_image,pos);vec2 imagecoord_b=mod(v_pos_b,1.0);vec2 pos2=mix(u_pattern_tl_b/u_texsize,u_pattern_br_b/u_texsize,imagecoord_b);vec4 color2=texture2D(u_image,pos2);gl_FragColor=mix(color1,color2,u_mix)*u_opacity;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform vec2 u_pattern_size_a;uniform vec2 u_pattern_size_b;uniform vec2 u_pixel_coord_upper;uniform vec2 u_pixel_coord_lower;uniform float u_scale_a;uniform float u_scale_b;uniform float u_tile_units_to_pixels;attribute vec2 a_pos;varying vec2 v_pos_a;varying vec2 v_pos_b;void main() {gl_Position=u_matrix*vec4(a_pos,0,1);v_pos_a=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,u_scale_a*u_pattern_size_a,u_tile_units_to_pixels,a_pos);v_pos_b=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,u_scale_b*u_pattern_size_b,u_tile_units_to_pixels,a_pos);}\"),Ze=yr(\"varying vec3 v_data;\\n#pragma mapbox: define highp vec4 color\\n#pragma mapbox: define mediump float radius\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define highp vec4 stroke_color\\n#pragma mapbox: define mediump float stroke_width\\n#pragma mapbox: define lowp float stroke_opacity\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 color\\n#pragma mapbox: initialize mediump float radius\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize highp vec4 stroke_color\\n#pragma mapbox: initialize mediump float stroke_width\\n#pragma mapbox: initialize lowp float stroke_opacity\\nvec2 extrude=v_data.xy;float extrude_length=length(extrude);lowp float antialiasblur=v_data.z;float antialiased_blur=-max(blur,antialiasblur);float opacity_t=smoothstep(0.0,antialiased_blur,extrude_length-1.0);float color_t=stroke_width < 0.01 ? 0.0 : smoothstep(antialiased_blur,0.0,extrude_length-radius/(radius+stroke_width));gl_FragColor=opacity_t*mix(color*opacity,stroke_color*stroke_opacity,color_t);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform bool u_scale_with_map;uniform bool u_pitch_with_map;uniform vec2 u_extrude_scale;uniform lowp float u_device_pixel_ratio;uniform highp float u_camera_to_center_distance;attribute vec2 a_pos;varying vec3 v_data;\\n#pragma mapbox: define highp vec4 color\\n#pragma mapbox: define mediump float radius\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define highp vec4 stroke_color\\n#pragma mapbox: define mediump float stroke_width\\n#pragma mapbox: define lowp float stroke_opacity\\nvoid main(void) {\\n#pragma mapbox: initialize highp vec4 color\\n#pragma mapbox: initialize mediump float radius\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize highp vec4 stroke_color\\n#pragma mapbox: initialize mediump float stroke_width\\n#pragma mapbox: initialize lowp float stroke_opacity\\nvec2 extrude=vec2(mod(a_pos,2.0)*2.0-1.0);vec2 circle_center=floor(a_pos*0.5);if (u_pitch_with_map) {vec2 corner_position=circle_center;if (u_scale_with_map) {corner_position+=extrude*(radius+stroke_width)*u_extrude_scale;} else {vec4 projected_center=u_matrix*vec4(circle_center,0,1);corner_position+=extrude*(radius+stroke_width)*u_extrude_scale*(projected_center.w/u_camera_to_center_distance);}gl_Position=u_matrix*vec4(corner_position,0,1);} else {gl_Position=u_matrix*vec4(circle_center,0,1);if (u_scale_with_map) {gl_Position.xy+=extrude*(radius+stroke_width)*u_extrude_scale*u_camera_to_center_distance;} else {gl_Position.xy+=extrude*(radius+stroke_width)*u_extrude_scale*gl_Position.w;}}lowp float antialiasblur=1.0/u_device_pixel_ratio/(radius+stroke_width);v_data=vec3(extrude.x,extrude.y,antialiasblur);}\"),Je=yr(\"void main() {gl_FragColor=vec4(1.0);}\",\"attribute vec2 a_pos;uniform mat4 u_matrix;void main() {gl_Position=u_matrix*vec4(a_pos,0,1);}\"),Ke=yr(\"uniform highp float u_intensity;varying vec2 v_extrude;\\n#pragma mapbox: define highp float weight\\n#define GAUSS_COEF 0.3989422804014327\\nvoid main() {\\n#pragma mapbox: initialize highp float weight\\nfloat d=-0.5*3.0*3.0*dot(v_extrude,v_extrude);float val=weight*u_intensity*GAUSS_COEF*exp(d);gl_FragColor=vec4(val,1.0,1.0,1.0);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform float u_extrude_scale;uniform float u_opacity;uniform float u_intensity;attribute vec2 a_pos;varying vec2 v_extrude;\\n#pragma mapbox: define highp float weight\\n#pragma mapbox: define mediump float radius\\nconst highp float ZERO=1.0/255.0/16.0;\\n#define GAUSS_COEF 0.3989422804014327\\nvoid main(void) {\\n#pragma mapbox: initialize highp float weight\\n#pragma mapbox: initialize mediump float radius\\nvec2 unscaled_extrude=vec2(mod(a_pos,2.0)*2.0-1.0);float S=sqrt(-2.0*log(ZERO/weight/u_intensity/GAUSS_COEF))/3.0;v_extrude=S*unscaled_extrude;vec2 extrude=v_extrude*radius*u_extrude_scale;vec4 pos=vec4(floor(a_pos*0.5)+extrude,0,1);gl_Position=u_matrix*pos;}\"),Qe=yr(\"uniform sampler2D u_image;uniform sampler2D u_color_ramp;uniform float u_opacity;varying vec2 v_pos;void main() {float t=texture2D(u_image,v_pos).r;vec4 color=texture2D(u_color_ramp,vec2(t,0.5));gl_FragColor=color*u_opacity;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(0.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform vec2 u_world;attribute vec2 a_pos;varying vec2 v_pos;void main() {gl_Position=u_matrix*vec4(a_pos*u_world,0,1);v_pos.x=a_pos.x;v_pos.y=1.0-a_pos.y;}\"),$e=yr(\"varying float v_placed;varying float v_notUsed;void main() {float alpha=0.5;gl_FragColor=vec4(1.0,0.0,0.0,1.0)*alpha;if (v_placed > 0.5) {gl_FragColor=vec4(0.0,0.0,1.0,0.5)*alpha;}if (v_notUsed > 0.5) {gl_FragColor*=.1;}}\",\"attribute vec2 a_pos;attribute vec2 a_anchor_pos;attribute vec2 a_extrude;attribute vec2 a_placed;attribute vec2 a_shift;uniform mat4 u_matrix;uniform vec2 u_extrude_scale;uniform float u_camera_to_center_distance;varying float v_placed;varying float v_notUsed;void main() {vec4 projectedPoint=u_matrix*vec4(a_anchor_pos,0,1);highp float camera_to_anchor_distance=projectedPoint.w;highp float collision_perspective_ratio=clamp(0.5+0.5*(u_camera_to_center_distance/camera_to_anchor_distance),0.0,4.0);gl_Position=u_matrix*vec4(a_pos,0.0,1.0);gl_Position.xy+=(a_extrude+a_shift)*u_extrude_scale*gl_Position.w*collision_perspective_ratio;v_placed=a_placed.x;v_notUsed=a_placed.y;}\"),tr=yr(\"varying float v_radius;varying vec2 v_extrude;varying float v_perspective_ratio;varying float v_collision;void main() {float alpha=0.5*min(v_perspective_ratio,1.0);float stroke_radius=0.9*max(v_perspective_ratio,1.0);float distance_to_center=length(v_extrude);float distance_to_edge=abs(distance_to_center-v_radius);float opacity_t=smoothstep(-stroke_radius,0.0,-distance_to_edge);vec4 color=mix(vec4(0.0,0.0,1.0,0.5),vec4(1.0,0.0,0.0,1.0),v_collision);gl_FragColor=color*alpha*opacity_t;}\",\"attribute vec2 a_pos;attribute float a_radius;attribute vec2 a_flags;uniform mat4 u_matrix;uniform mat4 u_inv_matrix;uniform vec2 u_viewport_size;uniform float u_camera_to_center_distance;varying float v_radius;varying vec2 v_extrude;varying float v_perspective_ratio;varying float v_collision;vec3 toTilePosition(vec2 screenPos) {vec4 rayStart=u_inv_matrix*vec4(screenPos,-1.0,1.0);vec4 rayEnd  =u_inv_matrix*vec4(screenPos, 1.0,1.0);rayStart.xyz/=rayStart.w;rayEnd.xyz  /=rayEnd.w;highp float t=(0.0-rayStart.z)/(rayEnd.z-rayStart.z);return mix(rayStart.xyz,rayEnd.xyz,t);}void main() {vec2 quadCenterPos=a_pos;float radius=a_radius;float collision=a_flags.x;float vertexIdx=a_flags.y;vec2 quadVertexOffset=vec2(mix(-1.0,1.0,float(vertexIdx >=2.0)),mix(-1.0,1.0,float(vertexIdx >=1.0 && vertexIdx <=2.0)));vec2 quadVertexExtent=quadVertexOffset*radius;vec3 tilePos=toTilePosition(quadCenterPos);vec4 clipPos=u_matrix*vec4(tilePos,1.0);highp float camera_to_anchor_distance=clipPos.w;highp float collision_perspective_ratio=clamp(0.5+0.5*(u_camera_to_center_distance/camera_to_anchor_distance),0.0,4.0);float padding_factor=1.2;v_radius=radius;v_extrude=quadVertexExtent*padding_factor;v_perspective_ratio=collision_perspective_ratio;v_collision=collision;gl_Position=vec4(clipPos.xyz/clipPos.w,1.0)+vec4(quadVertexExtent*padding_factor/u_viewport_size*2.0,0.0,0.0);}\"),er=yr(\"uniform highp vec4 u_color;uniform sampler2D u_overlay;varying vec2 v_uv;void main() {vec4 overlay_color=texture2D(u_overlay,v_uv);gl_FragColor=mix(u_color,overlay_color,overlay_color.a);}\",\"attribute vec2 a_pos;varying vec2 v_uv;uniform mat4 u_matrix;uniform float u_overlay_scale;void main() {v_uv=a_pos/8192.0;gl_Position=u_matrix*vec4(a_pos*u_overlay_scale,0,1);}\"),rr=yr(\"#pragma mapbox: define highp vec4 color\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 color\\n#pragma mapbox: initialize lowp float opacity\\ngl_FragColor=color*opacity;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"attribute vec2 a_pos;uniform mat4 u_matrix;\\n#pragma mapbox: define highp vec4 color\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 color\\n#pragma mapbox: initialize lowp float opacity\\ngl_Position=u_matrix*vec4(a_pos,0,1);}\"),nr=yr(\"varying vec2 v_pos;\\n#pragma mapbox: define highp vec4 outline_color\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 outline_color\\n#pragma mapbox: initialize lowp float opacity\\nfloat dist=length(v_pos-gl_FragCoord.xy);float alpha=1.0-smoothstep(0.0,1.0,dist);gl_FragColor=outline_color*(alpha*opacity);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"attribute vec2 a_pos;uniform mat4 u_matrix;uniform vec2 u_world;varying vec2 v_pos;\\n#pragma mapbox: define highp vec4 outline_color\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 outline_color\\n#pragma mapbox: initialize lowp float opacity\\ngl_Position=u_matrix*vec4(a_pos,0,1);v_pos=(gl_Position.xy/gl_Position.w+1.0)/2.0*u_world;}\"),ir=yr(\"uniform vec2 u_texsize;uniform sampler2D u_image;uniform float u_fade;varying vec2 v_pos_a;varying vec2 v_pos_b;varying vec2 v_pos;\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define lowp vec4 pattern_from\\n#pragma mapbox: define lowp vec4 pattern_to\\nvoid main() {\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize mediump vec4 pattern_from\\n#pragma mapbox: initialize mediump vec4 pattern_to\\nvec2 pattern_tl_a=pattern_from.xy;vec2 pattern_br_a=pattern_from.zw;vec2 pattern_tl_b=pattern_to.xy;vec2 pattern_br_b=pattern_to.zw;vec2 imagecoord=mod(v_pos_a,1.0);vec2 pos=mix(pattern_tl_a/u_texsize,pattern_br_a/u_texsize,imagecoord);vec4 color1=texture2D(u_image,pos);vec2 imagecoord_b=mod(v_pos_b,1.0);vec2 pos2=mix(pattern_tl_b/u_texsize,pattern_br_b/u_texsize,imagecoord_b);vec4 color2=texture2D(u_image,pos2);float dist=length(v_pos-gl_FragCoord.xy);float alpha=1.0-smoothstep(0.0,1.0,dist);gl_FragColor=mix(color1,color2,u_fade)*alpha*opacity;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform vec2 u_world;uniform vec2 u_pixel_coord_upper;uniform vec2 u_pixel_coord_lower;uniform vec3 u_scale;attribute vec2 a_pos;varying vec2 v_pos_a;varying vec2 v_pos_b;varying vec2 v_pos;\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define lowp vec4 pattern_from\\n#pragma mapbox: define lowp vec4 pattern_to\\n#pragma mapbox: define lowp float pixel_ratio_from\\n#pragma mapbox: define lowp float pixel_ratio_to\\nvoid main() {\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize mediump vec4 pattern_from\\n#pragma mapbox: initialize mediump vec4 pattern_to\\n#pragma mapbox: initialize lowp float pixel_ratio_from\\n#pragma mapbox: initialize lowp float pixel_ratio_to\\nvec2 pattern_tl_a=pattern_from.xy;vec2 pattern_br_a=pattern_from.zw;vec2 pattern_tl_b=pattern_to.xy;vec2 pattern_br_b=pattern_to.zw;float tileRatio=u_scale.x;float fromScale=u_scale.y;float toScale=u_scale.z;gl_Position=u_matrix*vec4(a_pos,0,1);vec2 display_size_a=(pattern_br_a-pattern_tl_a)/pixel_ratio_from;vec2 display_size_b=(pattern_br_b-pattern_tl_b)/pixel_ratio_to;v_pos_a=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,fromScale*display_size_a,tileRatio,a_pos);v_pos_b=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,toScale*display_size_b,tileRatio,a_pos);v_pos=(gl_Position.xy/gl_Position.w+1.0)/2.0*u_world;}\"),ar=yr(\"uniform vec2 u_texsize;uniform float u_fade;uniform sampler2D u_image;varying vec2 v_pos_a;varying vec2 v_pos_b;\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define lowp vec4 pattern_from\\n#pragma mapbox: define lowp vec4 pattern_to\\nvoid main() {\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize mediump vec4 pattern_from\\n#pragma mapbox: initialize mediump vec4 pattern_to\\nvec2 pattern_tl_a=pattern_from.xy;vec2 pattern_br_a=pattern_from.zw;vec2 pattern_tl_b=pattern_to.xy;vec2 pattern_br_b=pattern_to.zw;vec2 imagecoord=mod(v_pos_a,1.0);vec2 pos=mix(pattern_tl_a/u_texsize,pattern_br_a/u_texsize,imagecoord);vec4 color1=texture2D(u_image,pos);vec2 imagecoord_b=mod(v_pos_b,1.0);vec2 pos2=mix(pattern_tl_b/u_texsize,pattern_br_b/u_texsize,imagecoord_b);vec4 color2=texture2D(u_image,pos2);gl_FragColor=mix(color1,color2,u_fade)*opacity;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform vec2 u_pixel_coord_upper;uniform vec2 u_pixel_coord_lower;uniform vec3 u_scale;attribute vec2 a_pos;varying vec2 v_pos_a;varying vec2 v_pos_b;\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define lowp vec4 pattern_from\\n#pragma mapbox: define lowp vec4 pattern_to\\n#pragma mapbox: define lowp float pixel_ratio_from\\n#pragma mapbox: define lowp float pixel_ratio_to\\nvoid main() {\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize mediump vec4 pattern_from\\n#pragma mapbox: initialize mediump vec4 pattern_to\\n#pragma mapbox: initialize lowp float pixel_ratio_from\\n#pragma mapbox: initialize lowp float pixel_ratio_to\\nvec2 pattern_tl_a=pattern_from.xy;vec2 pattern_br_a=pattern_from.zw;vec2 pattern_tl_b=pattern_to.xy;vec2 pattern_br_b=pattern_to.zw;float tileZoomRatio=u_scale.x;float fromScale=u_scale.y;float toScale=u_scale.z;vec2 display_size_a=(pattern_br_a-pattern_tl_a)/pixel_ratio_from;vec2 display_size_b=(pattern_br_b-pattern_tl_b)/pixel_ratio_to;gl_Position=u_matrix*vec4(a_pos,0,1);v_pos_a=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,fromScale*display_size_a,tileZoomRatio,a_pos);v_pos_b=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,toScale*display_size_b,tileZoomRatio,a_pos);}\"),or=yr(\"varying vec4 v_color;void main() {gl_FragColor=v_color;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform vec3 u_lightcolor;uniform lowp vec3 u_lightpos;uniform lowp float u_lightintensity;uniform float u_vertical_gradient;uniform lowp float u_opacity;attribute vec2 a_pos;attribute vec4 a_normal_ed;varying vec4 v_color;\\n#pragma mapbox: define highp float base\\n#pragma mapbox: define highp float height\\n#pragma mapbox: define highp vec4 color\\nvoid main() {\\n#pragma mapbox: initialize highp float base\\n#pragma mapbox: initialize highp float height\\n#pragma mapbox: initialize highp vec4 color\\nvec3 normal=a_normal_ed.xyz;base=max(0.0,base);height=max(0.0,height);float t=mod(normal.x,2.0);gl_Position=u_matrix*vec4(a_pos,t > 0.0 ? height : base,1);float colorvalue=color.r*0.2126+color.g*0.7152+color.b*0.0722;v_color=vec4(0.0,0.0,0.0,1.0);vec4 ambientlight=vec4(0.03,0.03,0.03,1.0);color+=ambientlight;float directional=clamp(dot(normal/16384.0,u_lightpos),0.0,1.0);directional=mix((1.0-u_lightintensity),max((1.0-colorvalue+u_lightintensity),1.0),directional);if (normal.y !=0.0) {directional*=((1.0-u_vertical_gradient)+(u_vertical_gradient*clamp((t+base)*pow(height/150.0,0.5),mix(0.7,0.98,1.0-u_lightintensity),1.0)));}v_color.r+=clamp(color.r*directional*u_lightcolor.r,mix(0.0,0.3,1.0-u_lightcolor.r),1.0);v_color.g+=clamp(color.g*directional*u_lightcolor.g,mix(0.0,0.3,1.0-u_lightcolor.g),1.0);v_color.b+=clamp(color.b*directional*u_lightcolor.b,mix(0.0,0.3,1.0-u_lightcolor.b),1.0);v_color*=u_opacity;}\"),sr=yr(\"uniform vec2 u_texsize;uniform float u_fade;uniform sampler2D u_image;varying vec2 v_pos_a;varying vec2 v_pos_b;varying vec4 v_lighting;\\n#pragma mapbox: define lowp float base\\n#pragma mapbox: define lowp float height\\n#pragma mapbox: define lowp vec4 pattern_from\\n#pragma mapbox: define lowp vec4 pattern_to\\n#pragma mapbox: define lowp float pixel_ratio_from\\n#pragma mapbox: define lowp float pixel_ratio_to\\nvoid main() {\\n#pragma mapbox: initialize lowp float base\\n#pragma mapbox: initialize lowp float height\\n#pragma mapbox: initialize mediump vec4 pattern_from\\n#pragma mapbox: initialize mediump vec4 pattern_to\\n#pragma mapbox: initialize lowp float pixel_ratio_from\\n#pragma mapbox: initialize lowp float pixel_ratio_to\\nvec2 pattern_tl_a=pattern_from.xy;vec2 pattern_br_a=pattern_from.zw;vec2 pattern_tl_b=pattern_to.xy;vec2 pattern_br_b=pattern_to.zw;vec2 imagecoord=mod(v_pos_a,1.0);vec2 pos=mix(pattern_tl_a/u_texsize,pattern_br_a/u_texsize,imagecoord);vec4 color1=texture2D(u_image,pos);vec2 imagecoord_b=mod(v_pos_b,1.0);vec2 pos2=mix(pattern_tl_b/u_texsize,pattern_br_b/u_texsize,imagecoord_b);vec4 color2=texture2D(u_image,pos2);vec4 mixedColor=mix(color1,color2,u_fade);gl_FragColor=mixedColor*v_lighting;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform vec2 u_pixel_coord_upper;uniform vec2 u_pixel_coord_lower;uniform float u_height_factor;uniform vec3 u_scale;uniform float u_vertical_gradient;uniform lowp float u_opacity;uniform vec3 u_lightcolor;uniform lowp vec3 u_lightpos;uniform lowp float u_lightintensity;attribute vec2 a_pos;attribute vec4 a_normal_ed;varying vec2 v_pos_a;varying vec2 v_pos_b;varying vec4 v_lighting;\\n#pragma mapbox: define lowp float base\\n#pragma mapbox: define lowp float height\\n#pragma mapbox: define lowp vec4 pattern_from\\n#pragma mapbox: define lowp vec4 pattern_to\\n#pragma mapbox: define lowp float pixel_ratio_from\\n#pragma mapbox: define lowp float pixel_ratio_to\\nvoid main() {\\n#pragma mapbox: initialize lowp float base\\n#pragma mapbox: initialize lowp float height\\n#pragma mapbox: initialize mediump vec4 pattern_from\\n#pragma mapbox: initialize mediump vec4 pattern_to\\n#pragma mapbox: initialize lowp float pixel_ratio_from\\n#pragma mapbox: initialize lowp float pixel_ratio_to\\nvec2 pattern_tl_a=pattern_from.xy;vec2 pattern_br_a=pattern_from.zw;vec2 pattern_tl_b=pattern_to.xy;vec2 pattern_br_b=pattern_to.zw;float tileRatio=u_scale.x;float fromScale=u_scale.y;float toScale=u_scale.z;vec3 normal=a_normal_ed.xyz;float edgedistance=a_normal_ed.w;vec2 display_size_a=(pattern_br_a-pattern_tl_a)/pixel_ratio_from;vec2 display_size_b=(pattern_br_b-pattern_tl_b)/pixel_ratio_to;base=max(0.0,base);height=max(0.0,height);float t=mod(normal.x,2.0);float z=t > 0.0 ? height : base;gl_Position=u_matrix*vec4(a_pos,z,1);vec2 pos=normal.x==1.0 && normal.y==0.0 && normal.z==16384.0\\n? a_pos\\n: vec2(edgedistance,z*u_height_factor);v_pos_a=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,fromScale*display_size_a,tileRatio,pos);v_pos_b=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,toScale*display_size_b,tileRatio,pos);v_lighting=vec4(0.0,0.0,0.0,1.0);float directional=clamp(dot(normal/16383.0,u_lightpos),0.0,1.0);directional=mix((1.0-u_lightintensity),max((0.5+u_lightintensity),1.0),directional);if (normal.y !=0.0) {directional*=((1.0-u_vertical_gradient)+(u_vertical_gradient*clamp((t+base)*pow(height/150.0,0.5),mix(0.7,0.98,1.0-u_lightintensity),1.0)));}v_lighting.rgb+=clamp(directional*u_lightcolor,mix(vec3(0.0),vec3(0.3),1.0-u_lightcolor),vec3(1.0));v_lighting*=u_opacity;}\"),lr=yr(\"#ifdef GL_ES\\nprecision highp float;\\n#endif\\nuniform sampler2D u_image;varying vec2 v_pos;uniform vec2 u_dimension;uniform float u_zoom;uniform float u_maxzoom;uniform vec4 u_unpack;float getElevation(vec2 coord,float bias) {vec4 data=texture2D(u_image,coord)*255.0;data.a=-1.0;return dot(data,u_unpack)/4.0;}void main() {vec2 epsilon=1.0/u_dimension;float a=getElevation(v_pos+vec2(-epsilon.x,-epsilon.y),0.0);float b=getElevation(v_pos+vec2(0,-epsilon.y),0.0);float c=getElevation(v_pos+vec2(epsilon.x,-epsilon.y),0.0);float d=getElevation(v_pos+vec2(-epsilon.x,0),0.0);float e=getElevation(v_pos,0.0);float f=getElevation(v_pos+vec2(epsilon.x,0),0.0);float g=getElevation(v_pos+vec2(-epsilon.x,epsilon.y),0.0);float h=getElevation(v_pos+vec2(0,epsilon.y),0.0);float i=getElevation(v_pos+vec2(epsilon.x,epsilon.y),0.0);float exaggeration=u_zoom < 2.0 ? 0.4 : u_zoom < 4.5 ? 0.35 : 0.3;vec2 deriv=vec2((c+f+f+i)-(a+d+d+g),(g+h+h+i)-(a+b+b+c))/ pow(2.0,(u_zoom-u_maxzoom)*exaggeration+19.2562-u_zoom);gl_FragColor=clamp(vec4(deriv.x/2.0+0.5,deriv.y/2.0+0.5,1.0,1.0),0.0,1.0);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform vec2 u_dimension;attribute vec2 a_pos;attribute vec2 a_texture_pos;varying vec2 v_pos;void main() {gl_Position=u_matrix*vec4(a_pos,0,1);highp vec2 epsilon=1.0/u_dimension;float scale=(u_dimension.x-2.0)/u_dimension.x;v_pos=(a_texture_pos/8192.0)*scale+epsilon;}\"),cr=yr(\"uniform sampler2D u_image;varying vec2 v_pos;uniform vec2 u_latrange;uniform vec2 u_light;uniform vec4 u_shadow;uniform vec4 u_highlight;uniform vec4 u_accent;\\n#define PI 3.141592653589793\\nvoid main() {vec4 pixel=texture2D(u_image,v_pos);vec2 deriv=((pixel.rg*2.0)-1.0);float scaleFactor=cos(radians((u_latrange[0]-u_latrange[1])*(1.0-v_pos.y)+u_latrange[1]));float slope=atan(1.25*length(deriv)/scaleFactor);float aspect=deriv.x !=0.0 ? atan(deriv.y,-deriv.x) : PI/2.0*(deriv.y > 0.0 ? 1.0 :-1.0);float intensity=u_light.x;float azimuth=u_light.y+PI;float base=1.875-intensity*1.75;float maxValue=0.5*PI;float scaledSlope=intensity !=0.5 ? ((pow(base,slope)-1.0)/(pow(base,maxValue)-1.0))*maxValue : slope;float accent=cos(scaledSlope);vec4 accent_color=(1.0-accent)*u_accent*clamp(intensity*2.0,0.0,1.0);float shade=abs(mod((aspect+azimuth)/PI+0.5,2.0)-1.0);vec4 shade_color=mix(u_shadow,u_highlight,shade)*sin(scaledSlope)*clamp(intensity*2.0,0.0,1.0);gl_FragColor=accent_color*(1.0-shade_color.a)+shade_color;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;attribute vec2 a_pos;attribute vec2 a_texture_pos;varying vec2 v_pos;void main() {gl_Position=u_matrix*vec4(a_pos,0,1);v_pos=a_texture_pos/8192.0;}\"),ur=yr(\"uniform lowp float u_device_pixel_ratio;varying vec2 v_width2;varying vec2 v_normal;varying float v_gamma_scale;\\n#pragma mapbox: define highp vec4 color\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 color\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\nfloat dist=length(v_normal)*v_width2.s;float blur2=(blur+1.0/u_device_pixel_ratio)*v_gamma_scale;float alpha=clamp(min(dist-(v_width2.t-blur2),v_width2.s-dist)/blur2,0.0,1.0);gl_FragColor=color*(alpha*opacity);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"\\n#define scale 0.015873016\\nattribute vec2 a_pos_normal;attribute vec4 a_data;uniform mat4 u_matrix;uniform mediump float u_ratio;uniform vec2 u_units_to_pixels;uniform lowp float u_device_pixel_ratio;varying vec2 v_normal;varying vec2 v_width2;varying float v_gamma_scale;varying highp float v_linesofar;\\n#pragma mapbox: define highp vec4 color\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define mediump float gapwidth\\n#pragma mapbox: define lowp float offset\\n#pragma mapbox: define mediump float width\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 color\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize mediump float gapwidth\\n#pragma mapbox: initialize lowp float offset\\n#pragma mapbox: initialize mediump float width\\nfloat ANTIALIASING=1.0/u_device_pixel_ratio/2.0;vec2 a_extrude=a_data.xy-128.0;float a_direction=mod(a_data.z,4.0)-1.0;v_linesofar=(floor(a_data.z/4.0)+a_data.w*64.0)*2.0;vec2 pos=floor(a_pos_normal*0.5);mediump vec2 normal=a_pos_normal-2.0*pos;normal.y=normal.y*2.0-1.0;v_normal=normal;gapwidth=gapwidth/2.0;float halfwidth=width/2.0;offset=-1.0*offset;float inset=gapwidth+(gapwidth > 0.0 ? ANTIALIASING : 0.0);float outset=gapwidth+halfwidth*(gapwidth > 0.0 ? 2.0 : 1.0)+(halfwidth==0.0 ? 0.0 : ANTIALIASING);mediump vec2 dist=outset*a_extrude*scale;mediump float u=0.5*a_direction;mediump float t=1.0-abs(u);mediump vec2 offset2=offset*a_extrude*scale*normal.y*mat2(t,-u,u,t);vec4 projected_extrude=u_matrix*vec4(dist/u_ratio,0.0,0.0);gl_Position=u_matrix*vec4(pos+offset2/u_ratio,0.0,1.0)+projected_extrude;float extrude_length_without_perspective=length(dist);float extrude_length_with_perspective=length(projected_extrude.xy/gl_Position.w*u_units_to_pixels);v_gamma_scale=extrude_length_without_perspective/extrude_length_with_perspective;v_width2=vec2(outset,inset);}\"),fr=yr(\"uniform lowp float u_device_pixel_ratio;uniform sampler2D u_image;varying vec2 v_width2;varying vec2 v_normal;varying float v_gamma_scale;varying highp float v_lineprogress;\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\nfloat dist=length(v_normal)*v_width2.s;float blur2=(blur+1.0/u_device_pixel_ratio)*v_gamma_scale;float alpha=clamp(min(dist-(v_width2.t-blur2),v_width2.s-dist)/blur2,0.0,1.0);vec4 color=texture2D(u_image,vec2(v_lineprogress,0.5));gl_FragColor=color*(alpha*opacity);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"\\n#define MAX_LINE_DISTANCE 32767.0\\n#define scale 0.015873016\\nattribute vec2 a_pos_normal;attribute vec4 a_data;uniform mat4 u_matrix;uniform mediump float u_ratio;uniform lowp float u_device_pixel_ratio;uniform vec2 u_units_to_pixels;varying vec2 v_normal;varying vec2 v_width2;varying float v_gamma_scale;varying highp float v_lineprogress;\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define mediump float gapwidth\\n#pragma mapbox: define lowp float offset\\n#pragma mapbox: define mediump float width\\nvoid main() {\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize mediump float gapwidth\\n#pragma mapbox: initialize lowp float offset\\n#pragma mapbox: initialize mediump float width\\nfloat ANTIALIASING=1.0/u_device_pixel_ratio/2.0;vec2 a_extrude=a_data.xy-128.0;float a_direction=mod(a_data.z,4.0)-1.0;v_lineprogress=(floor(a_data.z/4.0)+a_data.w*64.0)*2.0/MAX_LINE_DISTANCE;vec2 pos=floor(a_pos_normal*0.5);mediump vec2 normal=a_pos_normal-2.0*pos;normal.y=normal.y*2.0-1.0;v_normal=normal;gapwidth=gapwidth/2.0;float halfwidth=width/2.0;offset=-1.0*offset;float inset=gapwidth+(gapwidth > 0.0 ? ANTIALIASING : 0.0);float outset=gapwidth+halfwidth*(gapwidth > 0.0 ? 2.0 : 1.0)+(halfwidth==0.0 ? 0.0 : ANTIALIASING);mediump vec2 dist=outset*a_extrude*scale;mediump float u=0.5*a_direction;mediump float t=1.0-abs(u);mediump vec2 offset2=offset*a_extrude*scale*normal.y*mat2(t,-u,u,t);vec4 projected_extrude=u_matrix*vec4(dist/u_ratio,0.0,0.0);gl_Position=u_matrix*vec4(pos+offset2/u_ratio,0.0,1.0)+projected_extrude;float extrude_length_without_perspective=length(dist);float extrude_length_with_perspective=length(projected_extrude.xy/gl_Position.w*u_units_to_pixels);v_gamma_scale=extrude_length_without_perspective/extrude_length_with_perspective;v_width2=vec2(outset,inset);}\"),hr=yr(\"uniform lowp float u_device_pixel_ratio;uniform vec2 u_texsize;uniform float u_fade;uniform mediump vec3 u_scale;uniform sampler2D u_image;varying vec2 v_normal;varying vec2 v_width2;varying float v_linesofar;varying float v_gamma_scale;varying float v_width;\\n#pragma mapbox: define lowp vec4 pattern_from\\n#pragma mapbox: define lowp vec4 pattern_to\\n#pragma mapbox: define lowp float pixel_ratio_from\\n#pragma mapbox: define lowp float pixel_ratio_to\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize mediump vec4 pattern_from\\n#pragma mapbox: initialize mediump vec4 pattern_to\\n#pragma mapbox: initialize lowp float pixel_ratio_from\\n#pragma mapbox: initialize lowp float pixel_ratio_to\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\nvec2 pattern_tl_a=pattern_from.xy;vec2 pattern_br_a=pattern_from.zw;vec2 pattern_tl_b=pattern_to.xy;vec2 pattern_br_b=pattern_to.zw;float tileZoomRatio=u_scale.x;float fromScale=u_scale.y;float toScale=u_scale.z;vec2 display_size_a=(pattern_br_a-pattern_tl_a)/pixel_ratio_from;vec2 display_size_b=(pattern_br_b-pattern_tl_b)/pixel_ratio_to;vec2 pattern_size_a=vec2(display_size_a.x*fromScale/tileZoomRatio,display_size_a.y);vec2 pattern_size_b=vec2(display_size_b.x*toScale/tileZoomRatio,display_size_b.y);float aspect_a=display_size_a.y/v_width;float aspect_b=display_size_b.y/v_width;float dist=length(v_normal)*v_width2.s;float blur2=(blur+1.0/u_device_pixel_ratio)*v_gamma_scale;float alpha=clamp(min(dist-(v_width2.t-blur2),v_width2.s-dist)/blur2,0.0,1.0);float x_a=mod(v_linesofar/pattern_size_a.x*aspect_a,1.0);float x_b=mod(v_linesofar/pattern_size_b.x*aspect_b,1.0);float y=0.5*v_normal.y+0.5;vec2 texel_size=1.0/u_texsize;vec2 pos_a=mix(pattern_tl_a*texel_size-texel_size,pattern_br_a*texel_size+texel_size,vec2(x_a,y));vec2 pos_b=mix(pattern_tl_b*texel_size-texel_size,pattern_br_b*texel_size+texel_size,vec2(x_b,y));vec4 color=mix(texture2D(u_image,pos_a),texture2D(u_image,pos_b),u_fade);gl_FragColor=color*alpha*opacity;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"\\n#define scale 0.015873016\\n#define LINE_DISTANCE_SCALE 2.0\\nattribute vec2 a_pos_normal;attribute vec4 a_data;uniform mat4 u_matrix;uniform vec2 u_units_to_pixels;uniform mediump float u_ratio;uniform lowp float u_device_pixel_ratio;varying vec2 v_normal;varying vec2 v_width2;varying float v_linesofar;varying float v_gamma_scale;varying float v_width;\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define lowp float offset\\n#pragma mapbox: define mediump float gapwidth\\n#pragma mapbox: define mediump float width\\n#pragma mapbox: define lowp float floorwidth\\n#pragma mapbox: define lowp vec4 pattern_from\\n#pragma mapbox: define lowp vec4 pattern_to\\n#pragma mapbox: define lowp float pixel_ratio_from\\n#pragma mapbox: define lowp float pixel_ratio_to\\nvoid main() {\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize lowp float offset\\n#pragma mapbox: initialize mediump float gapwidth\\n#pragma mapbox: initialize mediump float width\\n#pragma mapbox: initialize lowp float floorwidth\\n#pragma mapbox: initialize mediump vec4 pattern_from\\n#pragma mapbox: initialize mediump vec4 pattern_to\\n#pragma mapbox: initialize lowp float pixel_ratio_from\\n#pragma mapbox: initialize lowp float pixel_ratio_to\\nfloat ANTIALIASING=1.0/u_device_pixel_ratio/2.0;vec2 a_extrude=a_data.xy-128.0;float a_direction=mod(a_data.z,4.0)-1.0;float a_linesofar=(floor(a_data.z/4.0)+a_data.w*64.0)*LINE_DISTANCE_SCALE;vec2 pos=floor(a_pos_normal*0.5);mediump vec2 normal=a_pos_normal-2.0*pos;normal.y=normal.y*2.0-1.0;v_normal=normal;gapwidth=gapwidth/2.0;float halfwidth=width/2.0;offset=-1.0*offset;float inset=gapwidth+(gapwidth > 0.0 ? ANTIALIASING : 0.0);float outset=gapwidth+halfwidth*(gapwidth > 0.0 ? 2.0 : 1.0)+(halfwidth==0.0 ? 0.0 : ANTIALIASING);mediump vec2 dist=outset*a_extrude*scale;mediump float u=0.5*a_direction;mediump float t=1.0-abs(u);mediump vec2 offset2=offset*a_extrude*scale*normal.y*mat2(t,-u,u,t);vec4 projected_extrude=u_matrix*vec4(dist/u_ratio,0.0,0.0);gl_Position=u_matrix*vec4(pos+offset2/u_ratio,0.0,1.0)+projected_extrude;float extrude_length_without_perspective=length(dist);float extrude_length_with_perspective=length(projected_extrude.xy/gl_Position.w*u_units_to_pixels);v_gamma_scale=extrude_length_without_perspective/extrude_length_with_perspective;v_linesofar=a_linesofar;v_width2=vec2(outset,inset);v_width=floorwidth;}\"),pr=yr(\"uniform lowp float u_device_pixel_ratio;uniform sampler2D u_image;uniform float u_sdfgamma;uniform float u_mix;varying vec2 v_normal;varying vec2 v_width2;varying vec2 v_tex_a;varying vec2 v_tex_b;varying float v_gamma_scale;\\n#pragma mapbox: define highp vec4 color\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define mediump float width\\n#pragma mapbox: define lowp float floorwidth\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 color\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize mediump float width\\n#pragma mapbox: initialize lowp float floorwidth\\nfloat dist=length(v_normal)*v_width2.s;float blur2=(blur+1.0/u_device_pixel_ratio)*v_gamma_scale;float alpha=clamp(min(dist-(v_width2.t-blur2),v_width2.s-dist)/blur2,0.0,1.0);float sdfdist_a=texture2D(u_image,v_tex_a).a;float sdfdist_b=texture2D(u_image,v_tex_b).a;float sdfdist=mix(sdfdist_a,sdfdist_b,u_mix);alpha*=smoothstep(0.5-u_sdfgamma/floorwidth,0.5+u_sdfgamma/floorwidth,sdfdist);gl_FragColor=color*(alpha*opacity);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"\\n#define scale 0.015873016\\n#define LINE_DISTANCE_SCALE 2.0\\nattribute vec2 a_pos_normal;attribute vec4 a_data;uniform mat4 u_matrix;uniform mediump float u_ratio;uniform lowp float u_device_pixel_ratio;uniform vec2 u_patternscale_a;uniform float u_tex_y_a;uniform vec2 u_patternscale_b;uniform float u_tex_y_b;uniform vec2 u_units_to_pixels;varying vec2 v_normal;varying vec2 v_width2;varying vec2 v_tex_a;varying vec2 v_tex_b;varying float v_gamma_scale;\\n#pragma mapbox: define highp vec4 color\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define mediump float gapwidth\\n#pragma mapbox: define lowp float offset\\n#pragma mapbox: define mediump float width\\n#pragma mapbox: define lowp float floorwidth\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 color\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize mediump float gapwidth\\n#pragma mapbox: initialize lowp float offset\\n#pragma mapbox: initialize mediump float width\\n#pragma mapbox: initialize lowp float floorwidth\\nfloat ANTIALIASING=1.0/u_device_pixel_ratio/2.0;vec2 a_extrude=a_data.xy-128.0;float a_direction=mod(a_data.z,4.0)-1.0;float a_linesofar=(floor(a_data.z/4.0)+a_data.w*64.0)*LINE_DISTANCE_SCALE;vec2 pos=floor(a_pos_normal*0.5);mediump vec2 normal=a_pos_normal-2.0*pos;normal.y=normal.y*2.0-1.0;v_normal=normal;gapwidth=gapwidth/2.0;float halfwidth=width/2.0;offset=-1.0*offset;float inset=gapwidth+(gapwidth > 0.0 ? ANTIALIASING : 0.0);float outset=gapwidth+halfwidth*(gapwidth > 0.0 ? 2.0 : 1.0)+(halfwidth==0.0 ? 0.0 : ANTIALIASING);mediump vec2 dist=outset*a_extrude*scale;mediump float u=0.5*a_direction;mediump float t=1.0-abs(u);mediump vec2 offset2=offset*a_extrude*scale*normal.y*mat2(t,-u,u,t);vec4 projected_extrude=u_matrix*vec4(dist/u_ratio,0.0,0.0);gl_Position=u_matrix*vec4(pos+offset2/u_ratio,0.0,1.0)+projected_extrude;float extrude_length_without_perspective=length(dist);float extrude_length_with_perspective=length(projected_extrude.xy/gl_Position.w*u_units_to_pixels);v_gamma_scale=extrude_length_without_perspective/extrude_length_with_perspective;v_tex_a=vec2(a_linesofar*u_patternscale_a.x/floorwidth,normal.y*u_patternscale_a.y+u_tex_y_a);v_tex_b=vec2(a_linesofar*u_patternscale_b.x/floorwidth,normal.y*u_patternscale_b.y+u_tex_y_b);v_width2=vec2(outset,inset);}\"),dr=yr(\"uniform float u_fade_t;uniform float u_opacity;uniform sampler2D u_image0;uniform sampler2D u_image1;varying vec2 v_pos0;varying vec2 v_pos1;uniform float u_brightness_low;uniform float u_brightness_high;uniform float u_saturation_factor;uniform float u_contrast_factor;uniform vec3 u_spin_weights;void main() {vec4 color0=texture2D(u_image0,v_pos0);vec4 color1=texture2D(u_image1,v_pos1);if (color0.a > 0.0) {color0.rgb=color0.rgb/color0.a;}if (color1.a > 0.0) {color1.rgb=color1.rgb/color1.a;}vec4 color=mix(color0,color1,u_fade_t);color.a*=u_opacity;vec3 rgb=color.rgb;rgb=vec3(dot(rgb,u_spin_weights.xyz),dot(rgb,u_spin_weights.zxy),dot(rgb,u_spin_weights.yzx));float average=(color.r+color.g+color.b)/3.0;rgb+=(average-rgb)*u_saturation_factor;rgb=(rgb-0.5)*u_contrast_factor+0.5;vec3 u_high_vec=vec3(u_brightness_low,u_brightness_low,u_brightness_low);vec3 u_low_vec=vec3(u_brightness_high,u_brightness_high,u_brightness_high);gl_FragColor=vec4(mix(u_high_vec,u_low_vec,rgb)*color.a,color.a);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform vec2 u_tl_parent;uniform float u_scale_parent;uniform float u_buffer_scale;attribute vec2 a_pos;attribute vec2 a_texture_pos;varying vec2 v_pos0;varying vec2 v_pos1;void main() {gl_Position=u_matrix*vec4(a_pos,0,1);v_pos0=(((a_texture_pos/8192.0)-0.5)/u_buffer_scale )+0.5;v_pos1=(v_pos0*u_scale_parent)+u_tl_parent;}\"),mr=yr(\"uniform sampler2D u_texture;varying vec2 v_tex;varying float v_fade_opacity;\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize lowp float opacity\\nlowp float alpha=opacity*v_fade_opacity;gl_FragColor=texture2D(u_texture,v_tex)*alpha;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"const float PI=3.141592653589793;attribute vec4 a_pos_offset;attribute vec4 a_data;attribute vec4 a_pixeloffset;attribute vec3 a_projected_pos;attribute float a_fade_opacity;uniform bool u_is_size_zoom_constant;uniform bool u_is_size_feature_constant;uniform highp float u_size_t;uniform highp float u_size;uniform highp float u_camera_to_center_distance;uniform highp float u_pitch;uniform bool u_rotate_symbol;uniform highp float u_aspect_ratio;uniform float u_fade_change;uniform mat4 u_matrix;uniform mat4 u_label_plane_matrix;uniform mat4 u_coord_matrix;uniform bool u_is_text;uniform bool u_pitch_with_map;uniform vec2 u_texsize;varying vec2 v_tex;varying float v_fade_opacity;\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize lowp float opacity\\nvec2 a_pos=a_pos_offset.xy;vec2 a_offset=a_pos_offset.zw;vec2 a_tex=a_data.xy;vec2 a_size=a_data.zw;float a_size_min=floor(a_size[0]*0.5);vec2 a_pxoffset=a_pixeloffset.xy;vec2 a_minFontScale=a_pixeloffset.zw/256.0;highp float segment_angle=-a_projected_pos[2];float size;if (!u_is_size_zoom_constant && !u_is_size_feature_constant) {size=mix(a_size_min,a_size[1],u_size_t)/128.0;} else if (u_is_size_zoom_constant && !u_is_size_feature_constant) {size=a_size_min/128.0;} else {size=u_size;}vec4 projectedPoint=u_matrix*vec4(a_pos,0,1);highp float camera_to_anchor_distance=projectedPoint.w;highp float distance_ratio=u_pitch_with_map ?\\ncamera_to_anchor_distance/u_camera_to_center_distance :\\nu_camera_to_center_distance/camera_to_anchor_distance;highp float perspective_ratio=clamp(0.5+0.5*distance_ratio,0.0,4.0);size*=perspective_ratio;float fontScale=u_is_text ? size/24.0 : size;highp float symbol_rotation=0.0;if (u_rotate_symbol) {vec4 offsetProjectedPoint=u_matrix*vec4(a_pos+vec2(1,0),0,1);vec2 a=projectedPoint.xy/projectedPoint.w;vec2 b=offsetProjectedPoint.xy/offsetProjectedPoint.w;symbol_rotation=atan((b.y-a.y)/u_aspect_ratio,b.x-a.x);}highp float angle_sin=sin(segment_angle+symbol_rotation);highp float angle_cos=cos(segment_angle+symbol_rotation);mat2 rotation_matrix=mat2(angle_cos,-1.0*angle_sin,angle_sin,angle_cos);vec4 projected_pos=u_label_plane_matrix*vec4(a_projected_pos.xy,0.0,1.0);gl_Position=u_coord_matrix*vec4(projected_pos.xy/projected_pos.w+rotation_matrix*(a_offset/32.0*max(a_minFontScale,fontScale)+a_pxoffset/16.0),0.0,1.0);v_tex=a_tex/u_texsize;vec2 fade_opacity=unpack_opacity(a_fade_opacity);float fade_change=fade_opacity[1] > 0.5 ? u_fade_change :-u_fade_change;v_fade_opacity=max(0.0,min(1.0,fade_opacity[0]+fade_change));}\"),gr=yr(\"#define SDF_PX 8.0\\nuniform bool u_is_halo;uniform sampler2D u_texture;uniform highp float u_gamma_scale;uniform lowp float u_device_pixel_ratio;uniform bool u_is_text;varying vec2 v_data0;varying vec3 v_data1;\\n#pragma mapbox: define highp vec4 fill_color\\n#pragma mapbox: define highp vec4 halo_color\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define lowp float halo_width\\n#pragma mapbox: define lowp float halo_blur\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 fill_color\\n#pragma mapbox: initialize highp vec4 halo_color\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize lowp float halo_width\\n#pragma mapbox: initialize lowp float halo_blur\\nfloat EDGE_GAMMA=0.105/u_device_pixel_ratio;vec2 tex=v_data0.xy;float gamma_scale=v_data1.x;float size=v_data1.y;float fade_opacity=v_data1[2];float fontScale=u_is_text ? size/24.0 : size;lowp vec4 color=fill_color;highp float gamma=EDGE_GAMMA/(fontScale*u_gamma_scale);lowp float buff=(256.0-64.0)/256.0;if (u_is_halo) {color=halo_color;gamma=(halo_blur*1.19/SDF_PX+EDGE_GAMMA)/(fontScale*u_gamma_scale);buff=(6.0-halo_width/fontScale)/SDF_PX;}lowp float dist=texture2D(u_texture,tex).a;highp float gamma_scaled=gamma*gamma_scale;highp float alpha=smoothstep(buff-gamma_scaled,buff+gamma_scaled,dist);gl_FragColor=color*(alpha*opacity*fade_opacity);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"const float PI=3.141592653589793;attribute vec4 a_pos_offset;attribute vec4 a_data;attribute vec4 a_pixeloffset;attribute vec3 a_projected_pos;attribute float a_fade_opacity;uniform bool u_is_size_zoom_constant;uniform bool u_is_size_feature_constant;uniform highp float u_size_t;uniform highp float u_size;uniform mat4 u_matrix;uniform mat4 u_label_plane_matrix;uniform mat4 u_coord_matrix;uniform bool u_is_text;uniform bool u_pitch_with_map;uniform highp float u_pitch;uniform bool u_rotate_symbol;uniform highp float u_aspect_ratio;uniform highp float u_camera_to_center_distance;uniform float u_fade_change;uniform vec2 u_texsize;varying vec2 v_data0;varying vec3 v_data1;\\n#pragma mapbox: define highp vec4 fill_color\\n#pragma mapbox: define highp vec4 halo_color\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define lowp float halo_width\\n#pragma mapbox: define lowp float halo_blur\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 fill_color\\n#pragma mapbox: initialize highp vec4 halo_color\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize lowp float halo_width\\n#pragma mapbox: initialize lowp float halo_blur\\nvec2 a_pos=a_pos_offset.xy;vec2 a_offset=a_pos_offset.zw;vec2 a_tex=a_data.xy;vec2 a_size=a_data.zw;float a_size_min=floor(a_size[0]*0.5);vec2 a_pxoffset=a_pixeloffset.xy;highp float segment_angle=-a_projected_pos[2];float size;if (!u_is_size_zoom_constant && !u_is_size_feature_constant) {size=mix(a_size_min,a_size[1],u_size_t)/128.0;} else if (u_is_size_zoom_constant && !u_is_size_feature_constant) {size=a_size_min/128.0;} else {size=u_size;}vec4 projectedPoint=u_matrix*vec4(a_pos,0,1);highp float camera_to_anchor_distance=projectedPoint.w;highp float distance_ratio=u_pitch_with_map ?\\ncamera_to_anchor_distance/u_camera_to_center_distance :\\nu_camera_to_center_distance/camera_to_anchor_distance;highp float perspective_ratio=clamp(0.5+0.5*distance_ratio,0.0,4.0);size*=perspective_ratio;float fontScale=u_is_text ? size/24.0 : size;highp float symbol_rotation=0.0;if (u_rotate_symbol) {vec4 offsetProjectedPoint=u_matrix*vec4(a_pos+vec2(1,0),0,1);vec2 a=projectedPoint.xy/projectedPoint.w;vec2 b=offsetProjectedPoint.xy/offsetProjectedPoint.w;symbol_rotation=atan((b.y-a.y)/u_aspect_ratio,b.x-a.x);}highp float angle_sin=sin(segment_angle+symbol_rotation);highp float angle_cos=cos(segment_angle+symbol_rotation);mat2 rotation_matrix=mat2(angle_cos,-1.0*angle_sin,angle_sin,angle_cos);vec4 projected_pos=u_label_plane_matrix*vec4(a_projected_pos.xy,0.0,1.0);gl_Position=u_coord_matrix*vec4(projected_pos.xy/projected_pos.w+rotation_matrix*(a_offset/32.0*fontScale+a_pxoffset),0.0,1.0);float gamma_scale=gl_Position.w;vec2 fade_opacity=unpack_opacity(a_fade_opacity);float fade_change=fade_opacity[1] > 0.5 ? u_fade_change :-u_fade_change;float interpolated_fade_opacity=max(0.0,min(1.0,fade_opacity[0]+fade_change));v_data0=a_tex/u_texsize;v_data1=vec3(gamma_scale,size,interpolated_fade_opacity);}\"),vr=yr(\"#define SDF_PX 8.0\\n#define SDF 1.0\\n#define ICON 0.0\\nuniform bool u_is_halo;uniform sampler2D u_texture;uniform sampler2D u_texture_icon;uniform highp float u_gamma_scale;uniform lowp float u_device_pixel_ratio;varying vec4 v_data0;varying vec4 v_data1;\\n#pragma mapbox: define highp vec4 fill_color\\n#pragma mapbox: define highp vec4 halo_color\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define lowp float halo_width\\n#pragma mapbox: define lowp float halo_blur\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 fill_color\\n#pragma mapbox: initialize highp vec4 halo_color\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize lowp float halo_width\\n#pragma mapbox: initialize lowp float halo_blur\\nfloat fade_opacity=v_data1[2];if (v_data1.w==ICON) {vec2 tex_icon=v_data0.zw;lowp float alpha=opacity*fade_opacity;gl_FragColor=texture2D(u_texture_icon,tex_icon)*alpha;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\nreturn;}vec2 tex=v_data0.xy;float EDGE_GAMMA=0.105/u_device_pixel_ratio;float gamma_scale=v_data1.x;float size=v_data1.y;float fontScale=size/24.0;lowp vec4 color=fill_color;highp float gamma=EDGE_GAMMA/(fontScale*u_gamma_scale);lowp float buff=(256.0-64.0)/256.0;if (u_is_halo) {color=halo_color;gamma=(halo_blur*1.19/SDF_PX+EDGE_GAMMA)/(fontScale*u_gamma_scale);buff=(6.0-halo_width/fontScale)/SDF_PX;}lowp float dist=texture2D(u_texture,tex).a;highp float gamma_scaled=gamma*gamma_scale;highp float alpha=smoothstep(buff-gamma_scaled,buff+gamma_scaled,dist);gl_FragColor=color*(alpha*opacity*fade_opacity);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"const float PI=3.141592653589793;attribute vec4 a_pos_offset;attribute vec4 a_data;attribute vec3 a_projected_pos;attribute float a_fade_opacity;uniform bool u_is_size_zoom_constant;uniform bool u_is_size_feature_constant;uniform highp float u_size_t;uniform highp float u_size;uniform mat4 u_matrix;uniform mat4 u_label_plane_matrix;uniform mat4 u_coord_matrix;uniform bool u_is_text;uniform bool u_pitch_with_map;uniform highp float u_pitch;uniform bool u_rotate_symbol;uniform highp float u_aspect_ratio;uniform highp float u_camera_to_center_distance;uniform float u_fade_change;uniform vec2 u_texsize;uniform vec2 u_texsize_icon;varying vec4 v_data0;varying vec4 v_data1;\\n#pragma mapbox: define highp vec4 fill_color\\n#pragma mapbox: define highp vec4 halo_color\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define lowp float halo_width\\n#pragma mapbox: define lowp float halo_blur\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 fill_color\\n#pragma mapbox: initialize highp vec4 halo_color\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize lowp float halo_width\\n#pragma mapbox: initialize lowp float halo_blur\\nvec2 a_pos=a_pos_offset.xy;vec2 a_offset=a_pos_offset.zw;vec2 a_tex=a_data.xy;vec2 a_size=a_data.zw;float a_size_min=floor(a_size[0]*0.5);float is_sdf=a_size[0]-2.0*a_size_min;highp float segment_angle=-a_projected_pos[2];float size;if (!u_is_size_zoom_constant && !u_is_size_feature_constant) {size=mix(a_size_min,a_size[1],u_size_t)/128.0;} else if (u_is_size_zoom_constant && !u_is_size_feature_constant) {size=a_size_min/128.0;} else {size=u_size;}vec4 projectedPoint=u_matrix*vec4(a_pos,0,1);highp float camera_to_anchor_distance=projectedPoint.w;highp float distance_ratio=u_pitch_with_map ?\\ncamera_to_anchor_distance/u_camera_to_center_distance :\\nu_camera_to_center_distance/camera_to_anchor_distance;highp float perspective_ratio=clamp(0.5+0.5*distance_ratio,0.0,4.0);size*=perspective_ratio;float fontScale=size/24.0;highp float symbol_rotation=0.0;if (u_rotate_symbol) {vec4 offsetProjectedPoint=u_matrix*vec4(a_pos+vec2(1,0),0,1);vec2 a=projectedPoint.xy/projectedPoint.w;vec2 b=offsetProjectedPoint.xy/offsetProjectedPoint.w;symbol_rotation=atan((b.y-a.y)/u_aspect_ratio,b.x-a.x);}highp float angle_sin=sin(segment_angle+symbol_rotation);highp float angle_cos=cos(segment_angle+symbol_rotation);mat2 rotation_matrix=mat2(angle_cos,-1.0*angle_sin,angle_sin,angle_cos);vec4 projected_pos=u_label_plane_matrix*vec4(a_projected_pos.xy,0.0,1.0);gl_Position=u_coord_matrix*vec4(projected_pos.xy/projected_pos.w+rotation_matrix*(a_offset/32.0*fontScale),0.0,1.0);float gamma_scale=gl_Position.w;vec2 fade_opacity=unpack_opacity(a_fade_opacity);float fade_change=fade_opacity[1] > 0.5 ? u_fade_change :-u_fade_change;float interpolated_fade_opacity=max(0.0,min(1.0,fade_opacity[0]+fade_change));v_data0.xy=a_tex/u_texsize;v_data0.zw=a_tex/u_texsize_icon;v_data1=vec4(gamma_scale,size,interpolated_fade_opacity,is_sdf);}\");function yr(t,e){var r=/#pragma mapbox: ([\\w]+) ([\\w]+) ([\\w]+) ([\\w]+)/g,n={};return{fragmentSource:t=t.replace(r,(function(t,e,r,i,a){return n[a]=!0,\"define\"===e?\"\\n#ifndef HAS_UNIFORM_u_\"+a+\"\\nvarying \"+r+\" \"+i+\" \"+a+\";\\n#else\\nuniform \"+r+\" \"+i+\" u_\"+a+\";\\n#endif\\n\":\"\\n#ifdef HAS_UNIFORM_u_\"+a+\"\\n    \"+r+\" \"+i+\" \"+a+\" = u_\"+a+\";\\n#endif\\n\"})),vertexSource:e=e.replace(r,(function(t,e,r,i,a){var o=\"float\"===i?\"vec2\":\"vec4\",s=a.match(/color/)?\"color\":o;return n[a]?\"define\"===e?\"\\n#ifndef HAS_UNIFORM_u_\"+a+\"\\nuniform lowp float u_\"+a+\"_t;\\nattribute \"+r+\" \"+o+\" a_\"+a+\";\\nvarying \"+r+\" \"+i+\" \"+a+\";\\n#else\\nuniform \"+r+\" \"+i+\" u_\"+a+\";\\n#endif\\n\":\"vec4\"===s?\"\\n#ifndef HAS_UNIFORM_u_\"+a+\"\\n    \"+a+\" = a_\"+a+\";\\n#else\\n    \"+r+\" \"+i+\" \"+a+\" = u_\"+a+\";\\n#endif\\n\":\"\\n#ifndef HAS_UNIFORM_u_\"+a+\"\\n    \"+a+\" = unpack_mix_\"+s+\"(a_\"+a+\", u_\"+a+\"_t);\\n#else\\n    \"+r+\" \"+i+\" \"+a+\" = u_\"+a+\";\\n#endif\\n\":\"define\"===e?\"\\n#ifndef HAS_UNIFORM_u_\"+a+\"\\nuniform lowp float u_\"+a+\"_t;\\nattribute \"+r+\" \"+o+\" a_\"+a+\";\\n#else\\nuniform \"+r+\" \"+i+\" u_\"+a+\";\\n#endif\\n\":\"vec4\"===s?\"\\n#ifndef HAS_UNIFORM_u_\"+a+\"\\n    \"+r+\" \"+i+\" \"+a+\" = a_\"+a+\";\\n#else\\n    \"+r+\" \"+i+\" \"+a+\" = u_\"+a+\";\\n#endif\\n\":\"\\n#ifndef HAS_UNIFORM_u_\"+a+\"\\n    \"+r+\" \"+i+\" \"+a+\" = unpack_mix_\"+s+\"(a_\"+a+\", u_\"+a+\"_t);\\n#else\\n    \"+r+\" \"+i+\" \"+a+\" = u_\"+a+\";\\n#endif\\n\"}))}}var xr=Object.freeze({__proto__:null,prelude:Ye,background:We,backgroundPattern:Xe,circle:Ze,clippingMask:Je,heatmap:Ke,heatmapTexture:Qe,collisionBox:$e,collisionCircle:tr,debug:er,fill:rr,fillOutline:nr,fillOutlinePattern:ir,fillPattern:ar,fillExtrusion:or,fillExtrusionPattern:sr,hillshadePrepare:lr,hillshade:cr,line:ur,lineGradient:fr,linePattern:hr,lineSDF:pr,raster:dr,symbolIcon:mr,symbolSDF:gr,symbolTextAndIcon:vr}),br=function(){this.boundProgram=null,this.boundLayoutVertexBuffer=null,this.boundPaintVertexBuffers=[],this.boundIndexBuffer=null,this.boundVertexOffset=null,this.boundDynamicVertexBuffer=null,this.vao=null};br.prototype.bind=function(t,e,r,n,i,a,o,s){this.context=t;for(var l=this.boundPaintVertexBuffers.length!==n.length,c=0;!l&&c<n.length;c++)this.boundPaintVertexBuffers[c]!==n[c]&&(l=!0);var u=!this.vao||this.boundProgram!==e||this.boundLayoutVertexBuffer!==r||l||this.boundIndexBuffer!==i||this.boundVertexOffset!==a||this.boundDynamicVertexBuffer!==o||this.boundDynamicVertexBuffer2!==s;!t.extVertexArrayObject||u?this.freshBind(e,r,n,i,a,o,s):(t.bindVertexArrayOES.set(this.vao),o&&o.bind(),i&&i.dynamicDraw&&i.bind(),s&&s.bind())},br.prototype.freshBind=function(t,e,r,n,i,a,o){var s,l=t.numAttributes,c=this.context,u=c.gl;if(c.extVertexArrayObject)this.vao&&this.destroy(),this.vao=c.extVertexArrayObject.createVertexArrayOES(),c.bindVertexArrayOES.set(this.vao),s=0,this.boundProgram=t,this.boundLayoutVertexBuffer=e,this.boundPaintVertexBuffers=r,this.boundIndexBuffer=n,this.boundVertexOffset=i,this.boundDynamicVertexBuffer=a,this.boundDynamicVertexBuffer2=o;else{s=c.currentNumAttributes||0;for(var f=l;f<s;f++)u.disableVertexAttribArray(f)}e.enableAttributes(u,t);for(var h=0,p=r;h<p.length;h+=1){p[h].enableAttributes(u,t)}a&&a.enableAttributes(u,t),o&&o.enableAttributes(u,t),e.bind(),e.setVertexAttribPointers(u,t,i);for(var d=0,m=r;d<m.length;d+=1){var g=m[d];g.bind(),g.setVertexAttribPointers(u,t,i)}a&&(a.bind(),a.setVertexAttribPointers(u,t,i)),n&&n.bind(),o&&(o.bind(),o.setVertexAttribPointers(u,t,i)),c.currentNumAttributes=l},br.prototype.destroy=function(){this.vao&&(this.context.extVertexArrayObject.deleteVertexArrayOES(this.vao),this.vao=null)};var _r=function(t,e,r,n,i){var a=t.gl;this.program=a.createProgram();var o=r?r.defines():[];i&&o.push(\"#define OVERDRAW_INSPECTOR;\");var s=o.concat(Ye.fragmentSource,e.fragmentSource).join(\"\\n\"),l=o.concat(Ye.vertexSource,e.vertexSource).join(\"\\n\"),c=a.createShader(a.FRAGMENT_SHADER);if(a.isContextLost())this.failedToCreate=!0;else{a.shaderSource(c,s),a.compileShader(c),a.attachShader(this.program,c);var u=a.createShader(a.VERTEX_SHADER);if(a.isContextLost())this.failedToCreate=!0;else{a.shaderSource(u,l),a.compileShader(u),a.attachShader(this.program,u);for(var f=r?r.layoutAttributes:[],h=0;h<f.length;h++)a.bindAttribLocation(this.program,h,f[h].name);a.linkProgram(this.program),a.deleteShader(u),a.deleteShader(c),this.numAttributes=a.getProgramParameter(this.program,a.ACTIVE_ATTRIBUTES),this.attributes={};for(var p={},d=0;d<this.numAttributes;d++){var m=a.getActiveAttrib(this.program,d);m&&(this.attributes[m.name]=a.getAttribLocation(this.program,m.name))}for(var g=a.getProgramParameter(this.program,a.ACTIVE_UNIFORMS),v=0;v<g;v++){var y=a.getActiveUniform(this.program,v);y&&(p[y.name]=a.getUniformLocation(this.program,y.name))}this.fixedUniforms=n(t,p),this.binderUniforms=r?r.getUniforms(t,p):[]}}};function wr(t,e,r){var n=1/pe(r,1,e.transform.tileZoom),i=Math.pow(2,r.tileID.overscaledZ),a=r.tileSize*Math.pow(2,e.transform.tileZoom)/i,o=a*(r.tileID.canonical.x+r.tileID.wrap*i),s=a*r.tileID.canonical.y;return{u_image:0,u_texsize:r.imageAtlasTexture.size,u_scale:[n,t.fromScale,t.toScale],u_fade:t.t,u_pixel_coord_upper:[o>>16,s>>16],u_pixel_coord_lower:[65535&o,65535&s]}}_r.prototype.draw=function(t,e,r,n,i,a,o,s,l,c,u,f,h,p,d,m){var g,v=t.gl;if(!this.failedToCreate){for(var y in t.program.set(this.program),t.setDepthMode(r),t.setStencilMode(n),t.setColorMode(i),t.setCullFace(a),this.fixedUniforms)this.fixedUniforms[y].set(o[y]);p&&p.setUniforms(t,this.binderUniforms,f,{zoom:h});for(var x=(g={},g[v.LINES]=2,g[v.TRIANGLES]=3,g[v.LINE_STRIP]=1,g)[e],b=0,_=u.get();b<_.length;b+=1){var w=_[b],T=w.vaos||(w.vaos={});(T[s]||(T[s]=new br)).bind(t,this,l,p?p.getPaintVertexBuffers():[],c,w.vertexOffset,d,m),v.drawElements(e,w.primitiveLength*x,v.UNSIGNED_SHORT,w.primitiveOffset*x*2)}}};var Tr=function(e,r,n,i){var a=r.style.light,o=a.properties.get(\"position\"),s=[o.x,o.y,o.z],l=t.create$1();\"viewport\"===a.properties.get(\"anchor\")&&t.fromRotation(l,-r.transform.angle),t.transformMat3(s,s,l);var c=a.properties.get(\"color\");return{u_matrix:e,u_lightpos:s,u_lightintensity:a.properties.get(\"intensity\"),u_lightcolor:[c.r,c.g,c.b],u_vertical_gradient:+n,u_opacity:i}},kr=function(e,r,n,i,a,o,s){return t.extend(Tr(e,r,n,i),wr(o,r,s),{u_height_factor:-Math.pow(2,a.overscaledZ)/s.tileSize/8})},Mr=function(t){return{u_matrix:t}},Ar=function(e,r,n,i){return t.extend(Mr(e),wr(n,r,i))},Sr=function(t,e){return{u_matrix:t,u_world:e}},Er=function(e,r,n,i,a){return t.extend(Ar(e,r,n,i),{u_world:a})},Lr=function(e,r,n,i){var a,o,s=e.transform;if(\"map\"===i.paint.get(\"circle-pitch-alignment\")){var l=pe(n,1,s.zoom);a=!0,o=[l,l]}else a=!1,o=s.pixelsToGLUnits;return{u_camera_to_center_distance:s.cameraToCenterDistance,u_scale_with_map:+(\"map\"===i.paint.get(\"circle-pitch-scale\")),u_matrix:e.translatePosMatrix(r.posMatrix,n,i.paint.get(\"circle-translate\"),i.paint.get(\"circle-translate-anchor\")),u_pitch_with_map:+a,u_device_pixel_ratio:t.browser.devicePixelRatio,u_extrude_scale:o}},Cr=function(t,e,r){var n=pe(r,1,e.zoom),i=Math.pow(2,e.zoom-r.tileID.overscaledZ),a=r.tileID.overscaleFactor();return{u_matrix:t,u_camera_to_center_distance:e.cameraToCenterDistance,u_pixels_to_tile_units:n,u_extrude_scale:[e.pixelsToGLUnits[0]/(n*i),e.pixelsToGLUnits[1]/(n*i)],u_overscale_factor:a}},Pr=function(t,e,r){return{u_matrix:t,u_inv_matrix:e,u_camera_to_center_distance:r.cameraToCenterDistance,u_viewport_size:[r.width,r.height]}},Ir=function(t,e,r){return void 0===r&&(r=1),{u_matrix:t,u_color:e,u_overlay:0,u_overlay_scale:r}},Or=function(t){return{u_matrix:t}},zr=function(t,e,r,n){return{u_matrix:t,u_extrude_scale:pe(e,1,r),u_intensity:n}};function Dr(e,r){var n=Math.pow(2,r.canonical.z),i=r.canonical.y;return[new t.MercatorCoordinate(0,i/n).toLngLat().lat,new t.MercatorCoordinate(0,(i+1)/n).toLngLat().lat]}var Rr=function(e,r,n){var i=e.transform;return{u_matrix:Ur(e,r,n),u_ratio:1/pe(r,1,i.zoom),u_device_pixel_ratio:t.browser.devicePixelRatio,u_units_to_pixels:[1/i.pixelsToGLUnits[0],1/i.pixelsToGLUnits[1]]}},Fr=function(e,r,n){return t.extend(Rr(e,r,n),{u_image:0})},Br=function(e,r,n,i){var a=e.transform,o=jr(r,a);return{u_matrix:Ur(e,r,n),u_texsize:r.imageAtlasTexture.size,u_ratio:1/pe(r,1,a.zoom),u_device_pixel_ratio:t.browser.devicePixelRatio,u_image:0,u_scale:[o,i.fromScale,i.toScale],u_fade:i.t,u_units_to_pixels:[1/a.pixelsToGLUnits[0],1/a.pixelsToGLUnits[1]]}},Nr=function(e,r,n,i,a){var o=e.transform,s=e.lineAtlas,l=jr(r,o),c=\"round\"===n.layout.get(\"line-cap\"),u=s.getDash(i.from,c),f=s.getDash(i.to,c),h=u.width*a.fromScale,p=f.width*a.toScale;return t.extend(Rr(e,r,n),{u_patternscale_a:[l/h,-u.height/2],u_patternscale_b:[l/p,-f.height/2],u_sdfgamma:s.width/(256*Math.min(h,p)*t.browser.devicePixelRatio)/2,u_image:0,u_tex_y_a:u.y,u_tex_y_b:f.y,u_mix:a.t})};function jr(t,e){return 1/pe(t,1,e.tileZoom)}function Ur(t,e,r){return t.translatePosMatrix(e.tileID.posMatrix,e,r.paint.get(\"line-translate\"),r.paint.get(\"line-translate-anchor\"))}var Vr=function(t,e,r,n,i){return{u_matrix:t,u_tl_parent:e,u_scale_parent:r,u_buffer_scale:1,u_fade_t:n.mix,u_opacity:n.opacity*i.paint.get(\"raster-opacity\"),u_image0:0,u_image1:1,u_brightness_low:i.paint.get(\"raster-brightness-min\"),u_brightness_high:i.paint.get(\"raster-brightness-max\"),u_saturation_factor:(o=i.paint.get(\"raster-saturation\"),o>0?1-1/(1.001-o):-o),u_contrast_factor:(a=i.paint.get(\"raster-contrast\"),a>0?1/(1-a):1+a),u_spin_weights:qr(i.paint.get(\"raster-hue-rotate\"))};var a,o};function qr(t){t*=Math.PI/180;var e=Math.sin(t),r=Math.cos(t);return[(2*r+1)/3,(-Math.sqrt(3)*e-r+1)/3,(Math.sqrt(3)*e-r+1)/3]}var Hr,Gr=function(t,e,r,n,i,a,o,s,l,c){var u=i.transform;return{u_is_size_zoom_constant:+(\"constant\"===t||\"source\"===t),u_is_size_feature_constant:+(\"constant\"===t||\"camera\"===t),u_size_t:e?e.uSizeT:0,u_size:e?e.uSize:0,u_camera_to_center_distance:u.cameraToCenterDistance,u_pitch:u.pitch/360*2*Math.PI,u_rotate_symbol:+r,u_aspect_ratio:u.width/u.height,u_fade_change:i.options.fadeDuration?i.symbolFadeChange:1,u_matrix:a,u_label_plane_matrix:o,u_coord_matrix:s,u_is_text:+l,u_pitch_with_map:+n,u_texsize:c,u_texture:0}},Yr=function(e,r,n,i,a,o,s,l,c,u,f){var h=a.transform;return t.extend(Gr(e,r,n,i,a,o,s,l,c,u),{u_gamma_scale:i?Math.cos(h._pitch)*h.cameraToCenterDistance:1,u_device_pixel_ratio:t.browser.devicePixelRatio,u_is_halo:+f})},Wr=function(e,r,n,i,a,o,s,l,c,u){return t.extend(Yr(e,r,n,i,a,o,s,l,!0,c,!0),{u_texsize_icon:u,u_texture_icon:1})},Xr=function(t,e,r){return{u_matrix:t,u_opacity:e,u_color:r}},Zr=function(e,r,n,i,a,o){return t.extend(function(t,e,r,n){var i=r.imageManager.getPattern(t.from.toString()),a=r.imageManager.getPattern(t.to.toString()),o=r.imageManager.getPixelSize(),s=o.width,l=o.height,c=Math.pow(2,n.tileID.overscaledZ),u=n.tileSize*Math.pow(2,r.transform.tileZoom)/c,f=u*(n.tileID.canonical.x+n.tileID.wrap*c),h=u*n.tileID.canonical.y;return{u_image:0,u_pattern_tl_a:i.tl,u_pattern_br_a:i.br,u_pattern_tl_b:a.tl,u_pattern_br_b:a.br,u_texsize:[s,l],u_mix:e.t,u_pattern_size_a:i.displaySize,u_pattern_size_b:a.displaySize,u_scale_a:e.fromScale,u_scale_b:e.toScale,u_tile_units_to_pixels:1/pe(n,1,r.transform.tileZoom),u_pixel_coord_upper:[f>>16,h>>16],u_pixel_coord_lower:[65535&f,65535&h]}}(i,o,n,a),{u_matrix:e,u_opacity:r})},Jr={fillExtrusion:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_lightpos:new t.Uniform3f(e,r.u_lightpos),u_lightintensity:new t.Uniform1f(e,r.u_lightintensity),u_lightcolor:new t.Uniform3f(e,r.u_lightcolor),u_vertical_gradient:new t.Uniform1f(e,r.u_vertical_gradient),u_opacity:new t.Uniform1f(e,r.u_opacity)}},fillExtrusionPattern:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_lightpos:new t.Uniform3f(e,r.u_lightpos),u_lightintensity:new t.Uniform1f(e,r.u_lightintensity),u_lightcolor:new t.Uniform3f(e,r.u_lightcolor),u_vertical_gradient:new t.Uniform1f(e,r.u_vertical_gradient),u_height_factor:new t.Uniform1f(e,r.u_height_factor),u_image:new t.Uniform1i(e,r.u_image),u_texsize:new t.Uniform2f(e,r.u_texsize),u_pixel_coord_upper:new t.Uniform2f(e,r.u_pixel_coord_upper),u_pixel_coord_lower:new t.Uniform2f(e,r.u_pixel_coord_lower),u_scale:new t.Uniform3f(e,r.u_scale),u_fade:new t.Uniform1f(e,r.u_fade),u_opacity:new t.Uniform1f(e,r.u_opacity)}},fill:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix)}},fillPattern:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_image:new t.Uniform1i(e,r.u_image),u_texsize:new t.Uniform2f(e,r.u_texsize),u_pixel_coord_upper:new t.Uniform2f(e,r.u_pixel_coord_upper),u_pixel_coord_lower:new t.Uniform2f(e,r.u_pixel_coord_lower),u_scale:new t.Uniform3f(e,r.u_scale),u_fade:new t.Uniform1f(e,r.u_fade)}},fillOutline:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_world:new t.Uniform2f(e,r.u_world)}},fillOutlinePattern:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_world:new t.Uniform2f(e,r.u_world),u_image:new t.Uniform1i(e,r.u_image),u_texsize:new t.Uniform2f(e,r.u_texsize),u_pixel_coord_upper:new t.Uniform2f(e,r.u_pixel_coord_upper),u_pixel_coord_lower:new t.Uniform2f(e,r.u_pixel_coord_lower),u_scale:new t.Uniform3f(e,r.u_scale),u_fade:new t.Uniform1f(e,r.u_fade)}},circle:function(e,r){return{u_camera_to_center_distance:new t.Uniform1f(e,r.u_camera_to_center_distance),u_scale_with_map:new t.Uniform1i(e,r.u_scale_with_map),u_pitch_with_map:new t.Uniform1i(e,r.u_pitch_with_map),u_extrude_scale:new t.Uniform2f(e,r.u_extrude_scale),u_device_pixel_ratio:new t.Uniform1f(e,r.u_device_pixel_ratio),u_matrix:new t.UniformMatrix4f(e,r.u_matrix)}},collisionBox:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_camera_to_center_distance:new t.Uniform1f(e,r.u_camera_to_center_distance),u_pixels_to_tile_units:new t.Uniform1f(e,r.u_pixels_to_tile_units),u_extrude_scale:new t.Uniform2f(e,r.u_extrude_scale),u_overscale_factor:new t.Uniform1f(e,r.u_overscale_factor)}},collisionCircle:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_inv_matrix:new t.UniformMatrix4f(e,r.u_inv_matrix),u_camera_to_center_distance:new t.Uniform1f(e,r.u_camera_to_center_distance),u_viewport_size:new t.Uniform2f(e,r.u_viewport_size)}},debug:function(e,r){return{u_color:new t.UniformColor(e,r.u_color),u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_overlay:new t.Uniform1i(e,r.u_overlay),u_overlay_scale:new t.Uniform1f(e,r.u_overlay_scale)}},clippingMask:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix)}},heatmap:function(e,r){return{u_extrude_scale:new t.Uniform1f(e,r.u_extrude_scale),u_intensity:new t.Uniform1f(e,r.u_intensity),u_matrix:new t.UniformMatrix4f(e,r.u_matrix)}},heatmapTexture:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_world:new t.Uniform2f(e,r.u_world),u_image:new t.Uniform1i(e,r.u_image),u_color_ramp:new t.Uniform1i(e,r.u_color_ramp),u_opacity:new t.Uniform1f(e,r.u_opacity)}},hillshade:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_image:new t.Uniform1i(e,r.u_image),u_latrange:new t.Uniform2f(e,r.u_latrange),u_light:new t.Uniform2f(e,r.u_light),u_shadow:new t.UniformColor(e,r.u_shadow),u_highlight:new t.UniformColor(e,r.u_highlight),u_accent:new t.UniformColor(e,r.u_accent)}},hillshadePrepare:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_image:new t.Uniform1i(e,r.u_image),u_dimension:new t.Uniform2f(e,r.u_dimension),u_zoom:new t.Uniform1f(e,r.u_zoom),u_maxzoom:new t.Uniform1f(e,r.u_maxzoom),u_unpack:new t.Uniform4f(e,r.u_unpack)}},line:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_ratio:new t.Uniform1f(e,r.u_ratio),u_device_pixel_ratio:new t.Uniform1f(e,r.u_device_pixel_ratio),u_units_to_pixels:new t.Uniform2f(e,r.u_units_to_pixels)}},lineGradient:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_ratio:new t.Uniform1f(e,r.u_ratio),u_device_pixel_ratio:new t.Uniform1f(e,r.u_device_pixel_ratio),u_units_to_pixels:new t.Uniform2f(e,r.u_units_to_pixels),u_image:new t.Uniform1i(e,r.u_image)}},linePattern:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_texsize:new t.Uniform2f(e,r.u_texsize),u_ratio:new t.Uniform1f(e,r.u_ratio),u_device_pixel_ratio:new t.Uniform1f(e,r.u_device_pixel_ratio),u_image:new t.Uniform1i(e,r.u_image),u_units_to_pixels:new t.Uniform2f(e,r.u_units_to_pixels),u_scale:new t.Uniform3f(e,r.u_scale),u_fade:new t.Uniform1f(e,r.u_fade)}},lineSDF:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_ratio:new t.Uniform1f(e,r.u_ratio),u_device_pixel_ratio:new t.Uniform1f(e,r.u_device_pixel_ratio),u_units_to_pixels:new t.Uniform2f(e,r.u_units_to_pixels),u_patternscale_a:new t.Uniform2f(e,r.u_patternscale_a),u_patternscale_b:new t.Uniform2f(e,r.u_patternscale_b),u_sdfgamma:new t.Uniform1f(e,r.u_sdfgamma),u_image:new t.Uniform1i(e,r.u_image),u_tex_y_a:new t.Uniform1f(e,r.u_tex_y_a),u_tex_y_b:new t.Uniform1f(e,r.u_tex_y_b),u_mix:new t.Uniform1f(e,r.u_mix)}},raster:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_tl_parent:new t.Uniform2f(e,r.u_tl_parent),u_scale_parent:new t.Uniform1f(e,r.u_scale_parent),u_buffer_scale:new t.Uniform1f(e,r.u_buffer_scale),u_fade_t:new t.Uniform1f(e,r.u_fade_t),u_opacity:new t.Uniform1f(e,r.u_opacity),u_image0:new t.Uniform1i(e,r.u_image0),u_image1:new t.Uniform1i(e,r.u_image1),u_brightness_low:new t.Uniform1f(e,r.u_brightness_low),u_brightness_high:new t.Uniform1f(e,r.u_brightness_high),u_saturation_factor:new t.Uniform1f(e,r.u_saturation_factor),u_contrast_factor:new t.Uniform1f(e,r.u_contrast_factor),u_spin_weights:new t.Uniform3f(e,r.u_spin_weights)}},symbolIcon:function(e,r){return{u_is_size_zoom_constant:new t.Uniform1i(e,r.u_is_size_zoom_constant),u_is_size_feature_constant:new t.Uniform1i(e,r.u_is_size_feature_constant),u_size_t:new t.Uniform1f(e,r.u_size_t),u_size:new t.Uniform1f(e,r.u_size),u_camera_to_center_distance:new t.Uniform1f(e,r.u_camera_to_center_distance),u_pitch:new t.Uniform1f(e,r.u_pitch),u_rotate_symbol:new t.Uniform1i(e,r.u_rotate_symbol),u_aspect_ratio:new t.Uniform1f(e,r.u_aspect_ratio),u_fade_change:new t.Uniform1f(e,r.u_fade_change),u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_label_plane_matrix:new t.UniformMatrix4f(e,r.u_label_plane_matrix),u_coord_matrix:new t.UniformMatrix4f(e,r.u_coord_matrix),u_is_text:new t.Uniform1i(e,r.u_is_text),u_pitch_with_map:new t.Uniform1i(e,r.u_pitch_with_map),u_texsize:new t.Uniform2f(e,r.u_texsize),u_texture:new t.Uniform1i(e,r.u_texture)}},symbolSDF:function(e,r){return{u_is_size_zoom_constant:new t.Uniform1i(e,r.u_is_size_zoom_constant),u_is_size_feature_constant:new t.Uniform1i(e,r.u_is_size_feature_constant),u_size_t:new t.Uniform1f(e,r.u_size_t),u_size:new t.Uniform1f(e,r.u_size),u_camera_to_center_distance:new t.Uniform1f(e,r.u_camera_to_center_distance),u_pitch:new t.Uniform1f(e,r.u_pitch),u_rotate_symbol:new t.Uniform1i(e,r.u_rotate_symbol),u_aspect_ratio:new t.Uniform1f(e,r.u_aspect_ratio),u_fade_change:new t.Uniform1f(e,r.u_fade_change),u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_label_plane_matrix:new t.UniformMatrix4f(e,r.u_label_plane_matrix),u_coord_matrix:new t.UniformMatrix4f(e,r.u_coord_matrix),u_is_text:new t.Uniform1i(e,r.u_is_text),u_pitch_with_map:new t.Uniform1i(e,r.u_pitch_with_map),u_texsize:new t.Uniform2f(e,r.u_texsize),u_texture:new t.Uniform1i(e,r.u_texture),u_gamma_scale:new t.Uniform1f(e,r.u_gamma_scale),u_device_pixel_ratio:new t.Uniform1f(e,r.u_device_pixel_ratio),u_is_halo:new t.Uniform1i(e,r.u_is_halo)}},symbolTextAndIcon:function(e,r){return{u_is_size_zoom_constant:new t.Uniform1i(e,r.u_is_size_zoom_constant),u_is_size_feature_constant:new t.Uniform1i(e,r.u_is_size_feature_constant),u_size_t:new t.Uniform1f(e,r.u_size_t),u_size:new t.Uniform1f(e,r.u_size),u_camera_to_center_distance:new t.Uniform1f(e,r.u_camera_to_center_distance),u_pitch:new t.Uniform1f(e,r.u_pitch),u_rotate_symbol:new t.Uniform1i(e,r.u_rotate_symbol),u_aspect_ratio:new t.Uniform1f(e,r.u_aspect_ratio),u_fade_change:new t.Uniform1f(e,r.u_fade_change),u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_label_plane_matrix:new t.UniformMatrix4f(e,r.u_label_plane_matrix),u_coord_matrix:new t.UniformMatrix4f(e,r.u_coord_matrix),u_is_text:new t.Uniform1i(e,r.u_is_text),u_pitch_with_map:new t.Uniform1i(e,r.u_pitch_with_map),u_texsize:new t.Uniform2f(e,r.u_texsize),u_texsize_icon:new t.Uniform2f(e,r.u_texsize_icon),u_texture:new t.Uniform1i(e,r.u_texture),u_texture_icon:new t.Uniform1i(e,r.u_texture_icon),u_gamma_scale:new t.Uniform1f(e,r.u_gamma_scale),u_device_pixel_ratio:new t.Uniform1f(e,r.u_device_pixel_ratio),u_is_halo:new t.Uniform1i(e,r.u_is_halo)}},background:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_opacity:new t.Uniform1f(e,r.u_opacity),u_color:new t.UniformColor(e,r.u_color)}},backgroundPattern:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_opacity:new t.Uniform1f(e,r.u_opacity),u_image:new t.Uniform1i(e,r.u_image),u_pattern_tl_a:new t.Uniform2f(e,r.u_pattern_tl_a),u_pattern_br_a:new t.Uniform2f(e,r.u_pattern_br_a),u_pattern_tl_b:new t.Uniform2f(e,r.u_pattern_tl_b),u_pattern_br_b:new t.Uniform2f(e,r.u_pattern_br_b),u_texsize:new t.Uniform2f(e,r.u_texsize),u_mix:new t.Uniform1f(e,r.u_mix),u_pattern_size_a:new t.Uniform2f(e,r.u_pattern_size_a),u_pattern_size_b:new t.Uniform2f(e,r.u_pattern_size_b),u_scale_a:new t.Uniform1f(e,r.u_scale_a),u_scale_b:new t.Uniform1f(e,r.u_scale_b),u_pixel_coord_upper:new t.Uniform2f(e,r.u_pixel_coord_upper),u_pixel_coord_lower:new t.Uniform2f(e,r.u_pixel_coord_lower),u_tile_units_to_pixels:new t.Uniform1f(e,r.u_tile_units_to_pixels)}}};function Kr(e,r,n,i,a,o,s){for(var l=e.context,c=l.gl,u=e.useProgram(\"collisionBox\"),f=[],h=0,p=0,d=0;d<i.length;d++){var m=i[d],g=r.getTile(m),v=g.getBucket(n);if(v){var y=m.posMatrix;0===a[0]&&0===a[1]||(y=e.translatePosMatrix(m.posMatrix,g,a,o));var x=s?v.textCollisionBox:v.iconCollisionBox,b=v.collisionCircleArray;if(b.length>0){var _=t.create(),w=y;t.mul(_,v.placementInvProjMatrix,e.transform.glCoordMatrix),t.mul(_,_,v.placementViewportMatrix),f.push({circleArray:b,circleOffset:p,transform:w,invTransform:_}),p=h+=b.length/4}x&&u.draw(l,c.LINES,Mt.disabled,At.disabled,e.colorModeForRenderPass(),Et.disabled,Cr(y,e.transform,g),n.id,x.layoutVertexBuffer,x.indexBuffer,x.segments,null,e.transform.zoom,null,null,x.collisionVertexBuffer)}}if(s&&f.length){var T=e.useProgram(\"collisionCircle\"),k=new t.StructArrayLayout2f1f2i16;k.resize(4*h),k._trim();for(var M=0,A=0,S=f;A<S.length;A+=1)for(var E=S[A],L=0;L<E.circleArray.length/4;L++){var C=4*L,P=E.circleArray[C+0],I=E.circleArray[C+1],O=E.circleArray[C+2],z=E.circleArray[C+3];k.emplace(M++,P,I,O,z,0),k.emplace(M++,P,I,O,z,1),k.emplace(M++,P,I,O,z,2),k.emplace(M++,P,I,O,z,3)}(!Hr||Hr.length<2*h)&&(Hr=function(e){var r=2*e,n=new t.StructArrayLayout3ui6;n.resize(r),n._trim();for(var i=0;i<r;i++){var a=6*i;n.uint16[a+0]=4*i+0,n.uint16[a+1]=4*i+1,n.uint16[a+2]=4*i+2,n.uint16[a+3]=4*i+2,n.uint16[a+4]=4*i+3,n.uint16[a+5]=4*i+0}return n}(h));for(var D=l.createIndexBuffer(Hr,!0),R=l.createVertexBuffer(k,t.collisionCircleLayout.members,!0),F=0,B=f;F<B.length;F+=1){var N=B[F],j=Pr(N.transform,N.invTransform,e.transform);T.draw(l,c.TRIANGLES,Mt.disabled,At.disabled,e.colorModeForRenderPass(),Et.disabled,j,n.id,R,D,t.SegmentVector.simpleSegment(0,2*N.circleOffset,N.circleArray.length,N.circleArray.length/2),null,e.transform.zoom,null,null,null)}R.destroy(),D.destroy()}}var Qr=t.identity(new Float32Array(16));function $r(e,r,n,i,a,o){var s=t.getAnchorAlignment(e),l=-(s.horizontalAlign-.5)*r,c=-(s.verticalAlign-.5)*n,u=t.evaluateVariableOffset(e,i);return new t.Point((l/a+u[0])*o,(c/a+u[1])*o)}function tn(e,r,n,i,a,o,s,l,c,u,f){var h=e.text.placedSymbolArray,p=e.text.dynamicLayoutVertexArray,d=e.icon.dynamicLayoutVertexArray,m={};p.clear();for(var g=0;g<h.length;g++){var v=h.get(g),y=e.allowVerticalPlacement&&!v.placedOrientation,x=v.hidden||!v.crossTileID||y?null:i[v.crossTileID];if(x){var b=new t.Point(v.anchorX,v.anchorY),_=te(b,n?l:s),w=ee(o.cameraToCenterDistance,_.signedDistanceFromCamera),T=a.evaluateSizeForFeature(e.textSizeData,u,v)*w/t.ONE_EM;n&&(T*=e.tilePixelRatio/c);for(var k=x.width,M=x.height,A=$r(x.anchor,k,M,x.textOffset,x.textBoxScale,T),S=n?te(b.add(A),s).point:_.point.add(r?A.rotate(-o.angle):A),E=e.allowVerticalPlacement&&v.placedOrientation===t.WritingMode.vertical?Math.PI/2:0,L=0;L<v.numGlyphs;L++)t.addDynamicAttributes(p,S,E);f&&v.associatedIconIndex>=0&&(m[v.associatedIconIndex]={shiftedAnchor:S,angle:E})}else ue(v.numGlyphs,p)}if(f){d.clear();for(var C=e.icon.placedSymbolArray,P=0;P<C.length;P++){var I=C.get(P);if(I.hidden)ue(I.numGlyphs,d);else{var O=m[P];if(O)for(var z=0;z<I.numGlyphs;z++)t.addDynamicAttributes(d,O.shiftedAnchor,O.angle);else ue(I.numGlyphs,d)}}e.icon.dynamicLayoutVertexBuffer.updateData(d)}e.text.dynamicLayoutVertexBuffer.updateData(p)}function en(t,e,r){return r.iconsInText&&e?\"symbolTextAndIcon\":t?\"symbolSDF\":\"symbolIcon\"}function rn(e,r,n,i,a,o,s,l,c,u,f,h){for(var p=e.context,d=p.gl,m=e.transform,g=\"map\"===l,v=\"map\"===c,y=g&&\"point\"!==n.layout.get(\"symbol-placement\"),x=g&&!v&&!y,b=void 0!==n.layout.get(\"symbol-sort-key\").constantOr(1),_=e.depthModeForSublayer(0,Mt.ReadOnly),w=n.layout.get(\"text-variable-anchor\"),T=[],k=0,M=i;k<M.length;k+=1){var A=M[k],S=r.getTile(A),E=S.getBucket(n);if(E){var L=a?E.text:E.icon;if(L&&L.segments.get().length){var C=L.programConfigurations.get(n.id),P=a||E.sdfIcons,I=a?E.textSizeData:E.iconSizeData,O=v||0!==m.pitch,z=e.useProgram(en(P,a,E),C),D=t.evaluateSizeForZoom(I,m.zoom),R=void 0,F=[0,0],B=void 0,N=void 0,j=null,U=void 0;if(a){if(B=S.glyphAtlasTexture,N=d.LINEAR,R=S.glyphAtlasTexture.size,E.iconsInText){F=S.imageAtlasTexture.size,j=S.imageAtlasTexture;var V=\"composite\"===I.kind||\"camera\"===I.kind;U=O||e.options.rotating||e.options.zooming||V?d.LINEAR:d.NEAREST}}else{var q=1!==n.layout.get(\"icon-size\").constantOr(0)||E.iconsNeedLinear;B=S.imageAtlasTexture,N=P||e.options.rotating||e.options.zooming||q||O?d.LINEAR:d.NEAREST,R=S.imageAtlasTexture.size}var H=pe(S,1,e.transform.zoom),G=Qt(A.posMatrix,v,g,e.transform,H),Y=$t(A.posMatrix,v,g,e.transform,H),W=w&&E.hasTextData(),X=\"none\"!==n.layout.get(\"icon-text-fit\")&&W&&E.hasIconData();y&&ne(E,A.posMatrix,e,a,G,Y,v,u);var Z=e.translatePosMatrix(A.posMatrix,S,o,s),J=y||a&&w||X?Qr:G,K=e.translatePosMatrix(Y,S,o,s,!0),Q=P&&0!==n.paint.get(a?\"text-halo-width\":\"icon-halo-width\").constantOr(1),$={program:z,buffers:L,uniformValues:P?E.iconsInText?Wr(I.kind,D,x,v,e,Z,J,K,R,F):Yr(I.kind,D,x,v,e,Z,J,K,a,R,!0):Gr(I.kind,D,x,v,e,Z,J,K,a,R),atlasTexture:B,atlasTextureIcon:j,atlasInterpolation:N,atlasInterpolationIcon:U,isSDF:P,hasHalo:Q};if(b)for(var tt=0,et=L.segments.get();tt<et.length;tt+=1){var rt=et[tt];T.push({segments:new t.SegmentVector([rt]),sortKey:rt.sortKey,state:$})}else T.push({segments:L.segments,sortKey:0,state:$})}}}b&&T.sort((function(t,e){return t.sortKey-e.sortKey}));for(var nt=0,it=T;nt<it.length;nt+=1){var at=it[nt],ot=at.state;if(p.activeTexture.set(d.TEXTURE0),ot.atlasTexture.bind(ot.atlasInterpolation,d.CLAMP_TO_EDGE),ot.atlasTextureIcon&&(p.activeTexture.set(d.TEXTURE1),ot.atlasTextureIcon&&ot.atlasTextureIcon.bind(ot.atlasInterpolationIcon,d.CLAMP_TO_EDGE)),ot.isSDF){var st=ot.uniformValues;ot.hasHalo&&(st.u_is_halo=1,nn(ot.buffers,at.segments,n,e,ot.program,_,f,h,st)),st.u_is_halo=0}nn(ot.buffers,at.segments,n,e,ot.program,_,f,h,ot.uniformValues)}}function nn(t,e,r,n,i,a,o,s,l){var c=n.context,u=c.gl;i.draw(c,u.TRIANGLES,a,o,s,Et.disabled,l,r.id,t.layoutVertexBuffer,t.indexBuffer,e,r.paint,n.transform.zoom,t.programConfigurations.get(r.id),t.dynamicLayoutVertexBuffer,t.opacityVertexBuffer)}function an(t,e,r,n,i,a,o){var s,l,c,u,f,h=t.context.gl,p=r.paint.get(\"fill-pattern\"),d=p&&p.constantOr(1),m=r.getCrossfadeParameters();o?(l=d&&!r.getPaintProperty(\"fill-outline-color\")?\"fillOutlinePattern\":\"fillOutline\",s=h.LINES):(l=d?\"fillPattern\":\"fill\",s=h.TRIANGLES);for(var g=0,v=n;g<v.length;g+=1){var y=v[g],x=e.getTile(y);if(!d||x.patternsLoaded()){var b=x.getBucket(r);if(b){var _=b.programConfigurations.get(r.id),w=t.useProgram(l,_);d&&(t.context.activeTexture.set(h.TEXTURE0),x.imageAtlasTexture.bind(h.LINEAR,h.CLAMP_TO_EDGE),_.updatePaintBuffers(m));var T=p.constantOr(null);if(T&&x.imageAtlas){var k=x.imageAtlas,M=k.patternPositions[T.to.toString()],A=k.patternPositions[T.from.toString()];M&&A&&_.setConstantPatternPositions(M,A)}var S=t.translatePosMatrix(y.posMatrix,x,r.paint.get(\"fill-translate\"),r.paint.get(\"fill-translate-anchor\"));if(o){u=b.indexBuffer2,f=b.segments2;var E=[h.drawingBufferWidth,h.drawingBufferHeight];c=\"fillOutlinePattern\"===l&&d?Er(S,t,m,x,E):Sr(S,E)}else u=b.indexBuffer,f=b.segments,c=d?Ar(S,t,m,x):Mr(S);w.draw(t.context,s,i,t.stencilModeForClipping(y),a,Et.disabled,c,r.id,b.layoutVertexBuffer,u,f,r.paint,t.transform.zoom,_)}}}}function on(t,e,r,n,i,a,o){for(var s=t.context,l=s.gl,c=r.paint.get(\"fill-extrusion-pattern\"),u=c.constantOr(1),f=r.getCrossfadeParameters(),h=r.paint.get(\"fill-extrusion-opacity\"),p=0,d=n;p<d.length;p+=1){var m=d[p],g=e.getTile(m),v=g.getBucket(r);if(v){var y=v.programConfigurations.get(r.id),x=t.useProgram(u?\"fillExtrusionPattern\":\"fillExtrusion\",y);u&&(t.context.activeTexture.set(l.TEXTURE0),g.imageAtlasTexture.bind(l.LINEAR,l.CLAMP_TO_EDGE),y.updatePaintBuffers(f));var b=c.constantOr(null);if(b&&g.imageAtlas){var _=g.imageAtlas,w=_.patternPositions[b.to.toString()],T=_.patternPositions[b.from.toString()];w&&T&&y.setConstantPatternPositions(w,T)}var k=t.translatePosMatrix(m.posMatrix,g,r.paint.get(\"fill-extrusion-translate\"),r.paint.get(\"fill-extrusion-translate-anchor\")),M=r.paint.get(\"fill-extrusion-vertical-gradient\"),A=u?kr(k,t,M,h,m,f,g):Tr(k,t,M,h);x.draw(s,s.gl.TRIANGLES,i,a,o,Et.backCCW,A,r.id,v.layoutVertexBuffer,v.indexBuffer,v.segments,r.paint,t.transform.zoom,y)}}}function sn(t,e,r,n,i,a){var o=t.context,s=o.gl,l=e.fbo;if(l){var c=t.useProgram(\"hillshade\");o.activeTexture.set(s.TEXTURE0),s.bindTexture(s.TEXTURE_2D,l.colorAttachment.get());var u=function(t,e,r){var n=r.paint.get(\"hillshade-shadow-color\"),i=r.paint.get(\"hillshade-highlight-color\"),a=r.paint.get(\"hillshade-accent-color\"),o=r.paint.get(\"hillshade-illumination-direction\")*(Math.PI/180);\"viewport\"===r.paint.get(\"hillshade-illumination-anchor\")&&(o-=t.transform.angle);var s=!t.options.moving;return{u_matrix:t.transform.calculatePosMatrix(e.tileID.toUnwrapped(),s),u_image:0,u_latrange:Dr(t,e.tileID),u_light:[r.paint.get(\"hillshade-exaggeration\"),o],u_shadow:n,u_highlight:i,u_accent:a}}(t,e,r);c.draw(o,s.TRIANGLES,n,i,a,Et.disabled,u,r.id,t.rasterBoundsBuffer,t.quadTriangleIndexBuffer,t.rasterBoundsSegments)}}function ln(e,r,n,i,a,o,s){var l=e.context,c=l.gl,u=r.dem;if(u&&u.data){var f=u.dim,h=u.stride,p=u.getPixels();if(l.activeTexture.set(c.TEXTURE1),l.pixelStoreUnpackPremultiplyAlpha.set(!1),r.demTexture=r.demTexture||e.getTileTexture(h),r.demTexture){var d=r.demTexture;d.update(p,{premultiply:!1}),d.bind(c.NEAREST,c.CLAMP_TO_EDGE)}else r.demTexture=new t.Texture(l,p,c.RGBA,{premultiply:!1}),r.demTexture.bind(c.NEAREST,c.CLAMP_TO_EDGE);l.activeTexture.set(c.TEXTURE0);var m=r.fbo;if(!m){var g=new t.Texture(l,{width:f,height:f,data:null},c.RGBA);g.bind(c.LINEAR,c.CLAMP_TO_EDGE),(m=r.fbo=l.createFramebuffer(f,f,!0)).colorAttachment.set(g.texture)}l.bindFramebuffer.set(m.framebuffer),l.viewport.set([0,0,f,f]),e.useProgram(\"hillshadePrepare\").draw(l,c.TRIANGLES,a,o,s,Et.disabled,function(e,r,n){var i=r.stride,a=t.create();return t.ortho(a,0,t.EXTENT,-t.EXTENT,0,0,1),t.translate(a,a,[0,-t.EXTENT,0]),{u_matrix:a,u_image:1,u_dimension:[i,i],u_zoom:e.overscaledZ,u_maxzoom:n,u_unpack:r.getUnpackVector()}}(r.tileID,u,i),n.id,e.rasterBoundsBuffer,e.quadTriangleIndexBuffer,e.rasterBoundsSegments),r.needsHillshadePrepare=!1}}function cn(e,r,n,i,a){var o=i.paint.get(\"raster-fade-duration\");if(o>0){var s=t.browser.now(),l=(s-e.timeAdded)/o,c=r?(s-r.timeAdded)/o:-1,u=n.getSource(),f=a.coveringZoomLevel({tileSize:u.tileSize,roundZoom:u.roundZoom}),h=!r||Math.abs(r.tileID.overscaledZ-f)>Math.abs(e.tileID.overscaledZ-f),p=h&&e.refreshedUponExpiration?1:t.clamp(h?l:1-c,0,1);return e.refreshedUponExpiration&&l>=1&&(e.refreshedUponExpiration=!1),r?{opacity:1,mix:1-p}:{opacity:p,mix:0}}return{opacity:1,mix:0}}var un=new t.Color(1,0,0,1),fn=new t.Color(0,1,0,1),hn=new t.Color(0,0,1,1),pn=new t.Color(1,0,1,1),dn=new t.Color(0,1,1,1);function mn(t){var e=t.transform.padding;gn(t,t.transform.height-(e.top||0),3,un),gn(t,e.bottom||0,3,fn),vn(t,e.left||0,3,hn),vn(t,t.transform.width-(e.right||0),3,pn);var r=t.transform.centerPoint;!function(t,e,r,n){yn(t,e-1,r-10,2,20,n),yn(t,e-10,r-1,20,2,n)}(t,r.x,t.transform.height-r.y,dn)}function gn(t,e,r,n){yn(t,0,e+r/2,t.transform.width,r,n)}function vn(t,e,r,n){yn(t,e-r/2,0,r,t.transform.height,n)}function yn(e,r,n,i,a,o){var s=e.context,l=s.gl;l.enable(l.SCISSOR_TEST),l.scissor(r*t.browser.devicePixelRatio,n*t.browser.devicePixelRatio,i*t.browser.devicePixelRatio,a*t.browser.devicePixelRatio),s.clear({color:o}),l.disable(l.SCISSOR_TEST)}function xn(e,r,n){var i=e.context,a=i.gl,o=n.posMatrix,s=e.useProgram(\"debug\"),l=Mt.disabled,c=At.disabled,u=e.colorModeForRenderPass();i.activeTexture.set(a.TEXTURE0),e.emptyTexture.bind(a.LINEAR,a.CLAMP_TO_EDGE),s.draw(i,a.LINE_STRIP,l,c,u,Et.disabled,Ir(o,t.Color.red),\"$debug\",e.debugBuffer,e.tileBorderIndexBuffer,e.debugSegments);var f=r.getTileByID(n.key).latestRawTileData,h=f&&f.byteLength||0,p=Math.floor(h/1024),d=r.getTile(n).tileSize,m=512/Math.min(d,512)*(n.overscaledZ/e.transform.zoom)*.5,g=n.canonical.toString();n.overscaledZ!==n.canonical.z&&(g+=\" => \"+n.overscaledZ),function(t,e){t.initDebugOverlayCanvas();var r=t.debugOverlayCanvas,n=t.context.gl,i=t.debugOverlayCanvas.getContext(\"2d\");i.clearRect(0,0,r.width,r.height),i.shadowColor=\"white\",i.shadowBlur=2,i.lineWidth=1.5,i.strokeStyle=\"white\",i.textBaseline=\"top\",i.font=\"bold 36px Open Sans, sans-serif\",i.fillText(e,5,5),i.strokeText(e,5,5),t.debugOverlayTexture.update(r),t.debugOverlayTexture.bind(n.LINEAR,n.CLAMP_TO_EDGE)}(e,g+\" \"+p+\"kb\"),s.draw(i,a.TRIANGLES,l,c,St.alphaBlended,Et.disabled,Ir(o,t.Color.transparent,m),\"$debug\",e.debugBuffer,e.quadTriangleIndexBuffer,e.debugSegments)}var bn={symbol:function(e,r,n,i,a){if(\"translucent\"===e.renderPass){var o=At.disabled,s=e.colorModeForRenderPass();n.layout.get(\"text-variable-anchor\")&&function(e,r,n,i,a,o,s){for(var l=r.transform,c=\"map\"===a,u=\"map\"===o,f=0,h=e;f<h.length;f+=1){var p=h[f],d=i.getTile(p),m=d.getBucket(n);if(m&&m.text&&m.text.segments.get().length){var g=m.textSizeData,v=t.evaluateSizeForZoom(g,l.zoom),y=pe(d,1,r.transform.zoom),x=Qt(p.posMatrix,u,c,r.transform,y),b=\"none\"!==n.layout.get(\"icon-text-fit\")&&m.hasIconData();if(v){var _=Math.pow(2,l.zoom-d.tileID.overscaledZ);tn(m,c,u,s,t.symbolSize,l,x,p.posMatrix,_,v,b)}}}}(i,e,n,r,n.layout.get(\"text-rotation-alignment\"),n.layout.get(\"text-pitch-alignment\"),a),0!==n.paint.get(\"icon-opacity\").constantOr(1)&&rn(e,r,n,i,!1,n.paint.get(\"icon-translate\"),n.paint.get(\"icon-translate-anchor\"),n.layout.get(\"icon-rotation-alignment\"),n.layout.get(\"icon-pitch-alignment\"),n.layout.get(\"icon-keep-upright\"),o,s),0!==n.paint.get(\"text-opacity\").constantOr(1)&&rn(e,r,n,i,!0,n.paint.get(\"text-translate\"),n.paint.get(\"text-translate-anchor\"),n.layout.get(\"text-rotation-alignment\"),n.layout.get(\"text-pitch-alignment\"),n.layout.get(\"text-keep-upright\"),o,s),r.map.showCollisionBoxes&&(Kr(e,r,n,i,n.paint.get(\"text-translate\"),n.paint.get(\"text-translate-anchor\"),!0),Kr(e,r,n,i,n.paint.get(\"icon-translate\"),n.paint.get(\"icon-translate-anchor\"),!1))}},circle:function(e,r,n,i){if(\"translucent\"===e.renderPass){var a=n.paint.get(\"circle-opacity\"),o=n.paint.get(\"circle-stroke-width\"),s=n.paint.get(\"circle-stroke-opacity\"),l=void 0!==n.layout.get(\"circle-sort-key\").constantOr(1);if(0!==a.constantOr(1)||0!==o.constantOr(1)&&0!==s.constantOr(1)){for(var c=e.context,u=c.gl,f=e.depthModeForSublayer(0,Mt.ReadOnly),h=At.disabled,p=e.colorModeForRenderPass(),d=[],m=0;m<i.length;m++){var g=i[m],v=r.getTile(g),y=v.getBucket(n);if(y){var x=y.programConfigurations.get(n.id),b={programConfiguration:x,program:e.useProgram(\"circle\",x),layoutVertexBuffer:y.layoutVertexBuffer,indexBuffer:y.indexBuffer,uniformValues:Lr(e,g,v,n)};if(l)for(var _=0,w=y.segments.get();_<w.length;_+=1){var T=w[_];d.push({segments:new t.SegmentVector([T]),sortKey:T.sortKey,state:b})}else d.push({segments:y.segments,sortKey:0,state:b})}}l&&d.sort((function(t,e){return t.sortKey-e.sortKey}));for(var k=0,M=d;k<M.length;k+=1){var A=M[k],S=A.state,E=S.programConfiguration,L=S.program,C=S.layoutVertexBuffer,P=S.indexBuffer,I=S.uniformValues,O=A.segments;L.draw(c,u.TRIANGLES,f,h,p,Et.disabled,I,n.id,C,P,O,n.paint,e.transform.zoom,E)}}}},heatmap:function(e,r,n,i){if(0!==n.paint.get(\"heatmap-opacity\"))if(\"offscreen\"===e.renderPass){var a=e.context,o=a.gl,s=At.disabled,l=new St([o.ONE,o.ONE],t.Color.transparent,[!0,!0,!0,!0]);!function(t,e,r){var n=t.gl;t.activeTexture.set(n.TEXTURE1),t.viewport.set([0,0,e.width/4,e.height/4]);var i=r.heatmapFbo;if(i)n.bindTexture(n.TEXTURE_2D,i.colorAttachment.get()),t.bindFramebuffer.set(i.framebuffer);else{var a=n.createTexture();n.bindTexture(n.TEXTURE_2D,a),n.texParameteri(n.TEXTURE_2D,n.TEXTURE_WRAP_S,n.CLAMP_TO_EDGE),n.texParameteri(n.TEXTURE_2D,n.TEXTURE_WRAP_T,n.CLAMP_TO_EDGE),n.texParameteri(n.TEXTURE_2D,n.TEXTURE_MIN_FILTER,n.LINEAR),n.texParameteri(n.TEXTURE_2D,n.TEXTURE_MAG_FILTER,n.LINEAR),i=r.heatmapFbo=t.createFramebuffer(e.width/4,e.height/4,!1),function(t,e,r,n){var i=t.gl,a=t.extRenderToTextureHalfFloat?t.extTextureHalfFloat.HALF_FLOAT_OES:i.UNSIGNED_BYTE;i.texImage2D(i.TEXTURE_2D,0,i.RGBA,e.width/4,e.height/4,0,i.RGBA,a,null),n.colorAttachment.set(r)}(t,e,a,i)}}(a,e,n),a.clear({color:t.Color.transparent});for(var c=0;c<i.length;c++){var u=i[c];if(!r.hasRenderableParent(u)){var f=r.getTile(u),h=f.getBucket(n);if(h){var p=h.programConfigurations.get(n.id),d=e.useProgram(\"heatmap\",p),m=e.transform.zoom;d.draw(a,o.TRIANGLES,Mt.disabled,s,l,Et.disabled,zr(u.posMatrix,f,m,n.paint.get(\"heatmap-intensity\")),n.id,h.layoutVertexBuffer,h.indexBuffer,h.segments,n.paint,e.transform.zoom,p)}}}a.viewport.set([0,0,e.width,e.height])}else\"translucent\"===e.renderPass&&(e.context.setColorMode(e.colorModeForRenderPass()),function(e,r){var n=e.context,i=n.gl,a=r.heatmapFbo;if(!a)return;n.activeTexture.set(i.TEXTURE0),i.bindTexture(i.TEXTURE_2D,a.colorAttachment.get()),n.activeTexture.set(i.TEXTURE1);var o=r.colorRampTexture;o||(o=r.colorRampTexture=new t.Texture(n,r.colorRamp,i.RGBA));o.bind(i.LINEAR,i.CLAMP_TO_EDGE),e.useProgram(\"heatmapTexture\").draw(n,i.TRIANGLES,Mt.disabled,At.disabled,e.colorModeForRenderPass(),Et.disabled,function(e,r,n,i){var a=t.create();t.ortho(a,0,e.width,e.height,0,0,1);var o=e.context.gl;return{u_matrix:a,u_world:[o.drawingBufferWidth,o.drawingBufferHeight],u_image:n,u_color_ramp:i,u_opacity:r.paint.get(\"heatmap-opacity\")}}(e,r,0,1),r.id,e.viewportBuffer,e.quadTriangleIndexBuffer,e.viewportSegments,r.paint,e.transform.zoom)}(e,n))},line:function(e,r,n,i){if(\"translucent\"===e.renderPass){var a=n.paint.get(\"line-opacity\"),o=n.paint.get(\"line-width\");if(0!==a.constantOr(1)&&0!==o.constantOr(1)){var s=e.depthModeForSublayer(0,Mt.ReadOnly),l=e.colorModeForRenderPass(),c=n.paint.get(\"line-dasharray\"),u=n.paint.get(\"line-pattern\"),f=u.constantOr(1),h=n.paint.get(\"line-gradient\"),p=n.getCrossfadeParameters(),d=f?\"linePattern\":c?\"lineSDF\":h?\"lineGradient\":\"line\",m=e.context,g=m.gl,v=!0;if(h){m.activeTexture.set(g.TEXTURE0);var y=n.gradientTexture;if(!n.gradient)return;y||(y=n.gradientTexture=new t.Texture(m,n.gradient,g.RGBA)),y.bind(g.LINEAR,g.CLAMP_TO_EDGE)}for(var x=0,b=i;x<b.length;x+=1){var _=b[x],w=r.getTile(_);if(!f||w.patternsLoaded()){var T=w.getBucket(n);if(T){var k=T.programConfigurations.get(n.id),M=e.context.program.get(),A=e.useProgram(d,k),S=v||A.program!==M,E=u.constantOr(null);if(E&&w.imageAtlas){var L=w.imageAtlas,C=L.patternPositions[E.to.toString()],P=L.patternPositions[E.from.toString()];C&&P&&k.setConstantPatternPositions(C,P)}var I=f?Br(e,w,n,p):c?Nr(e,w,n,c,p):h?Fr(e,w,n):Rr(e,w,n);f?(m.activeTexture.set(g.TEXTURE0),w.imageAtlasTexture.bind(g.LINEAR,g.CLAMP_TO_EDGE),k.updatePaintBuffers(p)):c&&(S||e.lineAtlas.dirty)&&(m.activeTexture.set(g.TEXTURE0),e.lineAtlas.bind(m)),A.draw(m,g.TRIANGLES,s,e.stencilModeForClipping(_),l,Et.disabled,I,n.id,T.layoutVertexBuffer,T.indexBuffer,T.segments,n.paint,e.transform.zoom,k),v=!1}}}}}},fill:function(e,r,n,i){var a=n.paint.get(\"fill-color\"),o=n.paint.get(\"fill-opacity\");if(0!==o.constantOr(1)){var s=e.colorModeForRenderPass(),l=n.paint.get(\"fill-pattern\"),c=e.opaquePassEnabledForLayer()&&!l.constantOr(1)&&1===a.constantOr(t.Color.transparent).a&&1===o.constantOr(0)?\"opaque\":\"translucent\";if(e.renderPass===c){var u=e.depthModeForSublayer(1,\"opaque\"===e.renderPass?Mt.ReadWrite:Mt.ReadOnly);an(e,r,n,i,u,s,!1)}if(\"translucent\"===e.renderPass&&n.paint.get(\"fill-antialias\")){var f=e.depthModeForSublayer(n.getPaintProperty(\"fill-outline-color\")?2:0,Mt.ReadOnly);an(e,r,n,i,f,s,!0)}}},\"fill-extrusion\":function(t,e,r,n){var i=r.paint.get(\"fill-extrusion-opacity\");if(0!==i&&\"translucent\"===t.renderPass){var a=new Mt(t.context.gl.LEQUAL,Mt.ReadWrite,t.depthRangeFor3D);if(1!==i||r.paint.get(\"fill-extrusion-pattern\").constantOr(1))on(t,e,r,n,a,At.disabled,St.disabled),on(t,e,r,n,a,t.stencilModeFor3D(),t.colorModeForRenderPass());else{var o=t.colorModeForRenderPass();on(t,e,r,n,a,At.disabled,o)}}},hillshade:function(t,e,r,n){if(\"offscreen\"===t.renderPass||\"translucent\"===t.renderPass){for(var i=t.context,a=e.getSource().maxzoom,o=t.depthModeForSublayer(0,Mt.ReadOnly),s=t.colorModeForRenderPass(),l=\"translucent\"===t.renderPass?t.stencilConfigForOverlap(n):[{},n],c=l[0],u=0,f=l[1];u<f.length;u+=1){var h=f[u],p=e.getTile(h);p.needsHillshadePrepare&&\"offscreen\"===t.renderPass?ln(t,p,r,a,o,At.disabled,s):\"translucent\"===t.renderPass&&sn(t,p,r,o,c[h.overscaledZ],s)}i.viewport.set([0,0,t.width,t.height])}},raster:function(t,e,r,n){if(\"translucent\"===t.renderPass&&0!==r.paint.get(\"raster-opacity\")&&n.length)for(var i=t.context,a=i.gl,o=e.getSource(),s=t.useProgram(\"raster\"),l=t.colorModeForRenderPass(),c=o instanceof I?[{},n]:t.stencilConfigForOverlap(n),u=c[0],f=c[1],h=f[f.length-1].overscaledZ,p=!t.options.moving,d=0,m=f;d<m.length;d+=1){var g=m[d],v=t.depthModeForSublayer(g.overscaledZ-h,1===r.paint.get(\"raster-opacity\")?Mt.ReadWrite:Mt.ReadOnly,a.LESS),y=e.getTile(g),x=t.transform.calculatePosMatrix(g.toUnwrapped(),p);y.registerFadeDuration(r.paint.get(\"raster-fade-duration\"));var b=e.findLoadedParent(g,0),_=cn(y,b,e,r,t.transform),w=void 0,T=void 0,k=\"nearest\"===r.paint.get(\"raster-resampling\")?a.NEAREST:a.LINEAR;i.activeTexture.set(a.TEXTURE0),y.texture.bind(k,a.CLAMP_TO_EDGE,a.LINEAR_MIPMAP_NEAREST),i.activeTexture.set(a.TEXTURE1),b?(b.texture.bind(k,a.CLAMP_TO_EDGE,a.LINEAR_MIPMAP_NEAREST),w=Math.pow(2,b.tileID.overscaledZ-y.tileID.overscaledZ),T=[y.tileID.canonical.x*w%1,y.tileID.canonical.y*w%1]):y.texture.bind(k,a.CLAMP_TO_EDGE,a.LINEAR_MIPMAP_NEAREST);var M=Vr(x,T||[0,0],w||1,_,r);o instanceof I?s.draw(i,a.TRIANGLES,v,At.disabled,l,Et.disabled,M,r.id,o.boundsBuffer,t.quadTriangleIndexBuffer,o.boundsSegments):s.draw(i,a.TRIANGLES,v,u[g.overscaledZ],l,Et.disabled,M,r.id,t.rasterBoundsBuffer,t.quadTriangleIndexBuffer,t.rasterBoundsSegments)}},background:function(t,e,r){var n=r.paint.get(\"background-color\"),i=r.paint.get(\"background-opacity\");if(0!==i){var a=t.context,o=a.gl,s=t.transform,l=s.tileSize,c=r.paint.get(\"background-pattern\");if(!t.isPatternMissing(c)){var u=!c&&1===n.a&&1===i&&t.opaquePassEnabledForLayer()?\"opaque\":\"translucent\";if(t.renderPass===u){var f=At.disabled,h=t.depthModeForSublayer(0,\"opaque\"===u?Mt.ReadWrite:Mt.ReadOnly),p=t.colorModeForRenderPass(),d=t.useProgram(c?\"backgroundPattern\":\"background\"),m=s.coveringTiles({tileSize:l});c&&(a.activeTexture.set(o.TEXTURE0),t.imageManager.bind(t.context));for(var g=r.getCrossfadeParameters(),v=0,y=m;v<y.length;v+=1){var x=y[v],b=t.transform.calculatePosMatrix(x.toUnwrapped()),_=c?Zr(b,i,t,c,{tileID:x,tileSize:l},g):Xr(b,i,n);d.draw(a,o.TRIANGLES,h,f,p,Et.disabled,_,r.id,t.tileExtentBuffer,t.quadTriangleIndexBuffer,t.tileExtentSegments)}}}}},debug:function(t,e,r){for(var n=0;n<r.length;n++)xn(t,e,r[n])},custom:function(t,e,r){var n=t.context,i=r.implementation;if(\"offscreen\"===t.renderPass){var a=i.prerender;a&&(t.setCustomLayerDefaults(),n.setColorMode(t.colorModeForRenderPass()),a.call(i,n.gl,t.transform.customLayerMatrix()),n.setDirty(),t.setBaseState())}else if(\"translucent\"===t.renderPass){t.setCustomLayerDefaults(),n.setColorMode(t.colorModeForRenderPass()),n.setStencilMode(At.disabled);var o=\"3d\"===i.renderingMode?new Mt(t.context.gl.LEQUAL,Mt.ReadWrite,t.depthRangeFor3D):t.depthModeForSublayer(0,Mt.ReadOnly);n.setDepthMode(o),i.render(n.gl,t.transform.customLayerMatrix()),n.setDirty(),t.setBaseState(),n.bindFramebuffer.set(null)}}},_n=function(t,e){this.context=new Lt(t),this.transform=e,this._tileTextures={},this.setup(),this.numSublayers=Ct.maxUnderzooming+Ct.maxOverzooming+1,this.depthEpsilon=1/Math.pow(2,16),this.crossTileSymbolIndex=new Ne,this.gpuTimers={}};_n.prototype.resize=function(e,r){if(this.width=e*t.browser.devicePixelRatio,this.height=r*t.browser.devicePixelRatio,this.context.viewport.set([0,0,this.width,this.height]),this.style)for(var n=0,i=this.style._order;n<i.length;n+=1){var a=i[n];this.style._layers[a].resize()}},_n.prototype.setup=function(){var e=this.context,r=new t.StructArrayLayout2i4;r.emplaceBack(0,0),r.emplaceBack(t.EXTENT,0),r.emplaceBack(0,t.EXTENT),r.emplaceBack(t.EXTENT,t.EXTENT),this.tileExtentBuffer=e.createVertexBuffer(r,Ge.members),this.tileExtentSegments=t.SegmentVector.simpleSegment(0,0,4,2);var n=new t.StructArrayLayout2i4;n.emplaceBack(0,0),n.emplaceBack(t.EXTENT,0),n.emplaceBack(0,t.EXTENT),n.emplaceBack(t.EXTENT,t.EXTENT),this.debugBuffer=e.createVertexBuffer(n,Ge.members),this.debugSegments=t.SegmentVector.simpleSegment(0,0,4,5);var i=new t.StructArrayLayout4i8;i.emplaceBack(0,0,0,0),i.emplaceBack(t.EXTENT,0,t.EXTENT,0),i.emplaceBack(0,t.EXTENT,0,t.EXTENT),i.emplaceBack(t.EXTENT,t.EXTENT,t.EXTENT,t.EXTENT),this.rasterBoundsBuffer=e.createVertexBuffer(i,P.members),this.rasterBoundsSegments=t.SegmentVector.simpleSegment(0,0,4,2);var a=new t.StructArrayLayout2i4;a.emplaceBack(0,0),a.emplaceBack(1,0),a.emplaceBack(0,1),a.emplaceBack(1,1),this.viewportBuffer=e.createVertexBuffer(a,Ge.members),this.viewportSegments=t.SegmentVector.simpleSegment(0,0,4,2);var o=new t.StructArrayLayout1ui2;o.emplaceBack(0),o.emplaceBack(1),o.emplaceBack(3),o.emplaceBack(2),o.emplaceBack(0),this.tileBorderIndexBuffer=e.createIndexBuffer(o);var s=new t.StructArrayLayout3ui6;s.emplaceBack(0,1,2),s.emplaceBack(2,1,3),this.quadTriangleIndexBuffer=e.createIndexBuffer(s),this.emptyTexture=new t.Texture(e,{width:1,height:1,data:new Uint8Array([0,0,0,0])},e.gl.RGBA);var l=this.context.gl;this.stencilClearMode=new At({func:l.ALWAYS,mask:0},0,255,l.ZERO,l.ZERO,l.ZERO)},_n.prototype.clearStencil=function(){var e=this.context,r=e.gl;this.nextStencilID=1,this.currentStencilSource=void 0;var n=t.create();t.ortho(n,0,this.width,this.height,0,0,1),t.scale(n,n,[r.drawingBufferWidth,r.drawingBufferHeight,0]),this.useProgram(\"clippingMask\").draw(e,r.TRIANGLES,Mt.disabled,this.stencilClearMode,St.disabled,Et.disabled,Or(n),\"$clipping\",this.viewportBuffer,this.quadTriangleIndexBuffer,this.viewportSegments)},_n.prototype._renderTileClippingMasks=function(t,e){if(this.currentStencilSource!==t.source&&t.isTileClipped()&&e&&e.length){this.currentStencilSource=t.source;var r=this.context,n=r.gl;this.nextStencilID+e.length>256&&this.clearStencil(),r.setColorMode(St.disabled),r.setDepthMode(Mt.disabled);var i=this.useProgram(\"clippingMask\");this._tileClippingMaskIDs={};for(var a=0,o=e;a<o.length;a+=1){var s=o[a],l=this._tileClippingMaskIDs[s.key]=this.nextStencilID++;i.draw(r,n.TRIANGLES,Mt.disabled,new At({func:n.ALWAYS,mask:0},l,255,n.KEEP,n.KEEP,n.REPLACE),St.disabled,Et.disabled,Or(s.posMatrix),\"$clipping\",this.tileExtentBuffer,this.quadTriangleIndexBuffer,this.tileExtentSegments)}}},_n.prototype.stencilModeFor3D=function(){this.currentStencilSource=void 0,this.nextStencilID+1>256&&this.clearStencil();var t=this.nextStencilID++,e=this.context.gl;return new At({func:e.NOTEQUAL,mask:255},t,255,e.KEEP,e.KEEP,e.REPLACE)},_n.prototype.stencilModeForClipping=function(t){var e=this.context.gl;return new At({func:e.EQUAL,mask:255},this._tileClippingMaskIDs[t.key],0,e.KEEP,e.KEEP,e.REPLACE)},_n.prototype.stencilConfigForOverlap=function(t){var e,r=this.context.gl,n=t.sort((function(t,e){return e.overscaledZ-t.overscaledZ})),i=n[n.length-1].overscaledZ,a=n[0].overscaledZ-i+1;if(a>1){this.currentStencilSource=void 0,this.nextStencilID+a>256&&this.clearStencil();for(var o={},s=0;s<a;s++)o[s+i]=new At({func:r.GEQUAL,mask:255},s+this.nextStencilID,255,r.KEEP,r.KEEP,r.REPLACE);return this.nextStencilID+=a,[o,n]}return[(e={},e[i]=At.disabled,e),n]},_n.prototype.colorModeForRenderPass=function(){var e=this.context.gl;if(this._showOverdrawInspector){return new St([e.CONSTANT_COLOR,e.ONE],new t.Color(1/8,1/8,1/8,0),[!0,!0,!0,!0])}return\"opaque\"===this.renderPass?St.unblended:St.alphaBlended},_n.prototype.depthModeForSublayer=function(t,e,r){if(!this.opaquePassEnabledForLayer())return Mt.disabled;var n=1-((1+this.currentLayer)*this.numSublayers+t)*this.depthEpsilon;return new Mt(r||this.context.gl.LEQUAL,e,[n,n])},_n.prototype.opaquePassEnabledForLayer=function(){return this.currentLayer<this.opaquePassCutoff},_n.prototype.render=function(e,r){var n=this;this.style=e,this.options=r,this.lineAtlas=e.lineAtlas,this.imageManager=e.imageManager,this.glyphManager=e.glyphManager,this.symbolFadeChange=e.placement.symbolFadeChange(t.browser.now()),this.imageManager.beginFrame();var i=this.style._order,a=this.style.sourceCaches;for(var o in a){var s=a[o];s.used&&s.prepare(this.context)}var l,c,u={},f={},h={};for(var p in a){var d=a[p];u[p]=d.getVisibleCoordinates(),f[p]=u[p].slice().reverse(),h[p]=d.getVisibleCoordinates(!0).reverse()}this.opaquePassCutoff=1/0;for(var m=0;m<i.length;m++){var g=i[m];if(this.style._layers[g].is3D()){this.opaquePassCutoff=m;break}}this.renderPass=\"offscreen\";for(var v=0,y=i;v<y.length;v+=1){var x=y[v],b=this.style._layers[x];if(b.hasOffscreenPass()&&!b.isHidden(this.transform.zoom)){var _=f[b.source];(\"custom\"===b.type||_.length)&&this.renderLayer(this,a[b.source],b,_)}}for(this.context.bindFramebuffer.set(null),this.context.clear({color:r.showOverdrawInspector?t.Color.black:t.Color.transparent,depth:1}),this.clearStencil(),this._showOverdrawInspector=r.showOverdrawInspector,this.depthRangeFor3D=[0,1-(e._order.length+2)*this.numSublayers*this.depthEpsilon],this.renderPass=\"opaque\",this.currentLayer=i.length-1;this.currentLayer>=0;this.currentLayer--){var w=this.style._layers[i[this.currentLayer]],T=a[w.source],k=u[w.source];this._renderTileClippingMasks(w,k),this.renderLayer(this,T,w,k)}for(this.renderPass=\"translucent\",this.currentLayer=0;this.currentLayer<i.length;this.currentLayer++){var M=this.style._layers[i[this.currentLayer]],A=a[M.source],S=(\"symbol\"===M.type?h:f)[M.source];this._renderTileClippingMasks(M,u[M.source]),this.renderLayer(this,A,M,S)}this.options.showTileBoundaries&&(t.values(this.style._layers).forEach((function(t){t.source&&!t.isHidden(n.transform.zoom)&&(t.source!==(c&&c.id)&&(c=n.style.sourceCaches[t.source]),(!l||l.getSource().maxzoom<c.getSource().maxzoom)&&(l=c))})),l&&bn.debug(this,l,l.getVisibleCoordinates()));this.options.showPadding&&mn(this),this.context.setDefault()},_n.prototype.renderLayer=function(t,e,r,n){r.isHidden(this.transform.zoom)||(\"background\"===r.type||\"custom\"===r.type||n.length)&&(this.id=r.id,this.gpuTimingStart(r),bn[r.type](t,e,r,n,this.style.placement.variableOffsets),this.gpuTimingEnd())},_n.prototype.gpuTimingStart=function(t){if(this.options.gpuTiming){var e=this.context.extTimerQuery,r=this.gpuTimers[t.id];r||(r=this.gpuTimers[t.id]={calls:0,cpuTime:0,query:e.createQueryEXT()}),r.calls++,e.beginQueryEXT(e.TIME_ELAPSED_EXT,r.query)}},_n.prototype.gpuTimingEnd=function(){if(this.options.gpuTiming){var t=this.context.extTimerQuery;t.endQueryEXT(t.TIME_ELAPSED_EXT)}},_n.prototype.collectGpuTimers=function(){var t=this.gpuTimers;return this.gpuTimers={},t},_n.prototype.queryGpuTimers=function(t){var e={};for(var r in t){var n=t[r],i=this.context.extTimerQuery,a=i.getQueryObjectEXT(n.query,i.QUERY_RESULT_EXT)/1e6;i.deleteQueryEXT(n.query),e[r]=a}return e},_n.prototype.translatePosMatrix=function(e,r,n,i,a){if(!n[0]&&!n[1])return e;var o=a?\"map\"===i?this.transform.angle:0:\"viewport\"===i?-this.transform.angle:0;if(o){var s=Math.sin(o),l=Math.cos(o);n=[n[0]*l-n[1]*s,n[0]*s+n[1]*l]}var c=[a?n[0]:pe(r,n[0],this.transform.zoom),a?n[1]:pe(r,n[1],this.transform.zoom),0],u=new Float32Array(16);return t.translate(u,e,c),u},_n.prototype.saveTileTexture=function(t){var e=this._tileTextures[t.size[0]];e?e.push(t):this._tileTextures[t.size[0]]=[t]},_n.prototype.getTileTexture=function(t){var e=this._tileTextures[t];return e&&e.length>0?e.pop():null},_n.prototype.isPatternMissing=function(t){if(!t)return!1;if(!t.from||!t.to)return!0;var e=this.imageManager.getPattern(t.from.toString()),r=this.imageManager.getPattern(t.to.toString());return!e||!r},_n.prototype.useProgram=function(t,e){this.cache=this.cache||{};var r=\"\"+t+(e?e.cacheKey:\"\")+(this._showOverdrawInspector?\"/overdraw\":\"\");return this.cache[r]||(this.cache[r]=new _r(this.context,xr[t],e,Jr[t],this._showOverdrawInspector)),this.cache[r]},_n.prototype.setCustomLayerDefaults=function(){this.context.unbindVAO(),this.context.cullFace.setDefault(),this.context.activeTexture.setDefault(),this.context.pixelStoreUnpack.setDefault(),this.context.pixelStoreUnpackPremultiplyAlpha.setDefault(),this.context.pixelStoreUnpackFlipY.setDefault()},_n.prototype.setBaseState=function(){var t=this.context.gl;this.context.cullFace.set(!1),this.context.viewport.set([0,0,this.width,this.height]),this.context.blendEquation.set(t.FUNC_ADD)},_n.prototype.initDebugOverlayCanvas=function(){if(null==this.debugOverlayCanvas){this.debugOverlayCanvas=t.window.document.createElement(\"canvas\"),this.debugOverlayCanvas.width=512,this.debugOverlayCanvas.height=512;var e=this.context.gl;this.debugOverlayTexture=new t.Texture(this.context,this.debugOverlayCanvas,e.RGBA)}},_n.prototype.destroy=function(){this.emptyTexture.destroy(),this.debugOverlayTexture&&this.debugOverlayTexture.destroy()};var wn=function(t,e){this.points=t,this.planes=e};wn.fromInvProjectionMatrix=function(e,r,n){var i=Math.pow(2,n),a=[[-1,1,-1,1],[1,1,-1,1],[1,-1,-1,1],[-1,-1,-1,1],[-1,1,1,1],[1,1,1,1],[1,-1,1,1],[-1,-1,1,1]].map((function(r){return t.transformMat4([],r,e)})).map((function(e){return t.scale$1([],e,1/e[3]/r*i)})),o=[[0,1,2],[6,5,4],[0,3,7],[2,1,5],[3,2,6],[0,4,5]].map((function(e){var r=t.sub([],a[e[0]],a[e[1]]),n=t.sub([],a[e[2]],a[e[1]]),i=t.normalize([],t.cross([],r,n)),o=-t.dot(i,a[e[1]]);return i.concat(o)}));return new wn(a,o)};var Tn=function(e,r){this.min=e,this.max=r,this.center=t.scale$2([],t.add([],this.min,this.max),.5)};Tn.prototype.quadrant=function(e){for(var r=[e%2==0,e<2],n=t.clone$2(this.min),i=t.clone$2(this.max),a=0;a<r.length;a++)n[a]=r[a]?this.min[a]:this.center[a],i[a]=r[a]?this.center[a]:this.max[a];return i[2]=this.max[2],new Tn(n,i)},Tn.prototype.distanceX=function(t){return Math.max(Math.min(this.max[0],t[0]),this.min[0])-t[0]},Tn.prototype.distanceY=function(t){return Math.max(Math.min(this.max[1],t[1]),this.min[1])-t[1]},Tn.prototype.intersects=function(e){for(var r=[[this.min[0],this.min[1],0,1],[this.max[0],this.min[1],0,1],[this.max[0],this.max[1],0,1],[this.min[0],this.max[1],0,1]],n=!0,i=0;i<e.planes.length;i++){for(var a=e.planes[i],o=0,s=0;s<r.length;s++)o+=t.dot$1(a,r[s])>=0;if(0===o)return 0;o!==r.length&&(n=!1)}if(n)return 2;for(var l=0;l<3;l++){for(var c=Number.MAX_VALUE,u=-Number.MAX_VALUE,f=0;f<e.points.length;f++){var h=e.points[f][l]-this.min[l];c=Math.min(c,h),u=Math.max(u,h)}if(u<0||c>this.max[l]-this.min[l])return 0}return 1};var kn=function(t,e,r,n){if(void 0===t&&(t=0),void 0===e&&(e=0),void 0===r&&(r=0),void 0===n&&(n=0),isNaN(t)||t<0||isNaN(e)||e<0||isNaN(r)||r<0||isNaN(n)||n<0)throw new Error(\"Invalid value for edge-insets, top, bottom, left and right must all be numbers\");this.top=t,this.bottom=e,this.left=r,this.right=n};kn.prototype.interpolate=function(e,r,n){return null!=r.top&&null!=e.top&&(this.top=t.number(e.top,r.top,n)),null!=r.bottom&&null!=e.bottom&&(this.bottom=t.number(e.bottom,r.bottom,n)),null!=r.left&&null!=e.left&&(this.left=t.number(e.left,r.left,n)),null!=r.right&&null!=e.right&&(this.right=t.number(e.right,r.right,n)),this},kn.prototype.getCenter=function(e,r){var n=t.clamp((this.left+e-this.right)/2,0,e),i=t.clamp((this.top+r-this.bottom)/2,0,r);return new t.Point(n,i)},kn.prototype.equals=function(t){return this.top===t.top&&this.bottom===t.bottom&&this.left===t.left&&this.right===t.right},kn.prototype.clone=function(){return new kn(this.top,this.bottom,this.left,this.right)},kn.prototype.toJSON=function(){return{top:this.top,bottom:this.bottom,left:this.left,right:this.right}};var Mn=function(e,r,n,i,a){this.tileSize=512,this.maxValidLatitude=85.051129,this._renderWorldCopies=void 0===a||a,this._minZoom=e||0,this._maxZoom=r||22,this._minPitch=null==n?0:n,this._maxPitch=null==i?60:i,this.setMaxBounds(),this.width=0,this.height=0,this._center=new t.LngLat(0,0),this.zoom=0,this.angle=0,this._fov=.6435011087932844,this._pitch=0,this._unmodified=!0,this._edgeInsets=new kn,this._posMatrixCache={},this._alignedPosMatrixCache={}},An={minZoom:{configurable:!0},maxZoom:{configurable:!0},minPitch:{configurable:!0},maxPitch:{configurable:!0},renderWorldCopies:{configurable:!0},worldSize:{configurable:!0},centerOffset:{configurable:!0},size:{configurable:!0},bearing:{configurable:!0},pitch:{configurable:!0},fov:{configurable:!0},zoom:{configurable:!0},center:{configurable:!0},padding:{configurable:!0},centerPoint:{configurable:!0},unmodified:{configurable:!0},point:{configurable:!0}};Mn.prototype.clone=function(){var t=new Mn(this._minZoom,this._maxZoom,this._minPitch,this.maxPitch,this._renderWorldCopies);return t.tileSize=this.tileSize,t.latRange=this.latRange,t.width=this.width,t.height=this.height,t._center=this._center,t.zoom=this.zoom,t.angle=this.angle,t._fov=this._fov,t._pitch=this._pitch,t._unmodified=this._unmodified,t._edgeInsets=this._edgeInsets.clone(),t._calcMatrices(),t},An.minZoom.get=function(){return this._minZoom},An.minZoom.set=function(t){this._minZoom!==t&&(this._minZoom=t,this.zoom=Math.max(this.zoom,t))},An.maxZoom.get=function(){return this._maxZoom},An.maxZoom.set=function(t){this._maxZoom!==t&&(this._maxZoom=t,this.zoom=Math.min(this.zoom,t))},An.minPitch.get=function(){return this._minPitch},An.minPitch.set=function(t){this._minPitch!==t&&(this._minPitch=t,this.pitch=Math.max(this.pitch,t))},An.maxPitch.get=function(){return this._maxPitch},An.maxPitch.set=function(t){this._maxPitch!==t&&(this._maxPitch=t,this.pitch=Math.min(this.pitch,t))},An.renderWorldCopies.get=function(){return this._renderWorldCopies},An.renderWorldCopies.set=function(t){void 0===t?t=!0:null===t&&(t=!1),this._renderWorldCopies=t},An.worldSize.get=function(){return this.tileSize*this.scale},An.centerOffset.get=function(){return this.centerPoint._sub(this.size._div(2))},An.size.get=function(){return new t.Point(this.width,this.height)},An.bearing.get=function(){return-this.angle/Math.PI*180},An.bearing.set=function(e){var r=-t.wrap(e,-180,180)*Math.PI/180;this.angle!==r&&(this._unmodified=!1,this.angle=r,this._calcMatrices(),this.rotationMatrix=t.create$2(),t.rotate(this.rotationMatrix,this.rotationMatrix,this.angle))},An.pitch.get=function(){return this._pitch/Math.PI*180},An.pitch.set=function(e){var r=t.clamp(e,this.minPitch,this.maxPitch)/180*Math.PI;this._pitch!==r&&(this._unmodified=!1,this._pitch=r,this._calcMatrices())},An.fov.get=function(){return this._fov/Math.PI*180},An.fov.set=function(t){t=Math.max(.01,Math.min(60,t)),this._fov!==t&&(this._unmodified=!1,this._fov=t/180*Math.PI,this._calcMatrices())},An.zoom.get=function(){return this._zoom},An.zoom.set=function(t){var e=Math.min(Math.max(t,this.minZoom),this.maxZoom);this._zoom!==e&&(this._unmodified=!1,this._zoom=e,this.scale=this.zoomScale(e),this.tileZoom=Math.floor(e),this.zoomFraction=e-this.tileZoom,this._constrain(),this._calcMatrices())},An.center.get=function(){return this._center},An.center.set=function(t){t.lat===this._center.lat&&t.lng===this._center.lng||(this._unmodified=!1,this._center=t,this._constrain(),this._calcMatrices())},An.padding.get=function(){return this._edgeInsets.toJSON()},An.padding.set=function(t){this._edgeInsets.equals(t)||(this._unmodified=!1,this._edgeInsets.interpolate(this._edgeInsets,t,1),this._calcMatrices())},An.centerPoint.get=function(){return this._edgeInsets.getCenter(this.width,this.height)},Mn.prototype.isPaddingEqual=function(t){return this._edgeInsets.equals(t)},Mn.prototype.interpolatePadding=function(t,e,r){this._unmodified=!1,this._edgeInsets.interpolate(t,e,r),this._constrain(),this._calcMatrices()},Mn.prototype.coveringZoomLevel=function(t){var e=(t.roundZoom?Math.round:Math.floor)(this.zoom+this.scaleZoom(this.tileSize/t.tileSize));return Math.max(0,e)},Mn.prototype.getVisibleUnwrappedCoordinates=function(e){var r=[new t.UnwrappedTileID(0,e)];if(this._renderWorldCopies)for(var n=this.pointCoordinate(new t.Point(0,0)),i=this.pointCoordinate(new t.Point(this.width,0)),a=this.pointCoordinate(new t.Point(this.width,this.height)),o=this.pointCoordinate(new t.Point(0,this.height)),s=Math.floor(Math.min(n.x,i.x,a.x,o.x)),l=Math.floor(Math.max(n.x,i.x,a.x,o.x)),c=s-1;c<=l+1;c++)0!==c&&r.push(new t.UnwrappedTileID(c,e));return r},Mn.prototype.coveringTiles=function(e){var r=this.coveringZoomLevel(e),n=r;if(void 0!==e.minzoom&&r<e.minzoom)return[];void 0!==e.maxzoom&&r>e.maxzoom&&(r=e.maxzoom);var i=t.MercatorCoordinate.fromLngLat(this.center),a=Math.pow(2,r),o=[a*i.x,a*i.y,0],s=wn.fromInvProjectionMatrix(this.invProjMatrix,this.worldSize,r),l=e.minzoom||0;this.pitch<=60&&this._edgeInsets.top<.1&&(l=r);var c=function(t){return{aabb:new Tn([t*a,0,0],[(t+1)*a,a,0]),zoom:0,x:0,y:0,wrap:t,fullyVisible:!1}},u=[],f=[],h=r,p=e.reparseOverscaled?n:r;if(this._renderWorldCopies)for(var d=1;d<=3;d++)u.push(c(-d)),u.push(c(d));for(u.push(c(0));u.length>0;){var m=u.pop(),g=m.x,v=m.y,y=m.fullyVisible;if(!y){var x=m.aabb.intersects(s);if(0===x)continue;y=2===x}var b=m.aabb.distanceX(o),_=m.aabb.distanceY(o),w=Math.max(Math.abs(b),Math.abs(_)),T=3+(1<<h-m.zoom)-2;if(m.zoom===h||w>T&&m.zoom>=l)f.push({tileID:new t.OverscaledTileID(m.zoom===h?p:m.zoom,m.wrap,m.zoom,g,v),distanceSq:t.sqrLen([o[0]-.5-g,o[1]-.5-v])});else for(var k=0;k<4;k++){var M=(g<<1)+k%2,A=(v<<1)+(k>>1);u.push({aabb:m.aabb.quadrant(k),zoom:m.zoom+1,x:M,y:A,wrap:m.wrap,fullyVisible:y})}}return f.sort((function(t,e){return t.distanceSq-e.distanceSq})).map((function(t){return t.tileID}))},Mn.prototype.resize=function(t,e){this.width=t,this.height=e,this.pixelsToGLUnits=[2/t,-2/e],this._constrain(),this._calcMatrices()},An.unmodified.get=function(){return this._unmodified},Mn.prototype.zoomScale=function(t){return Math.pow(2,t)},Mn.prototype.scaleZoom=function(t){return Math.log(t)/Math.LN2},Mn.prototype.project=function(e){var r=t.clamp(e.lat,-this.maxValidLatitude,this.maxValidLatitude);return new t.Point(t.mercatorXfromLng(e.lng)*this.worldSize,t.mercatorYfromLat(r)*this.worldSize)},Mn.prototype.unproject=function(e){return new t.MercatorCoordinate(e.x/this.worldSize,e.y/this.worldSize).toLngLat()},An.point.get=function(){return this.project(this.center)},Mn.prototype.setLocationAtPoint=function(e,r){var n=this.pointCoordinate(r),i=this.pointCoordinate(this.centerPoint),a=this.locationCoordinate(e),o=new t.MercatorCoordinate(a.x-(n.x-i.x),a.y-(n.y-i.y));this.center=this.coordinateLocation(o),this._renderWorldCopies&&(this.center=this.center.wrap())},Mn.prototype.locationPoint=function(t){return this.coordinatePoint(this.locationCoordinate(t))},Mn.prototype.pointLocation=function(t){return this.coordinateLocation(this.pointCoordinate(t))},Mn.prototype.locationCoordinate=function(e){return t.MercatorCoordinate.fromLngLat(e)},Mn.prototype.coordinateLocation=function(t){return t.toLngLat()},Mn.prototype.pointCoordinate=function(e){var r=[e.x,e.y,0,1],n=[e.x,e.y,1,1];t.transformMat4(r,r,this.pixelMatrixInverse),t.transformMat4(n,n,this.pixelMatrixInverse);var i=r[3],a=n[3],o=r[0]/i,s=n[0]/a,l=r[1]/i,c=n[1]/a,u=r[2]/i,f=n[2]/a,h=u===f?0:(0-u)/(f-u);return new t.MercatorCoordinate(t.number(o,s,h)/this.worldSize,t.number(l,c,h)/this.worldSize)},Mn.prototype.coordinatePoint=function(e){var r=[e.x*this.worldSize,e.y*this.worldSize,0,1];return t.transformMat4(r,r,this.pixelMatrix),new t.Point(r[0]/r[3],r[1]/r[3])},Mn.prototype.getBounds=function(){return(new t.LngLatBounds).extend(this.pointLocation(new t.Point(0,0))).extend(this.pointLocation(new t.Point(this.width,0))).extend(this.pointLocation(new t.Point(this.width,this.height))).extend(this.pointLocation(new t.Point(0,this.height)))},Mn.prototype.getMaxBounds=function(){return this.latRange&&2===this.latRange.length&&this.lngRange&&2===this.lngRange.length?new t.LngLatBounds([this.lngRange[0],this.latRange[0]],[this.lngRange[1],this.latRange[1]]):null},Mn.prototype.setMaxBounds=function(t){t?(this.lngRange=[t.getWest(),t.getEast()],this.latRange=[t.getSouth(),t.getNorth()],this._constrain()):(this.lngRange=null,this.latRange=[-this.maxValidLatitude,this.maxValidLatitude])},Mn.prototype.calculatePosMatrix=function(e,r){void 0===r&&(r=!1);var n=e.key,i=r?this._alignedPosMatrixCache:this._posMatrixCache;if(i[n])return i[n];var a=e.canonical,o=this.worldSize/this.zoomScale(a.z),s=a.x+Math.pow(2,a.z)*e.wrap,l=t.identity(new Float64Array(16));return t.translate(l,l,[s*o,a.y*o,0]),t.scale(l,l,[o/t.EXTENT,o/t.EXTENT,1]),t.multiply(l,r?this.alignedProjMatrix:this.projMatrix,l),i[n]=new Float32Array(l),i[n]},Mn.prototype.customLayerMatrix=function(){return this.mercatorMatrix.slice()},Mn.prototype._constrain=function(){if(this.center&&this.width&&this.height&&!this._constraining){this._constraining=!0;var e,r,n,i,a=-90,o=90,s=-180,l=180,c=this.size,u=this._unmodified;if(this.latRange){var f=this.latRange;a=t.mercatorYfromLat(f[1])*this.worldSize,e=(o=t.mercatorYfromLat(f[0])*this.worldSize)-a<c.y?c.y/(o-a):0}if(this.lngRange){var h=this.lngRange;s=t.mercatorXfromLng(h[0])*this.worldSize,r=(l=t.mercatorXfromLng(h[1])*this.worldSize)-s<c.x?c.x/(l-s):0}var p=this.point,d=Math.max(r||0,e||0);if(d)return this.center=this.unproject(new t.Point(r?(l+s)/2:p.x,e?(o+a)/2:p.y)),this.zoom+=this.scaleZoom(d),this._unmodified=u,void(this._constraining=!1);if(this.latRange){var m=p.y,g=c.y/2;m-g<a&&(i=a+g),m+g>o&&(i=o-g)}if(this.lngRange){var v=p.x,y=c.x/2;v-y<s&&(n=s+y),v+y>l&&(n=l-y)}void 0===n&&void 0===i||(this.center=this.unproject(new t.Point(void 0!==n?n:p.x,void 0!==i?i:p.y))),this._unmodified=u,this._constraining=!1}},Mn.prototype._calcMatrices=function(){if(this.height){var e=this._fov/2,r=this.centerOffset;this.cameraToCenterDistance=.5/Math.tan(e)*this.height;var n=Math.PI/2+this._pitch,i=this._fov*(.5+r.y/this.height),a=Math.sin(i)*this.cameraToCenterDistance/Math.sin(t.clamp(Math.PI-n-i,.01,Math.PI-.01)),o=this.point,s=o.x,l=o.y,c=1.01*(Math.cos(Math.PI/2-this._pitch)*a+this.cameraToCenterDistance),u=this.height/50,f=new Float64Array(16);t.perspective(f,this._fov,this.width/this.height,u,c),f[8]=2*-r.x/this.width,f[9]=2*r.y/this.height,t.scale(f,f,[1,-1,1]),t.translate(f,f,[0,0,-this.cameraToCenterDistance]),t.rotateX(f,f,this._pitch),t.rotateZ(f,f,this.angle),t.translate(f,f,[-s,-l,0]),this.mercatorMatrix=t.scale([],f,[this.worldSize,this.worldSize,this.worldSize]),t.scale(f,f,[1,1,t.mercatorZfromAltitude(1,this.center.lat)*this.worldSize,1]),this.projMatrix=f,this.invProjMatrix=t.invert([],this.projMatrix);var h=this.width%2/2,p=this.height%2/2,d=Math.cos(this.angle),m=Math.sin(this.angle),g=s-Math.round(s)+d*h+m*p,v=l-Math.round(l)+d*p+m*h,y=new Float64Array(f);if(t.translate(y,y,[g>.5?g-1:g,v>.5?v-1:v,0]),this.alignedProjMatrix=y,f=t.create(),t.scale(f,f,[this.width/2,-this.height/2,1]),t.translate(f,f,[1,-1,0]),this.labelPlaneMatrix=f,f=t.create(),t.scale(f,f,[1,-1,1]),t.translate(f,f,[-1,-1,0]),t.scale(f,f,[2/this.width,2/this.height,1]),this.glCoordMatrix=f,this.pixelMatrix=t.multiply(new Float64Array(16),this.labelPlaneMatrix,this.projMatrix),!(f=t.invert(new Float64Array(16),this.pixelMatrix)))throw new Error(\"failed to invert matrix\");this.pixelMatrixInverse=f,this._posMatrixCache={},this._alignedPosMatrixCache={}}},Mn.prototype.maxPitchScaleFactor=function(){if(!this.pixelMatrixInverse)return 1;var e=this.pointCoordinate(new t.Point(0,0)),r=[e.x*this.worldSize,e.y*this.worldSize,0,1];return t.transformMat4(r,r,this.pixelMatrix)[3]/this.cameraToCenterDistance},Mn.prototype.getCameraPoint=function(){var e=this._pitch,r=Math.tan(e)*(this.cameraToCenterDistance||1);return this.centerPoint.add(new t.Point(0,r))},Mn.prototype.getCameraQueryGeometry=function(e){var r=this.getCameraPoint();if(1===e.length)return[e[0],r];for(var n=r.x,i=r.y,a=r.x,o=r.y,s=0,l=e;s<l.length;s+=1){var c=l[s];n=Math.min(n,c.x),i=Math.min(i,c.y),a=Math.max(a,c.x),o=Math.max(o,c.y)}return[new t.Point(n,i),new t.Point(a,i),new t.Point(a,o),new t.Point(n,o),new t.Point(n,i)]},Object.defineProperties(Mn.prototype,An);var Sn=function(e){var r,n,i,a,o;this._hashName=e&&encodeURIComponent(e),t.bindAll([\"_getCurrentHash\",\"_onHashChange\",\"_updateHash\"],this),this._updateHash=(r=this._updateHashUnthrottled.bind(this),n=300,i=!1,a=null,o=function(){a=null,i&&(r(),a=setTimeout(o,n),i=!1)},function(){return i=!0,a||o(),a})};Sn.prototype.addTo=function(e){return this._map=e,t.window.addEventListener(\"hashchange\",this._onHashChange,!1),this._map.on(\"moveend\",this._updateHash),this},Sn.prototype.remove=function(){return t.window.removeEventListener(\"hashchange\",this._onHashChange,!1),this._map.off(\"moveend\",this._updateHash),clearTimeout(this._updateHash()),delete this._map,this},Sn.prototype.getHashString=function(e){var r=this._map.getCenter(),n=Math.round(100*this._map.getZoom())/100,i=Math.ceil((n*Math.LN2+Math.log(512/360/.5))/Math.LN10),a=Math.pow(10,i),o=Math.round(r.lng*a)/a,s=Math.round(r.lat*a)/a,l=this._map.getBearing(),c=this._map.getPitch(),u=\"\";if(u+=e?\"/\"+o+\"/\"+s+\"/\"+n:n+\"/\"+s+\"/\"+o,(l||c)&&(u+=\"/\"+Math.round(10*l)/10),c&&(u+=\"/\"+Math.round(c)),this._hashName){var f=this._hashName,h=!1,p=t.window.location.hash.slice(1).split(\"&\").map((function(t){var e=t.split(\"=\")[0];return e===f?(h=!0,e+\"=\"+u):t})).filter((function(t){return t}));return h||p.push(f+\"=\"+u),\"#\"+p.join(\"&\")}return\"#\"+u},Sn.prototype._getCurrentHash=function(){var e,r=this,n=t.window.location.hash.replace(\"#\",\"\");return this._hashName?(n.split(\"&\").map((function(t){return t.split(\"=\")})).forEach((function(t){t[0]===r._hashName&&(e=t)})),(e&&e[1]||\"\").split(\"/\")):n.split(\"/\")},Sn.prototype._onHashChange=function(){var t=this._getCurrentHash();if(t.length>=3&&!t.some((function(t){return isNaN(t)}))){var e=this._map.dragRotate.isEnabled()&&this._map.touchZoomRotate.isEnabled()?+(t[3]||0):this._map.getBearing();return this._map.jumpTo({center:[+t[2],+t[1]],zoom:+t[0],bearing:e,pitch:+(t[4]||0)}),!0}return!1},Sn.prototype._updateHashUnthrottled=function(){var e=this.getHashString();try{t.window.history.replaceState(t.window.history.state,\"\",e)}catch(t){}};var En={linearity:.3,easing:t.bezier(0,0,.3,1)},Ln=t.extend({deceleration:2500,maxSpeed:1400},En),Cn=t.extend({deceleration:20,maxSpeed:1400},En),Pn=t.extend({deceleration:1e3,maxSpeed:360},En),In=t.extend({deceleration:1e3,maxSpeed:90},En),On=function(t){this._map=t,this.clear()};function zn(t,e){(!t.duration||t.duration<e.duration)&&(t.duration=e.duration,t.easing=e.easing)}function Dn(e,r,n){var i=n.maxSpeed,a=n.linearity,o=n.deceleration,s=t.clamp(e*a/(r/1e3),-i,i),l=Math.abs(s)/(o*a);return{easing:n.easing,duration:1e3*l,amount:s*(l/2)}}On.prototype.clear=function(){this._inertiaBuffer=[]},On.prototype.record=function(e){this._drainInertiaBuffer(),this._inertiaBuffer.push({time:t.browser.now(),settings:e})},On.prototype._drainInertiaBuffer=function(){for(var e=this._inertiaBuffer,r=t.browser.now();e.length>0&&r-e[0].time>160;)e.shift()},On.prototype._onMoveEnd=function(e){if(this._drainInertiaBuffer(),!(this._inertiaBuffer.length<2)){for(var r={zoom:0,bearing:0,pitch:0,pan:new t.Point(0,0),pinchAround:void 0,around:void 0},n=0,i=this._inertiaBuffer;n<i.length;n+=1){var a=i[n].settings;r.zoom+=a.zoomDelta||0,r.bearing+=a.bearingDelta||0,r.pitch+=a.pitchDelta||0,a.panDelta&&r.pan._add(a.panDelta),a.around&&(r.around=a.around),a.pinchAround&&(r.pinchAround=a.pinchAround)}var o=this._inertiaBuffer[this._inertiaBuffer.length-1].time-this._inertiaBuffer[0].time,s={};if(r.pan.mag()){var l=Dn(r.pan.mag(),o,t.extend({},Ln,e||{}));s.offset=r.pan.mult(l.amount/r.pan.mag()),s.center=this._map.transform.center,zn(s,l)}if(r.zoom){var c=Dn(r.zoom,o,Cn);s.zoom=this._map.transform.zoom+c.amount,zn(s,c)}if(r.bearing){var u=Dn(r.bearing,o,Pn);s.bearing=this._map.transform.bearing+t.clamp(u.amount,-179,179),zn(s,u)}if(r.pitch){var f=Dn(r.pitch,o,In);s.pitch=this._map.transform.pitch+f.amount,zn(s,f)}if(s.zoom||s.bearing){var h=void 0===r.pinchAround?r.around:r.pinchAround;s.around=h?this._map.unproject(h):this._map.getCenter()}return this.clear(),t.extend(s,{noMoveStart:!0})}};var Rn=function(e){function n(n,i,a,o){void 0===o&&(o={});var s=r.mousePos(i.getCanvasContainer(),a),l=i.unproject(s);e.call(this,n,t.extend({point:s,lngLat:l,originalEvent:a},o)),this._defaultPrevented=!1,this.target=i}e&&(n.__proto__=e),n.prototype=Object.create(e&&e.prototype),n.prototype.constructor=n;var i={defaultPrevented:{configurable:!0}};return n.prototype.preventDefault=function(){this._defaultPrevented=!0},i.defaultPrevented.get=function(){return this._defaultPrevented},Object.defineProperties(n.prototype,i),n}(t.Event),Fn=function(e){function n(n,i,a){var o=\"touchend\"===n?a.changedTouches:a.touches,s=r.touchPos(i.getCanvasContainer(),o),l=s.map((function(t){return i.unproject(t)})),c=s.reduce((function(t,e,r,n){return t.add(e.div(n.length))}),new t.Point(0,0)),u=i.unproject(c);e.call(this,n,{points:s,point:c,lngLats:l,lngLat:u,originalEvent:a}),this._defaultPrevented=!1}e&&(n.__proto__=e),n.prototype=Object.create(e&&e.prototype),n.prototype.constructor=n;var i={defaultPrevented:{configurable:!0}};return n.prototype.preventDefault=function(){this._defaultPrevented=!0},i.defaultPrevented.get=function(){return this._defaultPrevented},Object.defineProperties(n.prototype,i),n}(t.Event),Bn=function(t){function e(e,r,n){t.call(this,e,{originalEvent:n}),this._defaultPrevented=!1}t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e;var r={defaultPrevented:{configurable:!0}};return e.prototype.preventDefault=function(){this._defaultPrevented=!0},r.defaultPrevented.get=function(){return this._defaultPrevented},Object.defineProperties(e.prototype,r),e}(t.Event),Nn=function(t,e){this._map=t,this._clickTolerance=e.clickTolerance};Nn.prototype.reset=function(){delete this._mousedownPos},Nn.prototype.wheel=function(t){return this._firePreventable(new Bn(t.type,this._map,t))},Nn.prototype.mousedown=function(t,e){return this._mousedownPos=e,this._firePreventable(new Rn(t.type,this._map,t))},Nn.prototype.mouseup=function(t){this._map.fire(new Rn(t.type,this._map,t))},Nn.prototype.click=function(t,e){this._mousedownPos&&this._mousedownPos.dist(e)>=this._clickTolerance||this._map.fire(new Rn(t.type,this._map,t))},Nn.prototype.dblclick=function(t){return this._firePreventable(new Rn(t.type,this._map,t))},Nn.prototype.mouseover=function(t){this._map.fire(new Rn(t.type,this._map,t))},Nn.prototype.mouseout=function(t){this._map.fire(new Rn(t.type,this._map,t))},Nn.prototype.touchstart=function(t){return this._firePreventable(new Fn(t.type,this._map,t))},Nn.prototype.touchmove=function(t){this._map.fire(new Fn(t.type,this._map,t))},Nn.prototype.touchend=function(t){this._map.fire(new Fn(t.type,this._map,t))},Nn.prototype.touchcancel=function(t){this._map.fire(new Fn(t.type,this._map,t))},Nn.prototype._firePreventable=function(t){if(this._map.fire(t),t.defaultPrevented)return{}},Nn.prototype.isEnabled=function(){return!0},Nn.prototype.isActive=function(){return!1},Nn.prototype.enable=function(){},Nn.prototype.disable=function(){};var jn=function(t){this._map=t};jn.prototype.reset=function(){this._delayContextMenu=!1,delete this._contextMenuEvent},jn.prototype.mousemove=function(t){this._map.fire(new Rn(t.type,this._map,t))},jn.prototype.mousedown=function(){this._delayContextMenu=!0},jn.prototype.mouseup=function(){this._delayContextMenu=!1,this._contextMenuEvent&&(this._map.fire(new Rn(\"contextmenu\",this._map,this._contextMenuEvent)),delete this._contextMenuEvent)},jn.prototype.contextmenu=function(t){this._delayContextMenu?this._contextMenuEvent=t:this._map.fire(new Rn(t.type,this._map,t)),this._map.listens(\"contextmenu\")&&t.preventDefault()},jn.prototype.isEnabled=function(){return!0},jn.prototype.isActive=function(){return!1},jn.prototype.enable=function(){},jn.prototype.disable=function(){};var Un=function(t,e){this._map=t,this._el=t.getCanvasContainer(),this._container=t.getContainer(),this._clickTolerance=e.clickTolerance||1};function Vn(t,e){for(var r={},n=0;n<t.length;n++)r[t[n].identifier]=e[n];return r}Un.prototype.isEnabled=function(){return!!this._enabled},Un.prototype.isActive=function(){return!!this._active},Un.prototype.enable=function(){this.isEnabled()||(this._enabled=!0)},Un.prototype.disable=function(){this.isEnabled()&&(this._enabled=!1)},Un.prototype.mousedown=function(t,e){this.isEnabled()&&t.shiftKey&&0===t.button&&(r.disableDrag(),this._startPos=this._lastPos=e,this._active=!0)},Un.prototype.mousemoveWindow=function(t,e){if(this._active){var n=e;if(!(this._lastPos.equals(n)||!this._box&&n.dist(this._startPos)<this._clickTolerance)){var i=this._startPos;this._lastPos=n,this._box||(this._box=r.create(\"div\",\"mapboxgl-boxzoom\",this._container),this._container.classList.add(\"mapboxgl-crosshair\"),this._fireEvent(\"boxzoomstart\",t));var a=Math.min(i.x,n.x),o=Math.max(i.x,n.x),s=Math.min(i.y,n.y),l=Math.max(i.y,n.y);r.setTransform(this._box,\"translate(\"+a+\"px,\"+s+\"px)\"),this._box.style.width=o-a+\"px\",this._box.style.height=l-s+\"px\"}}},Un.prototype.mouseupWindow=function(e,n){var i=this;if(this._active&&0===e.button){var a=this._startPos,o=n;if(this.reset(),r.suppressClick(),a.x!==o.x||a.y!==o.y)return this._map.fire(new t.Event(\"boxzoomend\",{originalEvent:e})),{cameraAnimation:function(t){return t.fitScreenCoordinates(a,o,i._map.getBearing(),{linear:!0})}};this._fireEvent(\"boxzoomcancel\",e)}},Un.prototype.keydown=function(t){this._active&&27===t.keyCode&&(this.reset(),this._fireEvent(\"boxzoomcancel\",t))},Un.prototype.reset=function(){this._active=!1,this._container.classList.remove(\"mapboxgl-crosshair\"),this._box&&(r.remove(this._box),this._box=null),r.enableDrag(),delete this._startPos,delete this._lastPos},Un.prototype._fireEvent=function(e,r){return this._map.fire(new t.Event(e,{originalEvent:r}))};var qn=function(t){this.reset(),this.numTouches=t.numTouches};qn.prototype.reset=function(){delete this.centroid,delete this.startTime,delete this.touches,this.aborted=!1},qn.prototype.touchstart=function(e,r,n){(this.centroid||n.length>this.numTouches)&&(this.aborted=!0),this.aborted||(void 0===this.startTime&&(this.startTime=e.timeStamp),n.length===this.numTouches&&(this.centroid=function(e){for(var r=new t.Point(0,0),n=0,i=e;n<i.length;n+=1){var a=i[n];r._add(a)}return r.div(e.length)}(r),this.touches=Vn(n,r)))},qn.prototype.touchmove=function(t,e,r){if(!this.aborted&&this.centroid){var n=Vn(r,e);for(var i in this.touches){var a=this.touches[i],o=n[i];(!o||o.dist(a)>30)&&(this.aborted=!0)}}},qn.prototype.touchend=function(t,e,r){if((!this.centroid||t.timeStamp-this.startTime>500)&&(this.aborted=!0),0===r.length){var n=!this.aborted&&this.centroid;if(this.reset(),n)return n}};var Hn=function(t){this.singleTap=new qn(t),this.numTaps=t.numTaps,this.reset()};Hn.prototype.reset=function(){this.lastTime=1/0,delete this.lastTap,this.count=0,this.singleTap.reset()},Hn.prototype.touchstart=function(t,e,r){this.singleTap.touchstart(t,e,r)},Hn.prototype.touchmove=function(t,e,r){this.singleTap.touchmove(t,e,r)},Hn.prototype.touchend=function(t,e,r){var n=this.singleTap.touchend(t,e,r);if(n){var i=t.timeStamp-this.lastTime<500,a=!this.lastTap||this.lastTap.dist(n)<30;if(i&&a||this.reset(),this.count++,this.lastTime=t.timeStamp,this.lastTap=n,this.count===this.numTaps)return this.reset(),n}};var Gn=function(){this._zoomIn=new Hn({numTouches:1,numTaps:2}),this._zoomOut=new Hn({numTouches:2,numTaps:1}),this.reset()};Gn.prototype.reset=function(){this._active=!1,this._zoomIn.reset(),this._zoomOut.reset()},Gn.prototype.touchstart=function(t,e,r){this._zoomIn.touchstart(t,e,r),this._zoomOut.touchstart(t,e,r)},Gn.prototype.touchmove=function(t,e,r){this._zoomIn.touchmove(t,e,r),this._zoomOut.touchmove(t,e,r)},Gn.prototype.touchend=function(t,e,r){var n=this,i=this._zoomIn.touchend(t,e,r),a=this._zoomOut.touchend(t,e,r);return i?(this._active=!0,t.preventDefault(),setTimeout((function(){return n.reset()}),0),{cameraAnimation:function(e){return e.easeTo({duration:300,zoom:e.getZoom()+1,around:e.unproject(i)},{originalEvent:t})}}):a?(this._active=!0,t.preventDefault(),setTimeout((function(){return n.reset()}),0),{cameraAnimation:function(e){return e.easeTo({duration:300,zoom:e.getZoom()-1,around:e.unproject(a)},{originalEvent:t})}}):void 0},Gn.prototype.touchcancel=function(){this.reset()},Gn.prototype.enable=function(){this._enabled=!0},Gn.prototype.disable=function(){this._enabled=!1,this.reset()},Gn.prototype.isEnabled=function(){return this._enabled},Gn.prototype.isActive=function(){return this._active};var Yn=function(t){this.reset(),this._clickTolerance=t.clickTolerance||1};Yn.prototype.reset=function(){this._active=!1,this._moved=!1,delete this._lastPoint,delete this._eventButton},Yn.prototype._correctButton=function(t,e){return!1},Yn.prototype._move=function(t,e){return{}},Yn.prototype.mousedown=function(t,e){if(!this._lastPoint){var n=r.mouseButton(t);this._correctButton(t,n)&&(this._lastPoint=e,this._eventButton=n)}},Yn.prototype.mousemoveWindow=function(t,e){var r=this._lastPoint;if(r&&(t.preventDefault(),this._moved||!(e.dist(r)<this._clickTolerance)))return this._moved=!0,this._lastPoint=e,this._move(r,e)},Yn.prototype.mouseupWindow=function(t){r.mouseButton(t)===this._eventButton&&(this._moved&&r.suppressClick(),this.reset())},Yn.prototype.enable=function(){this._enabled=!0},Yn.prototype.disable=function(){this._enabled=!1,this.reset()},Yn.prototype.isEnabled=function(){return this._enabled},Yn.prototype.isActive=function(){return this._active};var Wn=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.mousedown=function(e,r){t.prototype.mousedown.call(this,e,r),this._lastPoint&&(this._active=!0)},e.prototype._correctButton=function(t,e){return 0===e&&!t.ctrlKey},e.prototype._move=function(t,e){return{around:e,panDelta:e.sub(t)}},e}(Yn),Xn=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._correctButton=function(t,e){return 0===e&&t.ctrlKey||2===e},e.prototype._move=function(t,e){var r=.8*(e.x-t.x);if(r)return this._active=!0,{bearingDelta:r}},e.prototype.contextmenu=function(t){t.preventDefault()},e}(Yn),Zn=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype._correctButton=function(t,e){return 0===e&&t.ctrlKey||2===e},e.prototype._move=function(t,e){var r=-.5*(e.y-t.y);if(r)return this._active=!0,{pitchDelta:r}},e.prototype.contextmenu=function(t){t.preventDefault()},e}(Yn),Jn=function(t){this._minTouches=1,this._clickTolerance=t.clickTolerance||1,this.reset()};Jn.prototype.reset=function(){this._active=!1,this._touches={},this._sum=new t.Point(0,0)},Jn.prototype.touchstart=function(t,e,r){return this._calculateTransform(t,e,r)},Jn.prototype.touchmove=function(t,e,r){if(this._active)return t.preventDefault(),this._calculateTransform(t,e,r)},Jn.prototype.touchend=function(t,e,r){this._calculateTransform(t,e,r),this._active&&r.length<this._minTouches&&this.reset()},Jn.prototype.touchcancel=function(){this.reset()},Jn.prototype._calculateTransform=function(e,r,n){n.length>0&&(this._active=!0);var i=Vn(n,r),a=new t.Point(0,0),o=new t.Point(0,0),s=0;for(var l in i){var c=i[l],u=this._touches[l];u&&(a._add(c),o._add(c.sub(u)),s++,i[l]=c)}if(this._touches=i,!(s<this._minTouches)&&o.mag()){var f=o.div(s);if(this._sum._add(f),!(this._sum.mag()<this._clickTolerance))return{around:a.div(s),panDelta:f}}},Jn.prototype.enable=function(){this._enabled=!0},Jn.prototype.disable=function(){this._enabled=!1,this.reset()},Jn.prototype.isEnabled=function(){return this._enabled},Jn.prototype.isActive=function(){return this._active};var Kn=function(){this.reset()};function Qn(t,e,r){for(var n=0;n<t.length;n++)if(t[n].identifier===r)return e[n]}Kn.prototype.reset=function(){this._active=!1,delete this._firstTwoTouches},Kn.prototype._start=function(t){},Kn.prototype._move=function(t,e,r){return{}},Kn.prototype.touchstart=function(t,e,r){this._firstTwoTouches||r.length<2||(this._firstTwoTouches=[r[0].identifier,r[1].identifier],this._start([e[0],e[1]]))},Kn.prototype.touchmove=function(t,e,r){if(this._firstTwoTouches){t.preventDefault();var n=this._firstTwoTouches,i=n[0],a=n[1],o=Qn(r,e,i),s=Qn(r,e,a);if(o&&s){var l=this._aroundCenter?null:o.add(s).div(2);return this._move([o,s],l,t)}}},Kn.prototype.touchend=function(t,e,n){if(this._firstTwoTouches){var i=this._firstTwoTouches,a=i[0],o=i[1],s=Qn(n,e,a),l=Qn(n,e,o);s&&l||(this._active&&r.suppressClick(),this.reset())}},Kn.prototype.touchcancel=function(){this.reset()},Kn.prototype.enable=function(t){this._enabled=!0,this._aroundCenter=!!t&&\"center\"===t.around},Kn.prototype.disable=function(){this._enabled=!1,this.reset()},Kn.prototype.isEnabled=function(){return this._enabled},Kn.prototype.isActive=function(){return this._active};function $n(t,e){return Math.log(t/e)/Math.LN2}var ti=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.reset=function(){t.prototype.reset.call(this),delete this._distance,delete this._startDistance},e.prototype._start=function(t){this._startDistance=this._distance=t[0].dist(t[1])},e.prototype._move=function(t,e){var r=this._distance;if(this._distance=t[0].dist(t[1]),this._active||!(Math.abs($n(this._distance,this._startDistance))<.1))return this._active=!0,{zoomDelta:$n(this._distance,r),pinchAround:e}},e}(Kn);function ei(t,e){return 180*t.angleWith(e)/Math.PI}var ri=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.reset=function(){t.prototype.reset.call(this),delete this._minDiameter,delete this._startVector,delete this._vector},e.prototype._start=function(t){this._startVector=this._vector=t[0].sub(t[1]),this._minDiameter=t[0].dist(t[1])},e.prototype._move=function(t,e){var r=this._vector;if(this._vector=t[0].sub(t[1]),this._active||!this._isBelowThreshold(this._vector))return this._active=!0,{bearingDelta:ei(this._vector,r),pinchAround:e}},e.prototype._isBelowThreshold=function(t){this._minDiameter=Math.min(this._minDiameter,t.mag());var e=25/(Math.PI*this._minDiameter)*360,r=ei(t,this._startVector);return Math.abs(r)<e},e}(Kn);function ni(t){return Math.abs(t.y)>Math.abs(t.x)}var ii=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e.prototype.reset=function(){t.prototype.reset.call(this),this._valid=void 0,delete this._firstMove,delete this._lastPoints},e.prototype._start=function(t){this._lastPoints=t,ni(t[0].sub(t[1]))&&(this._valid=!1)},e.prototype._move=function(t,e,r){var n=t[0].sub(this._lastPoints[0]),i=t[1].sub(this._lastPoints[1]);if(this._valid=this.gestureBeginsVertically(n,i,r.timeStamp),this._valid){this._lastPoints=t,this._active=!0;return{pitchDelta:-.5*((n.y+i.y)/2)}}},e.prototype.gestureBeginsVertically=function(t,e,r){if(void 0!==this._valid)return this._valid;var n=t.mag()>=2,i=e.mag()>=2;if(n||i){if(!n||!i)return void 0===this._firstMove&&(this._firstMove=r),r-this._firstMove<100&&void 0;var a=t.y>0==e.y>0;return ni(t)&&ni(e)&&a}},e}(Kn),ai={panStep:100,bearingStep:15,pitchStep:10},oi=function(){var t=ai;this._panStep=t.panStep,this._bearingStep=t.bearingStep,this._pitchStep=t.pitchStep};function si(t){return t*(2-t)}oi.prototype.reset=function(){this._active=!1},oi.prototype.keydown=function(t){var e=this;if(!(t.altKey||t.ctrlKey||t.metaKey)){var r=0,n=0,i=0,a=0,o=0;switch(t.keyCode){case 61:case 107:case 171:case 187:r=1;break;case 189:case 109:case 173:r=-1;break;case 37:t.shiftKey?n=-1:(t.preventDefault(),a=-1);break;case 39:t.shiftKey?n=1:(t.preventDefault(),a=1);break;case 38:t.shiftKey?i=1:(t.preventDefault(),o=-1);break;case 40:t.shiftKey?i=-1:(t.preventDefault(),o=1);break;default:return}return{cameraAnimation:function(s){var l=s.getZoom();s.easeTo({duration:300,easeId:\"keyboardHandler\",easing:si,zoom:r?Math.round(l)+r*(t.shiftKey?2:1):l,bearing:s.getBearing()+n*e._bearingStep,pitch:s.getPitch()+i*e._pitchStep,offset:[-a*e._panStep,-o*e._panStep],center:s.getCenter()},{originalEvent:t})}}}},oi.prototype.enable=function(){this._enabled=!0},oi.prototype.disable=function(){this._enabled=!1,this.reset()},oi.prototype.isEnabled=function(){return this._enabled},oi.prototype.isActive=function(){return this._active};var li=function(e,r){this._map=e,this._el=e.getCanvasContainer(),this._handler=r,this._delta=0,this._defaultZoomRate=.01,this._wheelZoomRate=1/450,t.bindAll([\"_onWheel\",\"_onTimeout\",\"_onScrollFrame\",\"_onScrollFinished\"],this)};li.prototype.setZoomRate=function(t){this._defaultZoomRate=t},li.prototype.setWheelZoomRate=function(t){this._wheelZoomRate=t},li.prototype.isEnabled=function(){return!!this._enabled},li.prototype.isActive=function(){return!!this._active||void 0!==this._finishTimeout},li.prototype.isZooming=function(){return!!this._zooming},li.prototype.enable=function(t){this.isEnabled()||(this._enabled=!0,this._aroundCenter=t&&\"center\"===t.around)},li.prototype.disable=function(){this.isEnabled()&&(this._enabled=!1)},li.prototype.wheel=function(e){if(this.isEnabled()){var r=e.deltaMode===t.window.WheelEvent.DOM_DELTA_LINE?40*e.deltaY:e.deltaY,n=t.browser.now(),i=n-(this._lastWheelEventTime||0);this._lastWheelEventTime=n,0!==r&&r%4.000244140625==0?this._type=\"wheel\":0!==r&&Math.abs(r)<4?this._type=\"trackpad\":i>400?(this._type=null,this._lastValue=r,this._timeout=setTimeout(this._onTimeout,40,e)):this._type||(this._type=Math.abs(i*r)<200?\"trackpad\":\"wheel\",this._timeout&&(clearTimeout(this._timeout),this._timeout=null,r+=this._lastValue)),e.shiftKey&&r&&(r/=4),this._type&&(this._lastWheelEvent=e,this._delta-=r,this._active||this._start(e)),e.preventDefault()}},li.prototype._onTimeout=function(t){this._type=\"wheel\",this._delta-=this._lastValue,this._active||this._start(t)},li.prototype._start=function(e){if(this._delta){this._frameId&&(this._frameId=null),this._active=!0,this.isZooming()||(this._zooming=!0),this._finishTimeout&&(clearTimeout(this._finishTimeout),delete this._finishTimeout);var n=r.mousePos(this._el,e);this._around=t.LngLat.convert(this._aroundCenter?this._map.getCenter():this._map.unproject(n)),this._aroundPoint=this._map.transform.locationPoint(this._around),this._frameId||(this._frameId=!0,this._handler._triggerRenderFrame())}},li.prototype.renderFrame=function(){return this._onScrollFrame()},li.prototype._onScrollFrame=function(){var e=this;if(this._frameId&&(this._frameId=null,this.isActive())){var r=this._map.transform;if(0!==this._delta){var n=\"wheel\"===this._type&&Math.abs(this._delta)>4.000244140625?this._wheelZoomRate:this._defaultZoomRate,i=2/(1+Math.exp(-Math.abs(this._delta*n)));this._delta<0&&0!==i&&(i=1/i);var a=\"number\"==typeof this._targetZoom?r.zoomScale(this._targetZoom):r.scale;this._targetZoom=Math.min(r.maxZoom,Math.max(r.minZoom,r.scaleZoom(a*i))),\"wheel\"===this._type&&(this._startZoom=r.zoom,this._easing=this._smoothOutEasing(200)),this._delta=0}var o,s=\"number\"==typeof this._targetZoom?this._targetZoom:r.zoom,l=this._startZoom,c=this._easing,u=!1;if(\"wheel\"===this._type&&l&&c){var f=Math.min((t.browser.now()-this._lastWheelEventTime)/200,1),h=c(f);o=t.number(l,s,h),f<1?this._frameId||(this._frameId=!0):u=!0}else o=s,u=!0;return this._active=!0,u&&(this._active=!1,this._finishTimeout=setTimeout((function(){e._zooming=!1,e._handler._triggerRenderFrame(),delete e._targetZoom,delete e._finishTimeout}),200)),{noInertia:!0,needsRenderFrame:!u,zoomDelta:o-r.zoom,around:this._aroundPoint,originalEvent:this._lastWheelEvent}}},li.prototype._smoothOutEasing=function(e){var r=t.ease;if(this._prevEase){var n=this._prevEase,i=(t.browser.now()-n.start)/n.duration,a=n.easing(i+.01)-n.easing(i),o=.27/Math.sqrt(a*a+1e-4)*.01,s=Math.sqrt(.0729-o*o);r=t.bezier(o,s,.25,1)}return this._prevEase={start:t.browser.now(),duration:e,easing:r},r},li.prototype.reset=function(){this._active=!1};var ci=function(t,e){this._clickZoom=t,this._tapZoom=e};ci.prototype.enable=function(){this._clickZoom.enable(),this._tapZoom.enable()},ci.prototype.disable=function(){this._clickZoom.disable(),this._tapZoom.disable()},ci.prototype.isEnabled=function(){return this._clickZoom.isEnabled()&&this._tapZoom.isEnabled()},ci.prototype.isActive=function(){return this._clickZoom.isActive()||this._tapZoom.isActive()};var ui=function(){this.reset()};ui.prototype.reset=function(){this._active=!1},ui.prototype.dblclick=function(t,e){return t.preventDefault(),{cameraAnimation:function(r){r.easeTo({duration:300,zoom:r.getZoom()+(t.shiftKey?-1:1),around:r.unproject(e)},{originalEvent:t})}}},ui.prototype.enable=function(){this._enabled=!0},ui.prototype.disable=function(){this._enabled=!1,this.reset()},ui.prototype.isEnabled=function(){return this._enabled},ui.prototype.isActive=function(){return this._active};var fi=function(){this._tap=new Hn({numTouches:1,numTaps:1}),this.reset()};fi.prototype.reset=function(){this._active=!1,delete this._swipePoint,delete this._swipeTouch,delete this._tapTime,this._tap.reset()},fi.prototype.touchstart=function(t,e,r){this._swipePoint||(this._tapTime&&t.timeStamp-this._tapTime>500&&this.reset(),this._tapTime?r.length>0&&(this._swipePoint=e[0],this._swipeTouch=r[0].identifier):this._tap.touchstart(t,e,r))},fi.prototype.touchmove=function(t,e,r){if(this._tapTime){if(this._swipePoint){if(r[0].identifier!==this._swipeTouch)return;var n=e[0],i=n.y-this._swipePoint.y;return this._swipePoint=n,t.preventDefault(),this._active=!0,{zoomDelta:i/128}}}else this._tap.touchmove(t,e,r)},fi.prototype.touchend=function(t,e,r){this._tapTime?this._swipePoint&&0===r.length&&this.reset():this._tap.touchend(t,e,r)&&(this._tapTime=t.timeStamp)},fi.prototype.touchcancel=function(){this.reset()},fi.prototype.enable=function(){this._enabled=!0},fi.prototype.disable=function(){this._enabled=!1,this.reset()},fi.prototype.isEnabled=function(){return this._enabled},fi.prototype.isActive=function(){return this._active};var hi=function(t,e,r){this._el=t,this._mousePan=e,this._touchPan=r};hi.prototype.enable=function(t){this._inertiaOptions=t||{},this._mousePan.enable(),this._touchPan.enable(),this._el.classList.add(\"mapboxgl-touch-drag-pan\")},hi.prototype.disable=function(){this._mousePan.disable(),this._touchPan.disable(),this._el.classList.remove(\"mapboxgl-touch-drag-pan\")},hi.prototype.isEnabled=function(){return this._mousePan.isEnabled()&&this._touchPan.isEnabled()},hi.prototype.isActive=function(){return this._mousePan.isActive()||this._touchPan.isActive()};var pi=function(t,e,r){this._pitchWithRotate=t.pitchWithRotate,this._mouseRotate=e,this._mousePitch=r};pi.prototype.enable=function(){this._mouseRotate.enable(),this._pitchWithRotate&&this._mousePitch.enable()},pi.prototype.disable=function(){this._mouseRotate.disable(),this._mousePitch.disable()},pi.prototype.isEnabled=function(){return this._mouseRotate.isEnabled()&&(!this._pitchWithRotate||this._mousePitch.isEnabled())},pi.prototype.isActive=function(){return this._mouseRotate.isActive()||this._mousePitch.isActive()};var di=function(t,e,r,n){this._el=t,this._touchZoom=e,this._touchRotate=r,this._tapDragZoom=n,this._rotationDisabled=!1,this._enabled=!0};di.prototype.enable=function(t){this._touchZoom.enable(t),this._rotationDisabled||this._touchRotate.enable(t),this._tapDragZoom.enable(),this._el.classList.add(\"mapboxgl-touch-zoom-rotate\")},di.prototype.disable=function(){this._touchZoom.disable(),this._touchRotate.disable(),this._tapDragZoom.disable(),this._el.classList.remove(\"mapboxgl-touch-zoom-rotate\")},di.prototype.isEnabled=function(){return this._touchZoom.isEnabled()&&(this._rotationDisabled||this._touchRotate.isEnabled())&&this._tapDragZoom.isEnabled()},di.prototype.isActive=function(){return this._touchZoom.isActive()||this._touchRotate.isActive()||this._tapDragZoom.isActive()},di.prototype.disableRotation=function(){this._rotationDisabled=!0,this._touchRotate.disable()},di.prototype.enableRotation=function(){this._rotationDisabled=!1,this._touchZoom.isEnabled()&&this._touchRotate.enable()};var mi=function(t){return t.zoom||t.drag||t.pitch||t.rotate},gi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),e.prototype=Object.create(t&&t.prototype),e.prototype.constructor=e,e}(t.Event);function vi(t){return t.panDelta&&t.panDelta.mag()||t.zoomDelta||t.bearingDelta||t.pitchDelta}var yi=function(e,n){this._map=e,this._el=this._map.getCanvasContainer(),this._handlers=[],this._handlersById={},this._changes=[],this._inertia=new On(e),this._bearingSnap=n.bearingSnap,this._previousActiveHandlers={},this._eventsInProgress={},this._addDefaultHandlers(n),t.bindAll([\"handleEvent\",\"handleWindowEvent\"],this);var i=this._el;this._listeners=[[i,\"touchstart\",{passive:!1}],[i,\"touchmove\",{passive:!1}],[i,\"touchend\",void 0],[i,\"touchcancel\",void 0],[i,\"mousedown\",void 0],[i,\"mousemove\",void 0],[i,\"mouseup\",void 0],[t.window.document,\"mousemove\",{capture:!0}],[t.window.document,\"mouseup\",void 0],[i,\"mouseover\",void 0],[i,\"mouseout\",void 0],[i,\"dblclick\",void 0],[i,\"click\",void 0],[i,\"keydown\",{capture:!1}],[i,\"keyup\",void 0],[i,\"wheel\",{passive:!1}],[i,\"contextmenu\",void 0],[t.window,\"blur\",void 0]];for(var a=0,o=this._listeners;a<o.length;a+=1){var s=o[a],l=s[0],c=s[1],u=s[2];r.addEventListener(l,c,l===t.window.document?this.handleWindowEvent:this.handleEvent,u)}};yi.prototype.destroy=function(){for(var e=0,n=this._listeners;e<n.length;e+=1){var i=n[e],a=i[0],o=i[1],s=i[2];r.removeEventListener(a,o,a===t.window.document?this.handleWindowEvent:this.handleEvent,s)}},yi.prototype._addDefaultHandlers=function(t){var e=this._map,r=e.getCanvasContainer();this._add(\"mapEvent\",new Nn(e,t));var n=e.boxZoom=new Un(e,t);this._add(\"boxZoom\",n);var i=new Gn,a=new ui;e.doubleClickZoom=new ci(a,i),this._add(\"tapZoom\",i),this._add(\"clickZoom\",a);var o=new fi;this._add(\"tapDragZoom\",o);var s=e.touchPitch=new ii;this._add(\"touchPitch\",s);var l=new Xn(t),c=new Zn(t);e.dragRotate=new pi(t,l,c),this._add(\"mouseRotate\",l,[\"mousePitch\"]),this._add(\"mousePitch\",c,[\"mouseRotate\"]);var u=new Wn(t),f=new Jn(t);e.dragPan=new hi(r,u,f),this._add(\"mousePan\",u),this._add(\"touchPan\",f,[\"touchZoom\",\"touchRotate\"]);var h=new ri,p=new ti;e.touchZoomRotate=new di(r,p,h,o),this._add(\"touchRotate\",h,[\"touchPan\",\"touchZoom\"]),this._add(\"touchZoom\",p,[\"touchPan\",\"touchRotate\"]);var d=e.scrollZoom=new li(e,this);this._add(\"scrollZoom\",d,[\"mousePan\"]);var m=e.keyboard=new oi;this._add(\"keyboard\",m),this._add(\"blockableMapEvent\",new jn(e));for(var g=0,v=[\"boxZoom\",\"doubleClickZoom\",\"tapDragZoom\",\"touchPitch\",\"dragRotate\",\"dragPan\",\"touchZoomRotate\",\"scrollZoom\",\"keyboard\"];g<v.length;g+=1){var y=v[g];t.interactive&&t[y]&&e[y].enable(t[y])}},yi.prototype._add=function(t,e,r){this._handlers.push({handlerName:t,handler:e,allowed:r}),this._handlersById[t]=e},yi.prototype.stop=function(){if(!this._updatingCamera){for(var t=0,e=this._handlers;t<e.length;t+=1){e[t].handler.reset()}this._inertia.clear(),this._fireEvents({},{}),this._changes=[]}},yi.prototype.isActive=function(){for(var t=0,e=this._handlers;t<e.length;t+=1){if(e[t].handler.isActive())return!0}return!1},yi.prototype.isZooming=function(){return!!this._eventsInProgress.zoom||this._map.scrollZoom.isZooming()},yi.prototype.isRotating=function(){return!!this._eventsInProgress.rotate},yi.prototype.isMoving=function(){return Boolean(mi(this._eventsInProgress))||this.isZooming()},yi.prototype._blockedByActive=function(t,e,r){for(var n in t)if(n!==r&&(!e||e.indexOf(n)<0))return!0;return!1},yi.prototype.handleWindowEvent=function(t){this.handleEvent(t,t.type+\"Window\")},yi.prototype._getMapTouches=function(t){for(var e=[],r=0,n=t;r<n.length;r+=1){var i=n[r],a=i.target;this._el.contains(a)&&e.push(i)}return e},yi.prototype.handleEvent=function(t,e){if(\"blur\"!==t.type){this._updatingCamera=!0;for(var n=\"renderFrame\"===t.type?void 0:t,i={needsRenderFrame:!1},a={},o={},s=t.touches?this._getMapTouches(t.touches):void 0,l=s?r.touchPos(this._el,s):r.mousePos(this._el,t),c=0,u=this._handlers;c<u.length;c+=1){var f=u[c],h=f.handlerName,p=f.handler,d=f.allowed;if(p.isEnabled()){var m=void 0;this._blockedByActive(o,d,h)?p.reset():p[e||t.type]&&(m=p[e||t.type](t,l,s),this.mergeHandlerResult(i,a,m,h,n),m&&m.needsRenderFrame&&this._triggerRenderFrame()),(m||p.isActive())&&(o[h]=p)}}var g={};for(var v in this._previousActiveHandlers)o[v]||(g[v]=n);this._previousActiveHandlers=o,(Object.keys(g).length||vi(i))&&(this._changes.push([i,a,g]),this._triggerRenderFrame()),(Object.keys(o).length||vi(i))&&this._map._stop(!0),this._updatingCamera=!1;var y=i.cameraAnimation;y&&(this._inertia.clear(),this._fireEvents({},{}),this._changes=[],y(this._map))}else this.stop()},yi.prototype.mergeHandlerResult=function(e,r,n,i,a){if(n){t.extend(e,n);var o={handlerName:i,originalEvent:n.originalEvent||a};void 0!==n.zoomDelta&&(r.zoom=o),void 0!==n.panDelta&&(r.drag=o),void 0!==n.pitchDelta&&(r.pitch=o),void 0!==n.bearingDelta&&(r.rotate=o)}},yi.prototype._applyChanges=function(){for(var e={},r={},n={},i=0,a=this._changes;i<a.length;i+=1){var o=a[i],s=o[0],l=o[1],c=o[2];s.panDelta&&(e.panDelta=(e.panDelta||new t.Point(0,0))._add(s.panDelta)),s.zoomDelta&&(e.zoomDelta=(e.zoomDelta||0)+s.zoomDelta),s.bearingDelta&&(e.bearingDelta=(e.bearingDelta||0)+s.bearingDelta),s.pitchDelta&&(e.pitchDelta=(e.pitchDelta||0)+s.pitchDelta),void 0!==s.around&&(e.around=s.around),void 0!==s.pinchAround&&(e.pinchAround=s.pinchAround),s.noInertia&&(e.noInertia=s.noInertia),t.extend(r,l),t.extend(n,c)}this._updateMapTransform(e,r,n),this._changes=[]},yi.prototype._updateMapTransform=function(t,e,r){var n=this._map,i=n.transform;if(!vi(t))return this._fireEvents(e,r);var a=t.panDelta,o=t.zoomDelta,s=t.bearingDelta,l=t.pitchDelta,c=t.around,u=t.pinchAround;void 0!==u&&(c=u),n._stop(!0),c=c||n.transform.centerPoint;var f=i.pointLocation(a?c.sub(a):c);s&&(i.bearing+=s),l&&(i.pitch+=l),o&&(i.zoom+=o),i.setLocationAtPoint(f,c),this._map._update(),t.noInertia||this._inertia.record(t),this._fireEvents(e,r)},yi.prototype._fireEvents=function(e,r){var n=this,i=mi(this._eventsInProgress),a=mi(e),o={};for(var s in e){var l=e[s].originalEvent;this._eventsInProgress[s]||(o[s+\"start\"]=l),this._eventsInProgress[s]=e[s]}for(var c in!i&&a&&this._fireEvent(\"movestart\",a.originalEvent),o)this._fireEvent(c,o[c]);for(var u in e.rotate&&(this._bearingChanged=!0),a&&this._fireEvent(\"move\",a.originalEvent),e){var f=e[u].originalEvent;this._fireEvent(u,f)}var h,p={};for(var d in this._eventsInProgress){var m=this._eventsInProgress[d],g=m.handlerName,v=m.originalEvent;this._handlersById[g].isActive()||(delete this._eventsInProgress[d],h=r[g]||v,p[d+\"end\"]=h)}for(var y in p)this._fireEvent(y,p[y]);var x=mi(this._eventsInProgress);if((i||a)&&!x){this._updatingCamera=!0;var b=this._inertia._onMoveEnd(this._map.dragPan._inertiaOptions),_=function(t){return 0!==t&&-n._bearingSnap<t&&t<n._bearingSnap};b?(_(b.bearing||this._map.getBearing())&&(b.bearing=0),this._map.easeTo(b,{originalEvent:h})):(this._map.fire(new t.Event(\"moveend\",{originalEvent:h})),_(this._map.getBearing())&&this._map.resetNorth()),this._bearingChanged=!1,this._updatingCamera=!1}},yi.prototype._fireEvent=function(e,r){this._map.fire(new t.Event(e,r?{originalEvent:r}:{}))},yi.prototype._triggerRenderFrame=function(){var t=this;void 0===this._frameId&&(this._frameId=this._map._requestRenderFrame((function(e){delete t._frameId,t.handleEvent(new gi(\"renderFrame\",{timeStamp:e})),t._applyChanges()})))};var xi=function(e){function r(r,n){e.call(this),this._moving=!1,this._zooming=!1,this.transform=r,this._bearingSnap=n.bearingSnap,t.bindAll([\"_renderFrameCallback\"],this)}return e&&(r.__proto__=e),r.prototype=Object.create(e&&e.prototype),r.prototype.constructor=r,r.prototype.getCenter=function(){return new t.LngLat(this.transform.center.lng,this.transform.center.lat)},r.prototype.setCenter=function(t,e){return this.jumpTo({center:t},e)},r.prototype.panBy=function(e,r,n){return e=t.Point.convert(e).mult(-1),this.panTo(this.transform.center,t.extend({offset:e},r),n)},r.prototype.panTo=function(e,r,n){return this.easeTo(t.extend({center:e},r),n)},r.prototype.getZoom=function(){return this.transform.zoom},r.prototype.setZoom=function(t,e){return this.jumpTo({zoom:t},e),this},r.prototype.zoomTo=function(e,r,n){return this.easeTo(t.extend({zoom:e},r),n)},r.prototype.zoomIn=function(t,e){return this.zoomTo(this.getZoom()+1,t,e),this},r.prototype.zoomOut=function(t,e){return this.zoomTo(this.getZoom()-1,t,e),this},r.prototype.getBearing=function(){return this.transform.bearing},r.prototype.setBearing=function(t,e){return this.jumpTo({bearing:t},e),this},r.prototype.getPadding=function(){return this.transform.padding},r.prototype.setPadding=function(t,e){return this.jumpTo({padding:t},e),this},r.prototype.rotateTo=function(e,r,n){return this.easeTo(t.extend({bearing:e},r),n)},r.prototype.resetNorth=function(e,r){return this.rotateTo(0,t.extend({duration:1e3},e),r),this},r.prototype.resetNorthPitch=function(e,r){return this.easeTo(t.extend({bearing:0,pitch:0,duration:1e3},e),r),this},r.prototype.snapToNorth=function(t,e){return Math.abs(this.getBearing())<this._bearingSnap?this.resetNorth(t,e):this},r.prototype.getPitch=function(){return this.transform.pitch},r.prototype.setPitch=function(t,e){return this.jumpTo({pitch:t},e),this},r.prototype.cameraForBounds=function(e,r){return e=t.LngLatBounds.convert(e),this._cameraForBoxAndBearing(e.getNorthWest(),e.getSouthEast(),0,r)},r.prototype._cameraForBoxAndBearing=function(e,r,n,i){var a={top:0,bottom:0,right:0,left:0};if(\"number\"==typeof(i=t.extend({padding:a,offset:[0,0],maxZoom:this.transform.maxZoom},i)).padding){var o=i.padding;i.padding={top:o,bottom:o,right:o,left:o}}i.padding=t.extend(a,i.padding);var s=this.transform,l=s.padding,c=s.project(t.LngLat.convert(e)),u=s.project(t.LngLat.convert(r)),f=c.rotate(-n*Math.PI/180),h=u.rotate(-n*Math.PI/180),p=new t.Point(Math.max(f.x,h.x),Math.max(f.y,h.y)),d=new t.Point(Math.min(f.x,h.x),Math.min(f.y,h.y)),m=p.sub(d),g=(s.width-(l.left+l.right+i.padding.left+i.padding.right))/m.x,v=(s.height-(l.top+l.bottom+i.padding.top+i.padding.bottom))/m.y;if(!(v<0||g<0)){var y=Math.min(s.scaleZoom(s.scale*Math.min(g,v)),i.maxZoom),x=t.Point.convert(i.offset),b=(i.padding.left-i.padding.right)/2,_=(i.padding.top-i.padding.bottom)/2,w=new t.Point(x.x+b,x.y+_).mult(s.scale/s.zoomScale(y));return{center:s.unproject(c.add(u).div(2).sub(w)),zoom:y,bearing:n}}t.warnOnce(\"Map cannot fit within canvas with the given bounds, padding, and/or offset.\")},r.prototype.fitBounds=function(t,e,r){return this._fitInternal(this.cameraForBounds(t,e),e,r)},r.prototype.fitScreenCoordinates=function(e,r,n,i,a){return this._fitInternal(this._cameraForBoxAndBearing(this.transform.pointLocation(t.Point.convert(e)),this.transform.pointLocation(t.Point.convert(r)),n,i),i,a)},r.prototype._fitInternal=function(e,r,n){return e?(delete(r=t.extend(e,r)).padding,r.linear?this.easeTo(r,n):this.flyTo(r,n)):this},r.prototype.jumpTo=function(e,r){this.stop();var n=this.transform,i=!1,a=!1,o=!1;return\"zoom\"in e&&n.zoom!==+e.zoom&&(i=!0,n.zoom=+e.zoom),void 0!==e.center&&(n.center=t.LngLat.convert(e.center)),\"bearing\"in e&&n.bearing!==+e.bearing&&(a=!0,n.bearing=+e.bearing),\"pitch\"in e&&n.pitch!==+e.pitch&&(o=!0,n.pitch=+e.pitch),null==e.padding||n.isPaddingEqual(e.padding)||(n.padding=e.padding),this.fire(new t.Event(\"movestart\",r)).fire(new t.Event(\"move\",r)),i&&this.fire(new t.Event(\"zoomstart\",r)).fire(new t.Event(\"zoom\",r)).fire(new t.Event(\"zoomend\",r)),a&&this.fire(new t.Event(\"rotatestart\",r)).fire(new t.Event(\"rotate\",r)).fire(new t.Event(\"rotateend\",r)),o&&this.fire(new t.Event(\"pitchstart\",r)).fire(new t.Event(\"pitch\",r)).fire(new t.Event(\"pitchend\",r)),this.fire(new t.Event(\"moveend\",r))},r.prototype.easeTo=function(e,r){var n=this;this._stop(!1,e.easeId),(!1===(e=t.extend({offset:[0,0],duration:500,easing:t.ease},e)).animate||!e.essential&&t.browser.prefersReducedMotion)&&(e.duration=0);var i=this.transform,a=this.getZoom(),o=this.getBearing(),s=this.getPitch(),l=this.getPadding(),c=\"zoom\"in e?+e.zoom:a,u=\"bearing\"in e?this._normalizeBearing(e.bearing,o):o,f=\"pitch\"in e?+e.pitch:s,h=\"padding\"in e?e.padding:i.padding,p=t.Point.convert(e.offset),d=i.centerPoint.add(p),m=i.pointLocation(d),g=t.LngLat.convert(e.center||m);this._normalizeCenter(g);var v,y,x=i.project(m),b=i.project(g).sub(x),_=i.zoomScale(c-a);e.around&&(v=t.LngLat.convert(e.around),y=i.locationPoint(v));var w={moving:this._moving,zooming:this._zooming,rotating:this._rotating,pitching:this._pitching};return this._zooming=this._zooming||c!==a,this._rotating=this._rotating||o!==u,this._pitching=this._pitching||f!==s,this._padding=!i.isPaddingEqual(h),this._easeId=e.easeId,this._prepareEase(r,e.noMoveStart,w),clearTimeout(this._easeEndTimeoutID),this._ease((function(e){if(n._zooming&&(i.zoom=t.number(a,c,e)),n._rotating&&(i.bearing=t.number(o,u,e)),n._pitching&&(i.pitch=t.number(s,f,e)),n._padding&&(i.interpolatePadding(l,h,e),d=i.centerPoint.add(p)),v)i.setLocationAtPoint(v,y);else{var m=i.zoomScale(i.zoom-a),g=c>a?Math.min(2,_):Math.max(.5,_),w=Math.pow(g,1-e),T=i.unproject(x.add(b.mult(e*w)).mult(m));i.setLocationAtPoint(i.renderWorldCopies?T.wrap():T,d)}n._fireMoveEvents(r)}),(function(t){n._afterEase(r,t)}),e),this},r.prototype._prepareEase=function(e,r,n){void 0===n&&(n={}),this._moving=!0,r||n.moving||this.fire(new t.Event(\"movestart\",e)),this._zooming&&!n.zooming&&this.fire(new t.Event(\"zoomstart\",e)),this._rotating&&!n.rotating&&this.fire(new t.Event(\"rotatestart\",e)),this._pitching&&!n.pitching&&this.fire(new t.Event(\"pitchstart\",e))},r.prototype._fireMoveEvents=function(e){this.fire(new t.Event(\"move\",e)),this._zooming&&this.fire(new t.Event(\"zoom\",e)),this._rotating&&this.fire(new t.Event(\"rotate\",e)),this._pitching&&this.fire(new t.Event(\"pitch\",e))},r.prototype._afterEase=function(e,r){if(!this._easeId||!r||this._easeId!==r){delete this._easeId;var n=this._zooming,i=this._rotating,a=this._pitching;this._moving=!1,this._zooming=!1,this._rotating=!1,this._pitching=!1,this._padding=!1,n&&this.fire(new t.Event(\"zoomend\",e)),i&&this.fire(new t.Event(\"rotateend\",e)),a&&this.fire(new t.Event(\"pitchend\",e)),this.fire(new t.Event(\"moveend\",e))}},r.prototype.flyTo=function(e,r){var n=this;if(!e.essential&&t.browser.prefersReducedMotion){var i=t.pick(e,[\"center\",\"zoom\",\"bearing\",\"pitch\",\"around\"]);return this.jumpTo(i,r)}this.stop(),e=t.extend({offset:[0,0],speed:1.2,curve:1.42,easing:t.ease},e);var a=this.transform,o=this.getZoom(),s=this.getBearing(),l=this.getPitch(),c=this.getPadding(),u=\"zoom\"in e?t.clamp(+e.zoom,a.minZoom,a.maxZoom):o,f=\"bearing\"in e?this._normalizeBearing(e.bearing,s):s,h=\"pitch\"in e?+e.pitch:l,p=\"padding\"in e?e.padding:a.padding,d=a.zoomScale(u-o),m=t.Point.convert(e.offset),g=a.centerPoint.add(m),v=a.pointLocation(g),y=t.LngLat.convert(e.center||v);this._normalizeCenter(y);var x=a.project(v),b=a.project(y).sub(x),_=e.curve,w=Math.max(a.width,a.height),T=w/d,k=b.mag();if(\"minZoom\"in e){var M=t.clamp(Math.min(e.minZoom,o,u),a.minZoom,a.maxZoom),A=w/a.zoomScale(M-o);_=Math.sqrt(A/k*2)}var S=_*_;function E(t){var e=(T*T-w*w+(t?-1:1)*S*S*k*k)/(2*(t?T:w)*S*k);return Math.log(Math.sqrt(e*e+1)-e)}function L(t){return(Math.exp(t)-Math.exp(-t))/2}function C(t){return(Math.exp(t)+Math.exp(-t))/2}var P=E(0),I=function(t){return C(P)/C(P+_*t)},O=function(t){return w*((C(P)*(L(e=P+_*t)/C(e))-L(P))/S)/k;var e},z=(E(1)-P)/_;if(Math.abs(k)<1e-6||!isFinite(z)){if(Math.abs(w-T)<1e-6)return this.easeTo(e,r);var D=T<w?-1:1;z=Math.abs(Math.log(T/w))/_,O=function(){return 0},I=function(t){return Math.exp(D*_*t)}}if(\"duration\"in e)e.duration=+e.duration;else{var R=\"screenSpeed\"in e?+e.screenSpeed/_:+e.speed;e.duration=1e3*z/R}return e.maxDuration&&e.duration>e.maxDuration&&(e.duration=0),this._zooming=!0,this._rotating=s!==f,this._pitching=h!==l,this._padding=!a.isPaddingEqual(p),this._prepareEase(r,!1),this._ease((function(e){var i=e*z,d=1/I(i);a.zoom=1===e?u:o+a.scaleZoom(d),n._rotating&&(a.bearing=t.number(s,f,e)),n._pitching&&(a.pitch=t.number(l,h,e)),n._padding&&(a.interpolatePadding(c,p,e),g=a.centerPoint.add(m));var v=1===e?y:a.unproject(x.add(b.mult(O(i))).mult(d));a.setLocationAtPoint(a.renderWorldCopies?v.wrap():v,g),n._fireMoveEvents(r)}),(function(){return n._afterEase(r)}),e),this},r.prototype.isEasing=function(){return!!this._easeFrameId},r.prototype.stop=function(){return this._stop()},r.prototype._stop=function(t,e){if(this._easeFrameId&&(this._cancelRenderFrame(this._easeFrameId),delete this._easeFrameId,delete this._onEaseFrame),this._onEaseEnd){var r=this._onEaseEnd;delete this._onEaseEnd,r.call(this,e)}if(!t){var n=this.handlers;n&&n.stop()}return this},r.prototype._ease=function(e,r,n){!1===n.animate||0===n.duration?(e(1),r()):(this._easeStart=t.browser.now(),this._easeOptions=n,this._onEaseFrame=e,this._onEaseEnd=r,this._easeFrameId=this._requestRenderFrame(this._renderFrameCallback))},r.prototype._renderFrameCallback=function(){var e=Math.min((t.browser.now()-this._easeStart)/this._easeOptions.duration,1);this._onEaseFrame(this._easeOptions.easing(e)),e<1?this._easeFrameId=this._requestRenderFrame(this._renderFrameCallback):this.stop()},r.prototype._normalizeBearing=function(e,r){e=t.wrap(e,-180,180);var n=Math.abs(e-r);return Math.abs(e-360-r)<n&&(e-=360),Math.abs(e+360-r)<n&&(e+=360),e},r.prototype._normalizeCenter=function(t){var e=this.transform;if(e.renderWorldCopies&&!e.lngRange){var r=t.lng-e.center.lng;t.lng+=r>180?-360:r<-180?360:0}},r}(t.Evented),bi=function(e){void 0===e&&(e={}),this.options=e,t.bindAll([\"_updateEditLink\",\"_updateData\",\"_updateCompact\"],this)};bi.prototype.getDefaultPosition=function(){return\"bottom-right\"},bi.prototype.onAdd=function(t){var e=this.options&&this.options.compact;return this._map=t,this._container=r.create(\"div\",\"mapboxgl-ctrl mapboxgl-ctrl-attrib\"),this._innerContainer=r.create(\"div\",\"mapboxgl-ctrl-attrib-inner\",this._container),e&&this._container.classList.add(\"mapboxgl-compact\"),this._updateAttributions(),this._updateEditLink(),this._map.on(\"styledata\",this._updateData),this._map.on(\"sourcedata\",this._updateData),this._map.on(\"moveend\",this._updateEditLink),void 0===e&&(this._map.on(\"resize\",this._updateCompact),this._updateCompact()),this._container},bi.prototype.onRemove=function(){r.remove(this._container),this._map.off(\"styledata\",this._updateData),this._map.off(\"sourcedata\",this._updateData),this._map.off(\"moveend\",this._updateEditLink),this._map.off(\"resize\",this._updateCompact),this._map=void 0,this._attribHTML=void 0},bi.prototype._updateEditLink=function(){var e=this._editLink;e||(e=this._editLink=this._container.querySelector(\".mapbox-improve-map\"));var r=[{key:\"owner\",value:this.styleOwner},{key:\"id\",value:this.styleId},{key:\"access_token\",value:this._map._requestManager._customAccessToken||t.config.ACCESS_TOKEN}];if(e){var n=r.reduce((function(t,e,n){return e.value&&(t+=e.key+\"=\"+e.value+(n<r.length-1?\"&\":\"\")),t}),\"?\");e.href=t.config.FEEDBACK_URL+\"/\"+n+(this._map._hash?this._map._hash.getHashString(!0):\"\"),e.rel=\"noopener nofollow\"}},bi.prototype._updateData=function(t){!t||\"metadata\"!==t.sourceDataType&&\"style\"!==t.dataType||(this._updateAttributions(),this._updateEditLink())},bi.prototype._updateAttributions=function(){if(this._map.style){var t=[];if(this.options.customAttribution&&(Array.isArray(this.options.customAttribution)?t=t.concat(this.options.customAttribution.map((function(t){return\"string\"!=typeof t?\"\":t}))):\"string\"==typeof this.options.customAttribution&&t.push(this.options.customAttribution)),this._map.style.stylesheet){var e=this._map.style.stylesheet;this.styleOwner=e.owner,this.styleId=e.id}var r=this._map.style.sourceCaches;for(var n in r){var i=r[n];if(i.used){var a=i.getSource();a.attribution&&t.indexOf(a.attribution)<0&&t.push(a.attribution)}}t.sort((function(t,e){return t.length-e.length}));var o=(t=t.filter((function(e,r){for(var n=r+1;n<t.length;n++)if(t[n].indexOf(e)>=0)return!1;return!0}))).join(\" | \");o!==this._attribHTML&&(this._attribHTML=o,t.length?(this._innerContainer.innerHTML=o,this._container.classList.remove(\"mapboxgl-attrib-empty\")):this._container.classList.add(\"mapboxgl-attrib-empty\"),this._editLink=null)}},bi.prototype._updateCompact=function(){this._map.getCanvasContainer().offsetWidth<=640?this._container.classList.add(\"mapboxgl-compact\"):this._container.classList.remove(\"mapboxgl-compact\")};var _i=function(){t.bindAll([\"_updateLogo\"],this),t.bindAll([\"_updateCompact\"],this)};_i.prototype.onAdd=function(t){this._map=t,this._container=r.create(\"div\",\"mapboxgl-ctrl\");var e=r.create(\"a\",\"mapboxgl-ctrl-logo\");return e.target=\"_blank\",e.rel=\"noopener nofollow\",e.href=\"https://www.mapbox.com/\",e.setAttribute(\"aria-label\",this._map._getUIString(\"LogoControl.Title\")),e.setAttribute(\"rel\",\"noopener nofollow\"),this._container.appendChild(e),this._container.style.display=\"none\",this._map.on(\"sourcedata\",this._updateLogo),this._updateLogo(),this._map.on(\"resize\",this._updateCompact),this._updateCompact(),this._container},_i.prototype.onRemove=function(){r.remove(this._container),this._map.off(\"sourcedata\",this._updateLogo),this._map.off(\"resize\",this._updateCompact)},_i.prototype.getDefaultPosition=function(){return\"bottom-left\"},_i.prototype._updateLogo=function(t){t&&\"metadata\"!==t.sourceDataType||(this._container.style.display=this._logoRequired()?\"block\":\"none\")},_i.prototype._logoRequired=function(){if(this._map.style){var t=this._map.style.sourceCaches;for(var e in t){if(t[e].getSource().mapbox_logo)return!0}return!1}},_i.prototype._updateCompact=function(){var t=this._container.children;if(t.length){var e=t[0];this._map.getCanvasContainer().offsetWidth<250?e.classList.add(\"mapboxgl-compact\"):e.classList.remove(\"mapboxgl-compact\")}};var wi=function(){this._queue=[],this._id=0,this._cleared=!1,this._currentlyRunning=!1};wi.prototype.add=function(t){var e=++this._id;return this._queue.push({callback:t,id:e,cancelled:!1}),e},wi.prototype.remove=function(t){for(var e=this._currentlyRunning,r=0,n=e?this._queue.concat(e):this._queue;r<n.length;r+=1){var i=n[r];if(i.id===t)return void(i.cancelled=!0)}},wi.prototype.run=function(t){void 0===t&&(t=0);var e=this._currentlyRunning=this._queue;this._queue=[];for(var r=0,n=e;r<n.length;r+=1){var i=n[r];if(!i.cancelled&&(i.callback(t),this._cleared))break}this._cleared=!1,this._currentlyRunning=!1},wi.prototype.clear=function(){this._currentlyRunning&&(this._cleared=!0),this._queue=[]};var Ti={\"FullscreenControl.Enter\":\"Enter fullscreen\",\"FullscreenControl.Exit\":\"Exit fullscreen\",\"GeolocateControl.FindMyLocation\":\"Find my location\",\"GeolocateControl.LocationNotAvailable\":\"Location not available\",\"LogoControl.Title\":\"Mapbox logo\",\"NavigationControl.ResetBearing\":\"Reset bearing to north\",\"NavigationControl.ZoomIn\":\"Zoom in\",\"NavigationControl.ZoomOut\":\"Zoom out\",\"ScaleControl.Feet\":\"ft\",\"ScaleControl.Meters\":\"m\",\"ScaleControl.Kilometers\":\"km\",\"ScaleControl.Miles\":\"mi\",\"ScaleControl.NauticalMiles\":\"nm\"},ki=t.window.HTMLImageElement,Mi=t.window.HTMLElement,Ai=t.window.ImageBitmap,Si={center:[0,0],zoom:0,bearing:0,pitch:0,minZoom:-2,maxZoom:22,minPitch:0,maxPitch:60,interactive:!0,scrollZoom:!0,boxZoom:!0,dragRotate:!0,dragPan:!0,keyboard:!0,doubleClickZoom:!0,touchZoomRotate:!0,touchPitch:!0,bearingSnap:7,clickTolerance:3,pitchWithRotate:!0,hash:!1,attributionControl:!0,failIfMajorPerformanceCaveat:!1,preserveDrawingBuffer:!1,trackResize:!0,renderWorldCopies:!0,refreshExpiredTiles:!0,maxTileCacheSize:null,localIdeographFontFamily:\"sans-serif\",transformRequest:null,accessToken:null,fadeDuration:300,crossSourceCollisions:!0},Ei=function(n){function i(e){var r=this;if(null!=(e=t.extend({},Si,e)).minZoom&&null!=e.maxZoom&&e.minZoom>e.maxZoom)throw new Error(\"maxZoom must be greater than or equal to minZoom\");if(null!=e.minPitch&&null!=e.maxPitch&&e.minPitch>e.maxPitch)throw new Error(\"maxPitch must be greater than or equal to minPitch\");if(null!=e.minPitch&&e.minPitch<0)throw new Error(\"minPitch must be greater than or equal to 0\");if(null!=e.maxPitch&&e.maxPitch>60)throw new Error(\"maxPitch must be less than or equal to 60\");var i=new Mn(e.minZoom,e.maxZoom,e.minPitch,e.maxPitch,e.renderWorldCopies);if(n.call(this,i,e),this._interactive=e.interactive,this._maxTileCacheSize=e.maxTileCacheSize,this._failIfMajorPerformanceCaveat=e.failIfMajorPerformanceCaveat,this._preserveDrawingBuffer=e.preserveDrawingBuffer,this._antialias=e.antialias,this._trackResize=e.trackResize,this._bearingSnap=e.bearingSnap,this._refreshExpiredTiles=e.refreshExpiredTiles,this._fadeDuration=e.fadeDuration,this._crossSourceCollisions=e.crossSourceCollisions,this._crossFadingFactor=1,this._collectResourceTiming=e.collectResourceTiming,this._renderTaskQueue=new wi,this._controls=[],this._mapId=t.uniqueId(),this._locale=t.extend({},Ti,e.locale),this._requestManager=new t.RequestManager(e.transformRequest,e.accessToken),\"string\"==typeof e.container){if(this._container=t.window.document.getElementById(e.container),!this._container)throw new Error(\"Container '\"+e.container+\"' not found.\")}else{if(!(e.container instanceof Mi))throw new Error(\"Invalid type: 'container' must be a String or HTMLElement.\");this._container=e.container}if(e.maxBounds&&this.setMaxBounds(e.maxBounds),t.bindAll([\"_onWindowOnline\",\"_onWindowResize\",\"_contextLost\",\"_contextRestored\"],this),this._setupContainer(),this._setupPainter(),void 0===this.painter)throw new Error(\"Failed to initialize WebGL.\");this.on(\"move\",(function(){return r._update(!1)})),this.on(\"moveend\",(function(){return r._update(!1)})),this.on(\"zoom\",(function(){return r._update(!0)})),void 0!==t.window&&(t.window.addEventListener(\"online\",this._onWindowOnline,!1),t.window.addEventListener(\"resize\",this._onWindowResize,!1)),this.handlers=new yi(this,e);var a=\"string\"==typeof e.hash&&e.hash||void 0;this._hash=e.hash&&new Sn(a).addTo(this),this._hash&&this._hash._onHashChange()||(this.jumpTo({center:e.center,zoom:e.zoom,bearing:e.bearing,pitch:e.pitch}),e.bounds&&(this.resize(),this.fitBounds(e.bounds,t.extend({},e.fitBoundsOptions,{duration:0})))),this.resize(),this._localIdeographFontFamily=e.localIdeographFontFamily,e.style&&this.setStyle(e.style,{localIdeographFontFamily:e.localIdeographFontFamily}),e.attributionControl&&this.addControl(new bi({customAttribution:e.customAttribution})),this.addControl(new _i,e.logoPosition),this.on(\"style.load\",(function(){r.transform.unmodified&&r.jumpTo(r.style.stylesheet)})),this.on(\"data\",(function(e){r._update(\"style\"===e.dataType),r.fire(new t.Event(e.dataType+\"data\",e))})),this.on(\"dataloading\",(function(e){r.fire(new t.Event(e.dataType+\"dataloading\",e))}))}n&&(i.__proto__=n),i.prototype=Object.create(n&&n.prototype),i.prototype.constructor=i;var a={showTileBoundaries:{configurable:!0},showPadding:{configurable:!0},showCollisionBoxes:{configurable:!0},showOverdrawInspector:{configurable:!0},repaint:{configurable:!0},vertices:{configurable:!0},version:{configurable:!0}};return i.prototype._getMapId=function(){return this._mapId},i.prototype.addControl=function(e,r){if(void 0===r&&e.getDefaultPosition&&(r=e.getDefaultPosition()),void 0===r&&(r=\"top-right\"),!e||!e.onAdd)return this.fire(new t.ErrorEvent(new Error(\"Invalid argument to map.addControl(). Argument must be a control with onAdd and onRemove methods.\")));var n=e.onAdd(this);this._controls.push(e);var i=this._controlPositions[r];return-1!==r.indexOf(\"bottom\")?i.insertBefore(n,i.firstChild):i.appendChild(n),this},i.prototype.removeControl=function(e){if(!e||!e.onRemove)return this.fire(new t.ErrorEvent(new Error(\"Invalid argument to map.removeControl(). Argument must be a control with onAdd and onRemove methods.\")));var r=this._controls.indexOf(e);return r>-1&&this._controls.splice(r,1),e.onRemove(this),this},i.prototype.resize=function(e){var r=this._containerDimensions(),n=r[0],i=r[1];this._resizeCanvas(n,i),this.transform.resize(n,i),this.painter.resize(n,i);var a=!this._moving;return a&&(this.stop(),this.fire(new t.Event(\"movestart\",e)).fire(new t.Event(\"move\",e))),this.fire(new t.Event(\"resize\",e)),a&&this.fire(new t.Event(\"moveend\",e)),this},i.prototype.getBounds=function(){return this.transform.getBounds()},i.prototype.getMaxBounds=function(){return this.transform.getMaxBounds()},i.prototype.setMaxBounds=function(e){return this.transform.setMaxBounds(t.LngLatBounds.convert(e)),this._update()},i.prototype.setMinZoom=function(t){if((t=null==t?-2:t)>=-2&&t<=this.transform.maxZoom)return this.transform.minZoom=t,this._update(),this.getZoom()<t&&this.setZoom(t),this;throw new Error(\"minZoom must be between -2 and the current maxZoom, inclusive\")},i.prototype.getMinZoom=function(){return this.transform.minZoom},i.prototype.setMaxZoom=function(t){if((t=null==t?22:t)>=this.transform.minZoom)return this.transform.maxZoom=t,this._update(),this.getZoom()>t&&this.setZoom(t),this;throw new Error(\"maxZoom must be greater than the current minZoom\")},i.prototype.getMaxZoom=function(){return this.transform.maxZoom},i.prototype.setMinPitch=function(t){if((t=null==t?0:t)<0)throw new Error(\"minPitch must be greater than or equal to 0\");if(t>=0&&t<=this.transform.maxPitch)return this.transform.minPitch=t,this._update(),this.getPitch()<t&&this.setPitch(t),this;throw new Error(\"minPitch must be between 0 and the current maxPitch, inclusive\")},i.prototype.getMinPitch=function(){return this.transform.minPitch},i.prototype.setMaxPitch=function(t){if((t=null==t?60:t)>60)throw new Error(\"maxPitch must be less than or equal to 60\");if(t>=this.transform.minPitch)return this.transform.maxPitch=t,this._update(),this.getPitch()>t&&this.setPitch(t),this;throw new Error(\"maxPitch must be greater than the current minPitch\")},i.prototype.getMaxPitch=function(){return this.transform.maxPitch},i.prototype.getRenderWorldCopies=function(){return this.transform.renderWorldCopies},i.prototype.setRenderWorldCopies=function(t){return this.transform.renderWorldCopies=t,this._update()},i.prototype.project=function(e){return this.transform.locationPoint(t.LngLat.convert(e))},i.prototype.unproject=function(e){return this.transform.pointLocation(t.Point.convert(e))},i.prototype.isMoving=function(){return this._moving||this.handlers.isMoving()},i.prototype.isZooming=function(){return this._zooming||this.handlers.isZooming()},i.prototype.isRotating=function(){return this._rotating||this.handlers.isRotating()},i.prototype._createDelegatedListener=function(t,e,r){var n,i=this;if(\"mouseenter\"===t||\"mouseover\"===t){var a=!1;return{layer:e,listener:r,delegates:{mousemove:function(n){var o=i.getLayer(e)?i.queryRenderedFeatures(n.point,{layers:[e]}):[];o.length?a||(a=!0,r.call(i,new Rn(t,i,n.originalEvent,{features:o}))):a=!1},mouseout:function(){a=!1}}}}if(\"mouseleave\"===t||\"mouseout\"===t){var o=!1;return{layer:e,listener:r,delegates:{mousemove:function(n){(i.getLayer(e)?i.queryRenderedFeatures(n.point,{layers:[e]}):[]).length?o=!0:o&&(o=!1,r.call(i,new Rn(t,i,n.originalEvent)))},mouseout:function(e){o&&(o=!1,r.call(i,new Rn(t,i,e.originalEvent)))}}}}return{layer:e,listener:r,delegates:(n={},n[t]=function(t){var n=i.getLayer(e)?i.queryRenderedFeatures(t.point,{layers:[e]}):[];n.length&&(t.features=n,r.call(i,t),delete t.features)},n)}},i.prototype.on=function(t,e,r){if(void 0===r)return n.prototype.on.call(this,t,e);var i=this._createDelegatedListener(t,e,r);for(var a in this._delegatedListeners=this._delegatedListeners||{},this._delegatedListeners[t]=this._delegatedListeners[t]||[],this._delegatedListeners[t].push(i),i.delegates)this.on(a,i.delegates[a]);return this},i.prototype.once=function(t,e,r){if(void 0===r)return n.prototype.once.call(this,t,e);var i=this._createDelegatedListener(t,e,r);for(var a in i.delegates)this.once(a,i.delegates[a]);return this},i.prototype.off=function(t,e,r){var i=this;if(void 0===r)return n.prototype.off.call(this,t,e);return this._delegatedListeners&&this._delegatedListeners[t]&&function(n){for(var a=n[t],o=0;o<a.length;o++){var s=a[o];if(s.layer===e&&s.listener===r){for(var l in s.delegates)i.off(l,s.delegates[l]);return a.splice(o,1),i}}}(this._delegatedListeners),this},i.prototype.queryRenderedFeatures=function(e,r){if(!this.style)return[];var n;if(void 0!==r||void 0===e||e instanceof t.Point||Array.isArray(e)||(r=e,e=void 0),r=r||{},(e=e||[[0,0],[this.transform.width,this.transform.height]])instanceof t.Point||\"number\"==typeof e[0])n=[t.Point.convert(e)];else{var i=t.Point.convert(e[0]),a=t.Point.convert(e[1]);n=[i,new t.Point(a.x,i.y),a,new t.Point(i.x,a.y),i]}return this.style.queryRenderedFeatures(n,r,this.transform)},i.prototype.querySourceFeatures=function(t,e){return this.style.querySourceFeatures(t,e)},i.prototype.setStyle=function(e,r){return!1!==(r=t.extend({},{localIdeographFontFamily:this._localIdeographFontFamily},r)).diff&&r.localIdeographFontFamily===this._localIdeographFontFamily&&this.style&&e?(this._diffStyle(e,r),this):(this._localIdeographFontFamily=r.localIdeographFontFamily,this._updateStyle(e,r))},i.prototype._getUIString=function(t){var e=this._locale[t];if(null==e)throw new Error(\"Missing UI string '\"+t+\"'\");return e},i.prototype._updateStyle=function(t,e){return this.style&&(this.style.setEventedParent(null),this.style._remove()),t?(this.style=new He(this,e||{}),this.style.setEventedParent(this,{style:this.style}),\"string\"==typeof t?this.style.loadURL(t):this.style.loadJSON(t),this):(delete this.style,this)},i.prototype._lazyInitEmptyStyle=function(){this.style||(this.style=new He(this,{}),this.style.setEventedParent(this,{style:this.style}),this.style.loadEmpty())},i.prototype._diffStyle=function(e,r){var n=this;if(\"string\"==typeof e){var i=this._requestManager.normalizeStyleURL(e),a=this._requestManager.transformRequest(i,t.ResourceType.Style);t.getJSON(a,(function(e,i){e?n.fire(new t.ErrorEvent(e)):i&&n._updateDiff(i,r)}))}else\"object\"==typeof e&&this._updateDiff(e,r)},i.prototype._updateDiff=function(e,r){try{this.style.setState(e)&&this._update(!0)}catch(n){t.warnOnce(\"Unable to perform style diff: \"+(n.message||n.error||n)+\".  Rebuilding the style from scratch.\"),this._updateStyle(e,r)}},i.prototype.getStyle=function(){if(this.style)return this.style.serialize()},i.prototype.isStyleLoaded=function(){return this.style?this.style.loaded():t.warnOnce(\"There is no style added to the map.\")},i.prototype.addSource=function(t,e){return this._lazyInitEmptyStyle(),this.style.addSource(t,e),this._update(!0)},i.prototype.isSourceLoaded=function(e){var r=this.style&&this.style.sourceCaches[e];if(void 0!==r)return r.loaded();this.fire(new t.ErrorEvent(new Error(\"There is no source with ID '\"+e+\"'\")))},i.prototype.areTilesLoaded=function(){var t=this.style&&this.style.sourceCaches;for(var e in t){var r=t[e]._tiles;for(var n in r){var i=r[n];if(\"loaded\"!==i.state&&\"errored\"!==i.state)return!1}}return!0},i.prototype.addSourceType=function(t,e,r){return this._lazyInitEmptyStyle(),this.style.addSourceType(t,e,r)},i.prototype.removeSource=function(t){return this.style.removeSource(t),this._update(!0)},i.prototype.getSource=function(t){return this.style.getSource(t)},i.prototype.addImage=function(e,r,n){void 0===n&&(n={});var i=n.pixelRatio;void 0===i&&(i=1);var a=n.sdf;void 0===a&&(a=!1);var o=n.stretchX,s=n.stretchY,l=n.content;this._lazyInitEmptyStyle();if(r instanceof ki||Ai&&r instanceof Ai){var c=t.browser.getImageData(r),u=c.width,f=c.height,h=c.data;this.style.addImage(e,{data:new t.RGBAImage({width:u,height:f},h),pixelRatio:i,stretchX:o,stretchY:s,content:l,sdf:a,version:0})}else{if(void 0===r.width||void 0===r.height)return this.fire(new t.ErrorEvent(new Error(\"Invalid arguments to map.addImage(). The second argument must be an `HTMLImageElement`, `ImageData`, `ImageBitmap`, or object with `width`, `height`, and `data` properties with the same format as `ImageData`\")));var p=r.width,d=r.height,m=r.data,g=r;this.style.addImage(e,{data:new t.RGBAImage({width:p,height:d},new Uint8Array(m)),pixelRatio:i,stretchX:o,stretchY:s,content:l,sdf:a,version:0,userImage:g}),g.onAdd&&g.onAdd(this,e)}},i.prototype.updateImage=function(e,r){var n=this.style.getImage(e);if(!n)return this.fire(new t.ErrorEvent(new Error(\"The map has no image with that id. If you are adding a new image use `map.addImage(...)` instead.\")));var i=r instanceof ki||Ai&&r instanceof Ai?t.browser.getImageData(r):r,a=i.width,o=i.height,s=i.data;if(void 0===a||void 0===o)return this.fire(new t.ErrorEvent(new Error(\"Invalid arguments to map.updateImage(). The second argument must be an `HTMLImageElement`, `ImageData`, `ImageBitmap`, or object with `width`, `height`, and `data` properties with the same format as `ImageData`\")));if(a!==n.data.width||o!==n.data.height)return this.fire(new t.ErrorEvent(new Error(\"The width and height of the updated image must be that same as the previous version of the image\")));var l=!(r instanceof ki||Ai&&r instanceof Ai);n.data.replace(s,l),this.style.updateImage(e,n)},i.prototype.hasImage=function(e){return e?!!this.style.getImage(e):(this.fire(new t.ErrorEvent(new Error(\"Missing required image id\"))),!1)},i.prototype.removeImage=function(t){this.style.removeImage(t)},i.prototype.loadImage=function(e,r){t.getImage(this._requestManager.transformRequest(e,t.ResourceType.Image),r)},i.prototype.listImages=function(){return this.style.listImages()},i.prototype.addLayer=function(t,e){return this._lazyInitEmptyStyle(),this.style.addLayer(t,e),this._update(!0)},i.prototype.moveLayer=function(t,e){return this.style.moveLayer(t,e),this._update(!0)},i.prototype.removeLayer=function(t){return this.style.removeLayer(t),this._update(!0)},i.prototype.getLayer=function(t){return this.style.getLayer(t)},i.prototype.setLayerZoomRange=function(t,e,r){return this.style.setLayerZoomRange(t,e,r),this._update(!0)},i.prototype.setFilter=function(t,e,r){return void 0===r&&(r={}),this.style.setFilter(t,e,r),this._update(!0)},i.prototype.getFilter=function(t){return this.style.getFilter(t)},i.prototype.setPaintProperty=function(t,e,r,n){return void 0===n&&(n={}),this.style.setPaintProperty(t,e,r,n),this._update(!0)},i.prototype.getPaintProperty=function(t,e){return this.style.getPaintProperty(t,e)},i.prototype.setLayoutProperty=function(t,e,r,n){return void 0===n&&(n={}),this.style.setLayoutProperty(t,e,r,n),this._update(!0)},i.prototype.getLayoutProperty=function(t,e){return this.style.getLayoutProperty(t,e)},i.prototype.setLight=function(t,e){return void 0===e&&(e={}),this._lazyInitEmptyStyle(),this.style.setLight(t,e),this._update(!0)},i.prototype.getLight=function(){return this.style.getLight()},i.prototype.setFeatureState=function(t,e){return this.style.setFeatureState(t,e),this._update()},i.prototype.removeFeatureState=function(t,e){return this.style.removeFeatureState(t,e),this._update()},i.prototype.getFeatureState=function(t){return this.style.getFeatureState(t)},i.prototype.getContainer=function(){return this._container},i.prototype.getCanvasContainer=function(){return this._canvasContainer},i.prototype.getCanvas=function(){return this._canvas},i.prototype._containerDimensions=function(){var t=0,e=0;return this._container&&(t=this._container.clientWidth||400,e=this._container.clientHeight||300),[t,e]},i.prototype._detectMissingCSS=function(){\"rgb(250, 128, 114)\"!==t.window.getComputedStyle(this._missingCSSCanary).getPropertyValue(\"background-color\")&&t.warnOnce(\"This page appears to be missing CSS declarations for Mapbox GL JS, which may cause the map to display incorrectly. Please ensure your page includes mapbox-gl.css, as described in https://www.mapbox.com/mapbox-gl-js/api/.\")},i.prototype._setupContainer=function(){var t=this._container;t.classList.add(\"mapboxgl-map\"),(this._missingCSSCanary=r.create(\"div\",\"mapboxgl-canary\",t)).style.visibility=\"hidden\",this._detectMissingCSS();var e=this._canvasContainer=r.create(\"div\",\"mapboxgl-canvas-container\",t);this._interactive&&e.classList.add(\"mapboxgl-interactive\"),this._canvas=r.create(\"canvas\",\"mapboxgl-canvas\",e),this._canvas.addEventListener(\"webglcontextlost\",this._contextLost,!1),this._canvas.addEventListener(\"webglcontextrestored\",this._contextRestored,!1),this._canvas.setAttribute(\"tabindex\",\"0\"),this._canvas.setAttribute(\"aria-label\",\"Map\");var n=this._containerDimensions();this._resizeCanvas(n[0],n[1]);var i=this._controlContainer=r.create(\"div\",\"mapboxgl-control-container\",t),a=this._controlPositions={};[\"top-left\",\"top-right\",\"bottom-left\",\"bottom-right\"].forEach((function(t){a[t]=r.create(\"div\",\"mapboxgl-ctrl-\"+t,i)}))},i.prototype._resizeCanvas=function(e,r){var n=t.browser.devicePixelRatio||1;this._canvas.width=n*e,this._canvas.height=n*r,this._canvas.style.width=e+\"px\",this._canvas.style.height=r+\"px\"},i.prototype._setupPainter=function(){var r=t.extend({},e.webGLContextAttributes,{failIfMajorPerformanceCaveat:this._failIfMajorPerformanceCaveat,preserveDrawingBuffer:this._preserveDrawingBuffer,antialias:this._antialias||!1}),n=this._canvas.getContext(\"webgl\",r)||this._canvas.getContext(\"experimental-webgl\",r);n?(this.painter=new _n(n,this.transform),t.webpSupported.testSupport(n)):this.fire(new t.ErrorEvent(new Error(\"Failed to initialize WebGL\")))},i.prototype._contextLost=function(e){e.preventDefault(),this._frame&&(this._frame.cancel(),this._frame=null),this.fire(new t.Event(\"webglcontextlost\",{originalEvent:e}))},i.prototype._contextRestored=function(e){this._setupPainter(),this.resize(),this._update(),this.fire(new t.Event(\"webglcontextrestored\",{originalEvent:e}))},i.prototype.loaded=function(){return!this._styleDirty&&!this._sourcesDirty&&!!this.style&&this.style.loaded()},i.prototype._update=function(t){return this.style?(this._styleDirty=this._styleDirty||t,this._sourcesDirty=!0,this.triggerRepaint(),this):this},i.prototype._requestRenderFrame=function(t){return this._update(),this._renderTaskQueue.add(t)},i.prototype._cancelRenderFrame=function(t){this._renderTaskQueue.remove(t)},i.prototype._render=function(e){var r,n=this,i=0,a=this.painter.context.extTimerQuery;if(this.listens(\"gpu-timing-frame\")&&(r=a.createQueryEXT(),a.beginQueryEXT(a.TIME_ELAPSED_EXT,r),i=t.browser.now()),this.painter.context.setDirty(),this.painter.setBaseState(),this._renderTaskQueue.run(e),!this._removed){var o=!1;if(this.style&&this._styleDirty){this._styleDirty=!1;var s=this.transform.zoom,l=t.browser.now();this.style.zoomHistory.update(s,l);var c=new t.EvaluationParameters(s,{now:l,fadeDuration:this._fadeDuration,zoomHistory:this.style.zoomHistory,transition:this.style.getTransition()}),u=c.crossFadingFactor();1===u&&u===this._crossFadingFactor||(o=!0,this._crossFadingFactor=u),this.style.update(c)}if(this.style&&this._sourcesDirty&&(this._sourcesDirty=!1,this.style._updateSources(this.transform)),this._placementDirty=this.style&&this.style._updatePlacement(this.painter.transform,this.showCollisionBoxes,this._fadeDuration,this._crossSourceCollisions),this.painter.render(this.style,{showTileBoundaries:this.showTileBoundaries,showOverdrawInspector:this._showOverdrawInspector,rotating:this.isRotating(),zooming:this.isZooming(),moving:this.isMoving(),fadeDuration:this._fadeDuration,showPadding:this.showPadding,gpuTiming:!!this.listens(\"gpu-timing-layer\")}),this.fire(new t.Event(\"render\")),this.loaded()&&!this._loaded&&(this._loaded=!0,this.fire(new t.Event(\"load\"))),this.style&&(this.style.hasTransitions()||o)&&(this._styleDirty=!0),this.style&&!this._placementDirty&&this.style._releaseSymbolFadeTiles(),this.listens(\"gpu-timing-frame\")){var f=t.browser.now()-i;a.endQueryEXT(a.TIME_ELAPSED_EXT,r),setTimeout((function(){var e=a.getQueryObjectEXT(r,a.QUERY_RESULT_EXT)/1e6;a.deleteQueryEXT(r),n.fire(new t.Event(\"gpu-timing-frame\",{cpuTime:f,gpuTime:e}))}),50)}if(this.listens(\"gpu-timing-layer\")){var h=this.painter.collectGpuTimers();setTimeout((function(){var e=n.painter.queryGpuTimers(h);n.fire(new t.Event(\"gpu-timing-layer\",{layerTimes:e}))}),50)}return this._sourcesDirty||this._styleDirty||this._placementDirty||this._repaint?this.triggerRepaint():!this.isMoving()&&this.loaded()&&(this._fullyLoaded||(this._fullyLoaded=!0),this.fire(new t.Event(\"idle\"))),this}},i.prototype.remove=function(){this._hash&&this._hash.remove();for(var e=0,r=this._controls;e<r.length;e+=1){r[e].onRemove(this)}this._controls=[],this._frame&&(this._frame.cancel(),this._frame=null),this._renderTaskQueue.clear(),this.painter.destroy(),this.handlers.destroy(),delete this.handlers,this.setStyle(null),void 0!==t.window&&(t.window.removeEventListener(\"resize\",this._onWindowResize,!1),t.window.removeEventListener(\"online\",this._onWindowOnline,!1));var n=this.painter.context.gl.getExtension(\"WEBGL_lose_context\");n&&n.loseContext(),Li(this._canvasContainer),Li(this._controlContainer),Li(this._missingCSSCanary),this._container.classList.remove(\"mapboxgl-map\"),this._removed=!0,this.fire(new t.Event(\"remove\"))},i.prototype.triggerRepaint=function(){var e=this;this.style&&!this._frame&&(this._frame=t.browser.frame((function(t){e._frame=null,e._render(t)})))},i.prototype._onWindowOnline=function(){this._update()},i.prototype._onWindowResize=function(t){this._trackResize&&this.resize({originalEvent:t})._update()},a.showTileBoundaries.get=function(){return!!this._showTileBoundaries},a.showTileBoundaries.set=function(t){this._showTileBoundaries!==t&&(this._showTileBoundaries=t,this._update())},a.showPadding.get=function(){return!!this._showPadding},a.showPadding.set=function(t){this._showPadding!==t&&(this._showPadding=t,this._update())},a.showCollisionBoxes.get=function(){return!!this._showCollisionBoxes},a.showCollisionBoxes.set=function(t){this._showCollisionBoxes!==t&&(this._showCollisionBoxes=t,t?this.style._generateCollisionBoxes():this._update())},a.showOverdrawInspector.get=function(){return!!this._showOverdrawInspector},a.showOverdrawInspector.set=function(t){this._showOverdrawInspector!==t&&(this._showOverdrawInspector=t,this._update())},a.repaint.get=function(){return!!this._repaint},a.repaint.set=function(t){this._repaint!==t&&(this._repaint=t,this.triggerRepaint())},a.vertices.get=function(){return!!this._vertices},a.vertices.set=function(t){this._vertices=t,this._update()},i.prototype._setCacheLimits=function(e,r){t.setCacheLimits(e,r)},a.version.get=function(){return t.version},Object.defineProperties(i.prototype,a),i}(xi);function Li(t){t.parentNode&&t.parentNode.removeChild(t)}var Ci={showCompass:!0,showZoom:!0,visualizePitch:!1},Pi=function(e){var n=this;this.options=t.extend({},Ci,e),this._container=r.create(\"div\",\"mapboxgl-ctrl mapboxgl-ctrl-group\"),this._container.addEventListener(\"contextmenu\",(function(t){return t.preventDefault()})),this.options.showZoom&&(t.bindAll([\"_setButtonTitle\",\"_updateZoomButtons\"],this),this._zoomInButton=this._createButton(\"mapboxgl-ctrl-zoom-in\",(function(t){return n._map.zoomIn({},{originalEvent:t})})),r.create(\"span\",\"mapboxgl-ctrl-icon\",this._zoomInButton).setAttribute(\"aria-hidden\",!0),this._zoomOutButton=this._createButton(\"mapboxgl-ctrl-zoom-out\",(function(t){return n._map.zoomOut({},{originalEvent:t})})),r.create(\"span\",\"mapboxgl-ctrl-icon\",this._zoomOutButton).setAttribute(\"aria-hidden\",!0)),this.options.showCompass&&(t.bindAll([\"_rotateCompassArrow\"],this),this._compass=this._createButton(\"mapboxgl-ctrl-compass\",(function(t){n.options.visualizePitch?n._map.resetNorthPitch({},{originalEvent:t}):n._map.resetNorth({},{originalEvent:t})})),this._compassIcon=r.create(\"span\",\"mapboxgl-ctrl-icon\",this._compass),this._compassIcon.setAttribute(\"aria-hidden\",!0))};Pi.prototype._updateZoomButtons=function(){var t=this._map.getZoom();this._zoomInButton.disabled=t===this._map.getMaxZoom(),this._zoomOutButton.disabled=t===this._map.getMinZoom()},Pi.prototype._rotateCompassArrow=function(){var t=this.options.visualizePitch?\"scale(\"+1/Math.pow(Math.cos(this._map.transform.pitch*(Math.PI/180)),.5)+\") rotateX(\"+this._map.transform.pitch+\"deg) rotateZ(\"+this._map.transform.angle*(180/Math.PI)+\"deg)\":\"rotate(\"+this._map.transform.angle*(180/Math.PI)+\"deg)\";this._compassIcon.style.transform=t},Pi.prototype.onAdd=function(t){return this._map=t,this.options.showZoom&&(this._setButtonTitle(this._zoomInButton,\"ZoomIn\"),this._setButtonTitle(this._zoomOutButton,\"ZoomOut\"),this._map.on(\"zoom\",this._updateZoomButtons),this._updateZoomButtons()),this.options.showCompass&&(this._setButtonTitle(this._compass,\"ResetBearing\"),this.options.visualizePitch&&this._map.on(\"pitch\",this._rotateCompassArrow),this._map.on(\"rotate\",this._rotateCompassArrow),this._rotateCompassArrow(),this._handler=new Ii(this._map,this._compass,this.options.visualizePitch)),this._container},Pi.prototype.onRemove=function(){r.remove(this._container),this.options.showZoom&&this._map.off(\"zoom\",this._updateZoomButtons),this.options.showCompass&&(this.options.visualizePitch&&this._map.off(\"pitch\",this._rotateCompassArrow),this._map.off(\"rotate\",this._rotateCompassArrow),this._handler.off(),delete this._handler),delete this._map},Pi.prototype._createButton=function(t,e){var n=r.create(\"button\",t,this._container);return n.type=\"button\",n.addEventListener(\"click\",e),n},Pi.prototype._setButtonTitle=function(t,e){var r=this._map._getUIString(\"NavigationControl.\"+e);t.title=r,t.setAttribute(\"aria-label\",r)};var Ii=function(e,n,i){void 0===i&&(i=!1),this._clickTolerance=10,this.element=n,this.mouseRotate=new Xn({clickTolerance:e.dragRotate._mouseRotate._clickTolerance}),this.map=e,i&&(this.mousePitch=new Zn({clickTolerance:e.dragRotate._mousePitch._clickTolerance})),t.bindAll([\"mousedown\",\"mousemove\",\"mouseup\",\"touchstart\",\"touchmove\",\"touchend\",\"reset\"],this),r.addEventListener(n,\"mousedown\",this.mousedown),r.addEventListener(n,\"touchstart\",this.touchstart,{passive:!1}),r.addEventListener(n,\"touchmove\",this.touchmove),r.addEventListener(n,\"touchend\",this.touchend),r.addEventListener(n,\"touchcancel\",this.reset)};function Oi(e,r,n){if(e=new t.LngLat(e.lng,e.lat),r){var i=new t.LngLat(e.lng-360,e.lat),a=new t.LngLat(e.lng+360,e.lat),o=n.locationPoint(e).distSqr(r);n.locationPoint(i).distSqr(r)<o?e=i:n.locationPoint(a).distSqr(r)<o&&(e=a)}for(;Math.abs(e.lng-n.center.lng)>180;){var s=n.locationPoint(e);if(s.x>=0&&s.y>=0&&s.x<=n.width&&s.y<=n.height)break;e.lng>n.center.lng?e.lng-=360:e.lng+=360}return e}Ii.prototype.down=function(t,e){this.mouseRotate.mousedown(t,e),this.mousePitch&&this.mousePitch.mousedown(t,e),r.disableDrag()},Ii.prototype.move=function(t,e){var r=this.map,n=this.mouseRotate.mousemoveWindow(t,e);if(n&&n.bearingDelta&&r.setBearing(r.getBearing()+n.bearingDelta),this.mousePitch){var i=this.mousePitch.mousemoveWindow(t,e);i&&i.pitchDelta&&r.setPitch(r.getPitch()+i.pitchDelta)}},Ii.prototype.off=function(){var t=this.element;r.removeEventListener(t,\"mousedown\",this.mousedown),r.removeEventListener(t,\"touchstart\",this.touchstart,{passive:!1}),r.removeEventListener(t,\"touchmove\",this.touchmove),r.removeEventListener(t,\"touchend\",this.touchend),r.removeEventListener(t,\"touchcancel\",this.reset),this.offTemp()},Ii.prototype.offTemp=function(){r.enableDrag(),r.removeEventListener(t.window,\"mousemove\",this.mousemove),r.removeEventListener(t.window,\"mouseup\",this.mouseup)},Ii.prototype.mousedown=function(e){this.down(t.extend({},e,{ctrlKey:!0,preventDefault:function(){return e.preventDefault()}}),r.mousePos(this.element,e)),r.addEventListener(t.window,\"mousemove\",this.mousemove),r.addEventListener(t.window,\"mouseup\",this.mouseup)},Ii.prototype.mousemove=function(t){this.move(t,r.mousePos(this.element,t))},Ii.prototype.mouseup=function(t){this.mouseRotate.mouseupWindow(t),this.mousePitch&&this.mousePitch.mouseupWindow(t),this.offTemp()},Ii.prototype.touchstart=function(t){1!==t.targetTouches.length?this.reset():(this._startPos=this._lastPos=r.touchPos(this.element,t.targetTouches)[0],this.down({type:\"mousedown\",button:0,ctrlKey:!0,preventDefault:function(){return t.preventDefault()}},this._startPos))},Ii.prototype.touchmove=function(t){1!==t.targetTouches.length?this.reset():(this._lastPos=r.touchPos(this.element,t.targetTouches)[0],this.move({preventDefault:function(){return t.preventDefault()}},this._lastPos))},Ii.prototype.touchend=function(t){0===t.targetTouches.length&&this._startPos&&this._lastPos&&this._startPos.dist(this._lastPos)<this._clickTolerance&&this.element.click(),this.reset()},Ii.prototype.reset=function(){this.mouseRotate.reset(),this.mousePitch&&this.mousePitch.reset(),delete this._startPos,delete this._lastPos,this.offTemp()};var zi={center:\"translate(-50%,-50%)\",top:\"translate(-50%,0)\",\"top-left\":\"translate(0,0)\",\"top-right\":\"translate(-100%,0)\",bottom:\"translate(-50%,-100%)\",\"bottom-left\":\"translate(0,-100%)\",\"bottom-right\":\"translate(-100%,-100%)\",left:\"translate(0,-50%)\",right:\"translate(-100%,-50%)\"};function Di(t,e,r){var n=t.classList;for(var i in zi)n.remove(\"mapboxgl-\"+r+\"-anchor-\"+i);n.add(\"mapboxgl-\"+r+\"-anchor-\"+e)}var Ri,Fi=function(e){function n(n,i){var a=this;if(e.call(this),(n instanceof t.window.HTMLElement||i)&&(n=t.extend({element:n},i)),t.bindAll([\"_update\",\"_onMove\",\"_onUp\",\"_addDragHandler\",\"_onMapClick\",\"_onKeyPress\"],this),this._anchor=n&&n.anchor||\"center\",this._color=n&&n.color||\"#3FB1CE\",this._draggable=n&&n.draggable||!1,this._state=\"inactive\",this._rotation=n&&n.rotation||0,this._rotationAlignment=n&&n.rotationAlignment||\"auto\",this._pitchAlignment=n&&n.pitchAlignment&&\"auto\"!==n.pitchAlignment?n.pitchAlignment:this._rotationAlignment,n&&n.element)this._element=n.element,this._offset=t.Point.convert(n&&n.offset||[0,0]);else{this._defaultMarker=!0,this._element=r.create(\"div\"),this._element.setAttribute(\"aria-label\",\"Map marker\");var o=r.createNS(\"http://www.w3.org/2000/svg\",\"svg\");o.setAttributeNS(null,\"display\",\"block\"),o.setAttributeNS(null,\"height\",\"41px\"),o.setAttributeNS(null,\"width\",\"27px\"),o.setAttributeNS(null,\"viewBox\",\"0 0 27 41\");var s=r.createNS(\"http://www.w3.org/2000/svg\",\"g\");s.setAttributeNS(null,\"stroke\",\"none\"),s.setAttributeNS(null,\"stroke-width\",\"1\"),s.setAttributeNS(null,\"fill\",\"none\"),s.setAttributeNS(null,\"fill-rule\",\"evenodd\");var l=r.createNS(\"http://www.w3.org/2000/svg\",\"g\");l.setAttributeNS(null,\"fill-rule\",\"nonzero\");var c=r.createNS(\"http://www.w3.org/2000/svg\",\"g\");c.setAttributeNS(null,\"transform\",\"translate(3.0, 29.0)\"),c.setAttributeNS(null,\"fill\",\"#000000\");for(var u=0,f=[{rx:\"10.5\",ry:\"5.25002273\"},{rx:\"10.5\",ry:\"5.25002273\"},{rx:\"9.5\",ry:\"4.77275007\"},{rx:\"8.5\",ry:\"4.29549936\"},{rx:\"7.5\",ry:\"3.81822308\"},{rx:\"6.5\",ry:\"3.34094679\"},{rx:\"5.5\",ry:\"2.86367051\"},{rx:\"4.5\",ry:\"2.38636864\"}];u<f.length;u+=1){var h=f[u],p=r.createNS(\"http://www.w3.org/2000/svg\",\"ellipse\");p.setAttributeNS(null,\"opacity\",\"0.04\"),p.setAttributeNS(null,\"cx\",\"10.5\"),p.setAttributeNS(null,\"cy\",\"5.80029008\"),p.setAttributeNS(null,\"rx\",h.rx),p.setAttributeNS(null,\"ry\",h.ry),c.appendChild(p)}var d=r.createNS(\"http://www.w3.org/2000/svg\",\"g\");d.setAttributeNS(null,\"fill\",this._color);var m=r.createNS(\"http://www.w3.org/2000/svg\",\"path\");m.setAttributeNS(null,\"d\",\"M27,13.5 C27,19.074644 20.250001,27.000002 14.75,34.500002 C14.016665,35.500004 12.983335,35.500004 12.25,34.500002 C6.7499993,27.000002 0,19.222562 0,13.5 C0,6.0441559 6.0441559,0 13.5,0 C20.955844,0 27,6.0441559 27,13.5 Z\"),d.appendChild(m);var g=r.createNS(\"http://www.w3.org/2000/svg\",\"g\");g.setAttributeNS(null,\"opacity\",\"0.25\"),g.setAttributeNS(null,\"fill\",\"#000000\");var v=r.createNS(\"http://www.w3.org/2000/svg\",\"path\");v.setAttributeNS(null,\"d\",\"M13.5,0 C6.0441559,0 0,6.0441559 0,13.5 C0,19.222562 6.7499993,27 12.25,34.5 C13,35.522727 14.016664,35.500004 14.75,34.5 C20.250001,27 27,19.074644 27,13.5 C27,6.0441559 20.955844,0 13.5,0 Z M13.5,1 C20.415404,1 26,6.584596 26,13.5 C26,15.898657 24.495584,19.181431 22.220703,22.738281 C19.945823,26.295132 16.705119,30.142167 13.943359,33.908203 C13.743445,34.180814 13.612715,34.322738 13.5,34.441406 C13.387285,34.322738 13.256555,34.180814 13.056641,33.908203 C10.284481,30.127985 7.4148684,26.314159 5.015625,22.773438 C2.6163816,19.232715 1,15.953538 1,13.5 C1,6.584596 6.584596,1 13.5,1 Z\"),g.appendChild(v);var y=r.createNS(\"http://www.w3.org/2000/svg\",\"g\");y.setAttributeNS(null,\"transform\",\"translate(6.0, 7.0)\"),y.setAttributeNS(null,\"fill\",\"#FFFFFF\");var x=r.createNS(\"http://www.w3.org/2000/svg\",\"g\");x.setAttributeNS(null,\"transform\",\"translate(8.0, 8.0)\");var b=r.createNS(\"http://www.w3.org/2000/svg\",\"circle\");b.setAttributeNS(null,\"fill\",\"#000000\"),b.setAttributeNS(null,\"opacity\",\"0.25\"),b.setAttributeNS(null,\"cx\",\"5.5\"),b.setAttributeNS(null,\"cy\",\"5.5\"),b.setAttributeNS(null,\"r\",\"5.4999962\");var _=r.createNS(\"http://www.w3.org/2000/svg\",\"circle\");_.setAttributeNS(null,\"fill\",\"#FFFFFF\"),_.setAttributeNS(null,\"cx\",\"5.5\"),_.setAttributeNS(null,\"cy\",\"5.5\"),_.setAttributeNS(null,\"r\",\"5.4999962\"),x.appendChild(b),x.appendChild(_),l.appendChild(c),l.appendChild(d),l.appendChild(g),l.appendChild(y),l.appendChild(x),o.appendChild(l),this._element.appendChild(o),this._offset=t.Point.convert(n&&n.offset||[0,-14])}this._element.classList.add(\"mapboxgl-marker\"),this._element.addEventListener(\"dragstart\",(function(t){t.preventDefault()})),this._element.addEventListener(\"mousedown\",(function(t){t.preventDefault()})),this._element.addEventListener(\"focus\",(function(){var t=a._map.getContainer();t.scrollTop=0,t.scrollLeft=0})),Di(this._element,this._anchor,\"marker\"),this._popup=null}return e&&(n.__proto__=e),n.prototype=Object.create(e&&e.prototype),n.prototype.constructor=n,n.prototype.addTo=function(t){return this.remove(),this._map=t,t.getCanvasContainer().appendChild(this._element),t.on(\"move\",this._update),t.on(\"moveend\",this._update),this.setDraggable(this._draggable),this._update(),this._map.on(\"click\",this._onMapClick),this},n.prototype.remove=function(){return this._map&&(this._map.off(\"click\",this._onMapClick),this._map.off(\"move\",this._update),this._map.off(\"moveend\",this._update),this._map.off(\"mousedown\",this._addDragHandler),this._map.off(\"touchstart\",this._addDragHandler),this._map.off(\"mouseup\",this._onUp),this._map.off(\"touchend\",this._onUp),this._map.off(\"mousemove\",this._onMove),this._map.off(\"touchmove\",this._onMove),delete this._map),r.remove(this._element),this._popup&&this._popup.remove(),this},n.prototype.getLngLat=function(){return this._lngLat},n.prototype.setLngLat=function(e){return this._lngLat=t.LngLat.convert(e),this._pos=null,this._popup&&this._popup.setLngLat(this._lngLat),this._update(),this},n.prototype.getElement=function(){return this._element},n.prototype.setPopup=function(t){if(this._popup&&(this._popup.remove(),this._popup=null,this._element.removeEventListener(\"keypress\",this._onKeyPress),this._originalTabIndex||this._element.removeAttribute(\"tabindex\")),t){if(!(\"offset\"in t.options)){var e=Math.sqrt(Math.pow(13.5,2)/2);t.options.offset=this._defaultMarker?{top:[0,0],\"top-left\":[0,0],\"top-right\":[0,0],bottom:[0,-38.1],\"bottom-left\":[e,-1*(24.6+e)],\"bottom-right\":[-e,-1*(24.6+e)],left:[13.5,-24.6],right:[-13.5,-24.6]}:this._offset}this._popup=t,this._lngLat&&this._popup.setLngLat(this._lngLat),this._originalTabIndex=this._element.getAttribute(\"tabindex\"),this._originalTabIndex||this._element.setAttribute(\"tabindex\",\"0\"),this._element.addEventListener(\"keypress\",this._onKeyPress)}return this},n.prototype._onKeyPress=function(t){var e=t.code,r=t.charCode||t.keyCode;\"Space\"!==e&&\"Enter\"!==e&&32!==r&&13!==r||this.togglePopup()},n.prototype._onMapClick=function(t){var e=t.originalEvent.target,r=this._element;this._popup&&(e===r||r.contains(e))&&this.togglePopup()},n.prototype.getPopup=function(){return this._popup},n.prototype.togglePopup=function(){var t=this._popup;return t?(t.isOpen()?t.remove():t.addTo(this._map),this):this},n.prototype._update=function(t){if(this._map){this._map.transform.renderWorldCopies&&(this._lngLat=Oi(this._lngLat,this._pos,this._map.transform)),this._pos=this._map.project(this._lngLat)._add(this._offset);var e=\"\";\"viewport\"===this._rotationAlignment||\"auto\"===this._rotationAlignment?e=\"rotateZ(\"+this._rotation+\"deg)\":\"map\"===this._rotationAlignment&&(e=\"rotateZ(\"+(this._rotation-this._map.getBearing())+\"deg)\");var n=\"\";\"viewport\"===this._pitchAlignment||\"auto\"===this._pitchAlignment?n=\"rotateX(0deg)\":\"map\"===this._pitchAlignment&&(n=\"rotateX(\"+this._map.getPitch()+\"deg)\"),t&&\"moveend\"!==t.type||(this._pos=this._pos.round()),r.setTransform(this._element,zi[this._anchor]+\" translate(\"+this._pos.x+\"px, \"+this._pos.y+\"px) \"+n+\" \"+e)}},n.prototype.getOffset=function(){return this._offset},n.prototype.setOffset=function(e){return this._offset=t.Point.convert(e),this._update(),this},n.prototype._onMove=function(e){this._pos=e.point.sub(this._positionDelta),this._lngLat=this._map.unproject(this._pos),this.setLngLat(this._lngLat),this._element.style.pointerEvents=\"none\",\"pending\"===this._state&&(this._state=\"active\",this.fire(new t.Event(\"dragstart\"))),this.fire(new t.Event(\"drag\"))},n.prototype._onUp=function(){this._element.style.pointerEvents=\"auto\",this._positionDelta=null,this._map.off(\"mousemove\",this._onMove),this._map.off(\"touchmove\",this._onMove),\"active\"===this._state&&this.fire(new t.Event(\"dragend\")),this._state=\"inactive\"},n.prototype._addDragHandler=function(t){this._element.contains(t.originalEvent.target)&&(t.preventDefault(),this._positionDelta=t.point.sub(this._pos).add(this._offset),this._state=\"pending\",this._map.on(\"mousemove\",this._onMove),this._map.on(\"touchmove\",this._onMove),this._map.once(\"mouseup\",this._onUp),this._map.once(\"touchend\",this._onUp))},n.prototype.setDraggable=function(t){return this._draggable=!!t,this._map&&(t?(this._map.on(\"mousedown\",this._addDragHandler),this._map.on(\"touchstart\",this._addDragHandler)):(this._map.off(\"mousedown\",this._addDragHandler),this._map.off(\"touchstart\",this._addDragHandler))),this},n.prototype.isDraggable=function(){return this._draggable},n.prototype.setRotation=function(t){return this._rotation=t||0,this._update(),this},n.prototype.getRotation=function(){return this._rotation},n.prototype.setRotationAlignment=function(t){return this._rotationAlignment=t||\"auto\",this._update(),this},n.prototype.getRotationAlignment=function(){return this._rotationAlignment},n.prototype.setPitchAlignment=function(t){return this._pitchAlignment=t&&\"auto\"!==t?t:this._rotationAlignment,this._update(),this},n.prototype.getPitchAlignment=function(){return this._pitchAlignment},n}(t.Evented),Bi={positionOptions:{enableHighAccuracy:!1,maximumAge:0,timeout:6e3},fitBoundsOptions:{maxZoom:15},trackUserLocation:!1,showAccuracyCircle:!0,showUserLocation:!0};var Ni=0,ji=!1,Ui=function(e){function n(r){e.call(this),this.options=t.extend({},Bi,r),t.bindAll([\"_onSuccess\",\"_onError\",\"_onZoom\",\"_finish\",\"_setupUI\",\"_updateCamera\",\"_updateMarker\"],this)}return e&&(n.__proto__=e),n.prototype=Object.create(e&&e.prototype),n.prototype.constructor=n,n.prototype.onAdd=function(e){var n;return this._map=e,this._container=r.create(\"div\",\"mapboxgl-ctrl mapboxgl-ctrl-group\"),n=this._setupUI,void 0!==Ri?n(Ri):void 0!==t.window.navigator.permissions?t.window.navigator.permissions.query({name:\"geolocation\"}).then((function(t){Ri=\"denied\"!==t.state,n(Ri)})):(Ri=!!t.window.navigator.geolocation,n(Ri)),this._container},n.prototype.onRemove=function(){void 0!==this._geolocationWatchID&&(t.window.navigator.geolocation.clearWatch(this._geolocationWatchID),this._geolocationWatchID=void 0),this.options.showUserLocation&&this._userLocationDotMarker&&this._userLocationDotMarker.remove(),this.options.showAccuracyCircle&&this._accuracyCircleMarker&&this._accuracyCircleMarker.remove(),r.remove(this._container),this._map.off(\"zoom\",this._onZoom),this._map=void 0,Ni=0,ji=!1},n.prototype._isOutOfMapMaxBounds=function(t){var e=this._map.getMaxBounds(),r=t.coords;return e&&(r.longitude<e.getWest()||r.longitude>e.getEast()||r.latitude<e.getSouth()||r.latitude>e.getNorth())},n.prototype._setErrorState=function(){switch(this._watchState){case\"WAITING_ACTIVE\":this._watchState=\"ACTIVE_ERROR\",this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-active\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-active-error\");break;case\"ACTIVE_LOCK\":this._watchState=\"ACTIVE_ERROR\",this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-active\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-active-error\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-waiting\");break;case\"BACKGROUND\":this._watchState=\"BACKGROUND_ERROR\",this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-background\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-background-error\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-waiting\")}},n.prototype._onSuccess=function(e){if(this._map){if(this._isOutOfMapMaxBounds(e))return this._setErrorState(),this.fire(new t.Event(\"outofmaxbounds\",e)),this._updateMarker(),void this._finish();if(this.options.trackUserLocation)switch(this._lastKnownPosition=e,this._watchState){case\"WAITING_ACTIVE\":case\"ACTIVE_LOCK\":case\"ACTIVE_ERROR\":this._watchState=\"ACTIVE_LOCK\",this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-active-error\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-active\");break;case\"BACKGROUND\":case\"BACKGROUND_ERROR\":this._watchState=\"BACKGROUND\",this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-background-error\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-background\")}this.options.showUserLocation&&\"OFF\"!==this._watchState&&this._updateMarker(e),this.options.trackUserLocation&&\"ACTIVE_LOCK\"!==this._watchState||this._updateCamera(e),this.options.showUserLocation&&this._dotElement.classList.remove(\"mapboxgl-user-location-dot-stale\"),this.fire(new t.Event(\"geolocate\",e)),this._finish()}},n.prototype._updateCamera=function(e){var r=new t.LngLat(e.coords.longitude,e.coords.latitude),n=e.coords.accuracy,i=this._map.getBearing(),a=t.extend({bearing:i},this.options.fitBoundsOptions);this._map.fitBounds(r.toBounds(n),a,{geolocateSource:!0})},n.prototype._updateMarker=function(e){if(e){var r=new t.LngLat(e.coords.longitude,e.coords.latitude);this._accuracyCircleMarker.setLngLat(r).addTo(this._map),this._userLocationDotMarker.setLngLat(r).addTo(this._map),this._accuracy=e.coords.accuracy,this.options.showUserLocation&&this.options.showAccuracyCircle&&this._updateCircleRadius()}else this._userLocationDotMarker.remove(),this._accuracyCircleMarker.remove()},n.prototype._updateCircleRadius=function(){var t=this._map._container.clientHeight/2,e=this._map.unproject([0,t]),r=this._map.unproject([1,t]),n=e.distanceTo(r),i=Math.ceil(2*this._accuracy/n);this._circleElement.style.width=i+\"px\",this._circleElement.style.height=i+\"px\"},n.prototype._onZoom=function(){this.options.showUserLocation&&this.options.showAccuracyCircle&&this._updateCircleRadius()},n.prototype._onError=function(e){if(this._map){if(this.options.trackUserLocation)if(1===e.code){this._watchState=\"OFF\",this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-active\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-active-error\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-background\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-background-error\"),this._geolocateButton.disabled=!0;var r=this._map._getUIString(\"GeolocateControl.LocationNotAvailable\");this._geolocateButton.title=r,this._geolocateButton.setAttribute(\"aria-label\",r),void 0!==this._geolocationWatchID&&this._clearWatch()}else{if(3===e.code&&ji)return;this._setErrorState()}\"OFF\"!==this._watchState&&this.options.showUserLocation&&this._dotElement.classList.add(\"mapboxgl-user-location-dot-stale\"),this.fire(new t.Event(\"error\",e)),this._finish()}},n.prototype._finish=function(){this._timeoutId&&clearTimeout(this._timeoutId),this._timeoutId=void 0},n.prototype._setupUI=function(e){var n=this;if(this._container.addEventListener(\"contextmenu\",(function(t){return t.preventDefault()})),this._geolocateButton=r.create(\"button\",\"mapboxgl-ctrl-geolocate\",this._container),r.create(\"span\",\"mapboxgl-ctrl-icon\",this._geolocateButton).setAttribute(\"aria-hidden\",!0),this._geolocateButton.type=\"button\",!1===e){t.warnOnce(\"Geolocation support is not available so the GeolocateControl will be disabled.\");var i=this._map._getUIString(\"GeolocateControl.LocationNotAvailable\");this._geolocateButton.disabled=!0,this._geolocateButton.title=i,this._geolocateButton.setAttribute(\"aria-label\",i)}else{var a=this._map._getUIString(\"GeolocateControl.FindMyLocation\");this._geolocateButton.title=a,this._geolocateButton.setAttribute(\"aria-label\",a)}this.options.trackUserLocation&&(this._geolocateButton.setAttribute(\"aria-pressed\",\"false\"),this._watchState=\"OFF\"),this.options.showUserLocation&&(this._dotElement=r.create(\"div\",\"mapboxgl-user-location-dot\"),this._userLocationDotMarker=new Fi(this._dotElement),this._circleElement=r.create(\"div\",\"mapboxgl-user-location-accuracy-circle\"),this._accuracyCircleMarker=new Fi({element:this._circleElement,pitchAlignment:\"map\"}),this.options.trackUserLocation&&(this._watchState=\"OFF\"),this._map.on(\"zoom\",this._onZoom)),this._geolocateButton.addEventListener(\"click\",this.trigger.bind(this)),this._setup=!0,this.options.trackUserLocation&&this._map.on(\"movestart\",(function(e){var r=e.originalEvent&&\"resize\"===e.originalEvent.type;e.geolocateSource||\"ACTIVE_LOCK\"!==n._watchState||r||(n._watchState=\"BACKGROUND\",n._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-background\"),n._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-active\"),n.fire(new t.Event(\"trackuserlocationend\")))}))},n.prototype.trigger=function(){if(!this._setup)return t.warnOnce(\"Geolocate control triggered before added to a map\"),!1;if(this.options.trackUserLocation){switch(this._watchState){case\"OFF\":this._watchState=\"WAITING_ACTIVE\",this.fire(new t.Event(\"trackuserlocationstart\"));break;case\"WAITING_ACTIVE\":case\"ACTIVE_LOCK\":case\"ACTIVE_ERROR\":case\"BACKGROUND_ERROR\":Ni--,ji=!1,this._watchState=\"OFF\",this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-active\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-active-error\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-background\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-background-error\"),this.fire(new t.Event(\"trackuserlocationend\"));break;case\"BACKGROUND\":this._watchState=\"ACTIVE_LOCK\",this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-background\"),this._lastKnownPosition&&this._updateCamera(this._lastKnownPosition),this.fire(new t.Event(\"trackuserlocationstart\"))}switch(this._watchState){case\"WAITING_ACTIVE\":this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-active\");break;case\"ACTIVE_LOCK\":this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-active\");break;case\"ACTIVE_ERROR\":this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-active-error\");break;case\"BACKGROUND\":this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-background\");break;case\"BACKGROUND_ERROR\":this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-background-error\")}if(\"OFF\"===this._watchState&&void 0!==this._geolocationWatchID)this._clearWatch();else if(void 0===this._geolocationWatchID){var e;this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.setAttribute(\"aria-pressed\",\"true\"),++Ni>1?(e={maximumAge:6e5,timeout:0},ji=!0):(e=this.options.positionOptions,ji=!1),this._geolocationWatchID=t.window.navigator.geolocation.watchPosition(this._onSuccess,this._onError,e)}}else t.window.navigator.geolocation.getCurrentPosition(this._onSuccess,this._onError,this.options.positionOptions),this._timeoutId=setTimeout(this._finish,1e4);return!0},n.prototype._clearWatch=function(){t.window.navigator.geolocation.clearWatch(this._geolocationWatchID),this._geolocationWatchID=void 0,this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.setAttribute(\"aria-pressed\",\"false\"),this.options.showUserLocation&&this._updateMarker(null)},n}(t.Evented),Vi={maxWidth:100,unit:\"metric\"},qi=function(e){this.options=t.extend({},Vi,e),t.bindAll([\"_onMove\",\"setUnit\"],this)};function Hi(t,e,r){var n=r&&r.maxWidth||100,i=t._container.clientHeight/2,a=t.unproject([0,i]),o=t.unproject([n,i]),s=a.distanceTo(o);if(r&&\"imperial\"===r.unit){var l=3.2808*s;if(l>5280)Gi(e,n,l/5280,t._getUIString(\"ScaleControl.Miles\"));else Gi(e,n,l,t._getUIString(\"ScaleControl.Feet\"))}else if(r&&\"nautical\"===r.unit){Gi(e,n,s/1852,t._getUIString(\"ScaleControl.NauticalMiles\"))}else s>=1e3?Gi(e,n,s/1e3,t._getUIString(\"ScaleControl.Kilometers\")):Gi(e,n,s,t._getUIString(\"ScaleControl.Meters\"))}function Gi(t,e,r,n){var i,a,o,s=(i=r,a=Math.pow(10,(\"\"+Math.floor(i)).length-1),o=(o=i/a)>=10?10:o>=5?5:o>=3?3:o>=2?2:o>=1?1:function(t){var e=Math.pow(10,Math.ceil(-Math.log(t)/Math.LN10));return Math.round(t*e)/e}(o),a*o),l=s/r;t.style.width=e*l+\"px\",t.innerHTML=s+\"&nbsp;\"+n}qi.prototype.getDefaultPosition=function(){return\"bottom-left\"},qi.prototype._onMove=function(){Hi(this._map,this._container,this.options)},qi.prototype.onAdd=function(t){return this._map=t,this._container=r.create(\"div\",\"mapboxgl-ctrl mapboxgl-ctrl-scale\",t.getContainer()),this._map.on(\"move\",this._onMove),this._onMove(),this._container},qi.prototype.onRemove=function(){r.remove(this._container),this._map.off(\"move\",this._onMove),this._map=void 0},qi.prototype.setUnit=function(t){this.options.unit=t,Hi(this._map,this._container,this.options)};var Yi=function(e){this._fullscreen=!1,e&&e.container&&(e.container instanceof t.window.HTMLElement?this._container=e.container:t.warnOnce(\"Full screen control 'container' must be a DOM element.\")),t.bindAll([\"_onClickFullscreen\",\"_changeIcon\"],this),\"onfullscreenchange\"in t.window.document?this._fullscreenchange=\"fullscreenchange\":\"onmozfullscreenchange\"in t.window.document?this._fullscreenchange=\"mozfullscreenchange\":\"onwebkitfullscreenchange\"in t.window.document?this._fullscreenchange=\"webkitfullscreenchange\":\"onmsfullscreenchange\"in t.window.document&&(this._fullscreenchange=\"MSFullscreenChange\")};Yi.prototype.onAdd=function(e){return this._map=e,this._container||(this._container=this._map.getContainer()),this._controlContainer=r.create(\"div\",\"mapboxgl-ctrl mapboxgl-ctrl-group\"),this._checkFullscreenSupport()?this._setupUI():(this._controlContainer.style.display=\"none\",t.warnOnce(\"This device does not support fullscreen mode.\")),this._controlContainer},Yi.prototype.onRemove=function(){r.remove(this._controlContainer),this._map=null,t.window.document.removeEventListener(this._fullscreenchange,this._changeIcon)},Yi.prototype._checkFullscreenSupport=function(){return!!(t.window.document.fullscreenEnabled||t.window.document.mozFullScreenEnabled||t.window.document.msFullscreenEnabled||t.window.document.webkitFullscreenEnabled)},Yi.prototype._setupUI=function(){var e=this._fullscreenButton=r.create(\"button\",\"mapboxgl-ctrl-fullscreen\",this._controlContainer);r.create(\"span\",\"mapboxgl-ctrl-icon\",e).setAttribute(\"aria-hidden\",!0),e.type=\"button\",this._updateTitle(),this._fullscreenButton.addEventListener(\"click\",this._onClickFullscreen),t.window.document.addEventListener(this._fullscreenchange,this._changeIcon)},Yi.prototype._updateTitle=function(){var t=this._getTitle();this._fullscreenButton.setAttribute(\"aria-label\",t),this._fullscreenButton.title=t},Yi.prototype._getTitle=function(){return this._map._getUIString(this._isFullscreen()?\"FullscreenControl.Exit\":\"FullscreenControl.Enter\")},Yi.prototype._isFullscreen=function(){return this._fullscreen},Yi.prototype._changeIcon=function(){(t.window.document.fullscreenElement||t.window.document.mozFullScreenElement||t.window.document.webkitFullscreenElement||t.window.document.msFullscreenElement)===this._container!==this._fullscreen&&(this._fullscreen=!this._fullscreen,this._fullscreenButton.classList.toggle(\"mapboxgl-ctrl-shrink\"),this._fullscreenButton.classList.toggle(\"mapboxgl-ctrl-fullscreen\"),this._updateTitle())},Yi.prototype._onClickFullscreen=function(){this._isFullscreen()?t.window.document.exitFullscreen?t.window.document.exitFullscreen():t.window.document.mozCancelFullScreen?t.window.document.mozCancelFullScreen():t.window.document.msExitFullscreen?t.window.document.msExitFullscreen():t.window.document.webkitCancelFullScreen&&t.window.document.webkitCancelFullScreen():this._container.requestFullscreen?this._container.requestFullscreen():this._container.mozRequestFullScreen?this._container.mozRequestFullScreen():this._container.msRequestFullscreen?this._container.msRequestFullscreen():this._container.webkitRequestFullscreen&&this._container.webkitRequestFullscreen()};var Wi={closeButton:!0,closeOnClick:!0,className:\"\",maxWidth:\"240px\"},Xi=function(e){function n(r){e.call(this),this.options=t.extend(Object.create(Wi),r),t.bindAll([\"_update\",\"_onClose\",\"remove\",\"_onMouseMove\",\"_onMouseUp\",\"_onDrag\"],this)}return e&&(n.__proto__=e),n.prototype=Object.create(e&&e.prototype),n.prototype.constructor=n,n.prototype.addTo=function(e){return this._map&&this.remove(),this._map=e,this.options.closeOnClick&&this._map.on(\"click\",this._onClose),this.options.closeOnMove&&this._map.on(\"move\",this._onClose),this._map.on(\"remove\",this.remove),this._update(),this._trackPointer?(this._map.on(\"mousemove\",this._onMouseMove),this._map.on(\"mouseup\",this._onMouseUp),this._container&&this._container.classList.add(\"mapboxgl-popup-track-pointer\"),this._map._canvasContainer.classList.add(\"mapboxgl-track-pointer\")):this._map.on(\"move\",this._update),this.fire(new t.Event(\"open\")),this},n.prototype.isOpen=function(){return!!this._map},n.prototype.remove=function(){return this._content&&r.remove(this._content),this._container&&(r.remove(this._container),delete this._container),this._map&&(this._map.off(\"move\",this._update),this._map.off(\"move\",this._onClose),this._map.off(\"click\",this._onClose),this._map.off(\"remove\",this.remove),this._map.off(\"mousemove\",this._onMouseMove),this._map.off(\"mouseup\",this._onMouseUp),this._map.off(\"drag\",this._onDrag),delete this._map),this.fire(new t.Event(\"close\")),this},n.prototype.getLngLat=function(){return this._lngLat},n.prototype.setLngLat=function(e){return this._lngLat=t.LngLat.convert(e),this._pos=null,this._trackPointer=!1,this._update(),this._map&&(this._map.on(\"move\",this._update),this._map.off(\"mousemove\",this._onMouseMove),this._container&&this._container.classList.remove(\"mapboxgl-popup-track-pointer\"),this._map._canvasContainer.classList.remove(\"mapboxgl-track-pointer\")),this},n.prototype.trackPointer=function(){return this._trackPointer=!0,this._pos=null,this._update(),this._map&&(this._map.off(\"move\",this._update),this._map.on(\"mousemove\",this._onMouseMove),this._map.on(\"drag\",this._onDrag),this._container&&this._container.classList.add(\"mapboxgl-popup-track-pointer\"),this._map._canvasContainer.classList.add(\"mapboxgl-track-pointer\")),this},n.prototype.getElement=function(){return this._container},n.prototype.setText=function(e){return this.setDOMContent(t.window.document.createTextNode(e))},n.prototype.setHTML=function(e){var r,n=t.window.document.createDocumentFragment(),i=t.window.document.createElement(\"body\");for(i.innerHTML=e;r=i.firstChild;)n.appendChild(r);return this.setDOMContent(n)},n.prototype.getMaxWidth=function(){return this._container&&this._container.style.maxWidth},n.prototype.setMaxWidth=function(t){return this.options.maxWidth=t,this._update(),this},n.prototype.setDOMContent=function(t){return this._createContent(),this._content.appendChild(t),this._update(),this},n.prototype.addClassName=function(t){this._container&&this._container.classList.add(t)},n.prototype.removeClassName=function(t){this._container&&this._container.classList.remove(t)},n.prototype.toggleClassName=function(t){if(this._container)return this._container.classList.toggle(t)},n.prototype._createContent=function(){this._content&&r.remove(this._content),this._content=r.create(\"div\",\"mapboxgl-popup-content\",this._container),this.options.closeButton&&(this._closeButton=r.create(\"button\",\"mapboxgl-popup-close-button\",this._content),this._closeButton.type=\"button\",this._closeButton.setAttribute(\"aria-label\",\"Close popup\"),this._closeButton.innerHTML=\"&#215;\",this._closeButton.addEventListener(\"click\",this._onClose))},n.prototype._onMouseUp=function(t){this._update(t.point)},n.prototype._onMouseMove=function(t){this._update(t.point)},n.prototype._onDrag=function(t){this._update(t.point)},n.prototype._update=function(e){var n=this,i=this._lngLat||this._trackPointer;if(this._map&&i&&this._content&&(this._container||(this._container=r.create(\"div\",\"mapboxgl-popup\",this._map.getContainer()),this._tip=r.create(\"div\",\"mapboxgl-popup-tip\",this._container),this._container.appendChild(this._content),this.options.className&&this.options.className.split(\" \").forEach((function(t){return n._container.classList.add(t)})),this._trackPointer&&this._container.classList.add(\"mapboxgl-popup-track-pointer\")),this.options.maxWidth&&this._container.style.maxWidth!==this.options.maxWidth&&(this._container.style.maxWidth=this.options.maxWidth),this._map.transform.renderWorldCopies&&!this._trackPointer&&(this._lngLat=Oi(this._lngLat,this._pos,this._map.transform)),!this._trackPointer||e)){var a=this._pos=this._trackPointer&&e?e:this._map.project(this._lngLat),o=this.options.anchor,s=function e(r){if(r){if(\"number\"==typeof r){var n=Math.round(Math.sqrt(.5*Math.pow(r,2)));return{center:new t.Point(0,0),top:new t.Point(0,r),\"top-left\":new t.Point(n,n),\"top-right\":new t.Point(-n,n),bottom:new t.Point(0,-r),\"bottom-left\":new t.Point(n,-n),\"bottom-right\":new t.Point(-n,-n),left:new t.Point(r,0),right:new t.Point(-r,0)}}if(r instanceof t.Point||Array.isArray(r)){var i=t.Point.convert(r);return{center:i,top:i,\"top-left\":i,\"top-right\":i,bottom:i,\"bottom-left\":i,\"bottom-right\":i,left:i,right:i}}return{center:t.Point.convert(r.center||[0,0]),top:t.Point.convert(r.top||[0,0]),\"top-left\":t.Point.convert(r[\"top-left\"]||[0,0]),\"top-right\":t.Point.convert(r[\"top-right\"]||[0,0]),bottom:t.Point.convert(r.bottom||[0,0]),\"bottom-left\":t.Point.convert(r[\"bottom-left\"]||[0,0]),\"bottom-right\":t.Point.convert(r[\"bottom-right\"]||[0,0]),left:t.Point.convert(r.left||[0,0]),right:t.Point.convert(r.right||[0,0])}}return e(new t.Point(0,0))}(this.options.offset);if(!o){var l,c=this._container.offsetWidth,u=this._container.offsetHeight;l=a.y+s.bottom.y<u?[\"top\"]:a.y>this._map.transform.height-u?[\"bottom\"]:[],a.x<c/2?l.push(\"left\"):a.x>this._map.transform.width-c/2&&l.push(\"right\"),o=0===l.length?\"bottom\":l.join(\"-\")}var f=a.add(s[o]).round();r.setTransform(this._container,zi[o]+\" translate(\"+f.x+\"px,\"+f.y+\"px)\"),Di(this._container,o,\"popup\")}},n.prototype._onClose=function(){this.remove()},n}(t.Evented);var Zi={version:t.version,supported:e,setRTLTextPlugin:t.setRTLTextPlugin,getRTLTextPluginStatus:t.getRTLTextPluginStatus,Map:Ei,NavigationControl:Pi,GeolocateControl:Ui,AttributionControl:bi,ScaleControl:qi,FullscreenControl:Yi,Popup:Xi,Marker:Fi,Style:He,LngLat:t.LngLat,LngLatBounds:t.LngLatBounds,Point:t.Point,MercatorCoordinate:t.MercatorCoordinate,Evented:t.Evented,config:t.config,prewarm:function(){Bt().acquire(zt)},clearPrewarmedResources:function(){var t=Rt;t&&(t.isPreloaded()&&1===t.numActive()?(t.release(zt),Rt=null):console.warn(\"Could not clear WebWorkers since there are active Map instances that still reference it. The pre-warmed WebWorker pool can only be cleared when all map instances have been removed with map.remove()\"))},get accessToken(){return t.config.ACCESS_TOKEN},set accessToken(e){t.config.ACCESS_TOKEN=e},get baseApiUrl(){return t.config.API_URL},set baseApiUrl(e){t.config.API_URL=e},get workerCount(){return Dt.workerCount},set workerCount(t){Dt.workerCount=t},get maxParallelImageRequests(){return t.config.MAX_PARALLEL_IMAGE_REQUESTS},set maxParallelImageRequests(e){t.config.MAX_PARALLEL_IMAGE_REQUESTS=e},clearStorage:function(e){t.clearTileCache(e)},workerUrl:\"\"};return Zi})),r}))},{}],458:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=1<<t+1,r=new Array(e),n=0;n<e;++n)r[n]=a(t,n);return r};var n=t(\"convex-hull\");function i(t,e,r){for(var n=new Array(t),i=0;i<t;++i)n[i]=0,i===e&&(n[i]+=.5),i===r&&(n[i]+=.5);return n}function a(t,e){if(0===e||e===(1<<t+1)-1)return[];for(var r=[],a=[],o=0;o<=t;++o)if(e&1<<o){r.push(i(t,o-1,o-1)),a.push(null);for(var s=0;s<=t;++s)~e&1<<s&&(r.push(i(t,o-1,s-1)),a.push([o,s]))}var l=n(r),c=[];t:for(o=0;o<l.length;++o){var u=l[o],f=[];for(s=0;s<u.length;++s){if(!a[u[s]])continue t;f.push(a[u[s]].slice())}c.push(f)}return c}},{\"convex-hull\":141}],459:[function(t,e,r){var n=t(\"./normalize\"),i=t(\"gl-mat4/create\"),a=t(\"gl-mat4/clone\"),o=t(\"gl-mat4/determinant\"),s=t(\"gl-mat4/invert\"),l=t(\"gl-mat4/transpose\"),c={length:t(\"gl-vec3/length\"),normalize:t(\"gl-vec3/normalize\"),dot:t(\"gl-vec3/dot\"),cross:t(\"gl-vec3/cross\")},u=i(),f=i(),h=[0,0,0,0],p=[[0,0,0],[0,0,0],[0,0,0]],d=[0,0,0];function m(t,e,r,n,i){t[0]=e[0]*n+r[0]*i,t[1]=e[1]*n+r[1]*i,t[2]=e[2]*n+r[2]*i}e.exports=function(t,e,r,i,g,v){if(e||(e=[0,0,0]),r||(r=[0,0,0]),i||(i=[0,0,0]),g||(g=[0,0,0,1]),v||(v=[0,0,0,1]),!n(u,t))return!1;if(a(f,u),f[3]=0,f[7]=0,f[11]=0,f[15]=1,Math.abs(o(f)<1e-8))return!1;var y,x,b,_,w,T,k,M=u[3],A=u[7],S=u[11],E=u[12],L=u[13],C=u[14],P=u[15];if(0!==M||0!==A||0!==S){if(h[0]=M,h[1]=A,h[2]=S,h[3]=P,!s(f,f))return!1;l(f,f),y=g,b=f,_=(x=h)[0],w=x[1],T=x[2],k=x[3],y[0]=b[0]*_+b[4]*w+b[8]*T+b[12]*k,y[1]=b[1]*_+b[5]*w+b[9]*T+b[13]*k,y[2]=b[2]*_+b[6]*w+b[10]*T+b[14]*k,y[3]=b[3]*_+b[7]*w+b[11]*T+b[15]*k}else g[0]=g[1]=g[2]=0,g[3]=1;if(e[0]=E,e[1]=L,e[2]=C,function(t,e){t[0][0]=e[0],t[0][1]=e[1],t[0][2]=e[2],t[1][0]=e[4],t[1][1]=e[5],t[1][2]=e[6],t[2][0]=e[8],t[2][1]=e[9],t[2][2]=e[10]}(p,u),r[0]=c.length(p[0]),c.normalize(p[0],p[0]),i[0]=c.dot(p[0],p[1]),m(p[1],p[1],p[0],1,-i[0]),r[1]=c.length(p[1]),c.normalize(p[1],p[1]),i[0]/=r[1],i[1]=c.dot(p[0],p[2]),m(p[2],p[2],p[0],1,-i[1]),i[2]=c.dot(p[1],p[2]),m(p[2],p[2],p[1],1,-i[2]),r[2]=c.length(p[2]),c.normalize(p[2],p[2]),i[1]/=r[2],i[2]/=r[2],c.cross(d,p[1],p[2]),c.dot(p[0],d)<0)for(var I=0;I<3;I++)r[I]*=-1,p[I][0]*=-1,p[I][1]*=-1,p[I][2]*=-1;return v[0]=.5*Math.sqrt(Math.max(1+p[0][0]-p[1][1]-p[2][2],0)),v[1]=.5*Math.sqrt(Math.max(1-p[0][0]+p[1][1]-p[2][2],0)),v[2]=.5*Math.sqrt(Math.max(1-p[0][0]-p[1][1]+p[2][2],0)),v[3]=.5*Math.sqrt(Math.max(1+p[0][0]+p[1][1]+p[2][2],0)),p[2][1]>p[1][2]&&(v[0]=-v[0]),p[0][2]>p[2][0]&&(v[1]=-v[1]),p[1][0]>p[0][1]&&(v[2]=-v[2]),!0}},{\"./normalize\":460,\"gl-mat4/clone\":280,\"gl-mat4/create\":282,\"gl-mat4/determinant\":283,\"gl-mat4/invert\":295,\"gl-mat4/transpose\":308,\"gl-vec3/cross\":364,\"gl-vec3/dot\":369,\"gl-vec3/length\":379,\"gl-vec3/normalize\":386}],460:[function(t,e,r){e.exports=function(t,e){var r=e[15];if(0===r)return!1;for(var n=1/r,i=0;i<16;i++)t[i]=e[i]*n;return!0}},{}],461:[function(t,e,r){var n=t(\"gl-vec3/lerp\"),i=t(\"mat4-recompose\"),a=t(\"mat4-decompose\"),o=t(\"gl-mat4/determinant\"),s=t(\"quat-slerp\"),l=f(),c=f(),u=f();function f(){return{translate:h(),scale:h(1),skew:h(),perspective:[0,0,0,1],quaternion:[0,0,0,1]}}function h(t){return[t||0,t||0,t||0]}e.exports=function(t,e,r,f){if(0===o(e)||0===o(r))return!1;var h=a(e,l.translate,l.scale,l.skew,l.perspective,l.quaternion),p=a(r,c.translate,c.scale,c.skew,c.perspective,c.quaternion);return!(!h||!p)&&(n(u.translate,l.translate,c.translate,f),n(u.skew,l.skew,c.skew,f),n(u.scale,l.scale,c.scale,f),n(u.perspective,l.perspective,c.perspective,f),s(u.quaternion,l.quaternion,c.quaternion,f),i(t,u.translate,u.scale,u.skew,u.perspective,u.quaternion),!0)}},{\"gl-mat4/determinant\":283,\"gl-vec3/lerp\":380,\"mat4-decompose\":459,\"mat4-recompose\":462,\"quat-slerp\":525}],462:[function(t,e,r){var n={identity:t(\"gl-mat4/identity\"),translate:t(\"gl-mat4/translate\"),multiply:t(\"gl-mat4/multiply\"),create:t(\"gl-mat4/create\"),scale:t(\"gl-mat4/scale\"),fromRotationTranslation:t(\"gl-mat4/fromRotationTranslation\")},i=(n.create(),n.create());e.exports=function(t,e,r,a,o,s){return n.identity(t),n.fromRotationTranslation(t,s,e),t[3]=o[0],t[7]=o[1],t[11]=o[2],t[15]=o[3],n.identity(i),0!==a[2]&&(i[9]=a[2],n.multiply(t,t,i)),0!==a[1]&&(i[9]=0,i[8]=a[1],n.multiply(t,t,i)),0!==a[0]&&(i[8]=0,i[4]=a[0],n.multiply(t,t,i)),n.scale(t,t,r),t}},{\"gl-mat4/create\":282,\"gl-mat4/fromRotationTranslation\":286,\"gl-mat4/identity\":293,\"gl-mat4/multiply\":297,\"gl-mat4/scale\":305,\"gl-mat4/translate\":307}],463:[function(t,e,r){\"use strict\";e.exports=Math.log2||function(t){return Math.log(t)*Math.LOG2E}},{}],464:[function(t,e,r){\"use strict\";var n=t(\"binary-search-bounds\"),i=t(\"mat4-interpolate\"),a=t(\"gl-mat4/invert\"),o=t(\"gl-mat4/rotateX\"),s=t(\"gl-mat4/rotateY\"),l=t(\"gl-mat4/rotateZ\"),c=t(\"gl-mat4/lookAt\"),u=t(\"gl-mat4/translate\"),f=(t(\"gl-mat4/scale\"),t(\"gl-vec3/normalize\")),h=[0,0,0];function p(t){this._components=t.slice(),this._time=[0],this.prevMatrix=t.slice(),this.nextMatrix=t.slice(),this.computedMatrix=t.slice(),this.computedInverse=t.slice(),this.computedEye=[0,0,0],this.computedUp=[0,0,0],this.computedCenter=[0,0,0],this.computedRadius=[0],this._limits=[-1/0,1/0]}e.exports=function(t){return new p((t=t||{}).matrix||[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1])};var d=p.prototype;d.recalcMatrix=function(t){var e=this._time,r=n.le(e,t),o=this.computedMatrix;if(!(r<0)){var s=this._components;if(r===e.length-1)for(var l=16*r,c=0;c<16;++c)o[c]=s[l++];else{var u=e[r+1]-e[r],h=(l=16*r,this.prevMatrix),p=!0;for(c=0;c<16;++c)h[c]=s[l++];var d=this.nextMatrix;for(c=0;c<16;++c)d[c]=s[l++],p=p&&h[c]===d[c];if(u<1e-6||p)for(c=0;c<16;++c)o[c]=h[c];else i(o,h,d,(t-e[r])/u)}var m=this.computedUp;m[0]=o[1],m[1]=o[5],m[2]=o[9],f(m,m);var g=this.computedInverse;a(g,o);var v=this.computedEye,y=g[15];v[0]=g[12]/y,v[1]=g[13]/y,v[2]=g[14]/y;var x=this.computedCenter,b=Math.exp(this.computedRadius[0]);for(c=0;c<3;++c)x[c]=v[c]-o[2+4*c]*b}},d.idle=function(t){if(!(t<this.lastT())){for(var e=this._components,r=e.length-16,n=0;n<16;++n)e.push(e[r++]);this._time.push(t)}},d.flush=function(t){var e=n.gt(this._time,t)-2;e<0||(this._time.splice(0,e),this._components.splice(0,16*e))},d.lastT=function(){return this._time[this._time.length-1]},d.lookAt=function(t,e,r,n){this.recalcMatrix(t),e=e||this.computedEye,r=r||h,n=n||this.computedUp,this.setMatrix(t,c(this.computedMatrix,e,r,n));for(var i=0,a=0;a<3;++a)i+=Math.pow(r[a]-e[a],2);i=Math.log(Math.sqrt(i)),this.computedRadius[0]=i},d.rotate=function(t,e,r,n){this.recalcMatrix(t);var i=this.computedInverse;e&&s(i,i,e),r&&o(i,i,r),n&&l(i,i,n),this.setMatrix(t,a(this.computedMatrix,i))};var m=[0,0,0];d.pan=function(t,e,r,n){m[0]=-(e||0),m[1]=-(r||0),m[2]=-(n||0),this.recalcMatrix(t);var i=this.computedInverse;u(i,i,m),this.setMatrix(t,a(i,i))},d.translate=function(t,e,r,n){m[0]=e||0,m[1]=r||0,m[2]=n||0,this.recalcMatrix(t);var i=this.computedMatrix;u(i,i,m),this.setMatrix(t,i)},d.setMatrix=function(t,e){if(!(t<this.lastT())){this._time.push(t);for(var r=0;r<16;++r)this._components.push(e[r])}},d.setDistance=function(t,e){this.computedRadius[0]=e},d.setDistanceLimits=function(t,e){var r=this._limits;r[0]=t,r[1]=e},d.getDistanceLimits=function(t){var e=this._limits;return t?(t[0]=e[0],t[1]=e[1],t):e}},{\"binary-search-bounds\":103,\"gl-mat4/invert\":295,\"gl-mat4/lookAt\":296,\"gl-mat4/rotateX\":302,\"gl-mat4/rotateY\":303,\"gl-mat4/rotateZ\":304,\"gl-mat4/scale\":305,\"gl-mat4/translate\":307,\"gl-vec3/normalize\":386,\"mat4-interpolate\":461}],465:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.length;if(e<3){for(var r=new Array(e),i=0;i<e;++i)r[i]=i;return 2===e&&t[0][0]===t[1][0]&&t[0][1]===t[1][1]?[0]:r}var a=new Array(e);for(i=0;i<e;++i)a[i]=i;a.sort((function(e,r){var n=t[e][0]-t[r][0];return n||t[e][1]-t[r][1]}));var o=[a[0],a[1]],s=[a[0],a[1]];for(i=2;i<e;++i){for(var l=a[i],c=t[l],u=o.length;u>1&&n(t[o[u-2]],t[o[u-1]],c)<=0;)u-=1,o.pop();for(o.push(l),u=s.length;u>1&&n(t[s[u-2]],t[s[u-1]],c)>=0;)u-=1,s.pop();s.push(l)}r=new Array(s.length+o.length-2);for(var f=0,h=(i=0,o.length);i<h;++i)r[f++]=o[i];for(var p=s.length-2;p>0;--p)r[f++]=s[p];return r};var n=t(\"robust-orientation\")[3]},{\"robust-orientation\":544}],466:[function(t,e,r){\"use strict\";e.exports=function(t,e){e||(e=t,t=window);var r=0,i=0,a=0,o={shift:!1,alt:!1,control:!1,meta:!1},s=!1;function l(t){var e=!1;return\"altKey\"in t&&(e=e||t.altKey!==o.alt,o.alt=!!t.altKey),\"shiftKey\"in t&&(e=e||t.shiftKey!==o.shift,o.shift=!!t.shiftKey),\"ctrlKey\"in t&&(e=e||t.ctrlKey!==o.control,o.control=!!t.ctrlKey),\"metaKey\"in t&&(e=e||t.metaKey!==o.meta,o.meta=!!t.metaKey),e}function c(t,s){var c=n.x(s),u=n.y(s);\"buttons\"in s&&(t=0|s.buttons),(t!==r||c!==i||u!==a||l(s))&&(r=0|t,i=c||0,a=u||0,e&&e(r,i,a,o))}function u(t){c(0,t)}function f(){(r||i||a||o.shift||o.alt||o.meta||o.control)&&(i=a=0,r=0,o.shift=o.alt=o.control=o.meta=!1,e&&e(0,0,0,o))}function h(t){l(t)&&e&&e(r,i,a,o)}function p(t){0===n.buttons(t)?c(0,t):c(r,t)}function d(t){c(r|n.buttons(t),t)}function m(t){c(r&~n.buttons(t),t)}function g(){s||(s=!0,t.addEventListener(\"mousemove\",p),t.addEventListener(\"mousedown\",d),t.addEventListener(\"mouseup\",m),t.addEventListener(\"mouseleave\",u),t.addEventListener(\"mouseenter\",u),t.addEventListener(\"mouseout\",u),t.addEventListener(\"mouseover\",u),t.addEventListener(\"blur\",f),t.addEventListener(\"keyup\",h),t.addEventListener(\"keydown\",h),t.addEventListener(\"keypress\",h),t!==window&&(window.addEventListener(\"blur\",f),window.addEventListener(\"keyup\",h),window.addEventListener(\"keydown\",h),window.addEventListener(\"keypress\",h)))}g();var v={element:t};return Object.defineProperties(v,{enabled:{get:function(){return s},set:function(e){e?g():function(){if(!s)return;s=!1,t.removeEventListener(\"mousemove\",p),t.removeEventListener(\"mousedown\",d),t.removeEventListener(\"mouseup\",m),t.removeEventListener(\"mouseleave\",u),t.removeEventListener(\"mouseenter\",u),t.removeEventListener(\"mouseout\",u),t.removeEventListener(\"mouseover\",u),t.removeEventListener(\"blur\",f),t.removeEventListener(\"keyup\",h),t.removeEventListener(\"keydown\",h),t.removeEventListener(\"keypress\",h),t!==window&&(window.removeEventListener(\"blur\",f),window.removeEventListener(\"keyup\",h),window.removeEventListener(\"keydown\",h),window.removeEventListener(\"keypress\",h))}()},enumerable:!0},buttons:{get:function(){return r},enumerable:!0},x:{get:function(){return i},enumerable:!0},y:{get:function(){return a},enumerable:!0},mods:{get:function(){return o},enumerable:!0}}),v};var n=t(\"mouse-event\")},{\"mouse-event\":468}],467:[function(t,e,r){var n={left:0,top:0};e.exports=function(t,e,r){e=e||t.currentTarget||t.srcElement,Array.isArray(r)||(r=[0,0]);var i=t.clientX||0,a=t.clientY||0,o=(s=e,s===window||s===document||s===document.body?n:s.getBoundingClientRect());var s;return r[0]=i-o.left,r[1]=a-o.top,r}},{}],468:[function(t,e,r){\"use strict\";function n(t){return t.target||t.srcElement||window}r.buttons=function(t){if(\"object\"==typeof t){if(\"buttons\"in t)return t.buttons;if(\"which\"in t){if(2===(e=t.which))return 4;if(3===e)return 2;if(e>0)return 1<<e-1}else if(\"button\"in t){var e;if(1===(e=t.button))return 4;if(2===e)return 2;if(e>=0)return 1<<e}}return 0},r.element=n,r.x=function(t){if(\"object\"==typeof t){if(\"offsetX\"in t)return t.offsetX;var e=n(t).getBoundingClientRect();return t.clientX-e.left}return 0},r.y=function(t){if(\"object\"==typeof t){if(\"offsetY\"in t)return t.offsetY;var e=n(t).getBoundingClientRect();return t.clientY-e.top}return 0}},{}],469:[function(t,e,r){\"use strict\";var n=t(\"to-px\");e.exports=function(t,e,r){\"function\"==typeof t&&(r=!!e,e=t,t=window);var i=n(\"ex\",t),a=function(t){r&&t.preventDefault();var n=t.deltaX||0,a=t.deltaY||0,o=t.deltaZ||0,s=1;switch(t.deltaMode){case 1:s=i;break;case 2:s=window.innerHeight}if(a*=s,o*=s,(n*=s)||a||o)return e(n,a,o,t)};return t.addEventListener(\"wheel\",a),a}},{\"to-px\":596}],470:[function(t,e,r){(function(t,r){(function(){\n",
       "/*! Native Promise Only\n",
       "    v0.8.1 (c) Kyle Simpson\n",
       "    MIT License: http://getify.mit-license.org\n",
       "*/\n",
       "!function(t,r,n){r[t]=r[t]||n(),void 0!==e&&e.exports&&(e.exports=r[t])}(\"Promise\",void 0!==t?t:this,(function(){\"use strict\";var t,e,n,i=Object.prototype.toString,a=void 0!==r?function(t){return r(t)}:setTimeout;try{Object.defineProperty({},\"x\",{}),t=function(t,e,r,n){return Object.defineProperty(t,e,{value:r,writable:!0,configurable:!1!==n})}}catch(e){t=function(t,e,r){return t[e]=r,t}}function o(t,r){n.add(t,r),e||(e=a(n.drain))}function s(t){var e,r=typeof t;return null==t||\"object\"!=r&&\"function\"!=r||(e=t.then),\"function\"==typeof e&&e}function l(){for(var t=0;t<this.chain.length;t++)c(this,1===this.state?this.chain[t].success:this.chain[t].failure,this.chain[t]);this.chain.length=0}function c(t,e,r){var n,i;try{!1===e?r.reject(t.msg):(n=!0===e?t.msg:e.call(void 0,t.msg))===r.promise?r.reject(TypeError(\"Promise-chain cycle\")):(i=s(n))?i.call(n,r.resolve,r.reject):r.resolve(n)}catch(t){r.reject(t)}}function u(t){var e,r=this;if(!r.triggered){r.triggered=!0,r.def&&(r=r.def);try{(e=s(t))?o((function(){var n=new p(r);try{e.call(t,(function(){u.apply(n,arguments)}),(function(){f.apply(n,arguments)}))}catch(t){f.call(n,t)}})):(r.msg=t,r.state=1,r.chain.length>0&&o(l,r))}catch(t){f.call(new p(r),t)}}}function f(t){var e=this;e.triggered||(e.triggered=!0,e.def&&(e=e.def),e.msg=t,e.state=2,e.chain.length>0&&o(l,e))}function h(t,e,r,n){for(var i=0;i<e.length;i++)!function(i){t.resolve(e[i]).then((function(t){r(i,t)}),n)}(i)}function p(t){this.def=t,this.triggered=!1}function d(t){this.promise=t,this.state=0,this.triggered=!1,this.chain=[],this.msg=void 0}function m(t){if(\"function\"!=typeof t)throw TypeError(\"Not a function\");if(0!==this.__NPO__)throw TypeError(\"Not a promise\");this.__NPO__=1;var e=new d(this);this.then=function(t,r){var n={success:\"function\"!=typeof t||t,failure:\"function\"==typeof r&&r};return n.promise=new this.constructor((function(t,e){if(\"function\"!=typeof t||\"function\"!=typeof e)throw TypeError(\"Not a function\");n.resolve=t,n.reject=e})),e.chain.push(n),0!==e.state&&o(l,e),n.promise},this.catch=function(t){return this.then(void 0,t)};try{t.call(void 0,(function(t){u.call(e,t)}),(function(t){f.call(e,t)}))}catch(t){f.call(e,t)}}n=function(){var t,r,n;function i(t,e){this.fn=t,this.self=e,this.next=void 0}return{add:function(e,a){n=new i(e,a),r?r.next=n:t=n,r=n,n=void 0},drain:function(){var n=t;for(t=r=e=void 0;n;)n.fn.call(n.self),n=n.next}}}();var g=t({},\"constructor\",m,!1);return m.prototype=g,t(g,\"__NPO__\",0,!1),t(m,\"resolve\",(function(t){return t&&\"object\"==typeof t&&1===t.__NPO__?t:new this((function(e,r){if(\"function\"!=typeof e||\"function\"!=typeof r)throw TypeError(\"Not a function\");e(t)}))})),t(m,\"reject\",(function(t){return new this((function(e,r){if(\"function\"!=typeof e||\"function\"!=typeof r)throw TypeError(\"Not a function\");r(t)}))})),t(m,\"all\",(function(t){var e=this;return\"[object Array]\"!=i.call(t)?e.reject(TypeError(\"Not an array\")):0===t.length?e.resolve([]):new e((function(r,n){if(\"function\"!=typeof r||\"function\"!=typeof n)throw TypeError(\"Not a function\");var i=t.length,a=Array(i),o=0;h(e,t,(function(t,e){a[t]=e,++o===i&&r(a)}),n)}))})),t(m,\"race\",(function(t){var e=this;return\"[object Array]\"!=i.call(t)?e.reject(TypeError(\"Not an array\")):new e((function(r,n){if(\"function\"!=typeof r||\"function\"!=typeof n)throw TypeError(\"Not a function\");h(e,t,(function(t,e){r(e)}),n)}))})),m}))}).call(this)}).call(this,\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{},t(\"timers\").setImmediate)},{timers:593}],471:[function(t,e,r){\"use strict\";var n=t(\"typedarray-pool\");function i(t){return\"a\"+t}function a(t){return\"d\"+t}function o(t,e){return\"c\"+t+\"_\"+e}function s(t){return\"s\"+t}function l(t,e){return\"t\"+t+\"_\"+e}function c(t){return\"o\"+t}function u(t){return\"x\"+t}function f(t){return\"p\"+t}function h(t,e){return\"d\"+t+\"_\"+e}function p(t){return\"i\"+t}function d(t,e){return\"u\"+t+\"_\"+e}function m(t){return\"b\"+t}function g(t){return\"y\"+t}function v(t){return\"e\"+t}function y(t){return\"v\"+t}e.exports=function(t){function e(t){throw new Error(\"ndarray-extract-contour: \"+t)}\"object\"!=typeof t&&e(\"Must specify arguments\");var r=t.order;Array.isArray(r)||e(\"Must specify order\");var b=t.arrayArguments||1;b<1&&e(\"Must have at least one array argument\");var _=t.scalarArguments||0;_<0&&e(\"Scalar arg count must be > 0\");\"function\"!=typeof t.vertex&&e(\"Must specify vertex creation function\");\"function\"!=typeof t.cell&&e(\"Must specify cell creation function\");\"function\"!=typeof t.phase&&e(\"Must specify phase function\");for(var w=t.getters||[],T=new Array(b),k=0;k<b;++k)w.indexOf(k)>=0?T[k]=!0:T[k]=!1;return function(t,e,r,b,_,w){var T=w.length,k=_.length;if(k<2)throw new Error(\"ndarray-extract-contour: Dimension must be at least 2\");for(var M=\"extractContour\"+_.join(\"_\"),A=[],S=[],E=[],L=0;L<T;++L)E.push(i(L));for(L=0;L<b;++L)E.push(u(L));for(L=0;L<k;++L)S.push(s(L)+\"=\"+i(0)+\".shape[\"+L+\"]|0\");for(L=0;L<T;++L){S.push(a(L)+\"=\"+i(L)+\".data\",c(L)+\"=\"+i(L)+\".offset|0\");for(var C=0;C<k;++C)S.push(l(L,C)+\"=\"+i(L)+\".stride[\"+C+\"]|0\")}for(L=0;L<T;++L){S.push(f(L)+\"=\"+c(L)),S.push(o(L,0));for(C=1;C<1<<k;++C){for(var P=[],I=0;I<k;++I)C&1<<I&&P.push(\"-\"+l(L,I));S.push(h(L,C)+\"=(\"+P.join(\"\")+\")|0\"),S.push(o(L,C)+\"=0\")}}for(L=0;L<T;++L)for(C=0;C<k;++C){var O=[l(L,_[C])];C>0&&O.push(l(L,_[C-1])+\"*\"+s(_[C-1])),S.push(d(L,_[C])+\"=(\"+O.join(\"-\")+\")|0\")}for(L=0;L<k;++L)S.push(p(L)+\"=0\");S.push(\"N=0\");var z=[\"2\"];for(L=k-2;L>=0;--L)z.push(s(_[L]));S.push(\"Q=(\"+z.join(\"*\")+\")|0\",\"P=mallocUint32(Q)\",\"V=mallocUint32(Q)\",\"X=0\"),S.push(m(0)+\"=0\");for(C=1;C<1<<k;++C){var D=[],R=[];for(I=0;I<k;++I)C&1<<I&&(0===R.length?D.push(\"1\"):D.unshift(R.join(\"*\"))),R.push(s(_[I]));var F=\"\";D[0].indexOf(s(_[k-2]))<0&&(F=\"-\");var B=x(k,C,_);S.push(v(B)+\"=(-\"+D.join(\"-\")+\")|0\",g(B)+\"=(\"+F+D.join(\"-\")+\")|0\",m(B)+\"=0\")}function N(t,e){A.push(\"for(\",p(_[t]),\"=\",e,\";\",p(_[t]),\"<\",s(_[t]),\";\",\"++\",p(_[t]),\"){\")}function j(t){for(var e=0;e<T;++e)A.push(f(e),\"+=\",d(e,_[t]),\";\");A.push(\"}\")}function U(){for(var t=1;t<1<<k;++t)A.push(\"T\",\"=\",v(t),\";\",v(t),\"=\",g(t),\";\",g(t),\"=\",\"T\",\";\")}S.push(y(0)+\"=0\",\"T=0\"),function t(e,r){if(e<0)!function(t){for(var e=0;e<T;++e)w[e]?A.push(o(e,0),\"=\",a(e),\".get(\",f(e),\");\"):A.push(o(e,0),\"=\",a(e),\"[\",f(e),\"];\");var r=[];for(e=0;e<T;++e)r.push(o(e,0));for(e=0;e<b;++e)r.push(u(e));A.push(m(0),\"=\",\"P\",\"[\",\"X\",\"]=phase(\",r.join(),\");\");for(var n=1;n<1<<k;++n)A.push(m(n),\"=\",\"P\",\"[\",\"X\",\"+\",v(n),\"];\");var i=[];for(n=1;n<1<<k;++n)i.push(\"(\"+m(0)+\"!==\"+m(n)+\")\");A.push(\"if(\",i.join(\"||\"),\"){\");var s=[];for(e=0;e<k;++e)s.push(p(e));for(e=0;e<T;++e){s.push(o(e,0));for(n=1;n<1<<k;++n)w[e]?A.push(o(e,n),\"=\",a(e),\".get(\",f(e),\"+\",h(e,n),\");\"):A.push(o(e,n),\"=\",a(e),\"[\",f(e),\"+\",h(e,n),\"];\"),s.push(o(e,n))}for(e=0;e<1<<k;++e)s.push(m(e));for(e=0;e<b;++e)s.push(u(e));A.push(\"vertex(\",s.join(),\");\",y(0),\"=\",\"V\",\"[\",\"X\",\"]=\",\"N\",\"++;\");var l=(1<<k)-1,c=m(l);for(n=0;n<k;++n)if(0==(t&~(1<<n))){for(var d=l^1<<n,g=m(d),x=[],_=d;_>0;_=_-1&d)x.push(\"V[X+\"+v(_)+\"]\");x.push(y(0));for(_=0;_<T;++_)1&n?x.push(o(_,l),o(_,d)):x.push(o(_,d),o(_,l));1&n?x.push(c,g):x.push(g,c);for(_=0;_<b;++_)x.push(u(_));A.push(\"if(\",c,\"!==\",g,\"){\",\"face(\",x.join(),\")}\")}A.push(\"}\",\"X\",\"+=1;\")}(r);else{!function(t){for(var e=t-1;e>=0;--e)N(e,0);var r=[];for(e=0;e<T;++e)w[e]?r.push(a(e)+\".get(\"+f(e)+\")\"):r.push(a(e)+\"[\"+f(e)+\"]\");for(e=0;e<b;++e)r.push(u(e));for(A.push(\"P\",\"[\",\"X\",\"++]=phase(\",r.join(),\");\"),e=0;e<t;++e)j(e);for(var n=0;n<T;++n)A.push(f(n),\"+=\",d(n,_[t]),\";\")}(e),A.push(\"if(\",s(_[e]),\">0){\",p(_[e]),\"=1;\"),t(e-1,r|1<<_[e]);for(var n=0;n<T;++n)A.push(f(n),\"+=\",d(n,_[e]),\";\");e===k-1&&(A.push(\"X\",\"=0;\"),U()),N(e,2),t(e-1,r),e===k-1&&(A.push(\"if(\",p(_[k-1]),\"&1){\",\"X\",\"=0;}\"),U()),j(e),A.push(\"}\")}}(k-1,0),A.push(\"freeUint32(\",\"V\",\");freeUint32(\",\"P\",\");\");var V=[\"'use strict';\",\"function \",M,\"(\",E.join(),\"){\",\"var \",S.join(),\";\",A.join(\"\"),\"}\",\"return \",M].join(\"\");return new Function(\"vertex\",\"face\",\"phase\",\"mallocUint32\",\"freeUint32\",V)(t,e,r,n.mallocUint32,n.freeUint32)}(t.vertex,t.cell,t.phase,_,r,T)};function x(t,e,r){for(var n=0,i=0;i<t;++i)e&1<<i&&(n|=1<<r[i]);return n}},{\"typedarray-pool\":613}],472:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){if(Array.isArray(r)){if(r.length!==e.dimension)throw new Error(\"ndarray-gradient: invalid boundary conditions\")}else r=n(e.dimension,\"string\"==typeof r?r:\"clamp\");if(t.dimension!==e.dimension+1)throw new Error(\"ndarray-gradient: output dimension must be +1 input dimension\");if(t.shape[e.dimension]!==e.dimension)throw new Error(\"ndarray-gradient: output shape must match input shape\");for(var i=0;i<e.dimension;++i)if(t.shape[i]!==e.shape[i])throw new Error(\"ndarray-gradient: shape mismatch\");if(0===e.size)return t;if(e.dimension<=0)return t.set(0),t;return function(t){var e=t.join();if(v=o[e])return v;var r=t.length,n=[\"function gradient(dst,src){var s=src.shape.slice();\"];function i(e){for(var i=r-e.length,a=[],o=[],s=[],l=0;l<r;++l)e.indexOf(l+1)>=0?s.push(\"0\"):e.indexOf(-(l+1))>=0?s.push(\"s[\"+l+\"]-1\"):(s.push(\"-1\"),a.push(\"1\"),o.push(\"s[\"+l+\"]-2\"));var c=\".lo(\"+a.join()+\").hi(\"+o.join()+\")\";if(0===a.length&&(c=\"\"),i>0){n.push(\"if(1\");for(l=0;l<r;++l)e.indexOf(l+1)>=0||e.indexOf(-(l+1))>=0||n.push(\"&&s[\",l,\"]>2\");n.push(\"){grad\",i,\"(src.pick(\",s.join(),\")\",c);for(l=0;l<r;++l)e.indexOf(l+1)>=0||e.indexOf(-(l+1))>=0||n.push(\",dst.pick(\",s.join(),\",\",l,\")\",c);n.push(\");\")}for(l=0;l<e.length;++l){var u=Math.abs(e[l])-1,f=\"dst.pick(\"+s.join()+\",\"+u+\")\"+c;switch(t[u]){case\"clamp\":var h=s.slice(),p=s.slice();e[l]<0?h[u]=\"s[\"+u+\"]-2\":p[u]=\"1\",0===i?n.push(\"if(s[\",u,\"]>1){dst.set(\",s.join(),\",\",u,\",0.5*(src.get(\",h.join(),\")-src.get(\",p.join(),\")))}else{dst.set(\",s.join(),\",\",u,\",0)};\"):n.push(\"if(s[\",u,\"]>1){diff(\",f,\",src.pick(\",h.join(),\")\",c,\",src.pick(\",p.join(),\")\",c,\");}else{zero(\",f,\");};\");break;case\"mirror\":0===i?n.push(\"dst.set(\",s.join(),\",\",u,\",0);\"):n.push(\"zero(\",f,\");\");break;case\"wrap\":var d=s.slice(),m=s.slice();e[l]<0?(d[u]=\"s[\"+u+\"]-2\",m[u]=\"0\"):(d[u]=\"s[\"+u+\"]-1\",m[u]=\"1\"),0===i?n.push(\"if(s[\",u,\"]>2){dst.set(\",s.join(),\",\",u,\",0.5*(src.get(\",d.join(),\")-src.get(\",m.join(),\")))}else{dst.set(\",s.join(),\",\",u,\",0)};\"):n.push(\"if(s[\",u,\"]>2){diff(\",f,\",src.pick(\",d.join(),\")\",c,\",src.pick(\",m.join(),\")\",c,\");}else{zero(\",f,\");};\");break;default:throw new Error(\"ndarray-gradient: Invalid boundary condition\")}}i>0&&n.push(\"};\")}for(var s=0;s<1<<r;++s){for(var f=[],h=0;h<r;++h)s&1<<h&&f.push(h+1);for(var p=0;p<1<<f.length;++p){var d=f.slice();for(h=0;h<f.length;++h)p&1<<h&&(d[h]=-d[h]);i(d)}}n.push(\"return dst;};return gradient\");var m=[\"diff\",\"zero\"],g=[l,c];for(s=1;s<=r;++s)m.push(\"grad\"+s),g.push(u(s));m.push(n.join(\"\"));var v=Function.apply(void 0,m).apply(void 0,g);return a[e]=v,v}(r)(t,e)};var n=t(\"dup\"),i=t(\"cwise-compiler\"),a={},o={},s={body:\"\",args:[],thisVars:[],localVars:[]},l=i({args:[\"array\",\"array\",\"array\"],pre:s,post:s,body:{args:[{name:\"out\",lvalue:!0,rvalue:!1,count:1},{name:\"left\",lvalue:!1,rvalue:!0,count:1},{name:\"right\",lvalue:!1,rvalue:!0,count:1}],body:\"out=0.5*(left-right)\",thisVars:[],localVars:[]},funcName:\"cdiff\"}),c=i({args:[\"array\"],pre:s,post:s,body:{args:[{name:\"out\",lvalue:!0,rvalue:!1,count:1}],body:\"out=0\",thisVars:[],localVars:[]},funcName:\"zero\"});function u(t){if(t in a)return a[t];for(var e=[],r=0;r<t;++r)e.push(\"out\",r,\"s=0.5*(inp\",r,\"l-inp\",r,\"r);\");var o=[\"array\"],l=[\"junk\"];for(r=0;r<t;++r){o.push(\"array\"),l.push(\"out\"+r+\"s\");var c=n(t);c[r]=-1,o.push({array:0,offset:c.slice()}),c[r]=1,o.push({array:0,offset:c.slice()}),l.push(\"inp\"+r+\"l\",\"inp\"+r+\"r\")}return a[t]=i({args:o,pre:s,post:s,body:{body:e.join(\"\"),args:l.map((function(t){return{name:t,lvalue:0===t.indexOf(\"out\"),rvalue:0===t.indexOf(\"inp\"),count:\"junk\"!==t|0}})),thisVars:[],localVars:[]},funcName:\"fdTemplate\"+t})}},{\"cwise-compiler\":157,dup:181}],473:[function(t,e,r){\"use strict\";function n(t,e){var r=Math.floor(e),n=e-r,i=0<=r&&r<t.shape[0],a=0<=r+1&&r+1<t.shape[0];return(1-n)*(i?+t.get(r):0)+n*(a?+t.get(r+1):0)}function i(t,e,r){var n=Math.floor(e),i=e-n,a=0<=n&&n<t.shape[0],o=0<=n+1&&n+1<t.shape[0],s=Math.floor(r),l=r-s,c=0<=s&&s<t.shape[1],u=0<=s+1&&s+1<t.shape[1],f=a&&c?t.get(n,s):0,h=a&&u?t.get(n,s+1):0;return(1-l)*((1-i)*f+i*(o&&c?t.get(n+1,s):0))+l*((1-i)*h+i*(o&&u?t.get(n+1,s+1):0))}function a(t,e,r,n){var i=Math.floor(e),a=e-i,o=0<=i&&i<t.shape[0],s=0<=i+1&&i+1<t.shape[0],l=Math.floor(r),c=r-l,u=0<=l&&l<t.shape[1],f=0<=l+1&&l+1<t.shape[1],h=Math.floor(n),p=n-h,d=0<=h&&h<t.shape[2],m=0<=h+1&&h+1<t.shape[2],g=o&&u&&d?t.get(i,l,h):0,v=o&&f&&d?t.get(i,l+1,h):0,y=s&&u&&d?t.get(i+1,l,h):0,x=s&&f&&d?t.get(i+1,l+1,h):0,b=o&&u&&m?t.get(i,l,h+1):0,_=o&&f&&m?t.get(i,l+1,h+1):0;return(1-p)*((1-c)*((1-a)*g+a*y)+c*((1-a)*v+a*x))+p*((1-c)*((1-a)*b+a*(s&&u&&m?t.get(i+1,l,h+1):0))+c*((1-a)*_+a*(s&&f&&m?t.get(i+1,l+1,h+1):0)))}function o(t){var e,r,n=0|t.shape.length,i=new Array(n),a=new Array(n),o=new Array(n),s=new Array(n);for(e=0;e<n;++e)r=+arguments[e+1],i[e]=Math.floor(r),a[e]=r-i[e],o[e]=0<=i[e]&&i[e]<t.shape[e],s[e]=0<=i[e]+1&&i[e]+1<t.shape[e];var l,c,u,f=0;t:for(e=0;e<1<<n;++e){for(c=1,u=t.offset,l=0;l<n;++l)if(e&1<<l){if(!s[l])continue t;c*=a[l],u+=t.stride[l]*(i[l]+1)}else{if(!o[l])continue t;c*=1-a[l],u+=t.stride[l]*i[l]}f+=c*t.data[u]}return f}e.exports=function(t,e,r,s){switch(t.shape.length){case 0:return 0;case 1:return n(t,e);case 2:return i(t,e,r);case 3:return a(t,e,r,s);default:return o.apply(void 0,arguments)}},e.exports.d1=n,e.exports.d2=i,e.exports.d3=a},{}],474:[function(t,e,r){\"use strict\";var n=t(\"cwise-compiler\"),i={body:\"\",args:[],thisVars:[],localVars:[]};function a(t){if(!t)return i;for(var e=0;e<t.args.length;++e){var r=t.args[e];t.args[e]=0===e?{name:r,lvalue:!0,rvalue:!!t.rvalue,count:t.count||1}:{name:r,lvalue:!1,rvalue:!0,count:1}}return t.thisVars||(t.thisVars=[]),t.localVars||(t.localVars=[]),t}function o(t){for(var e=[],r=0;r<t.args.length;++r)e.push(\"a\"+r);return new Function(\"P\",[\"return function \",t.funcName,\"_ndarrayops(\",e.join(\",\"),\") {P(\",e.join(\",\"),\");return a0}\"].join(\"\"))(function(t){return n({args:t.args,pre:a(t.pre),body:a(t.body),post:a(t.proc),funcName:t.funcName})}(t))}var s={add:\"+\",sub:\"-\",mul:\"*\",div:\"/\",mod:\"%\",band:\"&\",bor:\"|\",bxor:\"^\",lshift:\"<<\",rshift:\">>\",rrshift:\">>>\"};!function(){for(var t in s){var e=s[t];r[t]=o({args:[\"array\",\"array\",\"array\"],body:{args:[\"a\",\"b\",\"c\"],body:\"a=b\"+e+\"c\"},funcName:t}),r[t+\"eq\"]=o({args:[\"array\",\"array\"],body:{args:[\"a\",\"b\"],body:\"a\"+e+\"=b\"},rvalue:!0,funcName:t+\"eq\"}),r[t+\"s\"]=o({args:[\"array\",\"array\",\"scalar\"],body:{args:[\"a\",\"b\",\"s\"],body:\"a=b\"+e+\"s\"},funcName:t+\"s\"}),r[t+\"seq\"]=o({args:[\"array\",\"scalar\"],body:{args:[\"a\",\"s\"],body:\"a\"+e+\"=s\"},rvalue:!0,funcName:t+\"seq\"})}}();var l={not:\"!\",bnot:\"~\",neg:\"-\",recip:\"1.0/\"};!function(){for(var t in l){var e=l[t];r[t]=o({args:[\"array\",\"array\"],body:{args:[\"a\",\"b\"],body:\"a=\"+e+\"b\"},funcName:t}),r[t+\"eq\"]=o({args:[\"array\"],body:{args:[\"a\"],body:\"a=\"+e+\"a\"},rvalue:!0,count:2,funcName:t+\"eq\"})}}();var c={and:\"&&\",or:\"||\",eq:\"===\",neq:\"!==\",lt:\"<\",gt:\">\",leq:\"<=\",geq:\">=\"};!function(){for(var t in c){var e=c[t];r[t]=o({args:[\"array\",\"array\",\"array\"],body:{args:[\"a\",\"b\",\"c\"],body:\"a=b\"+e+\"c\"},funcName:t}),r[t+\"s\"]=o({args:[\"array\",\"array\",\"scalar\"],body:{args:[\"a\",\"b\",\"s\"],body:\"a=b\"+e+\"s\"},funcName:t+\"s\"}),r[t+\"eq\"]=o({args:[\"array\",\"array\"],body:{args:[\"a\",\"b\"],body:\"a=a\"+e+\"b\"},rvalue:!0,count:2,funcName:t+\"eq\"}),r[t+\"seq\"]=o({args:[\"array\",\"scalar\"],body:{args:[\"a\",\"s\"],body:\"a=a\"+e+\"s\"},rvalue:!0,count:2,funcName:t+\"seq\"})}}();var u=[\"abs\",\"acos\",\"asin\",\"atan\",\"ceil\",\"cos\",\"exp\",\"floor\",\"log\",\"round\",\"sin\",\"sqrt\",\"tan\"];!function(){for(var t=0;t<u.length;++t){var e=u[t];r[e]=o({args:[\"array\",\"array\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\",\"b\"],body:\"a=this_f(b)\",thisVars:[\"this_f\"]},funcName:e}),r[e+\"eq\"]=o({args:[\"array\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\"],body:\"a=this_f(a)\",thisVars:[\"this_f\"]},rvalue:!0,count:2,funcName:e+\"eq\"})}}();var f=[\"max\",\"min\",\"atan2\",\"pow\"];!function(){for(var t=0;t<f.length;++t){var e=f[t];r[e]=o({args:[\"array\",\"array\",\"array\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\",\"b\",\"c\"],body:\"a=this_f(b,c)\",thisVars:[\"this_f\"]},funcName:e}),r[e+\"s\"]=o({args:[\"array\",\"array\",\"scalar\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\",\"b\",\"c\"],body:\"a=this_f(b,c)\",thisVars:[\"this_f\"]},funcName:e+\"s\"}),r[e+\"eq\"]=o({args:[\"array\",\"array\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\",\"b\"],body:\"a=this_f(a,b)\",thisVars:[\"this_f\"]},rvalue:!0,count:2,funcName:e+\"eq\"}),r[e+\"seq\"]=o({args:[\"array\",\"scalar\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\",\"b\"],body:\"a=this_f(a,b)\",thisVars:[\"this_f\"]},rvalue:!0,count:2,funcName:e+\"seq\"})}}();var h=[\"atan2\",\"pow\"];!function(){for(var t=0;t<h.length;++t){var e=h[t];r[e+\"op\"]=o({args:[\"array\",\"array\",\"array\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\",\"b\",\"c\"],body:\"a=this_f(c,b)\",thisVars:[\"this_f\"]},funcName:e+\"op\"}),r[e+\"ops\"]=o({args:[\"array\",\"array\",\"scalar\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\",\"b\",\"c\"],body:\"a=this_f(c,b)\",thisVars:[\"this_f\"]},funcName:e+\"ops\"}),r[e+\"opeq\"]=o({args:[\"array\",\"array\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\",\"b\"],body:\"a=this_f(b,a)\",thisVars:[\"this_f\"]},rvalue:!0,count:2,funcName:e+\"opeq\"}),r[e+\"opseq\"]=o({args:[\"array\",\"scalar\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\",\"b\"],body:\"a=this_f(b,a)\",thisVars:[\"this_f\"]},rvalue:!0,count:2,funcName:e+\"opseq\"})}}(),r.any=n({args:[\"array\"],pre:i,body:{args:[{name:\"a\",lvalue:!1,rvalue:!0,count:1}],body:\"if(a){return true}\",localVars:[],thisVars:[]},post:{args:[],localVars:[],thisVars:[],body:\"return false\"},funcName:\"any\"}),r.all=n({args:[\"array\"],pre:i,body:{args:[{name:\"x\",lvalue:!1,rvalue:!0,count:1}],body:\"if(!x){return false}\",localVars:[],thisVars:[]},post:{args:[],localVars:[],thisVars:[],body:\"return true\"},funcName:\"all\"}),r.sum=n({args:[\"array\"],pre:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"this_s=0\"},body:{args:[{name:\"a\",lvalue:!1,rvalue:!0,count:1}],body:\"this_s+=a\",localVars:[],thisVars:[\"this_s\"]},post:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"return this_s\"},funcName:\"sum\"}),r.prod=n({args:[\"array\"],pre:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"this_s=1\"},body:{args:[{name:\"a\",lvalue:!1,rvalue:!0,count:1}],body:\"this_s*=a\",localVars:[],thisVars:[\"this_s\"]},post:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"return this_s\"},funcName:\"prod\"}),r.norm2squared=n({args:[\"array\"],pre:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"this_s=0\"},body:{args:[{name:\"a\",lvalue:!1,rvalue:!0,count:2}],body:\"this_s+=a*a\",localVars:[],thisVars:[\"this_s\"]},post:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"return this_s\"},funcName:\"norm2squared\"}),r.norm2=n({args:[\"array\"],pre:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"this_s=0\"},body:{args:[{name:\"a\",lvalue:!1,rvalue:!0,count:2}],body:\"this_s+=a*a\",localVars:[],thisVars:[\"this_s\"]},post:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"return Math.sqrt(this_s)\"},funcName:\"norm2\"}),r.norminf=n({args:[\"array\"],pre:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"this_s=0\"},body:{args:[{name:\"a\",lvalue:!1,rvalue:!0,count:4}],body:\"if(-a>this_s){this_s=-a}else if(a>this_s){this_s=a}\",localVars:[],thisVars:[\"this_s\"]},post:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"return this_s\"},funcName:\"norminf\"}),r.norm1=n({args:[\"array\"],pre:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"this_s=0\"},body:{args:[{name:\"a\",lvalue:!1,rvalue:!0,count:3}],body:\"this_s+=a<0?-a:a\",localVars:[],thisVars:[\"this_s\"]},post:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"return this_s\"},funcName:\"norm1\"}),r.sup=n({args:[\"array\"],pre:{body:\"this_h=-Infinity\",args:[],thisVars:[\"this_h\"],localVars:[]},body:{body:\"if(_inline_1_arg0_>this_h)this_h=_inline_1_arg0_\",args:[{name:\"_inline_1_arg0_\",lvalue:!1,rvalue:!0,count:2}],thisVars:[\"this_h\"],localVars:[]},post:{body:\"return this_h\",args:[],thisVars:[\"this_h\"],localVars:[]}}),r.inf=n({args:[\"array\"],pre:{body:\"this_h=Infinity\",args:[],thisVars:[\"this_h\"],localVars:[]},body:{body:\"if(_inline_1_arg0_<this_h)this_h=_inline_1_arg0_\",args:[{name:\"_inline_1_arg0_\",lvalue:!1,rvalue:!0,count:2}],thisVars:[\"this_h\"],localVars:[]},post:{body:\"return this_h\",args:[],thisVars:[\"this_h\"],localVars:[]}}),r.argmin=n({args:[\"index\",\"array\",\"shape\"],pre:{body:\"{this_v=Infinity;this_i=_inline_0_arg2_.slice(0)}\",args:[{name:\"_inline_0_arg0_\",lvalue:!1,rvalue:!1,count:0},{name:\"_inline_0_arg1_\",lvalue:!1,rvalue:!1,count:0},{name:\"_inline_0_arg2_\",lvalue:!1,rvalue:!0,count:1}],thisVars:[\"this_i\",\"this_v\"],localVars:[]},body:{body:\"{if(_inline_1_arg1_<this_v){this_v=_inline_1_arg1_;for(var _inline_1_k=0;_inline_1_k<_inline_1_arg0_.length;++_inline_1_k){this_i[_inline_1_k]=_inline_1_arg0_[_inline_1_k]}}}\",args:[{name:\"_inline_1_arg0_\",lvalue:!1,rvalue:!0,count:2},{name:\"_inline_1_arg1_\",lvalue:!1,rvalue:!0,count:2}],thisVars:[\"this_i\",\"this_v\"],localVars:[\"_inline_1_k\"]},post:{body:\"{return this_i}\",args:[],thisVars:[\"this_i\"],localVars:[]}}),r.argmax=n({args:[\"index\",\"array\",\"shape\"],pre:{body:\"{this_v=-Infinity;this_i=_inline_0_arg2_.slice(0)}\",args:[{name:\"_inline_0_arg0_\",lvalue:!1,rvalue:!1,count:0},{name:\"_inline_0_arg1_\",lvalue:!1,rvalue:!1,count:0},{name:\"_inline_0_arg2_\",lvalue:!1,rvalue:!0,count:1}],thisVars:[\"this_i\",\"this_v\"],localVars:[]},body:{body:\"{if(_inline_1_arg1_>this_v){this_v=_inline_1_arg1_;for(var _inline_1_k=0;_inline_1_k<_inline_1_arg0_.length;++_inline_1_k){this_i[_inline_1_k]=_inline_1_arg0_[_inline_1_k]}}}\",args:[{name:\"_inline_1_arg0_\",lvalue:!1,rvalue:!0,count:2},{name:\"_inline_1_arg1_\",lvalue:!1,rvalue:!0,count:2}],thisVars:[\"this_i\",\"this_v\"],localVars:[\"_inline_1_k\"]},post:{body:\"{return this_i}\",args:[],thisVars:[\"this_i\"],localVars:[]}}),r.random=o({args:[\"array\"],pre:{args:[],body:\"this_f=Math.random\",thisVars:[\"this_f\"]},body:{args:[\"a\"],body:\"a=this_f()\",thisVars:[\"this_f\"]},funcName:\"random\"}),r.assign=o({args:[\"array\",\"array\"],body:{args:[\"a\",\"b\"],body:\"a=b\"},funcName:\"assign\"}),r.assigns=o({args:[\"array\",\"scalar\"],body:{args:[\"a\",\"b\"],body:\"a=b\"},funcName:\"assigns\"}),r.equals=n({args:[\"array\",\"array\"],pre:i,body:{args:[{name:\"x\",lvalue:!1,rvalue:!0,count:1},{name:\"y\",lvalue:!1,rvalue:!0,count:1}],body:\"if(x!==y){return false}\",localVars:[],thisVars:[]},post:{args:[],localVars:[],thisVars:[],body:\"return true\"},funcName:\"equals\"})},{\"cwise-compiler\":157}],475:[function(t,e,r){\"use strict\";var n=t(\"ndarray\"),i=t(\"./doConvert.js\");e.exports=function(t,e){for(var r=[],a=t,o=1;Array.isArray(a);)r.push(a.length),o*=a.length,a=a[0];return 0===r.length?n():(e||(e=n(new Float64Array(o),r)),i(e,t),e)}},{\"./doConvert.js\":476,ndarray:479}],476:[function(t,e,r){e.exports=t(\"cwise-compiler\")({args:[\"array\",\"scalar\",\"index\"],pre:{body:\"{}\",args:[],thisVars:[],localVars:[]},body:{body:\"{\\nvar _inline_1_v=_inline_1_arg1_,_inline_1_i\\nfor(_inline_1_i=0;_inline_1_i<_inline_1_arg2_.length-1;++_inline_1_i) {\\n_inline_1_v=_inline_1_v[_inline_1_arg2_[_inline_1_i]]\\n}\\n_inline_1_arg0_=_inline_1_v[_inline_1_arg2_[_inline_1_arg2_.length-1]]\\n}\",args:[{name:\"_inline_1_arg0_\",lvalue:!0,rvalue:!1,count:1},{name:\"_inline_1_arg1_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_1_arg2_\",lvalue:!1,rvalue:!0,count:4}],thisVars:[],localVars:[\"_inline_1_i\",\"_inline_1_v\"]},post:{body:\"{}\",args:[],thisVars:[],localVars:[]},funcName:\"convert\",blockSize:64})},{\"cwise-compiler\":157}],477:[function(t,e,r){\"use strict\";var n=t(\"typedarray-pool\"),i=32;function a(t){switch(t){case\"uint8\":return[n.mallocUint8,n.freeUint8];case\"uint16\":return[n.mallocUint16,n.freeUint16];case\"uint32\":return[n.mallocUint32,n.freeUint32];case\"int8\":return[n.mallocInt8,n.freeInt8];case\"int16\":return[n.mallocInt16,n.freeInt16];case\"int32\":return[n.mallocInt32,n.freeInt32];case\"float32\":return[n.mallocFloat,n.freeFloat];case\"float64\":return[n.mallocDouble,n.freeDouble];default:return null}}function o(t){for(var e=[],r=0;r<t;++r)e.push(\"s\"+r);for(r=0;r<t;++r)e.push(\"n\"+r);for(r=1;r<t;++r)e.push(\"d\"+r);for(r=1;r<t;++r)e.push(\"e\"+r);for(r=1;r<t;++r)e.push(\"f\"+r);return e}e.exports=function(t,e){var r=[\"'use strict'\"],n=[\"ndarraySortWrapper\",t.join(\"d\"),e].join(\"\");r.push([\"function \",n,\"(\",[\"array\"].join(\",\"),\"){\"].join(\"\"));for(var s=[\"data=array.data,offset=array.offset|0,shape=array.shape,stride=array.stride\"],l=0;l<t.length;++l)s.push([\"s\",l,\"=stride[\",l,\"]|0,n\",l,\"=shape[\",l,\"]|0\"].join(\"\"));var c=new Array(t.length),u=[];for(l=0;l<t.length;++l){0!==(p=t[l])&&(0===u.length?c[p]=\"1\":c[p]=u.join(\"*\"),u.push(\"n\"+p))}var f=-1,h=-1;for(l=0;l<t.length;++l){var p,d=t[l];0!==d&&(f>0?s.push([\"d\",d,\"=s\",d,\"-d\",f,\"*n\",f].join(\"\")):s.push([\"d\",d,\"=s\",d].join(\"\")),f=d),0!==(p=t.length-1-l)&&(h>0?s.push([\"e\",p,\"=s\",p,\"-e\",h,\"*n\",h,\",f\",p,\"=\",c[p],\"-f\",h,\"*n\",h].join(\"\")):s.push([\"e\",p,\"=s\",p,\",f\",p,\"=\",c[p]].join(\"\")),h=p)}r.push(\"var \"+s.join(\",\"));var m=[\"0\",\"n0-1\",\"data\",\"offset\"].concat(o(t.length));r.push([\"if(n0<=\",i,\"){\",\"insertionSort(\",m.join(\",\"),\")}else{\",\"quickSort(\",m.join(\",\"),\")}\"].join(\"\")),r.push(\"}return \"+n);var g=new Function(\"insertionSort\",\"quickSort\",r.join(\"\\n\")),v=function(t,e){var r=[\"'use strict'\"],n=[\"ndarrayInsertionSort\",t.join(\"d\"),e].join(\"\"),i=[\"left\",\"right\",\"data\",\"offset\"].concat(o(t.length)),s=a(e),l=[\"i,j,cptr,ptr=left*s0+offset\"];if(t.length>1){for(var c=[],u=1;u<t.length;++u)l.push(\"i\"+u),c.push(\"n\"+u);s?l.push(\"scratch=malloc(\"+c.join(\"*\")+\")\"):l.push(\"scratch=new Array(\"+c.join(\"*\")+\")\"),l.push(\"dptr\",\"sptr\",\"a\",\"b\")}else l.push(\"scratch\");function f(t){return\"generic\"===e?[\"data.get(\",t,\")\"].join(\"\"):[\"data[\",t,\"]\"].join(\"\")}function h(t,r){return\"generic\"===e?[\"data.set(\",t,\",\",r,\")\"].join(\"\"):[\"data[\",t,\"]=\",r].join(\"\")}if(r.push([\"function \",n,\"(\",i.join(\",\"),\"){var \",l.join(\",\")].join(\"\"),\"for(i=left+1;i<=right;++i){\",\"j=i;ptr+=s0\",\"cptr=ptr\"),t.length>1){r.push(\"dptr=0;sptr=ptr\");for(u=t.length-1;u>=0;--u){0!==(p=t[u])&&r.push([\"for(i\",p,\"=0;i\",p,\"<n\",p,\";++i\",p,\"){\"].join(\"\"))}r.push(\"scratch[dptr++]=\",f(\"sptr\"));for(u=0;u<t.length;++u){0!==(p=t[u])&&r.push(\"sptr+=d\"+p,\"}\")}r.push(\"__g:while(j--\\x3eleft){\",\"dptr=0\",\"sptr=cptr-s0\");for(u=1;u<t.length;++u)1===u&&r.push(\"__l:\"),r.push([\"for(i\",u,\"=0;i\",u,\"<n\",u,\";++i\",u,\"){\"].join(\"\"));r.push([\"a=\",f(\"sptr\"),\"\\nb=scratch[dptr]\\nif(a<b){break __g}\\nif(a>b){break __l}\"].join(\"\"));for(u=t.length-1;u>=1;--u)r.push(\"sptr+=e\"+u,\"dptr+=f\"+u,\"}\");r.push(\"dptr=cptr;sptr=cptr-s0\");for(u=t.length-1;u>=0;--u){0!==(p=t[u])&&r.push([\"for(i\",p,\"=0;i\",p,\"<n\",p,\";++i\",p,\"){\"].join(\"\"))}r.push(h(\"dptr\",f(\"sptr\")));for(u=0;u<t.length;++u){0!==(p=t[u])&&r.push([\"dptr+=d\",p,\";sptr+=d\",p].join(\"\"),\"}\")}r.push(\"cptr-=s0\\n}\"),r.push(\"dptr=cptr;sptr=0\");for(u=t.length-1;u>=0;--u){0!==(p=t[u])&&r.push([\"for(i\",p,\"=0;i\",p,\"<n\",p,\";++i\",p,\"){\"].join(\"\"))}r.push(h(\"dptr\",\"scratch[sptr++]\"));for(u=0;u<t.length;++u){var p;0!==(p=t[u])&&r.push(\"dptr+=d\"+p,\"}\")}}else r.push(\"scratch=\"+f(\"ptr\"),\"while((j--\\x3eleft)&&(\"+f(\"cptr-s0\")+\">scratch)){\",h(\"cptr\",f(\"cptr-s0\")),\"cptr-=s0\",\"}\",h(\"cptr\",\"scratch\"));return r.push(\"}\"),t.length>1&&s&&r.push(\"free(scratch)\"),r.push(\"} return \"+n),s?new Function(\"malloc\",\"free\",r.join(\"\\n\"))(s[0],s[1]):new Function(r.join(\"\\n\"))()}(t,e),y=function(t,e,r){var n=[\"'use strict'\"],s=[\"ndarrayQuickSort\",t.join(\"d\"),e].join(\"\"),l=[\"left\",\"right\",\"data\",\"offset\"].concat(o(t.length)),c=a(e),u=0;n.push([\"function \",s,\"(\",l.join(\",\"),\"){\"].join(\"\"));var f=[\"sixth=((right-left+1)/6)|0\",\"index1=left+sixth\",\"index5=right-sixth\",\"index3=(left+right)>>1\",\"index2=index3-sixth\",\"index4=index3+sixth\",\"el1=index1\",\"el2=index2\",\"el3=index3\",\"el4=index4\",\"el5=index5\",\"less=left+1\",\"great=right-1\",\"pivots_are_equal=true\",\"tmp\",\"tmp0\",\"x\",\"y\",\"z\",\"k\",\"ptr0\",\"ptr1\",\"ptr2\",\"comp_pivot1=0\",\"comp_pivot2=0\",\"comp=0\"];if(t.length>1){for(var h=[],p=1;p<t.length;++p)h.push(\"n\"+p),f.push(\"i\"+p);for(p=0;p<8;++p)f.push(\"b_ptr\"+p);f.push(\"ptr3\",\"ptr4\",\"ptr5\",\"ptr6\",\"ptr7\",\"pivot_ptr\",\"ptr_shift\",\"elementSize=\"+h.join(\"*\")),c?f.push(\"pivot1=malloc(elementSize)\",\"pivot2=malloc(elementSize)\"):f.push(\"pivot1=new Array(elementSize),pivot2=new Array(elementSize)\")}else f.push(\"pivot1\",\"pivot2\");function d(t){return[\"(offset+\",t,\"*s0)\"].join(\"\")}function m(t){return\"generic\"===e?[\"data.get(\",t,\")\"].join(\"\"):[\"data[\",t,\"]\"].join(\"\")}function g(t,r){return\"generic\"===e?[\"data.set(\",t,\",\",r,\")\"].join(\"\"):[\"data[\",t,\"]=\",r].join(\"\")}function v(e,r,i){if(1===e.length)n.push(\"ptr0=\"+d(e[0]));else for(var a=0;a<e.length;++a)n.push([\"b_ptr\",a,\"=s0*\",e[a]].join(\"\"));r&&n.push(\"pivot_ptr=0\"),n.push(\"ptr_shift=offset\");for(a=t.length-1;a>=0;--a){0!==(o=t[a])&&n.push([\"for(i\",o,\"=0;i\",o,\"<n\",o,\";++i\",o,\"){\"].join(\"\"))}if(e.length>1)for(a=0;a<e.length;++a)n.push([\"ptr\",a,\"=b_ptr\",a,\"+ptr_shift\"].join(\"\"));n.push(i),r&&n.push(\"++pivot_ptr\");for(a=0;a<t.length;++a){var o;0!==(o=t[a])&&(e.length>1?n.push(\"ptr_shift+=d\"+o):n.push(\"ptr0+=d\"+o),n.push(\"}\"))}}function y(e,r,i,a){if(1===r.length)n.push(\"ptr0=\"+d(r[0]));else{for(var o=0;o<r.length;++o)n.push([\"b_ptr\",o,\"=s0*\",r[o]].join(\"\"));n.push(\"ptr_shift=offset\")}i&&n.push(\"pivot_ptr=0\"),e&&n.push(e+\":\");for(o=1;o<t.length;++o)n.push([\"for(i\",o,\"=0;i\",o,\"<n\",o,\";++i\",o,\"){\"].join(\"\"));if(r.length>1)for(o=0;o<r.length;++o)n.push([\"ptr\",o,\"=b_ptr\",o,\"+ptr_shift\"].join(\"\"));n.push(a);for(o=t.length-1;o>=1;--o)i&&n.push(\"pivot_ptr+=f\"+o),r.length>1?n.push(\"ptr_shift+=e\"+o):n.push(\"ptr0+=e\"+o),n.push(\"}\")}function x(){t.length>1&&c&&n.push(\"free(pivot1)\",\"free(pivot2)\")}function b(e,r){var i=\"el\"+e,a=\"el\"+r;if(t.length>1){var o=\"__l\"+ ++u;y(o,[i,a],!1,[\"comp=\",m(\"ptr0\"),\"-\",m(\"ptr1\"),\"\\n\",\"if(comp>0){tmp0=\",i,\";\",i,\"=\",a,\";\",a,\"=tmp0;break \",o,\"}\\n\",\"if(comp<0){break \",o,\"}\"].join(\"\"))}else n.push([\"if(\",m(d(i)),\">\",m(d(a)),\"){tmp0=\",i,\";\",i,\"=\",a,\";\",a,\"=tmp0}\"].join(\"\"))}function _(e,r){t.length>1?v([e,r],!1,g(\"ptr0\",m(\"ptr1\"))):n.push(g(d(e),m(d(r))))}function w(e,r,i){if(t.length>1){var a=\"__l\"+ ++u;y(a,[r],!0,[e,\"=\",m(\"ptr0\"),\"-pivot\",i,\"[pivot_ptr]\\n\",\"if(\",e,\"!==0){break \",a,\"}\"].join(\"\"))}else n.push([e,\"=\",m(d(r)),\"-pivot\",i].join(\"\"))}function T(e,r){t.length>1?v([e,r],!1,[\"tmp=\",m(\"ptr0\"),\"\\n\",g(\"ptr0\",m(\"ptr1\")),\"\\n\",g(\"ptr1\",\"tmp\")].join(\"\")):n.push([\"ptr0=\",d(e),\"\\n\",\"ptr1=\",d(r),\"\\n\",\"tmp=\",m(\"ptr0\"),\"\\n\",g(\"ptr0\",m(\"ptr1\")),\"\\n\",g(\"ptr1\",\"tmp\")].join(\"\"))}function k(e,r,i){t.length>1?(v([e,r,i],!1,[\"tmp=\",m(\"ptr0\"),\"\\n\",g(\"ptr0\",m(\"ptr1\")),\"\\n\",g(\"ptr1\",m(\"ptr2\")),\"\\n\",g(\"ptr2\",\"tmp\")].join(\"\")),n.push(\"++\"+r,\"--\"+i)):n.push([\"ptr0=\",d(e),\"\\n\",\"ptr1=\",d(r),\"\\n\",\"ptr2=\",d(i),\"\\n\",\"++\",r,\"\\n\",\"--\",i,\"\\n\",\"tmp=\",m(\"ptr0\"),\"\\n\",g(\"ptr0\",m(\"ptr1\")),\"\\n\",g(\"ptr1\",m(\"ptr2\")),\"\\n\",g(\"ptr2\",\"tmp\")].join(\"\"))}function M(t,e){T(t,e),n.push(\"--\"+e)}function A(e,r,i){t.length>1?v([e,r],!0,[g(\"ptr0\",m(\"ptr1\")),\"\\n\",g(\"ptr1\",[\"pivot\",i,\"[pivot_ptr]\"].join(\"\"))].join(\"\")):n.push(g(d(e),m(d(r))),g(d(r),\"pivot\"+i))}function S(e,r){n.push([\"if((\",r,\"-\",e,\")<=\",i,\"){\\n\",\"insertionSort(\",e,\",\",r,\",data,offset,\",o(t.length).join(\",\"),\")\\n\",\"}else{\\n\",s,\"(\",e,\",\",r,\",data,offset,\",o(t.length).join(\",\"),\")\\n\",\"}\"].join(\"\"))}function E(e,r,i){t.length>1?(n.push([\"__l\",++u,\":while(true){\"].join(\"\")),v([e],!0,[\"if(\",m(\"ptr0\"),\"!==pivot\",r,\"[pivot_ptr]){break __l\",u,\"}\"].join(\"\")),n.push(i,\"}\")):n.push([\"while(\",m(d(e)),\"===pivot\",r,\"){\",i,\"}\"].join(\"\"))}return n.push(\"var \"+f.join(\",\")),b(1,2),b(4,5),b(1,3),b(2,3),b(1,4),b(3,4),b(2,5),b(2,3),b(4,5),t.length>1?v([\"el1\",\"el2\",\"el3\",\"el4\",\"el5\",\"index1\",\"index3\",\"index5\"],!0,[\"pivot1[pivot_ptr]=\",m(\"ptr1\"),\"\\n\",\"pivot2[pivot_ptr]=\",m(\"ptr3\"),\"\\n\",\"pivots_are_equal=pivots_are_equal&&(pivot1[pivot_ptr]===pivot2[pivot_ptr])\\n\",\"x=\",m(\"ptr0\"),\"\\n\",\"y=\",m(\"ptr2\"),\"\\n\",\"z=\",m(\"ptr4\"),\"\\n\",g(\"ptr5\",\"x\"),\"\\n\",g(\"ptr6\",\"y\"),\"\\n\",g(\"ptr7\",\"z\")].join(\"\")):n.push([\"pivot1=\",m(d(\"el2\")),\"\\n\",\"pivot2=\",m(d(\"el4\")),\"\\n\",\"pivots_are_equal=pivot1===pivot2\\n\",\"x=\",m(d(\"el1\")),\"\\n\",\"y=\",m(d(\"el3\")),\"\\n\",\"z=\",m(d(\"el5\")),\"\\n\",g(d(\"index1\"),\"x\"),\"\\n\",g(d(\"index3\"),\"y\"),\"\\n\",g(d(\"index5\"),\"z\")].join(\"\")),_(\"index2\",\"left\"),_(\"index4\",\"right\"),n.push(\"if(pivots_are_equal){\"),n.push(\"for(k=less;k<=great;++k){\"),w(\"comp\",\"k\",1),n.push(\"if(comp===0){continue}\"),n.push(\"if(comp<0){\"),n.push(\"if(k!==less){\"),T(\"k\",\"less\"),n.push(\"}\"),n.push(\"++less\"),n.push(\"}else{\"),n.push(\"while(true){\"),w(\"comp\",\"great\",1),n.push(\"if(comp>0){\"),n.push(\"great--\"),n.push(\"}else if(comp<0){\"),k(\"k\",\"less\",\"great\"),n.push(\"break\"),n.push(\"}else{\"),M(\"k\",\"great\"),n.push(\"break\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}else{\"),n.push(\"for(k=less;k<=great;++k){\"),w(\"comp_pivot1\",\"k\",1),n.push(\"if(comp_pivot1<0){\"),n.push(\"if(k!==less){\"),T(\"k\",\"less\"),n.push(\"}\"),n.push(\"++less\"),n.push(\"}else{\"),w(\"comp_pivot2\",\"k\",2),n.push(\"if(comp_pivot2>0){\"),n.push(\"while(true){\"),w(\"comp\",\"great\",2),n.push(\"if(comp>0){\"),n.push(\"if(--great<k){break}\"),n.push(\"continue\"),n.push(\"}else{\"),w(\"comp\",\"great\",1),n.push(\"if(comp<0){\"),k(\"k\",\"less\",\"great\"),n.push(\"}else{\"),M(\"k\",\"great\"),n.push(\"}\"),n.push(\"break\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),A(\"left\",\"(less-1)\",1),A(\"right\",\"(great+1)\",2),S(\"left\",\"(less-2)\"),S(\"(great+2)\",\"right\"),n.push(\"if(pivots_are_equal){\"),x(),n.push(\"return\"),n.push(\"}\"),n.push(\"if(less<index1&&great>index5){\"),E(\"less\",1,\"++less\"),E(\"great\",2,\"--great\"),n.push(\"for(k=less;k<=great;++k){\"),w(\"comp_pivot1\",\"k\",1),n.push(\"if(comp_pivot1===0){\"),n.push(\"if(k!==less){\"),T(\"k\",\"less\"),n.push(\"}\"),n.push(\"++less\"),n.push(\"}else{\"),w(\"comp_pivot2\",\"k\",2),n.push(\"if(comp_pivot2===0){\"),n.push(\"while(true){\"),w(\"comp\",\"great\",2),n.push(\"if(comp===0){\"),n.push(\"if(--great<k){break}\"),n.push(\"continue\"),n.push(\"}else{\"),w(\"comp\",\"great\",1),n.push(\"if(comp<0){\"),k(\"k\",\"less\",\"great\"),n.push(\"}else{\"),M(\"k\",\"great\"),n.push(\"}\"),n.push(\"break\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),x(),S(\"less\",\"great\"),n.push(\"}return \"+s),t.length>1&&c?new Function(\"insertionSort\",\"malloc\",\"free\",n.join(\"\\n\"))(r,c[0],c[1]):new Function(\"insertionSort\",n.join(\"\\n\"))(r)}(t,e,v);return g(v,y)}},{\"typedarray-pool\":613}],478:[function(t,e,r){\"use strict\";var n=t(\"./lib/compile_sort.js\"),i={};e.exports=function(t){var e=t.order,r=t.dtype,a=[e,r].join(\":\"),o=i[a];return o||(i[a]=o=n(e,r)),o(t),t}},{\"./lib/compile_sort.js\":477}],479:[function(t,e,r){var n=t(\"iota-array\"),i=t(\"is-buffer\"),a=\"undefined\"!=typeof Float64Array;function o(t,e){return t[0]-e[0]}function s(){var t,e=this.stride,r=new Array(e.length);for(t=0;t<r.length;++t)r[t]=[Math.abs(e[t]),t];r.sort(o);var n=new Array(r.length);for(t=0;t<n.length;++t)n[t]=r[t][1];return n}function l(t,e){var r=[\"View\",e,\"d\",t].join(\"\");e<0&&(r=\"View_Nil\"+t);var i=\"generic\"===t;if(-1===e){var a=\"function \"+r+\"(a){this.data=a;};var proto=\"+r+\".prototype;proto.dtype='\"+t+\"';proto.index=function(){return -1};proto.size=0;proto.dimension=-1;proto.shape=proto.stride=proto.order=[];proto.lo=proto.hi=proto.transpose=proto.step=function(){return new \"+r+\"(this.data);};proto.get=proto.set=function(){};proto.pick=function(){return null};return function construct_\"+r+\"(a){return new \"+r+\"(a);}\";return new Function(a)()}if(0===e){a=\"function \"+r+\"(a,d) {this.data = a;this.offset = d};var proto=\"+r+\".prototype;proto.dtype='\"+t+\"';proto.index=function(){return this.offset};proto.dimension=0;proto.size=1;proto.shape=proto.stride=proto.order=[];proto.lo=proto.hi=proto.transpose=proto.step=function \"+r+\"_copy() {return new \"+r+\"(this.data,this.offset)};proto.pick=function \"+r+\"_pick(){return TrivialArray(this.data);};proto.valueOf=proto.get=function \"+r+\"_get(){return \"+(i?\"this.data.get(this.offset)\":\"this.data[this.offset]\")+\"};proto.set=function \"+r+\"_set(v){return \"+(i?\"this.data.set(this.offset,v)\":\"this.data[this.offset]=v\")+\"};return function construct_\"+r+\"(a,b,c,d){return new \"+r+\"(a,d)}\";return new Function(\"TrivialArray\",a)(c[t][0])}a=[\"'use strict'\"];var o=n(e),l=o.map((function(t){return\"i\"+t})),u=\"this.offset+\"+o.map((function(t){return\"this.stride[\"+t+\"]*i\"+t})).join(\"+\"),f=o.map((function(t){return\"b\"+t})).join(\",\"),h=o.map((function(t){return\"c\"+t})).join(\",\");a.push(\"function \"+r+\"(a,\"+f+\",\"+h+\",d){this.data=a\",\"this.shape=[\"+f+\"]\",\"this.stride=[\"+h+\"]\",\"this.offset=d|0}\",\"var proto=\"+r+\".prototype\",\"proto.dtype='\"+t+\"'\",\"proto.dimension=\"+e),a.push(\"Object.defineProperty(proto,'size',{get:function \"+r+\"_size(){return \"+o.map((function(t){return\"this.shape[\"+t+\"]\"})).join(\"*\"),\"}})\"),1===e?a.push(\"proto.order=[0]\"):(a.push(\"Object.defineProperty(proto,'order',{get:\"),e<4?(a.push(\"function \"+r+\"_order(){\"),2===e?a.push(\"return (Math.abs(this.stride[0])>Math.abs(this.stride[1]))?[1,0]:[0,1]}})\"):3===e&&a.push(\"var s0=Math.abs(this.stride[0]),s1=Math.abs(this.stride[1]),s2=Math.abs(this.stride[2]);if(s0>s1){if(s1>s2){return [2,1,0];}else if(s0>s2){return [1,2,0];}else{return [1,0,2];}}else if(s0>s2){return [2,0,1];}else if(s2>s1){return [0,1,2];}else{return [0,2,1];}}})\")):a.push(\"ORDER})\")),a.push(\"proto.set=function \"+r+\"_set(\"+l.join(\",\")+\",v){\"),i?a.push(\"return this.data.set(\"+u+\",v)}\"):a.push(\"return this.data[\"+u+\"]=v}\"),a.push(\"proto.get=function \"+r+\"_get(\"+l.join(\",\")+\"){\"),i?a.push(\"return this.data.get(\"+u+\")}\"):a.push(\"return this.data[\"+u+\"]}\"),a.push(\"proto.index=function \"+r+\"_index(\",l.join(),\"){return \"+u+\"}\"),a.push(\"proto.hi=function \"+r+\"_hi(\"+l.join(\",\")+\"){return new \"+r+\"(this.data,\"+o.map((function(t){return[\"(typeof i\",t,\"!=='number'||i\",t,\"<0)?this.shape[\",t,\"]:i\",t,\"|0\"].join(\"\")})).join(\",\")+\",\"+o.map((function(t){return\"this.stride[\"+t+\"]\"})).join(\",\")+\",this.offset)}\");var p=o.map((function(t){return\"a\"+t+\"=this.shape[\"+t+\"]\"})),d=o.map((function(t){return\"c\"+t+\"=this.stride[\"+t+\"]\"}));a.push(\"proto.lo=function \"+r+\"_lo(\"+l.join(\",\")+\"){var b=this.offset,d=0,\"+p.join(\",\")+\",\"+d.join(\",\"));for(var m=0;m<e;++m)a.push(\"if(typeof i\"+m+\"==='number'&&i\"+m+\">=0){d=i\"+m+\"|0;b+=c\"+m+\"*d;a\"+m+\"-=d}\");a.push(\"return new \"+r+\"(this.data,\"+o.map((function(t){return\"a\"+t})).join(\",\")+\",\"+o.map((function(t){return\"c\"+t})).join(\",\")+\",b)}\"),a.push(\"proto.step=function \"+r+\"_step(\"+l.join(\",\")+\"){var \"+o.map((function(t){return\"a\"+t+\"=this.shape[\"+t+\"]\"})).join(\",\")+\",\"+o.map((function(t){return\"b\"+t+\"=this.stride[\"+t+\"]\"})).join(\",\")+\",c=this.offset,d=0,ceil=Math.ceil\");for(m=0;m<e;++m)a.push(\"if(typeof i\"+m+\"==='number'){d=i\"+m+\"|0;if(d<0){c+=b\"+m+\"*(a\"+m+\"-1);a\"+m+\"=ceil(-a\"+m+\"/d)}else{a\"+m+\"=ceil(a\"+m+\"/d)}b\"+m+\"*=d}\");a.push(\"return new \"+r+\"(this.data,\"+o.map((function(t){return\"a\"+t})).join(\",\")+\",\"+o.map((function(t){return\"b\"+t})).join(\",\")+\",c)}\");var g=new Array(e),v=new Array(e);for(m=0;m<e;++m)g[m]=\"a[i\"+m+\"]\",v[m]=\"b[i\"+m+\"]\";a.push(\"proto.transpose=function \"+r+\"_transpose(\"+l+\"){\"+l.map((function(t,e){return t+\"=(\"+t+\"===undefined?\"+e+\":\"+t+\"|0)\"})).join(\";\"),\"var a=this.shape,b=this.stride;return new \"+r+\"(this.data,\"+g.join(\",\")+\",\"+v.join(\",\")+\",this.offset)}\"),a.push(\"proto.pick=function \"+r+\"_pick(\"+l+\"){var a=[],b=[],c=this.offset\");for(m=0;m<e;++m)a.push(\"if(typeof i\"+m+\"==='number'&&i\"+m+\">=0){c=(c+this.stride[\"+m+\"]*i\"+m+\")|0}else{a.push(this.shape[\"+m+\"]);b.push(this.stride[\"+m+\"])}\");return a.push(\"var ctor=CTOR_LIST[a.length+1];return ctor(this.data,a,b,c)}\"),a.push(\"return function construct_\"+r+\"(data,shape,stride,offset){return new \"+r+\"(data,\"+o.map((function(t){return\"shape[\"+t+\"]\"})).join(\",\")+\",\"+o.map((function(t){return\"stride[\"+t+\"]\"})).join(\",\")+\",offset)}\"),new Function(\"CTOR_LIST\",\"ORDER\",a.join(\"\\n\"))(c[t],s)}var c={float32:[],float64:[],int8:[],int16:[],int32:[],uint8:[],uint16:[],uint32:[],array:[],uint8_clamped:[],bigint64:[],biguint64:[],buffer:[],generic:[]};e.exports=function(t,e,r,n){if(void 0===t)return(0,c.array[0])([]);\"number\"==typeof t&&(t=[t]),void 0===e&&(e=[t.length]);var o=e.length;if(void 0===r){r=new Array(o);for(var s=o-1,u=1;s>=0;--s)r[s]=u,u*=e[s]}if(void 0===n){n=0;for(s=0;s<o;++s)r[s]<0&&(n-=(e[s]-1)*r[s])}for(var f=function(t){if(i(t))return\"buffer\";if(a)switch(Object.prototype.toString.call(t)){case\"[object Float64Array]\":return\"float64\";case\"[object Float32Array]\":return\"float32\";case\"[object Int8Array]\":return\"int8\";case\"[object Int16Array]\":return\"int16\";case\"[object Int32Array]\":return\"int32\";case\"[object Uint8Array]\":return\"uint8\";case\"[object Uint16Array]\":return\"uint16\";case\"[object Uint32Array]\":return\"uint32\";case\"[object Uint8ClampedArray]\":return\"uint8_clamped\";case\"[object BigInt64Array]\":return\"bigint64\";case\"[object BigUint64Array]\":return\"biguint64\"}return Array.isArray(t)?\"array\":\"generic\"}(t),h=c[f];h.length<=o+1;)h.push(l(f,h.length-1));return(0,h[o+1])(t,e,r,n)}},{\"iota-array\":447,\"is-buffer\":449}],480:[function(t,e,r){\"use strict\";var n=t(\"double-bits\"),i=Math.pow(2,-1074);e.exports=function(t,e){if(isNaN(t)||isNaN(e))return NaN;if(t===e)return t;if(0===t)return e<0?-i:i;var r=n.hi(t),a=n.lo(t);e>t==t>0?a===-1>>>0?(r+=1,a=0):a+=1:0===a?(a=-1>>>0,r-=1):a-=1;return n.pack(a,r)}},{\"double-bits\":178}],481:[function(t,e,r){var n=Math.PI,i=c(120);function a(t,e,r,n){return[\"C\",t,e,r,n,r,n]}function o(t,e,r,n,i,a){return[\"C\",t/3+2/3*r,e/3+2/3*n,i/3+2/3*r,a/3+2/3*n,i,a]}function s(t,e,r,a,o,c,u,f,h,p){if(p)T=p[0],k=p[1],_=p[2],w=p[3];else{var d=l(t,e,-o);t=d.x,e=d.y;var m=(t-(f=(d=l(f,h,-o)).x))/2,g=(e-(h=d.y))/2,v=m*m/(r*r)+g*g/(a*a);v>1&&(r*=v=Math.sqrt(v),a*=v);var y=r*r,x=a*a,b=(c==u?-1:1)*Math.sqrt(Math.abs((y*x-y*g*g-x*m*m)/(y*g*g+x*m*m)));b==1/0&&(b=1);var _=b*r*g/a+(t+f)/2,w=b*-a*m/r+(e+h)/2,T=Math.asin(((e-w)/a).toFixed(9)),k=Math.asin(((h-w)/a).toFixed(9));(T=t<_?n-T:T)<0&&(T=2*n+T),(k=f<_?n-k:k)<0&&(k=2*n+k),u&&T>k&&(T-=2*n),!u&&k>T&&(k-=2*n)}if(Math.abs(k-T)>i){var M=k,A=f,S=h;k=T+i*(u&&k>T?1:-1);var E=s(f=_+r*Math.cos(k),h=w+a*Math.sin(k),r,a,o,0,u,A,S,[k,M,_,w])}var L=Math.tan((k-T)/4),C=4/3*r*L,P=4/3*a*L,I=[2*t-(t+C*Math.sin(T)),2*e-(e-P*Math.cos(T)),f+C*Math.sin(k),h-P*Math.cos(k),f,h];if(p)return I;E&&(I=I.concat(E));for(var O=0;O<I.length;){var z=l(I[O],I[O+1],o);I[O++]=z.x,I[O++]=z.y}return I}function l(t,e,r){return{x:t*Math.cos(r)-e*Math.sin(r),y:t*Math.sin(r)+e*Math.cos(r)}}function c(t){return t*(n/180)}e.exports=function(t){for(var e,r=[],n=0,i=0,l=0,u=0,f=null,h=null,p=0,d=0,m=0,g=t.length;m<g;m++){var v=t[m],y=v[0];switch(y){case\"M\":l=v[1],u=v[2];break;case\"A\":(v=s(p,d,v[1],v[2],c(v[3]),v[4],v[5],v[6],v[7])).unshift(\"C\"),v.length>7&&(r.push(v.splice(0,7)),v.unshift(\"C\"));break;case\"S\":var x=p,b=d;\"C\"!=e&&\"S\"!=e||(x+=x-n,b+=b-i),v=[\"C\",x,b,v[1],v[2],v[3],v[4]];break;case\"T\":\"Q\"==e||\"T\"==e?(f=2*p-f,h=2*d-h):(f=p,h=d),v=o(p,d,f,h,v[1],v[2]);break;case\"Q\":f=v[1],h=v[2],v=o(p,d,v[1],v[2],v[3],v[4]);break;case\"L\":v=a(p,d,v[1],v[2]);break;case\"H\":v=a(p,d,v[1],d);break;case\"V\":v=a(p,d,p,v[1]);break;case\"Z\":v=a(p,d,l,u)}e=y,p=v[v.length-2],d=v[v.length-1],v.length>4?(n=v[v.length-4],i=v[v.length-3]):(n=p,i=d),r.push(v)}return r}},{}],482:[function(t,e,r){r.vertexNormals=function(t,e,r){for(var n=e.length,i=new Array(n),a=void 0===r?1e-6:r,o=0;o<n;++o)i[o]=[0,0,0];for(o=0;o<t.length;++o)for(var s=t[o],l=0,c=s[s.length-1],u=s[0],f=0;f<s.length;++f){l=c,c=u,u=s[(f+1)%s.length];for(var h=e[l],p=e[c],d=e[u],m=new Array(3),g=0,v=new Array(3),y=0,x=0;x<3;++x)m[x]=h[x]-p[x],g+=m[x]*m[x],v[x]=d[x]-p[x],y+=v[x]*v[x];if(g*y>a){var b=i[c],_=1/Math.sqrt(g*y);for(x=0;x<3;++x){var w=(x+1)%3,T=(x+2)%3;b[x]+=_*(v[w]*m[T]-v[T]*m[w])}}}for(o=0;o<n;++o){b=i[o];var k=0;for(x=0;x<3;++x)k+=b[x]*b[x];if(k>a)for(_=1/Math.sqrt(k),x=0;x<3;++x)b[x]*=_;else for(x=0;x<3;++x)b[x]=0}return i},r.faceNormals=function(t,e,r){for(var n=t.length,i=new Array(n),a=void 0===r?1e-6:r,o=0;o<n;++o){for(var s=t[o],l=new Array(3),c=0;c<3;++c)l[c]=e[s[c]];var u=new Array(3),f=new Array(3);for(c=0;c<3;++c)u[c]=l[1][c]-l[0][c],f[c]=l[2][c]-l[0][c];var h=new Array(3),p=0;for(c=0;c<3;++c){var d=(c+1)%3,m=(c+2)%3;h[c]=u[d]*f[m]-u[m]*f[d],p+=h[c]*h[c]}p=p>a?1/Math.sqrt(p):0;for(c=0;c<3;++c)h[c]*=p;i[o]=h}return i}},{}],483:[function(t,e,r){\n",
       "/*\n",
       "object-assign\n",
       "(c) Sindre Sorhus\n",
       "@license MIT\n",
       "*/\n",
       "\"use strict\";var n=Object.getOwnPropertySymbols,i=Object.prototype.hasOwnProperty,a=Object.prototype.propertyIsEnumerable;function o(t){if(null==t)throw new TypeError(\"Object.assign cannot be called with null or undefined\");return Object(t)}e.exports=function(){try{if(!Object.assign)return!1;var t=new String(\"abc\");if(t[5]=\"de\",\"5\"===Object.getOwnPropertyNames(t)[0])return!1;for(var e={},r=0;r<10;r++)e[\"_\"+String.fromCharCode(r)]=r;if(\"0123456789\"!==Object.getOwnPropertyNames(e).map((function(t){return e[t]})).join(\"\"))return!1;var n={};return\"abcdefghijklmnopqrst\".split(\"\").forEach((function(t){n[t]=t})),\"abcdefghijklmnopqrst\"===Object.keys(Object.assign({},n)).join(\"\")}catch(t){return!1}}()?Object.assign:function(t,e){for(var r,s,l=o(t),c=1;c<arguments.length;c++){for(var u in r=Object(arguments[c]))i.call(r,u)&&(l[u]=r[u]);if(n){s=n(r);for(var f=0;f<s.length;f++)a.call(r,s[f])&&(l[s[f]]=r[s[f]])}}return l}},{}],484:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,i,a,o,s,l,c){var u=e+a+c;if(f>0){var f=Math.sqrt(u+1);t[0]=.5*(o-l)/f,t[1]=.5*(s-n)/f,t[2]=.5*(r-a)/f,t[3]=.5*f}else{var h=Math.max(e,a,c);f=Math.sqrt(2*h-u+1);e>=h?(t[0]=.5*f,t[1]=.5*(i+r)/f,t[2]=.5*(s+n)/f,t[3]=.5*(o-l)/f):a>=h?(t[0]=.5*(r+i)/f,t[1]=.5*f,t[2]=.5*(l+o)/f,t[3]=.5*(s-n)/f):(t[0]=.5*(n+s)/f,t[1]=.5*(o+l)/f,t[2]=.5*f,t[3]=.5*(r-i)/f)}return t}},{}],485:[function(t,e,r){\"use strict\";e.exports=function(t){var e=(t=t||{}).center||[0,0,0],r=t.rotation||[0,0,0,1],n=t.radius||1;e=[].slice.call(e,0,3),u(r=[].slice.call(r,0,4),r);var i=new f(r,e,Math.log(n));i.setDistanceLimits(t.zoomMin,t.zoomMax),(\"eye\"in t||\"up\"in t)&&i.lookAt(0,t.eye,t.center,t.up);return i};var n=t(\"filtered-vector\"),i=t(\"gl-mat4/lookAt\"),a=t(\"gl-mat4/fromQuat\"),o=t(\"gl-mat4/invert\"),s=t(\"./lib/quatFromFrame\");function l(t,e,r){return Math.sqrt(Math.pow(t,2)+Math.pow(e,2)+Math.pow(r,2))}function c(t,e,r,n){return Math.sqrt(Math.pow(t,2)+Math.pow(e,2)+Math.pow(r,2)+Math.pow(n,2))}function u(t,e){var r=e[0],n=e[1],i=e[2],a=e[3],o=c(r,n,i,a);o>1e-6?(t[0]=r/o,t[1]=n/o,t[2]=i/o,t[3]=a/o):(t[0]=t[1]=t[2]=0,t[3]=1)}function f(t,e,r){this.radius=n([r]),this.center=n(e),this.rotation=n(t),this.computedRadius=this.radius.curve(0),this.computedCenter=this.center.curve(0),this.computedRotation=this.rotation.curve(0),this.computedUp=[.1,0,0],this.computedEye=[.1,0,0],this.computedMatrix=[.1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0],this.recalcMatrix(0)}var h=f.prototype;h.lastT=function(){return Math.max(this.radius.lastT(),this.center.lastT(),this.rotation.lastT())},h.recalcMatrix=function(t){this.radius.curve(t),this.center.curve(t),this.rotation.curve(t);var e=this.computedRotation;u(e,e);var r=this.computedMatrix;a(r,e);var n=this.computedCenter,i=this.computedEye,o=this.computedUp,s=Math.exp(this.computedRadius[0]);i[0]=n[0]+s*r[2],i[1]=n[1]+s*r[6],i[2]=n[2]+s*r[10],o[0]=r[1],o[1]=r[5],o[2]=r[9];for(var l=0;l<3;++l){for(var c=0,f=0;f<3;++f)c+=r[l+4*f]*i[f];r[12+l]=-c}},h.getMatrix=function(t,e){this.recalcMatrix(t);var r=this.computedMatrix;if(e){for(var n=0;n<16;++n)e[n]=r[n];return e}return r},h.idle=function(t){this.center.idle(t),this.radius.idle(t),this.rotation.idle(t)},h.flush=function(t){this.center.flush(t),this.radius.flush(t),this.rotation.flush(t)},h.pan=function(t,e,r,n){e=e||0,r=r||0,n=n||0,this.recalcMatrix(t);var i=this.computedMatrix,a=i[1],o=i[5],s=i[9],c=l(a,o,s);a/=c,o/=c,s/=c;var u=i[0],f=i[4],h=i[8],p=u*a+f*o+h*s,d=l(u-=a*p,f-=o*p,h-=s*p);u/=d,f/=d,h/=d;var m=i[2],g=i[6],v=i[10],y=m*a+g*o+v*s,x=m*u+g*f+v*h,b=l(m-=y*a+x*u,g-=y*o+x*f,v-=y*s+x*h);m/=b,g/=b,v/=b;var _=u*e+a*r,w=f*e+o*r,T=h*e+s*r;this.center.move(t,_,w,T);var k=Math.exp(this.computedRadius[0]);k=Math.max(1e-4,k+n),this.radius.set(t,Math.log(k))},h.rotate=function(t,e,r,n){this.recalcMatrix(t),e=e||0,r=r||0;var i=this.computedMatrix,a=i[0],o=i[4],s=i[8],u=i[1],f=i[5],h=i[9],p=i[2],d=i[6],m=i[10],g=e*a+r*u,v=e*o+r*f,y=e*s+r*h,x=-(d*y-m*v),b=-(m*g-p*y),_=-(p*v-d*g),w=Math.sqrt(Math.max(0,1-Math.pow(x,2)-Math.pow(b,2)-Math.pow(_,2))),T=c(x,b,_,w);T>1e-6?(x/=T,b/=T,_/=T,w/=T):(x=b=_=0,w=1);var k=this.computedRotation,M=k[0],A=k[1],S=k[2],E=k[3],L=M*w+E*x+A*_-S*b,C=A*w+E*b+S*x-M*_,P=S*w+E*_+M*b-A*x,I=E*w-M*x-A*b-S*_;if(n){x=p,b=d,_=m;var O=Math.sin(n)/l(x,b,_);x*=O,b*=O,_*=O,I=I*(w=Math.cos(e))-(L=L*w+I*x+C*_-P*b)*x-(C=C*w+I*b+P*x-L*_)*b-(P=P*w+I*_+L*b-C*x)*_}var z=c(L,C,P,I);z>1e-6?(L/=z,C/=z,P/=z,I/=z):(L=C=P=0,I=1),this.rotation.set(t,L,C,P,I)},h.lookAt=function(t,e,r,n){this.recalcMatrix(t),r=r||this.computedCenter,e=e||this.computedEye,n=n||this.computedUp;var a=this.computedMatrix;i(a,e,r,n);var o=this.computedRotation;s(o,a[0],a[1],a[2],a[4],a[5],a[6],a[8],a[9],a[10]),u(o,o),this.rotation.set(t,o[0],o[1],o[2],o[3]);for(var l=0,c=0;c<3;++c)l+=Math.pow(r[c]-e[c],2);this.radius.set(t,.5*Math.log(Math.max(l,1e-6))),this.center.set(t,r[0],r[1],r[2])},h.translate=function(t,e,r,n){this.center.move(t,e||0,r||0,n||0)},h.setMatrix=function(t,e){var r=this.computedRotation;s(r,e[0],e[1],e[2],e[4],e[5],e[6],e[8],e[9],e[10]),u(r,r),this.rotation.set(t,r[0],r[1],r[2],r[3]);var n=this.computedMatrix;o(n,e);var i=n[15];if(Math.abs(i)>1e-6){var a=n[12]/i,l=n[13]/i,c=n[14]/i;this.recalcMatrix(t);var f=Math.exp(this.computedRadius[0]);this.center.set(t,a-n[2]*f,l-n[6]*f,c-n[10]*f),this.radius.idle(t)}else this.center.idle(t),this.radius.idle(t)},h.setDistance=function(t,e){e>0&&this.radius.set(t,Math.log(e))},h.setDistanceLimits=function(t,e){t=t>0?Math.log(t):-1/0,e=e>0?Math.log(e):1/0,e=Math.max(e,t),this.radius.bounds[0][0]=t,this.radius.bounds[1][0]=e},h.getDistanceLimits=function(t){var e=this.radius.bounds;return t?(t[0]=Math.exp(e[0][0]),t[1]=Math.exp(e[1][0]),t):[Math.exp(e[0][0]),Math.exp(e[1][0])]},h.toJSON=function(){return this.recalcMatrix(this.lastT()),{center:this.computedCenter.slice(),rotation:this.computedRotation.slice(),distance:Math.log(this.computedRadius[0]),zoomMin:this.radius.bounds[0][0],zoomMax:this.radius.bounds[1][0]}},h.fromJSON=function(t){var e=this.lastT(),r=t.center;r&&this.center.set(e,r[0],r[1],r[2]);var n=t.rotation;n&&this.rotation.set(e,n[0],n[1],n[2],n[3]);var i=t.distance;i&&i>0&&this.radius.set(e,Math.log(i)),this.setDistanceLimits(t.zoomMin,t.zoomMax)}},{\"./lib/quatFromFrame\":484,\"filtered-vector\":246,\"gl-mat4/fromQuat\":284,\"gl-mat4/invert\":295,\"gl-mat4/lookAt\":296}],486:[function(t,e,r){\n",
       "/*!\n",
       " * pad-left <https://github.com/jonschlinkert/pad-left>\n",
       " *\n",
       " * Copyright (c) 2014-2015, Jon Schlinkert.\n",
       " * Licensed under the MIT license.\n",
       " */\n",
       "\"use strict\";var n=t(\"repeat-string\");e.exports=function(t,e,r){return n(r=void 0!==r?r+\"\":\" \",e)+t}},{\"repeat-string\":537}],487:[function(t,e,r){\"use strict\";function n(t,e){if(\"string\"!=typeof t)return[t];var r=[t];\"string\"==typeof e||Array.isArray(e)?e={brackets:e}:e||(e={});var n=e.brackets?Array.isArray(e.brackets)?e.brackets:[e.brackets]:[\"{}\",\"[]\",\"()\"],i=e.escape||\"___\",a=!!e.flat;n.forEach((function(t){var e=new RegExp([\"\\\\\",t[0],\"[^\\\\\",t[0],\"\\\\\",t[1],\"]*\\\\\",t[1]].join(\"\")),n=[];function a(e,a,o){var s=r.push(e.slice(t[0].length,-t[1].length))-1;return n.push(s),i+s+i}r.forEach((function(t,n){for(var i,o=0;t!=i;)if(i=t,t=t.replace(e,a),o++>1e4)throw Error(\"References have circular dependency. Please, check them.\");r[n]=t})),n=n.reverse(),r=r.map((function(e){return n.forEach((function(r){e=e.replace(new RegExp(\"(\\\\\"+i+r+\"\\\\\"+i+\")\",\"g\"),t[0]+\"$1\"+t[1])})),e}))}));var o=new RegExp(\"\\\\\"+i+\"([0-9]+)\\\\\"+i);return a?r:function t(e,r,n){for(var i,a=[],s=0;i=o.exec(e);){if(s++>1e4)throw Error(\"Circular references in parenthesis\");a.push(e.slice(0,i.index)),a.push(t(r[i[1]],r)),e=e.slice(i.index+i[0].length)}return a.push(e),a}(r[0],r)}function i(t,e){if(e&&e.flat){var r,n=e&&e.escape||\"___\",i=t[0];if(!i)return\"\";for(var a=new RegExp(\"\\\\\"+n+\"([0-9]+)\\\\\"+n),o=0;i!=r;){if(o++>1e4)throw Error(\"Circular references in \"+t);r=i,i=i.replace(a,s)}return i}return t.reduce((function t(e,r){return Array.isArray(r)&&(r=r.reduce(t,\"\")),e+r}),\"\");function s(e,r){if(null==t[r])throw Error(\"Reference \"+r+\"is undefined\");return t[r]}}function a(t,e){return Array.isArray(t)?i(t,e):n(t,e)}a.parse=n,a.stringify=i,e.exports=a},{}],488:[function(t,e,r){\"use strict\";var n=t(\"pick-by-alias\");e.exports=function(t){var e;arguments.length>1&&(t=arguments);\"string\"==typeof t?t=t.split(/\\s/).map(parseFloat):\"number\"==typeof t&&(t=[t]);t.length&&\"number\"==typeof t[0]?e=1===t.length?{width:t[0],height:t[0],x:0,y:0}:2===t.length?{width:t[0],height:t[1],x:0,y:0}:{x:t[0],y:t[1],width:t[2]-t[0]||0,height:t[3]-t[1]||0}:t&&(t=n(t,{left:\"x l left Left\",top:\"y t top Top\",width:\"w width W Width\",height:\"h height W Width\",bottom:\"b bottom Bottom\",right:\"r right Right\"}),e={x:t.left||0,y:t.top||0},null==t.width?t.right?e.width=t.right-e.x:e.width=0:e.width=t.width,null==t.height?t.bottom?e.height=t.bottom-e.y:e.height=0:e.height=t.height);return e}},{\"pick-by-alias\":494}],489:[function(t,e,r){e.exports=function(t){var e=[];return t.replace(i,(function(t,r,i){var o=r.toLowerCase();for(i=function(t){var e=t.match(a);return e?e.map(Number):[]}(i),\"m\"==o&&i.length>2&&(e.push([r].concat(i.splice(0,2))),o=\"l\",r=\"m\"==r?\"l\":\"L\");;){if(i.length==n[o])return i.unshift(r),e.push(i);if(i.length<n[o])throw new Error(\"malformed path data\");e.push([r].concat(i.splice(0,n[o])))}})),e};var n={a:7,c:6,h:1,l:2,m:2,q:4,s:4,t:2,v:1,z:0},i=/([astvzqmhlc])([^astvzqmhlc]*)/gi;var a=/-?[0-9]*\\.?[0-9]+(?:e[-+]?\\d+)?/gi},{}],490:[function(t,e,r){e.exports=function(t,e){e||(e=[0,\"\"]),t=String(t);var r=parseFloat(t,10);return e[0]=r,e[1]=t.match(/[\\d.\\-\\+]*\\s*(.*)/)[1]||\"\",e}},{}],491:[function(t,e,r){(function(t){(function(){(function(){var r,n,i,a,o,s;\"undefined\"!=typeof performance&&null!==performance&&performance.now?e.exports=function(){return performance.now()}:null!=t&&t.hrtime?(e.exports=function(){return(r()-o)/1e6},n=t.hrtime,a=(r=function(){var t;return 1e9*(t=n())[0]+t[1]})(),s=1e9*t.uptime(),o=a-s):Date.now?(e.exports=function(){return Date.now()-i},i=Date.now()):(e.exports=function(){return(new Date).getTime()-i},i=(new Date).getTime())}).call(this)}).call(this)}).call(this,t(\"_process\"))},{_process:524}],492:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.length;if(e<32){for(var r=1,i=0;i<e;++i)for(var a=0;a<i;++a)if(t[i]<t[a])r=-r;else if(t[i]===t[a])return 0;return r}var o=n.mallocUint8(e);for(i=0;i<e;++i)o[i]=0;for(r=1,i=0;i<e;++i)if(!o[i]){var s=1;o[i]=1;for(a=t[i];a!==i;a=t[a]){if(o[a])return n.freeUint8(o),0;s+=1,o[a]=1}1&s||(r=-r)}return n.freeUint8(o),r};var n=t(\"typedarray-pool\")},{\"typedarray-pool\":613}],493:[function(t,e,r){\"use strict\";var n=t(\"typedarray-pool\"),i=t(\"invert-permutation\");r.rank=function(t){var e=t.length;switch(e){case 0:case 1:return 0;case 2:return t[1]}var r,a,o,s=n.mallocUint32(e),l=n.mallocUint32(e),c=0;for(i(t,l),o=0;o<e;++o)s[o]=t[o];for(o=e-1;o>0;--o)a=l[o],r=s[o],s[o]=s[a],s[a]=r,l[o]=l[r],l[r]=a,c=(c+r)*o;return n.freeUint32(l),n.freeUint32(s),c},r.unrank=function(t,e,r){switch(t){case 0:return r||[];case 1:return r?(r[0]=0,r):[0];case 2:return r?(e?(r[0]=0,r[1]=1):(r[0]=1,r[1]=0),r):e?[0,1]:[1,0]}var n,i,a,o=1;for((r=r||new Array(t))[0]=0,a=1;a<t;++a)r[a]=a,o=o*a|0;for(a=t-1;a>0;--a)e=e-(n=e/o|0)*o|0,o=o/a|0,i=0|r[a],r[a]=0|r[n],r[n]=0|i;return r}},{\"invert-permutation\":446,\"typedarray-pool\":613}],494:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){var n,a,o={};if(\"string\"==typeof e&&(e=i(e)),Array.isArray(e)){var s={};for(a=0;a<e.length;a++)s[e[a]]=!0;e=s}for(n in e)e[n]=i(e[n]);var l={};for(n in e){var c=e[n];if(Array.isArray(c))for(a=0;a<c.length;a++){var u=c[a];if(r&&(l[u]=!0),u in t){if(o[n]=t[u],r)for(var f=a;f<c.length;f++)l[c[f]]=!0;break}}else n in t&&(e[n]&&(o[n]=t[n]),r&&(l[n]=!0))}if(r)for(n in t)l[n]||(o[n]=t[n]);return o};var n={};function i(t){return n[t]?n[t]:(\"string\"==typeof t&&(t=n[t]=t.split(/\\s*,\\s*|\\s+/)),t)}},{}],495:[function(t,e,r){\"use strict\";e.exports=function(t,e){for(var r=0|e.length,i=t.length,a=[new Array(r),new Array(r)],o=0;o<r;++o)a[0][o]=[],a[1][o]=[];for(o=0;o<i;++o){var s=t[o];a[0][s[0]].push(s),a[1][s[1]].push(s)}var l=[];for(o=0;o<r;++o)a[0][o].length+a[1][o].length===0&&l.push([o]);function c(t,e){var r=a[e][t[e]];r.splice(r.indexOf(t),1)}function u(t,r,i){for(var o,s,l,u=0;u<2;++u)if(a[u][r].length>0){o=a[u][r][0],l=u;break}s=o[1^l];for(var f=0;f<2;++f)for(var h=a[f][r],p=0;p<h.length;++p){var d=h[p],m=d[1^f];n(e[t],e[r],e[s],e[m])>0&&(o=d,s=m,l=f)}return i||o&&c(o,l),s}function f(t,r){var i=a[r][t][0],o=[t];c(i,r);for(var s=i[1^r];;){for(;s!==t;)o.push(s),s=u(o[o.length-2],s,!1);if(a[0][t].length+a[1][t].length===0)break;var l=o[o.length-1],f=t,h=o[1],p=u(l,f,!0);if(n(e[l],e[f],e[h],e[p])<0)break;o.push(t),s=u(l,f)}return o}function h(t,e){return e[1]===e[e.length-1]}for(o=0;o<r;++o)for(var p=0;p<2;++p){for(var d=[];a[p][o].length>0;){a[0][o].length;var m=f(o,p);h(0,m)?d.push.apply(d,m):(d.length>0&&l.push(d),d=m)}d.length>0&&l.push(d)}return l};var n=t(\"compare-angle\")},{\"compare-angle\":138}],496:[function(t,e,r){\"use strict\";e.exports=function(t,e){for(var r=n(t,e.length),i=new Array(e.length),a=new Array(e.length),o=[],s=0;s<e.length;++s){var l=r[s].length;a[s]=l,i[s]=!0,l<=1&&o.push(s)}for(;o.length>0;){var c=o.pop();i[c]=!1;var u=r[c];for(s=0;s<u.length;++s){var f=u[s];0==--a[f]&&o.push(f)}}var h=new Array(e.length),p=[];for(s=0;s<e.length;++s)if(i[s]){c=p.length;h[s]=c,p.push(e[s])}else h[s]=-1;var d=[];for(s=0;s<t.length;++s){var m=t[s];i[m[0]]&&i[m[1]]&&d.push([h[m[0]],h[m[1]]])}return[d,p]};var n=t(\"edges-to-adjacency-list\")},{\"edges-to-adjacency-list\":183}],497:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=c(t,e);t=r[0];for(var f=(e=r[1]).length,h=(t.length,n(t,e.length)),p=0;p<f;++p)if(h[p].length%2==1)throw new Error(\"planar-graph-to-polyline: graph must be manifold\");var d=i(t,e);var m=(d=d.filter((function(t){for(var r=t.length,n=[0],i=0;i<r;++i){var a=e[t[i]],l=e[t[(i+1)%r]],c=o(-a[0],a[1]),u=o(-a[0],l[1]),f=o(l[0],a[1]),h=o(l[0],l[1]);n=s(n,s(s(c,u),s(f,h)))}return n[n.length-1]>0}))).length,g=new Array(m),v=new Array(m);for(p=0;p<m;++p){g[p]=p;var y=new Array(m),x=d[p].map((function(t){return e[t]})),b=a([x]),_=0;t:for(var w=0;w<m;++w)if(y[w]=0,p!==w){for(var T=(q=d[w]).length,k=0;k<T;++k){var M=b(e[q[k]]);if(0!==M){M<0&&(y[w]=1,_+=1);continue t}}y[w]=1,_+=1}v[p]=[_,p,y]}v.sort((function(t,e){return e[0]-t[0]}));for(p=0;p<m;++p){var A=(y=v[p])[1],S=y[2];for(w=0;w<m;++w)S[w]&&(g[w]=A)}var E=function(t){for(var e=new Array(t),r=0;r<t;++r)e[r]=[];return e}(m);for(p=0;p<m;++p)E[p].push(g[p]),E[g[p]].push(p);var L={},C=u(f,!1);for(p=0;p<m;++p)for(T=(q=d[p]).length,w=0;w<T;++w){var P=q[w],I=q[(w+1)%T],O=Math.min(P,I)+\":\"+Math.max(P,I);if(O in L){var z=L[O];E[z].push(p),E[p].push(z),C[P]=C[I]=!0}else L[O]=p}function D(t){for(var e=t.length,r=0;r<e;++r)if(!C[t[r]])return!1;return!0}var R=[],F=u(m,-1);for(p=0;p<m;++p)g[p]!==p||D(d[p])?F[p]=-1:(R.push(p),F[p]=0);r=[];for(;R.length>0;){var B=R.pop(),N=E[B];l(N,(function(t,e){return t-e}));var j,U=N.length,V=F[B];if(0===V){var q=d[B];j=[q]}for(p=0;p<U;++p){var H=N[p];if(!(F[H]>=0))if(F[H]=1^V,R.push(H),0===V)D(q=d[H])||(q.reverse(),j.push(q))}0===V&&r.push(j)}return r};var n=t(\"edges-to-adjacency-list\"),i=t(\"planar-dual\"),a=t(\"point-in-big-polygon\"),o=t(\"two-product\"),s=t(\"robust-sum\"),l=t(\"uniq\"),c=t(\"./lib/trim-leaves\");function u(t,e){for(var r=new Array(t),n=0;n<t;++n)r[n]=e;return r}},{\"./lib/trim-leaves\":496,\"edges-to-adjacency-list\":183,\"planar-dual\":495,\"point-in-big-polygon\":499,\"robust-sum\":549,\"two-product\":600,uniq:615}],498:[function(t,e,r){arguments[4][247][0].apply(r,arguments)},{dup:247}],499:[function(t,e,r){e.exports=function(t){for(var e=t.length,r=[],a=[],s=0;s<e;++s)for(var u=t[s],f=u.length,h=f-1,p=0;p<f;h=p++){var d=u[h],m=u[p];d[0]===m[0]?a.push([d,m]):r.push([d,m])}if(0===r.length)return 0===a.length?c:(g=l(a),function(t){return g(t[0],t[1])?0:1});var g;var v=i(r),y=function(t,e){return function(r){var i=o.le(e,r[0]);if(i<0)return 1;var a=t[i];if(!a){if(!(i>0&&e[i]===r[0]))return 1;a=t[i-1]}for(var s=1;a;){var l=a.key,c=n(r,l[0],l[1]);if(l[0][0]<l[1][0])if(c<0)a=a.left;else{if(!(c>0))return 0;s=-1,a=a.right}else if(c>0)a=a.left;else{if(!(c<0))return 0;s=1,a=a.right}}return s}}(v.slabs,v.coordinates);return 0===a.length?y:function(t,e){return function(r){return t(r[0],r[1])?0:e(r)}}(l(a),y)};var n=t(\"robust-orientation\")[3],i=t(\"slab-decomposition\"),a=t(\"interval-tree-1d\"),o=t(\"binary-search-bounds\");function s(){return!0}function l(t){for(var e={},r=0;r<t.length;++r){var n=t[r],i=n[0][0],o=n[0][1],l=n[1][1],c=[Math.min(o,l),Math.max(o,l)];i in e?e[i].push(c):e[i]=[c]}var u={},f=Object.keys(e);for(r=0;r<f.length;++r){var h=e[f[r]];u[f[r]]=a(h)}return function(t){return function(e,r){var n=t[e];return!!n&&!!n.queryPoint(r,s)}}(u)}function c(t){return 1}},{\"binary-search-bounds\":498,\"interval-tree-1d\":444,\"robust-orientation\":544,\"slab-decomposition\":562}],500:[function(t,e,r){\n",
       "/*\n",
       " * @copyright 2016 Sean Connelly (@voidqk), http://syntheti.cc\n",
       " * @license MIT\n",
       " * @preserve Project Home: https://github.com/voidqk/polybooljs\n",
       " */\n",
       "var n,i=t(\"./lib/build-log\"),a=t(\"./lib/epsilon\"),o=t(\"./lib/intersecter\"),s=t(\"./lib/segment-chainer\"),l=t(\"./lib/segment-selector\"),c=t(\"./lib/geojson\"),u=!1,f=a();function h(t,e,r){var i=n.segments(t),a=n.segments(e),o=r(n.combine(i,a));return n.polygon(o)}n={buildLog:function(t){return!0===t?u=i():!1===t&&(u=!1),!1!==u&&u.list},epsilon:function(t){return f.epsilon(t)},segments:function(t){var e=o(!0,f,u);return t.regions.forEach(e.addRegion),{segments:e.calculate(t.inverted),inverted:t.inverted}},combine:function(t,e){return{combined:o(!1,f,u).calculate(t.segments,t.inverted,e.segments,e.inverted),inverted1:t.inverted,inverted2:e.inverted}},selectUnion:function(t){return{segments:l.union(t.combined,u),inverted:t.inverted1||t.inverted2}},selectIntersect:function(t){return{segments:l.intersect(t.combined,u),inverted:t.inverted1&&t.inverted2}},selectDifference:function(t){return{segments:l.difference(t.combined,u),inverted:t.inverted1&&!t.inverted2}},selectDifferenceRev:function(t){return{segments:l.differenceRev(t.combined,u),inverted:!t.inverted1&&t.inverted2}},selectXor:function(t){return{segments:l.xor(t.combined,u),inverted:t.inverted1!==t.inverted2}},polygon:function(t){return{regions:s(t.segments,f,u),inverted:t.inverted}},polygonFromGeoJSON:function(t){return c.toPolygon(n,t)},polygonToGeoJSON:function(t){return c.fromPolygon(n,f,t)},union:function(t,e){return h(t,e,n.selectUnion)},intersect:function(t,e){return h(t,e,n.selectIntersect)},difference:function(t,e){return h(t,e,n.selectDifference)},differenceRev:function(t,e){return h(t,e,n.selectDifferenceRev)},xor:function(t,e){return h(t,e,n.selectXor)}},\"object\"==typeof window&&(window.PolyBool=n),e.exports=n},{\"./lib/build-log\":501,\"./lib/epsilon\":502,\"./lib/geojson\":503,\"./lib/intersecter\":504,\"./lib/segment-chainer\":506,\"./lib/segment-selector\":507}],501:[function(t,e,r){e.exports=function(){var t,e=0,r=!1;function n(e,r){return t.list.push({type:e,data:r?JSON.parse(JSON.stringify(r)):void 0}),t}return t={list:[],segmentId:function(){return e++},checkIntersection:function(t,e){return n(\"check\",{seg1:t,seg2:e})},segmentChop:function(t,e){return n(\"div_seg\",{seg:t,pt:e}),n(\"chop\",{seg:t,pt:e})},statusRemove:function(t){return n(\"pop_seg\",{seg:t})},segmentUpdate:function(t){return n(\"seg_update\",{seg:t})},segmentNew:function(t,e){return n(\"new_seg\",{seg:t,primary:e})},segmentRemove:function(t){return n(\"rem_seg\",{seg:t})},tempStatus:function(t,e,r){return n(\"temp_status\",{seg:t,above:e,below:r})},rewind:function(t){return n(\"rewind\",{seg:t})},status:function(t,e,r){return n(\"status\",{seg:t,above:e,below:r})},vert:function(e){return e===r?t:(r=e,n(\"vert\",{x:e}))},log:function(t){return\"string\"!=typeof t&&(t=JSON.stringify(t,!1,\"  \")),n(\"log\",{txt:t})},reset:function(){return n(\"reset\")},selected:function(t){return n(\"selected\",{segs:t})},chainStart:function(t){return n(\"chain_start\",{seg:t})},chainRemoveHead:function(t,e){return n(\"chain_rem_head\",{index:t,pt:e})},chainRemoveTail:function(t,e){return n(\"chain_rem_tail\",{index:t,pt:e})},chainNew:function(t,e){return n(\"chain_new\",{pt1:t,pt2:e})},chainMatch:function(t){return n(\"chain_match\",{index:t})},chainClose:function(t){return n(\"chain_close\",{index:t})},chainAddHead:function(t,e){return n(\"chain_add_head\",{index:t,pt:e})},chainAddTail:function(t,e){return n(\"chain_add_tail\",{index:t,pt:e})},chainConnect:function(t,e){return n(\"chain_con\",{index1:t,index2:e})},chainReverse:function(t){return n(\"chain_rev\",{index:t})},chainJoin:function(t,e){return n(\"chain_join\",{index1:t,index2:e})},done:function(){return n(\"done\")}}}},{}],502:[function(t,e,r){e.exports=function(t){\"number\"!=typeof t&&(t=1e-10);var e={epsilon:function(e){return\"number\"==typeof e&&(t=e),t},pointAboveOrOnLine:function(e,r,n){var i=r[0],a=r[1],o=n[0],s=n[1],l=e[0];return(o-i)*(e[1]-a)-(s-a)*(l-i)>=-t},pointBetween:function(e,r,n){var i=e[1]-r[1],a=n[0]-r[0],o=e[0]-r[0],s=n[1]-r[1],l=o*a+i*s;return!(l<t)&&!(l-(a*a+s*s)>-t)},pointsSameX:function(e,r){return Math.abs(e[0]-r[0])<t},pointsSameY:function(e,r){return Math.abs(e[1]-r[1])<t},pointsSame:function(t,r){return e.pointsSameX(t,r)&&e.pointsSameY(t,r)},pointsCompare:function(t,r){return e.pointsSameX(t,r)?e.pointsSameY(t,r)?0:t[1]<r[1]?-1:1:t[0]<r[0]?-1:1},pointsCollinear:function(e,r,n){var i=e[0]-r[0],a=e[1]-r[1],o=r[0]-n[0],s=r[1]-n[1];return Math.abs(i*s-o*a)<t},linesIntersect:function(e,r,n,i){var a=r[0]-e[0],o=r[1]-e[1],s=i[0]-n[0],l=i[1]-n[1],c=a*l-o*s;if(Math.abs(c)<t)return!1;var u=e[0]-n[0],f=e[1]-n[1],h=(s*f-l*u)/c,p=(a*f-o*u)/c,d={alongA:0,alongB:0,pt:[e[0]+h*a,e[1]+h*o]};return d.alongA=h<=-t?-2:h<t?-1:h-1<=-t?0:h-1<t?1:2,d.alongB=p<=-t?-2:p<t?-1:p-1<=-t?0:p-1<t?1:2,d},pointInsideRegion:function(e,r){for(var n=e[0],i=e[1],a=r[r.length-1][0],o=r[r.length-1][1],s=!1,l=0;l<r.length;l++){var c=r[l][0],u=r[l][1];u-i>t!=o-i>t&&(a-c)*(i-u)/(o-u)+c-n>t&&(s=!s),a=c,o=u}return s}};return e}},{}],503:[function(t,e,r){var n={toPolygon:function(t,e){function r(e){if(e.length<=0)return t.segments({inverted:!1,regions:[]});function r(e){var r=e.slice(0,e.length-1);return t.segments({inverted:!1,regions:[r]})}for(var n=r(e[0]),i=1;i<e.length;i++)n=t.selectDifference(t.combine(n,r(e[i])));return n}if(\"Polygon\"===e.type)return t.polygon(r(e.coordinates));if(\"MultiPolygon\"===e.type){for(var n=t.segments({inverted:!1,regions:[]}),i=0;i<e.coordinates.length;i++)n=t.selectUnion(t.combine(n,r(e.coordinates[i])));return t.polygon(n)}throw new Error(\"PolyBool: Cannot convert GeoJSON object to PolyBool polygon\")},fromPolygon:function(t,e,r){function n(t,r){return e.pointInsideRegion([.5*(t[0][0]+t[1][0]),.5*(t[0][1]+t[1][1])],r)}function i(t){return{region:t,children:[]}}r=t.polygon(t.segments(r));var a=i(null);function o(t,e){for(var r=0;r<t.children.length;r++){if(n(e,(s=t.children[r]).region))return void o(s,e)}var a=i(e);for(r=0;r<t.children.length;r++){var s;n((s=t.children[r]).region,e)&&(a.children.push(s),t.children.splice(r,1),r--)}t.children.push(a)}for(var s=0;s<r.regions.length;s++){var l=r.regions[s];l.length<3||o(a,l)}function c(t,e){for(var r=0,n=t[t.length-1][0],i=t[t.length-1][1],a=[],o=0;o<t.length;o++){var s=t[o][0],l=t[o][1];a.push([s,l]),r+=l*n-s*i,n=s,i=l}return r<0!==e&&a.reverse(),a.push([a[0][0],a[0][1]]),a}var u=[];function f(t){var e=[c(t.region,!1)];u.push(e);for(var r=0;r<t.children.length;r++)e.push(h(t.children[r]))}function h(t){for(var e=0;e<t.children.length;e++)f(t.children[e]);return c(t.region,!0)}for(s=0;s<a.children.length;s++)f(a.children[s]);return u.length<=0?{type:\"Polygon\",coordinates:[]}:1==u.length?{type:\"Polygon\",coordinates:u[0]}:{type:\"MultiPolygon\",coordinates:u}}};e.exports=n},{}],504:[function(t,e,r){var n=t(\"./linked-list\");e.exports=function(t,e,r){function i(t,e,n){return{id:r?r.segmentId():-1,start:t,end:e,myFill:{above:n.myFill.above,below:n.myFill.below},otherFill:null}}var a=n.create();function o(t,r){a.insertBefore(t,(function(n){return function(t,r,n,i,a,o){var s=e.pointsCompare(r,a);return 0!==s?s:e.pointsSame(n,o)?0:t!==i?t?1:-1:e.pointAboveOrOnLine(n,i?a:o,i?o:a)?1:-1}(t.isStart,t.pt,r,n.isStart,n.pt,n.other.pt)<0}))}function s(t,e){var r=function(t,e){var r=n.node({isStart:!0,pt:t.start,seg:t,primary:e,other:null,status:null});return o(r,t.end),r}(t,e);return function(t,e,r){var i=n.node({isStart:!1,pt:e.end,seg:e,primary:r,other:t,status:null});t.other=i,o(i,t.pt)}(r,t,e),r}function l(t,e){var n=i(e,t.seg.end,t.seg);return function(t,e){r&&r.segmentChop(t.seg,e),t.other.remove(),t.seg.end=e,t.other.pt=e,o(t.other,t.pt)}(t,e),s(n,t.primary)}function c(i,o){var s=n.create();function c(t){return s.findTransition((function(r){var n,i,a,o,s,l;return(n=t,i=r.ev,a=n.seg.start,o=n.seg.end,s=i.seg.start,l=i.seg.end,e.pointsCollinear(a,s,l)?e.pointsCollinear(o,s,l)||e.pointAboveOrOnLine(o,s,l)?1:-1:e.pointAboveOrOnLine(a,s,l)?1:-1)>0}))}function u(t,n){var i=t.seg,a=n.seg,o=i.start,s=i.end,c=a.start,u=a.end;r&&r.checkIntersection(i,a);var f=e.linesIntersect(o,s,c,u);if(!1===f){if(!e.pointsCollinear(o,s,c))return!1;if(e.pointsSame(o,u)||e.pointsSame(s,c))return!1;var h=e.pointsSame(o,c),p=e.pointsSame(s,u);if(h&&p)return n;var d=!h&&e.pointBetween(o,c,u),m=!p&&e.pointBetween(s,c,u);if(h)return m?l(n,s):l(t,u),n;d&&(p||(m?l(n,s):l(t,u)),l(n,o))}else 0===f.alongA&&(-1===f.alongB?l(t,c):0===f.alongB?l(t,f.pt):1===f.alongB&&l(t,u)),0===f.alongB&&(-1===f.alongA?l(n,o):0===f.alongA?l(n,f.pt):1===f.alongA&&l(n,s));return!1}for(var f=[];!a.isEmpty();){var h=a.getHead();if(r&&r.vert(h.pt[0]),h.isStart){r&&r.segmentNew(h.seg,h.primary);var p=c(h),d=p.before?p.before.ev:null,m=p.after?p.after.ev:null;function g(){if(d){var t=u(h,d);if(t)return t}return!!m&&u(h,m)}r&&r.tempStatus(h.seg,!!d&&d.seg,!!m&&m.seg);var v,y=g();if(y){var x;if(t)(x=null===h.seg.myFill.below||h.seg.myFill.above!==h.seg.myFill.below)&&(y.seg.myFill.above=!y.seg.myFill.above);else y.seg.otherFill=h.seg.myFill;r&&r.segmentUpdate(y.seg),h.other.remove(),h.remove()}if(a.getHead()!==h){r&&r.rewind(h.seg);continue}if(t)x=null===h.seg.myFill.below||h.seg.myFill.above!==h.seg.myFill.below,h.seg.myFill.below=m?m.seg.myFill.above:i,h.seg.myFill.above=x?!h.seg.myFill.below:h.seg.myFill.below;else if(null===h.seg.otherFill)v=m?h.primary===m.primary?m.seg.otherFill.above:m.seg.myFill.above:h.primary?o:i,h.seg.otherFill={above:v,below:v};r&&r.status(h.seg,!!d&&d.seg,!!m&&m.seg),h.other.status=p.insert(n.node({ev:h}))}else{var b=h.status;if(null===b)throw new Error(\"PolyBool: Zero-length segment detected; your epsilon is probably too small or too large\");if(s.exists(b.prev)&&s.exists(b.next)&&u(b.prev.ev,b.next.ev),r&&r.statusRemove(b.ev.seg),b.remove(),!h.primary){var _=h.seg.myFill;h.seg.myFill=h.seg.otherFill,h.seg.otherFill=_}f.push(h.seg)}a.getHead().remove()}return r&&r.done(),f}return t?{addRegion:function(t){for(var n,i,a,o=t[t.length-1],l=0;l<t.length;l++){n=o,o=t[l];var c=e.pointsCompare(n,o);0!==c&&s((i=c<0?n:o,a=c<0?o:n,{id:r?r.segmentId():-1,start:i,end:a,myFill:{above:null,below:null},otherFill:null}),!0)}},calculate:function(t){return c(t,!1)}}:{calculate:function(t,e,r,n){return t.forEach((function(t){s(i(t.start,t.end,t),!0)})),r.forEach((function(t){s(i(t.start,t.end,t),!1)})),c(e,n)}}}},{\"./linked-list\":505}],505:[function(t,e,r){e.exports={create:function(){var t={root:{root:!0,next:null},exists:function(e){return null!==e&&e!==t.root},isEmpty:function(){return null===t.root.next},getHead:function(){return t.root.next},insertBefore:function(e,r){for(var n=t.root,i=t.root.next;null!==i;){if(r(i))return e.prev=i.prev,e.next=i,i.prev.next=e,void(i.prev=e);n=i,i=i.next}n.next=e,e.prev=n,e.next=null},findTransition:function(e){for(var r=t.root,n=t.root.next;null!==n&&!e(n);)r=n,n=n.next;return{before:r===t.root?null:r,after:n,insert:function(t){return t.prev=r,t.next=n,r.next=t,null!==n&&(n.prev=t),t}}}};return t},node:function(t){return t.prev=null,t.next=null,t.remove=function(){t.prev.next=t.next,t.next&&(t.next.prev=t.prev),t.prev=null,t.next=null},t}}},{}],506:[function(t,e,r){e.exports=function(t,e,r){var n=[],i=[];return t.forEach((function(t){var a=t.start,o=t.end;if(e.pointsSame(a,o))console.warn(\"PolyBool: Warning: Zero-length segment detected; your epsilon is probably too small or too large\");else{r&&r.chainStart(t);for(var s={index:0,matches_head:!1,matches_pt1:!1},l={index:0,matches_head:!1,matches_pt1:!1},c=s,u=0;u<n.length;u++){var f=(g=n[u])[0],h=(g[1],g[g.length-1]);g[g.length-2];if(e.pointsSame(f,a)){if(k(u,!0,!0))break}else if(e.pointsSame(f,o)){if(k(u,!0,!1))break}else if(e.pointsSame(h,a)){if(k(u,!1,!0))break}else if(e.pointsSame(h,o)&&k(u,!1,!1))break}if(c===s)return n.push([a,o]),void(r&&r.chainNew(a,o));if(c===l){r&&r.chainMatch(s.index);var p=s.index,d=s.matches_pt1?o:a,m=s.matches_head,g=n[p],v=m?g[0]:g[g.length-1],y=m?g[1]:g[g.length-2],x=m?g[g.length-1]:g[0],b=m?g[g.length-2]:g[1];return e.pointsCollinear(y,v,d)&&(m?(r&&r.chainRemoveHead(s.index,d),g.shift()):(r&&r.chainRemoveTail(s.index,d),g.pop()),v=y),e.pointsSame(x,d)?(n.splice(p,1),e.pointsCollinear(b,x,v)&&(m?(r&&r.chainRemoveTail(s.index,v),g.pop()):(r&&r.chainRemoveHead(s.index,v),g.shift())),r&&r.chainClose(s.index),void i.push(g)):void(m?(r&&r.chainAddHead(s.index,d),g.unshift(d)):(r&&r.chainAddTail(s.index,d),g.push(d)))}var _=s.index,w=l.index;r&&r.chainConnect(_,w);var T=n[_].length<n[w].length;s.matches_head?l.matches_head?T?(M(_),A(_,w)):(M(w),A(w,_)):A(w,_):l.matches_head?A(_,w):T?(M(_),A(w,_)):(M(w),A(_,w))}function k(t,e,r){return c.index=t,c.matches_head=e,c.matches_pt1=r,c===s?(c=l,!1):(c=null,!0)}function M(t){r&&r.chainReverse(t),n[t].reverse()}function A(t,i){var a=n[t],o=n[i],s=a[a.length-1],l=a[a.length-2],c=o[0],u=o[1];e.pointsCollinear(l,s,c)&&(r&&r.chainRemoveTail(t,s),a.pop(),s=l),e.pointsCollinear(s,c,u)&&(r&&r.chainRemoveHead(i,c),o.shift()),r&&r.chainJoin(t,i),n[t]=a.concat(o),n.splice(i,1)}})),i}},{}],507:[function(t,e,r){function n(t,e,r){var n=[];return t.forEach((function(t){var i=(t.myFill.above?8:0)+(t.myFill.below?4:0)+(t.otherFill&&t.otherFill.above?2:0)+(t.otherFill&&t.otherFill.below?1:0);0!==e[i]&&n.push({id:r?r.segmentId():-1,start:t.start,end:t.end,myFill:{above:1===e[i],below:2===e[i]},otherFill:null})})),r&&r.selected(n),n}var i={union:function(t,e){return n(t,[0,2,1,0,2,2,0,0,1,0,1,0,0,0,0,0],e)},intersect:function(t,e){return n(t,[0,0,0,0,0,2,0,2,0,0,1,1,0,2,1,0],e)},difference:function(t,e){return n(t,[0,0,0,0,2,0,2,0,1,1,0,0,0,1,2,0],e)},differenceRev:function(t,e){return n(t,[0,2,1,0,0,0,1,1,0,2,0,2,0,0,0,0],e)},xor:function(t,e){return n(t,[0,2,1,0,2,0,0,1,1,0,0,2,0,1,2,0],e)}};e.exports=i},{}],508:[function(t,e,r){\"use strict\";var n=new Float64Array(4),i=new Float64Array(4),a=new Float64Array(4);e.exports=function(t,e,r,o,s){n.length<o.length&&(n=new Float64Array(o.length),i=new Float64Array(o.length),a=new Float64Array(o.length));for(var l=0;l<o.length;++l)n[l]=t[l]-o[l],i[l]=e[l]-t[l],a[l]=r[l]-t[l];var c=0,u=0,f=0,h=0,p=0,d=0;for(l=0;l<o.length;++l){var m=i[l],g=a[l],v=n[l];c+=m*m,u+=m*g,f+=g*g,h+=v*m,p+=v*g,d+=v*v}var y,x,b,_,w,T=Math.abs(c*f-u*u),k=u*p-f*h,M=u*h-c*p;if(k+M<=T)if(k<0)M<0&&h<0?(M=0,-h>=c?(k=1,y=c+2*h+d):y=h*(k=-h/c)+d):(k=0,p>=0?(M=0,y=d):-p>=f?(M=1,y=f+2*p+d):y=p*(M=-p/f)+d);else if(M<0)M=0,h>=0?(k=0,y=d):-h>=c?(k=1,y=c+2*h+d):y=h*(k=-h/c)+d;else{var A=1/T;y=(k*=A)*(c*k+u*(M*=A)+2*h)+M*(u*k+f*M+2*p)+d}else k<0?(b=f+p)>(x=u+h)?(_=b-x)>=(w=c-2*u+f)?(k=1,M=0,y=c+2*h+d):y=(k=_/w)*(c*k+u*(M=1-k)+2*h)+M*(u*k+f*M+2*p)+d:(k=0,b<=0?(M=1,y=f+2*p+d):p>=0?(M=0,y=d):y=p*(M=-p/f)+d):M<0?(b=c+h)>(x=u+p)?(_=b-x)>=(w=c-2*u+f)?(M=1,k=0,y=f+2*p+d):y=(k=1-(M=_/w))*(c*k+u*M+2*h)+M*(u*k+f*M+2*p)+d:(M=0,b<=0?(k=1,y=c+2*h+d):h>=0?(k=0,y=d):y=h*(k=-h/c)+d):(_=f+p-u-h)<=0?(k=0,M=1,y=f+2*p+d):_>=(w=c-2*u+f)?(k=1,M=0,y=c+2*h+d):y=(k=_/w)*(c*k+u*(M=1-k)+2*h)+M*(u*k+f*M+2*p)+d;var S=1-k-M;for(l=0;l<o.length;++l)s[l]=S*t[l]+k*e[l]+M*r[l];return y<0?0:y}},{}],509:[function(t,e,r){\"use strict\";var n=t(\"stream\").Transform,i=t(\"stream-parser\");function a(){n.call(this,{readableObjectMode:!0})}function o(t,e,r){Error.call(this),Error.captureStackTrace(this,this.constructor),this.name=this.constructor.name,this.message=t,e&&(this.code=e),r&&(this.statusCode=r)}a.prototype=Object.create(n.prototype),a.prototype.constructor=a,i(a.prototype),r.ParserStream=a,r.sliceEq=function(t,e,r){for(var n=e,i=0;i<r.length;)if(t[n++]!==r[i++])return!1;return!0},r.str2arr=function(t,e){var r=[],n=0;if(e&&\"hex\"===e)for(;n<t.length;)r.push(parseInt(t.slice(n,n+2),16)),n+=2;else for(;n<t.length;n++)r.push(255&t.charCodeAt(n));return r},r.readUInt16LE=function(t,e){return t[e]|t[e+1]<<8},r.readUInt16BE=function(t,e){return t[e+1]|t[e]<<8},r.readUInt32LE=function(t,e){return t[e]|t[e+1]<<8|t[e+2]<<16|16777216*t[e+3]},r.readUInt32BE=function(t,e){return t[e+3]|t[e+2]<<8|t[e+1]<<16|16777216*t[e]},o.prototype=Object.create(Error.prototype),o.prototype.constructor=o,r.ProbeError=o},{stream:565,\"stream-parser\":581}],510:[function(t,e,r){\"use strict\";function n(t,e){var r=new Error(t);return r.code=e,r}function i(t){try{return decodeURIComponent(escape(t))}catch(e){return t}}function a(t,e,r){this.input=t.subarray(e,r),this.start=e;var i=String.fromCharCode.apply(null,this.input.subarray(0,4));if(\"II*\\0\"!==i&&\"MM\\0*\"!==i)throw n(\"invalid TIFF signature\",\"EBADDATA\");this.big_endian=\"M\"===i[0]}a.prototype.each=function(t){this.aborted=!1;var e=this.read_uint32(4);for(this.ifds_to_read=[{id:0,offset:e}];this.ifds_to_read.length>0&&!this.aborted;){var r=this.ifds_to_read.shift();r.offset&&this.scan_ifd(r.id,r.offset,t)}},a.prototype.read_uint16=function(t){var e=this.input;if(t+2>e.length)throw n(\"unexpected EOF\",\"EBADDATA\");return this.big_endian?256*e[t]+e[t+1]:e[t]+256*e[t+1]},a.prototype.read_uint32=function(t){var e=this.input;if(t+4>e.length)throw n(\"unexpected EOF\",\"EBADDATA\");return this.big_endian?16777216*e[t]+65536*e[t+1]+256*e[t+2]+e[t+3]:e[t]+256*e[t+1]+65536*e[t+2]+16777216*e[t+3]},a.prototype.is_subifd_link=function(t,e){return 0===t&&34665===e||0===t&&34853===e||34665===t&&40965===e},a.prototype.exif_format_length=function(t){switch(t){case 1:case 2:case 6:case 7:return 1;case 3:case 8:return 2;case 4:case 9:case 11:return 4;case 5:case 10:case 12:return 8;default:return 0}},a.prototype.exif_format_read=function(t,e){var r;switch(t){case 1:case 2:return r=this.input[e];case 6:return(r=this.input[e])|33554430*(128&r);case 3:return r=this.read_uint16(e);case 8:return(r=this.read_uint16(e))|131070*(32768&r);case 4:return r=this.read_uint32(e);case 9:return 0|(r=this.read_uint32(e));case 5:case 10:case 11:case 12:case 7:default:return null}},a.prototype.scan_ifd=function(t,e,r){var a=this.read_uint16(e);e+=2;for(var o=0;o<a;o++){var s=this.read_uint16(e),l=this.read_uint16(e+2),c=this.read_uint32(e+4),u=this.exif_format_length(l),f=c*u,h=f<=4?e+8:this.read_uint32(e+8),p=!1;if(h+f>this.input.length)throw n(\"unexpected EOF\",\"EBADDATA\");for(var d=[],m=h,g=0;g<c;g++,m+=u){var v=this.exif_format_read(l,m);if(null===v){d=null;break}d.push(v)}if(Array.isArray(d)&&2===l&&(d=i(String.fromCharCode.apply(null,d)))&&\"\\0\"===d[d.length-1]&&(d=d.slice(0,-1)),this.is_subifd_link(t,s)&&Array.isArray(d)&&Number.isInteger(d[0])&&d[0]>0&&(this.ifds_to_read.push({id:s,offset:d[0]}),p=!0),!1===r({is_big_endian:this.big_endian,ifd:t,tag:s,format:l,count:c,entry_offset:e+this.start,data_length:f,data_offset:h+this.start,value:d,is_subifd_link:p}))return void(this.aborted=!0);e+=12}0===t&&this.ifds_to_read.push({id:1,offset:this.read_uint32(e)})},e.exports.ExifParser=a,e.exports.get_orientation=function(t){var e=0;try{return new a(t,0,t.length).each((function(t){if(0===t.ifd&&274===t.tag&&Array.isArray(t.value))return e=t.value[0],!1})),e}catch(t){return-1}}},{}],511:[function(t,e,r){\"use strict\";var n=t(\"./common\").readUInt16BE,i=t(\"./common\").readUInt32BE;function a(t,e){if(t.length<4+e)return null;var r=i(t,e);return t.length<r+e||r<8?null:{boxtype:String.fromCharCode.apply(null,t.slice(e+4,e+8)),data:t.slice(e+8,e+r),end:e+r}}function o(t,e){for(var r=0;;){var n=a(t,r);if(!n)break;switch(n.boxtype){case\"ispe\":e.sizes.push({width:i(n.data,4),height:i(n.data,8)});break;case\"irot\":e.transforms.push({type:\"irot\",value:3&n.data[0]});break;case\"imir\":e.transforms.push({type:\"imir\",value:1&n.data[0]})}r=n.end}}function s(t,e,r){for(var n=0,i=0;i<r;i++)n=256*n+(t[e+i]||0);return n}function l(t,e){for(var r=t[4]>>4&15,i=15&t[4],a=t[5]>>4&15,o=n(t,6),l=8,c=0;c<o;c++){var u=n(t,l),f=n(t,l+=2),h=s(t,l+=2,a),p=n(t,l+=a);if(l+=2,0===f&&1===p){var d=s(t,l,r),m=s(t,l+r,i);e.item_loc[u]={length:m,offset:d+h}}l+=p*(r+i)}}function c(t,e){for(var r=n(t,4),i=6,o=0;o<r;o++){var s=a(t,i);if(!s)break;if(\"infe\"===s.boxtype){for(var l=n(s.data,4),c=\"\",u=8;u<s.data.length&&s.data[u];u++)c+=String.fromCharCode(s.data[u]);e.item_inf[c]=l}i=s.end}}function u(t,e){for(var r=0;;){var n=a(t,r);if(!n)break;\"ipco\"===n.boxtype&&o(n.data,e),r=n.end}}e.exports.unbox=a,e.exports.readSizeFromMeta=function(t){var e={sizes:[],transforms:[],item_inf:{},item_loc:{}};if(function(t,e){for(var r=4;;){var n=a(t,r);if(!n)break;\"iprp\"===n.boxtype&&u(n.data,e),\"iloc\"===n.boxtype&&l(n.data,e),\"iinf\"===n.boxtype&&c(n.data,e),r=n.end}}(t,e),e.sizes.length){var r,n,i,o=(r=e.sizes,n=r.reduce((function(t,e){return t.width>e.width||t.width===e.width&&t.height>e.height?t:e})),i=r.reduce((function(t,e){return t.height>e.height||t.height===e.height&&t.width>e.width?t:e})),n.width>i.height||n.width===i.height&&n.height>i.width?n:i),s=1;e.transforms.forEach((function(t){var e={1:6,2:5,3:8,4:7,5:4,6:3,7:2,8:1},r={1:4,2:3,3:2,4:1,5:6,6:5,7:8,8:7};if(\"imir\"===t.type&&(s=0===t.value?r[s]:e[s=e[s=r[s]]]),\"irot\"===t.type)for(var n=0;n<t.value;n++)s=e[s]}));var f=null;return e.item_inf.Exif&&(f=e.item_loc[e.item_inf.Exif]),{width:o.width,height:o.height,orientation:e.transforms.length?s:null,variants:e.sizes,exif_location:f}}},e.exports.getMimeType=function(t){var e=String.fromCharCode.apply(null,t.slice(0,4)),r={};r[e]=!0;for(var n=8;n<t.length;n+=4)r[String.fromCharCode.apply(null,t.slice(n,n+4))]=!0;if(r.mif1||r.msf1||r.miaf)return\"avif\"===e||\"avis\"===e||\"avio\"===e?{type:\"avif\",mime:\"image/avif\"}:\"heic\"===e||\"heix\"===e?{type:\"heic\",mime:\"image/heic\"}:\"hevc\"===e||\"hevx\"===e?{type:\"heic\",mime:\"image/heic-sequence\"}:r.avif||r.avis?{type:\"avif\",mime:\"image/avif\"}:r.heic||r.heix||r.hevc||r.hevx||r.heis?r.msf1?{type:\"heif\",mime:\"image/heif-sequence\"}:{type:\"heif\",mime:\"image/heif\"}:{type:\"avif\",mime:\"image/avif\"}}},{\"./common\":509}],512:[function(t,e,r){\"use strict\";var n=t(\"../common\").str2arr,i=t(\"../common\").sliceEq,a=t(\"../common\").readUInt32BE,o=t(\"../miaf_utils\"),s=t(\"../exif_utils\"),l=n(\"ftyp\");e.exports=function(t){if(i(t,4,l)){var e=o.unbox(t,0);if(e){var r=o.getMimeType(e.data);if(r){for(var n,c=e.end;;){var u=o.unbox(t,c);if(!u)break;if(c=u.end,\"mdat\"===u.boxtype)return;if(\"meta\"===u.boxtype){n=u.data;break}}if(n){var f=o.readSizeFromMeta(n);if(f){var h={width:f.width,height:f.height,type:r.type,mime:r.mime,wUnits:\"px\",hUnits:\"px\"};if(f.variants.length>1&&(h.variants=f.variants),f.orientation&&(h.orientation=f.orientation),f.exif_location&&f.exif_location.offset+f.exif_location.length<=t.length){var p=a(t,f.exif_location.offset),d=t.slice(f.exif_location.offset+p+4,f.exif_location.offset+f.exif_location.length),m=s.get_orientation(d);m>0&&(h.orientation=m)}return h}}}}}}},{\"../common\":509,\"../exif_utils\":510,\"../miaf_utils\":511}],513:[function(t,e,r){\"use strict\";var n=t(\"../common\").str2arr,i=t(\"../common\").sliceEq,a=t(\"../common\").readUInt16LE,o=n(\"BM\");e.exports=function(t){if(!(t.length<26)&&i(t,0,o))return{width:a(t,18),height:a(t,22),type:\"bmp\",mime:\"image/bmp\",wUnits:\"px\",hUnits:\"px\"}}},{\"../common\":509}],514:[function(t,e,r){\"use strict\";var n=t(\"../common\").str2arr,i=t(\"../common\").sliceEq,a=t(\"../common\").readUInt16LE,o=n(\"GIF87a\"),s=n(\"GIF89a\");e.exports=function(t){if(!(t.length<10)&&(i(t,0,o)||i(t,0,s)))return{width:a(t,6),height:a(t,8),type:\"gif\",mime:\"image/gif\",wUnits:\"px\",hUnits:\"px\"}}},{\"../common\":509}],515:[function(t,e,r){\"use strict\";var n=t(\"../common\").readUInt16LE;e.exports=function(t){var e=n(t,0),r=n(t,2),i=n(t,4);if(0===e&&1===r&&i){for(var a=[],o={width:0,height:0},s=0;s<i;s++){var l=t[6+16*s]||256,c=t[6+16*s+1]||256,u={width:l,height:c};a.push(u),(l>o.width||c>o.height)&&(o=u)}return{width:o.width,height:o.height,variants:a,type:\"ico\",mime:\"image/x-icon\",wUnits:\"px\",hUnits:\"px\"}}}},{\"../common\":509}],516:[function(t,e,r){\"use strict\";var n=t(\"../common\").readUInt16BE,i=t(\"../common\").str2arr,a=t(\"../common\").sliceEq,o=t(\"../exif_utils\"),s=i(\"Exif\\0\\0\");e.exports=function(t){if(!(t.length<2)&&255===t[0]&&216===t[1])for(var e=2;;){if(t.length-e<2)return;if(255!==t[e++])return;for(var r,i,l=t[e++];255===l;)l=t[e++];if(208<=l&&l<=217||1===l)r=0;else{if(!(192<=l&&l<=254))return;if(t.length-e<2)return;r=n(t,e)-2,e+=2}if(217===l||218===l)return;if(225===l&&r>=10&&a(t,e,s)&&(i=o.get_orientation(t.slice(e+6,e+r))),r>=5&&192<=l&&l<=207&&196!==l&&200!==l&&204!==l){if(t.length-e<r)return;var c={width:n(t,e+3),height:n(t,e+1),type:\"jpg\",mime:\"image/jpeg\",wUnits:\"px\",hUnits:\"px\"};return i>0&&(c.orientation=i),c}e+=r}}},{\"../common\":509,\"../exif_utils\":510}],517:[function(t,e,r){\"use strict\";var n=t(\"../common\").str2arr,i=t(\"../common\").sliceEq,a=t(\"../common\").readUInt32BE,o=n(\"\\x89PNG\\r\\n\\x1a\\n\"),s=n(\"IHDR\");e.exports=function(t){if(!(t.length<24)&&i(t,0,o)&&i(t,12,s))return{width:a(t,16),height:a(t,20),type:\"png\",mime:\"image/png\",wUnits:\"px\",hUnits:\"px\"}}},{\"../common\":509}],518:[function(t,e,r){\"use strict\";var n=t(\"../common\").str2arr,i=t(\"../common\").sliceEq,a=t(\"../common\").readUInt32BE,o=n(\"8BPS\\0\\x01\");e.exports=function(t){if(!(t.length<22)&&i(t,0,o))return{width:a(t,18),height:a(t,14),type:\"psd\",mime:\"image/vnd.adobe.photoshop\",wUnits:\"px\",hUnits:\"px\"}}},{\"../common\":509}],519:[function(t,e,r){\"use strict\";function n(t){return\"number\"==typeof t&&isFinite(t)&&t>0}var i=/<[-_.:a-zA-Z0-9][^>]*>/,a=/^<([-_.:a-zA-Z0-9]+:)?svg\\s/,o=/[^-]\\bwidth=\"([^%]+?)\"|[^-]\\bwidth='([^%]+?)'/,s=/\\bheight=\"([^%]+?)\"|\\bheight='([^%]+?)'/,l=/\\bview[bB]ox=\"(.+?)\"|\\bview[bB]ox='(.+?)'/,c=/in$|mm$|cm$|pt$|pc$|px$|em$|ex$/;function u(t){return c.test(t)?t.match(c)[0]:\"px\"}e.exports=function(t){if(function(t){var e,r=0,n=t.length;for(239===t[0]&&187===t[1]&&191===t[2]&&(r=3);r<n&&(32===(e=t[r])||9===e||13===e||10===e);)r++;return r!==n&&60===t[r]}(t)){for(var e=\"\",r=0;r<t.length;r++)e+=String.fromCharCode(t[r]);var c=(e.match(i)||[\"\"])[0];if(a.test(c)){var f=function(t){var e=t.match(o),r=t.match(s),n=t.match(l);return{width:e&&(e[1]||e[2]),height:r&&(r[1]||r[2]),viewbox:n&&(n[1]||n[2])}}(c),h=parseFloat(f.width),p=parseFloat(f.height);if(f.width&&f.height){if(!n(h)||!n(p))return;return{width:h,height:p,type:\"svg\",mime:\"image/svg+xml\",wUnits:u(f.width),hUnits:u(f.height)}}var d=(f.viewbox||\"\").split(\" \"),m={width:d[2],height:d[3]},g=parseFloat(m.width),v=parseFloat(m.height);if(n(g)&&n(v)&&u(m.width)===u(m.height)){var y=g/v;if(f.width){if(!n(h))return;return{width:h,height:h/y,type:\"svg\",mime:\"image/svg+xml\",wUnits:u(f.width),hUnits:u(f.width)}}if(f.height){if(!n(p))return;return{width:p*y,height:p,type:\"svg\",mime:\"image/svg+xml\",wUnits:u(f.height),hUnits:u(f.height)}}return{width:g,height:v,type:\"svg\",mime:\"image/svg+xml\",wUnits:u(m.width),hUnits:u(m.height)}}}}}},{}],520:[function(t,e,r){\"use strict\";var n=t(\"../common\").str2arr,i=t(\"../common\").sliceEq,a=t(\"../common\").readUInt16LE,o=t(\"../common\").readUInt16BE,s=t(\"../common\").readUInt32LE,l=t(\"../common\").readUInt32BE,c=n(\"II*\\0\"),u=n(\"MM\\0*\");function f(t,e,r){return r?o(t,e):a(t,e)}function h(t,e,r){return r?l(t,e):s(t,e)}function p(t,e,r){var n=f(t,e+2,r);return 1!==h(t,e+4,r)||3!==n&&4!==n?null:3===n?f(t,e+8,r):h(t,e+8,r)}e.exports=function(t){if(!(t.length<8)&&(i(t,0,c)||i(t,0,u))){var e=77===t[0],r=h(t,4,e)-8;if(!(r<0)){var n=r+8;if(!(t.length-n<2)){var a=12*f(t,n+0,e);if(!(a<=0||(n+=2,t.length-n<a))){var o,s,l,d;for(o=0;o<a;o+=12)256===(d=f(t,n+o,e))?s=p(t,n+o,e):257===d&&(l=p(t,n+o,e));return s&&l?{width:s,height:l,type:\"tiff\",mime:\"image/tiff\",wUnits:\"px\",hUnits:\"px\"}:void 0}}}}}},{\"../common\":509}],521:[function(t,e,r){\"use strict\";var n=t(\"../common\").str2arr,i=t(\"../common\").sliceEq,a=t(\"../common\").readUInt16LE,o=t(\"../common\").readUInt32LE,s=t(\"../exif_utils\"),l=n(\"RIFF\"),c=n(\"WEBP\");function u(t,e){if(157===t[e+3]&&1===t[e+4]&&42===t[e+5])return{width:16383&a(t,e+6),height:16383&a(t,e+8),type:\"webp\",mime:\"image/webp\",wUnits:\"px\",hUnits:\"px\"}}function f(t,e){if(47===t[e]){var r=o(t,e+1);return{width:1+(16383&r),height:1+(r>>14&16383),type:\"webp\",mime:\"image/webp\",wUnits:\"px\",hUnits:\"px\"}}}function h(t,e){return{width:1+(t[e+6]<<16|t[e+5]<<8|t[e+4]),height:1+(t[e+9]<<e|t[e+8]<<8|t[e+7]),type:\"webp\",mime:\"image/webp\",wUnits:\"px\",hUnits:\"px\"}}e.exports=function(t){if(!(t.length<16)&&(i(t,0,l)||i(t,8,c))){var e=12,r=null,n=0,a=o(t,4)+8;if(!(a>t.length)){for(;e+8<a;)if(0!==t[e]){var p=String.fromCharCode.apply(null,t.slice(e,e+4)),d=o(t,e+4);\"VP8 \"===p&&d>=10?r=r||u(t,e+8):\"VP8L\"===p&&d>=9?r=r||f(t,e+8):\"VP8X\"===p&&d>=10?r=r||h(t,e+8):\"EXIF\"===p&&(n=s.get_orientation(t.slice(e+8,e+8+d)),e=1/0),e+=8+d}else e++;if(r)return n>0&&(r.orientation=n),r}}}},{\"../common\":509,\"../exif_utils\":510}],522:[function(t,e,r){\"use strict\";e.exports={avif:t(\"./parse_sync/avif\"),bmp:t(\"./parse_sync/bmp\"),gif:t(\"./parse_sync/gif\"),ico:t(\"./parse_sync/ico\"),jpeg:t(\"./parse_sync/jpeg\"),png:t(\"./parse_sync/png\"),psd:t(\"./parse_sync/psd\"),svg:t(\"./parse_sync/svg\"),tiff:t(\"./parse_sync/tiff\"),webp:t(\"./parse_sync/webp\")}},{\"./parse_sync/avif\":512,\"./parse_sync/bmp\":513,\"./parse_sync/gif\":514,\"./parse_sync/ico\":515,\"./parse_sync/jpeg\":516,\"./parse_sync/png\":517,\"./parse_sync/psd\":518,\"./parse_sync/svg\":519,\"./parse_sync/tiff\":520,\"./parse_sync/webp\":521}],523:[function(t,e,r){\"use strict\";var n=t(\"./lib/parsers_sync\");e.exports=function(t){return function(t){for(var e=Object.keys(n),r=0;r<e.length;r++){var i=n[e[r]](t);if(i)return i}return null}(t)},e.exports.parsers=n},{\"./lib/parsers_sync\":522}],524:[function(t,e,r){var n,i,a=e.exports={};function o(){throw new Error(\"setTimeout has not been defined\")}function s(){throw new Error(\"clearTimeout has not been defined\")}function l(t){if(n===setTimeout)return setTimeout(t,0);if((n===o||!n)&&setTimeout)return n=setTimeout,setTimeout(t,0);try{return n(t,0)}catch(e){try{return n.call(null,t,0)}catch(e){return n.call(this,t,0)}}}!function(){try{n=\"function\"==typeof setTimeout?setTimeout:o}catch(t){n=o}try{i=\"function\"==typeof clearTimeout?clearTimeout:s}catch(t){i=s}}();var c,u=[],f=!1,h=-1;function p(){f&&c&&(f=!1,c.length?u=c.concat(u):h=-1,u.length&&d())}function d(){if(!f){var t=l(p);f=!0;for(var e=u.length;e;){for(c=u,u=[];++h<e;)c&&c[h].run();h=-1,e=u.length}c=null,f=!1,function(t){if(i===clearTimeout)return clearTimeout(t);if((i===s||!i)&&clearTimeout)return i=clearTimeout,clearTimeout(t);try{i(t)}catch(e){try{return i.call(null,t)}catch(e){return i.call(this,t)}}}(t)}}function m(t,e){this.fun=t,this.array=e}function g(){}a.nextTick=function(t){var e=new Array(arguments.length-1);if(arguments.length>1)for(var r=1;r<arguments.length;r++)e[r-1]=arguments[r];u.push(new m(t,e)),1!==u.length||f||l(d)},m.prototype.run=function(){this.fun.apply(null,this.array)},a.title=\"browser\",a.browser=!0,a.env={},a.argv=[],a.version=\"\",a.versions={},a.on=g,a.addListener=g,a.once=g,a.off=g,a.removeListener=g,a.removeAllListeners=g,a.emit=g,a.prependListener=g,a.prependOnceListener=g,a.listeners=function(t){return[]},a.binding=function(t){throw new Error(\"process.binding is not supported\")},a.cwd=function(){return\"/\"},a.chdir=function(t){throw new Error(\"process.chdir is not supported\")},a.umask=function(){return 0}},{}],525:[function(t,e,r){e.exports=t(\"gl-quat/slerp\")},{\"gl-quat/slerp\":325}],526:[function(t,e,r){(function(r){(function(){for(var n=t(\"performance-now\"),i=\"undefined\"==typeof window?r:window,a=[\"moz\",\"webkit\"],o=\"AnimationFrame\",s=i[\"request\"+o],l=i[\"cancel\"+o]||i[\"cancelRequest\"+o],c=0;!s&&c<a.length;c++)s=i[a[c]+\"Request\"+o],l=i[a[c]+\"Cancel\"+o]||i[a[c]+\"CancelRequest\"+o];if(!s||!l){var u=0,f=0,h=[];s=function(t){if(0===h.length){var e=n(),r=Math.max(0,1e3/60-(e-u));u=r+e,setTimeout((function(){var t=h.slice(0);h.length=0;for(var e=0;e<t.length;e++)if(!t[e].cancelled)try{t[e].callback(u)}catch(t){setTimeout((function(){throw t}),0)}}),Math.round(r))}return h.push({handle:++f,callback:t,cancelled:!1}),f},l=function(t){for(var e=0;e<h.length;e++)h[e].handle===t&&(h[e].cancelled=!0)}}e.exports=function(t){return s.call(i,t)},e.exports.cancel=function(){l.apply(i,arguments)},e.exports.polyfill=function(t){t||(t=i),t.requestAnimationFrame=s,t.cancelAnimationFrame=l}}).call(this)}).call(this,\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{\"performance-now\":491}],527:[function(t,e,r){\"use strict\";var n=t(\"big-rat/add\");e.exports=function(t,e){for(var r=t.length,i=new Array(r),a=0;a<r;++a)i[a]=n(t[a],e[a]);return i}},{\"big-rat/add\":87}],528:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=new Array(t.length),r=0;r<t.length;++r)e[r]=n(t[r]);return e};var n=t(\"big-rat\")},{\"big-rat\":90}],529:[function(t,e,r){\"use strict\";var n=t(\"big-rat\"),i=t(\"big-rat/mul\");e.exports=function(t,e){for(var r=n(e),a=t.length,o=new Array(a),s=0;s<a;++s)o[s]=i(t[s],r);return o}},{\"big-rat\":90,\"big-rat/mul\":99}],530:[function(t,e,r){\"use strict\";var n=t(\"big-rat/sub\");e.exports=function(t,e){for(var r=t.length,i=new Array(r),a=0;a<r;++a)i[a]=n(t[a],e[a]);return i}},{\"big-rat/sub\":101}],531:[function(t,e,r){\"use strict\";var n=t(\"compare-cell\"),i=t(\"compare-oriented-cell\"),a=t(\"cell-orientation\");e.exports=function(t){t.sort(i);for(var e=t.length,r=0,o=0;o<e;++o){var s=t[o],l=a(s);if(0!==l){if(r>0){var c=t[r-1];if(0===n(s,c)&&a(c)!==l){r-=1;continue}}t[r++]=s}}return t.length=r,t}},{\"cell-orientation\":123,\"compare-cell\":139,\"compare-oriented-cell\":140}],532:[function(t,e,r){\"use strict\";var n=t(\"array-bounds\"),i=t(\"color-normalize\"),a=t(\"update-diff\"),o=t(\"pick-by-alias\"),s=t(\"object-assign\"),l=t(\"flatten-vertex-data\"),c=t(\"to-float32\"),u=c.float32,f=c.fract32;e.exports=function(t,e){\"function\"==typeof t?(e||(e={}),e.regl=t):e=t;e.length&&(e.positions=e);if(!(t=e.regl).hasExtension(\"ANGLE_instanced_arrays\"))throw Error(\"regl-error2d: `ANGLE_instanced_arrays` extension should be enabled\");var r,c,p,d,m,g,v=t._gl,y={color:\"black\",capSize:5,lineWidth:1,opacity:1,viewport:null,range:null,offset:0,count:0,bounds:null,positions:[],errors:[]},x=[];return d=t.buffer({usage:\"dynamic\",type:\"uint8\",data:new Uint8Array(0)}),c=t.buffer({usage:\"dynamic\",type:\"float\",data:new Uint8Array(0)}),p=t.buffer({usage:\"dynamic\",type:\"float\",data:new Uint8Array(0)}),m=t.buffer({usage:\"dynamic\",type:\"float\",data:new Uint8Array(0)}),g=t.buffer({usage:\"static\",type:\"float\",data:h}),T(e),r=t({vert:\"\\n\\t\\tprecision highp float;\\n\\n\\t\\tattribute vec2 position, positionFract;\\n\\t\\tattribute vec4 error;\\n\\t\\tattribute vec4 color;\\n\\n\\t\\tattribute vec2 direction, lineOffset, capOffset;\\n\\n\\t\\tuniform vec4 viewport;\\n\\t\\tuniform float lineWidth, capSize;\\n\\t\\tuniform vec2 scale, scaleFract, translate, translateFract;\\n\\n\\t\\tvarying vec4 fragColor;\\n\\n\\t\\tvoid main() {\\n\\t\\t\\tfragColor = color / 255.;\\n\\n\\t\\t\\tvec2 pixelOffset = lineWidth * lineOffset + (capSize + lineWidth) * capOffset;\\n\\n\\t\\t\\tvec2 dxy = -step(.5, direction.xy) * error.xz + step(direction.xy, vec2(-.5)) * error.yw;\\n\\n\\t\\t\\tvec2 position = position + dxy;\\n\\n\\t\\t\\tvec2 pos = (position + translate) * scale\\n\\t\\t\\t\\t+ (positionFract + translateFract) * scale\\n\\t\\t\\t\\t+ (position + translate) * scaleFract\\n\\t\\t\\t\\t+ (positionFract + translateFract) * scaleFract;\\n\\n\\t\\t\\tpos += pixelOffset / viewport.zw;\\n\\n\\t\\t\\tgl_Position = vec4(pos * 2. - 1., 0, 1);\\n\\t\\t}\\n\\t\\t\",frag:\"\\n\\t\\tprecision highp float;\\n\\n\\t\\tvarying vec4 fragColor;\\n\\n\\t\\tuniform float opacity;\\n\\n\\t\\tvoid main() {\\n\\t\\t\\tgl_FragColor = fragColor;\\n\\t\\t\\tgl_FragColor.a *= opacity;\\n\\t\\t}\\n\\t\\t\",uniforms:{range:t.prop(\"range\"),lineWidth:t.prop(\"lineWidth\"),capSize:t.prop(\"capSize\"),opacity:t.prop(\"opacity\"),scale:t.prop(\"scale\"),translate:t.prop(\"translate\"),scaleFract:t.prop(\"scaleFract\"),translateFract:t.prop(\"translateFract\"),viewport:function(t,e){return[e.viewport.x,e.viewport.y,t.viewportWidth,t.viewportHeight]}},attributes:{color:{buffer:d,offset:function(t,e){return 4*e.offset},divisor:1},position:{buffer:c,offset:function(t,e){return 8*e.offset},divisor:1},positionFract:{buffer:p,offset:function(t,e){return 8*e.offset},divisor:1},error:{buffer:m,offset:function(t,e){return 16*e.offset},divisor:1},direction:{buffer:g,stride:24,offset:0},lineOffset:{buffer:g,stride:24,offset:8},capOffset:{buffer:g,stride:24,offset:16}},primitive:\"triangles\",blend:{enable:!0,color:[0,0,0,0],equation:{rgb:\"add\",alpha:\"add\"},func:{srcRGB:\"src alpha\",dstRGB:\"one minus src alpha\",srcAlpha:\"one minus dst alpha\",dstAlpha:\"one\"}},depth:{enable:!1},scissor:{enable:!0,box:t.prop(\"viewport\")},viewport:t.prop(\"viewport\"),stencil:!1,instances:t.prop(\"count\"),count:h.length}),s(b,{update:T,draw:_,destroy:k,regl:t,gl:v,canvas:v.canvas,groups:x}),b;function b(t){t?T(t):null===t&&k(),_()}function _(e){if(\"number\"==typeof e)return w(e);e&&!Array.isArray(e)&&(e=[e]),t._refresh(),x.forEach((function(t,r){t&&(e&&(e[r]?t.draw=!0:t.draw=!1),t.draw?w(r):t.draw=!0)}))}function w(t){\"number\"==typeof t&&(t=x[t]),null!=t&&t&&t.count&&t.color&&t.opacity&&t.positions&&t.positions.length>1&&(t.scaleRatio=[t.scale[0]*t.viewport.width,t.scale[1]*t.viewport.height],r(t),t.after&&t.after(t))}function T(t){if(t){null!=t.length?\"number\"==typeof t[0]&&(t=[{positions:t}]):Array.isArray(t)||(t=[t]);var e=0,r=0;if(b.groups=x=t.map((function(t,c){var u=x[c];return t?(\"function\"==typeof t?t={after:t}:\"number\"==typeof t[0]&&(t={positions:t}),t=o(t,{color:\"color colors fill\",capSize:\"capSize cap capsize cap-size\",lineWidth:\"lineWidth line-width width line thickness\",opacity:\"opacity alpha\",range:\"range dataBox\",viewport:\"viewport viewBox\",errors:\"errors error\",positions:\"positions position data points\"}),u||(x[c]=u={id:c,scale:null,translate:null,scaleFract:null,translateFract:null,draw:!0},t=s({},y,t)),a(u,t,[{lineWidth:function(t){return.5*+t},capSize:function(t){return.5*+t},opacity:parseFloat,errors:function(t){return t=l(t),r+=t.length,t},positions:function(t,r){return t=l(t,\"float64\"),r.count=Math.floor(t.length/2),r.bounds=n(t,2),r.offset=e,e+=r.count,t}},{color:function(t,e){var r=e.count;if(t||(t=\"transparent\"),!Array.isArray(t)||\"number\"==typeof t[0]){var n=t;t=Array(r);for(var a=0;a<r;a++)t[a]=n}if(t.length<r)throw Error(\"Not enough colors\");for(var o=new Uint8Array(4*r),s=0;s<r;s++){var l=i(t[s],\"uint8\");o.set(l,4*s)}return o},range:function(t,e,r){var n=e.bounds;return t||(t=n),e.scale=[1/(t[2]-t[0]),1/(t[3]-t[1])],e.translate=[-t[0],-t[1]],e.scaleFract=f(e.scale),e.translateFract=f(e.translate),t},viewport:function(t){var e;return Array.isArray(t)?e={x:t[0],y:t[1],width:t[2]-t[0],height:t[3]-t[1]}:t?(e={x:t.x||t.left||0,y:t.y||t.top||0},t.right?e.width=t.right-e.x:e.width=t.w||t.width||0,t.bottom?e.height=t.bottom-e.y:e.height=t.h||t.height||0):e={x:0,y:0,width:v.drawingBufferWidth,height:v.drawingBufferHeight},e}}]),u):u})),e||r){var h=x.reduce((function(t,e,r){return t+(e?e.count:0)}),0),g=new Float64Array(2*h),_=new Uint8Array(4*h),w=new Float32Array(4*h);x.forEach((function(t,e){if(t){var r=t.positions,n=t.count,i=t.offset,a=t.color,o=t.errors;n&&(_.set(a,4*i),w.set(o,4*i),g.set(r,2*i))}})),c(u(g)),p(f(g)),d(_),m(w)}}}function k(){c.destroy(),p.destroy(),d.destroy(),m.destroy(),g.destroy()}};var h=[[1,0,0,1,0,0],[1,0,0,-1,0,0],[-1,0,0,-1,0,0],[-1,0,0,-1,0,0],[-1,0,0,1,0,0],[1,0,0,1,0,0],[1,0,-1,0,0,1],[1,0,-1,0,0,-1],[1,0,1,0,0,-1],[1,0,1,0,0,-1],[1,0,1,0,0,1],[1,0,-1,0,0,1],[-1,0,-1,0,0,1],[-1,0,-1,0,0,-1],[-1,0,1,0,0,-1],[-1,0,1,0,0,-1],[-1,0,1,0,0,1],[-1,0,-1,0,0,1],[0,1,1,0,0,0],[0,1,-1,0,0,0],[0,-1,-1,0,0,0],[0,-1,-1,0,0,0],[0,1,1,0,0,0],[0,-1,1,0,0,0],[0,1,0,-1,1,0],[0,1,0,-1,-1,0],[0,1,0,1,-1,0],[0,1,0,1,1,0],[0,1,0,-1,1,0],[0,1,0,1,-1,0],[0,-1,0,-1,1,0],[0,-1,0,-1,-1,0],[0,-1,0,1,-1,0],[0,-1,0,1,1,0],[0,-1,0,-1,1,0],[0,-1,0,1,-1,0]]},{\"array-bounds\":76,\"color-normalize\":131,\"flatten-vertex-data\":248,\"object-assign\":483,\"pick-by-alias\":494,\"to-float32\":595,\"update-diff\":617}],533:[function(t,e,r){\"use strict\";var n=t(\"color-normalize\"),i=t(\"array-bounds\"),a=t(\"object-assign\"),o=t(\"glslify\"),s=t(\"pick-by-alias\"),l=t(\"flatten-vertex-data\"),c=t(\"earcut\"),u=t(\"array-normalize\"),f=t(\"to-float32\"),h=f.float32,p=f.fract32,d=t(\"es6-weak-map\"),m=t(\"parse-rect\"),g=t(\"array-find-index\");function v(t,e){if(!(this instanceof v))return new v(t,e);if(\"function\"==typeof t?(e||(e={}),e.regl=t):e=t,e.length&&(e.positions=e),!(t=e.regl).hasExtension(\"ANGLE_instanced_arrays\"))throw Error(\"regl-error2d: `ANGLE_instanced_arrays` extension should be enabled\");this.gl=t._gl,this.regl=t,this.passes=[],this.shaders=v.shaders.has(t)?v.shaders.get(t):v.shaders.set(t,v.createShaders(t)).get(t),this.update(e)}e.exports=v,v.dashMult=2,v.maxPatternLength=256,v.precisionThreshold=3e6,v.maxPoints=1e4,v.maxLines=2048,v.shaders=new d,v.createShaders=function(t){var e,r=t.buffer({usage:\"static\",type:\"float\",data:[0,1,0,0,1,1,1,0]}),n={primitive:\"triangle strip\",instances:t.prop(\"count\"),count:4,offset:0,uniforms:{miterMode:function(t,e){return\"round\"===e.join?2:1},miterLimit:t.prop(\"miterLimit\"),scale:t.prop(\"scale\"),scaleFract:t.prop(\"scaleFract\"),translateFract:t.prop(\"translateFract\"),translate:t.prop(\"translate\"),thickness:t.prop(\"thickness\"),dashPattern:t.prop(\"dashTexture\"),opacity:t.prop(\"opacity\"),pixelRatio:t.context(\"pixelRatio\"),id:t.prop(\"id\"),dashSize:t.prop(\"dashLength\"),viewport:function(t,e){return[e.viewport.x,e.viewport.y,t.viewportWidth,t.viewportHeight]},depth:t.prop(\"depth\")},blend:{enable:!0,color:[0,0,0,0],equation:{rgb:\"add\",alpha:\"add\"},func:{srcRGB:\"src alpha\",dstRGB:\"one minus src alpha\",srcAlpha:\"one minus dst alpha\",dstAlpha:\"one\"}},depth:{enable:function(t,e){return!e.overlay}},stencil:{enable:!1},scissor:{enable:!0,box:t.prop(\"viewport\")},viewport:t.prop(\"viewport\")},i=t(a({vert:o([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec2 aCoord, bCoord, aCoordFract, bCoordFract;\\nattribute vec4 color;\\nattribute float lineEnd, lineTop;\\n\\nuniform vec2 scale, scaleFract, translate, translateFract;\\nuniform float thickness, pixelRatio, id, depth;\\nuniform vec4 viewport;\\n\\nvarying vec4 fragColor;\\nvarying vec2 tangent;\\n\\nvec2 project(vec2 position, vec2 positionFract, vec2 scale, vec2 scaleFract, vec2 translate, vec2 translateFract) {\\n\\t// the order is important\\n\\treturn position * scale + translate\\n       + positionFract * scale + translateFract\\n       + position * scaleFract\\n       + positionFract * scaleFract;\\n}\\n\\nvoid main() {\\n\\tfloat lineStart = 1. - lineEnd;\\n\\tfloat lineOffset = lineTop * 2. - 1.;\\n\\n\\tvec2 diff = (bCoord + bCoordFract - aCoord - aCoordFract);\\n\\ttangent = normalize(diff * scale * viewport.zw);\\n\\tvec2 normal = vec2(-tangent.y, tangent.x);\\n\\n\\tvec2 position = project(aCoord, aCoordFract, scale, scaleFract, translate, translateFract) * lineStart\\n\\t\\t+ project(bCoord, bCoordFract, scale, scaleFract, translate, translateFract) * lineEnd\\n\\n\\t\\t+ thickness * normal * .5 * lineOffset / viewport.zw;\\n\\n\\tgl_Position = vec4(position * 2.0 - 1.0, depth, 1);\\n\\n\\tfragColor = color / 255.;\\n}\\n\"]),frag:o([\"precision highp float;\\n#define GLSLIFY 1\\n\\nuniform sampler2D dashPattern;\\n\\nuniform float dashSize, pixelRatio, thickness, opacity, id;\\n\\nvarying vec4 fragColor;\\nvarying vec2 tangent;\\n\\nvoid main() {\\n\\tfloat alpha = 1.;\\n\\n\\tfloat t = fract(dot(tangent, gl_FragCoord.xy) / dashSize) * .5 + .25;\\n\\tfloat dash = texture2D(dashPattern, vec2(t, .5)).r;\\n\\n\\tgl_FragColor = fragColor;\\n\\tgl_FragColor.a *= alpha * opacity * dash;\\n}\\n\"]),attributes:{lineEnd:{buffer:r,divisor:0,stride:8,offset:0},lineTop:{buffer:r,divisor:0,stride:8,offset:4},aCoord:{buffer:t.prop(\"positionBuffer\"),stride:8,offset:8,divisor:1},bCoord:{buffer:t.prop(\"positionBuffer\"),stride:8,offset:16,divisor:1},aCoordFract:{buffer:t.prop(\"positionFractBuffer\"),stride:8,offset:8,divisor:1},bCoordFract:{buffer:t.prop(\"positionFractBuffer\"),stride:8,offset:16,divisor:1},color:{buffer:t.prop(\"colorBuffer\"),stride:4,offset:0,divisor:1}}},n));try{e=t(a({cull:{enable:!0,face:\"back\"},vert:o([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec2 aCoord, bCoord, nextCoord, prevCoord;\\nattribute vec4 aColor, bColor;\\nattribute float lineEnd, lineTop;\\n\\nuniform vec2 scale, translate;\\nuniform float thickness, pixelRatio, id, depth;\\nuniform vec4 viewport;\\nuniform float miterLimit, miterMode;\\n\\nvarying vec4 fragColor;\\nvarying vec4 startCutoff, endCutoff;\\nvarying vec2 tangent;\\nvarying vec2 startCoord, endCoord;\\nvarying float enableStartMiter, enableEndMiter;\\n\\nconst float REVERSE_THRESHOLD = -.875;\\nconst float MIN_DIFF = 1e-6;\\n\\n// TODO: possible optimizations: avoid overcalculating all for vertices and calc just one instead\\n// TODO: precalculate dot products, normalize things beforehead etc.\\n// TODO: refactor to rectangular algorithm\\n\\nfloat distToLine(vec2 p, vec2 a, vec2 b) {\\n\\tvec2 diff = b - a;\\n\\tvec2 perp = normalize(vec2(-diff.y, diff.x));\\n\\treturn dot(p - a, perp);\\n}\\n\\nbool isNaN( float val ){\\n  return ( val < 0.0 || 0.0 < val || val == 0.0 ) ? false : true;\\n}\\n\\nvoid main() {\\n\\tvec2 aCoord = aCoord, bCoord = bCoord, prevCoord = prevCoord, nextCoord = nextCoord;\\n\\n  vec2 adjustedScale;\\n  adjustedScale.x = (abs(scale.x) < MIN_DIFF) ? MIN_DIFF : scale.x;\\n  adjustedScale.y = (abs(scale.y) < MIN_DIFF) ? MIN_DIFF : scale.y;\\n\\n  vec2 scaleRatio = adjustedScale * viewport.zw;\\n\\tvec2 normalWidth = thickness / scaleRatio;\\n\\n\\tfloat lineStart = 1. - lineEnd;\\n\\tfloat lineBot = 1. - lineTop;\\n\\n\\tfragColor = (lineStart * aColor + lineEnd * bColor) / 255.;\\n\\n\\tif (isNaN(aCoord.x) || isNaN(aCoord.y) || isNaN(bCoord.x) || isNaN(bCoord.y)) return;\\n\\n\\tif (aCoord == prevCoord) prevCoord = aCoord + normalize(bCoord - aCoord);\\n\\tif (bCoord == nextCoord) nextCoord = bCoord - normalize(bCoord - aCoord);\\n\\n\\tvec2 prevDiff = aCoord - prevCoord;\\n\\tvec2 currDiff = bCoord - aCoord;\\n\\tvec2 nextDiff = nextCoord - bCoord;\\n\\n\\tvec2 prevTangent = normalize(prevDiff * scaleRatio);\\n\\tvec2 currTangent = normalize(currDiff * scaleRatio);\\n\\tvec2 nextTangent = normalize(nextDiff * scaleRatio);\\n\\n\\tvec2 prevNormal = vec2(-prevTangent.y, prevTangent.x);\\n\\tvec2 currNormal = vec2(-currTangent.y, currTangent.x);\\n\\tvec2 nextNormal = vec2(-nextTangent.y, nextTangent.x);\\n\\n\\tvec2 startJoinDirection = normalize(prevTangent - currTangent);\\n\\tvec2 endJoinDirection = normalize(currTangent - nextTangent);\\n\\n\\t// collapsed/unidirectional segment cases\\n\\t// FIXME: there should be more elegant solution\\n\\tvec2 prevTanDiff = abs(prevTangent - currTangent);\\n\\tvec2 nextTanDiff = abs(nextTangent - currTangent);\\n\\tif (max(prevTanDiff.x, prevTanDiff.y) < MIN_DIFF) {\\n\\t\\tstartJoinDirection = currNormal;\\n\\t}\\n\\tif (max(nextTanDiff.x, nextTanDiff.y) < MIN_DIFF) {\\n\\t\\tendJoinDirection = currNormal;\\n\\t}\\n\\tif (aCoord == bCoord) {\\n\\t\\tendJoinDirection = startJoinDirection;\\n\\t\\tcurrNormal = prevNormal;\\n\\t\\tcurrTangent = prevTangent;\\n\\t}\\n\\n\\ttangent = currTangent;\\n\\n\\t//calculate join shifts relative to normals\\n\\tfloat startJoinShift = dot(currNormal, startJoinDirection);\\n\\tfloat endJoinShift = dot(currNormal, endJoinDirection);\\n\\n\\tfloat startMiterRatio = abs(1. / startJoinShift);\\n\\tfloat endMiterRatio = abs(1. / endJoinShift);\\n\\n\\tvec2 startJoin = startJoinDirection * startMiterRatio;\\n\\tvec2 endJoin = endJoinDirection * endMiterRatio;\\n\\n\\tvec2 startTopJoin, startBotJoin, endTopJoin, endBotJoin;\\n\\tstartTopJoin = sign(startJoinShift) * startJoin * .5;\\n\\tstartBotJoin = -startTopJoin;\\n\\n\\tendTopJoin = sign(endJoinShift) * endJoin * .5;\\n\\tendBotJoin = -endTopJoin;\\n\\n\\tvec2 aTopCoord = aCoord + normalWidth * startTopJoin;\\n\\tvec2 bTopCoord = bCoord + normalWidth * endTopJoin;\\n\\tvec2 aBotCoord = aCoord + normalWidth * startBotJoin;\\n\\tvec2 bBotCoord = bCoord + normalWidth * endBotJoin;\\n\\n\\t//miter anti-clipping\\n\\tfloat baClipping = distToLine(bCoord, aCoord, aBotCoord) / dot(normalize(normalWidth * endBotJoin), normalize(normalWidth.yx * vec2(-startBotJoin.y, startBotJoin.x)));\\n\\tfloat abClipping = distToLine(aCoord, bCoord, bTopCoord) / dot(normalize(normalWidth * startBotJoin), normalize(normalWidth.yx * vec2(-endBotJoin.y, endBotJoin.x)));\\n\\n\\t//prevent close to reverse direction switch\\n\\tbool prevReverse = dot(currTangent, prevTangent) <= REVERSE_THRESHOLD && abs(dot(currTangent, prevNormal)) * min(length(prevDiff), length(currDiff)) <  length(normalWidth * currNormal);\\n\\tbool nextReverse = dot(currTangent, nextTangent) <= REVERSE_THRESHOLD && abs(dot(currTangent, nextNormal)) * min(length(nextDiff), length(currDiff)) <  length(normalWidth * currNormal);\\n\\n\\tif (prevReverse) {\\n\\t\\t//make join rectangular\\n\\t\\tvec2 miterShift = normalWidth * startJoinDirection * miterLimit * .5;\\n\\t\\tfloat normalAdjust = 1. - min(miterLimit / startMiterRatio, 1.);\\n\\t\\taBotCoord = aCoord + miterShift - normalAdjust * normalWidth * currNormal * .5;\\n\\t\\taTopCoord = aCoord + miterShift + normalAdjust * normalWidth * currNormal * .5;\\n\\t}\\n\\telse if (!nextReverse && baClipping > 0. && baClipping < length(normalWidth * endBotJoin)) {\\n\\t\\t//handle miter clipping\\n\\t\\tbTopCoord -= normalWidth * endTopJoin;\\n\\t\\tbTopCoord += normalize(endTopJoin * normalWidth) * baClipping;\\n\\t}\\n\\n\\tif (nextReverse) {\\n\\t\\t//make join rectangular\\n\\t\\tvec2 miterShift = normalWidth * endJoinDirection * miterLimit * .5;\\n\\t\\tfloat normalAdjust = 1. - min(miterLimit / endMiterRatio, 1.);\\n\\t\\tbBotCoord = bCoord + miterShift - normalAdjust * normalWidth * currNormal * .5;\\n\\t\\tbTopCoord = bCoord + miterShift + normalAdjust * normalWidth * currNormal * .5;\\n\\t}\\n\\telse if (!prevReverse && abClipping > 0. && abClipping < length(normalWidth * startBotJoin)) {\\n\\t\\t//handle miter clipping\\n\\t\\taBotCoord -= normalWidth * startBotJoin;\\n\\t\\taBotCoord += normalize(startBotJoin * normalWidth) * abClipping;\\n\\t}\\n\\n\\tvec2 aTopPosition = (aTopCoord) * adjustedScale + translate;\\n\\tvec2 aBotPosition = (aBotCoord) * adjustedScale + translate;\\n\\n\\tvec2 bTopPosition = (bTopCoord) * adjustedScale + translate;\\n\\tvec2 bBotPosition = (bBotCoord) * adjustedScale + translate;\\n\\n\\t//position is normalized 0..1 coord on the screen\\n\\tvec2 position = (aTopPosition * lineTop + aBotPosition * lineBot) * lineStart + (bTopPosition * lineTop + bBotPosition * lineBot) * lineEnd;\\n\\n\\tstartCoord = aCoord * scaleRatio + translate * viewport.zw + viewport.xy;\\n\\tendCoord = bCoord * scaleRatio + translate * viewport.zw + viewport.xy;\\n\\n\\tgl_Position = vec4(position  * 2.0 - 1.0, depth, 1);\\n\\n\\tenableStartMiter = step(dot(currTangent, prevTangent), .5);\\n\\tenableEndMiter = step(dot(currTangent, nextTangent), .5);\\n\\n\\t//bevel miter cutoffs\\n\\tif (miterMode == 1.) {\\n\\t\\tif (enableStartMiter == 1.) {\\n\\t\\t\\tvec2 startMiterWidth = vec2(startJoinDirection) * thickness * miterLimit * .5;\\n\\t\\t\\tstartCutoff = vec4(aCoord, aCoord);\\n\\t\\t\\tstartCutoff.zw += vec2(-startJoinDirection.y, startJoinDirection.x) / scaleRatio;\\n\\t\\t\\tstartCutoff = startCutoff * scaleRatio.xyxy + translate.xyxy * viewport.zwzw;\\n\\t\\t\\tstartCutoff += viewport.xyxy;\\n\\t\\t\\tstartCutoff += startMiterWidth.xyxy;\\n\\t\\t}\\n\\n\\t\\tif (enableEndMiter == 1.) {\\n\\t\\t\\tvec2 endMiterWidth = vec2(endJoinDirection) * thickness * miterLimit * .5;\\n\\t\\t\\tendCutoff = vec4(bCoord, bCoord);\\n\\t\\t\\tendCutoff.zw += vec2(-endJoinDirection.y, endJoinDirection.x)  / scaleRatio;\\n\\t\\t\\tendCutoff = endCutoff * scaleRatio.xyxy + translate.xyxy * viewport.zwzw;\\n\\t\\t\\tendCutoff += viewport.xyxy;\\n\\t\\t\\tendCutoff += endMiterWidth.xyxy;\\n\\t\\t}\\n\\t}\\n\\n\\t//round miter cutoffs\\n\\telse if (miterMode == 2.) {\\n\\t\\tif (enableStartMiter == 1.) {\\n\\t\\t\\tvec2 startMiterWidth = vec2(startJoinDirection) * thickness * abs(dot(startJoinDirection, currNormal)) * .5;\\n\\t\\t\\tstartCutoff = vec4(aCoord, aCoord);\\n\\t\\t\\tstartCutoff.zw += vec2(-startJoinDirection.y, startJoinDirection.x) / scaleRatio;\\n\\t\\t\\tstartCutoff = startCutoff * scaleRatio.xyxy + translate.xyxy * viewport.zwzw;\\n\\t\\t\\tstartCutoff += viewport.xyxy;\\n\\t\\t\\tstartCutoff += startMiterWidth.xyxy;\\n\\t\\t}\\n\\n\\t\\tif (enableEndMiter == 1.) {\\n\\t\\t\\tvec2 endMiterWidth = vec2(endJoinDirection) * thickness * abs(dot(endJoinDirection, currNormal)) * .5;\\n\\t\\t\\tendCutoff = vec4(bCoord, bCoord);\\n\\t\\t\\tendCutoff.zw += vec2(-endJoinDirection.y, endJoinDirection.x)  / scaleRatio;\\n\\t\\t\\tendCutoff = endCutoff * scaleRatio.xyxy + translate.xyxy * viewport.zwzw;\\n\\t\\t\\tendCutoff += viewport.xyxy;\\n\\t\\t\\tendCutoff += endMiterWidth.xyxy;\\n\\t\\t}\\n\\t}\\n}\\n\"]),frag:o([\"precision highp float;\\n#define GLSLIFY 1\\n\\nuniform sampler2D dashPattern;\\nuniform float dashSize, pixelRatio, thickness, opacity, id, miterMode;\\n\\nvarying vec4 fragColor;\\nvarying vec2 tangent;\\nvarying vec4 startCutoff, endCutoff;\\nvarying vec2 startCoord, endCoord;\\nvarying float enableStartMiter, enableEndMiter;\\n\\nfloat distToLine(vec2 p, vec2 a, vec2 b) {\\n\\tvec2 diff = b - a;\\n\\tvec2 perp = normalize(vec2(-diff.y, diff.x));\\n\\treturn dot(p - a, perp);\\n}\\n\\nvoid main() {\\n\\tfloat alpha = 1., distToStart, distToEnd;\\n\\tfloat cutoff = thickness * .5;\\n\\n\\t//bevel miter\\n\\tif (miterMode == 1.) {\\n\\t\\tif (enableStartMiter == 1.) {\\n\\t\\t\\tdistToStart = distToLine(gl_FragCoord.xy, startCutoff.xy, startCutoff.zw);\\n\\t\\t\\tif (distToStart < -1.) {\\n\\t\\t\\t\\tdiscard;\\n\\t\\t\\t\\treturn;\\n\\t\\t\\t}\\n\\t\\t\\talpha *= min(max(distToStart + 1., 0.), 1.);\\n\\t\\t}\\n\\n\\t\\tif (enableEndMiter == 1.) {\\n\\t\\t\\tdistToEnd = distToLine(gl_FragCoord.xy, endCutoff.xy, endCutoff.zw);\\n\\t\\t\\tif (distToEnd < -1.) {\\n\\t\\t\\t\\tdiscard;\\n\\t\\t\\t\\treturn;\\n\\t\\t\\t}\\n\\t\\t\\talpha *= min(max(distToEnd + 1., 0.), 1.);\\n\\t\\t}\\n\\t}\\n\\n\\t// round miter\\n\\telse if (miterMode == 2.) {\\n\\t\\tif (enableStartMiter == 1.) {\\n\\t\\t\\tdistToStart = distToLine(gl_FragCoord.xy, startCutoff.xy, startCutoff.zw);\\n\\t\\t\\tif (distToStart < 0.) {\\n\\t\\t\\t\\tfloat radius = length(gl_FragCoord.xy - startCoord);\\n\\n\\t\\t\\t\\tif(radius > cutoff + .5) {\\n\\t\\t\\t\\t\\tdiscard;\\n\\t\\t\\t\\t\\treturn;\\n\\t\\t\\t\\t}\\n\\n\\t\\t\\t\\talpha -= smoothstep(cutoff - .5, cutoff + .5, radius);\\n\\t\\t\\t}\\n\\t\\t}\\n\\n\\t\\tif (enableEndMiter == 1.) {\\n\\t\\t\\tdistToEnd = distToLine(gl_FragCoord.xy, endCutoff.xy, endCutoff.zw);\\n\\t\\t\\tif (distToEnd < 0.) {\\n\\t\\t\\t\\tfloat radius = length(gl_FragCoord.xy - endCoord);\\n\\n\\t\\t\\t\\tif(radius > cutoff + .5) {\\n\\t\\t\\t\\t\\tdiscard;\\n\\t\\t\\t\\t\\treturn;\\n\\t\\t\\t\\t}\\n\\n\\t\\t\\t\\talpha -= smoothstep(cutoff - .5, cutoff + .5, radius);\\n\\t\\t\\t}\\n\\t\\t}\\n\\t}\\n\\n\\tfloat t = fract(dot(tangent, gl_FragCoord.xy) / dashSize) * .5 + .25;\\n\\tfloat dash = texture2D(dashPattern, vec2(t, .5)).r;\\n\\n\\tgl_FragColor = fragColor;\\n\\tgl_FragColor.a *= alpha * opacity * dash;\\n}\\n\"]),attributes:{lineEnd:{buffer:r,divisor:0,stride:8,offset:0},lineTop:{buffer:r,divisor:0,stride:8,offset:4},aColor:{buffer:t.prop(\"colorBuffer\"),stride:4,offset:0,divisor:1},bColor:{buffer:t.prop(\"colorBuffer\"),stride:4,offset:4,divisor:1},prevCoord:{buffer:t.prop(\"positionBuffer\"),stride:8,offset:0,divisor:1},aCoord:{buffer:t.prop(\"positionBuffer\"),stride:8,offset:8,divisor:1},bCoord:{buffer:t.prop(\"positionBuffer\"),stride:8,offset:16,divisor:1},nextCoord:{buffer:t.prop(\"positionBuffer\"),stride:8,offset:24,divisor:1}}},n))}catch(t){e=i}return{fill:t({primitive:\"triangle\",elements:function(t,e){return e.triangles},offset:0,vert:o([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec2 position, positionFract;\\n\\nuniform vec4 color;\\nuniform vec2 scale, scaleFract, translate, translateFract;\\nuniform float pixelRatio, id;\\nuniform vec4 viewport;\\nuniform float opacity;\\n\\nvarying vec4 fragColor;\\n\\nconst float MAX_LINES = 256.;\\n\\nvoid main() {\\n\\tfloat depth = (MAX_LINES - 4. - id) / (MAX_LINES);\\n\\n\\tvec2 position = position * scale + translate\\n       + positionFract * scale + translateFract\\n       + position * scaleFract\\n       + positionFract * scaleFract;\\n\\n\\tgl_Position = vec4(position * 2.0 - 1.0, depth, 1);\\n\\n\\tfragColor = color / 255.;\\n\\tfragColor.a *= opacity;\\n}\\n\"]),frag:o([\"precision highp float;\\n#define GLSLIFY 1\\n\\nvarying vec4 fragColor;\\n\\nvoid main() {\\n\\tgl_FragColor = fragColor;\\n}\\n\"]),uniforms:{scale:t.prop(\"scale\"),color:t.prop(\"fill\"),scaleFract:t.prop(\"scaleFract\"),translateFract:t.prop(\"translateFract\"),translate:t.prop(\"translate\"),opacity:t.prop(\"opacity\"),pixelRatio:t.context(\"pixelRatio\"),id:t.prop(\"id\"),viewport:function(t,e){return[e.viewport.x,e.viewport.y,t.viewportWidth,t.viewportHeight]}},attributes:{position:{buffer:t.prop(\"positionBuffer\"),stride:8,offset:8},positionFract:{buffer:t.prop(\"positionFractBuffer\"),stride:8,offset:8}},blend:n.blend,depth:{enable:!1},scissor:n.scissor,stencil:n.stencil,viewport:n.viewport}),rect:i,miter:e}},v.defaults={dashes:null,join:\"miter\",miterLimit:1,thickness:10,cap:\"square\",color:\"black\",opacity:1,overlay:!1,viewport:null,range:null,close:!1,fill:null},v.prototype.render=function(){for(var t,e=[],r=arguments.length;r--;)e[r]=arguments[r];e.length&&(t=this).update.apply(t,e),this.draw()},v.prototype.draw=function(){for(var t=this,e=[],r=arguments.length;r--;)e[r]=arguments[r];return(e.length?e:this.passes).forEach((function(e,r){var n;if(e&&Array.isArray(e))return(n=t).draw.apply(n,e);\"number\"==typeof e&&(e=t.passes[e]),e&&e.count>1&&e.opacity&&(t.regl._refresh(),e.fill&&e.triangles&&e.triangles.length>2&&t.shaders.fill(e),e.thickness&&(e.scale[0]*e.viewport.width>v.precisionThreshold||e.scale[1]*e.viewport.height>v.precisionThreshold||\"rect\"===e.join||!e.join&&(e.thickness<=2||e.count>=v.maxPoints)?t.shaders.rect(e):t.shaders.miter(e)))})),this},v.prototype.update=function(t){var e=this;if(t){null!=t.length?\"number\"==typeof t[0]&&(t=[{positions:t}]):Array.isArray(t)||(t=[t]);var r=this.regl,o=this.gl;if(t.forEach((function(t,f){var d=e.passes[f];if(void 0!==t)if(null!==t){if(\"number\"==typeof t[0]&&(t={positions:t}),t=s(t,{positions:\"positions points data coords\",thickness:\"thickness lineWidth lineWidths line-width linewidth width stroke-width strokewidth strokeWidth\",join:\"lineJoin linejoin join type mode\",miterLimit:\"miterlimit miterLimit\",dashes:\"dash dashes dasharray dash-array dashArray\",color:\"color colour stroke colors colours stroke-color strokeColor\",fill:\"fill fill-color fillColor\",opacity:\"alpha opacity\",overlay:\"overlay crease overlap intersect\",close:\"closed close closed-path closePath\",range:\"range dataBox\",viewport:\"viewport viewBox\",hole:\"holes hole hollow\",splitNull:\"splitNull\"}),d||(e.passes[f]=d={id:f,scale:null,scaleFract:null,translate:null,translateFract:null,count:0,hole:[],depth:0,dashLength:1,dashTexture:r.texture({channels:1,data:new Uint8Array([255]),width:1,height:1,mag:\"linear\",min:\"linear\"}),colorBuffer:r.buffer({usage:\"dynamic\",type:\"uint8\",data:new Uint8Array}),positionBuffer:r.buffer({usage:\"dynamic\",type:\"float\",data:new Uint8Array}),positionFractBuffer:r.buffer({usage:\"dynamic\",type:\"float\",data:new Uint8Array})},t=a({},v.defaults,t)),null!=t.thickness&&(d.thickness=parseFloat(t.thickness)),null!=t.opacity&&(d.opacity=parseFloat(t.opacity)),null!=t.miterLimit&&(d.miterLimit=parseFloat(t.miterLimit)),null!=t.overlay&&(d.overlay=!!t.overlay,f<v.maxLines&&(d.depth=2*(v.maxLines-1-f%v.maxLines)/v.maxLines-1)),null!=t.join&&(d.join=t.join),null!=t.hole&&(d.hole=t.hole),null!=t.fill&&(d.fill=t.fill?n(t.fill,\"uint8\"):null),null!=t.viewport&&(d.viewport=m(t.viewport)),d.viewport||(d.viewport=m([o.drawingBufferWidth,o.drawingBufferHeight])),null!=t.close&&(d.close=t.close),null===t.positions&&(t.positions=[]),t.positions){var y,x;if(t.positions.x&&t.positions.y){var b=t.positions.x,_=t.positions.y;x=d.count=Math.max(b.length,_.length),y=new Float64Array(2*x);for(var w=0;w<x;w++)y[2*w]=b[w],y[2*w+1]=_[w]}else y=l(t.positions,\"float64\"),x=d.count=Math.floor(y.length/2);var T=d.bounds=i(y,2);if(d.fill){for(var k=[],M={},A=0,S=0,E=0,L=d.count;S<L;S++){var C=y[2*S],P=y[2*S+1];isNaN(C)||isNaN(P)||null==C||null==P?(C=y[2*A],P=y[2*A+1],M[S]=A):A=S,k[E++]=C,k[E++]=P}if(t.splitNull){d.count-1 in M||(M[d.count]=d.count-1);var I=Object.keys(M).map(Number).sort((function(t,e){return t-e})),O=[],z=0,D=null!=d.hole?d.hole[0]:null;if(null!=D){var R=g(I,(function(t){return t>=D}));(I=I.slice(0,R)).push(D)}for(var F=function(t){var e=k.slice(2*z,2*I[t]).concat(D?k.slice(2*D):[]),r=(d.hole||[]).map((function(e){return e-D+(I[t]-z)})),n=c(e,r);n=n.map((function(e){return e+z+(e+z<I[t]?0:D-I[t])})),O.push.apply(O,n),z=I[t]+1},B=0;B<I.length;B++)F(B);for(var N=0,j=O.length;N<j;N++)null!=M[O[N]]&&(O[N]=M[O[N]]);d.triangles=O}else{for(var U=c(k,d.hole||[]),V=0,q=U.length;V<q;V++)null!=M[U[V]]&&(U[V]=M[U[V]]);d.triangles=U}}var H=new Float64Array(y);u(H,2,T);var G=new Float64Array(2*x+6);d.close?y[0]===y[2*x-2]&&y[1]===y[2*x-1]?(G[0]=H[2*x-4],G[1]=H[2*x-3]):(G[0]=H[2*x-2],G[1]=H[2*x-1]):(G[0]=H[0],G[1]=H[1]),G.set(H,2),d.close?y[0]===y[2*x-2]&&y[1]===y[2*x-1]?(G[2*x+2]=H[2],G[2*x+3]=H[3],d.count-=1):(G[2*x+2]=H[0],G[2*x+3]=H[1],G[2*x+4]=H[2],G[2*x+5]=H[3]):(G[2*x+2]=H[2*x-2],G[2*x+3]=H[2*x-1],G[2*x+4]=H[2*x-2],G[2*x+5]=H[2*x-1]),d.positionBuffer(h(G)),d.positionFractBuffer(p(G))}if(t.range?d.range=t.range:d.range||(d.range=d.bounds),(t.range||t.positions)&&d.count){var Y=d.bounds,W=Y[2]-Y[0],X=Y[3]-Y[1],Z=d.range[2]-d.range[0],J=d.range[3]-d.range[1];d.scale=[W/Z,X/J],d.translate=[-d.range[0]/Z+Y[0]/Z||0,-d.range[1]/J+Y[1]/J||0],d.scaleFract=p(d.scale),d.translateFract=p(d.translate)}if(t.dashes){var K,Q=0;if(!t.dashes||t.dashes.length<2)Q=1,K=new Uint8Array([255,255,255,255,255,255,255,255]);else{Q=0;for(var $=0;$<t.dashes.length;++$)Q+=t.dashes[$];K=new Uint8Array(Q*v.dashMult);for(var tt=0,et=255,rt=0;rt<2;rt++)for(var nt=0;nt<t.dashes.length;++nt){for(var it=0,at=t.dashes[nt]*v.dashMult*.5;it<at;++it)K[tt++]=et;et^=255}}d.dashLength=Q,d.dashTexture({channels:1,data:K,width:K.length,height:1,mag:\"linear\",min:\"linear\"},0,0)}if(t.color){var ot=d.count,st=t.color;st||(st=\"transparent\");var lt=new Uint8Array(4*ot+4);if(Array.isArray(st)&&\"number\"!=typeof st[0]){for(var ct=0;ct<ot;ct++){var ut=n(st[ct],\"uint8\");lt.set(ut,4*ct)}lt.set(n(st[0],\"uint8\"),4*ot)}else for(var ft=n(st,\"uint8\"),ht=0;ht<ot+1;ht++)lt.set(ft,4*ht);d.colorBuffer({usage:\"dynamic\",type:\"uint8\",data:lt})}}else e.passes[f]=null})),t.length<this.passes.length){for(var f=t.length;f<this.passes.length;f++){var d=this.passes[f];d&&(d.colorBuffer.destroy(),d.positionBuffer.destroy(),d.dashTexture.destroy())}this.passes.length=t.length}for(var y=[],x=0;x<this.passes.length;x++)null!==this.passes[x]&&y.push(this.passes[x]);return this.passes=y,this}},v.prototype.destroy=function(){return this.passes.forEach((function(t){t.colorBuffer.destroy(),t.positionBuffer.destroy(),t.dashTexture.destroy()})),this.passes.length=0,this}},{\"array-bounds\":76,\"array-find-index\":77,\"array-normalize\":78,\"color-normalize\":131,earcut:182,\"es6-weak-map\":237,\"flatten-vertex-data\":248,glslify:438,\"object-assign\":483,\"parse-rect\":488,\"pick-by-alias\":494,\"to-float32\":595}],534:[function(t,e,r){\"use strict\";function n(t,e){return function(t){if(Array.isArray(t))return t}(t)||function(t,e){if(\"undefined\"==typeof Symbol||!(Symbol.iterator in Object(t)))return;var r=[],n=!0,i=!1,a=void 0;try{for(var o,s=t[Symbol.iterator]();!(n=(o=s.next()).done)&&(r.push(o.value),!e||r.length!==e);n=!0);}catch(t){i=!0,a=t}finally{try{n||null==s.return||s.return()}finally{if(i)throw a}}return r}(t,e)||a(t,e)||function(){throw new TypeError(\"Invalid attempt to destructure non-iterable instance.\\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.\")}()}function i(t){return function(t){if(Array.isArray(t))return o(t)}(t)||function(t){if(\"undefined\"!=typeof Symbol&&Symbol.iterator in Object(t))return Array.from(t)}(t)||a(t)||function(){throw new TypeError(\"Invalid attempt to spread non-iterable instance.\\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.\")}()}function a(t,e){if(t){if(\"string\"==typeof t)return o(t,e);var r=Object.prototype.toString.call(t).slice(8,-1);return\"Object\"===r&&t.constructor&&(r=t.constructor.name),\"Map\"===r||\"Set\"===r?Array.from(t):\"Arguments\"===r||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(r)?o(t,e):void 0}}function o(t,e){(null==e||e>t.length)&&(e=t.length);for(var r=0,n=new Array(e);r<e;r++)n[r]=t[r];return n}var s=t(\"color-normalize\"),l=t(\"array-bounds\"),c=t(\"color-id\"),u=t(\"@plotly/point-cluster\"),f=t(\"object-assign\"),h=t(\"glslify\"),p=t(\"pick-by-alias\"),d=t(\"update-diff\"),m=t(\"flatten-vertex-data\"),g=t(\"is-iexplorer\"),v=t(\"to-float32\"),y=t(\"parse-rect\"),x=b;function b(t,e){var r=this;if(!(this instanceof b))return new b(t,e);\"function\"==typeof t?(e||(e={}),e.regl=t):(e=t,t=null),e&&e.length&&(e.positions=e);var n,i=(t=e.regl)._gl,a=[];this.tooManyColors=g,n=t.texture({data:new Uint8Array(1020),width:255,height:1,type:\"uint8\",format:\"rgba\",wrapS:\"clamp\",wrapT:\"clamp\",mag:\"nearest\",min:\"nearest\"}),f(this,{regl:t,gl:i,groups:[],markerCache:[null],markerTextures:[null],palette:a,paletteIds:{},paletteTexture:n,maxColors:255,maxSize:100,canvas:i.canvas}),this.update(e);var o={uniforms:{constPointSize:!!e.constPointSize,pixelRatio:t.context(\"pixelRatio\"),palette:n,paletteSize:function(t,e){return[r.tooManyColors?0:255,n.height]},scale:t.prop(\"scale\"),scaleFract:t.prop(\"scaleFract\"),translate:t.prop(\"translate\"),translateFract:t.prop(\"translateFract\"),opacity:t.prop(\"opacity\"),marker:t.prop(\"markerTexture\")},attributes:{x:function(t,e){return e.xAttr||{buffer:e.positionBuffer,stride:8,offset:0}},y:function(t,e){return e.yAttr||{buffer:e.positionBuffer,stride:8,offset:4}},xFract:function(t,e){return e.xAttr?{constant:[0,0]}:{buffer:e.positionFractBuffer,stride:8,offset:0}},yFract:function(t,e){return e.yAttr?{constant:[0,0]}:{buffer:e.positionFractBuffer,stride:8,offset:4}},size:function(t,e){return e.size.length?{buffer:e.sizeBuffer,stride:2,offset:0}:{constant:[Math.round(255*e.size/r.maxSize)]}},borderSize:function(t,e){return e.borderSize.length?{buffer:e.sizeBuffer,stride:2,offset:1}:{constant:[Math.round(255*e.borderSize/r.maxSize)]}},colorId:function(t,e){return e.color.length?{buffer:e.colorBuffer,stride:r.tooManyColors?8:4,offset:0}:{constant:r.tooManyColors?a.slice(4*e.color,4*e.color+4):[e.color]}},borderColorId:function(t,e){return e.borderColor.length?{buffer:e.colorBuffer,stride:r.tooManyColors?8:4,offset:r.tooManyColors?4:2}:{constant:r.tooManyColors?a.slice(4*e.borderColor,4*e.borderColor+4):[e.borderColor]}},isActive:function(t,e){return!0===e.activation?{constant:[1]}:e.activation?e.activation:{constant:[0]}}},blend:{enable:!0,color:[0,0,0,1],func:{srcRGB:\"src alpha\",dstRGB:\"one minus src alpha\",srcAlpha:\"one minus dst alpha\",dstAlpha:\"one\"}},scissor:{enable:!0,box:t.prop(\"viewport\")},viewport:t.prop(\"viewport\"),stencil:{enable:!1},depth:{enable:!1},elements:t.prop(\"elements\"),count:t.prop(\"count\"),offset:t.prop(\"offset\"),primitive:\"points\"},s=f({},o);s.frag=h([\"precision highp float;\\n#define GLSLIFY 1\\n\\nvarying vec4 fragColor, fragBorderColor;\\nvarying float fragWidth, fragBorderColorLevel, fragColorLevel;\\n\\nuniform sampler2D marker;\\nuniform float opacity;\\n\\nfloat smoothStep(float x, float y) {\\n  return 1.0 / (1.0 + exp(50.0*(x - y)));\\n}\\n\\nvoid main() {\\n  float dist = texture2D(marker, gl_PointCoord).r, delta = fragWidth;\\n\\n  // max-distance alpha\\n  if (dist < 0.003) discard;\\n\\n  // null-border case\\n  if (fragBorderColorLevel == fragColorLevel || fragBorderColor.a == 0.) {\\n    float colorAmt = smoothstep(.5 - delta, .5 + delta, dist);\\n    gl_FragColor = vec4(fragColor.rgb, colorAmt * fragColor.a * opacity);\\n  }\\n  else {\\n    float borderColorAmt = smoothstep(fragBorderColorLevel - delta, fragBorderColorLevel + delta, dist);\\n    float colorAmt = smoothstep(fragColorLevel - delta, fragColorLevel + delta, dist);\\n\\n    vec4 color = fragBorderColor;\\n    color.a *= borderColorAmt;\\n    color = mix(color, fragColor, colorAmt);\\n    color.a *= opacity;\\n\\n    gl_FragColor = color;\\n  }\\n\\n}\\n\"]),s.vert=h([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute float x, y, xFract, yFract;\\nattribute float size, borderSize;\\nattribute vec4 colorId, borderColorId;\\nattribute float isActive;\\n\\nuniform vec2 scale, scaleFract, translate, translateFract, paletteSize;\\nuniform float pixelRatio;\\nuniform bool constPointSize;\\nuniform sampler2D palette;\\n\\nconst float maxSize = 100.;\\nconst float borderLevel = .5;\\n\\nvarying vec4 fragColor, fragBorderColor;\\nvarying float fragPointSize, fragBorderRadius, fragWidth, fragBorderColorLevel, fragColorLevel;\\n\\nfloat pointSizeScale = (constPointSize) ? 2. : pixelRatio;\\n\\nbool isDirect = (paletteSize.x < 1.);\\n\\nvec4 getColor(vec4 id) {\\n  return isDirect ? id / 255. : texture2D(palette,\\n    vec2(\\n      (id.x + .5) / paletteSize.x,\\n      (id.y + .5) / paletteSize.y\\n    )\\n  );\\n}\\n\\nvoid main() {\\n  // ignore inactive points\\n  if (isActive == 0.) return;\\n\\n  vec2 position = vec2(x, y);\\n  vec2 positionFract = vec2(xFract, yFract);\\n\\n  vec4 color = getColor(colorId);\\n  vec4 borderColor = getColor(borderColorId);\\n\\n  float size = size * maxSize / 255.;\\n  float borderSize = borderSize * maxSize / 255.;\\n\\n  gl_PointSize = 2. * size * pointSizeScale;\\n  fragPointSize = size * pixelRatio;\\n\\n  vec2 pos = (position + translate) * scale\\n      + (positionFract + translateFract) * scale\\n      + (position + translate) * scaleFract\\n      + (positionFract + translateFract) * scaleFract;\\n\\n  gl_Position = vec4(pos * 2. - 1., 0., 1.);\\n\\n  fragColor = color;\\n  fragBorderColor = borderColor;\\n  fragWidth = 1. / gl_PointSize;\\n\\n  fragBorderColorLevel = clamp(borderLevel - borderLevel * borderSize / size, 0., 1.);\\n  fragColorLevel = clamp(borderLevel + (1. - borderLevel) * borderSize / size, 0., 1.);\\n}\"]),this.drawMarker=t(s);var l=f({},o);l.frag=h([\"precision highp float;\\n#define GLSLIFY 1\\n\\nvarying vec4 fragColor, fragBorderColor;\\n\\nuniform float opacity;\\nvarying float fragBorderRadius, fragWidth;\\n\\nfloat smoothStep(float edge0, float edge1, float x) {\\n\\tfloat t;\\n\\tt = clamp((x - edge0) / (edge1 - edge0), 0.0, 1.0);\\n\\treturn t * t * (3.0 - 2.0 * t);\\n}\\n\\nvoid main() {\\n\\tfloat radius, alpha = 1.0, delta = fragWidth;\\n\\n\\tradius = length(2.0 * gl_PointCoord.xy - 1.0);\\n\\n\\tif (radius > 1.0 + delta) {\\n\\t\\tdiscard;\\n\\t}\\n\\n\\talpha -= smoothstep(1.0 - delta, 1.0 + delta, radius);\\n\\n\\tfloat borderRadius = fragBorderRadius;\\n\\tfloat ratio = smoothstep(borderRadius - delta, borderRadius + delta, radius);\\n\\tvec4 color = mix(fragColor, fragBorderColor, ratio);\\n\\tcolor.a *= alpha * opacity;\\n\\tgl_FragColor = color;\\n}\\n\"]),l.vert=h([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute float x, y, xFract, yFract;\\nattribute float size, borderSize;\\nattribute vec4 colorId, borderColorId;\\nattribute float isActive;\\n\\nuniform vec2 scale, scaleFract, translate, translateFract;\\nuniform float pixelRatio;\\nuniform bool constPointSize;\\nuniform sampler2D palette;\\nuniform vec2 paletteSize;\\n\\nconst float maxSize = 100.;\\n\\nvarying vec4 fragColor, fragBorderColor;\\nvarying float fragBorderRadius, fragWidth;\\n\\nfloat pointSizeScale = (constPointSize) ? 2. : pixelRatio;\\n\\nbool isDirect = (paletteSize.x < 1.);\\n\\nvec4 getColor(vec4 id) {\\n  return isDirect ? id / 255. : texture2D(palette,\\n    vec2(\\n      (id.x + .5) / paletteSize.x,\\n      (id.y + .5) / paletteSize.y\\n    )\\n  );\\n}\\n\\nvoid main() {\\n  // ignore inactive points\\n  if (isActive == 0.) return;\\n\\n  vec2 position = vec2(x, y);\\n  vec2 positionFract = vec2(xFract, yFract);\\n\\n  vec4 color = getColor(colorId);\\n  vec4 borderColor = getColor(borderColorId);\\n\\n  float size = size * maxSize / 255.;\\n  float borderSize = borderSize * maxSize / 255.;\\n\\n  gl_PointSize = (size + borderSize) * pointSizeScale;\\n\\n  vec2 pos = (position + translate) * scale\\n      + (positionFract + translateFract) * scale\\n      + (position + translate) * scaleFract\\n      + (positionFract + translateFract) * scaleFract;\\n\\n  gl_Position = vec4(pos * 2. - 1., 0., 1.);\\n\\n  fragBorderRadius = 1. - 2. * borderSize / (size + borderSize);\\n  fragColor = color;\\n  fragBorderColor = borderColor.a == 0. || borderSize == 0. ? vec4(color.rgb, 0.) : borderColor;\\n  fragWidth = 1. / gl_PointSize;\\n}\\n\"]),g&&(l.frag=l.frag.replace(\"smoothstep\",\"smoothStep\"),s.frag=s.frag.replace(\"smoothstep\",\"smoothStep\")),this.drawCircle=t(l)}b.defaults={color:\"black\",borderColor:\"transparent\",borderSize:0,size:12,opacity:1,marker:void 0,viewport:null,range:null,pixelSize:null,count:0,offset:0,bounds:null,positions:[],snap:1e4},b.prototype.render=function(){return arguments.length&&this.update.apply(this,arguments),this.draw(),this},b.prototype.draw=function(){for(var t=this,e=arguments.length,r=new Array(e),n=0;n<e;n++)r[n]=arguments[n];var i=this.groups;if(1===r.length&&Array.isArray(r[0])&&(null===r[0][0]||Array.isArray(r[0][0]))&&(r=r[0]),this.regl._refresh(),r.length)for(var a=0;a<r.length;a++)this.drawItem(a,r[a]);else i.forEach((function(e,r){t.drawItem(r)}));return this},b.prototype.drawItem=function(t,e){var r=this.groups,n=r[t];if(\"number\"==typeof e&&(t=e,n=r[e],e=null),n&&n.count&&n.opacity){n.activation[0]&&this.drawCircle(this.getMarkerDrawOptions(0,n,e));for(var a=[],o=1;o<n.activation.length;o++)n.activation[o]&&(!0===n.activation[o]||n.activation[o].data.length)&&a.push.apply(a,i(this.getMarkerDrawOptions(o,n,e)));a.length&&this.drawMarker(a)}},b.prototype.getMarkerDrawOptions=function(t,e,r){var i=e.range,a=e.tree,o=e.viewport,s=e.activation,l=e.selectionBuffer,c=e.count;this.regl;if(!a)return r?[f({},e,{markerTexture:this.markerTextures[t],activation:s[t],count:r.length,elements:r,offset:0})]:[f({},e,{markerTexture:this.markerTextures[t],activation:s[t],offset:0})];var u=[],h=a.range(i,{lod:!0,px:[(i[2]-i[0])/o.width,(i[3]-i[1])/o.height]});if(r){for(var p=s[t].data,d=new Uint8Array(c),m=0;m<r.length;m++){var g=r[m];d[g]=p?p[g]:1}l.subdata(d)}for(var v=h.length;v--;){var y=n(h[v],2),x=y[0],b=y[1];u.push(f({},e,{markerTexture:this.markerTextures[t],activation:r?l:s[t],offset:x,count:b-x}))}return u},b.prototype.update=function(){for(var t=this,e=arguments.length,r=new Array(e),n=0;n<e;n++)r[n]=arguments[n];if(r.length){1===r.length&&Array.isArray(r[0])&&(r=r[0]);var i=this.groups,a=this.gl,o=this.regl,s=this.maxSize,c=this.maxColors,h=this.palette;this.groups=i=r.map((function(e,r){var n=i[r];if(void 0===e)return n;null===e?e={positions:null}:\"function\"==typeof e?e={ondraw:e}:\"number\"==typeof e[0]&&(e={positions:e}),null===(e=p(e,{positions:\"positions data points\",snap:\"snap cluster lod tree\",size:\"sizes size radius\",borderSize:\"borderSizes borderSize border-size bordersize borderWidth borderWidths border-width borderwidth stroke-width strokeWidth strokewidth outline\",color:\"colors color fill fill-color fillColor\",borderColor:\"borderColors borderColor stroke stroke-color strokeColor\",marker:\"markers marker shape\",range:\"range dataBox databox\",viewport:\"viewport viewPort viewBox viewbox\",opacity:\"opacity alpha transparency\",bounds:\"bound bounds boundaries limits\",tooManyColors:\"tooManyColors palette paletteMode optimizePalette enablePalette\"})).positions&&(e.positions=[]),null!=e.tooManyColors&&(t.tooManyColors=e.tooManyColors),n||(i[r]=n={id:r,scale:null,translate:null,scaleFract:null,translateFract:null,activation:[],selectionBuffer:o.buffer({data:new Uint8Array(0),usage:\"stream\",type:\"uint8\"}),sizeBuffer:o.buffer({data:new Uint8Array(0),usage:\"dynamic\",type:\"uint8\"}),colorBuffer:o.buffer({data:new Uint8Array(0),usage:\"dynamic\",type:\"uint8\"}),positionBuffer:o.buffer({data:new Uint8Array(0),usage:\"dynamic\",type:\"float\"}),positionFractBuffer:o.buffer({data:new Uint8Array(0),usage:\"dynamic\",type:\"float\"})},e=f({},b.defaults,e)),e.positions&&!(\"marker\"in e)&&(e.marker=n.marker,delete n.marker),e.marker&&!(\"positions\"in e)&&(e.positions=n.positions,delete n.positions);var g=0,x=0;if(d(n,e,[{snap:!0,size:function(t,e){return null==t&&(t=b.defaults.size),g+=t&&t.length?1:0,t},borderSize:function(t,e){return null==t&&(t=b.defaults.borderSize),g+=t&&t.length?1:0,t},opacity:parseFloat,color:function(e,r){return null==e&&(e=b.defaults.color),e=t.updateColor(e),x++,e},borderColor:function(e,r){return null==e&&(e=b.defaults.borderColor),e=t.updateColor(e),x++,e},bounds:function(t,e,r){return\"range\"in r||(r.range=null),t},positions:function(t,e,r){var n=e.snap,i=e.positionBuffer,a=e.positionFractBuffer,s=e.selectionBuffer;if(t.x||t.y)return t.x.length?e.xAttr={buffer:o.buffer(t.x),offset:0,stride:4,count:t.x.length}:e.xAttr={buffer:t.x.buffer,offset:4*t.x.offset||0,stride:4*(t.x.stride||1),count:t.x.count},t.y.length?e.yAttr={buffer:o.buffer(t.y),offset:0,stride:4,count:t.y.length}:e.yAttr={buffer:t.y.buffer,offset:4*t.y.offset||0,stride:4*(t.y.stride||1),count:t.y.count},e.count=Math.max(e.xAttr.count,e.yAttr.count),t;t=m(t,\"float64\");var c=e.count=Math.floor(t.length/2),f=e.bounds=c?l(t,2):null;if(r.range||e.range||(delete e.range,r.range=f),r.marker||e.marker||(delete e.marker,r.marker=null),n&&(!0===n||c>n)?e.tree=u(t,{bounds:f}):n&&n.length&&(e.tree=n),e.tree){var h={primitive:\"points\",usage:\"static\",data:e.tree,type:\"uint32\"};e.elements?e.elements(h):e.elements=o.elements(h)}return i({data:v.float(t),usage:\"dynamic\"}),a({data:v.fract(t),usage:\"dynamic\"}),s({data:new Uint8Array(c),type:\"uint8\",usage:\"stream\"}),t}},{marker:function(e,r,n){var i=r.activation;if(i.forEach((function(t){return t&&t.destroy&&t.destroy()})),i.length=0,e&&\"number\"!=typeof e[0]){for(var a=[],s=0,l=Math.min(e.length,r.count);s<l;s++){var c=t.addMarker(e[s]);a[c]||(a[c]=new Uint8Array(r.count)),a[c][s]=1}for(var u=0;u<a.length;u++)if(a[u]){var f={data:a[u],type:\"uint8\",usage:\"static\"};i[u]?i[u](f):i[u]=o.buffer(f),i[u].data=a[u]}}else{i[t.addMarker(e)]=!0}return e},range:function(t,e,r){var n=e.bounds;if(n)return t||(t=n),e.scale=[1/(t[2]-t[0]),1/(t[3]-t[1])],e.translate=[-t[0],-t[1]],e.scaleFract=v.fract(e.scale),e.translateFract=v.fract(e.translate),t},viewport:function(t){return y(t||[a.drawingBufferWidth,a.drawingBufferHeight])}}]),g){var _=n,w=_.count,T=_.size,k=_.borderSize,M=_.sizeBuffer,A=new Uint8Array(2*w);if(T.length||k.length)for(var S=0;S<w;S++)A[2*S]=Math.round(255*(null==T[S]?T:T[S])/s),A[2*S+1]=Math.round(255*(null==k[S]?k:k[S])/s);M({data:A,usage:\"dynamic\"})}if(x){var E,L=n,C=L.count,P=L.color,I=L.borderColor,O=L.colorBuffer;if(t.tooManyColors){if(P.length||I.length){E=new Uint8Array(8*C);for(var z=0;z<C;z++){var D=P[z];E[8*z]=h[4*D],E[8*z+1]=h[4*D+1],E[8*z+2]=h[4*D+2],E[8*z+3]=h[4*D+3];var R=I[z];E[8*z+4]=h[4*R],E[8*z+5]=h[4*R+1],E[8*z+6]=h[4*R+2],E[8*z+7]=h[4*R+3]}}}else if(P.length||I.length){E=new Uint8Array(4*C+2);for(var F=0;F<C;F++)null!=P[F]&&(E[4*F]=P[F]%c,E[4*F+1]=Math.floor(P[F]/c)),null!=I[F]&&(E[4*F+2]=I[F]%c,E[4*F+3]=Math.floor(I[F]/c))}O({data:E||new Uint8Array(0),type:\"uint8\",usage:\"dynamic\"})}return n}))}},b.prototype.addMarker=function(t){var e,r=this.markerTextures,n=this.regl,i=this.markerCache,a=null==t?0:i.indexOf(t);if(a>=0)return a;if(t instanceof Uint8Array||t instanceof Uint8ClampedArray)e=t;else{e=new Uint8Array(t.length);for(var o=0,s=t.length;o<s;o++)e[o]=255*t[o]}var l=Math.floor(Math.sqrt(e.length));return a=r.length,i.push(t),r.push(n.texture({channels:1,data:e,radius:l,mag:\"linear\",min:\"linear\"})),a},b.prototype.updateColor=function(t){var e=this.paletteIds,r=this.palette,n=this.maxColors;Array.isArray(t)||(t=[t]);var i=[];if(\"number\"==typeof t[0]){var a=[];if(Array.isArray(t))for(var o=0;o<t.length;o+=4)a.push(t.slice(o,o+4));else for(var l=0;l<t.length;l+=4)a.push(t.subarray(l,l+4));t=a}for(var u=0;u<t.length;u++){var f=t[u];f=s(f,\"uint8\");var h=c(f,!1);if(null==e[h]){var p=r.length;e[h]=Math.floor(p/4),r[p]=f[0],r[p+1]=f[1],r[p+2]=f[2],r[p+3]=f[3]}i[u]=e[h]}return!this.tooManyColors&&r.length>4*n&&(this.tooManyColors=!0),this.updatePalette(r),1===i.length?i[0]:i},b.prototype.updatePalette=function(t){if(!this.tooManyColors){var e=this.maxColors,r=this.paletteTexture,n=Math.ceil(.25*t.length/e);if(n>1)for(var i=.25*(t=t.slice()).length%e;i<n*e;i++)t.push(0,0,0,0);r.height<n&&r.resize(e,n),r.subimage({width:Math.min(.25*t.length,e),height:n,data:t},0,0)}},b.prototype.destroy=function(){return this.groups.forEach((function(t){t.sizeBuffer.destroy(),t.positionBuffer.destroy(),t.positionFractBuffer.destroy(),t.colorBuffer.destroy(),t.activation.forEach((function(t){return t&&t.destroy&&t.destroy()})),t.selectionBuffer.destroy(),t.elements&&t.elements.destroy()})),this.groups.length=0,this.paletteTexture.destroy(),this.markerTextures.forEach((function(t){return t&&t.destroy&&t.destroy()})),this};var _=t(\"object-assign\");e.exports=function(t,e){var r=new x(t,e),n=r.render.bind(r);return _(n,{render:n,update:r.update.bind(r),draw:r.draw.bind(r),destroy:r.destroy.bind(r),regl:r.regl,gl:r.gl,canvas:r.gl.canvas,groups:r.groups,markers:r.markerCache,palette:r.palette}),n}},{\"@plotly/point-cluster\":59,\"array-bounds\":76,\"color-id\":129,\"color-normalize\":131,\"flatten-vertex-data\":248,glslify:438,\"is-iexplorer\":450,\"object-assign\":483,\"parse-rect\":488,\"pick-by-alias\":494,\"to-float32\":595,\"update-diff\":617}],535:[function(t,e,r){\"use strict\";var n=t(\"regl-scatter2d\"),i=t(\"pick-by-alias\"),a=t(\"array-bounds\"),o=t(\"raf\"),s=t(\"array-range\"),l=t(\"parse-rect\"),c=t(\"flatten-vertex-data\");function u(t,e){if(!(this instanceof u))return new u(t,e);this.traces=[],this.passes={},this.regl=t,this.scatter=n(t),this.canvas=this.scatter.canvas}function f(t,e,r){return(null!=t.id?t.id:t)<<16|(255&e)<<8|255&r}function h(t,e,r){var n,i,a,o,s=t[e],l=t[r];return s.length>2?(s[0],s[2],n=s[1],i=s[3]):s.length?(n=s[0],i=s[1]):(s.x,n=s.y,s.x+s.width,i=s.y+s.height),l.length>2?(a=l[0],o=l[2],l[1],l[3]):l.length?(a=l[0],o=l[1]):(a=l.x,l.y,o=l.x+l.width,l.y+l.height),[a,n,o,i]}function p(t){if(\"number\"==typeof t)return[t,t,t,t];if(2===t.length)return[t[0],t[1],t[0],t[1]];var e=l(t);return[e.x,e.y,e.x+e.width,e.y+e.height]}e.exports=u,u.prototype.render=function(){for(var t,e=this,r=[],n=arguments.length;n--;)r[n]=arguments[n];return r.length&&(t=this).update.apply(t,r),this.regl.attributes.preserveDrawingBuffer?this.draw():(this.dirty?null==this.planned&&(this.planned=o((function(){e.draw(),e.dirty=!0,e.planned=null}))):(this.draw(),this.dirty=!0,o((function(){e.dirty=!1}))),this)},u.prototype.update=function(){for(var t,e=[],r=arguments.length;r--;)e[r]=arguments[r];if(e.length){for(var n=0;n<e.length;n++)this.updateItem(n,e[n]);this.traces=this.traces.filter(Boolean);for(var i=[],a=0,o=0;o<this.traces.length;o++){for(var s=this.traces[o],l=this.traces[o].passes,c=0;c<l.length;c++)i.push(this.passes[l[c]]);s.passOffset=a,a+=s.passes.length}return(t=this.scatter).update.apply(t,i),this}},u.prototype.updateItem=function(t,e){var r=this.regl;if(null===e)return this.traces[t]=null,this;if(!e)return this;var n,o=i(e,{data:\"data items columns rows values dimensions samples x\",snap:\"snap cluster\",size:\"sizes size radius\",color:\"colors color fill fill-color fillColor\",opacity:\"opacity alpha transparency opaque\",borderSize:\"borderSizes borderSize border-size bordersize borderWidth borderWidths border-width borderwidth stroke-width strokeWidth strokewidth outline\",borderColor:\"borderColors borderColor bordercolor stroke stroke-color strokeColor\",marker:\"markers marker shape\",range:\"range ranges databox dataBox\",viewport:\"viewport viewBox viewbox\",domain:\"domain domains area areas\",padding:\"pad padding paddings pads margin margins\",transpose:\"transpose transposed\",diagonal:\"diagonal diag showDiagonal\",upper:\"upper up top upperhalf upperHalf showupperhalf showUpper showUpperHalf\",lower:\"lower low bottom lowerhalf lowerHalf showlowerhalf showLowerHalf showLower\"}),s=this.traces[t]||(this.traces[t]={id:t,buffer:r.buffer({usage:\"dynamic\",type:\"float\",data:new Uint8Array}),color:\"black\",marker:null,size:12,borderColor:\"transparent\",borderSize:1,viewport:l([r._gl.drawingBufferWidth,r._gl.drawingBufferHeight]),padding:[0,0,0,0],opacity:1,diagonal:!0,upper:!0,lower:!0});if(null!=o.color&&(s.color=o.color),null!=o.size&&(s.size=o.size),null!=o.marker&&(s.marker=o.marker),null!=o.borderColor&&(s.borderColor=o.borderColor),null!=o.borderSize&&(s.borderSize=o.borderSize),null!=o.opacity&&(s.opacity=o.opacity),o.viewport&&(s.viewport=l(o.viewport)),null!=o.diagonal&&(s.diagonal=o.diagonal),null!=o.upper&&(s.upper=o.upper),null!=o.lower&&(s.lower=o.lower),o.data){s.buffer(c(o.data)),s.columns=o.data.length,s.count=o.data[0].length,s.bounds=[];for(var u=0;u<s.columns;u++)s.bounds[u]=a(o.data[u],1)}o.range&&(s.range=o.range,n=s.range&&\"number\"!=typeof s.range[0]),o.domain&&(s.domain=o.domain);var d=!1;null!=o.padding&&(Array.isArray(o.padding)&&o.padding.length===s.columns&&\"number\"==typeof o.padding[o.padding.length-1]?(s.padding=o.padding.map(p),d=!0):s.padding=p(o.padding));var m=s.columns,g=s.count,v=s.viewport.width,y=s.viewport.height,x=s.viewport.x,b=s.viewport.y,_=v/m,w=y/m;s.passes=[];for(var T=0;T<m;T++)for(var k=0;k<m;k++)if((s.diagonal||k!==T)&&(s.upper||!(T>k))&&(s.lower||!(T<k))){var M=f(s.id,T,k),A=this.passes[M]||(this.passes[M]={});if(o.data&&(o.transpose?A.positions={x:{buffer:s.buffer,offset:k,count:g,stride:m},y:{buffer:s.buffer,offset:T,count:g,stride:m}}:A.positions={x:{buffer:s.buffer,offset:k*g,count:g},y:{buffer:s.buffer,offset:T*g,count:g}},A.bounds=h(s.bounds,T,k)),o.domain||o.viewport||o.data){var S=d?h(s.padding,T,k):s.padding;if(s.domain){var E=h(s.domain,T,k),L=E[0],C=E[1],P=E[2],I=E[3];A.viewport=[x+L*v+S[0],b+C*y+S[1],x+P*v-S[2],b+I*y-S[3]]}else A.viewport=[x+k*_+_*S[0],b+T*w+w*S[1],x+(k+1)*_-_*S[2],b+(T+1)*w-w*S[3]]}o.color&&(A.color=s.color),o.size&&(A.size=s.size),o.marker&&(A.marker=s.marker),o.borderSize&&(A.borderSize=s.borderSize),o.borderColor&&(A.borderColor=s.borderColor),o.opacity&&(A.opacity=s.opacity),o.range&&(A.range=n?h(s.range,T,k):s.range||A.bounds),s.passes.push(M)}return this},u.prototype.draw=function(){for(var t,e=[],r=arguments.length;r--;)e[r]=arguments[r];if(e.length){for(var n=[],i=0;i<e.length;i++)if(\"number\"==typeof e[i]){var a=this.traces[e[i]],o=a.passes,l=a.passOffset;n.push.apply(n,s(l,l+o.length))}else if(e[i].length){var c=e[i],u=this.traces[i],f=u.passes,h=u.passOffset;f=f.map((function(t,e){n[h+e]=c}))}(t=this.scatter).draw.apply(t,n)}else this.scatter.draw();return this},u.prototype.destroy=function(){return this.traces.forEach((function(t){t.buffer&&t.buffer.destroy&&t.buffer.destroy()})),this.traces=null,this.passes=null,this.scatter.destroy(),this}},{\"array-bounds\":76,\"array-range\":79,\"flatten-vertex-data\":248,\"parse-rect\":488,\"pick-by-alias\":494,raf:526,\"regl-scatter2d\":534}],536:[function(t,e,r){!function(t,n){\"object\"==typeof r&&void 0!==e?e.exports=n():t.createREGL=n()}(this,(function(){function t(t,e){this.id=V++,this.type=t,this.data=e}function e(t){return\"[\"+function t(e){if(0===e.length)return[];var r=e.charAt(0),n=e.charAt(e.length-1);if(1<e.length&&r===n&&('\"'===r||\"'\"===r))return['\"'+e.substr(1,e.length-2).replace(/\\\\/g,\"\\\\\\\\\").replace(/\"/g,'\\\\\"')+'\"'];if(r=/\\[(false|true|null|\\d+|'[^']*'|\"[^\"]*\")\\]/.exec(e))return t(e.substr(0,r.index)).concat(t(r[1])).concat(t(e.substr(r.index+r[0].length)));if(1===(r=e.split(\".\")).length)return['\"'+e.replace(/\\\\/g,\"\\\\\\\\\").replace(/\"/g,'\\\\\"')+'\"'];for(e=[],n=0;n<r.length;++n)e=e.concat(t(r[n]));return e}(t).join(\"][\")+\"]\"}function r(t){return\"string\"==typeof t?t.split():t}function n(t){return\"string\"==typeof t?document.querySelector(t):t}function i(t){var e,i,a,o,s=t||{};t={};var l=[],c=[],u=\"undefined\"==typeof window?1:window.devicePixelRatio,f=!1,h=function(t){},p=function(){};if(\"string\"==typeof s?e=document.querySelector(s):\"object\"==typeof s&&(\"string\"==typeof s.nodeName&&\"function\"==typeof s.appendChild&&\"function\"==typeof s.getBoundingClientRect?e=s:\"function\"==typeof s.drawArrays||\"function\"==typeof s.drawElements?a=(o=s).canvas:(\"gl\"in s?o=s.gl:\"canvas\"in s?a=n(s.canvas):\"container\"in s&&(i=n(s.container)),\"attributes\"in s&&(t=s.attributes),\"extensions\"in s&&(l=r(s.extensions)),\"optionalExtensions\"in s&&(c=r(s.optionalExtensions)),\"onDone\"in s&&(h=s.onDone),\"profile\"in s&&(f=!!s.profile),\"pixelRatio\"in s&&(u=+s.pixelRatio))),e&&(\"canvas\"===e.nodeName.toLowerCase()?a=e:i=e),!o){if(!a){if(!(e=function(t,e,r){function n(){var e=window.innerWidth,n=window.innerHeight;t!==document.body&&(e=(n=t.getBoundingClientRect()).right-n.left,n=n.bottom-n.top),a.width=r*e,a.height=r*n,U(a.style,{width:e+\"px\",height:n+\"px\"})}var i,a=document.createElement(\"canvas\");return U(a.style,{border:0,margin:0,padding:0,top:0,left:0}),t.appendChild(a),t===document.body&&(a.style.position=\"absolute\",U(t.style,{margin:0,padding:0})),t!==document.body&&\"function\"==typeof ResizeObserver?(i=new ResizeObserver((function(){setTimeout(n)}))).observe(t):window.addEventListener(\"resize\",n,!1),n(),{canvas:a,onDestroy:function(){i?i.disconnect():window.removeEventListener(\"resize\",n),t.removeChild(a)}}}(i||document.body,0,u)))return null;a=e.canvas,p=e.onDestroy}void 0===t.premultipliedAlpha&&(t.premultipliedAlpha=!0),o=function(t,e){function r(r){try{return t.getContext(r,e)}catch(t){return null}}return r(\"webgl\")||r(\"experimental-webgl\")||r(\"webgl-experimental\")}(a,t)}return o?{gl:o,canvas:a,container:i,extensions:l,optionalExtensions:c,pixelRatio:u,profile:f,onDone:h,onDestroy:p}:(p(),h(\"webgl not supported, try upgrading your browser or graphics drivers http://get.webgl.org\"),null)}function a(t,e){for(var r=Array(t),n=0;n<t;++n)r[n]=e(n);return r}function o(t){var e,r;return e=(65535<t)<<4,e|=r=(255<(t>>>=e))<<3,(e|=r=(15<(t>>>=r))<<2)|(r=(3<(t>>>=r))<<1)|t>>>r>>1}function s(){function t(t){t:{for(var e=16;268435456>=e;e*=16)if(t<=e){t=e;break t}t=0}return 0<(e=r[o(t)>>2]).length?e.pop():new ArrayBuffer(t)}function e(t){r[o(t.byteLength)>>2].push(t)}var r=a(8,(function(){return[]}));return{alloc:t,free:e,allocType:function(e,r){var n=null;switch(e){case 5120:n=new Int8Array(t(r),0,r);break;case 5121:n=new Uint8Array(t(r),0,r);break;case 5122:n=new Int16Array(t(2*r),0,r);break;case 5123:n=new Uint16Array(t(2*r),0,r);break;case 5124:n=new Int32Array(t(4*r),0,r);break;case 5125:n=new Uint32Array(t(4*r),0,r);break;case 5126:n=new Float32Array(t(4*r),0,r);break;default:return null}return n.length!==r?n.subarray(0,r):n},freeType:function(t){e(t.buffer)}}}function l(t){return!!t&&\"object\"==typeof t&&Array.isArray(t.shape)&&Array.isArray(t.stride)&&\"number\"==typeof t.offset&&t.shape.length===t.stride.length&&(Array.isArray(t.data)||X(t.data))}function c(t,e,r,n,i,a){for(var o=0;o<e;++o)for(var s=t[o],l=0;l<r;++l)for(var c=s[l],u=0;u<n;++u)i[a++]=c[u]}function u(t){return 0|K[Object.prototype.toString.call(t)]}function f(t,e){for(var r=0;r<e.length;++r)t[r]=e[r]}function h(t,e,r,n,i,a,o){for(var s=0,l=0;l<r;++l)for(var c=0;c<n;++c)t[s++]=e[i*l+a*c+o]}function p(t,e,r,n){function i(e){this.id=c++,this.buffer=t.createBuffer(),this.type=e,this.usage=35044,this.byteLength=0,this.dimension=1,this.dtype=5121,this.persistentData=null,r.profile&&(this.stats={size:0})}function a(e,r,n){e.byteLength=r.byteLength,t.bufferData(e.type,r,n)}function o(t,e,r,n,i,o){if(t.usage=r,Array.isArray(e)){if(t.dtype=n||5126,0<e.length)if(Array.isArray(e[0])){i=et(e);for(var s=n=1;s<i.length;++s)n*=i[s];t.dimension=n,a(t,e=tt(e,i,t.dtype),r),o?t.persistentData=e:Y.freeType(e)}else\"number\"==typeof e[0]?(t.dimension=i,f(i=Y.allocType(t.dtype,e.length),e),a(t,i,r),o?t.persistentData=i:Y.freeType(i)):X(e[0])&&(t.dimension=e[0].length,t.dtype=n||u(e[0])||5126,a(t,e=tt(e,[e.length,e[0].length],t.dtype),r),o?t.persistentData=e:Y.freeType(e))}else if(X(e))t.dtype=n||u(e),t.dimension=i,a(t,e,r),o&&(t.persistentData=new Uint8Array(new Uint8Array(e.buffer)));else if(l(e)){i=e.shape;var c=e.stride,p=(s=e.offset,0),d=0,m=0,g=0;1===i.length?(p=i[0],d=1,m=c[0],g=0):2===i.length&&(p=i[0],d=i[1],m=c[0],g=c[1]),t.dtype=n||u(e.data)||5126,t.dimension=d,h(i=Y.allocType(t.dtype,p*d),e.data,p,d,m,g,s),a(t,i,r),o?t.persistentData=i:Y.freeType(i)}else e instanceof ArrayBuffer&&(t.dtype=5121,t.dimension=i,a(t,e,r),o&&(t.persistentData=new Uint8Array(new Uint8Array(e))))}function s(r){e.bufferCount--,n(r),t.deleteBuffer(r.buffer),r.buffer=null,delete p[r.id]}var c=0,p={};i.prototype.bind=function(){t.bindBuffer(this.type,this.buffer)},i.prototype.destroy=function(){s(this)};var d=[];return r.profile&&(e.getTotalBufferSize=function(){var t=0;return Object.keys(p).forEach((function(e){t+=p[e].stats.size})),t}),{create:function(n,a,c,d){function m(e){var n=35044,i=null,a=0,s=0,c=1;return Array.isArray(e)||X(e)||l(e)||e instanceof ArrayBuffer?i=e:\"number\"==typeof e?a=0|e:e&&(\"data\"in e&&(i=e.data),\"usage\"in e&&(n=$[e.usage]),\"type\"in e&&(s=Q[e.type]),\"dimension\"in e&&(c=0|e.dimension),\"length\"in e&&(a=0|e.length)),g.bind(),i?o(g,i,n,s,c,d):(a&&t.bufferData(g.type,a,n),g.dtype=s||5121,g.usage=n,g.dimension=c,g.byteLength=a),r.profile&&(g.stats.size=g.byteLength*rt[g.dtype]),m}e.bufferCount++;var g=new i(a);return p[g.id]=g,c||m(n),m._reglType=\"buffer\",m._buffer=g,m.subdata=function(e,r){var n,i=0|(r||0);if(g.bind(),X(e)||e instanceof ArrayBuffer)t.bufferSubData(g.type,i,e);else if(Array.isArray(e)){if(0<e.length)if(\"number\"==typeof e[0]){var a=Y.allocType(g.dtype,e.length);f(a,e),t.bufferSubData(g.type,i,a),Y.freeType(a)}else(Array.isArray(e[0])||X(e[0]))&&(n=et(e),a=tt(e,n,g.dtype),t.bufferSubData(g.type,i,a),Y.freeType(a))}else if(l(e)){n=e.shape;var o=e.stride,s=a=0,c=0,p=0;1===n.length?(a=n[0],s=1,c=o[0],p=0):2===n.length&&(a=n[0],s=n[1],c=o[0],p=o[1]),n=Array.isArray(e.data)?g.dtype:u(e.data),h(n=Y.allocType(n,a*s),e.data,a,s,c,p,e.offset),t.bufferSubData(g.type,i,n),Y.freeType(n)}return m},r.profile&&(m.stats=g.stats),m.destroy=function(){s(g)},m},createStream:function(t,e){var r=d.pop();return r||(r=new i(t)),r.bind(),o(r,e,35040,0,1,!1),r},destroyStream:function(t){d.push(t)},clear:function(){Z(p).forEach(s),d.forEach(s)},getBuffer:function(t){return t&&t._buffer instanceof i?t._buffer:null},restore:function(){Z(p).forEach((function(e){e.buffer=t.createBuffer(),t.bindBuffer(e.type,e.buffer),t.bufferData(e.type,e.persistentData||e.byteLength,e.usage)}))},_initBuffer:o}}function d(t,e,r,n){function i(t){this.id=c++,s[this.id]=this,this.buffer=t,this.primType=4,this.type=this.vertCount=0}function a(n,i,a,o,s,c,u){var f;if(n.buffer.bind(),i?((f=u)||X(i)&&(!l(i)||X(i.data))||(f=e.oes_element_index_uint?5125:5123),r._initBuffer(n.buffer,i,a,f,3)):(t.bufferData(34963,c,a),n.buffer.dtype=f||5121,n.buffer.usage=a,n.buffer.dimension=3,n.buffer.byteLength=c),f=u,!u){switch(n.buffer.dtype){case 5121:case 5120:f=5121;break;case 5123:case 5122:f=5123;break;case 5125:case 5124:f=5125}n.buffer.dtype=f}n.type=f,0>(i=s)&&(i=n.buffer.byteLength,5123===f?i>>=1:5125===f&&(i>>=2)),n.vertCount=i,i=o,0>o&&(i=4,1===(o=n.buffer.dimension)&&(i=0),2===o&&(i=1),3===o&&(i=4)),n.primType=i}function o(t){n.elementsCount--,delete s[t.id],t.buffer.destroy(),t.buffer=null}var s={},c=0,u={uint8:5121,uint16:5123};e.oes_element_index_uint&&(u.uint32=5125),i.prototype.bind=function(){this.buffer.bind()};var f=[];return{create:function(t,e){function s(t){if(t)if(\"number\"==typeof t)c(t),f.primType=4,f.vertCount=0|t,f.type=5121;else{var e=null,r=35044,n=-1,i=-1,o=0,h=0;Array.isArray(t)||X(t)||l(t)?e=t:(\"data\"in t&&(e=t.data),\"usage\"in t&&(r=$[t.usage]),\"primitive\"in t&&(n=nt[t.primitive]),\"count\"in t&&(i=0|t.count),\"type\"in t&&(h=u[t.type]),\"length\"in t?o=0|t.length:(o=i,5123===h||5122===h?o*=2:5125!==h&&5124!==h||(o*=4))),a(f,e,r,n,i,o,h)}else c(),f.primType=4,f.vertCount=0,f.type=5121;return s}var c=r.create(null,34963,!0),f=new i(c._buffer);return n.elementsCount++,s(t),s._reglType=\"elements\",s._elements=f,s.subdata=function(t,e){return c.subdata(t,e),s},s.destroy=function(){o(f)},s},createStream:function(t){var e=f.pop();return e||(e=new i(r.create(null,34963,!0,!1)._buffer)),a(e,t,35040,-1,-1,0,0),e},destroyStream:function(t){f.push(t)},getElements:function(t){return\"function\"==typeof t&&t._elements instanceof i?t._elements:null},clear:function(){Z(s).forEach(o)}}}function m(t){for(var e=Y.allocType(5123,t.length),r=0;r<t.length;++r)if(isNaN(t[r]))e[r]=65535;else if(1/0===t[r])e[r]=31744;else if(-1/0===t[r])e[r]=64512;else{it[0]=t[r];var n=(a=at[0])>>>31<<15,i=(a<<1>>>24)-127,a=a>>13&1023;e[r]=-24>i?n:-14>i?n+(a+1024>>-14-i):15<i?n+31744:n+(i+15<<10)+a}return e}function g(t){return Array.isArray(t)||X(t)}function v(t){return\"[object \"+t+\"]\"}function y(t){return Array.isArray(t)&&(0===t.length||\"number\"==typeof t[0])}function x(t){return!(!Array.isArray(t)||0===t.length||!g(t[0]))}function b(t){return Object.prototype.toString.call(t)}function _(t){if(!t)return!1;var e=b(t);return 0<=mt.indexOf(e)||(y(t)||x(t)||l(t))}function w(t,e){36193===t.type?(t.data=m(e),Y.freeType(e)):t.data=e}function T(t,e,r,n,i,a){if(t=void 0!==vt[t]?vt[t]:lt[t]*gt[e],a&&(t*=6),i){for(n=0;1<=r;)n+=t*r*r,r/=2;return n}return t*r*n}function k(t,e,r,n,i,a,o){function s(){this.format=this.internalformat=6408,this.type=5121,this.flipY=this.premultiplyAlpha=this.compressed=!1,this.unpackAlignment=1,this.colorSpace=37444,this.channels=this.height=this.width=0}function c(t,e){t.internalformat=e.internalformat,t.format=e.format,t.type=e.type,t.compressed=e.compressed,t.premultiplyAlpha=e.premultiplyAlpha,t.flipY=e.flipY,t.unpackAlignment=e.unpackAlignment,t.colorSpace=e.colorSpace,t.width=e.width,t.height=e.height,t.channels=e.channels}function u(t,e){if(\"object\"==typeof e&&e){\"premultiplyAlpha\"in e&&(t.premultiplyAlpha=e.premultiplyAlpha),\"flipY\"in e&&(t.flipY=e.flipY),\"alignment\"in e&&(t.unpackAlignment=e.alignment),\"colorSpace\"in e&&(t.colorSpace=q[e.colorSpace]),\"type\"in e&&(t.type=H[e.type]);var r=t.width,n=t.height,i=t.channels,a=!1;\"shape\"in e?(r=e.shape[0],n=e.shape[1],3===e.shape.length&&(i=e.shape[2],a=!0)):(\"radius\"in e&&(r=n=e.radius),\"width\"in e&&(r=e.width),\"height\"in e&&(n=e.height),\"channels\"in e&&(i=e.channels,a=!0)),t.width=0|r,t.height=0|n,t.channels=0|i,r=!1,\"format\"in e&&(r=e.format,n=t.internalformat=G[r],t.format=at[n],r in H&&!(\"type\"in e)&&(t.type=H[r]),r in W&&(t.compressed=!0),r=!0),!a&&r?t.channels=lt[t.format]:a&&!r&&t.channels!==st[t.format]&&(t.format=t.internalformat=st[t.channels])}}function f(e){t.pixelStorei(37440,e.flipY),t.pixelStorei(37441,e.premultiplyAlpha),t.pixelStorei(37443,e.colorSpace),t.pixelStorei(3317,e.unpackAlignment)}function h(){s.call(this),this.yOffset=this.xOffset=0,this.data=null,this.needsFree=!1,this.element=null,this.needsCopy=!1}function p(t,e){var r=null;if(_(e)?r=e:e&&(u(t,e),\"x\"in e&&(t.xOffset=0|e.x),\"y\"in e&&(t.yOffset=0|e.y),_(e.data)&&(r=e.data)),e.copy){var n=i.viewportWidth,a=i.viewportHeight;t.width=t.width||n-t.xOffset,t.height=t.height||a-t.yOffset,t.needsCopy=!0}else if(r){if(X(r))t.channels=t.channels||4,t.data=r,\"type\"in e||5121!==t.type||(t.type=0|K[Object.prototype.toString.call(r)]);else if(y(r)){switch(t.channels=t.channels||4,a=(n=r).length,t.type){case 5121:case 5123:case 5125:case 5126:(a=Y.allocType(t.type,a)).set(n),t.data=a;break;case 36193:t.data=m(n)}t.alignment=1,t.needsFree=!0}else if(l(r)){n=r.data,Array.isArray(n)||5121!==t.type||(t.type=0|K[Object.prototype.toString.call(n)]);a=r.shape;var o,s,c,f,h=r.stride;3===a.length?(c=a[2],f=h[2]):f=c=1,o=a[0],s=a[1],a=h[0],h=h[1],t.alignment=1,t.width=o,t.height=s,t.channels=c,t.format=t.internalformat=st[c],t.needsFree=!0,o=f,r=r.offset,c=t.width,f=t.height,s=t.channels;for(var p=Y.allocType(36193===t.type?5126:t.type,c*f*s),d=0,v=0;v<f;++v)for(var T=0;T<c;++T)for(var k=0;k<s;++k)p[d++]=n[a*T+h*v+o*k+r];w(t,p)}else if(b(r)===ct||b(r)===ut||b(r)===ft)b(r)===ct||b(r)===ut?t.element=r:t.element=r.canvas,t.width=t.element.width,t.height=t.element.height,t.channels=4;else if(b(r)===ht)t.element=r,t.width=r.width,t.height=r.height,t.channels=4;else if(b(r)===pt)t.element=r,t.width=r.naturalWidth,t.height=r.naturalHeight,t.channels=4;else if(b(r)===dt)t.element=r,t.width=r.videoWidth,t.height=r.videoHeight,t.channels=4;else if(x(r)){for(n=t.width||r[0].length,a=t.height||r.length,h=t.channels,h=g(r[0][0])?h||r[0][0].length:h||1,o=J.shape(r),c=1,f=0;f<o.length;++f)c*=o[f];c=Y.allocType(36193===t.type?5126:t.type,c),J.flatten(r,o,\"\",c),w(t,c),t.alignment=1,t.width=n,t.height=a,t.channels=h,t.format=t.internalformat=st[h],t.needsFree=!0}}else t.width=t.width||1,t.height=t.height||1,t.channels=t.channels||4}function d(e,r,i,a,o){var s=e.element,l=e.data,c=e.internalformat,u=e.format,h=e.type,p=e.width,d=e.height;f(e),s?t.texSubImage2D(r,o,i,a,u,h,s):e.compressed?t.compressedTexSubImage2D(r,o,i,a,c,p,d,l):e.needsCopy?(n(),t.copyTexSubImage2D(r,o,i,a,e.xOffset,e.yOffset,p,d)):t.texSubImage2D(r,o,i,a,p,d,u,h,l)}function v(){return mt.pop()||new h}function k(t){t.needsFree&&Y.freeType(t.data),h.call(t),mt.push(t)}function M(){s.call(this),this.genMipmaps=!1,this.mipmapHint=4352,this.mipmask=0,this.images=Array(16)}function A(t,e,r){var n=t.images[0]=v();t.mipmask=1,n.width=t.width=e,n.height=t.height=r,n.channels=t.channels=4}function S(t,e){var r=null;if(_(e))c(r=t.images[0]=v(),t),p(r,e),t.mipmask=1;else if(u(t,e),Array.isArray(e.mipmap))for(var n=e.mipmap,i=0;i<n.length;++i)c(r=t.images[i]=v(),t),r.width>>=i,r.height>>=i,p(r,n[i]),t.mipmask|=1<<i;else c(r=t.images[0]=v(),t),p(r,e),t.mipmask=1;c(t,t.images[0])}function E(e,r){for(var i=e.images,a=0;a<i.length&&i[a];++a){var o=i[a],s=r,l=a,c=o.element,u=o.data,h=o.internalformat,p=o.format,d=o.type,m=o.width,g=o.height;f(o),c?t.texImage2D(s,l,p,p,d,c):o.compressed?t.compressedTexImage2D(s,l,h,m,g,0,u):o.needsCopy?(n(),t.copyTexImage2D(s,l,p,o.xOffset,o.yOffset,m,g,0)):t.texImage2D(s,l,p,m,g,0,p,d,u||null)}}function L(){var t=gt.pop()||new M;s.call(t);for(var e=t.mipmask=0;16>e;++e)t.images[e]=null;return t}function C(t){for(var e=t.images,r=0;r<e.length;++r)e[r]&&k(e[r]),e[r]=null;gt.push(t)}function P(){this.magFilter=this.minFilter=9728,this.wrapT=this.wrapS=33071,this.anisotropic=1,this.genMipmaps=!1,this.mipmapHint=4352}function I(t,e){\"min\"in e&&(t.minFilter=V[e.min],0<=ot.indexOf(t.minFilter)&&!(\"faces\"in e)&&(t.genMipmaps=!0)),\"mag\"in e&&(t.magFilter=j[e.mag]);var r=t.wrapS,n=t.wrapT;if(\"wrap\"in e){var i=e.wrap;\"string\"==typeof i?r=n=N[i]:Array.isArray(i)&&(r=N[i[0]],n=N[i[1]])}else\"wrapS\"in e&&(r=N[e.wrapS]),\"wrapT\"in e&&(n=N[e.wrapT]);if(t.wrapS=r,t.wrapT=n,\"anisotropic\"in e&&(t.anisotropic=e.anisotropic),\"mipmap\"in e){switch(r=!1,typeof e.mipmap){case\"string\":t.mipmapHint=B[e.mipmap],r=t.genMipmaps=!0;break;case\"boolean\":r=t.genMipmaps=e.mipmap;break;case\"object\":t.genMipmaps=!1,r=!0}!r||\"min\"in e||(t.minFilter=9984)}}function O(r,n){t.texParameteri(n,10241,r.minFilter),t.texParameteri(n,10240,r.magFilter),t.texParameteri(n,10242,r.wrapS),t.texParameteri(n,10243,r.wrapT),e.ext_texture_filter_anisotropic&&t.texParameteri(n,34046,r.anisotropic),r.genMipmaps&&(t.hint(33170,r.mipmapHint),t.generateMipmap(n))}function z(e){s.call(this),this.mipmask=0,this.internalformat=6408,this.id=vt++,this.refCount=1,this.target=e,this.texture=t.createTexture(),this.unit=-1,this.bindCount=0,this.texInfo=new P,o.profile&&(this.stats={size:0})}function D(e){t.activeTexture(33984),t.bindTexture(e.target,e.texture)}function R(){var e=bt[0];e?t.bindTexture(e.target,e.texture):t.bindTexture(3553,null)}function F(e){var r=e.texture,n=e.unit,i=e.target;0<=n&&(t.activeTexture(33984+n),t.bindTexture(i,null),bt[n]=null),t.deleteTexture(r),e.texture=null,e.params=null,e.pixels=null,e.refCount=0,delete yt[e.id],a.textureCount--}var B={\"don't care\":4352,\"dont care\":4352,nice:4354,fast:4353},N={repeat:10497,clamp:33071,mirror:33648},j={nearest:9728,linear:9729},V=U({mipmap:9987,\"nearest mipmap nearest\":9984,\"linear mipmap nearest\":9985,\"nearest mipmap linear\":9986,\"linear mipmap linear\":9987},j),q={none:0,browser:37444},H={uint8:5121,rgba4:32819,rgb565:33635,\"rgb5 a1\":32820},G={alpha:6406,luminance:6409,\"luminance alpha\":6410,rgb:6407,rgba:6408,rgba4:32854,\"rgb5 a1\":32855,rgb565:36194},W={};e.ext_srgb&&(G.srgb=35904,G.srgba=35906),e.oes_texture_float&&(H.float32=H.float=5126),e.oes_texture_half_float&&(H.float16=H[\"half float\"]=36193),e.webgl_depth_texture&&(U(G,{depth:6402,\"depth stencil\":34041}),U(H,{uint16:5123,uint32:5125,\"depth stencil\":34042})),e.webgl_compressed_texture_s3tc&&U(W,{\"rgb s3tc dxt1\":33776,\"rgba s3tc dxt1\":33777,\"rgba s3tc dxt3\":33778,\"rgba s3tc dxt5\":33779}),e.webgl_compressed_texture_atc&&U(W,{\"rgb atc\":35986,\"rgba atc explicit alpha\":35987,\"rgba atc interpolated alpha\":34798}),e.webgl_compressed_texture_pvrtc&&U(W,{\"rgb pvrtc 4bppv1\":35840,\"rgb pvrtc 2bppv1\":35841,\"rgba pvrtc 4bppv1\":35842,\"rgba pvrtc 2bppv1\":35843}),e.webgl_compressed_texture_etc1&&(W[\"rgb etc1\"]=36196);var Q=Array.prototype.slice.call(t.getParameter(34467));Object.keys(W).forEach((function(t){var e=W[t];0<=Q.indexOf(e)&&(G[t]=e)}));var $=Object.keys(G);r.textureFormats=$;var tt=[];Object.keys(G).forEach((function(t){tt[G[t]]=t}));var et=[];Object.keys(H).forEach((function(t){et[H[t]]=t}));var rt=[];Object.keys(j).forEach((function(t){rt[j[t]]=t}));var nt=[];Object.keys(V).forEach((function(t){nt[V[t]]=t}));var it=[];Object.keys(N).forEach((function(t){it[N[t]]=t}));var at=$.reduce((function(t,r){var n=G[r];return 6409===n||6406===n||6409===n||6410===n||6402===n||34041===n||e.ext_srgb&&(35904===n||35906===n)?t[n]=n:32855===n||0<=r.indexOf(\"rgba\")?t[n]=6408:t[n]=6407,t}),{}),mt=[],gt=[],vt=0,yt={},xt=r.maxTextureUnits,bt=Array(xt).map((function(){return null}));return U(z.prototype,{bind:function(){this.bindCount+=1;var e=this.unit;if(0>e){for(var r=0;r<xt;++r){var n=bt[r];if(n){if(0<n.bindCount)continue;n.unit=-1}bt[r]=this,e=r;break}o.profile&&a.maxTextureUnits<e+1&&(a.maxTextureUnits=e+1),this.unit=e,t.activeTexture(33984+e),t.bindTexture(this.target,this.texture)}return e},unbind:function(){--this.bindCount},decRef:function(){0>=--this.refCount&&F(this)}}),o.profile&&(a.getTotalTextureSize=function(){var t=0;return Object.keys(yt).forEach((function(e){t+=yt[e].stats.size})),t}),{create2D:function(e,r){function n(t,e){var r=i.texInfo;P.call(r);var a=L();return\"number\"==typeof t?A(a,0|t,\"number\"==typeof e?0|e:0|t):t?(I(r,t),S(a,t)):A(a,1,1),r.genMipmaps&&(a.mipmask=(a.width<<1)-1),i.mipmask=a.mipmask,c(i,a),i.internalformat=a.internalformat,n.width=a.width,n.height=a.height,D(i),E(a,3553),O(r,3553),R(),C(a),o.profile&&(i.stats.size=T(i.internalformat,i.type,a.width,a.height,r.genMipmaps,!1)),n.format=tt[i.internalformat],n.type=et[i.type],n.mag=rt[r.magFilter],n.min=nt[r.minFilter],n.wrapS=it[r.wrapS],n.wrapT=it[r.wrapT],n}var i=new z(3553);return yt[i.id]=i,a.textureCount++,n(e,r),n.subimage=function(t,e,r,a){e|=0,r|=0,a|=0;var o=v();return c(o,i),o.width=0,o.height=0,p(o,t),o.width=o.width||(i.width>>a)-e,o.height=o.height||(i.height>>a)-r,D(i),d(o,3553,e,r,a),R(),k(o),n},n.resize=function(e,r){var a=0|e,s=0|r||a;if(a===i.width&&s===i.height)return n;n.width=i.width=a,n.height=i.height=s,D(i);for(var l=0;i.mipmask>>l;++l){var c=a>>l,u=s>>l;if(!c||!u)break;t.texImage2D(3553,l,i.format,c,u,0,i.format,i.type,null)}return R(),o.profile&&(i.stats.size=T(i.internalformat,i.type,a,s,!1,!1)),n},n._reglType=\"texture2d\",n._texture=i,o.profile&&(n.stats=i.stats),n.destroy=function(){i.decRef()},n},createCube:function(e,r,n,i,s,l){function f(t,e,r,n,i,a){var s,l=h.texInfo;for(P.call(l),s=0;6>s;++s)m[s]=L();if(\"number\"!=typeof t&&t){if(\"object\"==typeof t)if(e)S(m[0],t),S(m[1],e),S(m[2],r),S(m[3],n),S(m[4],i),S(m[5],a);else if(I(l,t),u(h,t),\"faces\"in t)for(t=t.faces,s=0;6>s;++s)c(m[s],h),S(m[s],t[s]);else for(s=0;6>s;++s)S(m[s],t)}else for(t=0|t||1,s=0;6>s;++s)A(m[s],t,t);for(c(h,m[0]),h.mipmask=l.genMipmaps?(m[0].width<<1)-1:m[0].mipmask,h.internalformat=m[0].internalformat,f.width=m[0].width,f.height=m[0].height,D(h),s=0;6>s;++s)E(m[s],34069+s);for(O(l,34067),R(),o.profile&&(h.stats.size=T(h.internalformat,h.type,f.width,f.height,l.genMipmaps,!0)),f.format=tt[h.internalformat],f.type=et[h.type],f.mag=rt[l.magFilter],f.min=nt[l.minFilter],f.wrapS=it[l.wrapS],f.wrapT=it[l.wrapT],s=0;6>s;++s)C(m[s]);return f}var h=new z(34067);yt[h.id]=h,a.cubeCount++;var m=Array(6);return f(e,r,n,i,s,l),f.subimage=function(t,e,r,n,i){r|=0,n|=0,i|=0;var a=v();return c(a,h),a.width=0,a.height=0,p(a,e),a.width=a.width||(h.width>>i)-r,a.height=a.height||(h.height>>i)-n,D(h),d(a,34069+t,r,n,i),R(),k(a),f},f.resize=function(e){if((e|=0)!==h.width){f.width=h.width=e,f.height=h.height=e,D(h);for(var r=0;6>r;++r)for(var n=0;h.mipmask>>n;++n)t.texImage2D(34069+r,n,h.format,e>>n,e>>n,0,h.format,h.type,null);return R(),o.profile&&(h.stats.size=T(h.internalformat,h.type,f.width,f.height,!1,!0)),f}},f._reglType=\"textureCube\",f._texture=h,o.profile&&(f.stats=h.stats),f.destroy=function(){h.decRef()},f},clear:function(){for(var e=0;e<xt;++e)t.activeTexture(33984+e),t.bindTexture(3553,null),bt[e]=null;Z(yt).forEach(F),a.cubeCount=0,a.textureCount=0},getTexture:function(t){return null},restore:function(){for(var e=0;e<xt;++e){var r=bt[e];r&&(r.bindCount=0,r.unit=-1,bt[e]=null)}Z(yt).forEach((function(e){e.texture=t.createTexture(),t.bindTexture(e.target,e.texture);for(var r=0;32>r;++r)if(0!=(e.mipmask&1<<r))if(3553===e.target)t.texImage2D(3553,r,e.internalformat,e.width>>r,e.height>>r,0,e.internalformat,e.type,null);else for(var n=0;6>n;++n)t.texImage2D(34069+n,r,e.internalformat,e.width>>r,e.height>>r,0,e.internalformat,e.type,null);O(e.texInfo,e.target)}))}}}function M(t,e,r,n,i,a){function o(t,e,r){this.target=t,this.texture=e,this.renderbuffer=r;var n=t=0;e?(t=e.width,n=e.height):r&&(t=r.width,n=r.height),this.width=t,this.height=n}function s(t){t&&(t.texture&&t.texture._texture.decRef(),t.renderbuffer&&t.renderbuffer._renderbuffer.decRef())}function l(t,e,r){t&&(t.texture?t.texture._texture.refCount+=1:t.renderbuffer._renderbuffer.refCount+=1)}function c(e,r){r&&(r.texture?t.framebufferTexture2D(36160,e,r.target,r.texture._texture.texture,0):t.framebufferRenderbuffer(36160,e,36161,r.renderbuffer._renderbuffer.renderbuffer))}function u(t){var e=3553,r=null,n=null,i=t;return\"object\"==typeof t&&(i=t.data,\"target\"in t&&(e=0|t.target)),\"texture2d\"===(t=i._reglType)||\"textureCube\"===t?r=i:\"renderbuffer\"===t&&(n=i,e=36161),new o(e,r,n)}function f(t,e,r,a,s){return r?((t=n.create2D({width:t,height:e,format:a,type:s}))._texture.refCount=0,new o(3553,t,null)):((t=i.create({width:t,height:e,format:a}))._renderbuffer.refCount=0,new o(36161,null,t))}function h(t){return t&&(t.texture||t.renderbuffer)}function p(t,e,r){t&&(t.texture?t.texture.resize(e,r):t.renderbuffer&&t.renderbuffer.resize(e,r),t.width=e,t.height=r)}function d(){this.id=T++,k[this.id]=this,this.framebuffer=t.createFramebuffer(),this.height=this.width=0,this.colorAttachments=[],this.depthStencilAttachment=this.stencilAttachment=this.depthAttachment=null}function m(t){t.colorAttachments.forEach(s),s(t.depthAttachment),s(t.stencilAttachment),s(t.depthStencilAttachment)}function g(e){t.deleteFramebuffer(e.framebuffer),e.framebuffer=null,a.framebufferCount--,delete k[e.id]}function v(e){var n;t.bindFramebuffer(36160,e.framebuffer);var i=e.colorAttachments;for(n=0;n<i.length;++n)c(36064+n,i[n]);for(n=i.length;n<r.maxColorAttachments;++n)t.framebufferTexture2D(36160,36064+n,3553,null,0);t.framebufferTexture2D(36160,33306,3553,null,0),t.framebufferTexture2D(36160,36096,3553,null,0),t.framebufferTexture2D(36160,36128,3553,null,0),c(36096,e.depthAttachment),c(36128,e.stencilAttachment),c(33306,e.depthStencilAttachment),t.checkFramebufferStatus(36160),t.isContextLost(),t.bindFramebuffer(36160,x.next?x.next.framebuffer:null),x.cur=x.next,t.getError()}function y(t,e){function r(t,e){var i,a=0,o=0,s=!0,c=!0;i=null;var p=!0,d=\"rgba\",g=\"uint8\",y=1,x=null,w=null,T=null,k=!1;\"number\"==typeof t?(a=0|t,o=0|e||a):t?(\"shape\"in t?(a=(o=t.shape)[0],o=o[1]):(\"radius\"in t&&(a=o=t.radius),\"width\"in t&&(a=t.width),\"height\"in t&&(o=t.height)),(\"color\"in t||\"colors\"in t)&&(i=t.color||t.colors,Array.isArray(i)),i||(\"colorCount\"in t&&(y=0|t.colorCount),\"colorTexture\"in t&&(p=!!t.colorTexture,d=\"rgba4\"),\"colorType\"in t&&(g=t.colorType,!p)&&(\"half float\"===g||\"float16\"===g?d=\"rgba16f\":\"float\"!==g&&\"float32\"!==g||(d=\"rgba32f\")),\"colorFormat\"in t&&(d=t.colorFormat,0<=b.indexOf(d)?p=!0:0<=_.indexOf(d)&&(p=!1))),(\"depthTexture\"in t||\"depthStencilTexture\"in t)&&(k=!(!t.depthTexture&&!t.depthStencilTexture)),\"depth\"in t&&(\"boolean\"==typeof t.depth?s=t.depth:(x=t.depth,c=!1)),\"stencil\"in t&&(\"boolean\"==typeof t.stencil?c=t.stencil:(w=t.stencil,s=!1)),\"depthStencil\"in t&&(\"boolean\"==typeof t.depthStencil?s=c=t.depthStencil:(T=t.depthStencil,c=s=!1))):a=o=1;var M=null,A=null,S=null,E=null;if(Array.isArray(i))M=i.map(u);else if(i)M=[u(i)];else for(M=Array(y),i=0;i<y;++i)M[i]=f(a,o,p,d,g);for(a=a||M[0].width,o=o||M[0].height,x?A=u(x):s&&!c&&(A=f(a,o,k,\"depth\",\"uint32\")),w?S=u(w):c&&!s&&(S=f(a,o,!1,\"stencil\",\"uint8\")),T?E=u(T):!x&&!w&&c&&s&&(E=f(a,o,k,\"depth stencil\",\"depth stencil\")),s=null,i=0;i<M.length;++i)l(M[i]),M[i]&&M[i].texture&&(c=bt[M[i].texture._texture.format]*_t[M[i].texture._texture.type],null===s&&(s=c));return l(A),l(S),l(E),m(n),n.width=a,n.height=o,n.colorAttachments=M,n.depthAttachment=A,n.stencilAttachment=S,n.depthStencilAttachment=E,r.color=M.map(h),r.depth=h(A),r.stencil=h(S),r.depthStencil=h(E),r.width=n.width,r.height=n.height,v(n),r}var n=new d;return a.framebufferCount++,r(t,e),U(r,{resize:function(t,e){var i=Math.max(0|t,1),a=Math.max(0|e||i,1);if(i===n.width&&a===n.height)return r;for(var o=n.colorAttachments,s=0;s<o.length;++s)p(o[s],i,a);return p(n.depthAttachment,i,a),p(n.stencilAttachment,i,a),p(n.depthStencilAttachment,i,a),n.width=r.width=i,n.height=r.height=a,v(n),r},_reglType:\"framebuffer\",_framebuffer:n,destroy:function(){g(n),m(n)},use:function(t){x.setFBO({framebuffer:r},t)}})}var x={cur:null,next:null,dirty:!1,setFBO:null},b=[\"rgba\"],_=[\"rgba4\",\"rgb565\",\"rgb5 a1\"];e.ext_srgb&&_.push(\"srgba\"),e.ext_color_buffer_half_float&&_.push(\"rgba16f\",\"rgb16f\"),e.webgl_color_buffer_float&&_.push(\"rgba32f\");var w=[\"uint8\"];e.oes_texture_half_float&&w.push(\"half float\",\"float16\"),e.oes_texture_float&&w.push(\"float\",\"float32\");var T=0,k={};return U(x,{getFramebuffer:function(t){return\"function\"==typeof t&&\"framebuffer\"===t._reglType&&(t=t._framebuffer)instanceof d?t:null},create:y,createCube:function(t){function e(t){var i,a={color:null},o=0,s=null;i=\"rgba\";var l=\"uint8\",c=1;if(\"number\"==typeof t?o=0|t:t?(\"shape\"in t?o=t.shape[0]:(\"radius\"in t&&(o=0|t.radius),\"width\"in t?o=0|t.width:\"height\"in t&&(o=0|t.height)),(\"color\"in t||\"colors\"in t)&&(s=t.color||t.colors,Array.isArray(s)),s||(\"colorCount\"in t&&(c=0|t.colorCount),\"colorType\"in t&&(l=t.colorType),\"colorFormat\"in t&&(i=t.colorFormat)),\"depth\"in t&&(a.depth=t.depth),\"stencil\"in t&&(a.stencil=t.stencil),\"depthStencil\"in t&&(a.depthStencil=t.depthStencil)):o=1,s)if(Array.isArray(s))for(t=[],i=0;i<s.length;++i)t[i]=s[i];else t=[s];else for(t=Array(c),s={radius:o,format:i,type:l},i=0;i<c;++i)t[i]=n.createCube(s);for(a.color=Array(t.length),i=0;i<t.length;++i)c=t[i],o=o||c.width,a.color[i]={target:34069,data:t[i]};for(i=0;6>i;++i){for(c=0;c<t.length;++c)a.color[c].target=34069+i;0<i&&(a.depth=r[0].depth,a.stencil=r[0].stencil,a.depthStencil=r[0].depthStencil),r[i]?r[i](a):r[i]=y(a)}return U(e,{width:o,height:o,color:t})}var r=Array(6);return e(t),U(e,{faces:r,resize:function(t){var n=0|t;if(n===e.width)return e;var i=e.color;for(t=0;t<i.length;++t)i[t].resize(n);for(t=0;6>t;++t)r[t].resize(n);return e.width=e.height=n,e},_reglType:\"framebufferCube\",destroy:function(){r.forEach((function(t){t.destroy()}))}})},clear:function(){Z(k).forEach(g)},restore:function(){x.cur=null,x.next=null,x.dirty=!0,Z(k).forEach((function(e){e.framebuffer=t.createFramebuffer(),v(e)}))}})}function A(){this.w=this.z=this.y=this.x=this.state=0,this.buffer=null,this.size=0,this.normalized=!1,this.type=5126,this.divisor=this.stride=this.offset=0}function S(t,e,r,n,i){function a(){this.id=++c,this.attributes=[];var t=e.oes_vertex_array_object;this.vao=t?t.createVertexArrayOES():null,u[this.id]=this,this.buffers=[]}var o=r.maxAttributes,s=Array(o);for(r=0;r<o;++r)s[r]=new A;var c=0,u={},f={Record:A,scope:{},state:s,currentVAO:null,targetVAO:null,restore:e.oes_vertex_array_object?function(){e.oes_vertex_array_object&&Z(u).forEach((function(t){t.refresh()}))}:function(){},createVAO:function(t){function e(t){for(var n=0;n<r.buffers.length;++n)r.buffers[n].destroy();r.buffers.length=0,(n=r.attributes).length=t.length;for(var a=0;a<t.length;++a){var o=t[a],s=n[a]=new A;Array.isArray(o)||X(o)||l(o)?(o=i.create(o,34962,!1,!0),s.buffer=i.getBuffer(o),s.size=0|s.buffer.dimension,s.normalized=!1,s.type=s.buffer.dtype,s.offset=0,s.stride=0,s.divisor=0,s.state=1,r.buffers.push(o)):i.getBuffer(o)?(s.buffer=i.getBuffer(o),s.size=0|s.buffer.dimension,s.normalized=!1,s.type=s.buffer.dtype,s.offset=0,s.stride=0,s.divisor=0,s.state=1):i.getBuffer(o.buffer)?(s.buffer=i.getBuffer(o.buffer),s.size=0|(+o.size||s.buffer.dimension),s.normalized=!!o.normalized||!1,s.type=\"type\"in o?Q[o.type]:s.buffer.dtype,s.offset=0|(o.offset||0),s.stride=0|(o.stride||0),s.divisor=0|(o.divisor||0),s.state=1):\"x\"in o&&(s.x=+o.x||0,s.y=+o.y||0,s.z=+o.z||0,s.w=+o.w||0,s.state=2)}return r.refresh(),e}var r=new a;return n.vaoCount+=1,e.destroy=function(){r.destroy()},e._vao=r,e._reglType=\"vao\",e(t)},getVAO:function(t){return\"function\"==typeof t&&t._vao?t._vao:null},destroyBuffer:function(e){for(var r=0;r<s.length;++r){var n=s[r];n.buffer===e&&(t.disableVertexAttribArray(r),n.buffer=null)}},setVAO:e.oes_vertex_array_object?function(t){if(t!==f.currentVAO){var r=e.oes_vertex_array_object;t?r.bindVertexArrayOES(t.vao):r.bindVertexArrayOES(null),f.currentVAO=t}}:function(r){if(r!==f.currentVAO){if(r)r.bindAttrs();else for(var n=e.angle_instanced_arrays,i=0;i<s.length;++i){var a=s[i];a.buffer?(t.enableVertexAttribArray(i),t.vertexAttribPointer(i,a.size,a.type,a.normalized,a.stride,a.offfset),n&&n.vertexAttribDivisorANGLE(i,a.divisor)):(t.disableVertexAttribArray(i),t.vertexAttrib4f(i,a.x,a.y,a.z,a.w))}f.currentVAO=r}},clear:e.oes_vertex_array_object?function(){Z(u).forEach((function(t){t.destroy()}))}:function(){}};return a.prototype.bindAttrs=function(){for(var r=e.angle_instanced_arrays,n=this.attributes,i=0;i<n.length;++i){var a=n[i];a.buffer?(t.enableVertexAttribArray(i),t.bindBuffer(34962,a.buffer.buffer),t.vertexAttribPointer(i,a.size,a.type,a.normalized,a.stride,a.offset),r&&r.vertexAttribDivisorANGLE(i,a.divisor)):(t.disableVertexAttribArray(i),t.vertexAttrib4f(i,a.x,a.y,a.z,a.w))}for(r=n.length;r<o;++r)t.disableVertexAttribArray(r)},a.prototype.refresh=function(){var t=e.oes_vertex_array_object;t&&(t.bindVertexArrayOES(this.vao),this.bindAttrs(),f.currentVAO=this)},a.prototype.destroy=function(){if(this.vao){var t=e.oes_vertex_array_object;this===f.currentVAO&&(f.currentVAO=null,t.bindVertexArrayOES(null)),t.deleteVertexArrayOES(this.vao),this.vao=null}u[this.id]&&(delete u[this.id],--n.vaoCount)},f}function E(t,e,r,n){function i(t,e,r,n){this.name=t,this.id=e,this.location=r,this.info=n}function a(t,e){for(var r=0;r<t.length;++r)if(t[r].id===e.id)return void(t[r].location=e.location);t.push(e)}function o(r,n,i){if(!(o=(i=35632===r?c:u)[n])){var a=e.str(n),o=t.createShader(r);t.shaderSource(o,a),t.compileShader(o),i[n]=o}return o}function s(t,e){this.id=p++,this.fragId=t,this.vertId=e,this.program=null,this.uniforms=[],this.attributes=[],n.profile&&(this.stats={uniformsCount:0,attributesCount:0})}function l(r,s,l){var c;c=o(35632,r.fragId);var u=o(35633,r.vertId);if(s=r.program=t.createProgram(),t.attachShader(s,c),t.attachShader(s,u),l)for(c=0;c<l.length;++c)u=l[c],t.bindAttribLocation(s,u[0],u[1]);t.linkProgram(s),u=t.getProgramParameter(s,35718),n.profile&&(r.stats.uniformsCount=u);var f=r.uniforms;for(c=0;c<u;++c)if(l=t.getActiveUniform(s,c))if(1<l.size)for(var h=0;h<l.size;++h){var p=l.name.replace(\"[0]\",\"[\"+h+\"]\");a(f,new i(p,e.id(p),t.getUniformLocation(s,p),l))}else a(f,new i(l.name,e.id(l.name),t.getUniformLocation(s,l.name),l));for(u=t.getProgramParameter(s,35721),n.profile&&(r.stats.attributesCount=u),r=r.attributes,c=0;c<u;++c)(l=t.getActiveAttrib(s,c))&&a(r,new i(l.name,e.id(l.name),t.getAttribLocation(s,l.name),l))}var c={},u={},f={},h=[],p=0;return n.profile&&(r.getMaxUniformsCount=function(){var t=0;return h.forEach((function(e){e.stats.uniformsCount>t&&(t=e.stats.uniformsCount)})),t},r.getMaxAttributesCount=function(){var t=0;return h.forEach((function(e){e.stats.attributesCount>t&&(t=e.stats.attributesCount)})),t}),{clear:function(){var e=t.deleteShader.bind(t);Z(c).forEach(e),c={},Z(u).forEach(e),u={},h.forEach((function(e){t.deleteProgram(e.program)})),h.length=0,f={},r.shaderCount=0},program:function(t,e,n,i){var a=f[e];a||(a=f[e]={});var o=a[t];return o&&!i?o:(e=new s(e,t),r.shaderCount++,l(e,n,i),o||(a[t]=e),h.push(e),e)},restore:function(){c={},u={};for(var t=0;t<h.length;++t)l(h[t],null,h[t].attributes.map((function(t){return[t.location,t.name]})))},shader:o,frag:-1,vert:-1}}function L(t,e,r,n,i,a,o){function s(i){var a;a=null===e.next?5121:e.next.colorAttachments[0].texture._texture.type;var o=0,s=0,l=n.framebufferWidth,c=n.framebufferHeight,u=null;return X(i)?u=i:i&&(o=0|i.x,s=0|i.y,l=0|(i.width||n.framebufferWidth-o),c=0|(i.height||n.framebufferHeight-s),u=i.data||null),r(),i=l*c*4,u||(5121===a?u=new Uint8Array(i):5126===a&&(u=u||new Float32Array(i))),t.pixelStorei(3333,4),t.readPixels(o,s,l,c,6408,a,u),u}return function(t){return t&&\"framebuffer\"in t?function(t){var r;return e.setFBO({framebuffer:t.framebuffer},(function(){r=s(t)})),r}(t):s(t)}}function C(t){return Array.prototype.slice.call(t)}function P(t){return C(t).join(\"\")}function I(){function t(){var t=[],e=[];return U((function(){t.push.apply(t,C(arguments))}),{def:function(){var n=\"v\"+r++;return e.push(n),0<arguments.length&&(t.push(n,\"=\"),t.push.apply(t,C(arguments)),t.push(\";\")),n},toString:function(){return P([0<e.length?\"var \"+e.join(\",\")+\";\":\"\",P(t)])}})}function e(){function e(t,e){n(t,e,\"=\",r.def(t,e),\";\")}var r=t(),n=t(),i=r.toString,a=n.toString;return U((function(){r.apply(r,C(arguments))}),{def:r.def,entry:r,exit:n,save:e,set:function(t,n,i){e(t,n),r(t,n,\"=\",i,\";\")},toString:function(){return i()+a()}})}var r=0,n=[],i=[],a=t(),o={};return{global:a,link:function(t){for(var e=0;e<i.length;++e)if(i[e]===t)return n[e];return e=\"g\"+r++,n.push(e),i.push(t),e},block:t,proc:function(t,r){function n(){var t=\"a\"+i.length;return i.push(t),t}var i=[];r=r||0;for(var a=0;a<r;++a)n();var s=(a=e()).toString;return o[t]=U(a,{arg:n,toString:function(){return P([\"function(\",i.join(),\"){\",s(),\"}\"])}})},scope:e,cond:function(){var t=P(arguments),r=e(),n=e(),i=r.toString,a=n.toString;return U(r,{then:function(){return r.apply(r,C(arguments)),this},else:function(){return n.apply(n,C(arguments)),this},toString:function(){var e=a();return e&&(e=\"else{\"+e+\"}\"),P([\"if(\",t,\"){\",i(),\"}\",e])}})},compile:function(){var t=['\"use strict\";',a,\"return {\"];Object.keys(o).forEach((function(e){t.push('\"',e,'\":',o[e].toString(),\",\")})),t.push(\"}\");var e=P(t).replace(/;/g,\";\\n\").replace(/}/g,\"}\\n\").replace(/{/g,\"{\\n\");return Function.apply(null,n.concat(e)).apply(null,i)}}}function O(t){return Array.isArray(t)||X(t)||l(t)}function z(t){return t.sort((function(t,e){return\"viewport\"===t?-1:\"viewport\"===e?1:t<e?-1:1}))}function D(t,e,r,n){this.thisDep=t,this.contextDep=e,this.propDep=r,this.append=n}function R(t){return t&&!(t.thisDep||t.contextDep||t.propDep)}function F(t){return new D(!1,!1,!1,t)}function B(t,e){var r=t.type;return 0===r?new D(!0,1<=(r=t.data.length),2<=r,e):4===r?new D((r=t.data).thisDep,r.contextDep,r.propDep,e):new D(3===r,2===r,1===r,e)}function N(t,e,r,n,i,o,s,l,c,u,f,h,p,d,m){function v(t){return t.replace(\".\",\"_\")}function y(t,e,r){var n=v(t);rt.push(t),et[n]=tt[n]=!!r,it[n]=e}function x(t,e,r){var n=v(t);rt.push(t),Array.isArray(r)?(tt[n]=r.slice(),et[n]=r.slice()):tt[n]=et[n]=r,at[n]=e}function b(){var t=I(),r=t.link,n=t.global;t.id=lt++,t.batchId=\"0\";var i=r(ot),a=t.shared={props:\"a0\"};Object.keys(ot).forEach((function(t){a[t]=n.def(i,\".\",t)}));var o=t.next={},s=t.current={};Object.keys(at).forEach((function(t){Array.isArray(tt[t])&&(o[t]=n.def(a.next,\".\",t),s[t]=n.def(a.current,\".\",t))}));var l=t.constants={};Object.keys(st).forEach((function(t){l[t]=n.def(JSON.stringify(st[t]))})),t.invoke=function(e,n){switch(n.type){case 0:var i=[\"this\",a.context,a.props,t.batchId];return e.def(r(n.data),\".call(\",i.slice(0,Math.max(n.data.length+1,4)),\")\");case 1:return e.def(a.props,n.data);case 2:return e.def(a.context,n.data);case 3:return e.def(\"this\",n.data);case 4:return n.data.append(t,e),n.data.ref}},t.attribCache={};var c={};return t.scopeAttrib=function(t){if((t=e.id(t))in c)return c[t];var n=u.scope[t];return n||(n=u.scope[t]=new Z),c[t]=r(n)},t}function _(t,e){var r=t.static,n=t.dynamic;if(\"framebuffer\"in r){var i=r.framebuffer;return i?(i=l.getFramebuffer(i),F((function(t,e){var r=t.link(i),n=t.shared;return e.set(n.framebuffer,\".next\",r),n=n.context,e.set(n,\".framebufferWidth\",r+\".width\"),e.set(n,\".framebufferHeight\",r+\".height\"),r}))):F((function(t,e){var r=t.shared;return e.set(r.framebuffer,\".next\",\"null\"),r=r.context,e.set(r,\".framebufferWidth\",r+\".drawingBufferWidth\"),e.set(r,\".framebufferHeight\",r+\".drawingBufferHeight\"),\"null\"}))}if(\"framebuffer\"in n){var a=n.framebuffer;return B(a,(function(t,e){var r=t.invoke(e,a),n=t.shared,i=n.framebuffer;r=e.def(i,\".getFramebuffer(\",r,\")\");return e.set(i,\".next\",r),n=n.context,e.set(n,\".framebufferWidth\",r+\"?\"+r+\".width:\"+n+\".drawingBufferWidth\"),e.set(n,\".framebufferHeight\",r+\"?\"+r+\".height:\"+n+\".drawingBufferHeight\"),r}))}return null}function w(t,r,n){function i(t){if(t in a){var r=e.id(a[t]);return(t=F((function(){return r}))).id=r,t}if(t in o){var n=o[t];return B(n,(function(t,e){var r=t.invoke(e,n);return e.def(t.shared.strings,\".id(\",r,\")\")}))}return null}var a=t.static,o=t.dynamic,s=i(\"frag\"),l=i(\"vert\"),c=null;return R(s)&&R(l)?(c=f.program(l.id,s.id,null,n),t=F((function(t,e){return t.link(c)}))):t=new D(s&&s.thisDep||l&&l.thisDep,s&&s.contextDep||l&&l.contextDep,s&&s.propDep||l&&l.propDep,(function(t,e){var r,n,i=t.shared.shader;return r=s?s.append(t,e):e.def(i,\".\",\"frag\"),n=l?l.append(t,e):e.def(i,\".\",\"vert\"),e.def(i+\".program(\"+n+\",\"+r+\")\")})),{frag:s,vert:l,progVar:t,program:c}}function T(t,e){function r(t,e){if(t in n){var r=0|n[t];return F((function(t,n){return e&&(t.OFFSET=r),r}))}if(t in i){var o=i[t];return B(o,(function(t,r){var n=t.invoke(r,o);return e&&(t.OFFSET=n),n}))}return e&&a?F((function(t,e){return t.OFFSET=\"0\",0})):null}var n=t.static,i=t.dynamic,a=function(){if(\"elements\"in n){var t=n.elements;O(t)?t=o.getElements(o.create(t,!0)):t&&(t=o.getElements(t));var e=F((function(e,r){if(t){var n=e.link(t);return e.ELEMENTS=n}return e.ELEMENTS=null}));return e.value=t,e}if(\"elements\"in i){var r=i.elements;return B(r,(function(t,e){var n=(i=t.shared).isBufferArgs,i=i.elements,a=t.invoke(e,r),o=e.def(\"null\");n=e.def(n,\"(\",a,\")\"),a=t.cond(n).then(o,\"=\",i,\".createStream(\",a,\");\").else(o,\"=\",i,\".getElements(\",a,\");\");return e.entry(a),e.exit(t.cond(n).then(i,\".destroyStream(\",o,\");\")),t.ELEMENTS=o}))}return null}(),s=r(\"offset\",!0);return{elements:a,primitive:function(){if(\"primitive\"in n){var t=n.primitive;return F((function(e,r){return nt[t]}))}if(\"primitive\"in i){var e=i.primitive;return B(e,(function(t,r){var n=t.constants.primTypes,i=t.invoke(r,e);return r.def(n,\"[\",i,\"]\")}))}return a?R(a)?a.value?F((function(t,e){return e.def(t.ELEMENTS,\".primType\")})):F((function(){return 4})):new D(a.thisDep,a.contextDep,a.propDep,(function(t,e){var r=t.ELEMENTS;return e.def(r,\"?\",r,\".primType:\",4)})):null}(),count:function(){if(\"count\"in n){var t=0|n.count;return F((function(){return t}))}if(\"count\"in i){var e=i.count;return B(e,(function(t,r){return t.invoke(r,e)}))}return a?R(a)?a?s?new D(s.thisDep,s.contextDep,s.propDep,(function(t,e){return e.def(t.ELEMENTS,\".vertCount-\",t.OFFSET)})):F((function(t,e){return e.def(t.ELEMENTS,\".vertCount\")})):F((function(){return-1})):new D(a.thisDep||s.thisDep,a.contextDep||s.contextDep,a.propDep||s.propDep,(function(t,e){var r=t.ELEMENTS;return t.OFFSET?e.def(r,\"?\",r,\".vertCount-\",t.OFFSET,\":-1\"):e.def(r,\"?\",r,\".vertCount:-1\")})):null}(),instances:r(\"instances\",!1),offset:s}}function k(t,r){var n=t.static,a=t.dynamic,o={};return Object.keys(n).forEach((function(t){var r=n[t],a=e.id(t),s=new Z;if(O(r))s.state=1,s.buffer=i.getBuffer(i.create(r,34962,!1,!0)),s.type=0;else if(c=i.getBuffer(r))s.state=1,s.buffer=c,s.type=0;else if(\"constant\"in r){var l=r.constant;s.buffer=\"null\",s.state=2,\"number\"==typeof l?s.x=l:wt.forEach((function(t,e){e<l.length&&(s[t]=l[e])}))}else{var c=O(r.buffer)?i.getBuffer(i.create(r.buffer,34962,!1,!0)):i.getBuffer(r.buffer),u=0|r.offset,f=0|r.stride,h=0|r.size,p=!!r.normalized,d=0;\"type\"in r&&(d=Q[r.type]),r=0|r.divisor,s.buffer=c,s.state=1,s.size=h,s.normalized=p,s.type=d||c.dtype,s.offset=u,s.stride=f,s.divisor=r}o[t]=F((function(t,e){var r=t.attribCache;if(a in r)return r[a];var n={isStream:!1};return Object.keys(s).forEach((function(t){n[t]=s[t]})),s.buffer&&(n.buffer=t.link(s.buffer),n.type=n.type||n.buffer+\".dtype\"),r[a]=n}))})),Object.keys(a).forEach((function(t){var e=a[t];o[t]=B(e,(function(t,r){function n(t){r(l[t],\"=\",i,\".\",t,\"|0;\")}var i=t.invoke(r,e),a=t.shared,o=t.constants,s=a.isBufferArgs,l=(a=a.buffer,{isStream:r.def(!1)}),c=new Z;c.state=1,Object.keys(c).forEach((function(t){l[t]=r.def(\"\"+c[t])}));var u=l.buffer,f=l.type;return r(\"if(\",s,\"(\",i,\")){\",l.isStream,\"=true;\",u,\"=\",a,\".createStream(\",34962,\",\",i,\");\",f,\"=\",u,\".dtype;\",\"}else{\",u,\"=\",a,\".getBuffer(\",i,\");\",\"if(\",u,\"){\",f,\"=\",u,\".dtype;\",'}else if(\"constant\" in ',i,\"){\",l.state,\"=\",2,\";\",\"if(typeof \"+i+'.constant === \"number\"){',l[wt[0]],\"=\",i,\".constant;\",wt.slice(1).map((function(t){return l[t]})).join(\"=\"),\"=0;\",\"}else{\",wt.map((function(t,e){return l[t]+\"=\"+i+\".constant.length>\"+e+\"?\"+i+\".constant[\"+e+\"]:0;\"})).join(\"\"),\"}}else{\",\"if(\",s,\"(\",i,\".buffer)){\",u,\"=\",a,\".createStream(\",34962,\",\",i,\".buffer);\",\"}else{\",u,\"=\",a,\".getBuffer(\",i,\".buffer);\",\"}\",f,'=\"type\" in ',i,\"?\",o.glTypes,\"[\",i,\".type]:\",u,\".dtype;\",l.normalized,\"=!!\",i,\".normalized;\"),n(\"size\"),n(\"offset\"),n(\"stride\"),n(\"divisor\"),r(\"}}\"),r.exit(\"if(\",l.isStream,\"){\",a,\".destroyStream(\",u,\");\",\"}\"),l}))})),o}function M(t,e,n,i,o){function s(t){var e=c[t];e&&(h[t]=e)}var l=function(t,e){if(\"string\"==typeof(r=t.static).frag&&\"string\"==typeof r.vert){if(0<Object.keys(e.dynamic).length)return null;var r=e.static,n=Object.keys(r);if(0<n.length&&\"number\"==typeof r[n[0]]){for(var i=[],a=0;a<n.length;++a)i.push([0|r[n[a]],n[a]]);return i}}return null}(t,e),c=function(t,e,r){function n(t){if(t in i){var r=i[t];t=!0;var n,o,s=0|r.x,l=0|r.y;return\"width\"in r?n=0|r.width:t=!1,\"height\"in r?o=0|r.height:t=!1,new D(!t&&e&&e.thisDep,!t&&e&&e.contextDep,!t&&e&&e.propDep,(function(t,e){var i=t.shared.context,a=n;\"width\"in r||(a=e.def(i,\".\",\"framebufferWidth\",\"-\",s));var c=o;return\"height\"in r||(c=e.def(i,\".\",\"framebufferHeight\",\"-\",l)),[s,l,a,c]}))}if(t in a){var c=a[t];return t=B(c,(function(t,e){var r=t.invoke(e,c),n=t.shared.context,i=e.def(r,\".x|0\"),a=e.def(r,\".y|0\");return[i,a,e.def('\"width\" in ',r,\"?\",r,\".width|0:\",\"(\",n,\".\",\"framebufferWidth\",\"-\",i,\")\"),r=e.def('\"height\" in ',r,\"?\",r,\".height|0:\",\"(\",n,\".\",\"framebufferHeight\",\"-\",a,\")\")]})),e&&(t.thisDep=t.thisDep||e.thisDep,t.contextDep=t.contextDep||e.contextDep,t.propDep=t.propDep||e.propDep),t}return e?new D(e.thisDep,e.contextDep,e.propDep,(function(t,e){var r=t.shared.context;return[0,0,e.def(r,\".\",\"framebufferWidth\"),e.def(r,\".\",\"framebufferHeight\")]})):null}var i=t.static,a=t.dynamic;if(t=n(\"viewport\")){var o=t;t=new D(t.thisDep,t.contextDep,t.propDep,(function(t,e){var r=o.append(t,e),n=t.shared.context;return e.set(n,\".viewportWidth\",r[2]),e.set(n,\".viewportHeight\",r[3]),r}))}return{viewport:t,scissor_box:n(\"scissor.box\")}}(t,d=_(t)),f=T(t),h=function(t,e){var r=t.static,n=t.dynamic,i={};return rt.forEach((function(t){function e(e,a){if(t in r){var s=e(r[t]);i[o]=F((function(){return s}))}else if(t in n){var l=n[t];i[o]=B(l,(function(t,e){return a(t,e,t.invoke(e,l))}))}}var o=v(t);switch(t){case\"cull.enable\":case\"blend.enable\":case\"dither\":case\"stencil.enable\":case\"depth.enable\":case\"scissor.enable\":case\"polygonOffset.enable\":case\"sample.alpha\":case\"sample.enable\":case\"depth.mask\":return e((function(t){return t}),(function(t,e,r){return r}));case\"depth.func\":return e((function(t){return Mt[t]}),(function(t,e,r){return e.def(t.constants.compareFuncs,\"[\",r,\"]\")}));case\"depth.range\":return e((function(t){return t}),(function(t,e,r){return[e.def(\"+\",r,\"[0]\"),e=e.def(\"+\",r,\"[1]\")]}));case\"blend.func\":return e((function(t){return[kt[\"srcRGB\"in t?t.srcRGB:t.src],kt[\"dstRGB\"in t?t.dstRGB:t.dst],kt[\"srcAlpha\"in t?t.srcAlpha:t.src],kt[\"dstAlpha\"in t?t.dstAlpha:t.dst]]}),(function(t,e,r){function n(t,n){return e.def('\"',t,n,'\" in ',r,\"?\",r,\".\",t,n,\":\",r,\".\",t)}t=t.constants.blendFuncs;var i=n(\"src\",\"RGB\"),a=n(\"dst\",\"RGB\"),o=(i=e.def(t,\"[\",i,\"]\"),e.def(t,\"[\",n(\"src\",\"Alpha\"),\"]\"));return[i,a=e.def(t,\"[\",a,\"]\"),o,t=e.def(t,\"[\",n(\"dst\",\"Alpha\"),\"]\")]}));case\"blend.equation\":return e((function(t){return\"string\"==typeof t?[J[t],J[t]]:\"object\"==typeof t?[J[t.rgb],J[t.alpha]]:void 0}),(function(t,e,r){var n=t.constants.blendEquations,i=e.def(),a=e.def();return(t=t.cond(\"typeof \",r,'===\"string\"')).then(i,\"=\",a,\"=\",n,\"[\",r,\"];\"),t.else(i,\"=\",n,\"[\",r,\".rgb];\",a,\"=\",n,\"[\",r,\".alpha];\"),e(t),[i,a]}));case\"blend.color\":return e((function(t){return a(4,(function(e){return+t[e]}))}),(function(t,e,r){return a(4,(function(t){return e.def(\"+\",r,\"[\",t,\"]\")}))}));case\"stencil.mask\":return e((function(t){return 0|t}),(function(t,e,r){return e.def(r,\"|0\")}));case\"stencil.func\":return e((function(t){return[Mt[t.cmp||\"keep\"],t.ref||0,\"mask\"in t?t.mask:-1]}),(function(t,e,r){return[t=e.def('\"cmp\" in ',r,\"?\",t.constants.compareFuncs,\"[\",r,\".cmp]\",\":\",7680),e.def(r,\".ref|0\"),e=e.def('\"mask\" in ',r,\"?\",r,\".mask|0:-1\")]}));case\"stencil.opFront\":case\"stencil.opBack\":return e((function(e){return[\"stencil.opBack\"===t?1029:1028,At[e.fail||\"keep\"],At[e.zfail||\"keep\"],At[e.zpass||\"keep\"]]}),(function(e,r,n){function i(t){return r.def('\"',t,'\" in ',n,\"?\",a,\"[\",n,\".\",t,\"]:\",7680)}var a=e.constants.stencilOps;return[\"stencil.opBack\"===t?1029:1028,i(\"fail\"),i(\"zfail\"),i(\"zpass\")]}));case\"polygonOffset.offset\":return e((function(t){return[0|t.factor,0|t.units]}),(function(t,e,r){return[e.def(r,\".factor|0\"),e=e.def(r,\".units|0\")]}));case\"cull.face\":return e((function(t){var e=0;return\"front\"===t?e=1028:\"back\"===t&&(e=1029),e}),(function(t,e,r){return e.def(r,'===\"front\"?',1028,\":\",1029)}));case\"lineWidth\":return e((function(t){return t}),(function(t,e,r){return r}));case\"frontFace\":return e((function(t){return St[t]}),(function(t,e,r){return e.def(r+'===\"cw\"?2304:2305')}));case\"colorMask\":return e((function(t){return t.map((function(t){return!!t}))}),(function(t,e,r){return a(4,(function(t){return\"!!\"+r+\"[\"+t+\"]\"}))}));case\"sample.coverage\":return e((function(t){return[\"value\"in t?t.value:1,!!t.invert]}),(function(t,e,r){return[e.def('\"value\" in ',r,\"?+\",r,\".value:1\"),e=e.def(\"!!\",r,\".invert\")]}))}})),i}(t),p=w(t,0,l);s(\"viewport\"),s(v(\"scissor.box\"));var d,m=0<Object.keys(h).length;if((d={framebuffer:d,draw:f,shader:p,state:h,dirty:m,scopeVAO:null,drawVAO:null,useVAO:!1,attributes:{}}).profile=function(t){var e,r=t.static;if(t=t.dynamic,\"profile\"in r){var n=!!r.profile;(e=F((function(t,e){return n}))).enable=n}else if(\"profile\"in t){var i=t.profile;e=B(i,(function(t,e){return t.invoke(e,i)}))}return e}(t),d.uniforms=function(t,e){var r=t.static,n=t.dynamic,i={};return Object.keys(r).forEach((function(t){var e,n=r[t];if(\"number\"==typeof n||\"boolean\"==typeof n)e=F((function(){return n}));else if(\"function\"==typeof n){var o=n._reglType;\"texture2d\"===o||\"textureCube\"===o?e=F((function(t){return t.link(n)})):\"framebuffer\"!==o&&\"framebufferCube\"!==o||(e=F((function(t){return t.link(n.color[0])})))}else g(n)&&(e=F((function(t){return t.global.def(\"[\",a(n.length,(function(t){return n[t]})),\"]\")})));e.value=n,i[t]=e})),Object.keys(n).forEach((function(t){var e=n[t];i[t]=B(e,(function(t,r){return t.invoke(r,e)}))})),i}(n),d.drawVAO=d.scopeVAO=function(t,e){var r=t.static,n=t.dynamic;if(\"vao\"in r){var i=r.vao;return null!==i&&null===u.getVAO(i)&&(i=u.createVAO(i)),F((function(t){return t.link(u.getVAO(i))}))}if(\"vao\"in n){var a=n.vao;return B(a,(function(t,e){var r=t.invoke(e,a);return e.def(t.shared.vao+\".getVAO(\"+r+\")\")}))}return null}(t),!d.drawVAO&&p.program&&!l&&r.angle_instanced_arrays){var y=!0;if(t=p.program.attributes.map((function(t){return t=e.static[t],y=y&&!!t,t})),y&&0<t.length){var x=u.getVAO(u.createVAO(t));d.drawVAO=new D(null,null,null,(function(t,e){return t.link(x)})),d.useVAO=!0}}return l?d.useVAO=!0:d.attributes=k(e),d.context=function(t){var e=t.static,r=t.dynamic,n={};return Object.keys(e).forEach((function(t){var r=e[t];n[t]=F((function(t,e){return\"number\"==typeof r||\"boolean\"==typeof r?\"\"+r:t.link(r)}))})),Object.keys(r).forEach((function(t){var e=r[t];n[t]=B(e,(function(t,r){return t.invoke(r,e)}))})),n}(i),d}function A(t,e,r){var n=t.shared.context,i=t.scope();Object.keys(r).forEach((function(a){e.save(n,\".\"+a),i(n,\".\",a,\"=\",r[a].append(t,e),\";\")})),e(i)}function S(t,e,r,n){var i,a=(s=t.shared).gl,o=s.framebuffer;$&&(i=e.def(s.extensions,\".webgl_draw_buffers\"));var s=(l=t.constants).drawBuffer,l=l.backBuffer;t=r?r.append(t,e):e.def(o,\".next\"),n||e(\"if(\",t,\"!==\",o,\".cur){\"),e(\"if(\",t,\"){\",a,\".bindFramebuffer(\",36160,\",\",t,\".framebuffer);\"),$&&e(i,\".drawBuffersWEBGL(\",s,\"[\",t,\".colorAttachments.length]);\"),e(\"}else{\",a,\".bindFramebuffer(\",36160,\",null);\"),$&&e(i,\".drawBuffersWEBGL(\",l,\");\"),e(\"}\",o,\".cur=\",t,\";\"),n||e(\"}\")}function E(t,e,r){var n=t.shared,i=n.gl,o=t.current,s=t.next,l=n.current,c=n.next,u=t.cond(l,\".dirty\");rt.forEach((function(e){var n,f;if(!((e=v(e))in r.state))if(e in s){n=s[e],f=o[e];var h=a(tt[e].length,(function(t){return u.def(n,\"[\",t,\"]\")}));u(t.cond(h.map((function(t,e){return t+\"!==\"+f+\"[\"+e+\"]\"})).join(\"||\")).then(i,\".\",at[e],\"(\",h,\");\",h.map((function(t,e){return f+\"[\"+e+\"]=\"+t})).join(\";\"),\";\"))}else n=u.def(c,\".\",e),h=t.cond(n,\"!==\",l,\".\",e),u(h),e in it?h(t.cond(n).then(i,\".enable(\",it[e],\");\").else(i,\".disable(\",it[e],\");\"),l,\".\",e,\"=\",n,\";\"):h(i,\".\",at[e],\"(\",n,\");\",l,\".\",e,\"=\",n,\";\")})),0===Object.keys(r.state).length&&u(l,\".dirty=false;\"),e(u)}function L(t,e,r,n){var i=t.shared,a=t.current,o=i.current,s=i.gl;z(Object.keys(r)).forEach((function(i){var l=r[i];if(!n||n(l)){var c=l.append(t,e);if(it[i]){var u=it[i];R(l)?e(s,c?\".enable(\":\".disable(\",u,\");\"):e(t.cond(c).then(s,\".enable(\",u,\");\").else(s,\".disable(\",u,\");\")),e(o,\".\",i,\"=\",c,\";\")}else if(g(c)){var f=a[i];e(s,\".\",at[i],\"(\",c,\");\",c.map((function(t,e){return f+\"[\"+e+\"]=\"+t})).join(\";\"),\";\")}else e(s,\".\",at[i],\"(\",c,\");\",o,\".\",i,\"=\",c,\";\")}}))}function C(t,e){K&&(t.instancing=e.def(t.shared.extensions,\".angle_instanced_arrays\"))}function P(t,e,r,n,i){function a(){return\"undefined\"==typeof performance?\"Date.now()\":\"performance.now()\"}function o(t){t(c=e.def(),\"=\",a(),\";\"),\"string\"==typeof i?t(h,\".count+=\",i,\";\"):t(h,\".count++;\"),d&&(n?t(u=e.def(),\"=\",m,\".getNumPendingQueries();\"):t(m,\".beginQuery(\",h,\");\"))}function s(t){t(h,\".cpuTime+=\",a(),\"-\",c,\";\"),d&&(n?t(m,\".pushScopeStats(\",u,\",\",m,\".getNumPendingQueries(),\",h,\");\"):t(m,\".endQuery();\"))}function l(t){var r=e.def(p,\".profile\");e(p,\".profile=\",t,\";\"),e.exit(p,\".profile=\",r,\";\")}var c,u,f=t.shared,h=t.stats,p=f.current,m=f.timer;if(r=r.profile){if(R(r))return void(r.enable?(o(e),s(e.exit),l(\"true\")):l(\"false\"));l(r=r.append(t,e))}else r=e.def(p,\".profile\");o(f=t.block()),e(\"if(\",r,\"){\",f,\"}\"),s(t=t.block()),e.exit(\"if(\",r,\"){\",t,\"}\")}function N(t,e,r,n,i){function a(r,n,i){function a(){e(\"if(!\",u,\".buffer){\",l,\".enableVertexAttribArray(\",c,\");}\");var r,a=i.type;r=i.size?e.def(i.size,\"||\",n):n,e(\"if(\",u,\".type!==\",a,\"||\",u,\".size!==\",r,\"||\",p.map((function(t){return u+\".\"+t+\"!==\"+i[t]})).join(\"||\"),\"){\",l,\".bindBuffer(\",34962,\",\",f,\".buffer);\",l,\".vertexAttribPointer(\",[c,r,a,i.normalized,i.stride,i.offset],\");\",u,\".type=\",a,\";\",u,\".size=\",r,\";\",p.map((function(t){return u+\".\"+t+\"=\"+i[t]+\";\"})).join(\"\"),\"}\"),K&&(a=i.divisor,e(\"if(\",u,\".divisor!==\",a,\"){\",t.instancing,\".vertexAttribDivisorANGLE(\",[c,a],\");\",u,\".divisor=\",a,\";}\"))}function s(){e(\"if(\",u,\".buffer){\",l,\".disableVertexAttribArray(\",c,\");\",u,\".buffer=null;\",\"}if(\",wt.map((function(t,e){return u+\".\"+t+\"!==\"+h[e]})).join(\"||\"),\"){\",l,\".vertexAttrib4f(\",c,\",\",h,\");\",wt.map((function(t,e){return u+\".\"+t+\"=\"+h[e]+\";\"})).join(\"\"),\"}\")}var l=o.gl,c=e.def(r,\".location\"),u=e.def(o.attributes,\"[\",c,\"]\");r=i.state;var f=i.buffer,h=[i.x,i.y,i.z,i.w],p=[\"buffer\",\"normalized\",\"offset\",\"stride\"];1===r?a():2===r?s():(e(\"if(\",r,\"===\",1,\"){\"),a(),e(\"}else{\"),s(),e(\"}\"))}var o=t.shared;n.forEach((function(n){var o,s=n.name,l=r.attributes[s];if(l){if(!i(l))return;o=l.append(t,e)}else{if(!i(Et))return;var c=t.scopeAttrib(s);o={},Object.keys(new Z).forEach((function(t){o[t]=e.def(c,\".\",t)}))}a(t.link(n),function(t){switch(t){case 35664:case 35667:case 35671:return 2;case 35665:case 35668:case 35672:return 3;case 35666:case 35669:case 35673:return 4;default:return 1}}(n.info.type),o)}))}function j(t,r,n,i,o){for(var s,l=t.shared,c=l.gl,u=0;u<i.length;++u){var f,h=(m=i[u]).name,p=m.info.type,d=n.uniforms[h],m=t.link(m)+\".location\";if(d){if(!o(d))continue;if(R(d)){if(h=d.value,35678===p||35680===p)r(c,\".uniform1i(\",m,\",\",(p=t.link(h._texture||h.color[0]._texture))+\".bind());\"),r.exit(p,\".unbind();\");else if(35674===p||35675===p||35676===p)d=2,35675===p?d=3:35676===p&&(d=4),r(c,\".uniformMatrix\",d,\"fv(\",m,\",false,\",h=t.global.def(\"new Float32Array([\"+Array.prototype.slice.call(h)+\"])\"),\");\");else{switch(p){case 5126:s=\"1f\";break;case 35664:s=\"2f\";break;case 35665:s=\"3f\";break;case 35666:s=\"4f\";break;case 35670:case 5124:s=\"1i\";break;case 35671:case 35667:s=\"2i\";break;case 35672:case 35668:s=\"3i\";break;case 35673:s=\"4i\";break;case 35669:s=\"4i\"}r(c,\".uniform\",s,\"(\",m,\",\",g(h)?Array.prototype.slice.call(h):h,\");\")}continue}f=d.append(t,r)}else{if(!o(Et))continue;f=r.def(l.uniforms,\"[\",e.id(h),\"]\")}switch(35678===p?r(\"if(\",f,\"&&\",f,'._reglType===\"framebuffer\"){',f,\"=\",f,\".color[0];\",\"}\"):35680===p&&r(\"if(\",f,\"&&\",f,'._reglType===\"framebufferCube\"){',f,\"=\",f,\".color[0];\",\"}\"),h=1,p){case 35678:case 35680:p=r.def(f,\"._texture\"),r(c,\".uniform1i(\",m,\",\",p,\".bind());\"),r.exit(p,\".unbind();\");continue;case 5124:case 35670:s=\"1i\";break;case 35667:case 35671:s=\"2i\",h=2;break;case 35668:case 35672:s=\"3i\",h=3;break;case 35669:case 35673:s=\"4i\",h=4;break;case 5126:s=\"1f\";break;case 35664:s=\"2f\",h=2;break;case 35665:s=\"3f\",h=3;break;case 35666:s=\"4f\",h=4;break;case 35674:s=\"Matrix2fv\";break;case 35675:s=\"Matrix3fv\";break;case 35676:s=\"Matrix4fv\"}if(r(c,\".uniform\",s,\"(\",m,\",\"),\"M\"===s.charAt(0)){m=Math.pow(p-35674+2,2);var v=t.global.def(\"new Float32Array(\",m,\")\");r(\"false,(Array.isArray(\",f,\")||\",f,\" instanceof Float32Array)?\",f,\":(\",a(m,(function(t){return v+\"[\"+t+\"]=\"+f+\"[\"+t+\"]\"})),\",\",v,\")\")}else r(1<h?a(h,(function(t){return f+\"[\"+t+\"]\"})):f);r(\");\")}}function U(t,e,r,n){function i(i){var a=h[i];return a?a.contextDep&&n.contextDynamic||a.propDep?a.append(t,r):a.append(t,e):e.def(f,\".\",i)}function a(){function t(){r(l,\".drawElementsInstancedANGLE(\",[d,g,v,m+\"<<((\"+v+\"-5121)>>1)\",s],\");\")}function e(){r(l,\".drawArraysInstancedANGLE(\",[d,m,g,s],\");\")}p?y?t():(r(\"if(\",p,\"){\"),t(),r(\"}else{\"),e(),r(\"}\")):e()}function o(){function t(){r(u+\".drawElements(\"+[d,g,v,m+\"<<((\"+v+\"-5121)>>1)\"]+\");\")}function e(){r(u+\".drawArrays(\"+[d,m,g]+\");\")}p?y?t():(r(\"if(\",p,\"){\"),t(),r(\"}else{\"),e(),r(\"}\")):e()}var s,l,c=t.shared,u=c.gl,f=c.draw,h=n.draw,p=function(){var i=h.elements,a=e;return i?((i.contextDep&&n.contextDynamic||i.propDep)&&(a=r),i=i.append(t,a)):i=a.def(f,\".\",\"elements\"),i&&a(\"if(\"+i+\")\"+u+\".bindBuffer(34963,\"+i+\".buffer.buffer);\"),i}(),d=i(\"primitive\"),m=i(\"offset\"),g=function(){var i=h.count,a=e;return i?((i.contextDep&&n.contextDynamic||i.propDep)&&(a=r),i=i.append(t,a)):i=a.def(f,\".\",\"count\"),i}();if(\"number\"==typeof g){if(0===g)return}else r(\"if(\",g,\"){\"),r.exit(\"}\");K&&(s=i(\"instances\"),l=t.instancing);var v=p+\".type\",y=h.elements&&R(h.elements);K&&(\"number\"!=typeof s||0<=s)?\"string\"==typeof s?(r(\"if(\",s,\">0){\"),a(),r(\"}else if(\",s,\"<0){\"),o(),r(\"}\")):a():o()}function V(t,e,r,n,i){return i=(e=b()).proc(\"body\",i),K&&(e.instancing=i.def(e.shared.extensions,\".angle_instanced_arrays\")),t(e,i,r,n),e.compile().body}function H(t,e,r,n){C(t,e),r.useVAO?r.drawVAO?e(t.shared.vao,\".setVAO(\",r.drawVAO.append(t,e),\");\"):e(t.shared.vao,\".setVAO(\",t.shared.vao,\".targetVAO);\"):(e(t.shared.vao,\".setVAO(null);\"),N(t,e,r,n.attributes,(function(){return!0}))),j(t,e,r,n.uniforms,(function(){return!0})),U(t,e,e,r)}function G(t,e,r,n){function i(){return!0}t.batchId=\"a1\",C(t,e),N(t,e,r,n.attributes,i),j(t,e,r,n.uniforms,i),U(t,e,e,r)}function Y(t,e,r,n){function i(t){return t.contextDep&&o||t.propDep}function a(t){return!i(t)}C(t,e);var o=r.contextDep,s=e.def(),l=e.def();t.shared.props=l,t.batchId=s;var c=t.scope(),u=t.scope();e(c.entry,\"for(\",s,\"=0;\",s,\"<\",\"a1\",\";++\",s,\"){\",l,\"=\",\"a0\",\"[\",s,\"];\",u,\"}\",c.exit),r.needsContext&&A(t,u,r.context),r.needsFramebuffer&&S(t,u,r.framebuffer),L(t,u,r.state,i),r.profile&&i(r.profile)&&P(t,u,r,!1,!0),n?(r.useVAO?r.drawVAO?i(r.drawVAO)?u(t.shared.vao,\".setVAO(\",r.drawVAO.append(t,u),\");\"):c(t.shared.vao,\".setVAO(\",r.drawVAO.append(t,c),\");\"):c(t.shared.vao,\".setVAO(\",t.shared.vao,\".targetVAO);\"):(c(t.shared.vao,\".setVAO(null);\"),N(t,c,r,n.attributes,a),N(t,u,r,n.attributes,i)),j(t,c,r,n.uniforms,a),j(t,u,r,n.uniforms,i),U(t,c,u,r)):(e=t.global.def(\"{}\"),n=r.shader.progVar.append(t,u),l=u.def(n,\".id\"),c=u.def(e,\"[\",l,\"]\"),u(t.shared.gl,\".useProgram(\",n,\".program);\",\"if(!\",c,\"){\",c,\"=\",e,\"[\",l,\"]=\",t.link((function(e){return V(G,t,r,e,2)})),\"(\",n,\");}\",c,\".call(this,a0[\",s,\"],\",s,\");\"))}function W(t,r){function n(e){var n=r.shader[e];n&&i.set(a.shader,\".\"+e,n.append(t,i))}var i=t.proc(\"scope\",3);t.batchId=\"a2\";var a=t.shared,o=a.current;A(t,i,r.context),r.framebuffer&&r.framebuffer.append(t,i),z(Object.keys(r.state)).forEach((function(e){var n=r.state[e].append(t,i);g(n)?n.forEach((function(r,n){i.set(t.next[e],\"[\"+n+\"]\",r)})):i.set(a.next,\".\"+e,n)})),P(t,i,r,!0,!0),[\"elements\",\"offset\",\"count\",\"instances\",\"primitive\"].forEach((function(e){var n=r.draw[e];n&&i.set(a.draw,\".\"+e,\"\"+n.append(t,i))})),Object.keys(r.uniforms).forEach((function(n){i.set(a.uniforms,\"[\"+e.id(n)+\"]\",r.uniforms[n].append(t,i))})),Object.keys(r.attributes).forEach((function(e){var n=r.attributes[e].append(t,i),a=t.scopeAttrib(e);Object.keys(new Z).forEach((function(t){i.set(a,\".\"+t,n[t])}))})),r.scopeVAO&&i.set(a.vao,\".targetVAO\",r.scopeVAO.append(t,i)),n(\"vert\"),n(\"frag\"),0<Object.keys(r.state).length&&(i(o,\".dirty=true;\"),i.exit(o,\".dirty=true;\")),i(\"a1(\",t.shared.context,\",a0,\",t.batchId,\");\")}function X(t,e,r){var n=e.static[r];if(n&&function(t){if(\"object\"==typeof t&&!g(t)){for(var e=Object.keys(t),r=0;r<e.length;++r)if(q.isDynamic(t[e[r]]))return!0;return!1}}(n)){var i=t.global,a=Object.keys(n),o=!1,s=!1,l=!1,c=t.global.def(\"{}\");a.forEach((function(e){var r=n[e];if(q.isDynamic(r))\"function\"==typeof r&&(r=n[e]=q.unbox(r)),e=B(r,null),o=o||e.thisDep,l=l||e.propDep,s=s||e.contextDep;else{switch(i(c,\".\",e,\"=\"),typeof r){case\"number\":i(r);break;case\"string\":i('\"',r,'\"');break;case\"object\":Array.isArray(r)&&i(\"[\",r.join(),\"]\");break;default:i(t.link(r))}i(\";\")}})),e.dynamic[r]=new q.DynamicVariable(4,{thisDep:o,contextDep:s,propDep:l,ref:c,append:function(t,e){a.forEach((function(r){var i=n[r];q.isDynamic(i)&&(i=t.invoke(e,i),e(c,\".\",r,\"=\",i,\";\"))}))}}),delete e.static[r]}}var Z=u.Record,J={add:32774,subtract:32778,\"reverse subtract\":32779};r.ext_blend_minmax&&(J.min=32775,J.max=32776);var K=r.angle_instanced_arrays,$=r.webgl_draw_buffers,tt={dirty:!0,profile:m.profile},et={},rt=[],it={},at={};y(\"dither\",3024),y(\"blend.enable\",3042),x(\"blend.color\",\"blendColor\",[0,0,0,0]),x(\"blend.equation\",\"blendEquationSeparate\",[32774,32774]),x(\"blend.func\",\"blendFuncSeparate\",[1,0,1,0]),y(\"depth.enable\",2929,!0),x(\"depth.func\",\"depthFunc\",513),x(\"depth.range\",\"depthRange\",[0,1]),x(\"depth.mask\",\"depthMask\",!0),x(\"colorMask\",\"colorMask\",[!0,!0,!0,!0]),y(\"cull.enable\",2884),x(\"cull.face\",\"cullFace\",1029),x(\"frontFace\",\"frontFace\",2305),x(\"lineWidth\",\"lineWidth\",1),y(\"polygonOffset.enable\",32823),x(\"polygonOffset.offset\",\"polygonOffset\",[0,0]),y(\"sample.alpha\",32926),y(\"sample.enable\",32928),x(\"sample.coverage\",\"sampleCoverage\",[1,!1]),y(\"stencil.enable\",2960),x(\"stencil.mask\",\"stencilMask\",-1),x(\"stencil.func\",\"stencilFunc\",[519,0,-1]),x(\"stencil.opFront\",\"stencilOpSeparate\",[1028,7680,7680,7680]),x(\"stencil.opBack\",\"stencilOpSeparate\",[1029,7680,7680,7680]),y(\"scissor.enable\",3089),x(\"scissor.box\",\"scissor\",[0,0,t.drawingBufferWidth,t.drawingBufferHeight]),x(\"viewport\",\"viewport\",[0,0,t.drawingBufferWidth,t.drawingBufferHeight]);var ot={gl:t,context:p,strings:e,next:et,current:tt,draw:h,elements:o,buffer:i,shader:f,attributes:u.state,vao:u,uniforms:c,framebuffer:l,extensions:r,timer:d,isBufferArgs:O},st={primTypes:nt,compareFuncs:Mt,blendFuncs:kt,blendEquations:J,stencilOps:At,glTypes:Q,orientationType:St};$&&(st.backBuffer=[1029],st.drawBuffer=a(n.maxDrawbuffers,(function(t){return 0===t?[0]:a(t,(function(t){return 36064+t}))})));var lt=0;return{next:et,current:tt,procs:function(){var t=b(),e=t.proc(\"poll\"),i=t.proc(\"refresh\"),o=t.block();e(o),i(o);var s,l=t.shared,c=l.gl,u=l.next,f=l.current;o(f,\".dirty=false;\"),S(t,e),S(t,i,null,!0),K&&(s=t.link(K)),r.oes_vertex_array_object&&i(t.link(r.oes_vertex_array_object),\".bindVertexArrayOES(null);\");for(var h=0;h<n.maxAttributes;++h){var p=i.def(l.attributes,\"[\",h,\"]\"),d=t.cond(p,\".buffer\");d.then(c,\".enableVertexAttribArray(\",h,\");\",c,\".bindBuffer(\",34962,\",\",p,\".buffer.buffer);\",c,\".vertexAttribPointer(\",h,\",\",p,\".size,\",p,\".type,\",p,\".normalized,\",p,\".stride,\",p,\".offset);\").else(c,\".disableVertexAttribArray(\",h,\");\",c,\".vertexAttrib4f(\",h,\",\",p,\".x,\",p,\".y,\",p,\".z,\",p,\".w);\",p,\".buffer=null;\"),i(d),K&&i(s,\".vertexAttribDivisorANGLE(\",h,\",\",p,\".divisor);\")}return i(t.shared.vao,\".currentVAO=null;\",t.shared.vao,\".setVAO(\",t.shared.vao,\".targetVAO);\"),Object.keys(it).forEach((function(r){var n=it[r],a=o.def(u,\".\",r),s=t.block();s(\"if(\",a,\"){\",c,\".enable(\",n,\")}else{\",c,\".disable(\",n,\")}\",f,\".\",r,\"=\",a,\";\"),i(s),e(\"if(\",a,\"!==\",f,\".\",r,\"){\",s,\"}\")})),Object.keys(at).forEach((function(r){var n,s,l=at[r],h=tt[r],p=t.block();p(c,\".\",l,\"(\"),g(h)?(l=h.length,n=t.global.def(u,\".\",r),s=t.global.def(f,\".\",r),p(a(l,(function(t){return n+\"[\"+t+\"]\"})),\");\",a(l,(function(t){return s+\"[\"+t+\"]=\"+n+\"[\"+t+\"];\"})).join(\"\")),e(\"if(\",a(l,(function(t){return n+\"[\"+t+\"]!==\"+s+\"[\"+t+\"]\"})).join(\"||\"),\"){\",p,\"}\")):(n=o.def(u,\".\",r),s=o.def(f,\".\",r),p(n,\");\",f,\".\",r,\"=\",n,\";\"),e(\"if(\",n,\"!==\",s,\"){\",p,\"}\")),i(p)})),t.compile()}(),compile:function(t,e,r,n,i){var a=b();return a.stats=a.link(i),Object.keys(e.static).forEach((function(t){X(a,e,t)})),Tt.forEach((function(e){X(a,t,e)})),r=M(t,e,r,n),function(t,e){var r=t.proc(\"draw\",1);C(t,r),A(t,r,e.context),S(t,r,e.framebuffer),E(t,r,e),L(t,r,e.state),P(t,r,e,!1,!0);var n=e.shader.progVar.append(t,r);if(r(t.shared.gl,\".useProgram(\",n,\".program);\"),e.shader.program)H(t,r,e,e.shader.program);else{r(t.shared.vao,\".setVAO(null);\");var i=t.global.def(\"{}\"),a=r.def(n,\".id\"),o=r.def(i,\"[\",a,\"]\");r(t.cond(o).then(o,\".call(this,a0);\").else(o,\"=\",i,\"[\",a,\"]=\",t.link((function(r){return V(H,t,e,r,1)})),\"(\",n,\");\",o,\".call(this,a0);\"))}0<Object.keys(e.state).length&&r(t.shared.current,\".dirty=true;\")}(a,r),W(a,r),function(t,e){function r(t){return t.contextDep&&i||t.propDep}var n=t.proc(\"batch\",2);t.batchId=\"0\",C(t,n);var i=!1,a=!0;Object.keys(e.context).forEach((function(t){i=i||e.context[t].propDep})),i||(A(t,n,e.context),a=!1);var o=!1;if((s=e.framebuffer)?(s.propDep?i=o=!0:s.contextDep&&i&&(o=!0),o||S(t,n,s)):S(t,n,null),e.state.viewport&&e.state.viewport.propDep&&(i=!0),E(t,n,e),L(t,n,e.state,(function(t){return!r(t)})),e.profile&&r(e.profile)||P(t,n,e,!1,\"a1\"),e.contextDep=i,e.needsContext=a,e.needsFramebuffer=o,(a=e.shader.progVar).contextDep&&i||a.propDep)Y(t,n,e,null);else if(a=a.append(t,n),n(t.shared.gl,\".useProgram(\",a,\".program);\"),e.shader.program)Y(t,n,e,e.shader.program);else{n(t.shared.vao,\".setVAO(null);\");var s=t.global.def(\"{}\"),l=(o=n.def(a,\".id\"),n.def(s,\"[\",o,\"]\"));n(t.cond(l).then(l,\".call(this,a0,a1);\").else(l,\"=\",s,\"[\",o,\"]=\",t.link((function(r){return V(Y,t,e,r,2)})),\"(\",a,\");\",l,\".call(this,a0,a1);\"))}0<Object.keys(e.state).length&&n(t.shared.current,\".dirty=true;\")}(a,r),a.compile()}}}function j(t,e){for(var r=0;r<t.length;++r)if(t[r]===e)return r;return-1}var U=function(t,e){for(var r=Object.keys(e),n=0;n<r.length;++n)t[r[n]]=e[r[n]];return t},V=0,q={DynamicVariable:t,define:function(r,n){return new t(r,e(n+\"\"))},isDynamic:function(e){return\"function\"==typeof e&&!e._reglType||e instanceof t},unbox:function(e,r){return\"function\"==typeof e?new t(0,e):e},accessor:e},H={next:\"function\"==typeof requestAnimationFrame?function(t){return requestAnimationFrame(t)}:function(t){return setTimeout(t,16)},cancel:\"function\"==typeof cancelAnimationFrame?function(t){return cancelAnimationFrame(t)}:clearTimeout},G=\"undefined\"!=typeof performance&&performance.now?function(){return performance.now()}:function(){return+new Date},Y=s();Y.zero=s();var W=function(t,e){var r=1;e.ext_texture_filter_anisotropic&&(r=t.getParameter(34047));var n=1,i=1;e.webgl_draw_buffers&&(n=t.getParameter(34852),i=t.getParameter(36063));var a=!!e.oes_texture_float;if(a){a=t.createTexture(),t.bindTexture(3553,a),t.texImage2D(3553,0,6408,1,1,0,6408,5126,null);var o=t.createFramebuffer();if(t.bindFramebuffer(36160,o),t.framebufferTexture2D(36160,36064,3553,a,0),t.bindTexture(3553,null),36053!==t.checkFramebufferStatus(36160))a=!1;else{t.viewport(0,0,1,1),t.clearColor(1,0,0,1),t.clear(16384);var s=Y.allocType(5126,4);t.readPixels(0,0,1,1,6408,5126,s),t.getError()?a=!1:(t.deleteFramebuffer(o),t.deleteTexture(a),a=1===s[0]),Y.freeType(s)}}return s=!0,\"undefined\"!=typeof navigator&&(/MSIE/.test(navigator.userAgent)||/Trident\\//.test(navigator.appVersion)||/Edge/.test(navigator.userAgent))||(s=t.createTexture(),o=Y.allocType(5121,36),t.activeTexture(33984),t.bindTexture(34067,s),t.texImage2D(34069,0,6408,3,3,0,6408,5121,o),Y.freeType(o),t.bindTexture(34067,null),t.deleteTexture(s),s=!t.getError()),{colorBits:[t.getParameter(3410),t.getParameter(3411),t.getParameter(3412),t.getParameter(3413)],depthBits:t.getParameter(3414),stencilBits:t.getParameter(3415),subpixelBits:t.getParameter(3408),extensions:Object.keys(e).filter((function(t){return!!e[t]})),maxAnisotropic:r,maxDrawbuffers:n,maxColorAttachments:i,pointSizeDims:t.getParameter(33901),lineWidthDims:t.getParameter(33902),maxViewportDims:t.getParameter(3386),maxCombinedTextureUnits:t.getParameter(35661),maxCubeMapSize:t.getParameter(34076),maxRenderbufferSize:t.getParameter(34024),maxTextureUnits:t.getParameter(34930),maxTextureSize:t.getParameter(3379),maxAttributes:t.getParameter(34921),maxVertexUniforms:t.getParameter(36347),maxVertexTextureUnits:t.getParameter(35660),maxVaryingVectors:t.getParameter(36348),maxFragmentUniforms:t.getParameter(36349),glsl:t.getParameter(35724),renderer:t.getParameter(7937),vendor:t.getParameter(7936),version:t.getParameter(7938),readFloat:a,npotTextureCube:s}},X=function(t){return t instanceof Uint8Array||t instanceof Uint16Array||t instanceof Uint32Array||t instanceof Int8Array||t instanceof Int16Array||t instanceof Int32Array||t instanceof Float32Array||t instanceof Float64Array||t instanceof Uint8ClampedArray},Z=function(t){return Object.keys(t).map((function(e){return t[e]}))},J={shape:function(t){for(var e=[];t.length;t=t[0])e.push(t.length);return e},flatten:function(t,e,r,n){var i=1;if(e.length)for(var a=0;a<e.length;++a)i*=e[a];else i=0;switch(r=n||Y.allocType(r,i),e.length){case 0:break;case 1:for(n=e[0],e=0;e<n;++e)r[e]=t[e];break;case 2:for(n=e[0],e=e[1],a=i=0;a<n;++a)for(var o=t[a],s=0;s<e;++s)r[i++]=o[s];break;case 3:c(t,e[0],e[1],e[2],r,0);break;default:!function t(e,r,n,i,a){for(var o=1,s=n+1;s<r.length;++s)o*=r[s];var l=r[n];if(4==r.length-n){var u=r[n+1],f=r[n+2];for(r=r[n+3],s=0;s<l;++s)c(e[s],u,f,r,i,a),a+=o}else for(s=0;s<l;++s)t(e[s],r,n+1,i,a),a+=o}(t,e,0,r,0)}return r}},K={\"[object Int8Array]\":5120,\"[object Int16Array]\":5122,\"[object Int32Array]\":5124,\"[object Uint8Array]\":5121,\"[object Uint8ClampedArray]\":5121,\"[object Uint16Array]\":5123,\"[object Uint32Array]\":5125,\"[object Float32Array]\":5126,\"[object Float64Array]\":5121,\"[object ArrayBuffer]\":5121},Q={int8:5120,int16:5122,int32:5124,uint8:5121,uint16:5123,uint32:5125,float:5126,float32:5126},$={dynamic:35048,stream:35040,static:35044},tt=J.flatten,et=J.shape,rt=[];rt[5120]=1,rt[5122]=2,rt[5124]=4,rt[5121]=1,rt[5123]=2,rt[5125]=4,rt[5126]=4;var nt={points:0,point:0,lines:1,line:1,triangles:4,triangle:4,\"line loop\":2,\"line strip\":3,\"triangle strip\":5,\"triangle fan\":6},it=new Float32Array(1),at=new Uint32Array(it.buffer),ot=[9984,9986,9985,9987],st=[0,6409,6410,6407,6408],lt={};lt[6409]=lt[6406]=lt[6402]=1,lt[34041]=lt[6410]=2,lt[6407]=lt[35904]=3,lt[6408]=lt[35906]=4;var ct=v(\"HTMLCanvasElement\"),ut=v(\"OffscreenCanvas\"),ft=v(\"CanvasRenderingContext2D\"),ht=v(\"ImageBitmap\"),pt=v(\"HTMLImageElement\"),dt=v(\"HTMLVideoElement\"),mt=Object.keys(K).concat([ct,ut,ft,ht,pt,dt]),gt=[];gt[5121]=1,gt[5126]=4,gt[36193]=2,gt[5123]=2,gt[5125]=4;var vt=[];vt[32854]=2,vt[32855]=2,vt[36194]=2,vt[34041]=4,vt[33776]=.5,vt[33777]=.5,vt[33778]=1,vt[33779]=1,vt[35986]=.5,vt[35987]=1,vt[34798]=1,vt[35840]=.5,vt[35841]=.25,vt[35842]=.5,vt[35843]=.25,vt[36196]=.5;var yt=[];yt[32854]=2,yt[32855]=2,yt[36194]=2,yt[33189]=2,yt[36168]=1,yt[34041]=4,yt[35907]=4,yt[34836]=16,yt[34842]=8,yt[34843]=6;var xt=function(t,e,r,n,i){function a(t){this.id=c++,this.refCount=1,this.renderbuffer=t,this.format=32854,this.height=this.width=0,i.profile&&(this.stats={size:0})}function o(e){var r=e.renderbuffer;t.bindRenderbuffer(36161,null),t.deleteRenderbuffer(r),e.renderbuffer=null,e.refCount=0,delete u[e.id],n.renderbufferCount--}var s={rgba4:32854,rgb565:36194,\"rgb5 a1\":32855,depth:33189,stencil:36168,\"depth stencil\":34041};e.ext_srgb&&(s.srgba=35907),e.ext_color_buffer_half_float&&(s.rgba16f=34842,s.rgb16f=34843),e.webgl_color_buffer_float&&(s.rgba32f=34836);var l=[];Object.keys(s).forEach((function(t){l[s[t]]=t}));var c=0,u={};return a.prototype.decRef=function(){0>=--this.refCount&&o(this)},i.profile&&(n.getTotalRenderbufferSize=function(){var t=0;return Object.keys(u).forEach((function(e){t+=u[e].stats.size})),t}),{create:function(e,r){function o(e,r){var n=0,a=0,u=32854;if(\"object\"==typeof e&&e?(\"shape\"in e?(n=0|(a=e.shape)[0],a=0|a[1]):(\"radius\"in e&&(n=a=0|e.radius),\"width\"in e&&(n=0|e.width),\"height\"in e&&(a=0|e.height)),\"format\"in e&&(u=s[e.format])):\"number\"==typeof e?(n=0|e,a=\"number\"==typeof r?0|r:n):e||(n=a=1),n!==c.width||a!==c.height||u!==c.format)return o.width=c.width=n,o.height=c.height=a,c.format=u,t.bindRenderbuffer(36161,c.renderbuffer),t.renderbufferStorage(36161,u,n,a),i.profile&&(c.stats.size=yt[c.format]*c.width*c.height),o.format=l[c.format],o}var c=new a(t.createRenderbuffer());return u[c.id]=c,n.renderbufferCount++,o(e,r),o.resize=function(e,r){var n=0|e,a=0|r||n;return n===c.width&&a===c.height||(o.width=c.width=n,o.height=c.height=a,t.bindRenderbuffer(36161,c.renderbuffer),t.renderbufferStorage(36161,c.format,n,a),i.profile&&(c.stats.size=yt[c.format]*c.width*c.height)),o},o._reglType=\"renderbuffer\",o._renderbuffer=c,i.profile&&(o.stats=c.stats),o.destroy=function(){c.decRef()},o},clear:function(){Z(u).forEach(o)},restore:function(){Z(u).forEach((function(e){e.renderbuffer=t.createRenderbuffer(),t.bindRenderbuffer(36161,e.renderbuffer),t.renderbufferStorage(36161,e.format,e.width,e.height)})),t.bindRenderbuffer(36161,null)}}},bt=[];bt[6408]=4,bt[6407]=3;var _t=[];_t[5121]=1,_t[5126]=4,_t[36193]=2;var wt=[\"x\",\"y\",\"z\",\"w\"],Tt=\"blend.func blend.equation stencil.func stencil.opFront stencil.opBack sample.coverage viewport scissor.box polygonOffset.offset\".split(\" \"),kt={0:0,1:1,zero:0,one:1,\"src color\":768,\"one minus src color\":769,\"src alpha\":770,\"one minus src alpha\":771,\"dst color\":774,\"one minus dst color\":775,\"dst alpha\":772,\"one minus dst alpha\":773,\"constant color\":32769,\"one minus constant color\":32770,\"constant alpha\":32771,\"one minus constant alpha\":32772,\"src alpha saturate\":776},Mt={never:512,less:513,\"<\":513,equal:514,\"=\":514,\"==\":514,\"===\":514,lequal:515,\"<=\":515,greater:516,\">\":516,notequal:517,\"!=\":517,\"!==\":517,gequal:518,\">=\":518,always:519},At={0:0,zero:0,keep:7680,replace:7681,increment:7682,decrement:7683,\"increment wrap\":34055,\"decrement wrap\":34056,invert:5386},St={cw:2304,ccw:2305},Et=new D(!1,!1,!1,(function(){}));return function(t){function e(){if(0===J.length)w&&w.update(),tt=null;else{tt=H.next(e),f();for(var t=J.length-1;0<=t;--t){var r=J[t];r&&r(P,null,0)}g.flush(),w&&w.update()}}function r(){!tt&&0<J.length&&(tt=H.next(e))}function n(){tt&&(H.cancel(e),tt=null)}function a(t){t.preventDefault(),n(),K.forEach((function(t){t()}))}function o(t){g.getError(),y.restore(),R.restore(),O.restore(),F.restore(),B.restore(),V.restore(),z.restore(),w&&w.restore(),Y.procs.refresh(),r(),Q.forEach((function(t){t()}))}function s(t){function e(t){var e={},r={};return Object.keys(t).forEach((function(n){var i=t[n];q.isDynamic(i)?r[n]=q.unbox(i,n):e[n]=i})),{dynamic:r,static:e}}var r=e(t.context||{}),n=e(t.uniforms||{}),i=e(t.attributes||{}),a=e(function(t){function e(t){if(t in r){var e=r[t];delete r[t],Object.keys(e).forEach((function(n){r[t+\".\"+n]=e[n]}))}}var r=U({},t);return delete r.uniforms,delete r.attributes,delete r.context,delete r.vao,\"stencil\"in r&&r.stencil.op&&(r.stencil.opBack=r.stencil.opFront=r.stencil.op,delete r.stencil.op),e(\"blend\"),e(\"depth\"),e(\"cull\"),e(\"stencil\"),e(\"polygonOffset\"),e(\"scissor\"),e(\"sample\"),\"vao\"in t&&(r.vao=t.vao),r}(t));t={gpuTime:0,cpuTime:0,count:0};var o=(r=Y.compile(a,i,n,r,t)).draw,s=r.batch,l=r.scope,c=[];return U((function(t,e){var r;if(\"function\"==typeof t)return l.call(this,null,t,0);if(\"function\"==typeof e)if(\"number\"==typeof t)for(r=0;r<t;++r)l.call(this,null,e,r);else{if(!Array.isArray(t))return l.call(this,t,e,0);for(r=0;r<t.length;++r)l.call(this,t[r],e,r)}else if(\"number\"==typeof t){if(0<t)return s.call(this,function(t){for(;c.length<t;)c.push(null);return c}(0|t),0|t)}else{if(!Array.isArray(t))return o.call(this,t);if(t.length)return s.call(this,t,t.length)}}),{stats:t})}function l(t,e){var r=0;Y.procs.poll();var n=e.color;n&&(g.clearColor(+n[0]||0,+n[1]||0,+n[2]||0,+n[3]||0),r|=16384),\"depth\"in e&&(g.clearDepth(+e.depth),r|=256),\"stencil\"in e&&(g.clearStencil(0|e.stencil),r|=1024),g.clear(r)}function c(t){return J.push(t),r(),{cancel:function(){var e=j(J,t);J[e]=function t(){var e=j(J,t);J[e]=J[J.length-1],--J.length,0>=J.length&&n()}}}}function u(){var t=X.viewport,e=X.scissor_box;t[0]=t[1]=e[0]=e[1]=0,P.viewportWidth=P.framebufferWidth=P.drawingBufferWidth=t[2]=e[2]=g.drawingBufferWidth,P.viewportHeight=P.framebufferHeight=P.drawingBufferHeight=t[3]=e[3]=g.drawingBufferHeight}function f(){P.tick+=1,P.time=m(),u(),Y.procs.poll()}function h(){u(),Y.procs.refresh(),w&&w.update()}function m(){return(G()-T)/1e3}if(!(t=i(t)))return null;var g=t.gl,v=g.getContextAttributes();g.isContextLost();var y=function(t,e){function r(e){var r;e=e.toLowerCase();try{r=n[e]=t.getExtension(e)}catch(t){}return!!r}for(var n={},i=0;i<e.extensions.length;++i){var a=e.extensions[i];if(!r(a))return e.onDestroy(),e.onDone('\"'+a+'\" extension is not supported by the current WebGL context, try upgrading your system or a different browser'),null}return e.optionalExtensions.forEach(r),{extensions:n,restore:function(){Object.keys(n).forEach((function(t){if(n[t]&&!r(t))throw Error(\"(regl): error restoring extension \"+t)}))}}}(g,t);if(!y)return null;var x=function(){var t={\"\":0},e=[\"\"];return{id:function(r){var n=t[r];return n||(n=t[r]=e.length,e.push(r),n)},str:function(t){return e[t]}}}(),b={vaoCount:0,bufferCount:0,elementsCount:0,framebufferCount:0,shaderCount:0,textureCount:0,cubeCount:0,renderbufferCount:0,maxTextureUnits:0},_=y.extensions,w=function(t,e){function r(){this.endQueryIndex=this.startQueryIndex=-1,this.sum=0,this.stats=null}function n(t,e,n){var i=o.pop()||new r;i.startQueryIndex=t,i.endQueryIndex=e,i.sum=0,i.stats=n,s.push(i)}if(!e.ext_disjoint_timer_query)return null;var i=[],a=[],o=[],s=[],l=[],c=[];return{beginQuery:function(t){var r=i.pop()||e.ext_disjoint_timer_query.createQueryEXT();e.ext_disjoint_timer_query.beginQueryEXT(35007,r),a.push(r),n(a.length-1,a.length,t)},endQuery:function(){e.ext_disjoint_timer_query.endQueryEXT(35007)},pushScopeStats:n,update:function(){var t,r;if(0!==(t=a.length)){c.length=Math.max(c.length,t+1),l.length=Math.max(l.length,t+1),l[0]=0;var n=c[0]=0;for(r=t=0;r<a.length;++r){var u=a[r];e.ext_disjoint_timer_query.getQueryObjectEXT(u,34919)?(n+=e.ext_disjoint_timer_query.getQueryObjectEXT(u,34918),i.push(u)):a[t++]=u,l[r+1]=n,c[r+1]=t}for(a.length=t,r=t=0;r<s.length;++r){var f=(n=s[r]).startQueryIndex;u=n.endQueryIndex;n.sum+=l[u]-l[f],f=c[f],(u=c[u])===f?(n.stats.gpuTime+=n.sum/1e6,o.push(n)):(n.startQueryIndex=f,n.endQueryIndex=u,s[t++]=n)}s.length=t}},getNumPendingQueries:function(){return a.length},clear:function(){i.push.apply(i,a);for(var t=0;t<i.length;t++)e.ext_disjoint_timer_query.deleteQueryEXT(i[t]);a.length=0,i.length=0},restore:function(){a.length=0,i.length=0}}}(0,_),T=G(),A=g.drawingBufferWidth,C=g.drawingBufferHeight,P={tick:0,time:0,viewportWidth:A,viewportHeight:C,framebufferWidth:A,framebufferHeight:C,drawingBufferWidth:A,drawingBufferHeight:C,pixelRatio:t.pixelRatio},I=W(g,_),O=p(g,b,t,(function(t){return z.destroyBuffer(t)})),z=S(g,_,I,b,O),D=d(g,_,O,b),R=E(g,x,b,t),F=k(g,_,I,(function(){Y.procs.poll()}),P,b,t),B=xt(g,_,0,b,t),V=M(g,_,I,F,B,b),Y=N(g,x,_,I,O,D,0,V,{},z,R,{elements:null,primitive:4,count:-1,offset:0,instances:-1},P,w,t),X=(x=L(g,V,Y.procs.poll,P),Y.next),Z=g.canvas,J=[],K=[],Q=[],$=[t.onDestroy],tt=null;Z&&(Z.addEventListener(\"webglcontextlost\",a,!1),Z.addEventListener(\"webglcontextrestored\",o,!1));var et=V.setFBO=s({framebuffer:q.define.call(null,1,\"framebuffer\")});return h(),v=U(s,{clear:function(t){if(\"framebuffer\"in t)if(t.framebuffer&&\"framebufferCube\"===t.framebuffer_reglType)for(var e=0;6>e;++e)et(U({framebuffer:t.framebuffer.faces[e]},t),l);else et(t,l);else l(0,t)},prop:q.define.bind(null,1),context:q.define.bind(null,2),this:q.define.bind(null,3),draw:s({}),buffer:function(t){return O.create(t,34962,!1,!1)},elements:function(t){return D.create(t,!1)},texture:F.create2D,cube:F.createCube,renderbuffer:B.create,framebuffer:V.create,framebufferCube:V.createCube,vao:z.createVAO,attributes:v,frame:c,on:function(t,e){var r;switch(t){case\"frame\":return c(e);case\"lost\":r=K;break;case\"restore\":r=Q;break;case\"destroy\":r=$}return r.push(e),{cancel:function(){for(var t=0;t<r.length;++t)if(r[t]===e){r[t]=r[r.length-1],r.pop();break}}}},limits:I,hasExtension:function(t){return 0<=I.extensions.indexOf(t.toLowerCase())},read:x,destroy:function(){J.length=0,n(),Z&&(Z.removeEventListener(\"webglcontextlost\",a),Z.removeEventListener(\"webglcontextrestored\",o)),R.clear(),V.clear(),B.clear(),F.clear(),D.clear(),O.clear(),z.clear(),w&&w.clear(),$.forEach((function(t){t()}))},_gl:g,_refresh:h,poll:function(){f(),w&&w.update()},now:m,stats:b}),t.onDone(null,v),v}}))},{}],537:[function(t,e,r){\n",
       "/*!\n",
       " * repeat-string <https://github.com/jonschlinkert/repeat-string>\n",
       " *\n",
       " * Copyright (c) 2014-2015, Jon Schlinkert.\n",
       " * Licensed under the MIT License.\n",
       " */\n",
       "\"use strict\";var n,i=\"\";e.exports=function(t,e){if(\"string\"!=typeof t)throw new TypeError(\"expected a string\");if(1===e)return t;if(2===e)return t+t;var r=t.length*e;if(n!==t||void 0===n)n=t,i=\"\";else if(i.length>=r)return i.substr(0,r);for(;r>i.length&&e>1;)1&e&&(i+=t),e>>=1,t+=t;return i=(i+=t).substr(0,r)}},{}],538:[function(t,e,r){(function(t){(function(){e.exports=t.performance&&t.performance.now?function(){return performance.now()}:Date.now||function(){return+new Date}}).call(this)}).call(this,\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{}],539:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=t.length,r=t[t.length-1],n=e,i=e-2;i>=0;--i){var a=r,o=t[i];(l=o-((r=a+o)-a))&&(t[--n]=r,r=l)}var s=0;for(i=n;i<e;++i){var l;a=t[i];(l=(o=r)-((r=a+o)-a))&&(t[s++]=l)}return t[s++]=r,t.length=s,t}},{}],540:[function(t,e,r){\"use strict\";var n=t(\"two-product\"),i=t(\"robust-sum\"),a=t(\"robust-scale\"),o=t(\"robust-compress\");function s(t,e){for(var r=new Array(t.length-1),n=1;n<t.length;++n)for(var i=r[n-1]=new Array(t.length-1),a=0,o=0;a<t.length;++a)a!==e&&(i[o++]=t[n][a]);return r}function l(t){for(var e=new Array(t),r=0;r<t;++r){e[r]=new Array(t);for(var n=0;n<t;++n)e[r][n]=[\"m[\",r,\"][\",n,\"]\"].join(\"\")}return e}function c(t){if(2===t.length)return[\"sum(prod(\",t[0][0],\",\",t[1][1],\"),prod(-\",t[0][1],\",\",t[1][0],\"))\"].join(\"\");for(var e=[],r=0;r<t.length;++r)e.push([\"scale(\",c(s(t,r)),\",\",(n=r,1&n?\"-\":\"\"),t[0][r],\")\"].join(\"\"));return function t(e){if(1===e.length)return e[0];if(2===e.length)return[\"sum(\",e[0],\",\",e[1],\")\"].join(\"\");var r=e.length>>1;return[\"sum(\",t(e.slice(0,r)),\",\",t(e.slice(r)),\")\"].join(\"\")}(e);var n}function u(t){return new Function(\"sum\",\"scale\",\"prod\",\"compress\",[\"function robustDeterminant\",t,\"(m){return compress(\",c(l(t)),\")};return robustDeterminant\",t].join(\"\"))(i,a,n,o)}var f=[function(){return[0]},function(t){return[t[0][0]]}];!function(){for(;f.length<6;)f.push(u(f.length));for(var t=[],r=[\"function robustDeterminant(m){switch(m.length){\"],n=0;n<6;++n)t.push(\"det\"+n),r.push(\"case \",n,\":return det\",n,\"(m);\");r.push(\"}var det=CACHE[m.length];if(!det)det=CACHE[m.length]=gen(m.length);return det(m);}return robustDeterminant\"),t.push(\"CACHE\",\"gen\",r.join(\"\"));var i=Function.apply(void 0,t);for(e.exports=i.apply(void 0,f.concat([f,u])),n=0;n<f.length;++n)e.exports[n]=f[n]}()},{\"robust-compress\":539,\"robust-scale\":546,\"robust-sum\":549,\"two-product\":600}],541:[function(t,e,r){\"use strict\";var n=t(\"two-product\"),i=t(\"robust-sum\");e.exports=function(t,e){for(var r=n(t[0],e[0]),a=1;a<t.length;++a)r=i(r,n(t[a],e[a]));return r}},{\"robust-sum\":549,\"two-product\":600}],542:[function(t,e,r){\"use strict\";var n=t(\"two-product\"),i=t(\"robust-sum\"),a=t(\"robust-subtract\"),o=t(\"robust-scale\");function s(t,e){for(var r=new Array(t.length-1),n=1;n<t.length;++n)for(var i=r[n-1]=new Array(t.length-1),a=0,o=0;a<t.length;++a)a!==e&&(i[o++]=t[n][a]);return r}function l(t){if(1===t.length)return t[0];if(2===t.length)return[\"sum(\",t[0],\",\",t[1],\")\"].join(\"\");var e=t.length>>1;return[\"sum(\",l(t.slice(0,e)),\",\",l(t.slice(e)),\")\"].join(\"\")}function c(t,e){if(\"m\"===t.charAt(0)){if(\"w\"===e.charAt(0)){var r=t.split(\"[\");return[\"w\",e.substr(1),\"m\",r[0].substr(1)].join(\"\")}return[\"prod(\",t,\",\",e,\")\"].join(\"\")}return c(e,t)}function u(t){if(2===t.length)return[[\"diff(\",c(t[0][0],t[1][1]),\",\",c(t[1][0],t[0][1]),\")\"].join(\"\")];for(var e=[],r=0;r<t.length;++r)e.push([\"scale(\",l(u(s(t,r))),\",\",(n=r,!0&n?\"-\":\"\"),t[0][r],\")\"].join(\"\"));return e;var n}function f(t,e){for(var r=[],n=0;n<e-2;++n)r.push([\"prod(m\",t,\"[\",n,\"],m\",t,\"[\",n,\"])\"].join(\"\"));return l(r)}function h(t){for(var e=[],r=[],c=function(t){for(var e=new Array(t),r=0;r<t;++r){e[r]=new Array(t);for(var n=0;n<t;++n)e[r][n]=[\"m\",n,\"[\",t-r-2,\"]\"].join(\"\")}return e}(t),h=0;h<t;++h)c[0][h]=\"1\",c[t-1][h]=\"w\"+h;for(h=0;h<t;++h)0==(1&h)?e.push.apply(e,u(s(c,h))):r.push.apply(r,u(s(c,h)));var p=l(e),d=l(r),m=\"exactInSphere\"+t,g=[];for(h=0;h<t;++h)g.push(\"m\"+h);var v=[\"function \",m,\"(\",g.join(),\"){\"];for(h=0;h<t;++h){v.push(\"var w\",h,\"=\",f(h,t),\";\");for(var y=0;y<t;++y)y!==h&&v.push(\"var w\",h,\"m\",y,\"=scale(w\",h,\",m\",y,\"[0]);\")}return v.push(\"var p=\",p,\",n=\",d,\",d=diff(p,n);return d[d.length-1];}return \",m),new Function(\"sum\",\"diff\",\"prod\",\"scale\",v.join(\"\"))(i,a,n,o)}var p=[function(){return 0},function(){return 0},function(){return 0}];function d(t){var e=p[t.length];return e||(e=p[t.length]=h(t.length)),e.apply(void 0,t)}!function(){for(;p.length<=6;)p.push(h(p.length));for(var t=[],r=[\"slow\"],n=0;n<=6;++n)t.push(\"a\"+n),r.push(\"o\"+n);var i=[\"function testInSphere(\",t.join(),\"){switch(arguments.length){case 0:case 1:return 0;\"];for(n=2;n<=6;++n)i.push(\"case \",n,\":return o\",n,\"(\",t.slice(0,n).join(),\");\");i.push(\"}var s=new Array(arguments.length);for(var i=0;i<arguments.length;++i){s[i]=arguments[i]};return slow(s);}return testInSphere\"),r.push(i.join(\"\"));var a=Function.apply(void 0,r);for(e.exports=a.apply(void 0,[d].concat(p)),n=0;n<=6;++n)e.exports[n]=p[n]}()},{\"robust-scale\":546,\"robust-subtract\":548,\"robust-sum\":549,\"two-product\":600}],543:[function(t,e,r){\"use strict\";var n=t(\"robust-determinant\");function i(t){for(var e=\"robustLinearSolve\"+t+\"d\",r=[\"function \",e,\"(A,b){return [\"],i=0;i<t;++i){r.push(\"det([\");for(var a=0;a<t;++a){a>0&&r.push(\",\"),r.push(\"[\");for(var o=0;o<t;++o)o>0&&r.push(\",\"),o===i?r.push(\"+b[\",a,\"]\"):r.push(\"+A[\",a,\"][\",o,\"]\");r.push(\"]\")}r.push(\"]),\")}r.push(\"det(A)]}return \",e);var s=new Function(\"det\",r.join(\"\"));return s(t<6?n[t]:n)}var a=[function(){return[0]},function(t,e){return[[e[0]],[t[0][0]]]}];!function(){for(;a.length<6;)a.push(i(a.length));for(var t=[],r=[\"function dispatchLinearSolve(A,b){switch(A.length){\"],n=0;n<6;++n)t.push(\"s\"+n),r.push(\"case \",n,\":return s\",n,\"(A,b);\");r.push(\"}var s=CACHE[A.length];if(!s)s=CACHE[A.length]=g(A.length);return s(A,b)}return dispatchLinearSolve\"),t.push(\"CACHE\",\"g\",r.join(\"\"));var o=Function.apply(void 0,t);for(e.exports=o.apply(void 0,a.concat([a,i])),n=0;n<6;++n)e.exports[n]=a[n]}()},{\"robust-determinant\":540}],544:[function(t,e,r){\"use strict\";var n=t(\"two-product\"),i=t(\"robust-sum\"),a=t(\"robust-scale\"),o=t(\"robust-subtract\");function s(t,e){for(var r=new Array(t.length-1),n=1;n<t.length;++n)for(var i=r[n-1]=new Array(t.length-1),a=0,o=0;a<t.length;++a)a!==e&&(i[o++]=t[n][a]);return r}function l(t){if(1===t.length)return t[0];if(2===t.length)return[\"sum(\",t[0],\",\",t[1],\")\"].join(\"\");var e=t.length>>1;return[\"sum(\",l(t.slice(0,e)),\",\",l(t.slice(e)),\")\"].join(\"\")}function c(t){if(2===t.length)return[[\"sum(prod(\",t[0][0],\",\",t[1][1],\"),prod(-\",t[0][1],\",\",t[1][0],\"))\"].join(\"\")];for(var e=[],r=0;r<t.length;++r)e.push([\"scale(\",l(c(s(t,r))),\",\",(n=r,1&n?\"-\":\"\"),t[0][r],\")\"].join(\"\"));return e;var n}function u(t){for(var e=[],r=[],u=function(t){for(var e=new Array(t),r=0;r<t;++r){e[r]=new Array(t);for(var n=0;n<t;++n)e[r][n]=[\"m\",n,\"[\",t-r-1,\"]\"].join(\"\")}return e}(t),f=[],h=0;h<t;++h)0==(1&h)?e.push.apply(e,c(s(u,h))):r.push.apply(r,c(s(u,h))),f.push(\"m\"+h);var p=l(e),d=l(r),m=\"orientation\"+t+\"Exact\",g=[\"function \",m,\"(\",f.join(),\"){var p=\",p,\",n=\",d,\",d=sub(p,n);return d[d.length-1];};return \",m].join(\"\");return new Function(\"sum\",\"prod\",\"scale\",\"sub\",g)(i,n,a,o)}var f=u(3),h=u(4),p=[function(){return 0},function(){return 0},function(t,e){return e[0]-t[0]},function(t,e,r){var n,i=(t[1]-r[1])*(e[0]-r[0]),a=(t[0]-r[0])*(e[1]-r[1]),o=i-a;if(i>0){if(a<=0)return o;n=i+a}else{if(!(i<0))return o;if(a>=0)return o;n=-(i+a)}var s=33306690738754716e-32*n;return o>=s||o<=-s?o:f(t,e,r)},function(t,e,r,n){var i=t[0]-n[0],a=e[0]-n[0],o=r[0]-n[0],s=t[1]-n[1],l=e[1]-n[1],c=r[1]-n[1],u=t[2]-n[2],f=e[2]-n[2],p=r[2]-n[2],d=a*c,m=o*l,g=o*s,v=i*c,y=i*l,x=a*s,b=u*(d-m)+f*(g-v)+p*(y-x),_=7771561172376103e-31*((Math.abs(d)+Math.abs(m))*Math.abs(u)+(Math.abs(g)+Math.abs(v))*Math.abs(f)+(Math.abs(y)+Math.abs(x))*Math.abs(p));return b>_||-b>_?b:h(t,e,r,n)}];function d(t){var e=p[t.length];return e||(e=p[t.length]=u(t.length)),e.apply(void 0,t)}!function(){for(;p.length<=5;)p.push(u(p.length));for(var t=[],r=[\"slow\"],n=0;n<=5;++n)t.push(\"a\"+n),r.push(\"o\"+n);var i=[\"function getOrientation(\",t.join(),\"){switch(arguments.length){case 0:case 1:return 0;\"];for(n=2;n<=5;++n)i.push(\"case \",n,\":return o\",n,\"(\",t.slice(0,n).join(),\");\");i.push(\"}var s=new Array(arguments.length);for(var i=0;i<arguments.length;++i){s[i]=arguments[i]};return slow(s);}return getOrientation\"),r.push(i.join(\"\"));var a=Function.apply(void 0,r);for(e.exports=a.apply(void 0,[d].concat(p)),n=0;n<=5;++n)e.exports[n]=p[n]}()},{\"robust-scale\":546,\"robust-subtract\":548,\"robust-sum\":549,\"two-product\":600}],545:[function(t,e,r){\"use strict\";var n=t(\"robust-sum\"),i=t(\"robust-scale\");e.exports=function(t,e){if(1===t.length)return i(e,t[0]);if(1===e.length)return i(t,e[0]);if(0===t.length||0===e.length)return[0];var r=[0];if(t.length<e.length)for(var a=0;a<t.length;++a)r=n(r,i(e,t[a]));else for(a=0;a<e.length;++a)r=n(r,i(t,e[a]));return r}},{\"robust-scale\":546,\"robust-sum\":549}],546:[function(t,e,r){\"use strict\";var n=t(\"two-product\"),i=t(\"two-sum\");e.exports=function(t,e){var r=t.length;if(1===r){var a=n(t[0],e);return a[0]?a:[a[1]]}var o=new Array(2*r),s=[.1,.1],l=[.1,.1],c=0;n(t[0],e,s),s[0]&&(o[c++]=s[0]);for(var u=1;u<r;++u){n(t[u],e,l);var f=s[1];i(f,l[0],s),s[0]&&(o[c++]=s[0]);var h=l[1],p=s[1],d=h+p,m=p-(d-h);s[1]=d,m&&(o[c++]=m)}s[1]&&(o[c++]=s[1]);0===c&&(o[c++]=0);return o.length=c,o}},{\"two-product\":600,\"two-sum\":601}],547:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,i){var a=n(t,r,i),o=n(e,r,i);if(a>0&&o>0||a<0&&o<0)return!1;var s=n(r,t,e),l=n(i,t,e);if(s>0&&l>0||s<0&&l<0)return!1;if(0===a&&0===o&&0===s&&0===l)return function(t,e,r,n){for(var i=0;i<2;++i){var a=t[i],o=e[i],s=Math.min(a,o),l=Math.max(a,o),c=r[i],u=n[i],f=Math.min(c,u);if(Math.max(c,u)<s||l<f)return!1}return!0}(t,e,r,i);return!0};var n=t(\"robust-orientation\")[3]},{\"robust-orientation\":544}],548:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=0|t.length,n=0|e.length;if(1===r&&1===n)return function(t,e){var r=t+e,n=r-t,i=t-(r-n)+(e-n);if(i)return[i,r];return[r]}(t[0],-e[0]);var i,a,o=new Array(r+n),s=0,l=0,c=0,u=Math.abs,f=t[l],h=u(f),p=-e[c],d=u(p);h<d?(a=f,(l+=1)<r&&(f=t[l],h=u(f))):(a=p,(c+=1)<n&&(p=-e[c],d=u(p)));l<r&&h<d||c>=n?(i=f,(l+=1)<r&&(f=t[l],h=u(f))):(i=p,(c+=1)<n&&(p=-e[c],d=u(p)));var m,g,v=i+a,y=v-i,x=a-y,b=x,_=v;for(;l<r&&c<n;)h<d?(i=f,(l+=1)<r&&(f=t[l],h=u(f))):(i=p,(c+=1)<n&&(p=-e[c],d=u(p))),(x=(a=b)-(y=(v=i+a)-i))&&(o[s++]=x),b=_-((m=_+v)-(g=m-_))+(v-g),_=m;for(;l<r;)(x=(a=b)-(y=(v=(i=f)+a)-i))&&(o[s++]=x),b=_-((m=_+v)-(g=m-_))+(v-g),_=m,(l+=1)<r&&(f=t[l]);for(;c<n;)(x=(a=b)-(y=(v=(i=p)+a)-i))&&(o[s++]=x),b=_-((m=_+v)-(g=m-_))+(v-g),_=m,(c+=1)<n&&(p=-e[c]);b&&(o[s++]=b);_&&(o[s++]=_);s||(o[s++]=0);return o.length=s,o}},{}],549:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=0|t.length,n=0|e.length;if(1===r&&1===n)return function(t,e){var r=t+e,n=r-t,i=t-(r-n)+(e-n);if(i)return[i,r];return[r]}(t[0],e[0]);var i,a,o=new Array(r+n),s=0,l=0,c=0,u=Math.abs,f=t[l],h=u(f),p=e[c],d=u(p);h<d?(a=f,(l+=1)<r&&(f=t[l],h=u(f))):(a=p,(c+=1)<n&&(p=e[c],d=u(p)));l<r&&h<d||c>=n?(i=f,(l+=1)<r&&(f=t[l],h=u(f))):(i=p,(c+=1)<n&&(p=e[c],d=u(p)));var m,g,v=i+a,y=v-i,x=a-y,b=x,_=v;for(;l<r&&c<n;)h<d?(i=f,(l+=1)<r&&(f=t[l],h=u(f))):(i=p,(c+=1)<n&&(p=e[c],d=u(p))),(x=(a=b)-(y=(v=i+a)-i))&&(o[s++]=x),b=_-((m=_+v)-(g=m-_))+(v-g),_=m;for(;l<r;)(x=(a=b)-(y=(v=(i=f)+a)-i))&&(o[s++]=x),b=_-((m=_+v)-(g=m-_))+(v-g),_=m,(l+=1)<r&&(f=t[l]);for(;c<n;)(x=(a=b)-(y=(v=(i=p)+a)-i))&&(o[s++]=x),b=_-((m=_+v)-(g=m-_))+(v-g),_=m,(c+=1)<n&&(p=e[c]);b&&(o[s++]=b);_&&(o[s++]=_);s||(o[s++]=0);return o.length=s,o}},{}],550:[function(t,e,r){var n=t(\"buffer\"),i=n.Buffer;function a(t,e){for(var r in t)e[r]=t[r]}function o(t,e,r){return i(t,e,r)}i.from&&i.alloc&&i.allocUnsafe&&i.allocUnsafeSlow?e.exports=n:(a(n,r),r.Buffer=o),o.prototype=Object.create(i.prototype),a(i,o),o.from=function(t,e,r){if(\"number\"==typeof t)throw new TypeError(\"Argument must not be a number\");return i(t,e,r)},o.alloc=function(t,e,r){if(\"number\"!=typeof t)throw new TypeError(\"Argument must be a number\");var n=i(t);return void 0!==e?\"string\"==typeof r?n.fill(e,r):n.fill(e):n.fill(0),n},o.allocUnsafe=function(t){if(\"number\"!=typeof t)throw new TypeError(\"Argument must be a number\");return i(t)},o.allocUnsafeSlow=function(t){if(\"number\"!=typeof t)throw new TypeError(\"Argument must be a number\");return n.SlowBuffer(t)}},{buffer:117}],551:[function(t,e,r){\"use strict\";e.exports=function(t){return t<0?-1:t>0?1:0}},{}],552:[function(t,e,r){\"use strict\";e.exports=function(t){return i(n(t))};var n=t(\"boundary-cells\"),i=t(\"reduce-simplicial-complex\")},{\"boundary-cells\":107,\"reduce-simplicial-complex\":531}],553:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,s){r=r||0,void 0===s&&(s=function(t){for(var e=t.length,r=0,n=0;n<e;++n)r=0|Math.max(r,t[n].length);return r-1}(t));if(0===t.length||s<1)return{cells:[],vertexIds:[],vertexWeights:[]};var l=function(t,e){for(var r=t.length,n=i.mallocUint8(r),a=0;a<r;++a)n[a]=t[a]<e|0;return n}(e,+r),c=function(t,e){for(var r=t.length,o=e*(e+1)/2*r|0,s=i.mallocUint32(2*o),l=0,c=0;c<r;++c)for(var u=t[c],f=(e=u.length,0);f<e;++f)for(var h=0;h<f;++h){var p=u[h],d=u[f];s[l++]=0|Math.min(p,d),s[l++]=0|Math.max(p,d)}a(n(s,[l/2|0,2]));var m=2;for(c=2;c<l;c+=2)s[c-2]===s[c]&&s[c-1]===s[c+1]||(s[m++]=s[c],s[m++]=s[c+1]);return n(s,[m/2|0,2])}(t,s),u=function(t,e,r,a){for(var o=t.data,s=t.shape[0],l=i.mallocDouble(s),c=0,u=0;u<s;++u){var f=o[2*u],h=o[2*u+1];if(r[f]!==r[h]){var p=e[f],d=e[h];o[2*c]=f,o[2*c+1]=h,l[c++]=(d-a)/(d-p)}}return t.shape[0]=c,n(l,[c])}(c,e,l,+r),f=function(t,e){var r=i.mallocInt32(2*e),n=t.shape[0],a=t.data;r[0]=0;for(var o=0,s=0;s<n;++s){var l=a[2*s];if(l!==o){for(r[2*o+1]=s;++o<l;)r[2*o]=s,r[2*o+1]=s;r[2*o]=s}}r[2*o+1]=n;for(;++o<e;)r[2*o]=r[2*o+1]=n;return r}(c,0|e.length),h=o(s)(t,c.data,f,l),p=function(t){for(var e=0|t.shape[0],r=t.data,n=new Array(e),i=0;i<e;++i)n[i]=[r[2*i],r[2*i+1]];return n}(c),d=[].slice.call(u.data,0,u.shape[0]);return i.free(l),i.free(c.data),i.free(u.data),i.free(f),{cells:h,vertexIds:p,vertexWeights:d}};var n=t(\"ndarray\"),i=t(\"typedarray-pool\"),a=t(\"ndarray-sort\"),o=t(\"./lib/codegen\")},{\"./lib/codegen\":554,ndarray:479,\"ndarray-sort\":478,\"typedarray-pool\":613}],554:[function(t,e,r){\"use strict\";e.exports=function(t){var e=a[t];e||(e=a[t]=function(t){var e=0,r=new Array(t+1);r[0]=[[]];for(var a=1;a<=t;++a)for(var o=r[a]=i(a),s=0;s<o.length;++s)e=Math.max(e,o[a].length);var l=[\"function B(C,E,i,j){\",\"var a=Math.min(i,j)|0,b=Math.max(i,j)|0,l=C[2*a],h=C[2*a+1];\",\"while(l<h){\",\"var m=(l+h)>>1,v=E[2*m+1];\",\"if(v===b){return m}\",\"if(b<v){h=m}else{l=m+1}\",\"}\",\"return l;\",\"};\",\"function getContour\",t,\"d(F,E,C,S){\",\"var n=F.length,R=[];\",\"for(var i=0;i<n;++i){var c=F[i],l=c.length;\"];function c(t){if(!(t.length<=0)){l.push(\"R.push(\");for(var e=0;e<t.length;++e){var r=t[e];e>0&&l.push(\",\"),l.push(\"[\");for(var n=0;n<r.length;++n){var i=r[n];n>0&&l.push(\",\"),l.push(\"B(C,E,c[\",i[0],\"],c[\",i[1],\"])\")}l.push(\"]\")}l.push(\");\")}}for(a=t+1;a>1;--a){a<t+1&&l.push(\"else \"),l.push(\"if(l===\",a,\"){\");var u=[];for(s=0;s<a;++s)u.push(\"(S[c[\"+s+\"]]<<\"+s+\")\");l.push(\"var M=\",u.join(\"+\"),\";if(M===0||M===\",(1<<a)-1,\"){continue}switch(M){\");for(o=r[a-1],s=0;s<o.length;++s)l.push(\"case \",s,\":\"),c(o[s]),l.push(\"break;\");l.push(\"}}\")}return l.push(\"}return R;};return getContour\",t,\"d\"),new Function(\"pool\",l.join(\"\"))(n)}(t));return e};var n=t(\"typedarray-pool\"),i=t(\"marching-simplex-table\"),a={}},{\"marching-simplex-table\":458,\"typedarray-pool\":613}],555:[function(t,e,r){\"use strict\";var n=t(\"bit-twiddle\"),i=t(\"union-find\");function a(t,e){var r=t.length,n=t.length-e.length,i=Math.min;if(n)return n;switch(r){case 0:return 0;case 1:return t[0]-e[0];case 2:return(s=t[0]+t[1]-e[0]-e[1])||i(t[0],t[1])-i(e[0],e[1]);case 3:var a=t[0]+t[1],o=e[0]+e[1];if(s=a+t[2]-(o+e[2]))return s;var s,l=i(t[0],t[1]),c=i(e[0],e[1]);return(s=i(l,t[2])-i(c,e[2]))||i(l+t[2],a)-i(c+e[2],o);default:var u=t.slice(0);u.sort();var f=e.slice(0);f.sort();for(var h=0;h<r;++h)if(n=u[h]-f[h])return n;return 0}}function o(t,e){return a(t[0],e[0])}function s(t,e){if(e){for(var r=t.length,n=new Array(r),i=0;i<r;++i)n[i]=[t[i],e[i]];n.sort(o);for(i=0;i<r;++i)t[i]=n[i][0],e[i]=n[i][1];return t}return t.sort(a),t}function l(t){if(0===t.length)return[];for(var e=1,r=t.length,n=1;n<r;++n){var i=t[n];if(a(i,t[n-1])){if(n===e){e++;continue}t[e++]=i}}return t.length=e,t}function c(t,e){for(var r=0,n=t.length-1,i=-1;r<=n;){var o=r+n>>1,s=a(t[o],e);s<=0?(0===s&&(i=o),r=o+1):s>0&&(n=o-1)}return i}function u(t,e){for(var r=new Array(t.length),i=0,o=r.length;i<o;++i)r[i]=[];for(var s=[],l=(i=0,e.length);i<l;++i)for(var u=e[i],f=u.length,h=1,p=1<<f;h<p;++h){s.length=n.popCount(h);for(var d=0,m=0;m<f;++m)h&1<<m&&(s[d++]=u[m]);var g=c(t,s);if(!(g<0))for(;r[g++].push(i),!(g>=t.length||0!==a(t[g],s)););}return r}function f(t,e){if(e<0)return[];for(var r=[],i=(1<<e+1)-1,a=0;a<t.length;++a)for(var o=t[a],l=i;l<1<<o.length;l=n.nextCombination(l)){for(var c=new Array(e+1),u=0,f=0;f<o.length;++f)l&1<<f&&(c[u++]=o[f]);r.push(c)}return s(r)}r.dimension=function(t){for(var e=0,r=Math.max,n=0,i=t.length;n<i;++n)e=r(e,t[n].length);return e-1},r.countVertices=function(t){for(var e=-1,r=Math.max,n=0,i=t.length;n<i;++n)for(var a=t[n],o=0,s=a.length;o<s;++o)e=r(e,a[o]);return e+1},r.cloneCells=function(t){for(var e=new Array(t.length),r=0,n=t.length;r<n;++r)e[r]=t[r].slice(0);return e},r.compareCells=a,r.normalize=s,r.unique=l,r.findCell=c,r.incidence=u,r.dual=function(t,e){if(!e)return u(l(f(t,0)),t);for(var r=new Array(e),n=0;n<e;++n)r[n]=[];n=0;for(var i=t.length;n<i;++n)for(var a=t[n],o=0,s=a.length;o<s;++o)r[a[o]].push(n);return r},r.explode=function(t){for(var e=[],r=0,n=t.length;r<n;++r)for(var i=t[r],a=0|i.length,o=1,l=1<<a;o<l;++o){for(var c=[],u=0;u<a;++u)o>>>u&1&&c.push(i[u]);e.push(c)}return s(e)},r.skeleton=f,r.boundary=function(t){for(var e=[],r=0,n=t.length;r<n;++r)for(var i=t[r],a=0,o=i.length;a<o;++a){for(var l=new Array(i.length-1),c=0,u=0;c<o;++c)c!==a&&(l[u++]=i[c]);e.push(l)}return s(e)},r.connectedComponents=function(t,e){return e?function(t,e){for(var r=new i(e),n=0;n<t.length;++n)for(var a=t[n],o=0;o<a.length;++o)for(var s=o+1;s<a.length;++s)r.link(a[o],a[s]);var l=[],c=r.ranks;for(n=0;n<c.length;++n)c[n]=-1;for(n=0;n<t.length;++n){var u=r.find(t[n][0]);c[u]<0?(c[u]=l.length,l.push([t[n].slice(0)])):l[c[u]].push(t[n].slice(0))}return l}(t,e):function(t){for(var e=l(s(f(t,0))),r=new i(e.length),n=0;n<t.length;++n)for(var a=t[n],o=0;o<a.length;++o)for(var u=c(e,[a[o]]),h=o+1;h<a.length;++h)r.link(u,c(e,[a[h]]));var p=[],d=r.ranks;for(n=0;n<d.length;++n)d[n]=-1;for(n=0;n<t.length;++n){var m=r.find(c(e,[t[n][0]]));d[m]<0?(d[m]=p.length,p.push([t[n].slice(0)])):p[d[m]].push(t[n].slice(0))}return p}(t)}},{\"bit-twiddle\":104,\"union-find\":614}],556:[function(t,e,r){arguments[4][104][0].apply(r,arguments)},{dup:104}],557:[function(t,e,r){arguments[4][555][0].apply(r,arguments)},{\"bit-twiddle\":556,dup:555,\"union-find\":558}],558:[function(t,e,r){\"use strict\";function n(t){this.roots=new Array(t),this.ranks=new Array(t);for(var e=0;e<t;++e)this.roots[e]=e,this.ranks[e]=0}e.exports=n,n.prototype.length=function(){return this.roots.length},n.prototype.makeSet=function(){var t=this.roots.length;return this.roots.push(t),this.ranks.push(0),t},n.prototype.find=function(t){for(var e=this.roots;e[t]!==t;){var r=e[t];e[t]=e[r],t=r}return t},n.prototype.link=function(t,e){var r=this.find(t),n=this.find(e);if(r!==n){var i=this.ranks,a=this.roots,o=i[r],s=i[n];o<s?a[r]=n:s<o?a[n]=r:(a[n]=r,++i[r])}}},{}],559:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){for(var a=e.length,o=t.length,s=new Array(a),l=new Array(a),c=new Array(a),u=new Array(a),f=0;f<a;++f)s[f]=l[f]=-1,c[f]=1/0,u[f]=!1;for(f=0;f<o;++f){var h=t[f];if(2!==h.length)throw new Error(\"Input must be a graph\");var p=h[1],d=h[0];-1!==l[d]?l[d]=-2:l[d]=p,-1!==s[p]?s[p]=-2:s[p]=d}function m(t){if(u[t])return 1/0;var r,i,a,o,c,f=s[t],h=l[t];return f<0||h<0?1/0:(r=e[t],i=e[f],a=e[h],o=Math.abs(n(r,i,a)),c=Math.sqrt(Math.pow(i[0]-a[0],2)+Math.pow(i[1]-a[1],2)),o/c)}function g(t,e){var r=k[t],n=k[e];k[t]=n,k[e]=r,M[r]=e,M[n]=t}function v(t){return c[k[t]]}function y(t){return 1&t?t-1>>1:(t>>1)-1}function x(t){for(var e=v(t);;){var r=e,n=2*t+1,i=2*(t+1),a=t;if(n<A){var o=v(n);o<r&&(a=n,r=o)}if(i<A)v(i)<r&&(a=i);if(a===t)return t;g(t,a),t=a}}function b(t){for(var e=v(t);t>0;){var r=y(t);if(r>=0)if(e<v(r)){g(t,r),t=r;continue}return t}}function _(){if(A>0){var t=k[0];return g(0,A-1),A-=1,x(0),t}return-1}function w(t,e){var r=k[t];return c[r]===e?t:(c[r]=-1/0,b(t),_(),c[r]=e,b((A+=1)-1))}function T(t){if(!u[t]){u[t]=!0;var e=s[t],r=l[t];s[r]>=0&&(s[r]=e),l[e]>=0&&(l[e]=r),M[e]>=0&&w(M[e],m(e)),M[r]>=0&&w(M[r],m(r))}}var k=[],M=new Array(a);for(f=0;f<a;++f){(c[f]=m(f))<1/0?(M[f]=k.length,k.push(f)):M[f]=-1}var A=k.length;for(f=A>>1;f>=0;--f)x(f);for(;;){var S=_();if(S<0||c[S]>r)break;T(S)}var E=[];for(f=0;f<a;++f)u[f]||(M[f]=E.length,E.push(e[f].slice()));E.length;function L(t,e){if(t[e]<0)return e;var r=e,n=e;do{var i=t[n];if(!u[n]||i<0||i===n)break;if(i=t[n=i],!u[n]||i<0||i===n)break;n=i,r=t[r]}while(r!==n);for(var a=e;a!==n;a=t[a])t[a]=n;return n}var C=[];return t.forEach((function(t){var e=L(s,t[0]),r=L(l,t[1]);if(e>=0&&r>=0&&e!==r){var n=M[e],i=M[r];n!==i&&C.push([n,i])}})),i.unique(i.normalize(C)),{positions:E,edges:C}};var n=t(\"robust-orientation\"),i=t(\"simplicial-complex\")},{\"robust-orientation\":544,\"simplicial-complex\":557}],560:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r,a,o,s;if(e[0][0]<e[1][0])r=e[0],a=e[1];else{if(!(e[0][0]>e[1][0]))return i(e,t);r=e[1],a=e[0]}if(t[0][0]<t[1][0])o=t[0],s=t[1];else{if(!(t[0][0]>t[1][0]))return-i(t,e);o=t[1],s=t[0]}var l=n(r,a,s),c=n(r,a,o);if(l<0){if(c<=0)return l}else if(l>0){if(c>=0)return l}else if(c)return c;if(l=n(s,o,a),c=n(s,o,r),l<0){if(c<=0)return l}else if(l>0){if(c>=0)return l}else if(c)return c;return a[0]-s[0]};var n=t(\"robust-orientation\");function i(t,e){var r,i,a,o;if(e[0][0]<e[1][0])r=e[0],i=e[1];else{if(!(e[0][0]>e[1][0])){var s=Math.min(t[0][1],t[1][1]),l=Math.max(t[0][1],t[1][1]),c=Math.min(e[0][1],e[1][1]),u=Math.max(e[0][1],e[1][1]);return l<c?l-c:s>u?s-u:l-u}r=e[1],i=e[0]}t[0][1]<t[1][1]?(a=t[0],o=t[1]):(a=t[1],o=t[0]);var f=n(i,r,a);return f||((f=n(i,r,o))||o-i)}},{\"robust-orientation\":544}],561:[function(t,e,r){arguments[4][247][0].apply(r,arguments)},{dup:247}],562:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=t.length,r=2*e,n=new Array(r),a=0;a<e;++a){var l=t[a],c=l[0][0]<l[1][0];n[2*a]=new f(l[0][0],l,c,a),n[2*a+1]=new f(l[1][0],l,!c,a)}n.sort((function(t,e){var r=t.x-e.x;return r||((r=t.create-e.create)||Math.min(t.segment[0][1],t.segment[1][1])-Math.min(e.segment[0][1],e.segment[1][1]))}));var h=i(o),p=[],d=[],m=[];for(a=0;a<r;){for(var g=n[a].x,v=[];a<r;){var y=n[a];if(y.x!==g)break;a+=1,y.segment[0][0]===y.x&&y.segment[1][0]===y.x?y.create&&(y.segment[0][1]<y.segment[1][1]?(v.push(new u(y.segment[0][1],y.index,!0,!0)),v.push(new u(y.segment[1][1],y.index,!1,!1))):(v.push(new u(y.segment[1][1],y.index,!0,!1)),v.push(new u(y.segment[0][1],y.index,!1,!0)))):h=y.create?h.insert(y.segment,y.index):h.remove(y.segment)}p.push(h.root),d.push(g),m.push(v)}return new s(p,d,m)};var n=t(\"binary-search-bounds\"),i=t(\"functional-red-black-tree\"),a=t(\"robust-orientation\"),o=t(\"./lib/order-segments\");function s(t,e,r){this.slabs=t,this.coordinates=e,this.horizontal=r}function l(t,e){return t.y-e}function c(t,e){for(var r=null;t;){var n,i,o=t.key;o[0][0]<o[1][0]?(n=o[0],i=o[1]):(n=o[1],i=o[0]);var s=a(n,i,e);if(s<0)t=t.left;else if(s>0)if(e[0]!==o[1][0])r=t,t=t.right;else{if(l=c(t.right,e))return l;t=t.left}else{if(e[0]!==o[1][0])return t;var l;if(l=c(t.right,e))return l;t=t.left}}return r}function u(t,e,r,n){this.y=t,this.index=e,this.start=r,this.closed=n}function f(t,e,r,n){this.x=t,this.segment=e,this.create=r,this.index=n}s.prototype.castUp=function(t){var e=n.le(this.coordinates,t[0]);if(e<0)return-1;this.slabs[e];var r=c(this.slabs[e],t),i=-1;if(r&&(i=r.value),this.coordinates[e]===t[0]){var s=null;if(r&&(s=r.key),e>0){var u=c(this.slabs[e-1],t);u&&(s?o(u.key,s)>0&&(s=u.key,i=u.value):(i=u.value,s=u.key))}var f=this.horizontal[e];if(f.length>0){var h=n.ge(f,t[1],l);if(h<f.length){var p=f[h];if(t[1]===p.y){if(p.closed)return p.index;for(;h<f.length-1&&f[h+1].y===t[1];)if((p=f[h+=1]).closed)return p.index;if(p.y===t[1]&&!p.start){if((h+=1)>=f.length)return i;p=f[h]}}if(p.start)if(s){var d=a(s[0],s[1],[t[0],p.y]);s[0][0]>s[1][0]&&(d=-d),d>0&&(i=p.index)}else i=p.index;else p.y!==t[1]&&(i=p.index)}}}return i}},{\"./lib/order-segments\":560,\"binary-search-bounds\":561,\"functional-red-black-tree\":251,\"robust-orientation\":544}],563:[function(t,e,r){\"use strict\";var n=t(\"robust-dot-product\"),i=t(\"robust-sum\");function a(t,e){var r=i(n(t,e),[e[e.length-1]]);return r[r.length-1]}function o(t,e,r,n){var i=-e/(n-e);i<0?i=0:i>1&&(i=1);for(var a=1-i,o=t.length,s=new Array(o),l=0;l<o;++l)s[l]=i*t[l]+a*r[l];return s}e.exports=function(t,e){for(var r=[],n=[],i=a(t[t.length-1],e),s=t[t.length-1],l=t[0],c=0;c<t.length;++c,s=l){var u=a(l=t[c],e);if(i<0&&u>0||i>0&&u<0){var f=o(s,u,l,i);r.push(f),n.push(f.slice())}u<0?n.push(l.slice()):u>0?r.push(l.slice()):(r.push(l.slice()),n.push(l.slice())),i=u}return{positive:r,negative:n}},e.exports.positive=function(t,e){for(var r=[],n=a(t[t.length-1],e),i=t[t.length-1],s=t[0],l=0;l<t.length;++l,i=s){var c=a(s=t[l],e);(n<0&&c>0||n>0&&c<0)&&r.push(o(i,c,s,n)),c>=0&&r.push(s.slice()),n=c}return r},e.exports.negative=function(t,e){for(var r=[],n=a(t[t.length-1],e),i=t[t.length-1],s=t[0],l=0;l<t.length;++l,i=s){var c=a(s=t[l],e);(n<0&&c>0||n>0&&c<0)&&r.push(o(i,c,s,n)),c<=0&&r.push(s.slice()),n=c}return r}},{\"robust-dot-product\":541,\"robust-sum\":549}],564:[function(t,e,r){!function(){\"use strict\";var t={not_string:/[^s]/,not_bool:/[^t]/,not_type:/[^T]/,not_primitive:/[^v]/,number:/[diefg]/,numeric_arg:/[bcdiefguxX]/,json:/[j]/,not_json:/[^j]/,text:/^[^\\x25]+/,modulo:/^\\x25{2}/,placeholder:/^\\x25(?:([1-9]\\d*)\\$|\\(([^)]+)\\))?(\\+)?(0|'[^$])?(-)?(\\d+)?(?:\\.(\\d+))?([b-gijostTuvxX])/,key:/^([a-z_][a-z_\\d]*)/i,key_access:/^\\.([a-z_][a-z_\\d]*)/i,index_access:/^\\[(\\d+)\\]/,sign:/^[+-]/};function e(t){return i(o(t),arguments)}function n(t,r){return e.apply(null,[t].concat(r||[]))}function i(r,n){var i,a,o,s,l,c,u,f,h,p=1,d=r.length,m=\"\";for(a=0;a<d;a++)if(\"string\"==typeof r[a])m+=r[a];else if(\"object\"==typeof r[a]){if((s=r[a]).keys)for(i=n[p],o=0;o<s.keys.length;o++){if(null==i)throw new Error(e('[sprintf] Cannot access property \"%s\" of undefined value \"%s\"',s.keys[o],s.keys[o-1]));i=i[s.keys[o]]}else i=s.param_no?n[s.param_no]:n[p++];if(t.not_type.test(s.type)&&t.not_primitive.test(s.type)&&i instanceof Function&&(i=i()),t.numeric_arg.test(s.type)&&\"number\"!=typeof i&&isNaN(i))throw new TypeError(e(\"[sprintf] expecting number but found %T\",i));switch(t.number.test(s.type)&&(f=i>=0),s.type){case\"b\":i=parseInt(i,10).toString(2);break;case\"c\":i=String.fromCharCode(parseInt(i,10));break;case\"d\":case\"i\":i=parseInt(i,10);break;case\"j\":i=JSON.stringify(i,null,s.width?parseInt(s.width):0);break;case\"e\":i=s.precision?parseFloat(i).toExponential(s.precision):parseFloat(i).toExponential();break;case\"f\":i=s.precision?parseFloat(i).toFixed(s.precision):parseFloat(i);break;case\"g\":i=s.precision?String(Number(i.toPrecision(s.precision))):parseFloat(i);break;case\"o\":i=(parseInt(i,10)>>>0).toString(8);break;case\"s\":i=String(i),i=s.precision?i.substring(0,s.precision):i;break;case\"t\":i=String(!!i),i=s.precision?i.substring(0,s.precision):i;break;case\"T\":i=Object.prototype.toString.call(i).slice(8,-1).toLowerCase(),i=s.precision?i.substring(0,s.precision):i;break;case\"u\":i=parseInt(i,10)>>>0;break;case\"v\":i=i.valueOf(),i=s.precision?i.substring(0,s.precision):i;break;case\"x\":i=(parseInt(i,10)>>>0).toString(16);break;case\"X\":i=(parseInt(i,10)>>>0).toString(16).toUpperCase()}t.json.test(s.type)?m+=i:(!t.number.test(s.type)||f&&!s.sign?h=\"\":(h=f?\"+\":\"-\",i=i.toString().replace(t.sign,\"\")),c=s.pad_char?\"0\"===s.pad_char?\"0\":s.pad_char.charAt(1):\" \",u=s.width-(h+i).length,l=s.width&&u>0?c.repeat(u):\"\",m+=s.align?h+i+l:\"0\"===c?h+l+i:l+h+i)}return m}var a=Object.create(null);function o(e){if(a[e])return a[e];for(var r,n=e,i=[],o=0;n;){if(null!==(r=t.text.exec(n)))i.push(r[0]);else if(null!==(r=t.modulo.exec(n)))i.push(\"%\");else{if(null===(r=t.placeholder.exec(n)))throw new SyntaxError(\"[sprintf] unexpected placeholder\");if(r[2]){o|=1;var s=[],l=r[2],c=[];if(null===(c=t.key.exec(l)))throw new SyntaxError(\"[sprintf] failed to parse named argument key\");for(s.push(c[1]);\"\"!==(l=l.substring(c[0].length));)if(null!==(c=t.key_access.exec(l)))s.push(c[1]);else{if(null===(c=t.index_access.exec(l)))throw new SyntaxError(\"[sprintf] failed to parse named argument key\");s.push(c[1])}r[2]=s}else o|=2;if(3===o)throw new Error(\"[sprintf] mixing positional and named placeholders is not (yet) supported\");i.push({placeholder:r[0],param_no:r[1],keys:r[2],sign:r[3],pad_char:r[4],align:r[5],width:r[6],precision:r[7],type:r[8]})}n=n.substring(r[0].length)}return a[e]=i}void 0!==r&&(r.sprintf=e,r.vsprintf=n),\"undefined\"!=typeof window&&(window.sprintf=e,window.vsprintf=n)}()},{}],565:[function(t,e,r){e.exports=i;var n=t(\"events\").EventEmitter;function i(){n.call(this)}t(\"inherits\")(i,n),i.Readable=t(\"readable-stream/lib/_stream_readable.js\"),i.Writable=t(\"readable-stream/lib/_stream_writable.js\"),i.Duplex=t(\"readable-stream/lib/_stream_duplex.js\"),i.Transform=t(\"readable-stream/lib/_stream_transform.js\"),i.PassThrough=t(\"readable-stream/lib/_stream_passthrough.js\"),i.finished=t(\"readable-stream/lib/internal/streams/end-of-stream.js\"),i.pipeline=t(\"readable-stream/lib/internal/streams/pipeline.js\"),i.Stream=i,i.prototype.pipe=function(t,e){var r=this;function i(e){t.writable&&!1===t.write(e)&&r.pause&&r.pause()}function a(){r.readable&&r.resume&&r.resume()}r.on(\"data\",i),t.on(\"drain\",a),t._isStdio||e&&!1===e.end||(r.on(\"end\",s),r.on(\"close\",l));var o=!1;function s(){o||(o=!0,t.end())}function l(){o||(o=!0,\"function\"==typeof t.destroy&&t.destroy())}function c(t){if(u(),0===n.listenerCount(this,\"error\"))throw t}function u(){r.removeListener(\"data\",i),t.removeListener(\"drain\",a),r.removeListener(\"end\",s),r.removeListener(\"close\",l),r.removeListener(\"error\",c),t.removeListener(\"error\",c),r.removeListener(\"end\",u),r.removeListener(\"close\",u),t.removeListener(\"close\",u)}return r.on(\"error\",c),t.on(\"error\",c),r.on(\"end\",u),r.on(\"close\",u),t.on(\"close\",u),t.emit(\"pipe\",r),t}},{events:116,inherits:443,\"readable-stream/lib/_stream_duplex.js\":567,\"readable-stream/lib/_stream_passthrough.js\":568,\"readable-stream/lib/_stream_readable.js\":569,\"readable-stream/lib/_stream_transform.js\":570,\"readable-stream/lib/_stream_writable.js\":571,\"readable-stream/lib/internal/streams/end-of-stream.js\":575,\"readable-stream/lib/internal/streams/pipeline.js\":577}],566:[function(t,e,r){\"use strict\";var n={};function i(t,e,r){r||(r=Error);var i=function(t){var r,n;function i(r,n,i){return t.call(this,function(t,r,n){return\"string\"==typeof e?e:e(t,r,n)}(r,n,i))||this}return n=t,(r=i).prototype=Object.create(n.prototype),r.prototype.constructor=r,r.__proto__=n,i}(r);i.prototype.name=r.name,i.prototype.code=t,n[t]=i}function a(t,e){if(Array.isArray(t)){var r=t.length;return t=t.map((function(t){return String(t)})),r>2?\"one of \".concat(e,\" \").concat(t.slice(0,r-1).join(\", \"),\", or \")+t[r-1]:2===r?\"one of \".concat(e,\" \").concat(t[0],\" or \").concat(t[1]):\"of \".concat(e,\" \").concat(t[0])}return\"of \".concat(e,\" \").concat(String(t))}i(\"ERR_INVALID_OPT_VALUE\",(function(t,e){return'The value \"'+e+'\" is invalid for option \"'+t+'\"'}),TypeError),i(\"ERR_INVALID_ARG_TYPE\",(function(t,e,r){var n,i,o,s;if(\"string\"==typeof e&&(i=\"not \",e.substr(!o||o<0?0:+o,i.length)===i)?(n=\"must not be\",e=e.replace(/^not /,\"\")):n=\"must be\",function(t,e,r){return(void 0===r||r>t.length)&&(r=t.length),t.substring(r-e.length,r)===e}(t,\" argument\"))s=\"The \".concat(t,\" \").concat(n,\" \").concat(a(e,\"type\"));else{var l=function(t,e,r){return\"number\"!=typeof r&&(r=0),!(r+e.length>t.length)&&-1!==t.indexOf(e,r)}(t,\".\")?\"property\":\"argument\";s='The \"'.concat(t,'\" ').concat(l,\" \").concat(n,\" \").concat(a(e,\"type\"))}return s+=\". Received type \".concat(typeof r)}),TypeError),i(\"ERR_STREAM_PUSH_AFTER_EOF\",\"stream.push() after EOF\"),i(\"ERR_METHOD_NOT_IMPLEMENTED\",(function(t){return\"The \"+t+\" method is not implemented\"})),i(\"ERR_STREAM_PREMATURE_CLOSE\",\"Premature close\"),i(\"ERR_STREAM_DESTROYED\",(function(t){return\"Cannot call \"+t+\" after a stream was destroyed\"})),i(\"ERR_MULTIPLE_CALLBACK\",\"Callback called multiple times\"),i(\"ERR_STREAM_CANNOT_PIPE\",\"Cannot pipe, not readable\"),i(\"ERR_STREAM_WRITE_AFTER_END\",\"write after end\"),i(\"ERR_STREAM_NULL_VALUES\",\"May not write null values to stream\",TypeError),i(\"ERR_UNKNOWN_ENCODING\",(function(t){return\"Unknown encoding: \"+t}),TypeError),i(\"ERR_STREAM_UNSHIFT_AFTER_END_EVENT\",\"stream.unshift() after end event\"),e.exports.codes=n},{}],567:[function(t,e,r){(function(r){(function(){\"use strict\";var n=Object.keys||function(t){var e=[];for(var r in t)e.push(r);return e};e.exports=c;var i=t(\"./_stream_readable\"),a=t(\"./_stream_writable\");t(\"inherits\")(c,i);for(var o=n(a.prototype),s=0;s<o.length;s++){var l=o[s];c.prototype[l]||(c.prototype[l]=a.prototype[l])}function c(t){if(!(this instanceof c))return new c(t);i.call(this,t),a.call(this,t),this.allowHalfOpen=!0,t&&(!1===t.readable&&(this.readable=!1),!1===t.writable&&(this.writable=!1),!1===t.allowHalfOpen&&(this.allowHalfOpen=!1,this.once(\"end\",u)))}function u(){this._writableState.ended||r.nextTick(f,this)}function f(t){t.end()}Object.defineProperty(c.prototype,\"writableHighWaterMark\",{enumerable:!1,get:function(){return this._writableState.highWaterMark}}),Object.defineProperty(c.prototype,\"writableBuffer\",{enumerable:!1,get:function(){return this._writableState&&this._writableState.getBuffer()}}),Object.defineProperty(c.prototype,\"writableLength\",{enumerable:!1,get:function(){return this._writableState.length}}),Object.defineProperty(c.prototype,\"destroyed\",{enumerable:!1,get:function(){return void 0!==this._readableState&&void 0!==this._writableState&&(this._readableState.destroyed&&this._writableState.destroyed)},set:function(t){void 0!==this._readableState&&void 0!==this._writableState&&(this._readableState.destroyed=t,this._writableState.destroyed=t)}})}).call(this)}).call(this,t(\"_process\"))},{\"./_stream_readable\":569,\"./_stream_writable\":571,_process:524,inherits:443}],568:[function(t,e,r){\"use strict\";e.exports=i;var n=t(\"./_stream_transform\");function i(t){if(!(this instanceof i))return new i(t);n.call(this,t)}t(\"inherits\")(i,n),i.prototype._transform=function(t,e,r){r(null,t)}},{\"./_stream_transform\":570,inherits:443}],569:[function(t,e,r){(function(r,n){(function(){\"use strict\";var i;e.exports=M,M.ReadableState=k;t(\"events\").EventEmitter;var a=function(t,e){return t.listeners(e).length},o=t(\"./internal/streams/stream\"),s=t(\"buffer\").Buffer,l=n.Uint8Array||function(){};var c,u=t(\"util\");c=u&&u.debuglog?u.debuglog(\"stream\"):function(){};var f,h,p,d=t(\"./internal/streams/buffer_list\"),m=t(\"./internal/streams/destroy\"),g=t(\"./internal/streams/state\").getHighWaterMark,v=t(\"../errors\").codes,y=v.ERR_INVALID_ARG_TYPE,x=v.ERR_STREAM_PUSH_AFTER_EOF,b=v.ERR_METHOD_NOT_IMPLEMENTED,_=v.ERR_STREAM_UNSHIFT_AFTER_END_EVENT;t(\"inherits\")(M,o);var w=m.errorOrDestroy,T=[\"error\",\"close\",\"destroy\",\"pause\",\"resume\"];function k(e,r,n){i=i||t(\"./_stream_duplex\"),e=e||{},\"boolean\"!=typeof n&&(n=r instanceof i),this.objectMode=!!e.objectMode,n&&(this.objectMode=this.objectMode||!!e.readableObjectMode),this.highWaterMark=g(this,e,\"readableHighWaterMark\",n),this.buffer=new d,this.length=0,this.pipes=null,this.pipesCount=0,this.flowing=null,this.ended=!1,this.endEmitted=!1,this.reading=!1,this.sync=!0,this.needReadable=!1,this.emittedReadable=!1,this.readableListening=!1,this.resumeScheduled=!1,this.paused=!0,this.emitClose=!1!==e.emitClose,this.autoDestroy=!!e.autoDestroy,this.destroyed=!1,this.defaultEncoding=e.defaultEncoding||\"utf8\",this.awaitDrain=0,this.readingMore=!1,this.decoder=null,this.encoding=null,e.encoding&&(f||(f=t(\"string_decoder/\").StringDecoder),this.decoder=new f(e.encoding),this.encoding=e.encoding)}function M(e){if(i=i||t(\"./_stream_duplex\"),!(this instanceof M))return new M(e);var r=this instanceof i;this._readableState=new k(e,this,r),this.readable=!0,e&&(\"function\"==typeof e.read&&(this._read=e.read),\"function\"==typeof e.destroy&&(this._destroy=e.destroy)),o.call(this)}function A(t,e,r,n,i){c(\"readableAddChunk\",e);var a,o=t._readableState;if(null===e)o.reading=!1,function(t,e){if(c(\"onEofChunk\"),e.ended)return;if(e.decoder){var r=e.decoder.end();r&&r.length&&(e.buffer.push(r),e.length+=e.objectMode?1:r.length)}e.ended=!0,e.sync?L(t):(e.needReadable=!1,e.emittedReadable||(e.emittedReadable=!0,C(t)))}(t,o);else if(i||(a=function(t,e){var r;n=e,s.isBuffer(n)||n instanceof l||\"string\"==typeof e||void 0===e||t.objectMode||(r=new y(\"chunk\",[\"string\",\"Buffer\",\"Uint8Array\"],e));var n;return r}(o,e)),a)w(t,a);else if(o.objectMode||e&&e.length>0)if(\"string\"==typeof e||o.objectMode||Object.getPrototypeOf(e)===s.prototype||(e=function(t){return s.from(t)}(e)),n)o.endEmitted?w(t,new _):S(t,o,e,!0);else if(o.ended)w(t,new x);else{if(o.destroyed)return!1;o.reading=!1,o.decoder&&!r?(e=o.decoder.write(e),o.objectMode||0!==e.length?S(t,o,e,!1):P(t,o)):S(t,o,e,!1)}else n||(o.reading=!1,P(t,o));return!o.ended&&(o.length<o.highWaterMark||0===o.length)}function S(t,e,r,n){e.flowing&&0===e.length&&!e.sync?(e.awaitDrain=0,t.emit(\"data\",r)):(e.length+=e.objectMode?1:r.length,n?e.buffer.unshift(r):e.buffer.push(r),e.needReadable&&L(t)),P(t,e)}Object.defineProperty(M.prototype,\"destroyed\",{enumerable:!1,get:function(){return void 0!==this._readableState&&this._readableState.destroyed},set:function(t){this._readableState&&(this._readableState.destroyed=t)}}),M.prototype.destroy=m.destroy,M.prototype._undestroy=m.undestroy,M.prototype._destroy=function(t,e){e(t)},M.prototype.push=function(t,e){var r,n=this._readableState;return n.objectMode?r=!0:\"string\"==typeof t&&((e=e||n.defaultEncoding)!==n.encoding&&(t=s.from(t,e),e=\"\"),r=!0),A(this,t,e,!1,r)},M.prototype.unshift=function(t){return A(this,t,null,!0,!1)},M.prototype.isPaused=function(){return!1===this._readableState.flowing},M.prototype.setEncoding=function(e){f||(f=t(\"string_decoder/\").StringDecoder);var r=new f(e);this._readableState.decoder=r,this._readableState.encoding=this._readableState.decoder.encoding;for(var n=this._readableState.buffer.head,i=\"\";null!==n;)i+=r.write(n.data),n=n.next;return this._readableState.buffer.clear(),\"\"!==i&&this._readableState.buffer.push(i),this._readableState.length=i.length,this};function E(t,e){return t<=0||0===e.length&&e.ended?0:e.objectMode?1:t!=t?e.flowing&&e.length?e.buffer.head.data.length:e.length:(t>e.highWaterMark&&(e.highWaterMark=function(t){return t>=1073741824?t=1073741824:(t--,t|=t>>>1,t|=t>>>2,t|=t>>>4,t|=t>>>8,t|=t>>>16,t++),t}(t)),t<=e.length?t:e.ended?e.length:(e.needReadable=!0,0))}function L(t){var e=t._readableState;c(\"emitReadable\",e.needReadable,e.emittedReadable),e.needReadable=!1,e.emittedReadable||(c(\"emitReadable\",e.flowing),e.emittedReadable=!0,r.nextTick(C,t))}function C(t){var e=t._readableState;c(\"emitReadable_\",e.destroyed,e.length,e.ended),e.destroyed||!e.length&&!e.ended||(t.emit(\"readable\"),e.emittedReadable=!1),e.needReadable=!e.flowing&&!e.ended&&e.length<=e.highWaterMark,R(t)}function P(t,e){e.readingMore||(e.readingMore=!0,r.nextTick(I,t,e))}function I(t,e){for(;!e.reading&&!e.ended&&(e.length<e.highWaterMark||e.flowing&&0===e.length);){var r=e.length;if(c(\"maybeReadMore read 0\"),t.read(0),r===e.length)break}e.readingMore=!1}function O(t){var e=t._readableState;e.readableListening=t.listenerCount(\"readable\")>0,e.resumeScheduled&&!e.paused?e.flowing=!0:t.listenerCount(\"data\")>0&&t.resume()}function z(t){c(\"readable nexttick read 0\"),t.read(0)}function D(t,e){c(\"resume\",e.reading),e.reading||t.read(0),e.resumeScheduled=!1,t.emit(\"resume\"),R(t),e.flowing&&!e.reading&&t.read(0)}function R(t){var e=t._readableState;for(c(\"flow\",e.flowing);e.flowing&&null!==t.read(););}function F(t,e){return 0===e.length?null:(e.objectMode?r=e.buffer.shift():!t||t>=e.length?(r=e.decoder?e.buffer.join(\"\"):1===e.buffer.length?e.buffer.first():e.buffer.concat(e.length),e.buffer.clear()):r=e.buffer.consume(t,e.decoder),r);var r}function B(t){var e=t._readableState;c(\"endReadable\",e.endEmitted),e.endEmitted||(e.ended=!0,r.nextTick(N,e,t))}function N(t,e){if(c(\"endReadableNT\",t.endEmitted,t.length),!t.endEmitted&&0===t.length&&(t.endEmitted=!0,e.readable=!1,e.emit(\"end\"),t.autoDestroy)){var r=e._writableState;(!r||r.autoDestroy&&r.finished)&&e.destroy()}}function j(t,e){for(var r=0,n=t.length;r<n;r++)if(t[r]===e)return r;return-1}M.prototype.read=function(t){c(\"read\",t),t=parseInt(t,10);var e=this._readableState,r=t;if(0!==t&&(e.emittedReadable=!1),0===t&&e.needReadable&&((0!==e.highWaterMark?e.length>=e.highWaterMark:e.length>0)||e.ended))return c(\"read: emitReadable\",e.length,e.ended),0===e.length&&e.ended?B(this):L(this),null;if(0===(t=E(t,e))&&e.ended)return 0===e.length&&B(this),null;var n,i=e.needReadable;return c(\"need readable\",i),(0===e.length||e.length-t<e.highWaterMark)&&c(\"length less than watermark\",i=!0),e.ended||e.reading?c(\"reading or ended\",i=!1):i&&(c(\"do read\"),e.reading=!0,e.sync=!0,0===e.length&&(e.needReadable=!0),this._read(e.highWaterMark),e.sync=!1,e.reading||(t=E(r,e))),null===(n=t>0?F(t,e):null)?(e.needReadable=e.length<=e.highWaterMark,t=0):(e.length-=t,e.awaitDrain=0),0===e.length&&(e.ended||(e.needReadable=!0),r!==t&&e.ended&&B(this)),null!==n&&this.emit(\"data\",n),n},M.prototype._read=function(t){w(this,new b(\"_read()\"))},M.prototype.pipe=function(t,e){var n=this,i=this._readableState;switch(i.pipesCount){case 0:i.pipes=t;break;case 1:i.pipes=[i.pipes,t];break;default:i.pipes.push(t)}i.pipesCount+=1,c(\"pipe count=%d opts=%j\",i.pipesCount,e);var o=(!e||!1!==e.end)&&t!==r.stdout&&t!==r.stderr?l:g;function s(e,r){c(\"onunpipe\"),e===n&&r&&!1===r.hasUnpiped&&(r.hasUnpiped=!0,c(\"cleanup\"),t.removeListener(\"close\",d),t.removeListener(\"finish\",m),t.removeListener(\"drain\",u),t.removeListener(\"error\",p),t.removeListener(\"unpipe\",s),n.removeListener(\"end\",l),n.removeListener(\"end\",g),n.removeListener(\"data\",h),f=!0,!i.awaitDrain||t._writableState&&!t._writableState.needDrain||u())}function l(){c(\"onend\"),t.end()}i.endEmitted?r.nextTick(o):n.once(\"end\",o),t.on(\"unpipe\",s);var u=function(t){return function(){var e=t._readableState;c(\"pipeOnDrain\",e.awaitDrain),e.awaitDrain&&e.awaitDrain--,0===e.awaitDrain&&a(t,\"data\")&&(e.flowing=!0,R(t))}}(n);t.on(\"drain\",u);var f=!1;function h(e){c(\"ondata\");var r=t.write(e);c(\"dest.write\",r),!1===r&&((1===i.pipesCount&&i.pipes===t||i.pipesCount>1&&-1!==j(i.pipes,t))&&!f&&(c(\"false write response, pause\",i.awaitDrain),i.awaitDrain++),n.pause())}function p(e){c(\"onerror\",e),g(),t.removeListener(\"error\",p),0===a(t,\"error\")&&w(t,e)}function d(){t.removeListener(\"finish\",m),g()}function m(){c(\"onfinish\"),t.removeListener(\"close\",d),g()}function g(){c(\"unpipe\"),n.unpipe(t)}return n.on(\"data\",h),function(t,e,r){if(\"function\"==typeof t.prependListener)return t.prependListener(e,r);t._events&&t._events[e]?Array.isArray(t._events[e])?t._events[e].unshift(r):t._events[e]=[r,t._events[e]]:t.on(e,r)}(t,\"error\",p),t.once(\"close\",d),t.once(\"finish\",m),t.emit(\"pipe\",n),i.flowing||(c(\"pipe resume\"),n.resume()),t},M.prototype.unpipe=function(t){var e=this._readableState,r={hasUnpiped:!1};if(0===e.pipesCount)return this;if(1===e.pipesCount)return t&&t!==e.pipes||(t||(t=e.pipes),e.pipes=null,e.pipesCount=0,e.flowing=!1,t&&t.emit(\"unpipe\",this,r)),this;if(!t){var n=e.pipes,i=e.pipesCount;e.pipes=null,e.pipesCount=0,e.flowing=!1;for(var a=0;a<i;a++)n[a].emit(\"unpipe\",this,{hasUnpiped:!1});return this}var o=j(e.pipes,t);return-1===o||(e.pipes.splice(o,1),e.pipesCount-=1,1===e.pipesCount&&(e.pipes=e.pipes[0]),t.emit(\"unpipe\",this,r)),this},M.prototype.on=function(t,e){var n=o.prototype.on.call(this,t,e),i=this._readableState;return\"data\"===t?(i.readableListening=this.listenerCount(\"readable\")>0,!1!==i.flowing&&this.resume()):\"readable\"===t&&(i.endEmitted||i.readableListening||(i.readableListening=i.needReadable=!0,i.flowing=!1,i.emittedReadable=!1,c(\"on readable\",i.length,i.reading),i.length?L(this):i.reading||r.nextTick(z,this))),n},M.prototype.addListener=M.prototype.on,M.prototype.removeListener=function(t,e){var n=o.prototype.removeListener.call(this,t,e);return\"readable\"===t&&r.nextTick(O,this),n},M.prototype.removeAllListeners=function(t){var e=o.prototype.removeAllListeners.apply(this,arguments);return\"readable\"!==t&&void 0!==t||r.nextTick(O,this),e},M.prototype.resume=function(){var t=this._readableState;return t.flowing||(c(\"resume\"),t.flowing=!t.readableListening,function(t,e){e.resumeScheduled||(e.resumeScheduled=!0,r.nextTick(D,t,e))}(this,t)),t.paused=!1,this},M.prototype.pause=function(){return c(\"call pause flowing=%j\",this._readableState.flowing),!1!==this._readableState.flowing&&(c(\"pause\"),this._readableState.flowing=!1,this.emit(\"pause\")),this._readableState.paused=!0,this},M.prototype.wrap=function(t){var e=this,r=this._readableState,n=!1;for(var i in t.on(\"end\",(function(){if(c(\"wrapped end\"),r.decoder&&!r.ended){var t=r.decoder.end();t&&t.length&&e.push(t)}e.push(null)})),t.on(\"data\",(function(i){(c(\"wrapped data\"),r.decoder&&(i=r.decoder.write(i)),r.objectMode&&null==i)||(r.objectMode||i&&i.length)&&(e.push(i)||(n=!0,t.pause()))})),t)void 0===this[i]&&\"function\"==typeof t[i]&&(this[i]=function(e){return function(){return t[e].apply(t,arguments)}}(i));for(var a=0;a<T.length;a++)t.on(T[a],this.emit.bind(this,T[a]));return this._read=function(e){c(\"wrapped _read\",e),n&&(n=!1,t.resume())},this},\"function\"==typeof Symbol&&(M.prototype[Symbol.asyncIterator]=function(){return void 0===h&&(h=t(\"./internal/streams/async_iterator\")),h(this)}),Object.defineProperty(M.prototype,\"readableHighWaterMark\",{enumerable:!1,get:function(){return this._readableState.highWaterMark}}),Object.defineProperty(M.prototype,\"readableBuffer\",{enumerable:!1,get:function(){return this._readableState&&this._readableState.buffer}}),Object.defineProperty(M.prototype,\"readableFlowing\",{enumerable:!1,get:function(){return this._readableState.flowing},set:function(t){this._readableState&&(this._readableState.flowing=t)}}),M._fromList=F,Object.defineProperty(M.prototype,\"readableLength\",{enumerable:!1,get:function(){return this._readableState.length}}),\"function\"==typeof Symbol&&(M.from=function(e,r){return void 0===p&&(p=t(\"./internal/streams/from\")),p(M,e,r)})}).call(this)}).call(this,t(\"_process\"),\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{\"../errors\":566,\"./_stream_duplex\":567,\"./internal/streams/async_iterator\":572,\"./internal/streams/buffer_list\":573,\"./internal/streams/destroy\":574,\"./internal/streams/from\":576,\"./internal/streams/state\":578,\"./internal/streams/stream\":579,_process:524,buffer:117,events:116,inherits:443,\"string_decoder/\":580,util:115}],570:[function(t,e,r){\"use strict\";e.exports=u;var n=t(\"../errors\").codes,i=n.ERR_METHOD_NOT_IMPLEMENTED,a=n.ERR_MULTIPLE_CALLBACK,o=n.ERR_TRANSFORM_ALREADY_TRANSFORMING,s=n.ERR_TRANSFORM_WITH_LENGTH_0,l=t(\"./_stream_duplex\");function c(t,e){var r=this._transformState;r.transforming=!1;var n=r.writecb;if(null===n)return this.emit(\"error\",new a);r.writechunk=null,r.writecb=null,null!=e&&this.push(e),n(t);var i=this._readableState;i.reading=!1,(i.needReadable||i.length<i.highWaterMark)&&this._read(i.highWaterMark)}function u(t){if(!(this instanceof u))return new u(t);l.call(this,t),this._transformState={afterTransform:c.bind(this),needTransform:!1,transforming:!1,writecb:null,writechunk:null,writeencoding:null},this._readableState.needReadable=!0,this._readableState.sync=!1,t&&(\"function\"==typeof t.transform&&(this._transform=t.transform),\"function\"==typeof t.flush&&(this._flush=t.flush)),this.on(\"prefinish\",f)}function f(){var t=this;\"function\"!=typeof this._flush||this._readableState.destroyed?h(this,null,null):this._flush((function(e,r){h(t,e,r)}))}function h(t,e,r){if(e)return t.emit(\"error\",e);if(null!=r&&t.push(r),t._writableState.length)throw new s;if(t._transformState.transforming)throw new o;return t.push(null)}t(\"inherits\")(u,l),u.prototype.push=function(t,e){return this._transformState.needTransform=!1,l.prototype.push.call(this,t,e)},u.prototype._transform=function(t,e,r){r(new i(\"_transform()\"))},u.prototype._write=function(t,e,r){var n=this._transformState;if(n.writecb=r,n.writechunk=t,n.writeencoding=e,!n.transforming){var i=this._readableState;(n.needTransform||i.needReadable||i.length<i.highWaterMark)&&this._read(i.highWaterMark)}},u.prototype._read=function(t){var e=this._transformState;null===e.writechunk||e.transforming?e.needTransform=!0:(e.transforming=!0,this._transform(e.writechunk,e.writeencoding,e.afterTransform))},u.prototype._destroy=function(t,e){l.prototype._destroy.call(this,t,(function(t){e(t)}))}},{\"../errors\":566,\"./_stream_duplex\":567,inherits:443}],571:[function(t,e,r){(function(r,n){(function(){\"use strict\";function i(t){var e=this;this.next=null,this.entry=null,this.finish=function(){!function(t,e,r){var n=t.entry;t.entry=null;for(;n;){var i=n.callback;e.pendingcb--,i(r),n=n.next}e.corkedRequestsFree.next=t}(e,t)}}var a;e.exports=M,M.WritableState=k;var o={deprecate:t(\"util-deprecate\")},s=t(\"./internal/streams/stream\"),l=t(\"buffer\").Buffer,c=n.Uint8Array||function(){};var u,f=t(\"./internal/streams/destroy\"),h=t(\"./internal/streams/state\").getHighWaterMark,p=t(\"../errors\").codes,d=p.ERR_INVALID_ARG_TYPE,m=p.ERR_METHOD_NOT_IMPLEMENTED,g=p.ERR_MULTIPLE_CALLBACK,v=p.ERR_STREAM_CANNOT_PIPE,y=p.ERR_STREAM_DESTROYED,x=p.ERR_STREAM_NULL_VALUES,b=p.ERR_STREAM_WRITE_AFTER_END,_=p.ERR_UNKNOWN_ENCODING,w=f.errorOrDestroy;function T(){}function k(e,n,o){a=a||t(\"./_stream_duplex\"),e=e||{},\"boolean\"!=typeof o&&(o=n instanceof a),this.objectMode=!!e.objectMode,o&&(this.objectMode=this.objectMode||!!e.writableObjectMode),this.highWaterMark=h(this,e,\"writableHighWaterMark\",o),this.finalCalled=!1,this.needDrain=!1,this.ending=!1,this.ended=!1,this.finished=!1,this.destroyed=!1;var s=!1===e.decodeStrings;this.decodeStrings=!s,this.defaultEncoding=e.defaultEncoding||\"utf8\",this.length=0,this.writing=!1,this.corked=0,this.sync=!0,this.bufferProcessing=!1,this.onwrite=function(t){!function(t,e){var n=t._writableState,i=n.sync,a=n.writecb;if(\"function\"!=typeof a)throw new g;if(function(t){t.writing=!1,t.writecb=null,t.length-=t.writelen,t.writelen=0}(n),e)!function(t,e,n,i,a){--e.pendingcb,n?(r.nextTick(a,i),r.nextTick(P,t,e),t._writableState.errorEmitted=!0,w(t,i)):(a(i),t._writableState.errorEmitted=!0,w(t,i),P(t,e))}(t,n,i,e,a);else{var o=L(n)||t.destroyed;o||n.corked||n.bufferProcessing||!n.bufferedRequest||E(t,n),i?r.nextTick(S,t,n,o,a):S(t,n,o,a)}}(n,t)},this.writecb=null,this.writelen=0,this.bufferedRequest=null,this.lastBufferedRequest=null,this.pendingcb=0,this.prefinished=!1,this.errorEmitted=!1,this.emitClose=!1!==e.emitClose,this.autoDestroy=!!e.autoDestroy,this.bufferedRequestCount=0,this.corkedRequestsFree=new i(this)}function M(e){var r=this instanceof(a=a||t(\"./_stream_duplex\"));if(!r&&!u.call(M,this))return new M(e);this._writableState=new k(e,this,r),this.writable=!0,e&&(\"function\"==typeof e.write&&(this._write=e.write),\"function\"==typeof e.writev&&(this._writev=e.writev),\"function\"==typeof e.destroy&&(this._destroy=e.destroy),\"function\"==typeof e.final&&(this._final=e.final)),s.call(this)}function A(t,e,r,n,i,a,o){e.writelen=n,e.writecb=o,e.writing=!0,e.sync=!0,e.destroyed?e.onwrite(new y(\"write\")):r?t._writev(i,e.onwrite):t._write(i,a,e.onwrite),e.sync=!1}function S(t,e,r,n){r||function(t,e){0===e.length&&e.needDrain&&(e.needDrain=!1,t.emit(\"drain\"))}(t,e),e.pendingcb--,n(),P(t,e)}function E(t,e){e.bufferProcessing=!0;var r=e.bufferedRequest;if(t._writev&&r&&r.next){var n=e.bufferedRequestCount,a=new Array(n),o=e.corkedRequestsFree;o.entry=r;for(var s=0,l=!0;r;)a[s]=r,r.isBuf||(l=!1),r=r.next,s+=1;a.allBuffers=l,A(t,e,!0,e.length,a,\"\",o.finish),e.pendingcb++,e.lastBufferedRequest=null,o.next?(e.corkedRequestsFree=o.next,o.next=null):e.corkedRequestsFree=new i(e),e.bufferedRequestCount=0}else{for(;r;){var c=r.chunk,u=r.encoding,f=r.callback;if(A(t,e,!1,e.objectMode?1:c.length,c,u,f),r=r.next,e.bufferedRequestCount--,e.writing)break}null===r&&(e.lastBufferedRequest=null)}e.bufferedRequest=r,e.bufferProcessing=!1}function L(t){return t.ending&&0===t.length&&null===t.bufferedRequest&&!t.finished&&!t.writing}function C(t,e){t._final((function(r){e.pendingcb--,r&&w(t,r),e.prefinished=!0,t.emit(\"prefinish\"),P(t,e)}))}function P(t,e){var n=L(e);if(n&&(function(t,e){e.prefinished||e.finalCalled||(\"function\"!=typeof t._final||e.destroyed?(e.prefinished=!0,t.emit(\"prefinish\")):(e.pendingcb++,e.finalCalled=!0,r.nextTick(C,t,e)))}(t,e),0===e.pendingcb&&(e.finished=!0,t.emit(\"finish\"),e.autoDestroy))){var i=t._readableState;(!i||i.autoDestroy&&i.endEmitted)&&t.destroy()}return n}t(\"inherits\")(M,s),k.prototype.getBuffer=function(){for(var t=this.bufferedRequest,e=[];t;)e.push(t),t=t.next;return e},function(){try{Object.defineProperty(k.prototype,\"buffer\",{get:o.deprecate((function(){return this.getBuffer()}),\"_writableState.buffer is deprecated. Use _writableState.getBuffer instead.\",\"DEP0003\")})}catch(t){}}(),\"function\"==typeof Symbol&&Symbol.hasInstance&&\"function\"==typeof Function.prototype[Symbol.hasInstance]?(u=Function.prototype[Symbol.hasInstance],Object.defineProperty(M,Symbol.hasInstance,{value:function(t){return!!u.call(this,t)||this===M&&(t&&t._writableState instanceof k)}})):u=function(t){return t instanceof this},M.prototype.pipe=function(){w(this,new v)},M.prototype.write=function(t,e,n){var i,a=this._writableState,o=!1,s=!a.objectMode&&(i=t,l.isBuffer(i)||i instanceof c);return s&&!l.isBuffer(t)&&(t=function(t){return l.from(t)}(t)),\"function\"==typeof e&&(n=e,e=null),s?e=\"buffer\":e||(e=a.defaultEncoding),\"function\"!=typeof n&&(n=T),a.ending?function(t,e){var n=new b;w(t,n),r.nextTick(e,n)}(this,n):(s||function(t,e,n,i){var a;return null===n?a=new x:\"string\"==typeof n||e.objectMode||(a=new d(\"chunk\",[\"string\",\"Buffer\"],n)),!a||(w(t,a),r.nextTick(i,a),!1)}(this,a,t,n))&&(a.pendingcb++,o=function(t,e,r,n,i,a){if(!r){var o=function(t,e,r){t.objectMode||!1===t.decodeStrings||\"string\"!=typeof e||(e=l.from(e,r));return e}(e,n,i);n!==o&&(r=!0,i=\"buffer\",n=o)}var s=e.objectMode?1:n.length;e.length+=s;var c=e.length<e.highWaterMark;c||(e.needDrain=!0);if(e.writing||e.corked){var u=e.lastBufferedRequest;e.lastBufferedRequest={chunk:n,encoding:i,isBuf:r,callback:a,next:null},u?u.next=e.lastBufferedRequest:e.bufferedRequest=e.lastBufferedRequest,e.bufferedRequestCount+=1}else A(t,e,!1,s,n,i,a);return c}(this,a,s,t,e,n)),o},M.prototype.cork=function(){this._writableState.corked++},M.prototype.uncork=function(){var t=this._writableState;t.corked&&(t.corked--,t.writing||t.corked||t.bufferProcessing||!t.bufferedRequest||E(this,t))},M.prototype.setDefaultEncoding=function(t){if(\"string\"==typeof t&&(t=t.toLowerCase()),!([\"hex\",\"utf8\",\"utf-8\",\"ascii\",\"binary\",\"base64\",\"ucs2\",\"ucs-2\",\"utf16le\",\"utf-16le\",\"raw\"].indexOf((t+\"\").toLowerCase())>-1))throw new _(t);return this._writableState.defaultEncoding=t,this},Object.defineProperty(M.prototype,\"writableBuffer\",{enumerable:!1,get:function(){return this._writableState&&this._writableState.getBuffer()}}),Object.defineProperty(M.prototype,\"writableHighWaterMark\",{enumerable:!1,get:function(){return this._writableState.highWaterMark}}),M.prototype._write=function(t,e,r){r(new m(\"_write()\"))},M.prototype._writev=null,M.prototype.end=function(t,e,n){var i=this._writableState;return\"function\"==typeof t?(n=t,t=null,e=null):\"function\"==typeof e&&(n=e,e=null),null!=t&&this.write(t,e),i.corked&&(i.corked=1,this.uncork()),i.ending||function(t,e,n){e.ending=!0,P(t,e),n&&(e.finished?r.nextTick(n):t.once(\"finish\",n));e.ended=!0,t.writable=!1}(this,i,n),this},Object.defineProperty(M.prototype,\"writableLength\",{enumerable:!1,get:function(){return this._writableState.length}}),Object.defineProperty(M.prototype,\"destroyed\",{enumerable:!1,get:function(){return void 0!==this._writableState&&this._writableState.destroyed},set:function(t){this._writableState&&(this._writableState.destroyed=t)}}),M.prototype.destroy=f.destroy,M.prototype._undestroy=f.undestroy,M.prototype._destroy=function(t,e){e(t)}}).call(this)}).call(this,t(\"_process\"),\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{\"../errors\":566,\"./_stream_duplex\":567,\"./internal/streams/destroy\":574,\"./internal/streams/state\":578,\"./internal/streams/stream\":579,_process:524,buffer:117,inherits:443,\"util-deprecate\":618}],572:[function(t,e,r){(function(r){(function(){\"use strict\";var n;function i(t,e,r){return e in t?Object.defineProperty(t,e,{value:r,enumerable:!0,configurable:!0,writable:!0}):t[e]=r,t}var a=t(\"./end-of-stream\"),o=Symbol(\"lastResolve\"),s=Symbol(\"lastReject\"),l=Symbol(\"error\"),c=Symbol(\"ended\"),u=Symbol(\"lastPromise\"),f=Symbol(\"handlePromise\"),h=Symbol(\"stream\");function p(t,e){return{value:t,done:e}}function d(t){var e=t[o];if(null!==e){var r=t[h].read();null!==r&&(t[u]=null,t[o]=null,t[s]=null,e(p(r,!1)))}}function m(t){r.nextTick(d,t)}var g=Object.getPrototypeOf((function(){})),v=Object.setPrototypeOf((i(n={get stream(){return this[h]},next:function(){var t=this,e=this[l];if(null!==e)return Promise.reject(e);if(this[c])return Promise.resolve(p(void 0,!0));if(this[h].destroyed)return new Promise((function(e,n){r.nextTick((function(){t[l]?n(t[l]):e(p(void 0,!0))}))}));var n,i=this[u];if(i)n=new Promise(function(t,e){return function(r,n){t.then((function(){e[c]?r(p(void 0,!0)):e[f](r,n)}),n)}}(i,this));else{var a=this[h].read();if(null!==a)return Promise.resolve(p(a,!1));n=new Promise(this[f])}return this[u]=n,n}},Symbol.asyncIterator,(function(){return this})),i(n,\"return\",(function(){var t=this;return new Promise((function(e,r){t[h].destroy(null,(function(t){t?r(t):e(p(void 0,!0))}))}))})),n),g);e.exports=function(t){var e,r=Object.create(v,(i(e={},h,{value:t,writable:!0}),i(e,o,{value:null,writable:!0}),i(e,s,{value:null,writable:!0}),i(e,l,{value:null,writable:!0}),i(e,c,{value:t._readableState.endEmitted,writable:!0}),i(e,f,{value:function(t,e){var n=r[h].read();n?(r[u]=null,r[o]=null,r[s]=null,t(p(n,!1))):(r[o]=t,r[s]=e)},writable:!0}),e));return r[u]=null,a(t,(function(t){if(t&&\"ERR_STREAM_PREMATURE_CLOSE\"!==t.code){var e=r[s];return null!==e&&(r[u]=null,r[o]=null,r[s]=null,e(t)),void(r[l]=t)}var n=r[o];null!==n&&(r[u]=null,r[o]=null,r[s]=null,n(p(void 0,!0))),r[c]=!0})),t.on(\"readable\",m.bind(null,r)),r}}).call(this)}).call(this,t(\"_process\"))},{\"./end-of-stream\":575,_process:524}],573:[function(t,e,r){\"use strict\";function n(t,e){var r=Object.keys(t);if(Object.getOwnPropertySymbols){var n=Object.getOwnPropertySymbols(t);e&&(n=n.filter((function(e){return Object.getOwnPropertyDescriptor(t,e).enumerable}))),r.push.apply(r,n)}return r}function i(t,e,r){return e in t?Object.defineProperty(t,e,{value:r,enumerable:!0,configurable:!0,writable:!0}):t[e]=r,t}function a(t,e){for(var r=0;r<e.length;r++){var n=e[r];n.enumerable=n.enumerable||!1,n.configurable=!0,\"value\"in n&&(n.writable=!0),Object.defineProperty(t,n.key,n)}}var o=t(\"buffer\").Buffer,s=t(\"util\").inspect,l=s&&s.custom||\"inspect\";e.exports=function(){function t(){!function(t,e){if(!(t instanceof e))throw new TypeError(\"Cannot call a class as a function\")}(this,t),this.head=null,this.tail=null,this.length=0}var e,r,c;return e=t,(r=[{key:\"push\",value:function(t){var e={data:t,next:null};this.length>0?this.tail.next=e:this.head=e,this.tail=e,++this.length}},{key:\"unshift\",value:function(t){var e={data:t,next:this.head};0===this.length&&(this.tail=e),this.head=e,++this.length}},{key:\"shift\",value:function(){if(0!==this.length){var t=this.head.data;return 1===this.length?this.head=this.tail=null:this.head=this.head.next,--this.length,t}}},{key:\"clear\",value:function(){this.head=this.tail=null,this.length=0}},{key:\"join\",value:function(t){if(0===this.length)return\"\";for(var e=this.head,r=\"\"+e.data;e=e.next;)r+=t+e.data;return r}},{key:\"concat\",value:function(t){if(0===this.length)return o.alloc(0);for(var e,r,n,i=o.allocUnsafe(t>>>0),a=this.head,s=0;a;)e=a.data,r=i,n=s,o.prototype.copy.call(e,r,n),s+=a.data.length,a=a.next;return i}},{key:\"consume\",value:function(t,e){var r;return t<this.head.data.length?(r=this.head.data.slice(0,t),this.head.data=this.head.data.slice(t)):r=t===this.head.data.length?this.shift():e?this._getString(t):this._getBuffer(t),r}},{key:\"first\",value:function(){return this.head.data}},{key:\"_getString\",value:function(t){var e=this.head,r=1,n=e.data;for(t-=n.length;e=e.next;){var i=e.data,a=t>i.length?i.length:t;if(a===i.length?n+=i:n+=i.slice(0,t),0==(t-=a)){a===i.length?(++r,e.next?this.head=e.next:this.head=this.tail=null):(this.head=e,e.data=i.slice(a));break}++r}return this.length-=r,n}},{key:\"_getBuffer\",value:function(t){var e=o.allocUnsafe(t),r=this.head,n=1;for(r.data.copy(e),t-=r.data.length;r=r.next;){var i=r.data,a=t>i.length?i.length:t;if(i.copy(e,e.length-t,0,a),0==(t-=a)){a===i.length?(++n,r.next?this.head=r.next:this.head=this.tail=null):(this.head=r,r.data=i.slice(a));break}++n}return this.length-=n,e}},{key:l,value:function(t,e){return s(this,function(t){for(var e=1;e<arguments.length;e++){var r=null!=arguments[e]?arguments[e]:{};e%2?n(Object(r),!0).forEach((function(e){i(t,e,r[e])})):Object.getOwnPropertyDescriptors?Object.defineProperties(t,Object.getOwnPropertyDescriptors(r)):n(Object(r)).forEach((function(e){Object.defineProperty(t,e,Object.getOwnPropertyDescriptor(r,e))}))}return t}({},e,{depth:0,customInspect:!1}))}}])&&a(e.prototype,r),c&&a(e,c),t}()},{buffer:117,util:115}],574:[function(t,e,r){(function(t){(function(){\"use strict\";function r(t,e){i(t,e),n(t)}function n(t){t._writableState&&!t._writableState.emitClose||t._readableState&&!t._readableState.emitClose||t.emit(\"close\")}function i(t,e){t.emit(\"error\",e)}e.exports={destroy:function(e,a){var o=this,s=this._readableState&&this._readableState.destroyed,l=this._writableState&&this._writableState.destroyed;return s||l?(a?a(e):e&&(this._writableState?this._writableState.errorEmitted||(this._writableState.errorEmitted=!0,t.nextTick(i,this,e)):t.nextTick(i,this,e)),this):(this._readableState&&(this._readableState.destroyed=!0),this._writableState&&(this._writableState.destroyed=!0),this._destroy(e||null,(function(e){!a&&e?o._writableState?o._writableState.errorEmitted?t.nextTick(n,o):(o._writableState.errorEmitted=!0,t.nextTick(r,o,e)):t.nextTick(r,o,e):a?(t.nextTick(n,o),a(e)):t.nextTick(n,o)})),this)},undestroy:function(){this._readableState&&(this._readableState.destroyed=!1,this._readableState.reading=!1,this._readableState.ended=!1,this._readableState.endEmitted=!1),this._writableState&&(this._writableState.destroyed=!1,this._writableState.ended=!1,this._writableState.ending=!1,this._writableState.finalCalled=!1,this._writableState.prefinished=!1,this._writableState.finished=!1,this._writableState.errorEmitted=!1)},errorOrDestroy:function(t,e){var r=t._readableState,n=t._writableState;r&&r.autoDestroy||n&&n.autoDestroy?t.destroy(e):t.emit(\"error\",e)}}}).call(this)}).call(this,t(\"_process\"))},{_process:524}],575:[function(t,e,r){\"use strict\";var n=t(\"../../../errors\").codes.ERR_STREAM_PREMATURE_CLOSE;function i(){}e.exports=function t(e,r,a){if(\"function\"==typeof r)return t(e,null,r);r||(r={}),a=function(t){var e=!1;return function(){if(!e){e=!0;for(var r=arguments.length,n=new Array(r),i=0;i<r;i++)n[i]=arguments[i];t.apply(this,n)}}}(a||i);var o=r.readable||!1!==r.readable&&e.readable,s=r.writable||!1!==r.writable&&e.writable,l=function(){e.writable||u()},c=e._writableState&&e._writableState.finished,u=function(){s=!1,c=!0,o||a.call(e)},f=e._readableState&&e._readableState.endEmitted,h=function(){o=!1,f=!0,s||a.call(e)},p=function(t){a.call(e,t)},d=function(){var t;return o&&!f?(e._readableState&&e._readableState.ended||(t=new n),a.call(e,t)):s&&!c?(e._writableState&&e._writableState.ended||(t=new n),a.call(e,t)):void 0},m=function(){e.req.on(\"finish\",u)};return!function(t){return t.setHeader&&\"function\"==typeof t.abort}(e)?s&&!e._writableState&&(e.on(\"end\",l),e.on(\"close\",l)):(e.on(\"complete\",u),e.on(\"abort\",d),e.req?m():e.on(\"request\",m)),e.on(\"end\",h),e.on(\"finish\",u),!1!==r.error&&e.on(\"error\",p),e.on(\"close\",d),function(){e.removeListener(\"complete\",u),e.removeListener(\"abort\",d),e.removeListener(\"request\",m),e.req&&e.req.removeListener(\"finish\",u),e.removeListener(\"end\",l),e.removeListener(\"close\",l),e.removeListener(\"finish\",u),e.removeListener(\"end\",h),e.removeListener(\"error\",p),e.removeListener(\"close\",d)}}},{\"../../../errors\":566}],576:[function(t,e,r){e.exports=function(){throw new Error(\"Readable.from is not available in the browser\")}},{}],577:[function(t,e,r){\"use strict\";var n;var i=t(\"../../../errors\").codes,a=i.ERR_MISSING_ARGS,o=i.ERR_STREAM_DESTROYED;function s(t){if(t)throw t}function l(e,r,i,a){a=function(t){var e=!1;return function(){e||(e=!0,t.apply(void 0,arguments))}}(a);var s=!1;e.on(\"close\",(function(){s=!0})),void 0===n&&(n=t(\"./end-of-stream\")),n(e,{readable:r,writable:i},(function(t){if(t)return a(t);s=!0,a()}));var l=!1;return function(t){if(!s&&!l)return l=!0,function(t){return t.setHeader&&\"function\"==typeof t.abort}(e)?e.abort():\"function\"==typeof e.destroy?e.destroy():void a(t||new o(\"pipe\"))}}function c(t){t()}function u(t,e){return t.pipe(e)}function f(t){return t.length?\"function\"!=typeof t[t.length-1]?s:t.pop():s}e.exports=function(){for(var t=arguments.length,e=new Array(t),r=0;r<t;r++)e[r]=arguments[r];var n,i=f(e);if(Array.isArray(e[0])&&(e=e[0]),e.length<2)throw new a(\"streams\");var o=e.map((function(t,r){var a=r<e.length-1;return l(t,a,r>0,(function(t){n||(n=t),t&&o.forEach(c),a||(o.forEach(c),i(n))}))}));return e.reduce(u)}},{\"../../../errors\":566,\"./end-of-stream\":575}],578:[function(t,e,r){\"use strict\";var n=t(\"../../../errors\").codes.ERR_INVALID_OPT_VALUE;e.exports={getHighWaterMark:function(t,e,r,i){var a=function(t,e,r){return null!=t.highWaterMark?t.highWaterMark:e?t[r]:null}(e,i,r);if(null!=a){if(!isFinite(a)||Math.floor(a)!==a||a<0)throw new n(i?r:\"highWaterMark\",a);return Math.floor(a)}return t.objectMode?16:16384}}},{\"../../../errors\":566}],579:[function(t,e,r){e.exports=t(\"events\").EventEmitter},{events:116}],580:[function(t,e,r){\"use strict\";var n=t(\"safe-buffer\").Buffer,i=n.isEncoding||function(t){switch((t=\"\"+t)&&t.toLowerCase()){case\"hex\":case\"utf8\":case\"utf-8\":case\"ascii\":case\"binary\":case\"base64\":case\"ucs2\":case\"ucs-2\":case\"utf16le\":case\"utf-16le\":case\"raw\":return!0;default:return!1}};function a(t){var e;switch(this.encoding=function(t){var e=function(t){if(!t)return\"utf8\";for(var e;;)switch(t){case\"utf8\":case\"utf-8\":return\"utf8\";case\"ucs2\":case\"ucs-2\":case\"utf16le\":case\"utf-16le\":return\"utf16le\";case\"latin1\":case\"binary\":return\"latin1\";case\"base64\":case\"ascii\":case\"hex\":return t;default:if(e)return;t=(\"\"+t).toLowerCase(),e=!0}}(t);if(\"string\"!=typeof e&&(n.isEncoding===i||!i(t)))throw new Error(\"Unknown encoding: \"+t);return e||t}(t),this.encoding){case\"utf16le\":this.text=l,this.end=c,e=4;break;case\"utf8\":this.fillLast=s,e=4;break;case\"base64\":this.text=u,this.end=f,e=3;break;default:return this.write=h,void(this.end=p)}this.lastNeed=0,this.lastTotal=0,this.lastChar=n.allocUnsafe(e)}function o(t){return t<=127?0:t>>5==6?2:t>>4==14?3:t>>3==30?4:t>>6==2?-1:-2}function s(t){var e=this.lastTotal-this.lastNeed,r=function(t,e,r){if(128!=(192&e[0]))return t.lastNeed=0,\"\\ufffd\";if(t.lastNeed>1&&e.length>1){if(128!=(192&e[1]))return t.lastNeed=1,\"\\ufffd\";if(t.lastNeed>2&&e.length>2&&128!=(192&e[2]))return t.lastNeed=2,\"\\ufffd\"}}(this,t);return void 0!==r?r:this.lastNeed<=t.length?(t.copy(this.lastChar,e,0,this.lastNeed),this.lastChar.toString(this.encoding,0,this.lastTotal)):(t.copy(this.lastChar,e,0,t.length),void(this.lastNeed-=t.length))}function l(t,e){if((t.length-e)%2==0){var r=t.toString(\"utf16le\",e);if(r){var n=r.charCodeAt(r.length-1);if(n>=55296&&n<=56319)return this.lastNeed=2,this.lastTotal=4,this.lastChar[0]=t[t.length-2],this.lastChar[1]=t[t.length-1],r.slice(0,-1)}return r}return this.lastNeed=1,this.lastTotal=2,this.lastChar[0]=t[t.length-1],t.toString(\"utf16le\",e,t.length-1)}function c(t){var e=t&&t.length?this.write(t):\"\";if(this.lastNeed){var r=this.lastTotal-this.lastNeed;return e+this.lastChar.toString(\"utf16le\",0,r)}return e}function u(t,e){var r=(t.length-e)%3;return 0===r?t.toString(\"base64\",e):(this.lastNeed=3-r,this.lastTotal=3,1===r?this.lastChar[0]=t[t.length-1]:(this.lastChar[0]=t[t.length-2],this.lastChar[1]=t[t.length-1]),t.toString(\"base64\",e,t.length-r))}function f(t){var e=t&&t.length?this.write(t):\"\";return this.lastNeed?e+this.lastChar.toString(\"base64\",0,3-this.lastNeed):e}function h(t){return t.toString(this.encoding)}function p(t){return t&&t.length?this.write(t):\"\"}r.StringDecoder=a,a.prototype.write=function(t){if(0===t.length)return\"\";var e,r;if(this.lastNeed){if(void 0===(e=this.fillLast(t)))return\"\";r=this.lastNeed,this.lastNeed=0}else r=0;return r<t.length?e?e+this.text(t,r):this.text(t,r):e||\"\"},a.prototype.end=function(t){var e=t&&t.length?this.write(t):\"\";return this.lastNeed?e+\"\\ufffd\":e},a.prototype.text=function(t,e){var r=function(t,e,r){var n=e.length-1;if(n<r)return 0;var i=o(e[n]);if(i>=0)return i>0&&(t.lastNeed=i-1),i;if(--n<r||-2===i)return 0;if((i=o(e[n]))>=0)return i>0&&(t.lastNeed=i-2),i;if(--n<r||-2===i)return 0;if((i=o(e[n]))>=0)return i>0&&(2===i?i=0:t.lastNeed=i-3),i;return 0}(this,t,e);if(!this.lastNeed)return t.toString(\"utf8\",e);this.lastTotal=r;var n=t.length-(r-this.lastNeed);return t.copy(this.lastChar,0,n),t.toString(\"utf8\",e,n)},a.prototype.fillLast=function(t){if(this.lastNeed<=t.length)return t.copy(this.lastChar,this.lastTotal-this.lastNeed,0,this.lastNeed),this.lastChar.toString(this.encoding,0,this.lastTotal);t.copy(this.lastChar,this.lastTotal-this.lastNeed,0,t.length),this.lastNeed-=t.length}},{\"safe-buffer\":550}],581:[function(t,e,r){(function(r,n){(function(){var r=t(\"assert\"),i=t(\"debug\")(\"stream-parser\");e.exports=function(t){var e=t&&\"function\"==typeof t._transform,r=t&&\"function\"==typeof t._write;if(!e&&!r)throw new Error(\"must pass a Writable or Transform stream in\");i(\"extending Parser into stream\"),t._bytes=o,t._skipBytes=s,e&&(t._passthrough=l);e?t._transform=u:t._write=c};function a(t){i(\"initializing parser stream\"),t._parserBytesLeft=0,t._parserBuffers=[],t._parserBuffered=0,t._parserState=-1,t._parserCallback=null,\"function\"==typeof t.push&&(t._parserOutput=t.push.bind(t)),t._parserInit=!0}function o(t,e){r(!this._parserCallback,'there is already a \"callback\" set!'),r(isFinite(t)&&t>0,'can only buffer a finite number of bytes > 0, got \"'+t+'\"'),this._parserInit||a(this),i(\"buffering %o bytes\",t),this._parserBytesLeft=t,this._parserCallback=e,this._parserState=0}function s(t,e){r(!this._parserCallback,'there is already a \"callback\" set!'),r(t>0,'can only skip > 0 bytes, got \"'+t+'\"'),this._parserInit||a(this),i(\"skipping %o bytes\",t),this._parserBytesLeft=t,this._parserCallback=e,this._parserState=1}function l(t,e){r(!this._parserCallback,'There is already a \"callback\" set!'),r(t>0,'can only pass through > 0 bytes, got \"'+t+'\"'),this._parserInit||a(this),i(\"passing through %o bytes\",t),this._parserBytesLeft=t,this._parserCallback=e,this._parserState=2}function c(t,e,r){this._parserInit||a(this),i(\"write(%o bytes)\",t.length),\"function\"==typeof e&&(r=e),h(this,t,null,r)}function u(t,e,r){this._parserInit||a(this),i(\"transform(%o bytes)\",t.length),\"function\"!=typeof e&&(e=this._parserOutput),h(this,t,e,r)}function f(t,e,r,a){if(t._parserBytesLeft-=e.length,i(\"%o bytes left for stream piece\",t._parserBytesLeft),0===t._parserState?(t._parserBuffers.push(e),t._parserBuffered+=e.length):2===t._parserState&&r(e),0!==t._parserBytesLeft)return a;var o=t._parserCallback;if(o&&0===t._parserState&&t._parserBuffers.length>1&&(e=n.concat(t._parserBuffers,t._parserBuffered)),0!==t._parserState&&(e=null),t._parserCallback=null,t._parserBuffered=0,t._parserState=-1,t._parserBuffers.splice(0),o){var s=[];e&&s.push(e),r&&s.push(r);var l=o.length>s.length;l&&s.push(p(a));var c=o.apply(t,s);if(!l||a===c)return a}}var h=p((function t(e,r,n,i){return e._parserBytesLeft<=0?i(new Error(\"got data but not currently parsing anything\")):r.length<=e._parserBytesLeft?function(){return f(e,r,n,i)}:function(){var a=r.slice(0,e._parserBytesLeft);return f(e,a,n,(function(o){return o?i(o):r.length>a.length?function(){return t(e,r.slice(a.length),n,i)}:void 0}))}}));function p(t){return function(){for(var e=t.apply(this,arguments);\"function\"==typeof e;)e=e();return e}}}).call(this)}).call(this,t(\"_process\"),t(\"buffer\").Buffer)},{_process:524,assert:80,buffer:117,debug:582}],582:[function(t,e,r){(function(n){(function(){function i(){var t;try{t=r.storage.debug}catch(t){}return!t&&void 0!==n&&\"env\"in n&&(t=n.env.DEBUG),t}(r=e.exports=t(\"./debug\")).log=function(){return\"object\"==typeof console&&console.log&&Function.prototype.apply.call(console.log,console,arguments)},r.formatArgs=function(t){var e=this.useColors;if(t[0]=(e?\"%c\":\"\")+this.namespace+(e?\" %c\":\" \")+t[0]+(e?\"%c \":\" \")+\"+\"+r.humanize(this.diff),!e)return;var n=\"color: \"+this.color;t.splice(1,0,n,\"color: inherit\");var i=0,a=0;t[0].replace(/%[a-zA-Z%]/g,(function(t){\"%%\"!==t&&(i++,\"%c\"===t&&(a=i))})),t.splice(a,0,n)},r.save=function(t){try{null==t?r.storage.removeItem(\"debug\"):r.storage.debug=t}catch(t){}},r.load=i,r.useColors=function(){if(\"undefined\"!=typeof window&&window.process&&\"renderer\"===window.process.type)return!0;return\"undefined\"!=typeof document&&document.documentElement&&document.documentElement.style&&document.documentElement.style.WebkitAppearance||\"undefined\"!=typeof window&&window.console&&(window.console.firebug||window.console.exception&&window.console.table)||\"undefined\"!=typeof navigator&&navigator.userAgent&&navigator.userAgent.toLowerCase().match(/firefox\\/(\\d+)/)&&parseInt(RegExp.$1,10)>=31||\"undefined\"!=typeof navigator&&navigator.userAgent&&navigator.userAgent.toLowerCase().match(/applewebkit\\/(\\d+)/)},r.storage=\"undefined\"!=typeof chrome&&void 0!==chrome.storage?chrome.storage.local:function(){try{return window.localStorage}catch(t){}}(),r.colors=[\"lightseagreen\",\"forestgreen\",\"goldenrod\",\"dodgerblue\",\"darkorchid\",\"crimson\"],r.formatters.j=function(t){try{return JSON.stringify(t)}catch(t){return\"[UnexpectedJSONParseError]: \"+t.message}},r.enable(i())}).call(this)}).call(this,t(\"_process\"))},{\"./debug\":583,_process:524}],583:[function(t,e,r){var n;function i(t){function e(){if(e.enabled){var t=e,i=+new Date,a=i-(n||i);t.diff=a,t.prev=n,t.curr=i,n=i;for(var o=new Array(arguments.length),s=0;s<o.length;s++)o[s]=arguments[s];o[0]=r.coerce(o[0]),\"string\"!=typeof o[0]&&o.unshift(\"%O\");var l=0;o[0]=o[0].replace(/%([a-zA-Z%])/g,(function(e,n){if(\"%%\"===e)return e;l++;var i=r.formatters[n];if(\"function\"==typeof i){var a=o[l];e=i.call(t,a),o.splice(l,1),l--}return e})),r.formatArgs.call(t,o);var c=e.log||r.log||console.log.bind(console);c.apply(t,o)}}return e.namespace=t,e.enabled=r.enabled(t),e.useColors=r.useColors(),e.color=function(t){var e,n=0;for(e in t)n=(n<<5)-n+t.charCodeAt(e),n|=0;return r.colors[Math.abs(n)%r.colors.length]}(t),\"function\"==typeof r.init&&r.init(e),e}(r=e.exports=i.debug=i.default=i).coerce=function(t){return t instanceof Error?t.stack||t.message:t},r.disable=function(){r.enable(\"\")},r.enable=function(t){r.save(t),r.names=[],r.skips=[];for(var e=(\"string\"==typeof t?t:\"\").split(/[\\s,]+/),n=e.length,i=0;i<n;i++)e[i]&&(\"-\"===(t=e[i].replace(/\\*/g,\".*?\"))[0]?r.skips.push(new RegExp(\"^\"+t.substr(1)+\"$\")):r.names.push(new RegExp(\"^\"+t+\"$\")))},r.enabled=function(t){var e,n;for(e=0,n=r.skips.length;e<n;e++)if(r.skips[e].test(t))return!1;for(e=0,n=r.names.length;e<n;e++)if(r.names[e].test(t))return!0;return!1},r.humanize=t(\"ms\"),r.names=[],r.skips=[],r.formatters={}},{ms:584}],584:[function(t,e,r){var n=1e3,i=6e4,a=60*i,o=24*a;function s(t,e,r){if(!(t<e))return t<1.5*e?Math.floor(t/e)+\" \"+r:Math.ceil(t/e)+\" \"+r+\"s\"}e.exports=function(t,e){e=e||{};var r,l=typeof t;if(\"string\"===l&&t.length>0)return function(t){if((t=String(t)).length>100)return;var e=/^((?:\\d+)?\\.?\\d+) *(milliseconds?|msecs?|ms|seconds?|secs?|s|minutes?|mins?|m|hours?|hrs?|h|days?|d|years?|yrs?|y)?$/i.exec(t);if(!e)return;var r=parseFloat(e[1]);switch((e[2]||\"ms\").toLowerCase()){case\"years\":case\"year\":case\"yrs\":case\"yr\":case\"y\":return 315576e5*r;case\"days\":case\"day\":case\"d\":return r*o;case\"hours\":case\"hour\":case\"hrs\":case\"hr\":case\"h\":return r*a;case\"minutes\":case\"minute\":case\"mins\":case\"min\":case\"m\":return r*i;case\"seconds\":case\"second\":case\"secs\":case\"sec\":case\"s\":return r*n;case\"milliseconds\":case\"millisecond\":case\"msecs\":case\"msec\":case\"ms\":return r;default:return}}(t);if(\"number\"===l&&!1===isNaN(t))return e.long?s(r=t,o,\"day\")||s(r,a,\"hour\")||s(r,i,\"minute\")||s(r,n,\"second\")||r+\" ms\":function(t){if(t>=o)return Math.round(t/o)+\"d\";if(t>=a)return Math.round(t/a)+\"h\";if(t>=i)return Math.round(t/i)+\"m\";if(t>=n)return Math.round(t/n)+\"s\";return t+\"ms\"}(t);throw new Error(\"val is not a non-empty string or a valid number. val=\"+JSON.stringify(t))}},{}],585:[function(t,e,r){\"use strict\";var n=t(\"parenthesis\");e.exports=function(t,e,r){if(null==t)throw Error(\"First argument should be a string\");if(null==e)throw Error(\"Separator should be a string or a RegExp\");r?(\"string\"==typeof r||Array.isArray(r))&&(r={ignore:r}):r={},null==r.escape&&(r.escape=!0),null==r.ignore?r.ignore=[\"[]\",\"()\",\"{}\",\"<>\",'\"\"',\"''\",\"``\",\"\\u201c\\u201d\",\"\\xab\\xbb\"]:(\"string\"==typeof r.ignore&&(r.ignore=[r.ignore]),r.ignore=r.ignore.map((function(t){return 1===t.length&&(t+=t),t})));var i=n.parse(t,{flat:!0,brackets:r.ignore}),a=i[0].split(e);if(r.escape){for(var o=[],s=0;s<a.length;s++){var l=a[s],c=a[s+1];\"\\\\\"===l[l.length-1]&&\"\\\\\"!==l[l.length-2]?(o.push(l+e+c),s++):o.push(l)}a=o}for(s=0;s<a.length;s++)i[0]=a[s],a[s]=n.stringify(i,{flat:!0});return a}},{parenthesis:487}],586:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=t.length,r=new Array(e),n=new Array(e),i=new Array(e),a=new Array(e),o=new Array(e),s=new Array(e),l=0;l<e;++l)r[l]=-1,n[l]=0,i[l]=!1,a[l]=0,o[l]=-1,s[l]=[];var c,u=0,f=[],h=[];function p(e){var l=[e],c=[e];for(r[e]=n[e]=u,i[e]=!0,u+=1;c.length>0;){e=c[c.length-1];var p=t[e];if(a[e]<p.length){for(var d=a[e];d<p.length;++d){var m=p[d];if(r[m]<0){r[m]=n[m]=u,i[m]=!0,u+=1,l.push(m),c.push(m);break}i[m]&&(n[e]=0|Math.min(n[e],n[m])),o[m]>=0&&s[e].push(o[m])}a[e]=d}else{if(n[e]===r[e]){var g=[],v=[],y=0;for(d=l.length-1;d>=0;--d){var x=l[d];if(i[x]=!1,g.push(x),v.push(s[x]),y+=s[x].length,o[x]=f.length,x===e){l.length=d;break}}f.push(g);var b=new Array(y);for(d=0;d<v.length;d++)for(var _=0;_<v[d].length;_++)b[--y]=v[d][_];h.push(b)}c.pop()}}}for(l=0;l<e;++l)r[l]<0&&p(l);for(l=0;l<h.length;l++){var d=h[l];if(0!==d.length){d.sort((function(t,e){return t-e})),c=[d[0]];for(var m=1;m<d.length;m++)d[m]!==d[m-1]&&c.push(d[m]);h[l]=c}}return{components:f,adjacencyList:h}}},{}],587:[function(t,e,r){\"use strict\";e.exports=function(t,e){if(t.dimension<=0)return{positions:[],cells:[]};if(1===t.dimension)return function(t,e){for(var r=a(t,e),n=r.length,i=new Array(n),o=new Array(n),s=0;s<n;++s)i[s]=[r[s]],o[s]=[s];return{positions:i,cells:o}}(t,e);var r=t.order.join()+\"-\"+t.dtype,s=o[r];e=+e||0;s||(s=o[r]=function(t,e){var r=t.length,a=[\"'use strict';\"],o=\"surfaceNets\"+t.join(\"_\")+\"d\"+e;a.push(\"var contour=genContour({\",\"order:[\",t.join(),\"],\",\"scalarArguments: 3,\",\"phase:function phaseFunc(p,a,b,c) { return (p > c)|0 },\"),\"generic\"===e&&a.push(\"getters:[0],\");for(var s=[],l=[],c=0;c<r;++c)s.push(\"d\"+c),l.push(\"d\"+c);for(c=0;c<1<<r;++c)s.push(\"v\"+c),l.push(\"v\"+c);for(c=0;c<1<<r;++c)s.push(\"p\"+c),l.push(\"p\"+c);s.push(\"a\",\"b\",\"c\"),l.push(\"a\",\"c\"),a.push(\"vertex:function vertexFunc(\",s.join(),\"){\");var u=[];for(c=0;c<1<<r;++c)u.push(\"(p\"+c+\"<<\"+c+\")\");a.push(\"var m=(\",u.join(\"+\"),\")|0;if(m===0||m===\",(1<<(1<<r))-1,\"){return}\");var f=[],h=[];1<<(1<<r)<=128?(a.push(\"switch(m){\"),h=a):a.push(\"switch(m>>>7){\");for(c=0;c<1<<(1<<r);++c){if(1<<(1<<r)>128&&c%128==0){f.length>0&&h.push(\"}}\");var p=\"vExtra\"+f.length;a.push(\"case \",c>>>7,\":\",p,\"(m&0x7f,\",l.join(),\");break;\"),h=[\"function \",p,\"(m,\",l.join(),\"){switch(m){\"],f.push(h)}h.push(\"case \",127&c,\":\");for(var d=new Array(r),m=new Array(r),g=new Array(r),v=new Array(r),y=0,x=0;x<r;++x)d[x]=[],m[x]=[],g[x]=0,v[x]=0;for(x=0;x<1<<r;++x)for(var b=0;b<r;++b){var _=x^1<<b;if(!(_>x)&&!(c&1<<_)!=!(c&1<<x)){var w=1;c&1<<_?m[b].push(\"v\"+_+\"-v\"+x):(m[b].push(\"v\"+x+\"-v\"+_),w=-w),w<0?(d[b].push(\"-v\"+x+\"-v\"+_),g[b]+=2):(d[b].push(\"v\"+x+\"+v\"+_),g[b]-=2),y+=1;for(var T=0;T<r;++T)T!==b&&(_&1<<T?v[T]+=1:v[T]-=1)}}var k=[];for(b=0;b<r;++b)if(0===d[b].length)k.push(\"d\"+b+\"-0.5\");else{var M=\"\";g[b]<0?M=g[b]+\"*c\":g[b]>0&&(M=\"+\"+g[b]+\"*c\");var A=d[b].length/y*.5,S=.5+v[b]/y*.5;k.push(\"d\"+b+\"-\"+S+\"-\"+A+\"*(\"+d[b].join(\"+\")+M+\")/(\"+m[b].join(\"+\")+\")\")}h.push(\"a.push([\",k.join(),\"]);\",\"break;\")}a.push(\"}},\"),f.length>0&&h.push(\"}}\");var E=[];for(c=0;c<1<<r-1;++c)E.push(\"v\"+c);E.push(\"c0\",\"c1\",\"p0\",\"p1\",\"a\",\"b\",\"c\"),a.push(\"cell:function cellFunc(\",E.join(),\"){\");var L=i(r-1);a.push(\"if(p0){b.push(\",L.map((function(t){return\"[\"+t.map((function(t){return\"v\"+t}))+\"]\"})).join(),\")}else{b.push(\",L.map((function(t){var e=t.slice();return e.reverse(),\"[\"+e.map((function(t){return\"v\"+t}))+\"]\"})).join(),\")}}});function \",o,\"(array,level){var verts=[],cells=[];contour(array,verts,cells,level);return {positions:verts,cells:cells};} return \",o,\";\");for(c=0;c<f.length;++c)a.push(f[c].join(\"\"));return new Function(\"genContour\",a.join(\"\"))(n)}(t.order,t.dtype));return s(t,e)};var n=t(\"ndarray-extract-contour\"),i=t(\"triangulate-hypercube\"),a=t(\"zero-crossings\");var o={}},{\"ndarray-extract-contour\":471,\"triangulate-hypercube\":598,\"zero-crossings\":643}],588:[function(t,e,r){\"use strict\";Object.defineProperty(r,\"__esModule\",{value:!0});var n=function(t,e){if(Array.isArray(t))return t;if(Symbol.iterator in Object(t))return function(t,e){var r=[],n=!0,i=!1,a=void 0;try{for(var o,s=t[Symbol.iterator]();!(n=(o=s.next()).done)&&(r.push(o.value),!e||r.length!==e);n=!0);}catch(t){i=!0,a=t}finally{try{!n&&s.return&&s.return()}finally{if(i)throw a}}return r}(t,e);throw new TypeError(\"Invalid attempt to destructure non-iterable instance\")},i=2*Math.PI,a=function(t,e,r,n,i,a,o){var s=t.x,l=t.y;return{x:n*(s*=e)-i*(l*=r)+a,y:i*s+n*l+o}},o=function(t,e){var r=1.5707963267948966===e?.551915024494:-1.5707963267948966===e?-.551915024494:4/3*Math.tan(e/4),n=Math.cos(t),i=Math.sin(t),a=Math.cos(t+e),o=Math.sin(t+e);return[{x:n-i*r,y:i+n*r},{x:a+o*r,y:o-a*r},{x:a,y:o}]},s=function(t,e,r,n){var i=t*r+e*n;return i>1&&(i=1),i<-1&&(i=-1),(t*n-e*r<0?-1:1)*Math.acos(i)};r.default=function(t){var e=t.px,r=t.py,l=t.cx,c=t.cy,u=t.rx,f=t.ry,h=t.xAxisRotation,p=void 0===h?0:h,d=t.largeArcFlag,m=void 0===d?0:d,g=t.sweepFlag,v=void 0===g?0:g,y=[];if(0===u||0===f)return[];var x=Math.sin(p*i/360),b=Math.cos(p*i/360),_=b*(e-l)/2+x*(r-c)/2,w=-x*(e-l)/2+b*(r-c)/2;if(0===_&&0===w)return[];u=Math.abs(u),f=Math.abs(f);var T=Math.pow(_,2)/Math.pow(u,2)+Math.pow(w,2)/Math.pow(f,2);T>1&&(u*=Math.sqrt(T),f*=Math.sqrt(T));var k=function(t,e,r,n,a,o,l,c,u,f,h,p){var d=Math.pow(a,2),m=Math.pow(o,2),g=Math.pow(h,2),v=Math.pow(p,2),y=d*m-d*v-m*g;y<0&&(y=0),y/=d*v+m*g;var x=(y=Math.sqrt(y)*(l===c?-1:1))*a/o*p,b=y*-o/a*h,_=f*x-u*b+(t+r)/2,w=u*x+f*b+(e+n)/2,T=(h-x)/a,k=(p-b)/o,M=(-h-x)/a,A=(-p-b)/o,S=s(1,0,T,k),E=s(T,k,M,A);return 0===c&&E>0&&(E-=i),1===c&&E<0&&(E+=i),[_,w,S,E]}(e,r,l,c,u,f,m,v,x,b,_,w),M=n(k,4),A=M[0],S=M[1],E=M[2],L=M[3],C=Math.abs(L)/(i/4);Math.abs(1-C)<1e-7&&(C=1);var P=Math.max(Math.ceil(C),1);L/=P;for(var I=0;I<P;I++)y.push(o(E,L)),E+=L;return y.map((function(t){var e=a(t[0],u,f,b,x,A,S),r=e.x,n=e.y,i=a(t[1],u,f,b,x,A,S),o=i.x,s=i.y,l=a(t[2],u,f,b,x,A,S);return{x1:r,y1:n,x2:o,y2:s,x:l.x,y:l.y}}))},e.exports=r.default},{}],589:[function(t,e,r){\"use strict\";var n=t(\"parse-svg-path\"),i=t(\"abs-svg-path\"),a=t(\"normalize-svg-path\"),o=t(\"is-svg-path\"),s=t(\"assert\");e.exports=function(t){Array.isArray(t)&&1===t.length&&\"string\"==typeof t[0]&&(t=t[0]);\"string\"==typeof t&&(s(o(t),\"String is not an SVG path.\"),t=n(t));if(s(Array.isArray(t),\"Argument should be a string or an array of path segments.\"),t=i(t),!(t=a(t)).length)return[0,0,0,0];for(var e=[1/0,1/0,-1/0,-1/0],r=0,l=t.length;r<l;r++)for(var c=t[r].slice(1),u=0;u<c.length;u+=2)c[u+0]<e[0]&&(e[0]=c[u+0]),c[u+1]<e[1]&&(e[1]=c[u+1]),c[u+0]>e[2]&&(e[2]=c[u+0]),c[u+1]>e[3]&&(e[3]=c[u+1]);return e}},{\"abs-svg-path\":71,assert:80,\"is-svg-path\":455,\"normalize-svg-path\":590,\"parse-svg-path\":489}],590:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e,r=[],o=0,s=0,l=0,c=0,u=null,f=null,h=0,p=0,d=0,m=t.length;d<m;d++){var g=t[d],v=g[0];switch(v){case\"M\":l=g[1],c=g[2];break;case\"A\":var y=n({px:h,py:p,cx:g[6],cy:g[7],rx:g[1],ry:g[2],xAxisRotation:g[3],largeArcFlag:g[4],sweepFlag:g[5]});if(!y.length)continue;for(var x,b=0;b<y.length;b++)x=y[b],g=[\"C\",x.x1,x.y1,x.x2,x.y2,x.x,x.y],b<y.length-1&&r.push(g);break;case\"S\":var _=h,w=p;\"C\"!=e&&\"S\"!=e||(_+=_-o,w+=w-s),g=[\"C\",_,w,g[1],g[2],g[3],g[4]];break;case\"T\":\"Q\"==e||\"T\"==e?(u=2*h-u,f=2*p-f):(u=h,f=p),g=a(h,p,u,f,g[1],g[2]);break;case\"Q\":u=g[1],f=g[2],g=a(h,p,g[1],g[2],g[3],g[4]);break;case\"L\":g=i(h,p,g[1],g[2]);break;case\"H\":g=i(h,p,g[1],p);break;case\"V\":g=i(h,p,h,g[1]);break;case\"Z\":g=i(h,p,l,c)}e=v,h=g[g.length-2],p=g[g.length-1],g.length>4?(o=g[g.length-4],s=g[g.length-3]):(o=h,s=p),r.push(g)}return r};var n=t(\"svg-arc-to-cubic-bezier\");function i(t,e,r,n){return[\"C\",t,e,r,n,r,n]}function a(t,e,r,n,i,a){return[\"C\",t/3+2/3*r,e/3+2/3*n,i/3+2/3*r,a/3+2/3*n,i,a]}},{\"svg-arc-to-cubic-bezier\":588}],591:[function(t,e,r){\"use strict\";var n,i=t(\"svg-path-bounds\"),a=t(\"parse-svg-path\"),o=t(\"draw-svg-path\"),s=t(\"is-svg-path\"),l=t(\"bitmap-sdf\"),c=document.createElement(\"canvas\"),u=c.getContext(\"2d\");e.exports=function(t,e){if(!s(t))throw Error(\"Argument should be valid svg path string\");e||(e={});var r,f;e.shape?(r=e.shape[0],f=e.shape[1]):(r=c.width=e.w||e.width||200,f=c.height=e.h||e.height||200);var h=Math.min(r,f),p=e.stroke||0,d=e.viewbox||e.viewBox||i(t),m=[r/(d[2]-d[0]),f/(d[3]-d[1])],g=Math.min(m[0]||0,m[1]||0)/2;u.fillStyle=\"black\",u.fillRect(0,0,r,f),u.fillStyle=\"white\",p&&(\"number\"!=typeof p&&(p=1),u.strokeStyle=p>0?\"white\":\"black\",u.lineWidth=Math.abs(p));if(u.translate(.5*r,.5*f),u.scale(g,g),function(){if(null!=n)return n;var t=document.createElement(\"canvas\").getContext(\"2d\");if(t.canvas.width=t.canvas.height=1,!window.Path2D)return n=!1;var e=new Path2D(\"M0,0h1v1h-1v-1Z\");t.fillStyle=\"black\",t.fill(e);var r=t.getImageData(0,0,1,1);return n=r&&r.data&&255===r.data[3]}()){var v=new Path2D(t);u.fill(v),p&&u.stroke(v)}else{var y=a(t);o(u,y),u.fill(),p&&u.stroke()}return u.setTransform(1,0,0,1,0,0),l(u,{cutoff:null!=e.cutoff?e.cutoff:.5,radius:null!=e.radius?e.radius:.5*h})}},{\"bitmap-sdf\":105,\"draw-svg-path\":179,\"is-svg-path\":455,\"parse-svg-path\":489,\"svg-path-bounds\":589}],592:[function(t,e,r){(function(r){(function(){\"use strict\";e.exports=function t(e,r,i){i=i||{};var o=a[e];o||(o=a[e]={\" \":{data:new Float32Array(0),shape:.2}});var s=o[r];if(!s)if(r.length<=1||!/\\d/.test(r))s=o[r]=function(t){for(var e=t.cells,r=t.positions,n=new Float32Array(6*e.length),i=0,a=0,o=0;o<e.length;++o)for(var s=e[o],l=0;l<3;++l){var c=r[s[l]];n[i++]=c[0],n[i++]=c[1]+1.4,a=Math.max(c[0],a)}return{data:n,shape:a}}(n(r,{triangles:!0,font:e,textAlign:i.textAlign||\"left\",textBaseline:\"alphabetic\",styletags:{breaklines:!0,bolds:!0,italics:!0,subscripts:!0,superscripts:!0}}));else{for(var l=r.split(/(\\d|\\s)/),c=new Array(l.length),u=0,f=0,h=0;h<l.length;++h)c[h]=t(e,l[h]),u+=c[h].data.length,f+=c[h].shape,h>0&&(f+=.02);var p=new Float32Array(u),d=0,m=-.5*f;for(h=0;h<c.length;++h){for(var g=c[h].data,v=0;v<g.length;v+=2)p[d++]=g[v]+m,p[d++]=g[v+1];m+=c[h].shape+.02}s=o[r]={data:p,shape:f}}return s};var n=t(\"vectorize-text\"),i=window||r.global||{},a=i.__TEXT_CACHE||{};i.__TEXT_CACHE={}}).call(this)}).call(this,t(\"_process\"))},{_process:524,\"vectorize-text\":619}],593:[function(t,e,r){(function(e,n){(function(){var i=t(\"process/browser.js\").nextTick,a=Function.prototype.apply,o=Array.prototype.slice,s={},l=0;function c(t,e){this._id=t,this._clearFn=e}r.setTimeout=function(){return new c(a.call(setTimeout,window,arguments),clearTimeout)},r.setInterval=function(){return new c(a.call(setInterval,window,arguments),clearInterval)},r.clearTimeout=r.clearInterval=function(t){t.close()},c.prototype.unref=c.prototype.ref=function(){},c.prototype.close=function(){this._clearFn.call(window,this._id)},r.enroll=function(t,e){clearTimeout(t._idleTimeoutId),t._idleTimeout=e},r.unenroll=function(t){clearTimeout(t._idleTimeoutId),t._idleTimeout=-1},r._unrefActive=r.active=function(t){clearTimeout(t._idleTimeoutId);var e=t._idleTimeout;e>=0&&(t._idleTimeoutId=setTimeout((function(){t._onTimeout&&t._onTimeout()}),e))},r.setImmediate=\"function\"==typeof e?e:function(t){var e=l++,n=!(arguments.length<2)&&o.call(arguments,1);return s[e]=!0,i((function(){s[e]&&(n?t.apply(null,n):t.call(null),r.clearImmediate(e))})),e},r.clearImmediate=\"function\"==typeof n?n:function(t){delete s[t]}}).call(this)}).call(this,t(\"timers\").setImmediate,t(\"timers\").clearImmediate)},{\"process/browser.js\":524,timers:593}],594:[function(t,e,r){!function(t){var r=/^\\s+/,n=/\\s+$/,i=0,a=t.round,o=t.min,s=t.max,l=t.random;function c(e,l){if(l=l||{},(e=e||\"\")instanceof c)return e;if(!(this instanceof c))return new c(e,l);var u=function(e){var i={r:0,g:0,b:0},a=1,l=null,c=null,u=null,f=!1,h=!1;\"string\"==typeof e&&(e=function(t){t=t.replace(r,\"\").replace(n,\"\").toLowerCase();var e,i=!1;if(S[t])t=S[t],i=!0;else if(\"transparent\"==t)return{r:0,g:0,b:0,a:0,format:\"name\"};if(e=j.rgb.exec(t))return{r:e[1],g:e[2],b:e[3]};if(e=j.rgba.exec(t))return{r:e[1],g:e[2],b:e[3],a:e[4]};if(e=j.hsl.exec(t))return{h:e[1],s:e[2],l:e[3]};if(e=j.hsla.exec(t))return{h:e[1],s:e[2],l:e[3],a:e[4]};if(e=j.hsv.exec(t))return{h:e[1],s:e[2],v:e[3]};if(e=j.hsva.exec(t))return{h:e[1],s:e[2],v:e[3],a:e[4]};if(e=j.hex8.exec(t))return{r:I(e[1]),g:I(e[2]),b:I(e[3]),a:R(e[4]),format:i?\"name\":\"hex8\"};if(e=j.hex6.exec(t))return{r:I(e[1]),g:I(e[2]),b:I(e[3]),format:i?\"name\":\"hex\"};if(e=j.hex4.exec(t))return{r:I(e[1]+\"\"+e[1]),g:I(e[2]+\"\"+e[2]),b:I(e[3]+\"\"+e[3]),a:R(e[4]+\"\"+e[4]),format:i?\"name\":\"hex8\"};if(e=j.hex3.exec(t))return{r:I(e[1]+\"\"+e[1]),g:I(e[2]+\"\"+e[2]),b:I(e[3]+\"\"+e[3]),format:i?\"name\":\"hex\"};return!1}(e));\"object\"==typeof e&&(U(e.r)&&U(e.g)&&U(e.b)?(p=e.r,d=e.g,m=e.b,i={r:255*C(p,255),g:255*C(d,255),b:255*C(m,255)},f=!0,h=\"%\"===String(e.r).substr(-1)?\"prgb\":\"rgb\"):U(e.h)&&U(e.s)&&U(e.v)?(l=z(e.s),c=z(e.v),i=function(e,r,n){e=6*C(e,360),r=C(r,100),n=C(n,100);var i=t.floor(e),a=e-i,o=n*(1-r),s=n*(1-a*r),l=n*(1-(1-a)*r),c=i%6;return{r:255*[n,s,o,o,l,n][c],g:255*[l,n,n,s,o,o][c],b:255*[o,o,l,n,n,s][c]}}(e.h,l,c),f=!0,h=\"hsv\"):U(e.h)&&U(e.s)&&U(e.l)&&(l=z(e.s),u=z(e.l),i=function(t,e,r){var n,i,a;function o(t,e,r){return r<0&&(r+=1),r>1&&(r-=1),r<1/6?t+6*(e-t)*r:r<.5?e:r<2/3?t+(e-t)*(2/3-r)*6:t}if(t=C(t,360),e=C(e,100),r=C(r,100),0===e)n=i=a=r;else{var s=r<.5?r*(1+e):r+e-r*e,l=2*r-s;n=o(l,s,t+1/3),i=o(l,s,t),a=o(l,s,t-1/3)}return{r:255*n,g:255*i,b:255*a}}(e.h,l,u),f=!0,h=\"hsl\"),e.hasOwnProperty(\"a\")&&(a=e.a));var p,d,m;return a=L(a),{ok:f,format:e.format||h,r:o(255,s(i.r,0)),g:o(255,s(i.g,0)),b:o(255,s(i.b,0)),a:a}}(e);this._originalInput=e,this._r=u.r,this._g=u.g,this._b=u.b,this._a=u.a,this._roundA=a(100*this._a)/100,this._format=l.format||u.format,this._gradientType=l.gradientType,this._r<1&&(this._r=a(this._r)),this._g<1&&(this._g=a(this._g)),this._b<1&&(this._b=a(this._b)),this._ok=u.ok,this._tc_id=i++}function u(t,e,r){t=C(t,255),e=C(e,255),r=C(r,255);var n,i,a=s(t,e,r),l=o(t,e,r),c=(a+l)/2;if(a==l)n=i=0;else{var u=a-l;switch(i=c>.5?u/(2-a-l):u/(a+l),a){case t:n=(e-r)/u+(e<r?6:0);break;case e:n=(r-t)/u+2;break;case r:n=(t-e)/u+4}n/=6}return{h:n,s:i,l:c}}function f(t,e,r){t=C(t,255),e=C(e,255),r=C(r,255);var n,i,a=s(t,e,r),l=o(t,e,r),c=a,u=a-l;if(i=0===a?0:u/a,a==l)n=0;else{switch(a){case t:n=(e-r)/u+(e<r?6:0);break;case e:n=(r-t)/u+2;break;case r:n=(t-e)/u+4}n/=6}return{h:n,s:i,v:c}}function h(t,e,r,n){var i=[O(a(t).toString(16)),O(a(e).toString(16)),O(a(r).toString(16))];return n&&i[0].charAt(0)==i[0].charAt(1)&&i[1].charAt(0)==i[1].charAt(1)&&i[2].charAt(0)==i[2].charAt(1)?i[0].charAt(0)+i[1].charAt(0)+i[2].charAt(0):i.join(\"\")}function p(t,e,r,n){return[O(D(n)),O(a(t).toString(16)),O(a(e).toString(16)),O(a(r).toString(16))].join(\"\")}function d(t,e){e=0===e?0:e||10;var r=c(t).toHsl();return r.s-=e/100,r.s=P(r.s),c(r)}function m(t,e){e=0===e?0:e||10;var r=c(t).toHsl();return r.s+=e/100,r.s=P(r.s),c(r)}function g(t){return c(t).desaturate(100)}function v(t,e){e=0===e?0:e||10;var r=c(t).toHsl();return r.l+=e/100,r.l=P(r.l),c(r)}function y(t,e){e=0===e?0:e||10;var r=c(t).toRgb();return r.r=s(0,o(255,r.r-a(-e/100*255))),r.g=s(0,o(255,r.g-a(-e/100*255))),r.b=s(0,o(255,r.b-a(-e/100*255))),c(r)}function x(t,e){e=0===e?0:e||10;var r=c(t).toHsl();return r.l-=e/100,r.l=P(r.l),c(r)}function b(t,e){var r=c(t).toHsl(),n=(r.h+e)%360;return r.h=n<0?360+n:n,c(r)}function _(t){var e=c(t).toHsl();return e.h=(e.h+180)%360,c(e)}function w(t){var e=c(t).toHsl(),r=e.h;return[c(t),c({h:(r+120)%360,s:e.s,l:e.l}),c({h:(r+240)%360,s:e.s,l:e.l})]}function T(t){var e=c(t).toHsl(),r=e.h;return[c(t),c({h:(r+90)%360,s:e.s,l:e.l}),c({h:(r+180)%360,s:e.s,l:e.l}),c({h:(r+270)%360,s:e.s,l:e.l})]}function k(t){var e=c(t).toHsl(),r=e.h;return[c(t),c({h:(r+72)%360,s:e.s,l:e.l}),c({h:(r+216)%360,s:e.s,l:e.l})]}function M(t,e,r){e=e||6,r=r||30;var n=c(t).toHsl(),i=360/r,a=[c(t)];for(n.h=(n.h-(i*e>>1)+720)%360;--e;)n.h=(n.h+i)%360,a.push(c(n));return a}function A(t,e){e=e||6;for(var r=c(t).toHsv(),n=r.h,i=r.s,a=r.v,o=[],s=1/e;e--;)o.push(c({h:n,s:i,v:a})),a=(a+s)%1;return o}c.prototype={isDark:function(){return this.getBrightness()<128},isLight:function(){return!this.isDark()},isValid:function(){return this._ok},getOriginalInput:function(){return this._originalInput},getFormat:function(){return this._format},getAlpha:function(){return this._a},getBrightness:function(){var t=this.toRgb();return(299*t.r+587*t.g+114*t.b)/1e3},getLuminance:function(){var e,r,n,i=this.toRgb();return e=i.r/255,r=i.g/255,n=i.b/255,.2126*(e<=.03928?e/12.92:t.pow((e+.055)/1.055,2.4))+.7152*(r<=.03928?r/12.92:t.pow((r+.055)/1.055,2.4))+.0722*(n<=.03928?n/12.92:t.pow((n+.055)/1.055,2.4))},setAlpha:function(t){return this._a=L(t),this._roundA=a(100*this._a)/100,this},toHsv:function(){var t=f(this._r,this._g,this._b);return{h:360*t.h,s:t.s,v:t.v,a:this._a}},toHsvString:function(){var t=f(this._r,this._g,this._b),e=a(360*t.h),r=a(100*t.s),n=a(100*t.v);return 1==this._a?\"hsv(\"+e+\", \"+r+\"%, \"+n+\"%)\":\"hsva(\"+e+\", \"+r+\"%, \"+n+\"%, \"+this._roundA+\")\"},toHsl:function(){var t=u(this._r,this._g,this._b);return{h:360*t.h,s:t.s,l:t.l,a:this._a}},toHslString:function(){var t=u(this._r,this._g,this._b),e=a(360*t.h),r=a(100*t.s),n=a(100*t.l);return 1==this._a?\"hsl(\"+e+\", \"+r+\"%, \"+n+\"%)\":\"hsla(\"+e+\", \"+r+\"%, \"+n+\"%, \"+this._roundA+\")\"},toHex:function(t){return h(this._r,this._g,this._b,t)},toHexString:function(t){return\"#\"+this.toHex(t)},toHex8:function(t){return function(t,e,r,n,i){var o=[O(a(t).toString(16)),O(a(e).toString(16)),O(a(r).toString(16)),O(D(n))];if(i&&o[0].charAt(0)==o[0].charAt(1)&&o[1].charAt(0)==o[1].charAt(1)&&o[2].charAt(0)==o[2].charAt(1)&&o[3].charAt(0)==o[3].charAt(1))return o[0].charAt(0)+o[1].charAt(0)+o[2].charAt(0)+o[3].charAt(0);return o.join(\"\")}(this._r,this._g,this._b,this._a,t)},toHex8String:function(t){return\"#\"+this.toHex8(t)},toRgb:function(){return{r:a(this._r),g:a(this._g),b:a(this._b),a:this._a}},toRgbString:function(){return 1==this._a?\"rgb(\"+a(this._r)+\", \"+a(this._g)+\", \"+a(this._b)+\")\":\"rgba(\"+a(this._r)+\", \"+a(this._g)+\", \"+a(this._b)+\", \"+this._roundA+\")\"},toPercentageRgb:function(){return{r:a(100*C(this._r,255))+\"%\",g:a(100*C(this._g,255))+\"%\",b:a(100*C(this._b,255))+\"%\",a:this._a}},toPercentageRgbString:function(){return 1==this._a?\"rgb(\"+a(100*C(this._r,255))+\"%, \"+a(100*C(this._g,255))+\"%, \"+a(100*C(this._b,255))+\"%)\":\"rgba(\"+a(100*C(this._r,255))+\"%, \"+a(100*C(this._g,255))+\"%, \"+a(100*C(this._b,255))+\"%, \"+this._roundA+\")\"},toName:function(){return 0===this._a?\"transparent\":!(this._a<1)&&(E[h(this._r,this._g,this._b,!0)]||!1)},toFilter:function(t){var e=\"#\"+p(this._r,this._g,this._b,this._a),r=e,n=this._gradientType?\"GradientType = 1, \":\"\";if(t){var i=c(t);r=\"#\"+p(i._r,i._g,i._b,i._a)}return\"progid:DXImageTransform.Microsoft.gradient(\"+n+\"startColorstr=\"+e+\",endColorstr=\"+r+\")\"},toString:function(t){var e=!!t;t=t||this._format;var r=!1,n=this._a<1&&this._a>=0;return e||!n||\"hex\"!==t&&\"hex6\"!==t&&\"hex3\"!==t&&\"hex4\"!==t&&\"hex8\"!==t&&\"name\"!==t?(\"rgb\"===t&&(r=this.toRgbString()),\"prgb\"===t&&(r=this.toPercentageRgbString()),\"hex\"!==t&&\"hex6\"!==t||(r=this.toHexString()),\"hex3\"===t&&(r=this.toHexString(!0)),\"hex4\"===t&&(r=this.toHex8String(!0)),\"hex8\"===t&&(r=this.toHex8String()),\"name\"===t&&(r=this.toName()),\"hsl\"===t&&(r=this.toHslString()),\"hsv\"===t&&(r=this.toHsvString()),r||this.toHexString()):\"name\"===t&&0===this._a?this.toName():this.toRgbString()},clone:function(){return c(this.toString())},_applyModification:function(t,e){var r=t.apply(null,[this].concat([].slice.call(e)));return this._r=r._r,this._g=r._g,this._b=r._b,this.setAlpha(r._a),this},lighten:function(){return this._applyModification(v,arguments)},brighten:function(){return this._applyModification(y,arguments)},darken:function(){return this._applyModification(x,arguments)},desaturate:function(){return this._applyModification(d,arguments)},saturate:function(){return this._applyModification(m,arguments)},greyscale:function(){return this._applyModification(g,arguments)},spin:function(){return this._applyModification(b,arguments)},_applyCombination:function(t,e){return t.apply(null,[this].concat([].slice.call(e)))},analogous:function(){return this._applyCombination(M,arguments)},complement:function(){return this._applyCombination(_,arguments)},monochromatic:function(){return this._applyCombination(A,arguments)},splitcomplement:function(){return this._applyCombination(k,arguments)},triad:function(){return this._applyCombination(w,arguments)},tetrad:function(){return this._applyCombination(T,arguments)}},c.fromRatio=function(t,e){if(\"object\"==typeof t){var r={};for(var n in t)t.hasOwnProperty(n)&&(r[n]=\"a\"===n?t[n]:z(t[n]));t=r}return c(t,e)},c.equals=function(t,e){return!(!t||!e)&&c(t).toRgbString()==c(e).toRgbString()},c.random=function(){return c.fromRatio({r:l(),g:l(),b:l()})},c.mix=function(t,e,r){r=0===r?0:r||50;var n=c(t).toRgb(),i=c(e).toRgb(),a=r/100;return c({r:(i.r-n.r)*a+n.r,g:(i.g-n.g)*a+n.g,b:(i.b-n.b)*a+n.b,a:(i.a-n.a)*a+n.a})},c.readability=function(e,r){var n=c(e),i=c(r);return(t.max(n.getLuminance(),i.getLuminance())+.05)/(t.min(n.getLuminance(),i.getLuminance())+.05)},c.isReadable=function(t,e,r){var n,i,a=c.readability(t,e);switch(i=!1,(n=function(t){var e,r;e=((t=t||{level:\"AA\",size:\"small\"}).level||\"AA\").toUpperCase(),r=(t.size||\"small\").toLowerCase(),\"AA\"!==e&&\"AAA\"!==e&&(e=\"AA\");\"small\"!==r&&\"large\"!==r&&(r=\"small\");return{level:e,size:r}}(r)).level+n.size){case\"AAsmall\":case\"AAAlarge\":i=a>=4.5;break;case\"AAlarge\":i=a>=3;break;case\"AAAsmall\":i=a>=7}return i},c.mostReadable=function(t,e,r){var n,i,a,o,s=null,l=0;i=(r=r||{}).includeFallbackColors,a=r.level,o=r.size;for(var u=0;u<e.length;u++)(n=c.readability(t,e[u]))>l&&(l=n,s=c(e[u]));return c.isReadable(t,s,{level:a,size:o})||!i?s:(r.includeFallbackColors=!1,c.mostReadable(t,[\"#fff\",\"#000\"],r))};var S=c.names={aliceblue:\"f0f8ff\",antiquewhite:\"faebd7\",aqua:\"0ff\",aquamarine:\"7fffd4\",azure:\"f0ffff\",beige:\"f5f5dc\",bisque:\"ffe4c4\",black:\"000\",blanchedalmond:\"ffebcd\",blue:\"00f\",blueviolet:\"8a2be2\",brown:\"a52a2a\",burlywood:\"deb887\",burntsienna:\"ea7e5d\",cadetblue:\"5f9ea0\",chartreuse:\"7fff00\",chocolate:\"d2691e\",coral:\"ff7f50\",cornflowerblue:\"6495ed\",cornsilk:\"fff8dc\",crimson:\"dc143c\",cyan:\"0ff\",darkblue:\"00008b\",darkcyan:\"008b8b\",darkgoldenrod:\"b8860b\",darkgray:\"a9a9a9\",darkgreen:\"006400\",darkgrey:\"a9a9a9\",darkkhaki:\"bdb76b\",darkmagenta:\"8b008b\",darkolivegreen:\"556b2f\",darkorange:\"ff8c00\",darkorchid:\"9932cc\",darkred:\"8b0000\",darksalmon:\"e9967a\",darkseagreen:\"8fbc8f\",darkslateblue:\"483d8b\",darkslategray:\"2f4f4f\",darkslategrey:\"2f4f4f\",darkturquoise:\"00ced1\",darkviolet:\"9400d3\",deeppink:\"ff1493\",deepskyblue:\"00bfff\",dimgray:\"696969\",dimgrey:\"696969\",dodgerblue:\"1e90ff\",firebrick:\"b22222\",floralwhite:\"fffaf0\",forestgreen:\"228b22\",fuchsia:\"f0f\",gainsboro:\"dcdcdc\",ghostwhite:\"f8f8ff\",gold:\"ffd700\",goldenrod:\"daa520\",gray:\"808080\",green:\"008000\",greenyellow:\"adff2f\",grey:\"808080\",honeydew:\"f0fff0\",hotpink:\"ff69b4\",indianred:\"cd5c5c\",indigo:\"4b0082\",ivory:\"fffff0\",khaki:\"f0e68c\",lavender:\"e6e6fa\",lavenderblush:\"fff0f5\",lawngreen:\"7cfc00\",lemonchiffon:\"fffacd\",lightblue:\"add8e6\",lightcoral:\"f08080\",lightcyan:\"e0ffff\",lightgoldenrodyellow:\"fafad2\",lightgray:\"d3d3d3\",lightgreen:\"90ee90\",lightgrey:\"d3d3d3\",lightpink:\"ffb6c1\",lightsalmon:\"ffa07a\",lightseagreen:\"20b2aa\",lightskyblue:\"87cefa\",lightslategray:\"789\",lightslategrey:\"789\",lightsteelblue:\"b0c4de\",lightyellow:\"ffffe0\",lime:\"0f0\",limegreen:\"32cd32\",linen:\"faf0e6\",magenta:\"f0f\",maroon:\"800000\",mediumaquamarine:\"66cdaa\",mediumblue:\"0000cd\",mediumorchid:\"ba55d3\",mediumpurple:\"9370db\",mediumseagreen:\"3cb371\",mediumslateblue:\"7b68ee\",mediumspringgreen:\"00fa9a\",mediumturquoise:\"48d1cc\",mediumvioletred:\"c71585\",midnightblue:\"191970\",mintcream:\"f5fffa\",mistyrose:\"ffe4e1\",moccasin:\"ffe4b5\",navajowhite:\"ffdead\",navy:\"000080\",oldlace:\"fdf5e6\",olive:\"808000\",olivedrab:\"6b8e23\",orange:\"ffa500\",orangered:\"ff4500\",orchid:\"da70d6\",palegoldenrod:\"eee8aa\",palegreen:\"98fb98\",paleturquoise:\"afeeee\",palevioletred:\"db7093\",papayawhip:\"ffefd5\",peachpuff:\"ffdab9\",peru:\"cd853f\",pink:\"ffc0cb\",plum:\"dda0dd\",powderblue:\"b0e0e6\",purple:\"800080\",rebeccapurple:\"663399\",red:\"f00\",rosybrown:\"bc8f8f\",royalblue:\"4169e1\",saddlebrown:\"8b4513\",salmon:\"fa8072\",sandybrown:\"f4a460\",seagreen:\"2e8b57\",seashell:\"fff5ee\",sienna:\"a0522d\",silver:\"c0c0c0\",skyblue:\"87ceeb\",slateblue:\"6a5acd\",slategray:\"708090\",slategrey:\"708090\",snow:\"fffafa\",springgreen:\"00ff7f\",steelblue:\"4682b4\",tan:\"d2b48c\",teal:\"008080\",thistle:\"d8bfd8\",tomato:\"ff6347\",turquoise:\"40e0d0\",violet:\"ee82ee\",wheat:\"f5deb3\",white:\"fff\",whitesmoke:\"f5f5f5\",yellow:\"ff0\",yellowgreen:\"9acd32\"},E=c.hexNames=function(t){var e={};for(var r in t)t.hasOwnProperty(r)&&(e[t[r]]=r);return e}(S);function L(t){return t=parseFloat(t),(isNaN(t)||t<0||t>1)&&(t=1),t}function C(e,r){(function(t){return\"string\"==typeof t&&-1!=t.indexOf(\".\")&&1===parseFloat(t)})(e)&&(e=\"100%\");var n=function(t){return\"string\"==typeof t&&-1!=t.indexOf(\"%\")}(e);return e=o(r,s(0,parseFloat(e))),n&&(e=parseInt(e*r,10)/100),t.abs(e-r)<1e-6?1:e%r/parseFloat(r)}function P(t){return o(1,s(0,t))}function I(t){return parseInt(t,16)}function O(t){return 1==t.length?\"0\"+t:\"\"+t}function z(t){return t<=1&&(t=100*t+\"%\"),t}function D(e){return t.round(255*parseFloat(e)).toString(16)}function R(t){return I(t)/255}var F,B,N,j=(B=\"[\\\\s|\\\\(]+(\"+(F=\"(?:[-\\\\+]?\\\\d*\\\\.\\\\d+%?)|(?:[-\\\\+]?\\\\d+%?)\")+\")[,|\\\\s]+(\"+F+\")[,|\\\\s]+(\"+F+\")\\\\s*\\\\)?\",N=\"[\\\\s|\\\\(]+(\"+F+\")[,|\\\\s]+(\"+F+\")[,|\\\\s]+(\"+F+\")[,|\\\\s]+(\"+F+\")\\\\s*\\\\)?\",{CSS_UNIT:new RegExp(F),rgb:new RegExp(\"rgb\"+B),rgba:new RegExp(\"rgba\"+N),hsl:new RegExp(\"hsl\"+B),hsla:new RegExp(\"hsla\"+N),hsv:new RegExp(\"hsv\"+B),hsva:new RegExp(\"hsva\"+N),hex3:/^#?([0-9a-fA-F]{1})([0-9a-fA-F]{1})([0-9a-fA-F]{1})$/,hex6:/^#?([0-9a-fA-F]{2})([0-9a-fA-F]{2})([0-9a-fA-F]{2})$/,hex4:/^#?([0-9a-fA-F]{1})([0-9a-fA-F]{1})([0-9a-fA-F]{1})([0-9a-fA-F]{1})$/,hex8:/^#?([0-9a-fA-F]{2})([0-9a-fA-F]{2})([0-9a-fA-F]{2})([0-9a-fA-F]{2})$/});function U(t){return!!j.CSS_UNIT.exec(t)}void 0!==e&&e.exports?e.exports=c:window.tinycolor=c}(Math)},{}],595:[function(t,e,r){\"use strict\";e.exports=i,e.exports.float32=e.exports.float=i,e.exports.fract32=e.exports.fract=function(t){if(t.length){for(var e=i(t),r=0,n=e.length;r<n;r++)e[r]=t[r]-e[r];return e}return i(t-i(t))};var n=new Float32Array(1);function i(t){if(t.length){if(t instanceof Float32Array)return t;var e=new Float32Array(t);return e.set(t),e}return n[0]=t,n[0]}},{}],596:[function(t,e,r){\"use strict\";var n=t(\"parse-unit\");e.exports=a;function i(t,e){var r=n(getComputedStyle(t).getPropertyValue(e));return r[0]*a(r[1],t)}function a(t,e){switch(e=e||document.body,t=(t||\"px\").trim().toLowerCase(),e!==window&&e!==document||(e=document.body),t){case\"%\":return e.clientHeight/100;case\"ch\":case\"ex\":return function(t,e){var r=document.createElement(\"div\");r.style[\"font-size\"]=\"128\"+t,e.appendChild(r);var n=i(r,\"font-size\")/128;return e.removeChild(r),n}(t,e);case\"em\":return i(e,\"font-size\");case\"rem\":return i(document.body,\"font-size\");case\"vw\":return window.innerWidth/100;case\"vh\":return window.innerHeight/100;case\"vmin\":return Math.min(window.innerWidth,window.innerHeight)/100;case\"vmax\":return Math.max(window.innerWidth,window.innerHeight)/100;case\"in\":return 96;case\"cm\":return 96/2.54;case\"mm\":return 96/25.4;case\"pt\":return 96/72;case\"pc\":return 16}return 1}},{\"parse-unit\":490}],597:[function(t,e,r){!function(t,n){\"object\"==typeof r&&void 0!==e?n(r):n((t=t||self).topojson=t.topojson||{})}(this,(function(t){\"use strict\";function e(t){return t}function r(t){if(null==t)return e;var r,n,i=t.scale[0],a=t.scale[1],o=t.translate[0],s=t.translate[1];return function(t,e){e||(r=n=0);var l=2,c=t.length,u=new Array(c);for(u[0]=(r+=t[0])*i+o,u[1]=(n+=t[1])*a+s;l<c;)u[l]=t[l],++l;return u}}function n(t){var e,n=r(t.transform),i=1/0,a=i,o=-i,s=-i;function l(t){(t=n(t))[0]<i&&(i=t[0]),t[0]>o&&(o=t[0]),t[1]<a&&(a=t[1]),t[1]>s&&(s=t[1])}function c(t){switch(t.type){case\"GeometryCollection\":t.geometries.forEach(c);break;case\"Point\":l(t.coordinates);break;case\"MultiPoint\":t.coordinates.forEach(l)}}for(e in t.arcs.forEach((function(t){for(var e,r=-1,l=t.length;++r<l;)(e=n(t[r],r))[0]<i&&(i=e[0]),e[0]>o&&(o=e[0]),e[1]<a&&(a=e[1]),e[1]>s&&(s=e[1])})),t.objects)c(t.objects[e]);return[i,a,o,s]}function i(t,e){var r=e.id,n=e.bbox,i=null==e.properties?{}:e.properties,o=a(t,e);return null==r&&null==n?{type:\"Feature\",properties:i,geometry:o}:null==n?{type:\"Feature\",id:r,properties:i,geometry:o}:{type:\"Feature\",id:r,bbox:n,properties:i,geometry:o}}function a(t,e){var n=r(t.transform),i=t.arcs;function a(t,e){e.length&&e.pop();for(var r=i[t<0?~t:t],a=0,o=r.length;a<o;++a)e.push(n(r[a],a));t<0&&function(t,e){for(var r,n=t.length,i=n-e;i<--n;)r=t[i],t[i++]=t[n],t[n]=r}(e,o)}function o(t){return n(t)}function s(t){for(var e=[],r=0,n=t.length;r<n;++r)a(t[r],e);return e.length<2&&e.push(e[0]),e}function l(t){for(var e=s(t);e.length<4;)e.push(e[0]);return e}function c(t){return t.map(l)}return function t(e){var r,n=e.type;switch(n){case\"GeometryCollection\":return{type:n,geometries:e.geometries.map(t)};case\"Point\":r=o(e.coordinates);break;case\"MultiPoint\":r=e.coordinates.map(o);break;case\"LineString\":r=s(e.arcs);break;case\"MultiLineString\":r=e.arcs.map(s);break;case\"Polygon\":r=c(e.arcs);break;case\"MultiPolygon\":r=e.arcs.map(c);break;default:return null}return{type:n,coordinates:r}}(e)}function o(t,e){var r={},n={},i={},a=[],o=-1;function s(t,e){for(var n in t){var i=t[n];delete e[i.start],delete i.start,delete i.end,i.forEach((function(t){r[t<0?~t:t]=1})),a.push(i)}}return e.forEach((function(r,n){var i,a=t.arcs[r<0?~r:r];a.length<3&&!a[1][0]&&!a[1][1]&&(i=e[++o],e[o]=r,e[n]=i)})),e.forEach((function(e){var r,a,o=function(e){var r,n=t.arcs[e<0?~e:e],i=n[0];t.transform?(r=[0,0],n.forEach((function(t){r[0]+=t[0],r[1]+=t[1]}))):r=n[n.length-1];return e<0?[r,i]:[i,r]}(e),s=o[0],l=o[1];if(r=i[s])if(delete i[r.end],r.push(e),r.end=l,a=n[l]){delete n[a.start];var c=a===r?r:r.concat(a);n[c.start=r.start]=i[c.end=a.end]=c}else n[r.start]=i[r.end]=r;else if(r=n[l])if(delete n[r.start],r.unshift(e),r.start=s,a=i[s]){delete i[a.end];var u=a===r?r:a.concat(r);n[u.start=a.start]=i[u.end=r.end]=u}else n[r.start]=i[r.end]=r;else n[(r=[e]).start=s]=i[r.end=l]=r})),s(i,n),s(n,i),e.forEach((function(t){r[t<0?~t:t]||a.push([t])})),a}function s(t,e,r){var n,i,a;if(arguments.length>1)n=l(t,e,r);else for(i=0,n=new Array(a=t.arcs.length);i<a;++i)n[i]=i;return{type:\"MultiLineString\",arcs:o(t,n)}}function l(t,e,r){var n,i=[],a=[];function o(t){var e=t<0?~t:t;(a[e]||(a[e]=[])).push({i:t,g:n})}function s(t){t.forEach(o)}function l(t){t.forEach(s)}return function t(e){switch(n=e,e.type){case\"GeometryCollection\":e.geometries.forEach(t);break;case\"LineString\":s(e.arcs);break;case\"MultiLineString\":case\"Polygon\":l(e.arcs);break;case\"MultiPolygon\":!function(t){t.forEach(l)}(e.arcs)}}(e),a.forEach(null==r?function(t){i.push(t[0].i)}:function(t){r(t[0].g,t[t.length-1].g)&&i.push(t[0].i)}),i}function c(t,e){var r={},n=[],i=[];function s(t){t.forEach((function(e){e.forEach((function(e){(r[e=e<0?~e:e]||(r[e]=[])).push(t)}))})),n.push(t)}function l(e){return function(t){for(var e,r=-1,n=t.length,i=t[n-1],a=0;++r<n;)e=i,i=t[r],a+=e[0]*i[1]-e[1]*i[0];return Math.abs(a)}(a(t,{type:\"Polygon\",arcs:[e]}).coordinates[0])}return e.forEach((function t(e){switch(e.type){case\"GeometryCollection\":e.geometries.forEach(t);break;case\"Polygon\":s(e.arcs);break;case\"MultiPolygon\":e.arcs.forEach(s)}})),n.forEach((function(t){if(!t._){var e=[],n=[t];for(t._=1,i.push(e);t=n.pop();)e.push(t),t.forEach((function(t){t.forEach((function(t){r[t<0?~t:t].forEach((function(t){t._||(t._=1,n.push(t))}))}))}))}})),n.forEach((function(t){delete t._})),{type:\"MultiPolygon\",arcs:i.map((function(e){var n,i=[];if(e.forEach((function(t){t.forEach((function(t){t.forEach((function(t){r[t<0?~t:t].length<2&&i.push(t)}))}))})),(n=(i=o(t,i)).length)>1)for(var a,s,c=1,u=l(i[0]);c<n;++c)(a=l(i[c]))>u&&(s=i[0],i[0]=i[c],i[c]=s,u=a);return i})).filter((function(t){return t.length>0}))}}function u(t,e){for(var r=0,n=t.length;r<n;){var i=r+n>>>1;t[i]<e?r=i+1:n=i}return r}function f(t){if(null==t)return e;var r,n,i=t.scale[0],a=t.scale[1],o=t.translate[0],s=t.translate[1];return function(t,e){e||(r=n=0);var l=2,c=t.length,u=new Array(c),f=Math.round((t[0]-o)/i),h=Math.round((t[1]-s)/a);for(u[0]=f-r,r=f,u[1]=h-n,n=h;l<c;)u[l]=t[l],++l;return u}}t.bbox=n,t.feature=function(t,e){return\"string\"==typeof e&&(e=t.objects[e]),\"GeometryCollection\"===e.type?{type:\"FeatureCollection\",features:e.geometries.map((function(e){return i(t,e)}))}:i(t,e)},t.merge=function(t){return a(t,c.apply(this,arguments))},t.mergeArcs=c,t.mesh=function(t){return a(t,s.apply(this,arguments))},t.meshArcs=s,t.neighbors=function(t){var e={},r=t.map((function(){return[]}));function n(t,r){t.forEach((function(t){t<0&&(t=~t);var n=e[t];n?n.push(r):e[t]=[r]}))}function i(t,e){t.forEach((function(t){n(t,e)}))}var a={LineString:n,MultiLineString:i,Polygon:i,MultiPolygon:function(t,e){t.forEach((function(t){i(t,e)}))}};for(var o in t.forEach((function t(e,r){\"GeometryCollection\"===e.type?e.geometries.forEach((function(e){t(e,r)})):e.type in a&&a[e.type](e.arcs,r)})),e)for(var s=e[o],l=s.length,c=0;c<l;++c)for(var f=c+1;f<l;++f){var h,p=s[c],d=s[f];(h=r[p])[o=u(h,d)]!==d&&h.splice(o,0,d),(h=r[d])[o=u(h,p)]!==p&&h.splice(o,0,p)}return r},t.quantize=function(t,e){if(t.transform)throw new Error(\"already quantized\");if(e&&e.scale)l=t.bbox;else{if(!((r=Math.floor(e))>=2))throw new Error(\"n must be \\u22652\");var r,i=(l=t.bbox||n(t))[0],a=l[1],o=l[2],s=l[3];e={scale:[o-i?(o-i)/(r-1):1,s-a?(s-a)/(r-1):1],translate:[i,a]}}var l,c,u=f(e),h=t.objects,p={};function d(t){return u(t)}function m(t){var e;switch(t.type){case\"GeometryCollection\":e={type:\"GeometryCollection\",geometries:t.geometries.map(m)};break;case\"Point\":e={type:\"Point\",coordinates:d(t.coordinates)};break;case\"MultiPoint\":e={type:\"MultiPoint\",coordinates:t.coordinates.map(d)};break;default:return t}return null!=t.id&&(e.id=t.id),null!=t.bbox&&(e.bbox=t.bbox),null!=t.properties&&(e.properties=t.properties),e}for(c in h)p[c]=m(h[c]);return{type:\"Topology\",bbox:l,transform:e,objects:p,arcs:t.arcs.map((function(t){var e,r=0,n=1,i=t.length,a=new Array(i);for(a[0]=u(t[0],0);++r<i;)((e=u(t[r],r))[0]||e[1])&&(a[n++]=e);return 1===n&&(a[n++]=[0,0]),a.length=n,a}))}},t.transform=r,t.untransform=f,Object.defineProperty(t,\"__esModule\",{value:!0})}))},{}],598:[function(t,e,r){\"use strict\";e.exports=function(t){if(t<0)return[];if(0===t)return[[0]];for(var e=0|Math.round(a(t+1)),r=[],o=0;o<e;++o){for(var s=n.unrank(t,o),l=[0],c=0,u=0;u<s.length;++u)c+=1<<s[u],l.push(c);i(s)<1&&(l[0]=c,l[t]=0),r.push(l)}return r};var n=t(\"permutation-rank\"),i=t(\"permutation-parity\"),a=t(\"gamma\")},{gamma:252,\"permutation-parity\":492,\"permutation-rank\":493}],599:[function(t,e,r){\"use strict\";e.exports=function(t){var e=(t=t||{}).center||[0,0,0],r=t.up||[0,1,0],n=t.right||f(r),i=t.radius||1,a=t.theta||0,u=t.phi||0;if(e=[].slice.call(e,0,3),r=[].slice.call(r,0,3),s(r,r),n=[].slice.call(n,0,3),s(n,n),\"eye\"in t){var p=t.eye,d=[p[0]-e[0],p[1]-e[1],p[2]-e[2]];o(n,d,r),c(n[0],n[1],n[2])<1e-6?n=f(r):s(n,n),i=c(d[0],d[1],d[2]);var m=l(r,d)/i,g=l(n,d)/i;u=Math.acos(m),a=Math.acos(g)}return i=Math.log(i),new h(t.zoomMin,t.zoomMax,e,r,n,i,a,u)};var n=t(\"filtered-vector\"),i=t(\"gl-mat4/invert\"),a=t(\"gl-mat4/rotate\"),o=t(\"gl-vec3/cross\"),s=t(\"gl-vec3/normalize\"),l=t(\"gl-vec3/dot\");function c(t,e,r){return Math.sqrt(Math.pow(t,2)+Math.pow(e,2)+Math.pow(r,2))}function u(t){return Math.min(1,Math.max(-1,t))}function f(t){var e=Math.abs(t[0]),r=Math.abs(t[1]),n=Math.abs(t[2]),i=[0,0,0];e>Math.max(r,n)?i[2]=1:r>Math.max(e,n)?i[0]=1:i[1]=1;for(var a=0,o=0,l=0;l<3;++l)a+=t[l]*t[l],o+=i[l]*t[l];for(l=0;l<3;++l)i[l]-=o/a*t[l];return s(i,i),i}function h(t,e,r,i,a,o,s,l){this.center=n(r),this.up=n(i),this.right=n(a),this.radius=n([o]),this.angle=n([s,l]),this.angle.bounds=[[-1/0,-Math.PI/2],[1/0,Math.PI/2]],this.setDistanceLimits(t,e),this.computedCenter=this.center.curve(0),this.computedUp=this.up.curve(0),this.computedRight=this.right.curve(0),this.computedRadius=this.radius.curve(0),this.computedAngle=this.angle.curve(0),this.computedToward=[0,0,0],this.computedEye=[0,0,0],this.computedMatrix=new Array(16);for(var c=0;c<16;++c)this.computedMatrix[c]=.5;this.recalcMatrix(0)}var p=h.prototype;p.setDistanceLimits=function(t,e){t=t>0?Math.log(t):-1/0,e=e>0?Math.log(e):1/0,e=Math.max(e,t),this.radius.bounds[0][0]=t,this.radius.bounds[1][0]=e},p.getDistanceLimits=function(t){var e=this.radius.bounds[0];return t?(t[0]=Math.exp(e[0][0]),t[1]=Math.exp(e[1][0]),t):[Math.exp(e[0][0]),Math.exp(e[1][0])]},p.recalcMatrix=function(t){this.center.curve(t),this.up.curve(t),this.right.curve(t),this.radius.curve(t),this.angle.curve(t);for(var e=this.computedUp,r=this.computedRight,n=0,i=0,a=0;a<3;++a)i+=e[a]*r[a],n+=e[a]*e[a];var l=Math.sqrt(n),u=0;for(a=0;a<3;++a)r[a]-=e[a]*i/n,u+=r[a]*r[a],e[a]/=l;var f=Math.sqrt(u);for(a=0;a<3;++a)r[a]/=f;var h=this.computedToward;o(h,e,r),s(h,h);var p=Math.exp(this.computedRadius[0]),d=this.computedAngle[0],m=this.computedAngle[1],g=Math.cos(d),v=Math.sin(d),y=Math.cos(m),x=Math.sin(m),b=this.computedCenter,_=g*y,w=v*y,T=x,k=-g*x,M=-v*x,A=y,S=this.computedEye,E=this.computedMatrix;for(a=0;a<3;++a){var L=_*r[a]+w*h[a]+T*e[a];E[4*a+1]=k*r[a]+M*h[a]+A*e[a],E[4*a+2]=L,E[4*a+3]=0}var C=E[1],P=E[5],I=E[9],O=E[2],z=E[6],D=E[10],R=P*D-I*z,F=I*O-C*D,B=C*z-P*O,N=c(R,F,B);R/=N,F/=N,B/=N,E[0]=R,E[4]=F,E[8]=B;for(a=0;a<3;++a)S[a]=b[a]+E[2+4*a]*p;for(a=0;a<3;++a){u=0;for(var j=0;j<3;++j)u+=E[a+4*j]*S[j];E[12+a]=-u}E[15]=1},p.getMatrix=function(t,e){this.recalcMatrix(t);var r=this.computedMatrix;if(e){for(var n=0;n<16;++n)e[n]=r[n];return e}return r};var d=[0,0,0];p.rotate=function(t,e,r,n){if(this.angle.move(t,e,r),n){this.recalcMatrix(t);var i=this.computedMatrix;d[0]=i[2],d[1]=i[6],d[2]=i[10];for(var o=this.computedUp,s=this.computedRight,l=this.computedToward,c=0;c<3;++c)i[4*c]=o[c],i[4*c+1]=s[c],i[4*c+2]=l[c];a(i,i,n,d);for(c=0;c<3;++c)o[c]=i[4*c],s[c]=i[4*c+1];this.up.set(t,o[0],o[1],o[2]),this.right.set(t,s[0],s[1],s[2])}},p.pan=function(t,e,r,n){e=e||0,r=r||0,n=n||0,this.recalcMatrix(t);var i=this.computedMatrix,a=(Math.exp(this.computedRadius[0]),i[1]),o=i[5],s=i[9],l=c(a,o,s);a/=l,o/=l,s/=l;var u=i[0],f=i[4],h=i[8],p=u*a+f*o+h*s,d=c(u-=a*p,f-=o*p,h-=s*p),m=(u/=d)*e+a*r,g=(f/=d)*e+o*r,v=(h/=d)*e+s*r;this.center.move(t,m,g,v);var y=Math.exp(this.computedRadius[0]);y=Math.max(1e-4,y+n),this.radius.set(t,Math.log(y))},p.translate=function(t,e,r,n){this.center.move(t,e||0,r||0,n||0)},p.setMatrix=function(t,e,r,n){var a=1;\"number\"==typeof r&&(a=0|r),(a<0||a>3)&&(a=1);var o=(a+2)%3;e||(this.recalcMatrix(t),e=this.computedMatrix);var s=e[a],l=e[a+4],f=e[a+8];if(n){var h=Math.abs(s),p=Math.abs(l),d=Math.abs(f),m=Math.max(h,p,d);h===m?(s=s<0?-1:1,l=f=0):d===m?(f=f<0?-1:1,s=l=0):(l=l<0?-1:1,s=f=0)}else{var g=c(s,l,f);s/=g,l/=g,f/=g}var v,y,x=e[o],b=e[o+4],_=e[o+8],w=x*s+b*l+_*f,T=c(x-=s*w,b-=l*w,_-=f*w),k=l*(_/=T)-f*(b/=T),M=f*(x/=T)-s*_,A=s*b-l*x,S=c(k,M,A);if(k/=S,M/=S,A/=S,this.center.jump(t,H,G,Y),this.radius.idle(t),this.up.jump(t,s,l,f),this.right.jump(t,x,b,_),2===a){var E=e[1],L=e[5],C=e[9],P=E*x+L*b+C*_,I=E*k+L*M+C*A;v=R<0?-Math.PI/2:Math.PI/2,y=Math.atan2(I,P)}else{var O=e[2],z=e[6],D=e[10],R=O*s+z*l+D*f,F=O*x+z*b+D*_,B=O*k+z*M+D*A;v=Math.asin(u(R)),y=Math.atan2(B,F)}this.angle.jump(t,y,v),this.recalcMatrix(t);var N=e[2],j=e[6],U=e[10],V=this.computedMatrix;i(V,e);var q=V[15],H=V[12]/q,G=V[13]/q,Y=V[14]/q,W=Math.exp(this.computedRadius[0]);this.center.jump(t,H-N*W,G-j*W,Y-U*W)},p.lastT=function(){return Math.max(this.center.lastT(),this.up.lastT(),this.right.lastT(),this.radius.lastT(),this.angle.lastT())},p.idle=function(t){this.center.idle(t),this.up.idle(t),this.right.idle(t),this.radius.idle(t),this.angle.idle(t)},p.flush=function(t){this.center.flush(t),this.up.flush(t),this.right.flush(t),this.radius.flush(t),this.angle.flush(t)},p.setDistance=function(t,e){e>0&&this.radius.set(t,Math.log(e))},p.lookAt=function(t,e,r,n){this.recalcMatrix(t),e=e||this.computedEye,r=r||this.computedCenter;var i=(n=n||this.computedUp)[0],a=n[1],o=n[2],s=c(i,a,o);if(!(s<1e-6)){i/=s,a/=s,o/=s;var l=e[0]-r[0],f=e[1]-r[1],h=e[2]-r[2],p=c(l,f,h);if(!(p<1e-6)){l/=p,f/=p,h/=p;var d=this.computedRight,m=d[0],g=d[1],v=d[2],y=i*m+a*g+o*v,x=c(m-=y*i,g-=y*a,v-=y*o);if(!(x<.01&&(x=c(m=a*h-o*f,g=o*l-i*h,v=i*f-a*l))<1e-6)){m/=x,g/=x,v/=x,this.up.set(t,i,a,o),this.right.set(t,m,g,v),this.center.set(t,r[0],r[1],r[2]),this.radius.set(t,Math.log(p));var b=a*v-o*g,_=o*m-i*v,w=i*g-a*m,T=c(b,_,w),k=i*l+a*f+o*h,M=m*l+g*f+v*h,A=(b/=T)*l+(_/=T)*f+(w/=T)*h,S=Math.asin(u(k)),E=Math.atan2(A,M),L=this.angle._state,C=L[L.length-1],P=L[L.length-2];C%=2*Math.PI;var I=Math.abs(C+2*Math.PI-E),O=Math.abs(C-E),z=Math.abs(C-2*Math.PI-E);I<O&&(C+=2*Math.PI),z<O&&(C-=2*Math.PI),this.angle.jump(this.angle.lastT(),C,P),this.angle.set(t,E,S)}}}}},{\"filtered-vector\":246,\"gl-mat4/invert\":295,\"gl-mat4/rotate\":301,\"gl-vec3/cross\":364,\"gl-vec3/dot\":369,\"gl-vec3/normalize\":386}],600:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){var i=t*e,a=n*t,o=a-(a-t),s=t-o,l=n*e,c=l-(l-e),u=e-c,f=s*u-(i-o*c-s*c-o*u);if(r)return r[0]=f,r[1]=i,r;return[f,i]};var n=+(Math.pow(2,27)+1)},{}],601:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){var n=t+e,i=n-t,a=e-i,o=t-(n-i);if(r)return r[0]=o+a,r[1]=n,r;return[o+a,n]}},{}],602:[function(t,e,r){\"use strict\";var n=t(\"../prototype/is\");e.exports=function(t){if(\"function\"!=typeof t)return!1;if(!hasOwnProperty.call(t,\"length\"))return!1;try{if(\"number\"!=typeof t.length)return!1;if(\"function\"!=typeof t.call)return!1;if(\"function\"!=typeof t.apply)return!1}catch(t){return!1}return!n(t)}},{\"../prototype/is\":609}],603:[function(t,e,r){\"use strict\";var n=t(\"../value/is\"),i=t(\"../object/is\"),a=t(\"../string/coerce\"),o=t(\"./to-short-string\"),s=function(t,e){return t.replace(\"%v\",o(e))};e.exports=function(t,e,r){if(!i(r))throw new TypeError(s(e,t));if(!n(t)){if(\"default\"in r)return r.default;if(r.isOptional)return null}var o=a(r.errorMessage);throw n(o)||(o=e),new TypeError(s(o,t))}},{\"../object/is\":606,\"../string/coerce\":610,\"../value/is\":612,\"./to-short-string\":605}],604:[function(t,e,r){\"use strict\";e.exports=function(t){try{return t.toString()}catch(e){try{return String(t)}catch(t){return null}}}},{}],605:[function(t,e,r){\"use strict\";var n=t(\"./safe-to-string\"),i=/[\\n\\r\\u2028\\u2029]/g;e.exports=function(t){var e=n(t);return null===e?\"<Non-coercible to string value>\":(e.length>100&&(e=e.slice(0,99)+\"\\u2026\"),e=e.replace(i,(function(t){switch(t){case\"\\n\":return\"\\\\n\";case\"\\r\":return\"\\\\r\";case\"\\u2028\":return\"\\\\u2028\";case\"\\u2029\":return\"\\\\u2029\";default:throw new Error(\"Unexpected character\")}})))}},{\"./safe-to-string\":604}],606:[function(t,e,r){\"use strict\";var n=t(\"../value/is\"),i={object:!0,function:!0,undefined:!0};e.exports=function(t){return!!n(t)&&hasOwnProperty.call(i,typeof t)}},{\"../value/is\":612}],607:[function(t,e,r){\"use strict\";var n=t(\"../lib/resolve-exception\"),i=t(\"./is\");e.exports=function(t){return i(t)?t:n(t,\"%v is not a plain function\",arguments[1])}},{\"../lib/resolve-exception\":603,\"./is\":608}],608:[function(t,e,r){\"use strict\";var n=t(\"../function/is\"),i=/^\\s*class[\\s{/}]/,a=Function.prototype.toString;e.exports=function(t){return!!n(t)&&!i.test(a.call(t))}},{\"../function/is\":602}],609:[function(t,e,r){\"use strict\";var n=t(\"../object/is\");e.exports=function(t){if(!n(t))return!1;try{return!!t.constructor&&t.constructor.prototype===t}catch(t){return!1}}},{\"../object/is\":606}],610:[function(t,e,r){\"use strict\";var n=t(\"../value/is\"),i=t(\"../object/is\"),a=Object.prototype.toString;e.exports=function(t){if(!n(t))return null;if(i(t)){var e=t.toString;if(\"function\"!=typeof e)return null;if(e===a)return null}try{return\"\"+t}catch(t){return null}}},{\"../object/is\":606,\"../value/is\":612}],611:[function(t,e,r){\"use strict\";var n=t(\"../lib/resolve-exception\"),i=t(\"./is\");e.exports=function(t){return i(t)?t:n(t,\"Cannot use %v\",arguments[1])}},{\"../lib/resolve-exception\":603,\"./is\":612}],612:[function(t,e,r){\"use strict\";e.exports=function(t){return null!=t}},{}],613:[function(t,e,r){(function(e){(function(){\"use strict\";var n=t(\"bit-twiddle\"),i=t(\"dup\"),a=t(\"buffer\").Buffer;e.__TYPEDARRAY_POOL||(e.__TYPEDARRAY_POOL={UINT8:i([32,0]),UINT16:i([32,0]),UINT32:i([32,0]),BIGUINT64:i([32,0]),INT8:i([32,0]),INT16:i([32,0]),INT32:i([32,0]),BIGINT64:i([32,0]),FLOAT:i([32,0]),DOUBLE:i([32,0]),DATA:i([32,0]),UINT8C:i([32,0]),BUFFER:i([32,0])});var o=\"undefined\"!=typeof Uint8ClampedArray,s=\"undefined\"!=typeof BigUint64Array,l=\"undefined\"!=typeof BigInt64Array,c=e.__TYPEDARRAY_POOL;c.UINT8C||(c.UINT8C=i([32,0])),c.BIGUINT64||(c.BIGUINT64=i([32,0])),c.BIGINT64||(c.BIGINT64=i([32,0])),c.BUFFER||(c.BUFFER=i([32,0]));var u=c.DATA,f=c.BUFFER;function h(t){if(t){var e=t.length||t.byteLength,r=n.log2(e);u[r].push(t)}}function p(t){t=n.nextPow2(t);var e=n.log2(t),r=u[e];return r.length>0?r.pop():new ArrayBuffer(t)}function d(t){return new Uint8Array(p(t),0,t)}function m(t){return new Uint16Array(p(2*t),0,t)}function g(t){return new Uint32Array(p(4*t),0,t)}function v(t){return new Int8Array(p(t),0,t)}function y(t){return new Int16Array(p(2*t),0,t)}function x(t){return new Int32Array(p(4*t),0,t)}function b(t){return new Float32Array(p(4*t),0,t)}function _(t){return new Float64Array(p(8*t),0,t)}function w(t){return o?new Uint8ClampedArray(p(t),0,t):d(t)}function T(t){return s?new BigUint64Array(p(8*t),0,t):null}function k(t){return l?new BigInt64Array(p(8*t),0,t):null}function M(t){return new DataView(p(t),0,t)}function A(t){t=n.nextPow2(t);var e=n.log2(t),r=f[e];return r.length>0?r.pop():new a(t)}r.free=function(t){if(a.isBuffer(t))f[n.log2(t.length)].push(t);else{if(\"[object ArrayBuffer]\"!==Object.prototype.toString.call(t)&&(t=t.buffer),!t)return;var e=t.length||t.byteLength,r=0|n.log2(e);u[r].push(t)}},r.freeUint8=r.freeUint16=r.freeUint32=r.freeBigUint64=r.freeInt8=r.freeInt16=r.freeInt32=r.freeBigInt64=r.freeFloat32=r.freeFloat=r.freeFloat64=r.freeDouble=r.freeUint8Clamped=r.freeDataView=function(t){h(t.buffer)},r.freeArrayBuffer=h,r.freeBuffer=function(t){f[n.log2(t.length)].push(t)},r.malloc=function(t,e){if(void 0===e||\"arraybuffer\"===e)return p(t);switch(e){case\"uint8\":return d(t);case\"uint16\":return m(t);case\"uint32\":return g(t);case\"int8\":return v(t);case\"int16\":return y(t);case\"int32\":return x(t);case\"float\":case\"float32\":return b(t);case\"double\":case\"float64\":return _(t);case\"uint8_clamped\":return w(t);case\"bigint64\":return k(t);case\"biguint64\":return T(t);case\"buffer\":return A(t);case\"data\":case\"dataview\":return M(t);default:return null}return null},r.mallocArrayBuffer=p,r.mallocUint8=d,r.mallocUint16=m,r.mallocUint32=g,r.mallocInt8=v,r.mallocInt16=y,r.mallocInt32=x,r.mallocFloat32=r.mallocFloat=b,r.mallocFloat64=r.mallocDouble=_,r.mallocUint8Clamped=w,r.mallocBigUint64=T,r.mallocBigInt64=k,r.mallocDataView=M,r.mallocBuffer=A,r.clearCache=function(){for(var t=0;t<32;++t)c.UINT8[t].length=0,c.UINT16[t].length=0,c.UINT32[t].length=0,c.INT8[t].length=0,c.INT16[t].length=0,c.INT32[t].length=0,c.FLOAT[t].length=0,c.DOUBLE[t].length=0,c.BIGUINT64[t].length=0,c.BIGINT64[t].length=0,c.UINT8C[t].length=0,u[t].length=0,f[t].length=0}}).call(this)}).call(this,\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{\"bit-twiddle\":104,buffer:117,dup:181}],614:[function(t,e,r){\"use strict\";function n(t){this.roots=new Array(t),this.ranks=new Array(t);for(var e=0;e<t;++e)this.roots[e]=e,this.ranks[e]=0}e.exports=n;var i=n.prototype;Object.defineProperty(i,\"length\",{get:function(){return this.roots.length}}),i.makeSet=function(){var t=this.roots.length;return this.roots.push(t),this.ranks.push(0),t},i.find=function(t){for(var e=t,r=this.roots;r[t]!==t;)t=r[t];for(;r[e]!==t;){var n=r[e];r[e]=t,e=n}return t},i.link=function(t,e){var r=this.find(t),n=this.find(e);if(r!==n){var i=this.ranks,a=this.roots,o=i[r],s=i[n];o<s?a[r]=n:s<o?a[n]=r:(a[n]=r,++i[r])}}},{}],615:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){return 0===t.length?t:e?(r||t.sort(e),function(t,e){for(var r=1,n=t.length,i=t[0],a=t[0],o=1;o<n;++o)if(a=i,e(i=t[o],a)){if(o===r){r++;continue}t[r++]=i}return t.length=r,t}(t,e)):(r||t.sort(),function(t){for(var e=1,r=t.length,n=t[0],i=t[0],a=1;a<r;++a,i=n)if(i=n,(n=t[a])!==i){if(a===e){e++;continue}t[e++]=n}return t.length=e,t}(t))}},{}],616:[function(t,e,r){var n=/[\\'\\\"]/;e.exports=function(t){return t?(n.test(t.charAt(0))&&(t=t.substr(1)),n.test(t.charAt(t.length-1))&&(t=t.substr(0,t.length-1)),t):\"\"}},{}],617:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){Array.isArray(r)||(r=[].slice.call(arguments,2));for(var n=0,i=r.length;n<i;n++){var a=r[n];for(var o in a)if((void 0===e[o]||Array.isArray(e[o])||t[o]!==e[o])&&o in e){var s;if(!0===a[o])s=e[o];else{if(!1===a[o])continue;if(\"function\"==typeof a[o]&&void 0===(s=a[o](e[o],t,e)))continue}t[o]=s}}return t}},{}],618:[function(t,e,r){(function(t){(function(){function r(e){try{if(!t.localStorage)return!1}catch(t){return!1}var r=t.localStorage[e];return null!=r&&\"true\"===String(r).toLowerCase()}e.exports=function(t,e){if(r(\"noDeprecation\"))return t;var n=!1;return function(){if(!n){if(r(\"throwDeprecation\"))throw new Error(e);r(\"traceDeprecation\")?console.trace(e):console.warn(e),n=!0}return t.apply(this,arguments)}}}).call(this)}).call(this,\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{}],619:[function(t,e,r){\"use strict\";e.exports=function(t,e){\"object\"==typeof e&&null!==e||(e={});return n(t,e.canvas||i,e.context||a,e)};var n=t(\"./lib/vtext\"),i=null,a=null;\"undefined\"!=typeof document&&((i=document.createElement(\"canvas\")).width=8192,i.height=1024,a=i.getContext(\"2d\"))},{\"./lib/vtext\":620}],620:[function(t,e,r){e.exports=function(t,e,r,n){var a=64,o=1.25,s={breaklines:!1,bolds:!1,italics:!1,subscripts:!1,superscripts:!1};n&&(n.size&&n.size>0&&(a=n.size),n.lineSpacing&&n.lineSpacing>0&&(o=n.lineSpacing),n.styletags&&n.styletags.breaklines&&(s.breaklines=!!n.styletags.breaklines),n.styletags&&n.styletags.bolds&&(s.bolds=!!n.styletags.bolds),n.styletags&&n.styletags.italics&&(s.italics=!!n.styletags.italics),n.styletags&&n.styletags.subscripts&&(s.subscripts=!!n.styletags.subscripts),n.styletags&&n.styletags.superscripts&&(s.superscripts=!!n.styletags.superscripts));return r.font=[n.fontStyle,n.fontVariant,n.fontWeight,a+\"px\",n.font].filter((function(t){return t})).join(\" \"),r.textAlign=\"start\",r.textBaseline=\"alphabetic\",r.direction=\"ltr\",h(function(t,e,r,n,a,o){r=r.replace(/\\n/g,\"\"),r=!0===o.breaklines?r.replace(/\\<br\\>/g,\"\\n\"):r.replace(/\\<br\\>/g,\" \");var s=\"\",l=[];for(p=0;p<r.length;++p)l[p]=s;!0===o.bolds&&(l=c(\"b\",\"b|\",r,l));!0===o.italics&&(l=c(\"i\",\"i|\",r,l));!0===o.superscripts&&(l=c(\"sup\",\"+1\",r,l));!0===o.subscripts&&(l=c(\"sub\",\"-1\",r,l));var u=[],f=\"\";for(p=0;p<r.length;++p)null!==l[p]&&(f+=r[p],u.push(l[p]));var h,p,d,m,g,v=f.split(\"\\n\"),y=v.length,x=Math.round(a*n),b=n,_=2*n,w=0,T=y*x+_;t.height<T&&(t.height=T);e.fillStyle=\"#000\",e.fillRect(0,0,t.width,t.height),e.fillStyle=\"#fff\";var k=0,M=\"\";function A(){if(\"\"!==M){var t=e.measureText(M).width;e.fillText(M,b+d,_+m),d+=t}}function S(){return Math.round(g)+\"px \"}function E(t,r){var n=\"\"+e.font;if(!0===o.subscripts){var i=t.indexOf(\"-\"),a=r.indexOf(\"-\"),s=i>-1?parseInt(t[1+i]):0,l=a>-1?parseInt(r[1+a]):0;s!==l&&(n=n.replace(S(),\"?px \"),g*=Math.pow(.75,l-s),n=n.replace(\"?px \",S())),m+=.25*x*(l-s)}if(!0===o.superscripts){var c=t.indexOf(\"+\"),u=r.indexOf(\"+\"),f=c>-1?parseInt(t[1+c]):0,h=u>-1?parseInt(r[1+u]):0;f!==h&&(n=n.replace(S(),\"?px \"),g*=Math.pow(.75,h-f),n=n.replace(\"?px \",S())),m-=.25*x*(h-f)}if(!0===o.bolds){var p=t.indexOf(\"b|\")>-1,d=r.indexOf(\"b|\")>-1;!p&&d&&(n=v?n.replace(\"italic \",\"italic bold \"):\"bold \"+n),p&&!d&&(n=n.replace(\"bold \",\"\"))}if(!0===o.italics){var v=t.indexOf(\"i|\")>-1,y=r.indexOf(\"i|\")>-1;!v&&y&&(n=\"italic \"+n),v&&!y&&(n=n.replace(\"italic \",\"\"))}e.font=n}for(h=0;h<y;++h){var L=v[h]+\"\\n\";for(d=0,m=h*x,g=n,M=\"\",p=0;p<L.length;++p){var C=p+k<u.length?u[p+k]:u[u.length-1];s===C?M+=L[p]:(A(),M=L[p],void 0!==C&&(E(s,C),s=C))}A(),k+=L.length;var P=0|Math.round(d+2*b);w<P&&(w=P)}var I=w,O=_+x*y;return i(e.getImageData(0,0,I,O).data,[O,I,4]).pick(-1,-1,0).transpose(1,0)}(e,r,t,a,o,s),n,a)},e.exports.processPixels=h;var n=t(\"surface-nets\"),i=t(\"ndarray\"),a=t(\"simplify-planar-graph\"),o=t(\"clean-pslg\"),s=t(\"cdt2d\"),l=t(\"planar-graph-to-polyline\");function c(t,e,r,n){for(var i=\"<\"+t+\">\",a=\"</\"+t+\">\",o=i.length,s=a.length,l=\"+\"===e[0]||\"-\"===e[0],c=0,u=-s;c>-1&&-1!==(c=r.indexOf(i,c))&&-1!==(u=r.indexOf(a,c+o))&&!(u<=c);){for(var f=c;f<u+s;++f)if(f<c+o||f>=u)n[f]=null,r=r.substr(0,f)+\" \"+r.substr(f+1);else if(null!==n[f]){var h=n[f].indexOf(e[0]);-1===h?n[f]+=e:l&&(n[f]=n[f].substr(0,h+1)+(1+parseInt(n[f][h+1]))+n[f].substr(h+2))}var p=c+o,d=r.substr(p,u-p).indexOf(i);c=-1!==d?d:u+s}return n}function u(t,e){var r=n(t,128);return e?a(r.cells,r.positions,.25):{edges:r.cells,positions:r.positions}}function f(t,e,r,n){var i=u(t,n),a=function(t,e,r){for(var n=e.textAlign||\"start\",i=e.textBaseline||\"alphabetic\",a=[1<<30,1<<30],o=[0,0],s=t.length,l=0;l<s;++l)for(var c=t[l],u=0;u<2;++u)a[u]=0|Math.min(a[u],c[u]),o[u]=0|Math.max(o[u],c[u]);var f=0;switch(n){case\"center\":f=-.5*(a[0]+o[0]);break;case\"right\":case\"end\":f=-o[0];break;case\"left\":case\"start\":f=-a[0];break;default:throw new Error(\"vectorize-text: Unrecognized textAlign: '\"+n+\"'\")}var h=0;switch(i){case\"hanging\":case\"top\":h=-a[1];break;case\"middle\":h=-.5*(a[1]+o[1]);break;case\"alphabetic\":case\"ideographic\":h=-3*r;break;case\"bottom\":h=-o[1];break;default:throw new Error(\"vectorize-text: Unrecoginized textBaseline: '\"+i+\"'\")}var p=1/r;return\"lineHeight\"in e?p*=+e.lineHeight:\"width\"in e?p=e.width/(o[0]-a[0]):\"height\"in e&&(p=e.height/(o[1]-a[1])),t.map((function(t){return[p*(t[0]+f),p*(t[1]+h)]}))}(i.positions,e,r),c=i.edges,f=\"ccw\"===e.orientation;if(o(a,c),e.polygons||e.polygon||e.polyline){for(var h=l(c,a),p=new Array(h.length),d=0;d<h.length;++d){for(var m=h[d],g=new Array(m.length),v=0;v<m.length;++v){for(var y=m[v],x=new Array(y.length),b=0;b<y.length;++b)x[b]=a[y[b]].slice();f&&x.reverse(),g[v]=x}p[d]=g}return p}return e.triangles||e.triangulate||e.triangle?{cells:s(a,c,{delaunay:!1,exterior:!1,interior:!0}),positions:a}:{edges:c,positions:a}}function h(t,e,r){try{return f(t,e,r,!0)}catch(t){}try{return f(t,e,r,!1)}catch(t){}return e.polygons||e.polyline||e.polygon?[]:e.triangles||e.triangulate||e.triangle?{cells:[],positions:[]}:{edges:[],positions:[]}}},{cdt2d:118,\"clean-pslg\":127,ndarray:479,\"planar-graph-to-polyline\":497,\"simplify-planar-graph\":559,\"surface-nets\":587}],621:[function(t,e,r){!function(){\"use strict\";if(\"undefined\"==typeof ses||!ses.ok||ses.ok()){\"undefined\"!=typeof ses&&(ses.weakMapPermitHostObjects=m);var t=!1;if(\"function\"==typeof WeakMap){var r=WeakMap;if(\"undefined\"!=typeof navigator&&/Firefox/.test(navigator.userAgent));else{var n=new r,i=Object.freeze({});if(n.set(i,1),1===n.get(i))return void(e.exports=WeakMap);t=!0}}Object.prototype.hasOwnProperty;var a=Object.getOwnPropertyNames,o=Object.defineProperty,s=Object.isExtensible,l=\"weakmap:ident:\"+Math.random()+\"___\";if(\"undefined\"!=typeof crypto&&\"function\"==typeof crypto.getRandomValues&&\"function\"==typeof ArrayBuffer&&\"function\"==typeof Uint8Array){var c=new ArrayBuffer(25),u=new Uint8Array(c);crypto.getRandomValues(u),l=\"weakmap:rand:\"+Array.prototype.map.call(u,(function(t){return(t%36).toString(36)})).join(\"\")+\"___\"}if(o(Object,\"getOwnPropertyNames\",{value:function(t){return a(t).filter(g)}}),\"getPropertyNames\"in Object){var f=Object.getPropertyNames;o(Object,\"getPropertyNames\",{value:function(t){return f(t).filter(g)}})}!function(){var t=Object.freeze;o(Object,\"freeze\",{value:function(e){return v(e),t(e)}});var e=Object.seal;o(Object,\"seal\",{value:function(t){return v(t),e(t)}});var r=Object.preventExtensions;o(Object,\"preventExtensions\",{value:function(t){return v(t),r(t)}})}();var h=!1,p=0,d=function(){this instanceof d||x();var t=[],e=[],r=p++;return Object.create(d.prototype,{get___:{value:y((function(n,i){var a,o=v(n);return o?r in o?o[r]:i:(a=t.indexOf(n))>=0?e[a]:i}))},has___:{value:y((function(e){var n=v(e);return n?r in n:t.indexOf(e)>=0}))},set___:{value:y((function(n,i){var a,o=v(n);return o?o[r]=i:(a=t.indexOf(n))>=0?e[a]=i:(a=t.length,e[a]=i,t[a]=n),this}))},delete___:{value:y((function(n){var i,a,o=v(n);return o?r in o&&delete o[r]:!((i=t.indexOf(n))<0)&&(a=t.length-1,t[i]=void 0,e[i]=e[a],t[i]=t[a],t.length=a,e.length=a,!0)}))}})};d.prototype=Object.create(Object.prototype,{get:{value:function(t,e){return this.get___(t,e)},writable:!0,configurable:!0},has:{value:function(t){return this.has___(t)},writable:!0,configurable:!0},set:{value:function(t,e){return this.set___(t,e)},writable:!0,configurable:!0},delete:{value:function(t){return this.delete___(t)},writable:!0,configurable:!0}}),\"function\"==typeof r?function(){function n(){this instanceof d||x();var e,n=new r,i=void 0,a=!1;return e=t?function(t,e){return n.set(t,e),n.has(t)||(i||(i=new d),i.set(t,e)),this}:function(t,e){if(a)try{n.set(t,e)}catch(r){i||(i=new d),i.set___(t,e)}else n.set(t,e);return this},Object.create(d.prototype,{get___:{value:y((function(t,e){return i?n.has(t)?n.get(t):i.get___(t,e):n.get(t,e)}))},has___:{value:y((function(t){return n.has(t)||!!i&&i.has___(t)}))},set___:{value:y(e)},delete___:{value:y((function(t){var e=!!n.delete(t);return i&&i.delete___(t)||e}))},permitHostObjects___:{value:y((function(t){if(t!==m)throw new Error(\"bogus call to permitHostObjects___\");a=!0}))}})}t&&\"undefined\"!=typeof Proxy&&(Proxy=void 0),n.prototype=d.prototype,e.exports=n,Object.defineProperty(WeakMap.prototype,\"constructor\",{value:WeakMap,enumerable:!1,configurable:!0,writable:!0})}():(\"undefined\"!=typeof Proxy&&(Proxy=void 0),e.exports=d)}function m(t){t.permitHostObjects___&&t.permitHostObjects___(m)}function g(t){return!(\"weakmap:\"==t.substr(0,\"weakmap:\".length)&&\"___\"===t.substr(t.length-3))}function v(t){if(t!==Object(t))throw new TypeError(\"Not an object: \"+t);var e=t[l];if(e&&e.key===t)return e;if(s(t)){e={key:t};try{return o(t,l,{value:e,writable:!1,enumerable:!1,configurable:!1}),e}catch(t){return}}}function y(t){return t.prototype=null,Object.freeze(t)}function x(){h||\"undefined\"==typeof console||(h=!0,console.warn(\"WeakMap should be invoked as new WeakMap(), not WeakMap(). This will be an error in the future.\"))}}()},{}],622:[function(t,e,r){var n=t(\"./hidden-store.js\");e.exports=function(){var t={};return function(e){if((\"object\"!=typeof e||null===e)&&\"function\"!=typeof e)throw new Error(\"Weakmap-shim: Key must be object\");var r=e.valueOf(t);return r&&r.identity===t?r:n(e,t)}}},{\"./hidden-store.js\":623}],623:[function(t,e,r){e.exports=function(t,e){var r={identity:e},n=t.valueOf;return Object.defineProperty(t,\"valueOf\",{value:function(t){return t!==e?n.apply(this,arguments):r},writable:!0}),r}},{}],624:[function(t,e,r){var n=t(\"./create-store.js\");e.exports=function(){var t=n();return{get:function(e,r){var n=t(e);return n.hasOwnProperty(\"value\")?n.value:r},set:function(e,r){return t(e).value=r,this},has:function(e){return\"value\"in t(e)},delete:function(e){return delete t(e).value}}}},{\"./create-store.js\":622}],625:[function(t,e,r){var n=t(\"get-canvas-context\");e.exports=function(t){return n(\"webgl\",t)}},{\"get-canvas-context\":253}],626:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\"),a=n.instance();function o(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}o.prototype=new n.baseCalendar,i(o.prototype,{name:\"Chinese\",jdEpoch:1721425.5,hasYearZero:!1,minMonth:0,firstMonth:0,minDay:1,regionalOptions:{\"\":{name:\"Chinese\",epochs:[\"BEC\",\"EC\"],monthNumbers:function(t,e){if(\"string\"==typeof t){var r=t.match(l);return r?r[0]:\"\"}var n=this._validateYear(t),i=t.month(),a=\"\"+this.toChineseMonth(n,i);return e&&a.length<2&&(a=\"0\"+a),this.isIntercalaryMonth(n,i)&&(a+=\"i\"),a},monthNames:function(t){if(\"string\"==typeof t){var e=t.match(c);return e?e[0]:\"\"}var r=this._validateYear(t),n=t.month(),i=[\"\\u4e00\\u6708\",\"\\u4e8c\\u6708\",\"\\u4e09\\u6708\",\"\\u56db\\u6708\",\"\\u4e94\\u6708\",\"\\u516d\\u6708\",\"\\u4e03\\u6708\",\"\\u516b\\u6708\",\"\\u4e5d\\u6708\",\"\\u5341\\u6708\",\"\\u5341\\u4e00\\u6708\",\"\\u5341\\u4e8c\\u6708\"][this.toChineseMonth(r,n)-1];return this.isIntercalaryMonth(r,n)&&(i=\"\\u95f0\"+i),i},monthNamesShort:function(t){if(\"string\"==typeof t){var e=t.match(u);return e?e[0]:\"\"}var r=this._validateYear(t),n=t.month(),i=[\"\\u4e00\",\"\\u4e8c\",\"\\u4e09\",\"\\u56db\",\"\\u4e94\",\"\\u516d\",\"\\u4e03\",\"\\u516b\",\"\\u4e5d\",\"\\u5341\",\"\\u5341\\u4e00\",\"\\u5341\\u4e8c\"][this.toChineseMonth(r,n)-1];return this.isIntercalaryMonth(r,n)&&(i=\"\\u95f0\"+i),i},parseMonth:function(t,e){t=this._validateYear(t);var r,n=parseInt(e);if(isNaN(n))\"\\u95f0\"===e[0]&&(r=!0,e=e.substring(1)),\"\\u6708\"===e[e.length-1]&&(e=e.substring(0,e.length-1)),n=1+[\"\\u4e00\",\"\\u4e8c\",\"\\u4e09\",\"\\u56db\",\"\\u4e94\",\"\\u516d\",\"\\u4e03\",\"\\u516b\",\"\\u4e5d\",\"\\u5341\",\"\\u5341\\u4e00\",\"\\u5341\\u4e8c\"].indexOf(e);else{var i=e[e.length-1];r=\"i\"===i||\"I\"===i}return this.toMonthIndex(t,n,r)},dayNames:[\"Sunday\",\"Monday\",\"Tuesday\",\"Wednesday\",\"Thursday\",\"Friday\",\"Saturday\"],dayNamesShort:[\"Sun\",\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\"],dayNamesMin:[\"Su\",\"Mo\",\"Tu\",\"We\",\"Th\",\"Fr\",\"Sa\"],digits:null,dateFormat:\"yyyy/mm/dd\",firstDay:1,isRTL:!1}},_validateYear:function(t,e){if(t.year&&(t=t.year()),\"number\"!=typeof t||t<1888||t>2111)throw e.replace(/\\{0\\}/,this.local.name);return t},toMonthIndex:function(t,e,r){var i=this.intercalaryMonth(t);if(r&&e!==i||e<1||e>12)throw n.local.invalidMonth.replace(/\\{0\\}/,this.local.name);return i?!r&&e<=i?e-1:e:e-1},toChineseMonth:function(t,e){t.year&&(e=(t=t.year()).month());var r=this.intercalaryMonth(t);if(e<0||e>(r?12:11))throw n.local.invalidMonth.replace(/\\{0\\}/,this.local.name);return r?e<r?e+1:e:e+1},intercalaryMonth:function(t){return t=this._validateYear(t),f[t-f[0]]>>13},isIntercalaryMonth:function(t,e){t.year&&(e=(t=t.year()).month());var r=this.intercalaryMonth(t);return!!r&&r===e},leapYear:function(t){return 0!==this.intercalaryMonth(t)},weekOfYear:function(t,e,r){var i,o=this._validateYear(t,n.local.invalidyear),s=h[o-h[0]],l=s>>9&4095,c=s>>5&15,u=31&s;(i=a.newDate(l,c,u)).add(4-(i.dayOfWeek()||7),\"d\");var f=this.toJD(t,e,r)-i.toJD();return 1+Math.floor(f/7)},monthsInYear:function(t){return this.leapYear(t)?13:12},daysInMonth:function(t,e){t.year&&(e=t.month(),t=t.year()),t=this._validateYear(t);var r=f[t-f[0]];if(e>(r>>13?12:11))throw n.local.invalidMonth.replace(/\\{0\\}/,this.local.name);return r&1<<12-e?30:29},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var i=this._validate(t,s,r,n.local.invalidDate);t=this._validateYear(i.year()),e=i.month(),r=i.day();var o=this.isIntercalaryMonth(t,e),s=this.toChineseMonth(t,e),l=function(t,e,r,n,i){var a,o,s;if(\"object\"==typeof t)o=t,a=e||{};else{var l;if(!(\"number\"==typeof t&&t>=1888&&t<=2111))throw new Error(\"Lunar year outside range 1888-2111\");if(!(\"number\"==typeof e&&e>=1&&e<=12))throw new Error(\"Lunar month outside range 1 - 12\");if(!(\"number\"==typeof r&&r>=1&&r<=30))throw new Error(\"Lunar day outside range 1 - 30\");\"object\"==typeof n?(l=!1,a=n):(l=!!n,a=i||{}),o={year:t,month:e,day:r,isIntercalary:l}}s=o.day-1;var c,u=f[o.year-f[0]],p=u>>13;c=p&&(o.month>p||o.isIntercalary)?o.month:o.month-1;for(var d=0;d<c;d++){s+=u&1<<12-d?30:29}var m=h[o.year-h[0]],g=new Date(m>>9&4095,(m>>5&15)-1,(31&m)+s);return a.year=g.getFullYear(),a.month=1+g.getMonth(),a.day=g.getDate(),a}(t,s,r,o);return a.toJD(l.year,l.month,l.day)},fromJD:function(t){var e=a.fromJD(t),r=function(t,e,r,n){var i,a;if(\"object\"==typeof t)i=t,a=e||{};else{if(!(\"number\"==typeof t&&t>=1888&&t<=2111))throw new Error(\"Solar year outside range 1888-2111\");if(!(\"number\"==typeof e&&e>=1&&e<=12))throw new Error(\"Solar month outside range 1 - 12\");if(!(\"number\"==typeof r&&r>=1&&r<=31))throw new Error(\"Solar day outside range 1 - 31\");i={year:t,month:e,day:r},a=n||{}}var o=h[i.year-h[0]],s=i.year<<9|i.month<<5|i.day;a.year=s>=o?i.year:i.year-1,o=h[a.year-h[0]];var l,c=new Date(o>>9&4095,(o>>5&15)-1,31&o),u=new Date(i.year,i.month-1,i.day);l=Math.round((u-c)/864e5);var p,d=f[a.year-f[0]];for(p=0;p<13;p++){var m=d&1<<12-p?30:29;if(l<m)break;l-=m}var g=d>>13;!g||p<g?(a.isIntercalary=!1,a.month=1+p):p===g?(a.isIntercalary=!0,a.month=p):(a.isIntercalary=!1,a.month=p);return a.day=1+l,a}(e.year(),e.month(),e.day()),n=this.toMonthIndex(r.year,r.month,r.isIntercalary);return this.newDate(r.year,n,r.day)},fromString:function(t){var e=t.match(s),r=this._validateYear(+e[1]),n=+e[2],i=!!e[3],a=this.toMonthIndex(r,n,i),o=+e[4];return this.newDate(r,a,o)},add:function(t,e,r){var n=t.year(),i=t.month(),a=this.isIntercalaryMonth(n,i),s=this.toChineseMonth(n,i),l=Object.getPrototypeOf(o.prototype).add.call(this,t,e,r);if(\"y\"===r){var c=l.year(),u=l.month(),f=this.isIntercalaryMonth(c,s),h=a&&f?this.toMonthIndex(c,s,!0):this.toMonthIndex(c,s,!1);h!==u&&l.month(h)}return l}});var s=/^\\s*(-?\\d\\d\\d\\d|\\d\\d)[-/](\\d?\\d)([iI]?)[-/](\\d?\\d)/m,l=/^\\d?\\d[iI]?/m,c=/^\\u95f0?\\u5341?[\\u4e00\\u4e8c\\u4e09\\u56db\\u4e94\\u516d\\u4e03\\u516b\\u4e5d]?\\u6708/m,u=/^\\u95f0?\\u5341?[\\u4e00\\u4e8c\\u4e09\\u56db\\u4e94\\u516d\\u4e03\\u516b\\u4e5d]?/m;n.calendars.chinese=o;var f=[1887,5780,5802,19157,2742,50359,1198,2646,46378,7466,3412,30122,5482,67949,2396,5294,43597,6732,6954,36181,2772,4954,18781,2396,54427,5274,6730,47781,5800,6868,21210,4790,59703,2350,5270,46667,3402,3496,38325,1388,4782,18735,2350,52374,6804,7498,44457,2906,1388,29294,4700,63789,6442,6804,56138,5802,2772,38235,1210,4698,22827,5418,63125,3476,5802,43701,2484,5302,27223,2646,70954,7466,3412,54698,5482,2412,38062,5294,2636,32038,6954,60245,2772,4826,43357,2394,5274,39501,6730,72357,5800,5844,53978,4790,2358,38039,5270,87627,3402,3496,54708,5484,4782,43311,2350,3222,27978,7498,68965,2904,5484,45677,4700,6444,39573,6804,6986,19285,2772,62811,1210,4698,47403,5418,5780,38570,5546,76469,2420,5302,51799,2646,5414,36501,3412,5546,18869,2412,54446,5276,6732,48422,6822,2900,28010,4826,92509,2394,5274,55883,6730,6820,47956,5812,2778,18779,2358,62615,5270,5450,46757,3492,5556,27318,4718,67887,2350,3222,52554,7498,3428,38252,5468,4700,31022,6444,64149,6804,6986,43861,2772,5338,35421,2650,70955,5418,5780,54954,5546,2740,38074,5302,2646,29991,3366,61011,3412,5546,43445,2412,5294,35406,6732,72998,6820,6996,52586,2778,2396,38045,5274,6698,23333,6820,64338,5812,2746,43355,2358,5270,39499,5450,79525,3492,5548],h=[1887,966732,967231,967733,968265,968766,969297,969798,970298,970829,971330,971830,972362,972863,973395,973896,974397,974928,975428,975929,976461,976962,977462,977994,978494,979026,979526,980026,980558,981059,981559,982091,982593,983124,983624,984124,984656,985157,985656,986189,986690,987191,987722,988222,988753,989254,989754,990286,990788,991288,991819,992319,992851,993352,993851,994383,994885,995385,995917,996418,996918,997450,997949,998481,998982,999483,1000014,1000515,1001016,1001548,1002047,1002578,1003080,1003580,1004111,1004613,1005113,1005645,1006146,1006645,1007177,1007678,1008209,1008710,1009211,1009743,1010243,1010743,1011275,1011775,1012306,1012807,1013308,1013840,1014341,1014841,1015373,1015874,1016404,1016905,1017405,1017937,1018438,1018939,1019471,1019972,1020471,1021002,1021503,1022035,1022535,1023036,1023568,1024069,1024568,1025100,1025601,1026102,1026633,1027133,1027666,1028167,1028666,1029198,1029699,1030199,1030730,1031231,1031763,1032264,1032764,1033296,1033797,1034297,1034828,1035329,1035830,1036362,1036861,1037393,1037894,1038394,1038925,1039427,1039927,1040459,1040959,1041491,1041992,1042492,1043023,1043524,1044024,1044556,1045057,1045558,1046090,1046590,1047121,1047622,1048122,1048654,1049154,1049655,1050187,1050689,1051219,1051720,1052220,1052751,1053252,1053752,1054284,1054786,1055285,1055817,1056317,1056849,1057349,1057850,1058382,1058883,1059383,1059915,1060415,1060947,1061447,1061947,1062479,1062981,1063480,1064012,1064514,1065014,1065545,1066045,1066577,1067078,1067578,1068110,1068611,1069112,1069642,1070142,1070674,1071175,1071675,1072207,1072709,1073209,1073740,1074241,1074741,1075273,1075773,1076305,1076807,1077308,1077839,1078340,1078840,1079372,1079871,1080403,1080904]},{\"../main\":640,\"object-assign\":483}],627:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"Coptic\",jdEpoch:1825029.5,daysPerMonth:[30,30,30,30,30,30,30,30,30,30,30,30,5],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Coptic\",epochs:[\"BAM\",\"AM\"],monthNames:[\"Thout\",\"Paopi\",\"Hathor\",\"Koiak\",\"Tobi\",\"Meshir\",\"Paremhat\",\"Paremoude\",\"Pashons\",\"Paoni\",\"Epip\",\"Mesori\",\"Pi Kogi Enavot\"],monthNamesShort:[\"Tho\",\"Pao\",\"Hath\",\"Koi\",\"Tob\",\"Mesh\",\"Pat\",\"Pad\",\"Pash\",\"Pao\",\"Epi\",\"Meso\",\"PiK\"],dayNames:[\"Tkyriaka\",\"Pesnau\",\"Pshoment\",\"Peftoou\",\"Ptiou\",\"Psoou\",\"Psabbaton\"],dayNamesShort:[\"Tky\",\"Pes\",\"Psh\",\"Pef\",\"Pti\",\"Pso\",\"Psa\"],dayNamesMin:[\"Tk\",\"Pes\",\"Psh\",\"Pef\",\"Pt\",\"Pso\",\"Psa\"],digits:null,dateFormat:\"dd/mm/yyyy\",firstDay:0,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);return(t=e.year()+(e.year()<0?1:0))%4==3||t%4==-1},monthsInYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear||n.regionalOptions[\"\"].invalidYear),13},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-n.dayOfWeek(),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(13===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);return(t=i.year())<0&&t++,i.day()+30*(i.month()-1)+365*(t-1)+Math.floor(t/4)+this.jdEpoch-1},fromJD:function(t){var e=Math.floor(t)+.5-this.jdEpoch,r=Math.floor((e-Math.floor((e+366)/1461))/365)+1;r<=0&&r--,e=Math.floor(t)+.5-this.newDate(r,1,1).toJD();var n=Math.floor(e/30)+1,i=e-30*(n-1)+1;return this.newDate(r,n,i)}}),n.calendars.coptic=a},{\"../main\":640,\"object-assign\":483}],628:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"Discworld\",jdEpoch:1721425.5,daysPerMonth:[16,32,32,32,32,32,32,32,32,32,32,32,32],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Discworld\",epochs:[\"BUC\",\"UC\"],monthNames:[\"Ick\",\"Offle\",\"February\",\"March\",\"April\",\"May\",\"June\",\"Grune\",\"August\",\"Spune\",\"Sektober\",\"Ember\",\"December\"],monthNamesShort:[\"Ick\",\"Off\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\"Gru\",\"Aug\",\"Spu\",\"Sek\",\"Emb\",\"Dec\"],dayNames:[\"Sunday\",\"Octeday\",\"Monday\",\"Tuesday\",\"Wednesday\",\"Thursday\",\"Friday\",\"Saturday\"],dayNamesShort:[\"Sun\",\"Oct\",\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\"],dayNamesMin:[\"Su\",\"Oc\",\"Mo\",\"Tu\",\"We\",\"Th\",\"Fr\",\"Sa\"],digits:null,dateFormat:\"yyyy/mm/dd\",firstDay:2,isRTL:!1}},leapYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear),!1},monthsInYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear),13},daysInYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear),400},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-n.dayOfWeek(),\"d\"),Math.floor((n.dayOfYear()-1)/8)+1},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]},daysInWeek:function(){return 8},dayOfWeek:function(t,e,r){return(this._validate(t,e,r,n.local.invalidDate).day()+1)%8},weekDay:function(t,e,r){var n=this.dayOfWeek(t,e,r);return n>=2&&n<=6},extraInfo:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);return{century:o[Math.floor((i.year()-1)/100)+1]||\"\"}},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);return t=i.year()+(i.year()<0?1:0),e=i.month(),(r=i.day())+(e>1?16:0)+(e>2?32*(e-2):0)+400*(t-1)+this.jdEpoch-1},fromJD:function(t){t=Math.floor(t+.5)-Math.floor(this.jdEpoch)-1;var e=Math.floor(t/400)+1;t-=400*(e-1),t+=t>15?16:0;var r=Math.floor(t/32)+1,n=t-32*(r-1)+1;return this.newDate(e<=0?e-1:e,r,n)}});var o={20:\"Fruitbat\",21:\"Anchovy\"};n.calendars.discworld=a},{\"../main\":640,\"object-assign\":483}],629:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"Ethiopian\",jdEpoch:1724220.5,daysPerMonth:[30,30,30,30,30,30,30,30,30,30,30,30,5],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Ethiopian\",epochs:[\"BEE\",\"EE\"],monthNames:[\"Meskerem\",\"Tikemet\",\"Hidar\",\"Tahesas\",\"Tir\",\"Yekatit\",\"Megabit\",\"Miazia\",\"Genbot\",\"Sene\",\"Hamle\",\"Nehase\",\"Pagume\"],monthNamesShort:[\"Mes\",\"Tik\",\"Hid\",\"Tah\",\"Tir\",\"Yek\",\"Meg\",\"Mia\",\"Gen\",\"Sen\",\"Ham\",\"Neh\",\"Pag\"],dayNames:[\"Ehud\",\"Segno\",\"Maksegno\",\"Irob\",\"Hamus\",\"Arb\",\"Kidame\"],dayNamesShort:[\"Ehu\",\"Seg\",\"Mak\",\"Iro\",\"Ham\",\"Arb\",\"Kid\"],dayNamesMin:[\"Eh\",\"Se\",\"Ma\",\"Ir\",\"Ha\",\"Ar\",\"Ki\"],digits:null,dateFormat:\"dd/mm/yyyy\",firstDay:0,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);return(t=e.year()+(e.year()<0?1:0))%4==3||t%4==-1},monthsInYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear||n.regionalOptions[\"\"].invalidYear),13},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-n.dayOfWeek(),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(13===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);return(t=i.year())<0&&t++,i.day()+30*(i.month()-1)+365*(t-1)+Math.floor(t/4)+this.jdEpoch-1},fromJD:function(t){var e=Math.floor(t)+.5-this.jdEpoch,r=Math.floor((e-Math.floor((e+366)/1461))/365)+1;r<=0&&r--,e=Math.floor(t)+.5-this.newDate(r,1,1).toJD();var n=Math.floor(e/30)+1,i=e-30*(n-1)+1;return this.newDate(r,n,i)}}),n.calendars.ethiopian=a},{\"../main\":640,\"object-assign\":483}],630:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}function o(t,e){return t-e*Math.floor(t/e)}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"Hebrew\",jdEpoch:347995.5,daysPerMonth:[30,29,30,29,30,29,30,29,30,29,30,29,29],hasYearZero:!1,minMonth:1,firstMonth:7,minDay:1,regionalOptions:{\"\":{name:\"Hebrew\",epochs:[\"BAM\",\"AM\"],monthNames:[\"Nisan\",\"Iyar\",\"Sivan\",\"Tammuz\",\"Av\",\"Elul\",\"Tishrei\",\"Cheshvan\",\"Kislev\",\"Tevet\",\"Shevat\",\"Adar\",\"Adar II\"],monthNamesShort:[\"Nis\",\"Iya\",\"Siv\",\"Tam\",\"Av\",\"Elu\",\"Tis\",\"Che\",\"Kis\",\"Tev\",\"She\",\"Ada\",\"Ad2\"],dayNames:[\"Yom Rishon\",\"Yom Sheni\",\"Yom Shlishi\",\"Yom Revi'i\",\"Yom Chamishi\",\"Yom Shishi\",\"Yom Shabbat\"],dayNamesShort:[\"Ris\",\"She\",\"Shl\",\"Rev\",\"Cha\",\"Shi\",\"Sha\"],dayNamesMin:[\"Ri\",\"She\",\"Shl\",\"Re\",\"Ch\",\"Shi\",\"Sha\"],digits:null,dateFormat:\"dd/mm/yyyy\",firstDay:0,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);return this._leapYear(e.year())},_leapYear:function(t){return o(7*(t=t<0?t+1:t)+1,19)<7},monthsInYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear),this._leapYear(t.year?t.year():t)?13:12},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-n.dayOfWeek(),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInYear:function(t){return t=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear).year(),this.toJD(-1===t?1:t+1,7,1)-this.toJD(t,7,1)},daysInMonth:function(t,e){return t.year&&(e=t.month(),t=t.year()),this._validate(t,e,this.minDay,n.local.invalidMonth),12===e&&this.leapYear(t)||8===e&&5===o(this.daysInYear(t),10)?30:9===e&&3===o(this.daysInYear(t),10)?29:this.daysPerMonth[e-1]},weekDay:function(t,e,r){return 6!==this.dayOfWeek(t,e,r)},extraInfo:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);return{yearType:(this.leapYear(i)?\"embolismic\":\"common\")+\" \"+[\"deficient\",\"regular\",\"complete\"][this.daysInYear(i)%10-3]}},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);t=i.year(),e=i.month(),r=i.day();var a=t<=0?t+1:t,o=this.jdEpoch+this._delay1(a)+this._delay2(a)+r+1;if(e<7){for(var s=7;s<=this.monthsInYear(t);s++)o+=this.daysInMonth(t,s);for(s=1;s<e;s++)o+=this.daysInMonth(t,s)}else for(s=7;s<e;s++)o+=this.daysInMonth(t,s);return o},_delay1:function(t){var e=Math.floor((235*t-234)/19),r=12084+13753*e,n=29*e+Math.floor(r/25920);return o(3*(n+1),7)<3&&n++,n},_delay2:function(t){var e=this._delay1(t-1),r=this._delay1(t);return this._delay1(t+1)-r==356?2:r-e==382?1:0},fromJD:function(t){t=Math.floor(t)+.5;for(var e=Math.floor(98496*(t-this.jdEpoch)/35975351)-1;t>=this.toJD(-1===e?1:e+1,7,1);)e++;for(var r=t<this.toJD(e,1,1)?7:1;t>this.toJD(e,r,this.daysInMonth(e,r));)r++;var n=t-this.toJD(e,r,1)+1;return this.newDate(e,r,n)}}),n.calendars.hebrew=a},{\"../main\":640,\"object-assign\":483}],631:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"Islamic\",jdEpoch:1948439.5,daysPerMonth:[30,29,30,29,30,29,30,29,30,29,30,29],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Islamic\",epochs:[\"BH\",\"AH\"],monthNames:[\"Muharram\",\"Safar\",\"Rabi' al-awwal\",\"Rabi' al-thani\",\"Jumada al-awwal\",\"Jumada al-thani\",\"Rajab\",\"Sha'aban\",\"Ramadan\",\"Shawwal\",\"Dhu al-Qi'dah\",\"Dhu al-Hijjah\"],monthNamesShort:[\"Muh\",\"Saf\",\"Rab1\",\"Rab2\",\"Jum1\",\"Jum2\",\"Raj\",\"Sha'\",\"Ram\",\"Shaw\",\"DhuQ\",\"DhuH\"],dayNames:[\"Yawm al-ahad\",\"Yawm al-ithnayn\",\"Yawm ath-thulaathaa'\",\"Yawm al-arbi'aa'\",\"Yawm al-kham\\u012bs\",\"Yawm al-jum'a\",\"Yawm as-sabt\"],dayNamesShort:[\"Aha\",\"Ith\",\"Thu\",\"Arb\",\"Kha\",\"Jum\",\"Sab\"],dayNamesMin:[\"Ah\",\"It\",\"Th\",\"Ar\",\"Kh\",\"Ju\",\"Sa\"],digits:null,dateFormat:\"yyyy/mm/dd\",firstDay:6,isRTL:!1}},leapYear:function(t){return(11*this._validate(t,this.minMonth,this.minDay,n.local.invalidYear).year()+14)%30<11},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-n.dayOfWeek(),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInYear:function(t){return this.leapYear(t)?355:354},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(12===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return 5!==this.dayOfWeek(t,e,r)},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);return t=i.year(),e=i.month(),t=t<=0?t+1:t,(r=i.day())+Math.ceil(29.5*(e-1))+354*(t-1)+Math.floor((3+11*t)/30)+this.jdEpoch-1},fromJD:function(t){t=Math.floor(t)+.5;var e=Math.floor((30*(t-this.jdEpoch)+10646)/10631);e=e<=0?e-1:e;var r=Math.min(12,Math.ceil((t-29-this.toJD(e,1,1))/29.5)+1),n=t-this.toJD(e,r,1)+1;return this.newDate(e,r,n)}}),n.calendars.islamic=a},{\"../main\":640,\"object-assign\":483}],632:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"Julian\",jdEpoch:1721423.5,daysPerMonth:[31,28,31,30,31,30,31,31,30,31,30,31],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Julian\",epochs:[\"BC\",\"AD\"],monthNames:[\"January\",\"February\",\"March\",\"April\",\"May\",\"June\",\"July\",\"August\",\"September\",\"October\",\"November\",\"December\"],monthNamesShort:[\"Jan\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\"Jul\",\"Aug\",\"Sep\",\"Oct\",\"Nov\",\"Dec\"],dayNames:[\"Sunday\",\"Monday\",\"Tuesday\",\"Wednesday\",\"Thursday\",\"Friday\",\"Saturday\"],dayNamesShort:[\"Sun\",\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\"],dayNamesMin:[\"Su\",\"Mo\",\"Tu\",\"We\",\"Th\",\"Fr\",\"Sa\"],digits:null,dateFormat:\"mm/dd/yyyy\",firstDay:0,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);return(t=e.year()<0?e.year()+1:e.year())%4==0},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(4-(n.dayOfWeek()||7),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(2===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);return t=i.year(),e=i.month(),r=i.day(),t<0&&t++,e<=2&&(t--,e+=12),Math.floor(365.25*(t+4716))+Math.floor(30.6001*(e+1))+r-1524.5},fromJD:function(t){var e=Math.floor(t+.5)+1524,r=Math.floor((e-122.1)/365.25),n=Math.floor(365.25*r),i=Math.floor((e-n)/30.6001),a=i-Math.floor(i<14?1:13),o=r-Math.floor(a>2?4716:4715),s=e-n-Math.floor(30.6001*i);return o<=0&&o--,this.newDate(o,a,s)}}),n.calendars.julian=a},{\"../main\":640,\"object-assign\":483}],633:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}function o(t,e){return t-e*Math.floor(t/e)}function s(t,e){return o(t-1,e)+1}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"Mayan\",jdEpoch:584282.5,hasYearZero:!0,minMonth:0,firstMonth:0,minDay:0,regionalOptions:{\"\":{name:\"Mayan\",epochs:[\"\",\"\"],monthNames:[\"0\",\"1\",\"2\",\"3\",\"4\",\"5\",\"6\",\"7\",\"8\",\"9\",\"10\",\"11\",\"12\",\"13\",\"14\",\"15\",\"16\",\"17\"],monthNamesShort:[\"0\",\"1\",\"2\",\"3\",\"4\",\"5\",\"6\",\"7\",\"8\",\"9\",\"10\",\"11\",\"12\",\"13\",\"14\",\"15\",\"16\",\"17\"],dayNames:[\"0\",\"1\",\"2\",\"3\",\"4\",\"5\",\"6\",\"7\",\"8\",\"9\",\"10\",\"11\",\"12\",\"13\",\"14\",\"15\",\"16\",\"17\",\"18\",\"19\"],dayNamesShort:[\"0\",\"1\",\"2\",\"3\",\"4\",\"5\",\"6\",\"7\",\"8\",\"9\",\"10\",\"11\",\"12\",\"13\",\"14\",\"15\",\"16\",\"17\",\"18\",\"19\"],dayNamesMin:[\"0\",\"1\",\"2\",\"3\",\"4\",\"5\",\"6\",\"7\",\"8\",\"9\",\"10\",\"11\",\"12\",\"13\",\"14\",\"15\",\"16\",\"17\",\"18\",\"19\"],digits:null,dateFormat:\"YYYY.m.d\",firstDay:0,isRTL:!1,haabMonths:[\"Pop\",\"Uo\",\"Zip\",\"Zotz\",\"Tzec\",\"Xul\",\"Yaxkin\",\"Mol\",\"Chen\",\"Yax\",\"Zac\",\"Ceh\",\"Mac\",\"Kankin\",\"Muan\",\"Pax\",\"Kayab\",\"Cumku\",\"Uayeb\"],tzolkinMonths:[\"Imix\",\"Ik\",\"Akbal\",\"Kan\",\"Chicchan\",\"Cimi\",\"Manik\",\"Lamat\",\"Muluc\",\"Oc\",\"Chuen\",\"Eb\",\"Ben\",\"Ix\",\"Men\",\"Cib\",\"Caban\",\"Etznab\",\"Cauac\",\"Ahau\"]}},leapYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear),!1},formatYear:function(t){t=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear).year();var e=Math.floor(t/400);return t%=400,t+=t<0?400:0,e+\".\"+Math.floor(t/20)+\".\"+t%20},forYear:function(t){if((t=t.split(\".\")).length<3)throw\"Invalid Mayan year\";for(var e=0,r=0;r<t.length;r++){var n=parseInt(t[r],10);if(Math.abs(n)>19||r>0&&n<0)throw\"Invalid Mayan year\";e=20*e+n}return e},monthsInYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear),18},weekOfYear:function(t,e,r){return this._validate(t,e,r,n.local.invalidDate),0},daysInYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear),360},daysInMonth:function(t,e){return this._validate(t,e,this.minDay,n.local.invalidMonth),20},daysInWeek:function(){return 5},dayOfWeek:function(t,e,r){return this._validate(t,e,r,n.local.invalidDate).day()},weekDay:function(t,e,r){return this._validate(t,e,r,n.local.invalidDate),!0},extraInfo:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate).toJD(),a=this._toHaab(i),o=this._toTzolkin(i);return{haabMonthName:this.local.haabMonths[a[0]-1],haabMonth:a[0],haabDay:a[1],tzolkinDayName:this.local.tzolkinMonths[o[0]-1],tzolkinDay:o[0],tzolkinTrecena:o[1]}},_toHaab:function(t){var e=o((t-=this.jdEpoch)+8+340,365);return[Math.floor(e/20)+1,o(e,20)]},_toTzolkin:function(t){return[s((t-=this.jdEpoch)+20,20),s(t+4,13)]},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);return i.day()+20*i.month()+360*i.year()+this.jdEpoch},fromJD:function(t){t=Math.floor(t)+.5-this.jdEpoch;var e=Math.floor(t/360);t%=360,t+=t<0?360:0;var r=Math.floor(t/20),n=t%20;return this.newDate(e,r,n)}}),n.calendars.mayan=a},{\"../main\":640,\"object-assign\":483}],634:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}a.prototype=new n.baseCalendar;var o=n.instance(\"gregorian\");i(a.prototype,{name:\"Nanakshahi\",jdEpoch:2257673.5,daysPerMonth:[31,31,31,31,31,30,30,30,30,30,30,30],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Nanakshahi\",epochs:[\"BN\",\"AN\"],monthNames:[\"Chet\",\"Vaisakh\",\"Jeth\",\"Harh\",\"Sawan\",\"Bhadon\",\"Assu\",\"Katak\",\"Maghar\",\"Poh\",\"Magh\",\"Phagun\"],monthNamesShort:[\"Che\",\"Vai\",\"Jet\",\"Har\",\"Saw\",\"Bha\",\"Ass\",\"Kat\",\"Mgr\",\"Poh\",\"Mgh\",\"Pha\"],dayNames:[\"Somvaar\",\"Mangalvar\",\"Budhvaar\",\"Veervaar\",\"Shukarvaar\",\"Sanicharvaar\",\"Etvaar\"],dayNamesShort:[\"Som\",\"Mangal\",\"Budh\",\"Veer\",\"Shukar\",\"Sanichar\",\"Et\"],dayNamesMin:[\"So\",\"Ma\",\"Bu\",\"Ve\",\"Sh\",\"Sa\",\"Et\"],digits:null,dateFormat:\"dd-mm-yyyy\",firstDay:0,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear||n.regionalOptions[\"\"].invalidYear);return o.leapYear(e.year()+(e.year()<1?1:0)+1469)},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(1-(n.dayOfWeek()||7),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(12===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidMonth);(t=i.year())<0&&t++;for(var a=i.day(),s=1;s<i.month();s++)a+=this.daysPerMonth[s-1];return a+o.toJD(t+1468,3,13)},fromJD:function(t){t=Math.floor(t+.5);for(var e=Math.floor((t-(this.jdEpoch-1))/366);t>=this.toJD(e+1,1,1);)e++;for(var r=t-Math.floor(this.toJD(e,1,1)+.5)+1,n=1;r>this.daysInMonth(e,n);)r-=this.daysInMonth(e,n),n++;return this.newDate(e,n,r)}}),n.calendars.nanakshahi=a},{\"../main\":640,\"object-assign\":483}],635:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"Nepali\",jdEpoch:1700709.5,daysPerMonth:[31,31,32,32,31,30,30,29,30,29,30,30],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,daysPerYear:365,regionalOptions:{\"\":{name:\"Nepali\",epochs:[\"BBS\",\"ABS\"],monthNames:[\"Baisakh\",\"Jestha\",\"Ashadh\",\"Shrawan\",\"Bhadra\",\"Ashwin\",\"Kartik\",\"Mangsir\",\"Paush\",\"Mangh\",\"Falgun\",\"Chaitra\"],monthNamesShort:[\"Bai\",\"Je\",\"As\",\"Shra\",\"Bha\",\"Ash\",\"Kar\",\"Mang\",\"Pau\",\"Ma\",\"Fal\",\"Chai\"],dayNames:[\"Aaitabaar\",\"Sombaar\",\"Manglbaar\",\"Budhabaar\",\"Bihibaar\",\"Shukrabaar\",\"Shanibaar\"],dayNamesShort:[\"Aaita\",\"Som\",\"Mangl\",\"Budha\",\"Bihi\",\"Shukra\",\"Shani\"],dayNamesMin:[\"Aai\",\"So\",\"Man\",\"Bu\",\"Bi\",\"Shu\",\"Sha\"],digits:null,dateFormat:\"dd/mm/yyyy\",firstDay:1,isRTL:!1}},leapYear:function(t){return this.daysInYear(t)!==this.daysPerYear},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-n.dayOfWeek(),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInYear:function(t){if(t=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear).year(),void 0===this.NEPALI_CALENDAR_DATA[t])return this.daysPerYear;for(var e=0,r=this.minMonth;r<=12;r++)e+=this.NEPALI_CALENDAR_DATA[t][r];return e},daysInMonth:function(t,e){return t.year&&(e=t.month(),t=t.year()),this._validate(t,e,this.minDay,n.local.invalidMonth),void 0===this.NEPALI_CALENDAR_DATA[t]?this.daysPerMonth[e-1]:this.NEPALI_CALENDAR_DATA[t][e]},weekDay:function(t,e,r){return 6!==this.dayOfWeek(t,e,r)},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);t=i.year(),e=i.month(),r=i.day();var a=n.instance(),o=0,s=e,l=t;this._createMissingCalendarData(t);var c=t-(s>9||9===s&&r>=this.NEPALI_CALENDAR_DATA[l][0]?56:57);for(9!==e&&(o=r,s--);9!==s;)s<=0&&(s=12,l--),o+=this.NEPALI_CALENDAR_DATA[l][s],s--;return 9===e?(o+=r-this.NEPALI_CALENDAR_DATA[l][0])<0&&(o+=a.daysInYear(c)):o+=this.NEPALI_CALENDAR_DATA[l][9]-this.NEPALI_CALENDAR_DATA[l][0],a.newDate(c,1,1).add(o,\"d\").toJD()},fromJD:function(t){var e=n.instance().fromJD(t),r=e.year(),i=e.dayOfYear(),a=r+56;this._createMissingCalendarData(a);for(var o=9,s=this.NEPALI_CALENDAR_DATA[a][0],l=this.NEPALI_CALENDAR_DATA[a][o]-s+1;i>l;)++o>12&&(o=1,a++),l+=this.NEPALI_CALENDAR_DATA[a][o];var c=this.NEPALI_CALENDAR_DATA[a][o]-(l-i);return this.newDate(a,o,c)},_createMissingCalendarData:function(t){var e=this.daysPerMonth.slice(0);e.unshift(17);for(var r=t-1;r<t+2;r++)void 0===this.NEPALI_CALENDAR_DATA[r]&&(this.NEPALI_CALENDAR_DATA[r]=e)},NEPALI_CALENDAR_DATA:{1970:[18,31,31,32,31,31,31,30,29,30,29,30,30],1971:[18,31,31,32,31,32,30,30,29,30,29,30,30],1972:[17,31,32,31,32,31,30,30,30,29,29,30,30],1973:[19,30,32,31,32,31,30,30,30,29,30,29,31],1974:[19,31,31,32,30,31,31,30,29,30,29,30,30],1975:[18,31,31,32,32,30,31,30,29,30,29,30,30],1976:[17,31,32,31,32,31,30,30,30,29,29,30,31],1977:[18,31,32,31,32,31,31,29,30,29,30,29,31],1978:[18,31,31,32,31,31,31,30,29,30,29,30,30],1979:[18,31,31,32,32,31,30,30,29,30,29,30,30],1980:[17,31,32,31,32,31,30,30,30,29,29,30,31],1981:[18,31,31,31,32,31,31,29,30,30,29,30,30],1982:[18,31,31,32,31,31,31,30,29,30,29,30,30],1983:[18,31,31,32,32,31,30,30,29,30,29,30,30],1984:[17,31,32,31,32,31,30,30,30,29,29,30,31],1985:[18,31,31,31,32,31,31,29,30,30,29,30,30],1986:[18,31,31,32,31,31,31,30,29,30,29,30,30],1987:[18,31,32,31,32,31,30,30,29,30,29,30,30],1988:[17,31,32,31,32,31,30,30,30,29,29,30,31],1989:[18,31,31,31,32,31,31,30,29,30,29,30,30],1990:[18,31,31,32,31,31,31,30,29,30,29,30,30],1991:[18,31,32,31,32,31,30,30,29,30,29,30,30],1992:[17,31,32,31,32,31,30,30,30,29,30,29,31],1993:[18,31,31,31,32,31,31,30,29,30,29,30,30],1994:[18,31,31,32,31,31,31,30,29,30,29,30,30],1995:[17,31,32,31,32,31,30,30,30,29,29,30,30],1996:[17,31,32,31,32,31,30,30,30,29,30,29,31],1997:[18,31,31,32,31,31,31,30,29,30,29,30,30],1998:[18,31,31,32,31,31,31,30,29,30,29,30,30],1999:[17,31,32,31,32,31,30,30,30,29,29,30,31],2e3:[17,30,32,31,32,31,30,30,30,29,30,29,31],2001:[18,31,31,32,31,31,31,30,29,30,29,30,30],2002:[18,31,31,32,32,31,30,30,29,30,29,30,30],2003:[17,31,32,31,32,31,30,30,30,29,29,30,31],2004:[17,30,32,31,32,31,30,30,30,29,30,29,31],2005:[18,31,31,32,31,31,31,30,29,30,29,30,30],2006:[18,31,31,32,32,31,30,30,29,30,29,30,30],2007:[17,31,32,31,32,31,30,30,30,29,29,30,31],2008:[17,31,31,31,32,31,31,29,30,30,29,29,31],2009:[18,31,31,32,31,31,31,30,29,30,29,30,30],2010:[18,31,31,32,32,31,30,30,29,30,29,30,30],2011:[17,31,32,31,32,31,30,30,30,29,29,30,31],2012:[17,31,31,31,32,31,31,29,30,30,29,30,30],2013:[18,31,31,32,31,31,31,30,29,30,29,30,30],2014:[18,31,31,32,32,31,30,30,29,30,29,30,30],2015:[17,31,32,31,32,31,30,30,30,29,29,30,31],2016:[17,31,31,31,32,31,31,29,30,30,29,30,30],2017:[18,31,31,32,31,31,31,30,29,30,29,30,30],2018:[18,31,32,31,32,31,30,30,29,30,29,30,30],2019:[17,31,32,31,32,31,30,30,30,29,30,29,31],2020:[17,31,31,31,32,31,31,30,29,30,29,30,30],2021:[18,31,31,32,31,31,31,30,29,30,29,30,30],2022:[17,31,32,31,32,31,30,30,30,29,29,30,30],2023:[17,31,32,31,32,31,30,30,30,29,30,29,31],2024:[17,31,31,31,32,31,31,30,29,30,29,30,30],2025:[18,31,31,32,31,31,31,30,29,30,29,30,30],2026:[17,31,32,31,32,31,30,30,30,29,29,30,31],2027:[17,30,32,31,32,31,30,30,30,29,30,29,31],2028:[17,31,31,32,31,31,31,30,29,30,29,30,30],2029:[18,31,31,32,31,32,30,30,29,30,29,30,30],2030:[17,31,32,31,32,31,30,30,30,30,30,30,31],2031:[17,31,32,31,32,31,31,31,31,31,31,31,31],2032:[17,32,32,32,32,32,32,32,32,32,32,32,32],2033:[18,31,31,32,32,31,30,30,29,30,29,30,30],2034:[17,31,32,31,32,31,30,30,30,29,29,30,31],2035:[17,30,32,31,32,31,31,29,30,30,29,29,31],2036:[17,31,31,32,31,31,31,30,29,30,29,30,30],2037:[18,31,31,32,32,31,30,30,29,30,29,30,30],2038:[17,31,32,31,32,31,30,30,30,29,29,30,31],2039:[17,31,31,31,32,31,31,29,30,30,29,30,30],2040:[17,31,31,32,31,31,31,30,29,30,29,30,30],2041:[18,31,31,32,32,31,30,30,29,30,29,30,30],2042:[17,31,32,31,32,31,30,30,30,29,29,30,31],2043:[17,31,31,31,32,31,31,29,30,30,29,30,30],2044:[17,31,31,32,31,31,31,30,29,30,29,30,30],2045:[18,31,32,31,32,31,30,30,29,30,29,30,30],2046:[17,31,32,31,32,31,30,30,30,29,29,30,31],2047:[17,31,31,31,32,31,31,30,29,30,29,30,30],2048:[17,31,31,32,31,31,31,30,29,30,29,30,30],2049:[17,31,32,31,32,31,30,30,30,29,29,30,30],2050:[17,31,32,31,32,31,30,30,30,29,30,29,31],2051:[17,31,31,31,32,31,31,30,29,30,29,30,30],2052:[17,31,31,32,31,31,31,30,29,30,29,30,30],2053:[17,31,32,31,32,31,30,30,30,29,29,30,30],2054:[17,31,32,31,32,31,30,30,30,29,30,29,31],2055:[17,31,31,32,31,31,31,30,29,30,30,29,30],2056:[17,31,31,32,31,32,30,30,29,30,29,30,30],2057:[17,31,32,31,32,31,30,30,30,29,29,30,31],2058:[17,30,32,31,32,31,30,30,30,29,30,29,31],2059:[17,31,31,32,31,31,31,30,29,30,29,30,30],2060:[17,31,31,32,32,31,30,30,29,30,29,30,30],2061:[17,31,32,31,32,31,30,30,30,29,29,30,31],2062:[17,30,32,31,32,31,31,29,30,29,30,29,31],2063:[17,31,31,32,31,31,31,30,29,30,29,30,30],2064:[17,31,31,32,32,31,30,30,29,30,29,30,30],2065:[17,31,32,31,32,31,30,30,30,29,29,30,31],2066:[17,31,31,31,32,31,31,29,30,30,29,29,31],2067:[17,31,31,32,31,31,31,30,29,30,29,30,30],2068:[17,31,31,32,32,31,30,30,29,30,29,30,30],2069:[17,31,32,31,32,31,30,30,30,29,29,30,31],2070:[17,31,31,31,32,31,31,29,30,30,29,30,30],2071:[17,31,31,32,31,31,31,30,29,30,29,30,30],2072:[17,31,32,31,32,31,30,30,29,30,29,30,30],2073:[17,31,32,31,32,31,30,30,30,29,29,30,31],2074:[17,31,31,31,32,31,31,30,29,30,29,30,30],2075:[17,31,31,32,31,31,31,30,29,30,29,30,30],2076:[16,31,32,31,32,31,30,30,30,29,29,30,30],2077:[17,31,32,31,32,31,30,30,30,29,30,29,31],2078:[17,31,31,31,32,31,31,30,29,30,29,30,30],2079:[17,31,31,32,31,31,31,30,29,30,29,30,30],2080:[16,31,32,31,32,31,30,30,30,29,29,30,30],2081:[17,31,31,32,32,31,30,30,30,29,30,30,30],2082:[17,31,32,31,32,31,30,30,30,29,30,30,30],2083:[17,31,31,32,31,31,30,30,30,29,30,30,30],2084:[17,31,31,32,31,31,30,30,30,29,30,30,30],2085:[17,31,32,31,32,31,31,30,30,29,30,30,30],2086:[17,31,32,31,32,31,30,30,30,29,30,30,30],2087:[16,31,31,32,31,31,31,30,30,29,30,30,30],2088:[16,30,31,32,32,30,31,30,30,29,30,30,30],2089:[17,31,32,31,32,31,30,30,30,29,30,30,30],2090:[17,31,32,31,32,31,30,30,30,29,30,30,30],2091:[16,31,31,32,31,31,31,30,30,29,30,30,30],2092:[16,31,31,32,32,31,30,30,30,29,30,30,30],2093:[17,31,32,31,32,31,30,30,30,29,30,30,30],2094:[17,31,31,32,31,31,30,30,30,29,30,30,30],2095:[17,31,31,32,31,31,31,30,29,30,30,30,30],2096:[17,30,31,32,32,31,30,30,29,30,29,30,30],2097:[17,31,32,31,32,31,30,30,30,29,30,30,30],2098:[17,31,31,32,31,31,31,29,30,29,30,30,31],2099:[17,31,31,32,31,31,31,30,29,29,30,30,30],2100:[17,31,32,31,32,30,31,30,29,30,29,30,30]}}),n.calendars.nepali=a},{\"../main\":640,\"object-assign\":483}],636:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}function o(t,e){return t-e*Math.floor(t/e)}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"Persian\",jdEpoch:1948320.5,daysPerMonth:[31,31,31,31,31,31,30,30,30,30,30,29],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Persian\",epochs:[\"BP\",\"AP\"],monthNames:[\"Farvardin\",\"Ordibehesht\",\"Khordad\",\"Tir\",\"Mordad\",\"Shahrivar\",\"Mehr\",\"Aban\",\"Azar\",\"Day\",\"Bahman\",\"Esfand\"],monthNamesShort:[\"Far\",\"Ord\",\"Kho\",\"Tir\",\"Mor\",\"Sha\",\"Meh\",\"Aba\",\"Aza\",\"Day\",\"Bah\",\"Esf\"],dayNames:[\"Yekshambe\",\"Doshambe\",\"Seshambe\",\"Ch\\xe6harshambe\",\"Panjshambe\",\"Jom'e\",\"Shambe\"],dayNamesShort:[\"Yek\",\"Do\",\"Se\",\"Ch\\xe6\",\"Panj\",\"Jom\",\"Sha\"],dayNamesMin:[\"Ye\",\"Do\",\"Se\",\"Ch\",\"Pa\",\"Jo\",\"Sh\"],digits:null,dateFormat:\"yyyy/mm/dd\",firstDay:6,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);return 682*((e.year()-(e.year()>0?474:473))%2820+474+38)%2816<682},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-(n.dayOfWeek()+1)%7,\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(12===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return 5!==this.dayOfWeek(t,e,r)},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);t=i.year(),e=i.month(),r=i.day();var a=t-(t>=0?474:473),s=474+o(a,2820);return r+(e<=7?31*(e-1):30*(e-1)+6)+Math.floor((682*s-110)/2816)+365*(s-1)+1029983*Math.floor(a/2820)+this.jdEpoch-1},fromJD:function(t){var e=(t=Math.floor(t)+.5)-this.toJD(475,1,1),r=Math.floor(e/1029983),n=o(e,1029983),i=2820;if(1029982!==n){var a=Math.floor(n/366),s=o(n,366);i=Math.floor((2134*a+2816*s+2815)/1028522)+a+1}var l=i+2820*r+474;l=l<=0?l-1:l;var c=t-this.toJD(l,1,1)+1,u=c<=186?Math.ceil(c/31):Math.ceil((c-6)/30),f=t-this.toJD(l,u,1)+1;return this.newDate(l,u,f)}}),n.calendars.persian=a,n.calendars.jalali=a},{\"../main\":640,\"object-assign\":483}],637:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\"),a=n.instance();function o(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}o.prototype=new n.baseCalendar,i(o.prototype,{name:\"Taiwan\",jdEpoch:2419402.5,yearsOffset:1911,daysPerMonth:[31,28,31,30,31,30,31,31,30,31,30,31],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Taiwan\",epochs:[\"BROC\",\"ROC\"],monthNames:[\"January\",\"February\",\"March\",\"April\",\"May\",\"June\",\"July\",\"August\",\"September\",\"October\",\"November\",\"December\"],monthNamesShort:[\"Jan\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\"Jul\",\"Aug\",\"Sep\",\"Oct\",\"Nov\",\"Dec\"],dayNames:[\"Sunday\",\"Monday\",\"Tuesday\",\"Wednesday\",\"Thursday\",\"Friday\",\"Saturday\"],dayNamesShort:[\"Sun\",\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\"],dayNamesMin:[\"Su\",\"Mo\",\"Tu\",\"We\",\"Th\",\"Fr\",\"Sa\"],digits:null,dateFormat:\"yyyy/mm/dd\",firstDay:1,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);t=this._t2gYear(e.year());return a.leapYear(t)},weekOfYear:function(t,e,r){var i=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);t=this._t2gYear(i.year());return a.weekOfYear(t,i.month(),i.day())},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(2===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);t=this._t2gYear(i.year());return a.toJD(t,i.month(),i.day())},fromJD:function(t){var e=a.fromJD(t),r=this._g2tYear(e.year());return this.newDate(r,e.month(),e.day())},_t2gYear:function(t){return t+this.yearsOffset+(t>=-this.yearsOffset&&t<=-1?1:0)},_g2tYear:function(t){return t-this.yearsOffset-(t>=1&&t<=this.yearsOffset?1:0)}}),n.calendars.taiwan=o},{\"../main\":640,\"object-assign\":483}],638:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\"),a=n.instance();function o(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}o.prototype=new n.baseCalendar,i(o.prototype,{name:\"Thai\",jdEpoch:1523098.5,yearsOffset:543,daysPerMonth:[31,28,31,30,31,30,31,31,30,31,30,31],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Thai\",epochs:[\"BBE\",\"BE\"],monthNames:[\"January\",\"February\",\"March\",\"April\",\"May\",\"June\",\"July\",\"August\",\"September\",\"October\",\"November\",\"December\"],monthNamesShort:[\"Jan\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\"Jul\",\"Aug\",\"Sep\",\"Oct\",\"Nov\",\"Dec\"],dayNames:[\"Sunday\",\"Monday\",\"Tuesday\",\"Wednesday\",\"Thursday\",\"Friday\",\"Saturday\"],dayNamesShort:[\"Sun\",\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\"],dayNamesMin:[\"Su\",\"Mo\",\"Tu\",\"We\",\"Th\",\"Fr\",\"Sa\"],digits:null,dateFormat:\"dd/mm/yyyy\",firstDay:0,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);t=this._t2gYear(e.year());return a.leapYear(t)},weekOfYear:function(t,e,r){var i=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);t=this._t2gYear(i.year());return a.weekOfYear(t,i.month(),i.day())},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(2===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);t=this._t2gYear(i.year());return a.toJD(t,i.month(),i.day())},fromJD:function(t){var e=a.fromJD(t),r=this._g2tYear(e.year());return this.newDate(r,e.month(),e.day())},_t2gYear:function(t){return t-this.yearsOffset-(t>=1&&t<=this.yearsOffset?1:0)},_g2tYear:function(t){return t+this.yearsOffset+(t>=-this.yearsOffset&&t<=-1?1:0)}}),n.calendars.thai=o},{\"../main\":640,\"object-assign\":483}],639:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"UmmAlQura\",hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Umm al-Qura\",epochs:[\"BH\",\"AH\"],monthNames:[\"Al-Muharram\",\"Safar\",\"Rabi' al-awwal\",\"Rabi' Al-Thani\",\"Jumada Al-Awwal\",\"Jumada Al-Thani\",\"Rajab\",\"Sha'aban\",\"Ramadan\",\"Shawwal\",\"Dhu al-Qi'dah\",\"Dhu al-Hijjah\"],monthNamesShort:[\"Muh\",\"Saf\",\"Rab1\",\"Rab2\",\"Jum1\",\"Jum2\",\"Raj\",\"Sha'\",\"Ram\",\"Shaw\",\"DhuQ\",\"DhuH\"],dayNames:[\"Yawm al-Ahad\",\"Yawm al-Ithnain\",\"Yawm al-Thal\\u0101th\\u0101\\u2019\",\"Yawm al-Arba\\u2018\\u0101\\u2019\",\"Yawm al-Kham\\u012bs\",\"Yawm al-Jum\\u2018a\",\"Yawm al-Sabt\"],dayNamesMin:[\"Ah\",\"Ith\",\"Th\",\"Ar\",\"Kh\",\"Ju\",\"Sa\"],digits:null,dateFormat:\"yyyy/mm/dd\",firstDay:6,isRTL:!0}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);return 355===this.daysInYear(e.year())},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-n.dayOfWeek(),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInYear:function(t){for(var e=0,r=1;r<=12;r++)e+=this.daysInMonth(t,r);return e},daysInMonth:function(t,e){for(var r=this._validate(t,e,this.minDay,n.local.invalidMonth).toJD()-24e5+.5,i=0,a=0;a<o.length;a++){if(o[a]>r)return o[i]-o[i-1];i++}return 30},weekDay:function(t,e,r){return 5!==this.dayOfWeek(t,e,r)},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate),a=12*(i.year()-1)+i.month()-15292;return i.day()+o[a-1]-1+24e5-.5},fromJD:function(t){for(var e=t-24e5+.5,r=0,n=0;n<o.length&&!(o[n]>e);n++)r++;var i=r+15292,a=Math.floor((i-1)/12),s=a+1,l=i-12*a,c=e-o[r-1]+1;return this.newDate(s,l,c)},isValid:function(t,e,r){var i=n.baseCalendar.prototype.isValid.apply(this,arguments);return i&&(i=(t=null!=t.year?t.year:t)>=1276&&t<=1500),i},_validate:function(t,e,r,i){var a=n.baseCalendar.prototype._validate.apply(this,arguments);if(a.year<1276||a.year>1500)throw i.replace(/\\{0\\}/,this.local.name);return a}}),n.calendars.ummalqura=a;var o=[20,50,79,109,138,168,197,227,256,286,315,345,374,404,433,463,492,522,551,581,611,641,670,700,729,759,788,818,847,877,906,936,965,995,1024,1054,1083,1113,1142,1172,1201,1231,1260,1290,1320,1350,1379,1409,1438,1468,1497,1527,1556,1586,1615,1645,1674,1704,1733,1763,1792,1822,1851,1881,1910,1940,1969,1999,2028,2058,2087,2117,2146,2176,2205,2235,2264,2294,2323,2353,2383,2413,2442,2472,2501,2531,2560,2590,2619,2649,2678,2708,2737,2767,2796,2826,2855,2885,2914,2944,2973,3003,3032,3062,3091,3121,3150,3180,3209,3239,3268,3298,3327,3357,3386,3416,3446,3476,3505,3535,3564,3594,3623,3653,3682,3712,3741,3771,3800,3830,3859,3889,3918,3948,3977,4007,4036,4066,4095,4125,4155,4185,4214,4244,4273,4303,4332,4362,4391,4421,4450,4480,4509,4539,4568,4598,4627,4657,4686,4716,4745,4775,4804,4834,4863,4893,4922,4952,4981,5011,5040,5070,5099,5129,5158,5188,5218,5248,5277,5307,5336,5366,5395,5425,5454,5484,5513,5543,5572,5602,5631,5661,5690,5720,5749,5779,5808,5838,5867,5897,5926,5956,5985,6015,6044,6074,6103,6133,6162,6192,6221,6251,6281,6311,6340,6370,6399,6429,6458,6488,6517,6547,6576,6606,6635,6665,6694,6724,6753,6783,6812,6842,6871,6901,6930,6960,6989,7019,7048,7078,7107,7137,7166,7196,7225,7255,7284,7314,7344,7374,7403,7433,7462,7492,7521,7551,7580,7610,7639,7669,7698,7728,7757,7787,7816,7846,7875,7905,7934,7964,7993,8023,8053,8083,8112,8142,8171,8201,8230,8260,8289,8319,8348,8378,8407,8437,8466,8496,8525,8555,8584,8614,8643,8673,8702,8732,8761,8791,8821,8850,8880,8909,8938,8968,8997,9027,9056,9086,9115,9145,9175,9205,9234,9264,9293,9322,9352,9381,9410,9440,9470,9499,9529,9559,9589,9618,9648,9677,9706,9736,9765,9794,9824,9853,9883,9913,9943,9972,10002,10032,10061,10090,10120,10149,10178,10208,10237,10267,10297,10326,10356,10386,10415,10445,10474,10504,10533,10562,10592,10621,10651,10680,10710,10740,10770,10799,10829,10858,10888,10917,10947,10976,11005,11035,11064,11094,11124,11153,11183,11213,11242,11272,11301,11331,11360,11389,11419,11448,11478,11507,11537,11567,11596,11626,11655,11685,11715,11744,11774,11803,11832,11862,11891,11921,11950,11980,12010,12039,12069,12099,12128,12158,12187,12216,12246,12275,12304,12334,12364,12393,12423,12453,12483,12512,12542,12571,12600,12630,12659,12688,12718,12747,12777,12807,12837,12866,12896,12926,12955,12984,13014,13043,13072,13102,13131,13161,13191,13220,13250,13280,13310,13339,13368,13398,13427,13456,13486,13515,13545,13574,13604,13634,13664,13693,13723,13752,13782,13811,13840,13870,13899,13929,13958,13988,14018,14047,14077,14107,14136,14166,14195,14224,14254,14283,14313,14342,14372,14401,14431,14461,14490,14520,14550,14579,14609,14638,14667,14697,14726,14756,14785,14815,14844,14874,14904,14933,14963,14993,15021,15051,15081,15110,15140,15169,15199,15228,15258,15287,15317,15347,15377,15406,15436,15465,15494,15524,15553,15582,15612,15641,15671,15701,15731,15760,15790,15820,15849,15878,15908,15937,15966,15996,16025,16055,16085,16114,16144,16174,16204,16233,16262,16292,16321,16350,16380,16409,16439,16468,16498,16528,16558,16587,16617,16646,16676,16705,16734,16764,16793,16823,16852,16882,16912,16941,16971,17001,17030,17060,17089,17118,17148,17177,17207,17236,17266,17295,17325,17355,17384,17414,17444,17473,17502,17532,17561,17591,17620,17650,17679,17709,17738,17768,17798,17827,17857,17886,17916,17945,17975,18004,18034,18063,18093,18122,18152,18181,18211,18241,18270,18300,18330,18359,18388,18418,18447,18476,18506,18535,18565,18595,18625,18654,18684,18714,18743,18772,18802,18831,18860,18890,18919,18949,18979,19008,19038,19068,19098,19127,19156,19186,19215,19244,19274,19303,19333,19362,19392,19422,19452,19481,19511,19540,19570,19599,19628,19658,19687,19717,19746,19776,19806,19836,19865,19895,19924,19954,19983,20012,20042,20071,20101,20130,20160,20190,20219,20249,20279,20308,20338,20367,20396,20426,20455,20485,20514,20544,20573,20603,20633,20662,20692,20721,20751,20780,20810,20839,20869,20898,20928,20957,20987,21016,21046,21076,21105,21135,21164,21194,21223,21253,21282,21312,21341,21371,21400,21430,21459,21489,21519,21548,21578,21607,21637,21666,21696,21725,21754,21784,21813,21843,21873,21902,21932,21962,21991,22021,22050,22080,22109,22138,22168,22197,22227,22256,22286,22316,22346,22375,22405,22434,22464,22493,22522,22552,22581,22611,22640,22670,22700,22730,22759,22789,22818,22848,22877,22906,22936,22965,22994,23024,23054,23083,23113,23143,23173,23202,23232,23261,23290,23320,23349,23379,23408,23438,23467,23497,23527,23556,23586,23616,23645,23674,23704,23733,23763,23792,23822,23851,23881,23910,23940,23970,23999,24029,24058,24088,24117,24147,24176,24206,24235,24265,24294,24324,24353,24383,24413,24442,24472,24501,24531,24560,24590,24619,24648,24678,24707,24737,24767,24796,24826,24856,24885,24915,24944,24974,25003,25032,25062,25091,25121,25150,25180,25210,25240,25269,25299,25328,25358,25387,25416,25446,25475,25505,25534,25564,25594,25624,25653,25683,25712,25742,25771,25800,25830,25859,25888,25918,25948,25977,26007,26037,26067,26096,26126,26155,26184,26214,26243,26272,26302,26332,26361,26391,26421,26451,26480,26510,26539,26568,26598,26627,26656,26686,26715,26745,26775,26805,26834,26864,26893,26923,26952,26982,27011,27041,27070,27099,27129,27159,27188,27218,27248,27277,27307,27336,27366,27395,27425,27454,27484,27513,27542,27572,27602,27631,27661,27691,27720,27750,27779,27809,27838,27868,27897,27926,27956,27985,28015,28045,28074,28104,28134,28163,28193,28222,28252,28281,28310,28340,28369,28399,28428,28458,28488,28517,28547,28577,28607,28636,28665,28695,28724,28754,28783,28813,28843,28872,28901,28931,28960,28990,29019,29049,29078,29108,29137,29167,29196,29226,29255,29285,29315,29345,29375,29404,29434,29463,29492,29522,29551,29580,29610,29640,29669,29699,29729,29759,29788,29818,29847,29876,29906,29935,29964,29994,30023,30053,30082,30112,30141,30171,30200,30230,30259,30289,30318,30348,30378,30408,30437,30467,30496,30526,30555,30585,30614,30644,30673,30703,30732,30762,30791,30821,30850,30880,30909,30939,30968,30998,31027,31057,31086,31116,31145,31175,31204,31234,31263,31293,31322,31352,31381,31411,31441,31471,31500,31530,31559,31589,31618,31648,31676,31706,31736,31766,31795,31825,31854,31884,31913,31943,31972,32002,32031,32061,32090,32120,32150,32180,32209,32239,32268,32298,32327,32357,32386,32416,32445,32475,32504,32534,32563,32593,32622,32652,32681,32711,32740,32770,32799,32829,32858,32888,32917,32947,32976,33006,33035,33065,33094,33124,33153,33183,33213,33243,33272,33302,33331,33361,33390,33420,33450,33479,33509,33539,33568,33598,33627,33657,33686,33716,33745,33775,33804,33834,33863,33893,33922,33952,33981,34011,34040,34069,34099,34128,34158,34187,34217,34247,34277,34306,34336,34365,34395,34424,34454,34483,34512,34542,34571,34601,34631,34660,34690,34719,34749,34778,34808,34837,34867,34896,34926,34955,34985,35015,35044,35074,35103,35133,35162,35192,35222,35251,35280,35310,35340,35370,35399,35429,35458,35488,35517,35547,35576,35605,35635,35665,35694,35723,35753,35782,35811,35841,35871,35901,35930,35960,35989,36019,36048,36078,36107,36136,36166,36195,36225,36254,36284,36314,36343,36373,36403,36433,36462,36492,36521,36551,36580,36610,36639,36669,36698,36728,36757,36786,36816,36845,36875,36904,36934,36963,36993,37022,37052,37081,37111,37141,37170,37200,37229,37259,37288,37318,37347,37377,37406,37436,37465,37495,37524,37554,37584,37613,37643,37672,37701,37731,37760,37790,37819,37849,37878,37908,37938,37967,37997,38027,38056,38085,38115,38144,38174,38203,38233,38262,38292,38322,38351,38381,38410,38440,38469,38499,38528,38558,38587,38617,38646,38676,38705,38735,38764,38794,38823,38853,38882,38912,38941,38971,39001,39030,39059,39089,39118,39148,39178,39208,39237,39267,39297,39326,39355,39385,39414,39444,39473,39503,39532,39562,39592,39621,39650,39680,39709,39739,39768,39798,39827,39857,39886,39916,39946,39975,40005,40035,40064,40094,40123,40153,40182,40212,40241,40271,40300,40330,40359,40389,40418,40448,40477,40507,40536,40566,40595,40625,40655,40685,40714,40744,40773,40803,40832,40862,40892,40921,40951,40980,41009,41039,41068,41098,41127,41157,41186,41216,41245,41275,41304,41334,41364,41393,41422,41452,41481,41511,41540,41570,41599,41629,41658,41688,41718,41748,41777,41807,41836,41865,41894,41924,41953,41983,42012,42042,42072,42102,42131,42161,42190,42220,42249,42279,42308,42337,42367,42397,42426,42456,42485,42515,42545,42574,42604,42633,42662,42692,42721,42751,42780,42810,42839,42869,42899,42929,42958,42988,43017,43046,43076,43105,43135,43164,43194,43223,43253,43283,43312,43342,43371,43401,43430,43460,43489,43519,43548,43578,43607,43637,43666,43696,43726,43755,43785,43814,43844,43873,43903,43932,43962,43991,44021,44050,44080,44109,44139,44169,44198,44228,44258,44287,44317,44346,44375,44405,44434,44464,44493,44523,44553,44582,44612,44641,44671,44700,44730,44759,44788,44818,44847,44877,44906,44936,44966,44996,45025,45055,45084,45114,45143,45172,45202,45231,45261,45290,45320,45350,45380,45409,45439,45468,45498,45527,45556,45586,45615,45644,45674,45704,45733,45763,45793,45823,45852,45882,45911,45940,45970,45999,46028,46058,46088,46117,46147,46177,46206,46236,46265,46295,46324,46354,46383,46413,46442,46472,46501,46531,46560,46590,46620,46649,46679,46708,46738,46767,46797,46826,46856,46885,46915,46944,46974,47003,47033,47063,47092,47122,47151,47181,47210,47240,47269,47298,47328,47357,47387,47417,47446,47476,47506,47535,47565,47594,47624,47653,47682,47712,47741,47771,47800,47830,47860,47890,47919,47949,47978,48008,48037,48066,48096,48125,48155,48184,48214,48244,48273,48303,48333,48362,48392,48421,48450,48480,48509,48538,48568,48598,48627,48657,48687,48717,48746,48776,48805,48834,48864,48893,48922,48952,48982,49011,49041,49071,49100,49130,49160,49189,49218,49248,49277,49306,49336,49365,49395,49425,49455,49484,49514,49543,49573,49602,49632,49661,49690,49720,49749,49779,49809,49838,49868,49898,49927,49957,49986,50016,50045,50075,50104,50133,50163,50192,50222,50252,50281,50311,50340,50370,50400,50429,50459,50488,50518,50547,50576,50606,50635,50665,50694,50724,50754,50784,50813,50843,50872,50902,50931,50960,50990,51019,51049,51078,51108,51138,51167,51197,51227,51256,51286,51315,51345,51374,51403,51433,51462,51492,51522,51552,51582,51611,51641,51670,51699,51729,51758,51787,51816,51846,51876,51906,51936,51965,51995,52025,52054,52083,52113,52142,52171,52200,52230,52260,52290,52319,52349,52379,52408,52438,52467,52497,52526,52555,52585,52614,52644,52673,52703,52733,52762,52792,52822,52851,52881,52910,52939,52969,52998,53028,53057,53087,53116,53146,53176,53205,53235,53264,53294,53324,53353,53383,53412,53441,53471,53500,53530,53559,53589,53619,53648,53678,53708,53737,53767,53796,53825,53855,53884,53913,53943,53973,54003,54032,54062,54092,54121,54151,54180,54209,54239,54268,54297,54327,54357,54387,54416,54446,54476,54505,54535,54564,54593,54623,54652,54681,54711,54741,54770,54800,54830,54859,54889,54919,54948,54977,55007,55036,55066,55095,55125,55154,55184,55213,55243,55273,55302,55332,55361,55391,55420,55450,55479,55508,55538,55567,55597,55627,55657,55686,55716,55745,55775,55804,55834,55863,55892,55922,55951,55981,56011,56040,56070,56100,56129,56159,56188,56218,56247,56276,56306,56335,56365,56394,56424,56454,56483,56513,56543,56572,56601,56631,56660,56690,56719,56749,56778,56808,56837,56867,56897,56926,56956,56985,57015,57044,57074,57103,57133,57162,57192,57221,57251,57280,57310,57340,57369,57399,57429,57458,57487,57517,57546,57576,57605,57634,57664,57694,57723,57753,57783,57813,57842,57871,57901,57930,57959,57989,58018,58048,58077,58107,58137,58167,58196,58226,58255,58285,58314,58343,58373,58402,58432,58461,58491,58521,58551,58580,58610,58639,58669,58698,58727,58757,58786,58816,58845,58875,58905,58934,58964,58994,59023,59053,59082,59111,59141,59170,59200,59229,59259,59288,59318,59348,59377,59407,59436,59466,59495,59525,59554,59584,59613,59643,59672,59702,59731,59761,59791,59820,59850,59879,59909,59939,59968,59997,60027,60056,60086,60115,60145,60174,60204,60234,60264,60293,60323,60352,60381,60411,60440,60469,60499,60528,60558,60588,60618,60648,60677,60707,60736,60765,60795,60824,60853,60883,60912,60942,60972,61002,61031,61061,61090,61120,61149,61179,61208,61237,61267,61296,61326,61356,61385,61415,61445,61474,61504,61533,61563,61592,61621,61651,61680,61710,61739,61769,61799,61828,61858,61888,61917,61947,61976,62006,62035,62064,62094,62123,62153,62182,62212,62242,62271,62301,62331,62360,62390,62419,62448,62478,62507,62537,62566,62596,62625,62655,62685,62715,62744,62774,62803,62832,62862,62891,62921,62950,62980,63009,63039,63069,63099,63128,63157,63187,63216,63246,63275,63305,63334,63363,63393,63423,63453,63482,63512,63541,63571,63600,63630,63659,63689,63718,63747,63777,63807,63836,63866,63895,63925,63955,63984,64014,64043,64073,64102,64131,64161,64190,64220,64249,64279,64309,64339,64368,64398,64427,64457,64486,64515,64545,64574,64603,64633,64663,64692,64722,64752,64782,64811,64841,64870,64899,64929,64958,64987,65017,65047,65076,65106,65136,65166,65195,65225,65254,65283,65313,65342,65371,65401,65431,65460,65490,65520,65549,65579,65608,65638,65667,65697,65726,65755,65785,65815,65844,65874,65903,65933,65963,65992,66022,66051,66081,66110,66140,66169,66199,66228,66258,66287,66317,66346,66376,66405,66435,66465,66494,66524,66553,66583,66612,66641,66671,66700,66730,66760,66789,66819,66849,66878,66908,66937,66967,66996,67025,67055,67084,67114,67143,67173,67203,67233,67262,67292,67321,67351,67380,67409,67439,67468,67497,67527,67557,67587,67617,67646,67676,67705,67735,67764,67793,67823,67852,67882,67911,67941,67971,68e3,68030,68060,68089,68119,68148,68177,68207,68236,68266,68295,68325,68354,68384,68414,68443,68473,68502,68532,68561,68591,68620,68650,68679,68708,68738,68768,68797,68827,68857,68886,68916,68946,68975,69004,69034,69063,69092,69122,69152,69181,69211,69240,69270,69300,69330,69359,69388,69418,69447,69476,69506,69535,69565,69595,69624,69654,69684,69713,69743,69772,69802,69831,69861,69890,69919,69949,69978,70008,70038,70067,70097,70126,70156,70186,70215,70245,70274,70303,70333,70362,70392,70421,70451,70481,70510,70540,70570,70599,70629,70658,70687,70717,70746,70776,70805,70835,70864,70894,70924,70954,70983,71013,71042,71071,71101,71130,71159,71189,71218,71248,71278,71308,71337,71367,71397,71426,71455,71485,71514,71543,71573,71602,71632,71662,71691,71721,71751,71781,71810,71839,71869,71898,71927,71957,71986,72016,72046,72075,72105,72135,72164,72194,72223,72253,72282,72311,72341,72370,72400,72429,72459,72489,72518,72548,72577,72607,72637,72666,72695,72725,72754,72784,72813,72843,72872,72902,72931,72961,72991,73020,73050,73080,73109,73139,73168,73197,73227,73256,73286,73315,73345,73375,73404,73434,73464,73493,73523,73552,73581,73611,73640,73669,73699,73729,73758,73788,73818,73848,73877,73907,73936,73965,73995,74024,74053,74083,74113,74142,74172,74202,74231,74261,74291,74320,74349,74379,74408,74437,74467,74497,74526,74556,74586,74615,74645,74675,74704,74733,74763,74792,74822,74851,74881,74910,74940,74969,74999,75029,75058,75088,75117,75147,75176,75206,75235,75264,75294,75323,75353,75383,75412,75442,75472,75501,75531,75560,75590,75619,75648,75678,75707,75737,75766,75796,75826,75856,75885,75915,75944,75974,76003,76032,76062,76091,76121,76150,76180,76210,76239,76269,76299,76328,76358,76387,76416,76446,76475,76505,76534,76564,76593,76623,76653,76682,76712,76741,76771,76801,76830,76859,76889,76918,76948,76977,77007,77036,77066,77096,77125,77155,77185,77214,77243,77273,77302,77332,77361,77390,77420,77450,77479,77509,77539,77569,77598,77627,77657,77686,77715,77745,77774,77804,77833,77863,77893,77923,77952,77982,78011,78041,78070,78099,78129,78158,78188,78217,78247,78277,78307,78336,78366,78395,78425,78454,78483,78513,78542,78572,78601,78631,78661,78690,78720,78750,78779,78808,78838,78867,78897,78926,78956,78985,79015,79044,79074,79104,79133,79163,79192,79222,79251,79281,79310,79340,79369,79399,79428,79458,79487,79517,79546,79576,79606,79635,79665,79695,79724,79753,79783,79812,79841,79871,79900,79930,79960,79990]},{\"../main\":640,\"object-assign\":483}],640:[function(t,e,r){var n=t(\"object-assign\");function i(){this.regionalOptions=[],this.regionalOptions[\"\"]={invalidCalendar:\"Calendar {0} not found\",invalidDate:\"Invalid {0} date\",invalidMonth:\"Invalid {0} month\",invalidYear:\"Invalid {0} year\",differentCalendars:\"Cannot mix {0} and {1} dates\"},this.local=this.regionalOptions[\"\"],this.calendars={},this._localCals={}}function a(t,e,r,n){if(this._calendar=t,this._year=e,this._month=r,this._day=n,0===this._calendar._validateLevel&&!this._calendar.isValid(this._year,this._month,this._day))throw(c.local.invalidDate||c.regionalOptions[\"\"].invalidDate).replace(/\\{0\\}/,this._calendar.local.name)}function o(t,e){return\"000000\".substring(0,e-(t=\"\"+t).length)+t}function s(){this.shortYearCutoff=\"+10\"}function l(t){this.local=this.regionalOptions[t]||this.regionalOptions[\"\"]}n(i.prototype,{instance:function(t,e){t=(t||\"gregorian\").toLowerCase(),e=e||\"\";var r=this._localCals[t+\"-\"+e];if(!r&&this.calendars[t]&&(r=new this.calendars[t](e),this._localCals[t+\"-\"+e]=r),!r)throw(this.local.invalidCalendar||this.regionalOptions[\"\"].invalidCalendar).replace(/\\{0\\}/,t);return r},newDate:function(t,e,r,n,i){return(n=(null!=t&&t.year?t.calendar():\"string\"==typeof n?this.instance(n,i):n)||this.instance()).newDate(t,e,r)},substituteDigits:function(t){return function(e){return(e+\"\").replace(/[0-9]/g,(function(e){return t[e]}))}},substituteChineseDigits:function(t,e){return function(r){for(var n=\"\",i=0;r>0;){var a=r%10;n=(0===a?\"\":t[a]+e[i])+n,i++,r=Math.floor(r/10)}return 0===n.indexOf(t[1]+e[1])&&(n=n.substr(1)),n||t[0]}}}),n(a.prototype,{newDate:function(t,e,r){return this._calendar.newDate(null==t?this:t,e,r)},year:function(t){return 0===arguments.length?this._year:this.set(t,\"y\")},month:function(t){return 0===arguments.length?this._month:this.set(t,\"m\")},day:function(t){return 0===arguments.length?this._day:this.set(t,\"d\")},date:function(t,e,r){if(!this._calendar.isValid(t,e,r))throw(c.local.invalidDate||c.regionalOptions[\"\"].invalidDate).replace(/\\{0\\}/,this._calendar.local.name);return this._year=t,this._month=e,this._day=r,this},leapYear:function(){return this._calendar.leapYear(this)},epoch:function(){return this._calendar.epoch(this)},formatYear:function(){return this._calendar.formatYear(this)},monthOfYear:function(){return this._calendar.monthOfYear(this)},weekOfYear:function(){return this._calendar.weekOfYear(this)},daysInYear:function(){return this._calendar.daysInYear(this)},dayOfYear:function(){return this._calendar.dayOfYear(this)},daysInMonth:function(){return this._calendar.daysInMonth(this)},dayOfWeek:function(){return this._calendar.dayOfWeek(this)},weekDay:function(){return this._calendar.weekDay(this)},extraInfo:function(){return this._calendar.extraInfo(this)},add:function(t,e){return this._calendar.add(this,t,e)},set:function(t,e){return this._calendar.set(this,t,e)},compareTo:function(t){if(this._calendar.name!==t._calendar.name)throw(c.local.differentCalendars||c.regionalOptions[\"\"].differentCalendars).replace(/\\{0\\}/,this._calendar.local.name).replace(/\\{1\\}/,t._calendar.local.name);var e=this._year!==t._year?this._year-t._year:this._month!==t._month?this.monthOfYear()-t.monthOfYear():this._day-t._day;return 0===e?0:e<0?-1:1},calendar:function(){return this._calendar},toJD:function(){return this._calendar.toJD(this)},fromJD:function(t){return this._calendar.fromJD(t)},toJSDate:function(){return this._calendar.toJSDate(this)},fromJSDate:function(t){return this._calendar.fromJSDate(t)},toString:function(){return(this.year()<0?\"-\":\"\")+o(Math.abs(this.year()),4)+\"-\"+o(this.month(),2)+\"-\"+o(this.day(),2)}}),n(s.prototype,{_validateLevel:0,newDate:function(t,e,r){return null==t?this.today():(t.year&&(this._validate(t,e,r,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate),r=t.day(),e=t.month(),t=t.year()),new a(this,t,e,r))},today:function(){return this.fromJSDate(new Date)},epoch:function(t){return this._validate(t,this.minMonth,this.minDay,c.local.invalidYear||c.regionalOptions[\"\"].invalidYear).year()<0?this.local.epochs[0]:this.local.epochs[1]},formatYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,c.local.invalidYear||c.regionalOptions[\"\"].invalidYear);return(e.year()<0?\"-\":\"\")+o(Math.abs(e.year()),4)},monthsInYear:function(t){return this._validate(t,this.minMonth,this.minDay,c.local.invalidYear||c.regionalOptions[\"\"].invalidYear),12},monthOfYear:function(t,e){var r=this._validate(t,e,this.minDay,c.local.invalidMonth||c.regionalOptions[\"\"].invalidMonth);return(r.month()+this.monthsInYear(r)-this.firstMonth)%this.monthsInYear(r)+this.minMonth},fromMonthOfYear:function(t,e){var r=(e+this.firstMonth-2*this.minMonth)%this.monthsInYear(t)+this.minMonth;return this._validate(t,r,this.minDay,c.local.invalidMonth||c.regionalOptions[\"\"].invalidMonth),r},daysInYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,c.local.invalidYear||c.regionalOptions[\"\"].invalidYear);return this.leapYear(e)?366:365},dayOfYear:function(t,e,r){var n=this._validate(t,e,r,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate);return n.toJD()-this.newDate(n.year(),this.fromMonthOfYear(n.year(),this.minMonth),this.minDay).toJD()+1},daysInWeek:function(){return 7},dayOfWeek:function(t,e,r){var n=this._validate(t,e,r,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate);return(Math.floor(this.toJD(n))+2)%this.daysInWeek()},extraInfo:function(t,e,r){return this._validate(t,e,r,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate),{}},add:function(t,e,r){return this._validate(t,this.minMonth,this.minDay,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate),this._correctAdd(t,this._add(t,e,r),e,r)},_add:function(t,e,r){if(this._validateLevel++,\"d\"===r||\"w\"===r){var n=t.toJD()+e*(\"w\"===r?this.daysInWeek():1),i=t.calendar().fromJD(n);return this._validateLevel--,[i.year(),i.month(),i.day()]}try{var a=t.year()+(\"y\"===r?e:0),o=t.monthOfYear()+(\"m\"===r?e:0);i=t.day();\"y\"===r?(t.month()!==this.fromMonthOfYear(a,o)&&(o=this.newDate(a,t.month(),this.minDay).monthOfYear()),o=Math.min(o,this.monthsInYear(a)),i=Math.min(i,this.daysInMonth(a,this.fromMonthOfYear(a,o)))):\"m\"===r&&(!function(t){for(;o<t.minMonth;)a--,o+=t.monthsInYear(a);for(var e=t.monthsInYear(a);o>e-1+t.minMonth;)a++,o-=e,e=t.monthsInYear(a)}(this),i=Math.min(i,this.daysInMonth(a,this.fromMonthOfYear(a,o))));var s=[a,this.fromMonthOfYear(a,o),i];return this._validateLevel--,s}catch(t){throw this._validateLevel--,t}},_correctAdd:function(t,e,r,n){if(!(this.hasYearZero||\"y\"!==n&&\"m\"!==n||0!==e[0]&&t.year()>0==e[0]>0)){var i={y:[1,1,\"y\"],m:[1,this.monthsInYear(-1),\"m\"],w:[this.daysInWeek(),this.daysInYear(-1),\"d\"],d:[1,this.daysInYear(-1),\"d\"]}[n],a=r<0?-1:1;e=this._add(t,r*i[0]+a*i[1],i[2])}return t.date(e[0],e[1],e[2])},set:function(t,e,r){this._validate(t,this.minMonth,this.minDay,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate);var n=\"y\"===r?e:t.year(),i=\"m\"===r?e:t.month(),a=\"d\"===r?e:t.day();return\"y\"!==r&&\"m\"!==r||(a=Math.min(a,this.daysInMonth(n,i))),t.date(n,i,a)},isValid:function(t,e,r){this._validateLevel++;var n=this.hasYearZero||0!==t;if(n){var i=this.newDate(t,e,this.minDay);n=e>=this.minMonth&&e-this.minMonth<this.monthsInYear(i)&&r>=this.minDay&&r-this.minDay<this.daysInMonth(i)}return this._validateLevel--,n},toJSDate:function(t,e,r){var n=this._validate(t,e,r,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate);return c.instance().fromJD(this.toJD(n)).toJSDate()},fromJSDate:function(t){return this.fromJD(c.instance().fromJSDate(t).toJD())},_validate:function(t,e,r,n){if(t.year){if(0===this._validateLevel&&this.name!==t.calendar().name)throw(c.local.differentCalendars||c.regionalOptions[\"\"].differentCalendars).replace(/\\{0\\}/,this.local.name).replace(/\\{1\\}/,t.calendar().local.name);return t}try{if(this._validateLevel++,1===this._validateLevel&&!this.isValid(t,e,r))throw n.replace(/\\{0\\}/,this.local.name);var i=this.newDate(t,e,r);return this._validateLevel--,i}catch(t){throw this._validateLevel--,t}}}),l.prototype=new s,n(l.prototype,{name:\"Gregorian\",jdEpoch:1721425.5,daysPerMonth:[31,28,31,30,31,30,31,31,30,31,30,31],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Gregorian\",epochs:[\"BCE\",\"CE\"],monthNames:[\"January\",\"February\",\"March\",\"April\",\"May\",\"June\",\"July\",\"August\",\"September\",\"October\",\"November\",\"December\"],monthNamesShort:[\"Jan\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\"Jul\",\"Aug\",\"Sep\",\"Oct\",\"Nov\",\"Dec\"],dayNames:[\"Sunday\",\"Monday\",\"Tuesday\",\"Wednesday\",\"Thursday\",\"Friday\",\"Saturday\"],dayNamesShort:[\"Sun\",\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\"],dayNamesMin:[\"Su\",\"Mo\",\"Tu\",\"We\",\"Th\",\"Fr\",\"Sa\"],digits:null,dateFormat:\"mm/dd/yyyy\",firstDay:0,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,c.local.invalidYear||c.regionalOptions[\"\"].invalidYear);return(t=e.year()+(e.year()<0?1:0))%4==0&&(t%100!=0||t%400==0)},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(4-(n.dayOfWeek()||7),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,c.local.invalidMonth||c.regionalOptions[\"\"].invalidMonth);return this.daysPerMonth[r.month()-1]+(2===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var n=this._validate(t,e,r,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate);t=n.year(),e=n.month(),r=n.day(),t<0&&t++,e<3&&(e+=12,t--);var i=Math.floor(t/100),a=2-i+Math.floor(i/4);return Math.floor(365.25*(t+4716))+Math.floor(30.6001*(e+1))+r+a-1524.5},fromJD:function(t){var e=Math.floor(t+.5),r=Math.floor((e-1867216.25)/36524.25),n=(r=e+1+r-Math.floor(r/4))+1524,i=Math.floor((n-122.1)/365.25),a=Math.floor(365.25*i),o=Math.floor((n-a)/30.6001),s=n-a-Math.floor(30.6001*o),l=o-(o>13.5?13:1),c=i-(l>2.5?4716:4715);return c<=0&&c--,this.newDate(c,l,s)},toJSDate:function(t,e,r){var n=this._validate(t,e,r,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate),i=new Date(n.year(),n.month()-1,n.day());return i.setHours(0),i.setMinutes(0),i.setSeconds(0),i.setMilliseconds(0),i.setHours(i.getHours()>12?i.getHours()+2:0),i},fromJSDate:function(t){return this.newDate(t.getFullYear(),t.getMonth()+1,t.getDate())}});var c=e.exports=new i;c.cdate=a,c.baseCalendar=s,c.calendars.gregorian=l},{\"object-assign\":483}],641:[function(t,e,r){var n=t(\"object-assign\"),i=t(\"./main\");n(i.regionalOptions[\"\"],{invalidArguments:\"Invalid arguments\",invalidFormat:\"Cannot format a date from another calendar\",missingNumberAt:\"Missing number at position {0}\",unknownNameAt:\"Unknown name at position {0}\",unexpectedLiteralAt:\"Unexpected literal at position {0}\",unexpectedText:\"Additional text found at end\"}),i.local=i.regionalOptions[\"\"],n(i.cdate.prototype,{formatDate:function(t,e){return\"string\"!=typeof t&&(e=t,t=\"\"),this._calendar.formatDate(t||\"\",this,e)}}),n(i.baseCalendar.prototype,{UNIX_EPOCH:i.instance().newDate(1970,1,1).toJD(),SECS_PER_DAY:86400,TICKS_EPOCH:i.instance().jdEpoch,TICKS_PER_DAY:864e9,ATOM:\"yyyy-mm-dd\",COOKIE:\"D, dd M yyyy\",FULL:\"DD, MM d, yyyy\",ISO_8601:\"yyyy-mm-dd\",JULIAN:\"J\",RFC_822:\"D, d M yy\",RFC_850:\"DD, dd-M-yy\",RFC_1036:\"D, d M yy\",RFC_1123:\"D, d M yyyy\",RFC_2822:\"D, d M yyyy\",RSS:\"D, d M yy\",TICKS:\"!\",TIMESTAMP:\"@\",W3C:\"yyyy-mm-dd\",formatDate:function(t,e,r){if(\"string\"!=typeof t&&(r=e,e=t,t=\"\"),!e)return\"\";if(e.calendar()!==this)throw i.local.invalidFormat||i.regionalOptions[\"\"].invalidFormat;t=t||this.local.dateFormat;for(var n,a,o,s,l=(r=r||{}).dayNamesShort||this.local.dayNamesShort,c=r.dayNames||this.local.dayNames,u=r.monthNumbers||this.local.monthNumbers,f=r.monthNamesShort||this.local.monthNamesShort,h=r.monthNames||this.local.monthNames,p=(r.calculateWeek||this.local.calculateWeek,function(e,r){for(var n=1;w+n<t.length&&t.charAt(w+n)===e;)n++;return w+=n-1,Math.floor(n/(r||1))>1}),d=function(t,e,r,n){var i=\"\"+e;if(p(t,n))for(;i.length<r;)i=\"0\"+i;return i},m=this,g=function(t){return\"function\"==typeof u?u.call(m,t,p(\"m\")):x(d(\"m\",t.month(),2))},v=function(t,e){return e?\"function\"==typeof h?h.call(m,t):h[t.month()-m.minMonth]:\"function\"==typeof f?f.call(m,t):f[t.month()-m.minMonth]},y=this.local.digits,x=function(t){return r.localNumbers&&y?y(t):t},b=\"\",_=!1,w=0;w<t.length;w++)if(_)\"'\"!==t.charAt(w)||p(\"'\")?b+=t.charAt(w):_=!1;else switch(t.charAt(w)){case\"d\":b+=x(d(\"d\",e.day(),2));break;case\"D\":b+=(n=\"D\",a=e.dayOfWeek(),o=l,s=c,p(n)?s[a]:o[a]);break;case\"o\":b+=d(\"o\",e.dayOfYear(),3);break;case\"w\":b+=d(\"w\",e.weekOfYear(),2);break;case\"m\":b+=g(e);break;case\"M\":b+=v(e,p(\"M\"));break;case\"y\":b+=p(\"y\",2)?e.year():(e.year()%100<10?\"0\":\"\")+e.year()%100;break;case\"Y\":p(\"Y\",2),b+=e.formatYear();break;case\"J\":b+=e.toJD();break;case\"@\":b+=(e.toJD()-this.UNIX_EPOCH)*this.SECS_PER_DAY;break;case\"!\":b+=(e.toJD()-this.TICKS_EPOCH)*this.TICKS_PER_DAY;break;case\"'\":p(\"'\")?b+=\"'\":_=!0;break;default:b+=t.charAt(w)}return b},parseDate:function(t,e,r){if(null==e)throw i.local.invalidArguments||i.regionalOptions[\"\"].invalidArguments;if(\"\"===(e=\"object\"==typeof e?e.toString():e+\"\"))return null;t=t||this.local.dateFormat;var n=(r=r||{}).shortYearCutoff||this.shortYearCutoff;n=\"string\"!=typeof n?n:this.today().year()%100+parseInt(n,10);for(var a=r.dayNamesShort||this.local.dayNamesShort,o=r.dayNames||this.local.dayNames,s=r.parseMonth||this.local.parseMonth,l=r.monthNumbers||this.local.monthNumbers,c=r.monthNamesShort||this.local.monthNamesShort,u=r.monthNames||this.local.monthNames,f=-1,h=-1,p=-1,d=-1,m=-1,g=!1,v=!1,y=function(e,r){for(var n=1;A+n<t.length&&t.charAt(A+n)===e;)n++;return A+=n-1,Math.floor(n/(r||1))>1},x=function(t,r){var n=y(t,r),a=[2,3,n?4:2,n?4:2,10,11,20][\"oyYJ@!\".indexOf(t)+1],o=new RegExp(\"^-?\\\\d{1,\"+a+\"}\"),s=e.substring(M).match(o);if(!s)throw(i.local.missingNumberAt||i.regionalOptions[\"\"].missingNumberAt).replace(/\\{0\\}/,M);return M+=s[0].length,parseInt(s[0],10)},b=this,_=function(){if(\"function\"==typeof l){y(\"m\");var t=l.call(b,e.substring(M));return M+=t.length,t}return x(\"m\")},w=function(t,r,n,a){for(var o=y(t,a)?n:r,s=0;s<o.length;s++)if(e.substr(M,o[s].length).toLowerCase()===o[s].toLowerCase())return M+=o[s].length,s+b.minMonth;throw(i.local.unknownNameAt||i.regionalOptions[\"\"].unknownNameAt).replace(/\\{0\\}/,M)},T=function(){if(\"function\"==typeof u){var t=y(\"M\")?u.call(b,e.substring(M)):c.call(b,e.substring(M));return M+=t.length,t}return w(\"M\",c,u)},k=function(){if(e.charAt(M)!==t.charAt(A))throw(i.local.unexpectedLiteralAt||i.regionalOptions[\"\"].unexpectedLiteralAt).replace(/\\{0\\}/,M);M++},M=0,A=0;A<t.length;A++)if(v)\"'\"!==t.charAt(A)||y(\"'\")?k():v=!1;else switch(t.charAt(A)){case\"d\":d=x(\"d\");break;case\"D\":w(\"D\",a,o);break;case\"o\":m=x(\"o\");break;case\"w\":x(\"w\");break;case\"m\":p=_();break;case\"M\":p=T();break;case\"y\":var S=A;g=!y(\"y\",2),A=S,h=x(\"y\",2);break;case\"Y\":h=x(\"Y\",2);break;case\"J\":f=x(\"J\")+.5,\".\"===e.charAt(M)&&(M++,x(\"J\"));break;case\"@\":f=x(\"@\")/this.SECS_PER_DAY+this.UNIX_EPOCH;break;case\"!\":f=x(\"!\")/this.TICKS_PER_DAY+this.TICKS_EPOCH;break;case\"*\":M=e.length;break;case\"'\":y(\"'\")?k():v=!0;break;default:k()}if(M<e.length)throw i.local.unexpectedText||i.regionalOptions[\"\"].unexpectedText;if(-1===h?h=this.today().year():h<100&&g&&(h+=-1===n?1900:this.today().year()-this.today().year()%100-(h<=n?0:100)),\"string\"==typeof p&&(p=s.call(this,h,p)),m>-1){p=1,d=m;for(var E=this.daysInMonth(h,p);d>E;E=this.daysInMonth(h,p))p++,d-=E}return f>-1?this.fromJD(f):this.newDate(h,p,d)},determineDate:function(t,e,r,n,i){r&&\"object\"!=typeof r&&(i=n,n=r,r=null),\"string\"!=typeof n&&(i=n,n=\"\");var a=this;return e=e?e.newDate():null,t=null==t?e:\"string\"==typeof t?function(t){try{return a.parseDate(n,t,i)}catch(t){}for(var e=((t=t.toLowerCase()).match(/^c/)&&r?r.newDate():null)||a.today(),o=/([+-]?[0-9]+)\\s*(d|w|m|y)?/g,s=o.exec(t);s;)e.add(parseInt(s[1],10),s[2]||\"d\"),s=o.exec(t);return e}(t):\"number\"==typeof t?isNaN(t)||t===1/0||t===-1/0?e:a.today().add(t,\"d\"):a.newDate(t)}})},{\"./main\":640,\"object-assign\":483}],642:[function(t,e,r){e.exports=t(\"cwise-compiler\")({args:[\"array\",{offset:[1],array:0},\"scalar\",\"scalar\",\"index\"],pre:{body:\"{}\",args:[],thisVars:[],localVars:[]},post:{body:\"{}\",args:[],thisVars:[],localVars:[]},body:{body:\"{\\n        var _inline_1_da = _inline_1_arg0_ - _inline_1_arg3_\\n        var _inline_1_db = _inline_1_arg1_ - _inline_1_arg3_\\n        if((_inline_1_da >= 0) !== (_inline_1_db >= 0)) {\\n          _inline_1_arg2_.push(_inline_1_arg4_[0] + 0.5 + 0.5 * (_inline_1_da + _inline_1_db) / (_inline_1_da - _inline_1_db))\\n        }\\n      }\",args:[{name:\"_inline_1_arg0_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_1_arg1_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_1_arg2_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_1_arg3_\",lvalue:!1,rvalue:!0,count:2},{name:\"_inline_1_arg4_\",lvalue:!1,rvalue:!0,count:1}],thisVars:[],localVars:[\"_inline_1_da\",\"_inline_1_db\"]},funcName:\"zeroCrossings\"})},{\"cwise-compiler\":157}],643:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=[];return e=+e||0,n(t.hi(t.shape[0]-1),r,e),r};var n=t(\"./lib/zc-core\")},{\"./lib/zc-core\":642}],644:[function(t,e,r){\"use strict\";e.exports=[{path:\"\",backoff:0},{path:\"M-2.4,-3V3L0.6,0Z\",backoff:.6},{path:\"M-3.7,-2.5V2.5L1.3,0Z\",backoff:1.3},{path:\"M-4.45,-3L-1.65,-0.2V0.2L-4.45,3L1.55,0Z\",backoff:1.55},{path:\"M-2.2,-2.2L-0.2,-0.2V0.2L-2.2,2.2L-1.4,3L1.6,0L-1.4,-3Z\",backoff:1.6},{path:\"M-4.4,-2.1L-0.6,-0.2V0.2L-4.4,2.1L-4,3L2,0L-4,-3Z\",backoff:2},{path:\"M2,0A2,2 0 1,1 0,-2A2,2 0 0,1 2,0Z\",backoff:0,noRotate:!0},{path:\"M2,2V-2H-2V2Z\",backoff:0,noRotate:!0}]},{}],645:[function(t,e,r){\"use strict\";var n=t(\"./arrow_paths\"),i=t(\"../../plots/font_attributes\"),a=t(\"../../plots/cartesian/constants\"),o=t(\"../../plot_api/plot_template\").templatedArray;t(\"../../constants/axis_placeable_objects\");e.exports=o(\"annotation\",{visible:{valType:\"boolean\",dflt:!0,editType:\"calc+arraydraw\"},text:{valType:\"string\",editType:\"calc+arraydraw\"},textangle:{valType:\"angle\",dflt:0,editType:\"calc+arraydraw\"},font:i({editType:\"calc+arraydraw\",colorEditType:\"arraydraw\"}),width:{valType:\"number\",min:1,dflt:null,editType:\"calc+arraydraw\"},height:{valType:\"number\",min:1,dflt:null,editType:\"calc+arraydraw\"},opacity:{valType:\"number\",min:0,max:1,dflt:1,editType:\"arraydraw\"},align:{valType:\"enumerated\",values:[\"left\",\"center\",\"right\"],dflt:\"center\",editType:\"arraydraw\"},valign:{valType:\"enumerated\",values:[\"top\",\"middle\",\"bottom\"],dflt:\"middle\",editType:\"arraydraw\"},bgcolor:{valType:\"color\",dflt:\"rgba(0,0,0,0)\",editType:\"arraydraw\"},bordercolor:{valType:\"color\",dflt:\"rgba(0,0,0,0)\",editType:\"arraydraw\"},borderpad:{valType:\"number\",min:0,dflt:1,editType:\"calc+arraydraw\"},borderwidth:{valType:\"number\",min:0,dflt:1,editType:\"calc+arraydraw\"},showarrow:{valType:\"boolean\",dflt:!0,editType:\"calc+arraydraw\"},arrowcolor:{valType:\"color\",editType:\"arraydraw\"},arrowhead:{valType:\"integer\",min:0,max:n.length,dflt:1,editType:\"arraydraw\"},startarrowhead:{valType:\"integer\",min:0,max:n.length,dflt:1,editType:\"arraydraw\"},arrowside:{valType:\"flaglist\",flags:[\"end\",\"start\"],extras:[\"none\"],dflt:\"end\",editType:\"arraydraw\"},arrowsize:{valType:\"number\",min:.3,dflt:1,editType:\"calc+arraydraw\"},startarrowsize:{valType:\"number\",min:.3,dflt:1,editType:\"calc+arraydraw\"},arrowwidth:{valType:\"number\",min:.1,editType:\"calc+arraydraw\"},standoff:{valType:\"number\",min:0,dflt:0,editType:\"calc+arraydraw\"},startstandoff:{valType:\"number\",min:0,dflt:0,editType:\"calc+arraydraw\"},ax:{valType:\"any\",editType:\"calc+arraydraw\"},ay:{valType:\"any\",editType:\"calc+arraydraw\"},axref:{valType:\"enumerated\",dflt:\"pixel\",values:[\"pixel\",a.idRegex.x.toString()],editType:\"calc\"},ayref:{valType:\"enumerated\",dflt:\"pixel\",values:[\"pixel\",a.idRegex.y.toString()],editType:\"calc\"},xref:{valType:\"enumerated\",values:[\"paper\",a.idRegex.x.toString()],editType:\"calc\"},x:{valType:\"any\",editType:\"calc+arraydraw\"},xanchor:{valType:\"enumerated\",values:[\"auto\",\"left\",\"center\",\"right\"],dflt:\"auto\",editType:\"calc+arraydraw\"},xshift:{valType:\"number\",dflt:0,editType:\"calc+arraydraw\"},yref:{valType:\"enumerated\",values:[\"paper\",a.idRegex.y.toString()],editType:\"calc\"},y:{valType:\"any\",editType:\"calc+arraydraw\"},yanchor:{valType:\"enumerated\",values:[\"auto\",\"top\",\"middle\",\"bottom\"],dflt:\"auto\",editType:\"calc+arraydraw\"},yshift:{valType:\"number\",dflt:0,editType:\"calc+arraydraw\"},clicktoshow:{valType:\"enumerated\",values:[!1,\"onoff\",\"onout\"],dflt:!1,editType:\"arraydraw\"},xclick:{valType:\"any\",editType:\"arraydraw\"},yclick:{valType:\"any\",editType:\"arraydraw\"},hovertext:{valType:\"string\",editType:\"arraydraw\"},hoverlabel:{bgcolor:{valType:\"color\",editType:\"arraydraw\"},bordercolor:{valType:\"color\",editType:\"arraydraw\"},font:i({editType:\"arraydraw\"}),editType:\"arraydraw\"},captureevents:{valType:\"boolean\",editType:\"arraydraw\"},editType:\"calc\",_deprecated:{ref:{valType:\"string\",editType:\"calc\"}}})},{\"../../constants/axis_placeable_objects\":768,\"../../plot_api/plot_template\":838,\"../../plots/cartesian/constants\":856,\"../../plots/font_attributes\":878,\"./arrow_paths\":644}],646:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"./draw\").draw;function o(t){var e=t._fullLayout;n.filterVisible(e.annotations).forEach((function(e){var r=i.getFromId(t,e.xref),n=i.getFromId(t,e.yref),a=i.getRefType(e.xref),o=i.getRefType(e.yref);e._extremes={},\"range\"===a&&s(e,r),\"range\"===o&&s(e,n)}))}function s(t,e){var r,n=e._id,a=n.charAt(0),o=t[a],s=t[\"a\"+a],l=t[a+\"ref\"],c=t[\"a\"+a+\"ref\"],u=t[\"_\"+a+\"padplus\"],f=t[\"_\"+a+\"padminus\"],h={x:1,y:-1}[a]*t[a+\"shift\"],p=3*t.arrowsize*t.arrowwidth||0,d=p+h,m=p-h,g=3*t.startarrowsize*t.arrowwidth||0,v=g+h,y=g-h;if(c===l){var x=i.findExtremes(e,[e.r2c(o)],{ppadplus:d,ppadminus:m}),b=i.findExtremes(e,[e.r2c(s)],{ppadplus:Math.max(u,v),ppadminus:Math.max(f,y)});r={min:[x.min[0],b.min[0]],max:[x.max[0],b.max[0]]}}else v=s?v+s:v,y=s?y-s:y,r=i.findExtremes(e,[e.r2c(o)],{ppadplus:Math.max(u,d,v),ppadminus:Math.max(f,m,y)});t._extremes[n]=r}e.exports=function(t){var e=t._fullLayout;if(n.filterVisible(e.annotations).length&&t._fullData.length)return n.syncOrAsync([a,o],t)}},{\"../../lib\":799,\"../../plots/cartesian/axes\":849,\"./draw\":651}],647:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../registry\"),a=t(\"../../plot_api/plot_template\").arrayEditor;function o(t,e){var r,n,i,a,o,l,c,u=t._fullLayout.annotations,f=[],h=[],p=[],d=(e||[]).length;for(r=0;r<u.length;r++)if(a=(i=u[r]).clicktoshow){for(n=0;n<d;n++)if(l=(o=e[n]).xaxis,c=o.yaxis,l._id===i.xref&&c._id===i.yref&&l.d2r(o.x)===s(i._xclick,l)&&c.d2r(o.y)===s(i._yclick,c)){(i.visible?\"onout\"===a?h:p:f).push(r);break}n===d&&i.visible&&\"onout\"===a&&h.push(r)}return{on:f,off:h,explicitOff:p}}function s(t,e){return\"log\"===e.type?e.l2r(t):e.d2r(t)}e.exports={hasClickToShow:function(t,e){var r=o(t,e);return r.on.length>0||r.explicitOff.length>0},onClick:function(t,e){var r,s,l=o(t,e),c=l.on,u=l.off.concat(l.explicitOff),f={},h=t._fullLayout.annotations;if(!c.length&&!u.length)return;for(r=0;r<c.length;r++)(s=a(t.layout,\"annotations\",h[c[r]])).modifyItem(\"visible\",!0),n.extendFlat(f,s.getUpdateObj());for(r=0;r<u.length;r++)(s=a(t.layout,\"annotations\",h[u[r]])).modifyItem(\"visible\",!1),n.extendFlat(f,s.getUpdateObj());return i.call(\"update\",t,{},f)}}},{\"../../lib\":799,\"../../plot_api/plot_template\":838,\"../../registry\":927}],648:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../color\");e.exports=function(t,e,r,a){a(\"opacity\");var o=a(\"bgcolor\"),s=a(\"bordercolor\"),l=i.opacity(s);a(\"borderpad\");var c=a(\"borderwidth\"),u=a(\"showarrow\");if(a(\"text\",u?\" \":r._dfltTitle.annotation),a(\"textangle\"),n.coerceFont(a,\"font\",r.font),a(\"width\"),a(\"align\"),a(\"height\")&&a(\"valign\"),u){var f,h,p=a(\"arrowside\");-1!==p.indexOf(\"end\")&&(f=a(\"arrowhead\"),h=a(\"arrowsize\")),-1!==p.indexOf(\"start\")&&(a(\"startarrowhead\",f),a(\"startarrowsize\",h)),a(\"arrowcolor\",l?e.bordercolor:i.defaultLine),a(\"arrowwidth\",2*(l&&c||1)),a(\"standoff\"),a(\"startstandoff\")}var d=a(\"hovertext\"),m=r.hoverlabel||{};if(d){var g=a(\"hoverlabel.bgcolor\",m.bgcolor||(i.opacity(o)?i.rgb(o):i.defaultLine)),v=a(\"hoverlabel.bordercolor\",m.bordercolor||i.contrast(g));n.coerceFont(a,\"hoverlabel.font\",{family:m.font.family,size:m.font.size,color:m.font.color||v})}a(\"captureevents\",!!d)}},{\"../../lib\":799,\"../color\":662}],649:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib/to_log_range\");e.exports=function(t,e,r,a){e=e||{};var o=\"log\"===r&&\"linear\"===e.type,s=\"linear\"===r&&\"log\"===e.type;if(o||s)for(var l,c,u=t._fullLayout.annotations,f=e._id.charAt(0),h=0;h<u.length;h++)l=u[h],c=\"annotations[\"+h+\"].\",l[f+\"ref\"]===e._id&&p(f),l[\"a\"+f+\"ref\"]===e._id&&p(\"a\"+f);function p(t){var r=l[t],s=null;s=o?i(r,e.range):Math.pow(10,r),n(s)||(s=null),a(c+t,s)}}},{\"../../lib/to_log_range\":826,\"fast-isnumeric\":245}],650:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../../plots/array_container_defaults\"),o=t(\"./common_defaults\"),s=t(\"./attributes\");function l(t,e,r){function a(r,i){return n.coerce(t,e,s,r,i)}var l=a(\"visible\"),c=a(\"clicktoshow\");if(l||c){o(t,e,r,a);for(var u=e.showarrow,f=[\"x\",\"y\"],h=[-10,-30],p={_fullLayout:r},d=0;d<2;d++){var m=f[d],g=i.coerceRef(t,e,p,m,\"\",\"paper\");if(\"paper\"!==g)i.getFromId(p,g)._annIndices.push(e._index);if(i.coercePosition(e,p,a,g,m,.5),u){var v=\"a\"+m,y=i.coerceRef(t,e,p,v,\"pixel\",[\"pixel\",\"paper\"]);\"pixel\"!==y&&y!==g&&(y=e[v]=\"pixel\");var x=\"pixel\"===y?h[d]:.4;i.coercePosition(e,p,a,y,v,x)}a(m+\"anchor\"),a(m+\"shift\")}if(n.noneOrAll(t,e,[\"x\",\"y\"]),u&&n.noneOrAll(t,e,[\"ax\",\"ay\"]),c){var b=a(\"xclick\"),_=a(\"yclick\");e._xclick=void 0===b?e.x:i.cleanPosition(b,p,e.xref),e._yclick=void 0===_?e.y:i.cleanPosition(_,p,e.yref)}}}e.exports=function(t,e){a(t,e,{name:\"annotations\",handleItemDefaults:l})}},{\"../../lib\":799,\"../../plots/array_container_defaults\":844,\"../../plots/cartesian/axes\":849,\"./attributes\":645,\"./common_defaults\":648}],651:[function(t,e,r){\"use strict\";var n=t(\"@plotly/d3\"),i=t(\"../../registry\"),a=t(\"../../plots/plots\"),o=t(\"../../lib\"),s=o.strTranslate,l=t(\"../../plots/cartesian/axes\"),c=t(\"../color\"),u=t(\"../drawing\"),f=t(\"../fx\"),h=t(\"../../lib/svg_text_utils\"),p=t(\"../../lib/setcursor\"),d=t(\"../dragelement\"),m=t(\"../../plot_api/plot_template\").arrayEditor,g=t(\"./draw_arrow_head\");function v(t,e){var r=t._fullLayout.annotations[e]||{},n=l.getFromId(t,r.xref),i=l.getFromId(t,r.yref);n&&n.setScale(),i&&i.setScale(),x(t,r,e,!1,n,i)}function y(t,e,r,n,i){var a=i[r],o=i[r+\"ref\"],s=-1!==r.indexOf(\"y\"),c=\"domain\"===l.getRefType(o),u=s?n.h:n.w;return t?c?a+(s?-e:e)/t._length:t.p2r(t.r2p(a)+e):a+(s?-e:e)/u}function x(t,e,r,a,v,x){var b,_,w=t._fullLayout,T=t._fullLayout._size,k=t._context.edits;a?(b=\"annotation-\"+a,_=a+\".annotations\"):(b=\"annotation\",_=\"annotations\");var M=m(t.layout,_,e),A=M.modifyBase,S=M.modifyItem,E=M.getUpdateObj;w._infolayer.selectAll(\".\"+b+'[data-index=\"'+r+'\"]').remove();var L=\"clip\"+w._uid+\"_ann\"+r;if(e._input&&!1!==e.visible){var C={x:{},y:{}},P=+e.textangle||0,I=w._infolayer.append(\"g\").classed(b,!0).attr(\"data-index\",String(r)).style(\"opacity\",e.opacity),O=I.append(\"g\").classed(\"annotation-text-g\",!0),z=k[e.showarrow?\"annotationTail\":\"annotationPosition\"],D=e.captureevents||k.annotationText||z,R=O.append(\"g\").style(\"pointer-events\",D?\"all\":null).call(p,\"pointer\").on(\"click\",(function(){t._dragging=!1,t.emit(\"plotly_clickannotation\",Y(n.event))}));e.hovertext&&R.on(\"mouseover\",(function(){var r=e.hoverlabel,n=r.font,i=this.getBoundingClientRect(),a=t.getBoundingClientRect();f.loneHover({x0:i.left-a.left,x1:i.right-a.left,y:(i.top+i.bottom)/2-a.top,text:e.hovertext,color:r.bgcolor,borderColor:r.bordercolor,fontFamily:n.family,fontSize:n.size,fontColor:n.color},{container:w._hoverlayer.node(),outerContainer:w._paper.node(),gd:t})})).on(\"mouseout\",(function(){f.loneUnhover(w._hoverlayer.node())}));var F=e.borderwidth,B=e.borderpad,N=F+B,j=R.append(\"rect\").attr(\"class\",\"bg\").style(\"stroke-width\",F+\"px\").call(c.stroke,e.bordercolor).call(c.fill,e.bgcolor),U=e.width||e.height,V=w._topclips.selectAll(\"#\"+L).data(U?[0]:[]);V.enter().append(\"clipPath\").classed(\"annclip\",!0).attr(\"id\",L).append(\"rect\"),V.exit().remove();var q=e.font,H=w._meta?o.templateString(e.text,w._meta):e.text,G=R.append(\"text\").classed(\"annotation-text\",!0).text(H);k.annotationText?G.call(h.makeEditable,{delegate:R,gd:t}).call(W).on(\"edit\",(function(r){e.text=r,this.call(W),S(\"text\",r),v&&v.autorange&&A(v._name+\".autorange\",!0),x&&x.autorange&&A(x._name+\".autorange\",!0),i.call(\"_guiRelayout\",t,E())})):G.call(W)}else n.selectAll(\"#\"+L).remove();function Y(t){var n={index:r,annotation:e._input,fullAnnotation:e,event:t};return a&&(n.subplotId=a),n}function W(r){return r.call(u.font,q).attr({\"text-anchor\":{left:\"start\",right:\"end\"}[e.align]||\"middle\"}),h.convertToTspans(r,t,X),r}function X(){var r=G.selectAll(\"a\");1===r.size()&&r.text()===G.text()&&R.insert(\"a\",\":first-child\").attr({\"xlink:xlink:href\":r.attr(\"xlink:href\"),\"xlink:xlink:show\":r.attr(\"xlink:show\")}).style({cursor:\"pointer\"}).node().appendChild(j.node());var n=R.select(\".annotation-text-math-group\"),f=!n.empty(),m=u.bBox((f?n:G).node()),b=m.width,_=m.height,M=e.width||b,D=e.height||_,B=Math.round(M+2*N),q=Math.round(D+2*N);function H(t,e){return\"auto\"===e&&(e=t<1/3?\"left\":t>2/3?\"right\":\"center\"),{center:0,middle:0,left:.5,bottom:-.5,right:-.5,top:.5}[e]}for(var W=!1,X=[\"x\",\"y\"],Z=0;Z<X.length;Z++){var J,K,Q,$,tt,et=X[Z],rt=e[et+\"ref\"]||et,nt=e[\"a\"+et+\"ref\"],it={x:v,y:x}[et],at=(P+(\"x\"===et?0:-90))*Math.PI/180,ot=B*Math.cos(at),st=q*Math.sin(at),lt=Math.abs(ot)+Math.abs(st),ct=e[et+\"anchor\"],ut=e[et+\"shift\"]*(\"x\"===et?1:-1),ft=C[et],ht=l.getRefType(rt);if(it&&\"domain\"!==ht){var pt=it.r2fraction(e[et]);(pt<0||pt>1)&&(nt===rt?((pt=it.r2fraction(e[\"a\"+et]))<0||pt>1)&&(W=!0):W=!0),J=it._offset+it.r2p(e[et]),$=.5}else{var dt=\"domain\"===ht;\"x\"===et?(Q=e[et],J=dt?it._offset+it._length*Q:J=T.l+T.w*Q):(Q=1-e[et],J=dt?it._offset+it._length*Q:J=T.t+T.h*Q),$=e.showarrow?.5:Q}if(e.showarrow){ft.head=J;var mt=e[\"a\"+et];if(tt=ot*H(.5,e.xanchor)-st*H(.5,e.yanchor),nt===rt){var gt=l.getRefType(nt);\"domain\"===gt?(\"y\"===et&&(mt=1-mt),ft.tail=it._offset+it._length*mt):\"paper\"===gt?\"y\"===et?(mt=1-mt,ft.tail=T.t+T.h*mt):ft.tail=T.l+T.w*mt:ft.tail=it._offset+it.r2p(mt),K=tt}else ft.tail=J+mt,K=tt+mt;ft.text=ft.tail+tt;var vt=w[\"x\"===et?\"width\":\"height\"];if(\"paper\"===rt&&(ft.head=o.constrain(ft.head,1,vt-1)),\"pixel\"===nt){var yt=-Math.max(ft.tail-3,ft.text),xt=Math.min(ft.tail+3,ft.text)-vt;yt>0?(ft.tail+=yt,ft.text+=yt):xt>0&&(ft.tail-=xt,ft.text-=xt)}ft.tail+=ut,ft.head+=ut}else K=tt=lt*H($,ct),ft.text=J+tt;ft.text+=ut,tt+=ut,K+=ut,e[\"_\"+et+\"padplus\"]=lt/2+K,e[\"_\"+et+\"padminus\"]=lt/2-K,e[\"_\"+et+\"size\"]=lt,e[\"_\"+et+\"shift\"]=tt}if(W)R.remove();else{var bt=0,_t=0;if(\"left\"!==e.align&&(bt=(M-b)*(\"center\"===e.align?.5:1)),\"top\"!==e.valign&&(_t=(D-_)*(\"middle\"===e.valign?.5:1)),f)n.select(\"svg\").attr({x:N+bt-1,y:N+_t}).call(u.setClipUrl,U?L:null,t);else{var wt=N+_t-m.top,Tt=N+bt-m.left;G.call(h.positionText,Tt,wt).call(u.setClipUrl,U?L:null,t)}V.select(\"rect\").call(u.setRect,N,N,M,D),j.call(u.setRect,F/2,F/2,B-F,q-F),R.call(u.setTranslate,Math.round(C.x.text-B/2),Math.round(C.y.text-q/2)),O.attr({transform:\"rotate(\"+P+\",\"+C.x.text+\",\"+C.y.text+\")\"});var kt,Mt=function(r,n){I.selectAll(\".annotation-arrow-g\").remove();var l=C.x.head,f=C.y.head,h=C.x.tail+r,p=C.y.tail+n,m=C.x.text+r,b=C.y.text+n,_=o.rotationXYMatrix(P,m,b),w=o.apply2DTransform(_),M=o.apply2DTransform2(_),L=+j.attr(\"width\"),z=+j.attr(\"height\"),D=m-.5*L,F=D+L,B=b-.5*z,N=B+z,U=[[D,B,D,N],[D,N,F,N],[F,N,F,B],[F,B,D,B]].map(M);if(!U.reduce((function(t,e){return t^!!o.segmentsIntersect(l,f,l+1e6,f+1e6,e[0],e[1],e[2],e[3])}),!1)){U.forEach((function(t){var e=o.segmentsIntersect(h,p,l,f,t[0],t[1],t[2],t[3]);e&&(h=e.x,p=e.y)}));var V=e.arrowwidth,q=e.arrowcolor,H=e.arrowside,G=I.append(\"g\").style({opacity:c.opacity(q)}).classed(\"annotation-arrow-g\",!0),Y=G.append(\"path\").attr(\"d\",\"M\"+h+\",\"+p+\"L\"+l+\",\"+f).style(\"stroke-width\",V+\"px\").call(c.stroke,c.rgb(q));if(g(Y,H,e),k.annotationPosition&&Y.node().parentNode&&!a){var W=l,X=f;if(e.standoff){var Z=Math.sqrt(Math.pow(l-h,2)+Math.pow(f-p,2));W+=e.standoff*(h-l)/Z,X+=e.standoff*(p-f)/Z}var J,K,Q=G.append(\"path\").classed(\"annotation-arrow\",!0).classed(\"anndrag\",!0).classed(\"cursor-move\",!0).attr({d:\"M3,3H-3V-3H3ZM0,0L\"+(h-W)+\",\"+(p-X),transform:s(W,X)}).style(\"stroke-width\",V+6+\"px\").call(c.stroke,\"rgba(0,0,0,0)\").call(c.fill,\"rgba(0,0,0,0)\");d.init({element:Q.node(),gd:t,prepFn:function(){var t=u.getTranslate(R);J=t.x,K=t.y,v&&v.autorange&&A(v._name+\".autorange\",!0),x&&x.autorange&&A(x._name+\".autorange\",!0)},moveFn:function(t,r){var n=w(J,K),i=n[0]+t,a=n[1]+r;R.call(u.setTranslate,i,a),S(\"x\",y(v,t,\"x\",T,e)),S(\"y\",y(x,r,\"y\",T,e)),e.axref===e.xref&&S(\"ax\",y(v,t,\"ax\",T,e)),e.ayref===e.yref&&S(\"ay\",y(x,r,\"ay\",T,e)),G.attr(\"transform\",s(t,r)),O.attr({transform:\"rotate(\"+P+\",\"+i+\",\"+a+\")\"})},doneFn:function(){i.call(\"_guiRelayout\",t,E());var e=document.querySelector(\".js-notes-box-panel\");e&&e.redraw(e.selectedObj)}})}}};if(e.showarrow&&Mt(0,0),z)d.init({element:R.node(),gd:t,prepFn:function(){kt=O.attr(\"transform\")},moveFn:function(t,r){var n=\"pointer\";if(e.showarrow)e.axref===e.xref?S(\"ax\",y(v,t,\"ax\",T,e)):S(\"ax\",e.ax+t),e.ayref===e.yref?S(\"ay\",y(x,r,\"ay\",T.w,e)):S(\"ay\",e.ay+r),Mt(t,r);else{if(a)return;var i,o;if(v)i=y(v,t,\"x\",T,e);else{var l=e._xsize/T.w,c=e.x+(e._xshift-e.xshift)/T.w-l/2;i=d.align(c+t/T.w,l,0,1,e.xanchor)}if(x)o=y(x,r,\"y\",T,e);else{var u=e._ysize/T.h,f=e.y-(e._yshift+e.yshift)/T.h-u/2;o=d.align(f-r/T.h,u,0,1,e.yanchor)}S(\"x\",i),S(\"y\",o),v&&x||(n=d.getCursor(v?.5:i,x?.5:o,e.xanchor,e.yanchor))}O.attr({transform:s(t,r)+kt}),p(R,n)},clickFn:function(r,n){e.captureevents&&t.emit(\"plotly_clickannotation\",Y(n))},doneFn:function(){p(R),i.call(\"_guiRelayout\",t,E());var e=document.querySelector(\".js-notes-box-panel\");e&&e.redraw(e.selectedObj)}})}}}e.exports={draw:function(t){var e=t._fullLayout;e._infolayer.selectAll(\".annotation\").remove();for(var r=0;r<e.annotations.length;r++)e.annotations[r].visible&&v(t,r);return a.previousPromises(t)},drawOne:v,drawRaw:x}},{\"../../lib\":799,\"../../lib/setcursor\":820,\"../../lib/svg_text_utils\":824,\"../../plot_api/plot_template\":838,\"../../plots/cartesian/axes\":849,\"../../plots/plots\":913,\"../../registry\":927,\"../color\":662,\"../dragelement\":681,\"../drawing\":684,\"../fx\":702,\"./draw_arrow_head\":652,\"@plotly/d3\":58}],652:[function(t,e,r){\"use strict\";var n=t(\"@plotly/d3\"),i=t(\"../color\"),a=t(\"./arrow_paths\"),o=t(\"../../lib\"),s=o.strScale,l=o.strRotate,c=o.strTranslate;e.exports=function(t,e,r){var o,u,f,h,p=t.node(),d=a[r.arrowhead||0],m=a[r.startarrowhead||0],g=(r.arrowwidth||1)*(r.arrowsize||1),v=(r.arrowwidth||1)*(r.startarrowsize||1),y=e.indexOf(\"start\")>=0,x=e.indexOf(\"end\")>=0,b=d.backoff*g+r.standoff,_=m.backoff*v+r.startstandoff;if(\"line\"===p.nodeName){o={x:+t.attr(\"x1\"),y:+t.attr(\"y1\")},u={x:+t.attr(\"x2\"),y:+t.attr(\"y2\")};var w=o.x-u.x,T=o.y-u.y;if(h=(f=Math.atan2(T,w))+Math.PI,b&&_&&b+_>Math.sqrt(w*w+T*T))return void z();if(b){if(b*b>w*w+T*T)return void z();var k=b*Math.cos(f),M=b*Math.sin(f);u.x+=k,u.y+=M,t.attr({x2:u.x,y2:u.y})}if(_){if(_*_>w*w+T*T)return void z();var A=_*Math.cos(f),S=_*Math.sin(f);o.x-=A,o.y-=S,t.attr({x1:o.x,y1:o.y})}}else if(\"path\"===p.nodeName){var E=p.getTotalLength(),L=\"\";if(E<b+_)return void z();var C=p.getPointAtLength(0),P=p.getPointAtLength(.1);f=Math.atan2(C.y-P.y,C.x-P.x),o=p.getPointAtLength(Math.min(_,E)),L=\"0px,\"+_+\"px,\";var I=p.getPointAtLength(E),O=p.getPointAtLength(E-.1);h=Math.atan2(I.y-O.y,I.x-O.x),u=p.getPointAtLength(Math.max(0,E-b)),L+=E-(L?_+b:b)+\"px,\"+E+\"px\",t.style(\"stroke-dasharray\",L)}function z(){t.style(\"stroke-dasharray\",\"0px,100px\")}function D(e,a,o,u){e.path&&(e.noRotate&&(o=0),n.select(p.parentNode).append(\"path\").attr({class:t.attr(\"class\"),d:e.path,transform:c(a.x,a.y)+l(180*o/Math.PI)+s(u)}).style({fill:i.rgb(r.arrowcolor),\"stroke-width\":0}))}y&&D(m,o,f,v),x&&D(d,u,h,g)}},{\"../../lib\":799,\"../color\":662,\"./arrow_paths\":644,\"@plotly/d3\":58}],653:[function(t,e,r){\"use strict\";var n=t(\"./draw\"),i=t(\"./click\");e.exports={moduleType:\"component\",name:\"annotations\",layoutAttributes:t(\"./attributes\"),supplyLayoutDefaults:t(\"./defaults\"),includeBasePlot:t(\"../../plots/cartesian/include_components\")(\"annotations\"),calcAutorange:t(\"./calc_autorange\"),draw:n.draw,drawOne:n.drawOne,drawRaw:n.drawRaw,hasClickToShow:i.hasClickToShow,onClick:i.onClick,convertCoords:t(\"./convert_coords\")}},{\"../../plots/cartesian/include_components\":862,\"./attributes\":645,\"./calc_autorange\":646,\"./click\":647,\"./convert_coords\":649,\"./defaults\":650,\"./draw\":651}],654:[function(t,e,r){\"use strict\";var n=t(\"../annotations/attributes\"),i=t(\"../../plot_api/edit_types\").overrideAll,a=t(\"../../plot_api/plot_template\").templatedArray;e.exports=i(a(\"annotation\",{visible:n.visible,x:{valType:\"any\"},y:{valType:\"any\"},z:{valType:\"any\"},ax:{valType:\"number\"},ay:{valType:\"number\"},xanchor:n.xanchor,xshift:n.xshift,yanchor:n.yanchor,yshift:n.yshift,text:n.text,textangle:n.textangle,font:n.font,width:n.width,height:n.height,opacity:n.opacity,align:n.align,valign:n.valign,bgcolor:n.bgcolor,bordercolor:n.bordercolor,borderpad:n.borderpad,borderwidth:n.borderwidth,showarrow:n.showarrow,arrowcolor:n.arrowcolor,arrowhead:n.arrowhead,startarrowhead:n.startarrowhead,arrowside:n.arrowside,arrowsize:n.arrowsize,startarrowsize:n.startarrowsize,arrowwidth:n.arrowwidth,standoff:n.standoff,startstandoff:n.startstandoff,hovertext:n.hovertext,hoverlabel:n.hoverlabel,captureevents:n.captureevents}),\"calc\",\"from-root\")},{\"../../plot_api/edit_types\":831,\"../../plot_api/plot_template\":838,\"../annotations/attributes\":645}],655:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\");function a(t,e){var r=e.fullSceneLayout.domain,a=e.fullLayout._size,o={pdata:null,type:\"linear\",autorange:!1,range:[-1/0,1/0]};t._xa={},n.extendFlat(t._xa,o),i.setConvert(t._xa),t._xa._offset=a.l+r.x[0]*a.w,t._xa.l2p=function(){return.5*(1+t._pdata[0]/t._pdata[3])*a.w*(r.x[1]-r.x[0])},t._ya={},n.extendFlat(t._ya,o),i.setConvert(t._ya),t._ya._offset=a.t+(1-r.y[1])*a.h,t._ya.l2p=function(){return.5*(1-t._pdata[1]/t._pdata[3])*a.h*(r.y[1]-r.y[0])}}e.exports=function(t){for(var e=t.fullSceneLayout.annotations,r=0;r<e.length;r++)a(e[r],t);t.fullLayout._infolayer.selectAll(\".annotation-\"+t.id).remove()}},{\"../../lib\":799,\"../../plots/cartesian/axes\":849}],656:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../../plots/array_container_defaults\"),o=t(\"../annotations/common_defaults\"),s=t(\"./attributes\");function l(t,e,r,a){function l(r,i){return n.coerce(t,e,s,r,i)}function c(t){var n=t+\"axis\",a={_fullLayout:{}};return a._fullLayout[n]=r[n],i.coercePosition(e,a,l,t,t,.5)}l(\"visible\")&&(o(t,e,a.fullLayout,l),c(\"x\"),c(\"y\"),c(\"z\"),n.noneOrAll(t,e,[\"x\",\"y\",\"z\"]),e.xref=\"x\",e.yref=\"y\",e.zref=\"z\",l(\"xanchor\"),l(\"yanchor\"),l(\"xshift\"),l(\"yshift\"),e.showarrow&&(e.axref=\"pixel\",e.ayref=\"pixel\",l(\"ax\",-10),l(\"ay\",-30),n.noneOrAll(t,e,[\"ax\",\"ay\"])))}e.exports=function(t,e,r){a(t,e,{name:\"annotations\",handleItemDefaults:l,fullLayout:r.fullLayout})}},{\"../../lib\":799,\"../../plots/array_container_defaults\":844,\"../../plots/cartesian/axes\":849,\"../annotations/common_defaults\":648,\"./attributes\":654}],657:[function(t,e,r){\"use strict\";var n=t(\"../annotations/draw\").drawRaw,i=t(\"../../plots/gl3d/project\"),a=[\"x\",\"y\",\"z\"];e.exports=function(t){for(var e=t.fullSceneLayout,r=t.dataScale,o=e.annotations,s=0;s<o.length;s++){for(var l=o[s],c=!1,u=0;u<3;u++){var f=a[u],h=l[f],p=e[f+\"axis\"].r2fraction(h);if(p<0||p>1){c=!0;break}}c?t.fullLayout._infolayer.select(\".annotation-\"+t.id+'[data-index=\"'+s+'\"]').remove():(l._pdata=i(t.glplot.cameraParams,[e.xaxis.r2l(l.x)*r[0],e.yaxis.r2l(l.y)*r[1],e.zaxis.r2l(l.z)*r[2]]),n(t.graphDiv,l,s,t.id,l._xa,l._ya))}}},{\"../../plots/gl3d/project\":901,\"../annotations/draw\":651}],658:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\");e.exports={moduleType:\"component\",name:\"annotations3d\",schema:{subplots:{scene:{annotations:t(\"./attributes\")}}},layoutAttributes:t(\"./attributes\"),handleDefaults:t(\"./defaults\"),includeBasePlot:function(t,e){var r=n.subplotsRegistry.gl3d;if(!r)return;for(var a=r.attrRegex,o=Object.keys(t),s=0;s<o.length;s++){var l=o[s];a.test(l)&&(t[l].annotations||[]).length&&(i.pushUnique(e._basePlotModules,r),i.pushUnique(e._subplots.gl3d,l))}},convert:t(\"./convert\"),draw:t(\"./draw\")}},{\"../../lib\":799,\"../../registry\":927,\"./attributes\":654,\"./convert\":655,\"./defaults\":656,\"./draw\":657}],659:[function(t,e,r){\"use strict\";e.exports=t(\"world-calendars/dist/main\"),t(\"world-calendars/dist/plus\"),t(\"world-calendars/dist/calendars/chinese\"),t(\"world-calendars/dist/calendars/coptic\"),t(\"world-calendars/dist/calendars/discworld\"),t(\"world-calendars/dist/calendars/ethiopian\"),t(\"world-calendars/dist/calendars/hebrew\"),t(\"world-calendars/dist/calendars/islamic\"),t(\"world-calendars/dist/calendars/julian\"),t(\"world-calendars/dist/calendars/mayan\"),t(\"world-calendars/dist/calendars/nanakshahi\"),t(\"world-calendars/dist/calendars/nepali\"),t(\"world-calendars/dist/calendars/persian\"),t(\"world-calendars/dist/calendars/taiwan\"),t(\"world-calendars/dist/calendars/thai\"),t(\"world-calendars/dist/calendars/ummalqura\")},{\"world-calendars/dist/calendars/chinese\":626,\"world-calendars/dist/calendars/coptic\":627,\"world-calendars/dist/calendars/discworld\":628,\"world-calendars/dist/calendars/ethiopian\":629,\"world-calendars/dist/calendars/hebrew\":630,\"world-calendars/dist/calendars/islamic\":631,\"world-calendars/dist/calendars/julian\":632,\"world-calendars/dist/calendars/mayan\":633,\"world-calendars/dist/calendars/nanakshahi\":634,\"world-calendars/dist/calendars/nepali\":635,\"world-calendars/dist/calendars/persian\":636,\"world-calendars/dist/calendars/taiwan\":637,\"world-calendars/dist/calendars/thai\":638,\"world-calendars/dist/calendars/ummalqura\":639,\"world-calendars/dist/main\":640,\"world-calendars/dist/plus\":641}],660:[function(t,e,r){\"use strict\";var n=t(\"./calendars\"),i=t(\"../../lib\"),a=t(\"../../constants/numerical\"),o=a.EPOCHJD,s=a.ONEDAY,l={valType:\"enumerated\",values:Object.keys(n.calendars),editType:\"calc\",dflt:\"gregorian\"},c=function(t,e,r,n){var a={};return a[r]=l,i.coerce(t,e,a,r,n)},u={d:{0:\"dd\",\"-\":\"d\"},e:{0:\"d\",\"-\":\"d\"},a:{0:\"D\",\"-\":\"D\"},A:{0:\"DD\",\"-\":\"DD\"},j:{0:\"oo\",\"-\":\"o\"},W:{0:\"ww\",\"-\":\"w\"},m:{0:\"mm\",\"-\":\"m\"},b:{0:\"M\",\"-\":\"M\"},B:{0:\"MM\",\"-\":\"MM\"},y:{0:\"yy\",\"-\":\"yy\"},Y:{0:\"yyyy\",\"-\":\"yyyy\"},U:\"##\",w:\"##\",c:{0:\"D M d %X yyyy\",\"-\":\"D M d %X yyyy\"},x:{0:\"mm/dd/yyyy\",\"-\":\"mm/dd/yyyy\"}};var f={};function h(t){var e=f[t];return e||(e=f[t]=n.instance(t))}function p(t){return i.extendFlat({},l,{description:t})}function d(t){return\"Sets the calendar system to use with `\"+t+\"` date data.\"}var m={xcalendar:p(d(\"x\"))},g=i.extendFlat({},m,{ycalendar:p(d(\"y\"))}),v=i.extendFlat({},g,{zcalendar:p(d(\"z\"))}),y=p([\"Sets the calendar system to use for `range` and `tick0`\",\"if this is a date axis. This does not set the calendar for\",\"interpreting data on this axis, that's specified in the trace\",\"or via the global `layout.calendar`\"].join(\" \"));e.exports={moduleType:\"component\",name:\"calendars\",schema:{traces:{scatter:g,bar:g,box:g,heatmap:g,contour:g,histogram:g,histogram2d:g,histogram2dcontour:g,scatter3d:v,surface:v,mesh3d:v,scattergl:g,ohlc:m,candlestick:m},layout:{calendar:p([\"Sets the default calendar system to use for interpreting and\",\"displaying dates throughout the plot.\"].join(\" \"))},subplots:{xaxis:{calendar:y},yaxis:{calendar:y},scene:{xaxis:{calendar:y},yaxis:{calendar:y},zaxis:{calendar:y}},polar:{radialaxis:{calendar:y}}},transforms:{filter:{valuecalendar:p([\"WARNING: All transforms are deprecated and may be removed from the API in next major version.\",\"Sets the calendar system to use for `value`, if it is a date.\"].join(\" \")),targetcalendar:p([\"WARNING: All transforms are deprecated and may be removed from the API in next major version.\",\"Sets the calendar system to use for `target`, if it is an\",\"array of dates. If `target` is a string (eg *x*) we use the\",\"corresponding trace attribute (eg `xcalendar`) if it exists,\",\"even if `targetcalendar` is provided.\"].join(\" \"))}}},layoutAttributes:l,handleDefaults:c,handleTraceDefaults:function(t,e,r,n){for(var i=0;i<r.length;i++)c(t,e,r[i]+\"calendar\",n.calendar)},CANONICAL_SUNDAY:{chinese:\"2000-01-02\",coptic:\"2000-01-03\",discworld:\"2000-01-03\",ethiopian:\"2000-01-05\",hebrew:\"5000-01-01\",islamic:\"1000-01-02\",julian:\"2000-01-03\",mayan:\"5000-01-01\",nanakshahi:\"1000-01-05\",nepali:\"2000-01-05\",persian:\"1000-01-01\",jalali:\"1000-01-01\",taiwan:\"1000-01-04\",thai:\"2000-01-04\",ummalqura:\"1400-01-06\"},CANONICAL_TICK:{chinese:\"2000-01-01\",coptic:\"2000-01-01\",discworld:\"2000-01-01\",ethiopian:\"2000-01-01\",hebrew:\"5000-01-01\",islamic:\"1000-01-01\",julian:\"2000-01-01\",mayan:\"5000-01-01\",nanakshahi:\"1000-01-01\",nepali:\"2000-01-01\",persian:\"1000-01-01\",jalali:\"1000-01-01\",taiwan:\"1000-01-01\",thai:\"2000-01-01\",ummalqura:\"1400-01-01\"},DFLTRANGE:{chinese:[\"2000-01-01\",\"2001-01-01\"],coptic:[\"1700-01-01\",\"1701-01-01\"],discworld:[\"1800-01-01\",\"1801-01-01\"],ethiopian:[\"2000-01-01\",\"2001-01-01\"],hebrew:[\"5700-01-01\",\"5701-01-01\"],islamic:[\"1400-01-01\",\"1401-01-01\"],julian:[\"2000-01-01\",\"2001-01-01\"],mayan:[\"5200-01-01\",\"5201-01-01\"],nanakshahi:[\"0500-01-01\",\"0501-01-01\"],nepali:[\"2000-01-01\",\"2001-01-01\"],persian:[\"1400-01-01\",\"1401-01-01\"],jalali:[\"1400-01-01\",\"1401-01-01\"],taiwan:[\"0100-01-01\",\"0101-01-01\"],thai:[\"2500-01-01\",\"2501-01-01\"],ummalqura:[\"1400-01-01\",\"1401-01-01\"]},getCal:h,worldCalFmt:function(t,e,r){for(var n,i,a,l,c,f=Math.floor((e+.05)/s)+o,p=h(r).fromJD(f),d=0;-1!==(d=t.indexOf(\"%\",d));)\"0\"===(n=t.charAt(d+1))||\"-\"===n||\"_\"===n?(a=3,i=t.charAt(d+2),\"_\"===n&&(n=\"-\")):(i=n,n=\"0\",a=2),(l=u[i])?(c=\"##\"===l?\"##\":p.formatDate(l[n]),t=t.substr(0,d)+c+t.substr(d+a),d+=c.length):d+=a;return t}}},{\"../../constants/numerical\":775,\"../../lib\":799,\"./calendars\":659}],661:[function(t,e,r){\"use strict\";r.defaults=[\"#1f77b4\",\"#ff7f0e\",\"#2ca02c\",\"#d62728\",\"#9467bd\",\"#8c564b\",\"#e377c2\",\"#7f7f7f\",\"#bcbd22\",\"#17becf\"],r.defaultLine=\"#444\",r.lightLine=\"#eee\",r.background=\"#fff\",r.borderLine=\"#BEC8D9\",r.lightFraction=1e3/11},{}],662:[function(t,e,r){\"use strict\";var n=t(\"tinycolor2\"),i=t(\"fast-isnumeric\"),a=t(\"../../lib/array\").isTypedArray,o=e.exports={},s=t(\"./attributes\");o.defaults=s.defaults;var l=o.defaultLine=s.defaultLine;o.lightLine=s.lightLine;var c=o.background=s.background;function u(t){if(i(t)||\"string\"!=typeof t)return t;var e=t.trim();if(\"rgb\"!==e.substr(0,3))return t;var r=e.match(/^rgba?\\s*\\(([^()]*)\\)$/);if(!r)return t;var n=r[1].trim().split(/\\s*[\\s,]\\s*/),a=\"a\"===e.charAt(3)&&4===n.length;if(!a&&3!==n.length)return t;for(var o=0;o<n.length;o++){if(!n[o].length)return t;if(n[o]=Number(n[o]),!(n[o]>=0))return t;if(3===o)n[o]>1&&(n[o]=1);else if(n[o]>=1)return t}var s=Math.round(255*n[0])+\", \"+Math.round(255*n[1])+\", \"+Math.round(255*n[2]);return a?\"rgba(\"+s+\", \"+n[3]+\")\":\"rgb(\"+s+\")\"}o.tinyRGB=function(t){var e=t.toRgb();return\"rgb(\"+Math.round(e.r)+\", \"+Math.round(e.g)+\", \"+Math.round(e.b)+\")\"},o.rgb=function(t){return o.tinyRGB(n(t))},o.opacity=function(t){return t?n(t).getAlpha():0},o.addOpacity=function(t,e){var r=n(t).toRgb();return\"rgba(\"+Math.round(r.r)+\", \"+Math.round(r.g)+\", \"+Math.round(r.b)+\", \"+e+\")\"},o.combine=function(t,e){var r=n(t).toRgb();if(1===r.a)return n(t).toRgbString();var i=n(e||c).toRgb(),a=1===i.a?i:{r:255*(1-i.a)+i.r*i.a,g:255*(1-i.a)+i.g*i.a,b:255*(1-i.a)+i.b*i.a},o={r:a.r*(1-r.a)+r.r*r.a,g:a.g*(1-r.a)+r.g*r.a,b:a.b*(1-r.a)+r.b*r.a};return n(o).toRgbString()},o.contrast=function(t,e,r){var i=n(t);return 1!==i.getAlpha()&&(i=n(o.combine(t,c))),(i.isDark()?e?i.lighten(e):c:r?i.darken(r):l).toString()},o.stroke=function(t,e){var r=n(e);t.style({stroke:o.tinyRGB(r),\"stroke-opacity\":r.getAlpha()})},o.fill=function(t,e){var r=n(e);t.style({fill:o.tinyRGB(r),\"fill-opacity\":r.getAlpha()})},o.clean=function(t){if(t&&\"object\"==typeof t){var e,r,n,i,s=Object.keys(t);for(e=0;e<s.length;e++)if(i=t[n=s[e]],\"color\"===n.substr(n.length-5))if(Array.isArray(i))for(r=0;r<i.length;r++)i[r]=u(i[r]);else t[n]=u(i);else if(\"colorscale\"===n.substr(n.length-10)&&Array.isArray(i))for(r=0;r<i.length;r++)Array.isArray(i[r])&&(i[r][1]=u(i[r][1]));else if(Array.isArray(i)){var l=i[0];if(!Array.isArray(l)&&l&&\"object\"==typeof l)for(r=0;r<i.length;r++)o.clean(i[r])}else i&&\"object\"==typeof i&&!a(i)&&o.clean(i)}}},{\"../../lib/array\":781,\"./attributes\":661,\"fast-isnumeric\":245,tinycolor2:594}],663:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/layout_attributes\"),i=t(\"../../plots/font_attributes\"),a=t(\"../../lib/extend\").extendFlat,o=t(\"../../plot_api/edit_types\").overrideAll;e.exports=o({thicknessmode:{valType:\"enumerated\",values:[\"fraction\",\"pixels\"],dflt:\"pixels\"},thickness:{valType:\"number\",min:0,dflt:30},lenmode:{valType:\"enumerated\",values:[\"fraction\",\"pixels\"],dflt:\"fraction\"},len:{valType:\"number\",min:0,dflt:1},x:{valType:\"number\",dflt:1.02,min:-2,max:3},xanchor:{valType:\"enumerated\",values:[\"left\",\"center\",\"right\"],dflt:\"left\"},xpad:{valType:\"number\",min:0,dflt:10},y:{valType:\"number\",dflt:.5,min:-2,max:3},yanchor:{valType:\"enumerated\",values:[\"top\",\"middle\",\"bottom\"],dflt:\"middle\"},ypad:{valType:\"number\",min:0,dflt:10},outlinecolor:n.linecolor,outlinewidth:n.linewidth,bordercolor:n.linecolor,borderwidth:{valType:\"number\",min:0,dflt:0},bgcolor:{valType:\"color\",dflt:\"rgba(0,0,0,0)\"},tickmode:n.tickmode,nticks:n.nticks,tick0:n.tick0,dtick:n.dtick,tickvals:n.tickvals,ticktext:n.ticktext,ticks:a({},n.ticks,{dflt:\"\"}),ticklabeloverflow:a({},n.ticklabeloverflow,{}),ticklabelposition:{valType:\"enumerated\",values:[\"outside\",\"inside\",\"outside top\",\"inside top\",\"outside bottom\",\"inside bottom\"],dflt:\"outside\"},ticklen:n.ticklen,tickwidth:n.tickwidth,tickcolor:n.tickcolor,showticklabels:n.showticklabels,tickfont:i({}),tickangle:n.tickangle,tickformat:n.tickformat,tickformatstops:n.tickformatstops,tickprefix:n.tickprefix,showtickprefix:n.showtickprefix,ticksuffix:n.ticksuffix,showticksuffix:n.showticksuffix,separatethousands:n.separatethousands,exponentformat:n.exponentformat,minexponent:n.minexponent,showexponent:n.showexponent,title:{text:{valType:\"string\"},font:i({}),side:{valType:\"enumerated\",values:[\"right\",\"top\",\"bottom\"],dflt:\"top\"}},_deprecated:{title:{valType:\"string\"},titlefont:i({}),titleside:{valType:\"enumerated\",values:[\"right\",\"top\",\"bottom\"],dflt:\"top\"}}},\"colorbars\",\"from-root\")},{\"../../lib/extend\":789,\"../../plot_api/edit_types\":831,\"../../plots/cartesian/layout_attributes\":864,\"../../plots/font_attributes\":878}],664:[function(t,e,r){\"use strict\";e.exports={cn:{colorbar:\"colorbar\",cbbg:\"cbbg\",cbfill:\"cbfill\",cbfills:\"cbfills\",cbline:\"cbline\",cblines:\"cblines\",cbaxis:\"cbaxis\",cbtitleunshift:\"cbtitleunshift\",cbtitle:\"cbtitle\",cboutline:\"cboutline\",crisp:\"crisp\",jsPlaceholder:\"js-placeholder\"}}},{}],665:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plot_api/plot_template\"),a=t(\"../../plots/cartesian/tick_value_defaults\"),o=t(\"../../plots/cartesian/tick_mark_defaults\"),s=t(\"../../plots/cartesian/tick_label_defaults\"),l=t(\"./attributes\");e.exports=function(t,e,r){var c=i.newContainer(e,\"colorbar\"),u=t.colorbar||{};function f(t,e){return n.coerce(u,c,l,t,e)}var h=f(\"thicknessmode\");f(\"thickness\",\"fraction\"===h?30/(r.width-r.margin.l-r.margin.r):30);var p=f(\"lenmode\");f(\"len\",\"fraction\"===p?1:r.height-r.margin.t-r.margin.b),f(\"x\"),f(\"xanchor\"),f(\"xpad\"),f(\"y\"),f(\"yanchor\"),f(\"ypad\"),n.noneOrAll(u,c,[\"x\",\"y\"]),f(\"outlinecolor\"),f(\"outlinewidth\"),f(\"bordercolor\"),f(\"borderwidth\"),f(\"bgcolor\");var d=f(\"ticklabelposition\");f(\"ticklabeloverflow\",-1!==d.indexOf(\"inside\")?\"hide past domain\":\"hide past div\"),a(u,c,f,\"linear\");var m=r.font,g={outerTicks:!1,font:m};-1!==d.indexOf(\"inside\")&&(g.bgColor=\"black\"),s(u,c,f,\"linear\",g),o(u,c,f,\"linear\",g),f(\"title.text\",r._dfltTitle.colorbar);var v=c.tickfont,y=n.extendFlat({},v,{color:m.color,size:n.bigFont(v.size)});n.coerceFont(f,\"title.font\",y),f(\"title.side\")}},{\"../../lib\":799,\"../../plot_api/plot_template\":838,\"../../plots/cartesian/tick_label_defaults\":871,\"../../plots/cartesian/tick_mark_defaults\":872,\"../../plots/cartesian/tick_value_defaults\":873,\"./attributes\":663}],666:[function(t,e,r){\"use strict\";var n=t(\"@plotly/d3\"),i=t(\"tinycolor2\"),a=t(\"../../plots/plots\"),o=t(\"../../registry\"),s=t(\"../../plots/cartesian/axes\"),l=t(\"../dragelement\"),c=t(\"../../lib\"),u=c.strTranslate,f=t(\"../../lib/extend\").extendFlat,h=t(\"../../lib/setcursor\"),p=t(\"../drawing\"),d=t(\"../color\"),m=t(\"../titles\"),g=t(\"../../lib/svg_text_utils\"),v=t(\"../colorscale/helpers\").flipScale,y=t(\"../../plots/cartesian/axis_defaults\"),x=t(\"../../plots/cartesian/position_defaults\"),b=t(\"../../plots/cartesian/layout_attributes\"),_=t(\"../../constants/alignment\"),w=_.LINE_SPACING,T=_.FROM_TL,k=_.FROM_BR,M=t(\"./constants\").cn;e.exports={draw:function(t){var e=t._fullLayout._infolayer.selectAll(\"g.\"+M.colorbar).data(function(t){var e,r,n,i,a=t._fullLayout,o=t.calcdata,s=[];function l(t){return f(t,{_fillcolor:null,_line:{color:null,width:null,dash:null},_levels:{start:null,end:null,size:null},_filllevels:null,_fillgradient:null,_zrange:null})}function c(){\"function\"==typeof i.calc?i.calc(t,n,e):(e._fillgradient=r.reversescale?v(r.colorscale):r.colorscale,e._zrange=[r[i.min],r[i.max]])}for(var u=0;u<o.length;u++){var h=o[u],p=(n=h[0].trace)._module.colorbar;if(!0===n.visible&&p)for(var d=Array.isArray(p),m=d?p:[p],g=0;g<m.length;g++){var y=(i=m[g]).container;(r=y?n[y]:n)&&r.showscale&&((e=l(r.colorbar))._id=\"cb\"+n.uid+(d&&y?\"-\"+y:\"\"),e._traceIndex=n.index,e._propPrefix=(y?y+\".\":\"\")+\"colorbar.\",e._meta=n._meta,c(),s.push(e))}}for(var x in a._colorAxes)if((r=a[x]).showscale){var b=a._colorAxes[x];(e=l(r.colorbar))._id=\"cb\"+x,e._propPrefix=x+\".colorbar.\",e._meta=a._meta,i={min:\"cmin\",max:\"cmax\"},\"heatmap\"!==b[0]&&(n=b[1],i.calc=n._module.colorbar.calc),c(),s.push(e)}return s}(t),(function(t){return t._id}));e.enter().append(\"g\").attr(\"class\",(function(t){return t._id})).classed(M.colorbar,!0),e.each((function(e){var r=n.select(this);c.ensureSingle(r,\"rect\",M.cbbg),c.ensureSingle(r,\"g\",M.cbfills),c.ensureSingle(r,\"g\",M.cblines),c.ensureSingle(r,\"g\",M.cbaxis,(function(t){t.classed(M.crisp,!0)})),c.ensureSingle(r,\"g\",M.cbtitleunshift,(function(t){t.append(\"g\").classed(M.cbtitle,!0)})),c.ensureSingle(r,\"rect\",M.cboutline);var v=function(t,e,r){var o=r._fullLayout,l=o._size,h=e._fillcolor,v=e._line,_=e.title,A=_.side,S=e._zrange||n.extent((\"function\"==typeof h?h:v.color).domain()),E=\"function\"==typeof v.color?v.color:function(){return v.color},L=\"function\"==typeof h?h:function(){return h},C=e._levels,P=function(t,e,r){var n,i,a=e._levels,o=[],s=[],l=a.end+a.size/100,c=a.size,u=1.001*r[0]-.001*r[1],f=1.001*r[1]-.001*r[0];for(i=0;i<1e5&&(n=a.start+i*c,!(c>0?n>=l:n<=l));i++)n>u&&n<f&&o.push(n);if(e._fillgradient)s=[0];else if(\"function\"==typeof e._fillcolor){var h=e._filllevels;if(h)for(l=h.end+h.size/100,c=h.size,i=0;i<1e5&&(n=h.start+i*c,!(c>0?n>=l:n<=l));i++)n>r[0]&&n<r[1]&&s.push(n);else(s=o.map((function(t){return t-a.size/2}))).push(s[s.length-1]+a.size)}else e._fillcolor&&\"string\"==typeof e._fillcolor&&(s=[0]);a.size<0&&(o.reverse(),s.reverse());return{line:o,fill:s}}(0,e,S),I=P.fill,O=P.line,z=Math.round(e.thickness*(\"fraction\"===e.thicknessmode?l.w:1)),D=z/l.w,R=Math.round(e.len*(\"fraction\"===e.lenmode?l.h:1)),F=R/l.h,B=e.xpad/l.w,N=(e.borderwidth+e.outlinewidth)/2,j=e.ypad/l.h,U=Math.round(e.x*l.w+e.xpad),V=e.x-D*({middle:.5,right:1}[e.xanchor]||0),q=e.y+F*(({top:-.5,bottom:.5}[e.yanchor]||0)-.5),H=Math.round(l.h*(1-q)),G=H-R;e._lenFrac=F,e._thickFrac=D,e._xLeftFrac=V,e._yBottomFrac=q;var Y=e._axis=function(t,e,r){var n=t._fullLayout,i={type:\"linear\",range:r,tickmode:e.tickmode,nticks:e.nticks,tick0:e.tick0,dtick:e.dtick,tickvals:e.tickvals,ticktext:e.ticktext,ticks:e.ticks,ticklen:e.ticklen,tickwidth:e.tickwidth,tickcolor:e.tickcolor,showticklabels:e.showticklabels,ticklabelposition:e.ticklabelposition,ticklabeloverflow:e.ticklabeloverflow,tickfont:e.tickfont,tickangle:e.tickangle,tickformat:e.tickformat,exponentformat:e.exponentformat,minexponent:e.minexponent,separatethousands:e.separatethousands,showexponent:e.showexponent,showtickprefix:e.showtickprefix,tickprefix:e.tickprefix,showticksuffix:e.showticksuffix,ticksuffix:e.ticksuffix,title:e.title,showline:!0,anchor:\"free\",side:\"right\",position:1},a={type:\"linear\",_id:\"y\"+e._id},o={letter:\"y\",font:n.font,noHover:!0,noTickson:!0,noTicklabelmode:!0,calendar:n.calendar};function s(t,e){return c.coerce(i,a,b,t,e)}return y(i,a,s,o,n),x(i,a,s,o),a}(r,e,S);Y.position=e.x+B+D,-1!==[\"top\",\"bottom\"].indexOf(A)&&(Y.title.side=A,Y.titlex=e.x+B,Y.titley=q+(\"top\"===_.side?F-j:j));if(v.color&&\"auto\"===e.tickmode){Y.tickmode=\"linear\",Y.tick0=C.start;var W=C.size,X=c.constrain((H-G)/50,4,15)+1,Z=(S[1]-S[0])/((e.nticks||X)*W);if(Z>1){var J=Math.pow(10,Math.floor(Math.log(Z)/Math.LN10));W*=J*c.roundUp(Z/J,[2,5,10]),(Math.abs(C.start)/C.size+1e-6)%1<2e-6&&(Y.tick0=0)}Y.dtick=W}Y.domain=[q+j,q+F-j],Y.setScale(),t.attr(\"transform\",u(Math.round(l.l),Math.round(l.t)));var K,Q=t.select(\".\"+M.cbtitleunshift).attr(\"transform\",u(-Math.round(l.l),-Math.round(l.t))),$=t.select(\".\"+M.cbaxis),tt=0;function et(n,i){var a={propContainer:Y,propName:e._propPrefix+\"title\",traceIndex:e._traceIndex,_meta:e._meta,placeholder:o._dfltTitle.colorbar,containerGroup:t.select(\".\"+M.cbtitle)},s=\"h\"===n.charAt(0)?n.substr(1):\"h\"+n;t.selectAll(\".\"+s+\",.\"+s+\"-math-group\").remove(),m.draw(r,n,f(a,i||{}))}return c.syncOrAsync([a.previousPromises,function(){if(-1!==[\"top\",\"bottom\"].indexOf(A)){var t,r=l.l+(e.x+B)*l.w,n=Y.title.font.size;t=\"top\"===A?(1-(q+F-j))*l.h+l.t+3+.75*n:(1-(q+j))*l.h+l.t-3-.25*n,et(Y._id+\"title\",{attributes:{x:r,y:t,\"text-anchor\":\"start\"}})}},function(){if(-1!==[\"top\",\"bottom\"].indexOf(A)){var a=t.select(\".\"+M.cbtitle),o=a.select(\"text\"),f=[-e.outlinewidth/2,e.outlinewidth/2],h=a.select(\".h\"+Y._id+\"title-math-group\").node(),d=15.6;if(o.node()&&(d=parseInt(o.node().style.fontSize,10)*w),h?(tt=p.bBox(h).height)>d&&(f[1]-=(tt-d)/2):o.node()&&!o.classed(M.jsPlaceholder)&&(tt=p.bBox(o.node()).height),tt){if(tt+=5,\"top\"===A)Y.domain[1]-=tt/l.h,f[1]*=-1;else{Y.domain[0]+=tt/l.h;var m=g.lineCount(o);f[1]+=(1-m)*d}a.attr(\"transform\",u(f[0],f[1])),Y.setScale()}}t.selectAll(\".\"+M.cbfills+\",.\"+M.cblines).attr(\"transform\",u(0,Math.round(l.h*(1-Y.domain[1])))),$.attr(\"transform\",u(0,Math.round(-l.t)));var y=t.select(\".\"+M.cbfills).selectAll(\"rect.\"+M.cbfill).attr(\"style\",\"\").data(I);y.enter().append(\"rect\").classed(M.cbfill,!0).style(\"stroke\",\"none\"),y.exit().remove();var x=S.map(Y.c2p).map(Math.round).sort((function(t,e){return t-e}));y.each((function(t,a){var o=[0===a?S[0]:(I[a]+I[a-1])/2,a===I.length-1?S[1]:(I[a]+I[a+1])/2].map(Y.c2p).map(Math.round);o[1]=c.constrain(o[1]+(o[1]>o[0])?1:-1,x[0],x[1]);var s=n.select(this).attr({x:U,width:Math.max(z,2),y:n.min(o),height:Math.max(n.max(o)-n.min(o),2)});if(e._fillgradient)p.gradient(s,r,e._id,\"vertical\",e._fillgradient,\"fill\");else{var l=L(t).replace(\"e-\",\"\");s.attr(\"fill\",i(l).toHexString())}}));var b=t.select(\".\"+M.cblines).selectAll(\"path.\"+M.cbline).data(v.color&&v.width?O:[]);b.enter().append(\"path\").classed(M.cbline,!0),b.exit().remove(),b.each((function(t){n.select(this).attr(\"d\",\"M\"+U+\",\"+(Math.round(Y.c2p(t))+v.width/2%1)+\"h\"+z).call(p.lineGroupStyle,v.width,E(t),v.dash)})),$.selectAll(\"g.\"+Y._id+\"tick,path\").remove();var _=U+z+(e.outlinewidth||0)/2-(\"outside\"===e.ticks?1:0),T=s.calcTicks(Y),k=s.getTickSigns(Y)[2];return s.drawTicks(r,Y,{vals:\"inside\"===Y.ticks?s.clipEnds(Y,T):T,layer:$,path:s.makeTickPath(Y,_,k),transFn:s.makeTransTickFn(Y)}),s.drawLabels(r,Y,{vals:T,layer:$,transFn:s.makeTransTickLabelFn(Y),labelFns:s.makeLabelFns(Y,_)})},function(){if(-1===[\"top\",\"bottom\"].indexOf(A)){var t=Y.title.font.size,e=Y._offset+Y._length/2,i=l.l+(Y.position||0)*l.w+(\"right\"===Y.side?10+t*(Y.showticklabels?1:.5):-10-t*(Y.showticklabels?.5:0));et(\"h\"+Y._id+\"title\",{avoid:{selection:n.select(r).selectAll(\"g.\"+Y._id+\"tick\"),side:A,offsetLeft:l.l,offsetTop:0,maxShift:o.width},attributes:{x:i,y:e,\"text-anchor\":\"middle\"},transform:{rotate:\"-90\",offset:0}})}},a.previousPromises,function(){var n=z+e.outlinewidth/2;if(-1===Y.ticklabelposition.indexOf(\"inside\")&&(n+=p.bBox($.node()).width),(K=Q.select(\"text\")).node()&&!K.classed(M.jsPlaceholder)){var i,o=Q.select(\".h\"+Y._id+\"title-math-group\").node();i=o&&-1!==[\"top\",\"bottom\"].indexOf(A)?p.bBox(o).width:p.bBox(Q.node()).right-U-l.l,n=Math.max(n,i)}var s=2*e.xpad+n+e.borderwidth+e.outlinewidth/2,c=H-G;t.select(\".\"+M.cbbg).attr({x:U-e.xpad-(e.borderwidth+e.outlinewidth)/2,y:G-N,width:Math.max(s,2),height:Math.max(c+2*N,2)}).call(d.fill,e.bgcolor).call(d.stroke,e.bordercolor).style(\"stroke-width\",e.borderwidth),t.selectAll(\".\"+M.cboutline).attr({x:U,y:G+e.ypad+(\"top\"===A?tt:0),width:Math.max(z,2),height:Math.max(c-2*e.ypad-tt,2)}).call(d.stroke,e.outlinecolor).style({fill:\"none\",\"stroke-width\":e.outlinewidth});var f=({center:.5,right:1}[e.xanchor]||0)*s;t.attr(\"transform\",u(l.l-f,l.t));var h={},m=T[e.yanchor],g=k[e.yanchor];\"pixels\"===e.lenmode?(h.y=e.y,h.t=c*m,h.b=c*g):(h.t=h.b=0,h.yt=e.y+e.len*m,h.yb=e.y-e.len*g);var v=T[e.xanchor],y=k[e.xanchor];if(\"pixels\"===e.thicknessmode)h.x=e.x,h.l=s*v,h.r=s*y;else{var x=s-z;h.l=x*v,h.r=x*y,h.xl=e.x-e.thickness*v,h.xr=e.x+e.thickness*y}a.autoMargin(r,e._id,h)}],r)}(r,e,t);v&&v.then&&(t._promises||[]).push(v),t._context.edits.colorbarPosition&&function(t,e,r){var n,i,a,s=r._fullLayout._size;l.init({element:t.node(),gd:r,prepFn:function(){n=t.attr(\"transform\"),h(t)},moveFn:function(r,o){t.attr(\"transform\",n+u(r,o)),i=l.align(e._xLeftFrac+r/s.w,e._thickFrac,0,1,e.xanchor),a=l.align(e._yBottomFrac-o/s.h,e._lenFrac,0,1,e.yanchor);var c=l.getCursor(i,a,e.xanchor,e.yanchor);h(t,c)},doneFn:function(){if(h(t),void 0!==i&&void 0!==a){var n={};n[e._propPrefix+\"x\"]=i,n[e._propPrefix+\"y\"]=a,void 0!==e._traceIndex?o.call(\"_guiRestyle\",r,n,e._traceIndex):o.call(\"_guiRelayout\",r,n)}}})}(r,e,t)})),e.exit().each((function(e){a.autoMargin(t,e._id)})).remove(),e.order()}}},{\"../../constants/alignment\":767,\"../../lib\":799,\"../../lib/extend\":789,\"../../lib/setcursor\":820,\"../../lib/svg_text_utils\":824,\"../../plots/cartesian/axes\":849,\"../../plots/cartesian/axis_defaults\":851,\"../../plots/cartesian/layout_attributes\":864,\"../../plots/cartesian/position_defaults\":867,\"../../plots/plots\":913,\"../../registry\":927,\"../color\":662,\"../colorscale/helpers\":673,\"../dragelement\":681,\"../drawing\":684,\"../titles\":760,\"./constants\":664,\"@plotly/d3\":58,tinycolor2:594}],667:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t){return n.isPlainObject(t.colorbar)}},{\"../../lib\":799}],668:[function(t,e,r){\"use strict\";e.exports={moduleType:\"component\",name:\"colorbar\",attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),draw:t(\"./draw\").draw,hasColorbar:t(\"./has_colorbar\")}},{\"./attributes\":663,\"./defaults\":665,\"./draw\":666,\"./has_colorbar\":667}],669:[function(t,e,r){\"use strict\";var n=t(\"../colorbar/attributes\"),i=t(\"../../lib/regex\").counter,a=t(\"./scales.js\").scales;Object.keys(a);function o(t){return\"`\"+t+\"`\"}e.exports=function(t,e){t=t||\"\";var r,s=(e=e||{}).cLetter||\"c\",l=(\"onlyIfNumerical\"in e?e.onlyIfNumerical:Boolean(t),\"noScale\"in e?e.noScale:\"marker.line\"===t),c=\"showScaleDflt\"in e?e.showScaleDflt:\"z\"===s,u=\"string\"==typeof e.colorscaleDflt?a[e.colorscaleDflt]:null,f=e.editTypeOverride||\"\",h=t?t+\".\":\"\";\"colorAttr\"in e?(r=e.colorAttr,e.colorAttr):o(h+(r={z:\"z\",c:\"color\"}[s]));var p=s+\"auto\",d=s+\"min\",m=s+\"max\",g=s+\"mid\",v=(o(h+p),o(h+d),o(h+m),{});v[d]=v[m]=void 0;var y={};y[p]=!1;var x={};return\"color\"===r&&(x.color={valType:\"color\",arrayOk:!0,editType:f||\"style\"},e.anim&&(x.color.anim=!0)),x[p]={valType:\"boolean\",dflt:!0,editType:\"calc\",impliedEdits:v},x[d]={valType:\"number\",dflt:null,editType:f||\"plot\",impliedEdits:y},x[m]={valType:\"number\",dflt:null,editType:f||\"plot\",impliedEdits:y},x[g]={valType:\"number\",dflt:null,editType:\"calc\",impliedEdits:v},x.colorscale={valType:\"colorscale\",editType:\"calc\",dflt:u,impliedEdits:{autocolorscale:!1}},x.autocolorscale={valType:\"boolean\",dflt:!1!==e.autoColorDflt,editType:\"calc\",impliedEdits:{colorscale:void 0}},x.reversescale={valType:\"boolean\",dflt:!1,editType:\"plot\"},l||(x.showscale={valType:\"boolean\",dflt:c,editType:\"calc\"},x.colorbar=n),e.noColorAxis||(x.coloraxis={valType:\"subplotid\",regex:i(\"coloraxis\"),dflt:null,editType:\"calc\"}),x}},{\"../../lib/regex\":816,\"../colorbar/attributes\":663,\"./scales.js\":677}],670:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"./helpers\").extractOpts;e.exports=function(t,e,r){var o,s=t._fullLayout,l=r.vals,c=r.containerStr,u=c?i.nestedProperty(e,c).get():e,f=a(u),h=!1!==f.auto,p=f.min,d=f.max,m=f.mid,g=function(){return i.aggNums(Math.min,null,l)},v=function(){return i.aggNums(Math.max,null,l)};(void 0===p?p=g():h&&(p=u._colorAx&&n(p)?Math.min(p,g()):g()),void 0===d?d=v():h&&(d=u._colorAx&&n(d)?Math.max(d,v()):v()),h&&void 0!==m&&(d-m>m-p?p=m-(d-m):d-m<m-p&&(d=m+(m-p))),p===d&&(p-=.5,d+=.5),f._sync(\"min\",p),f._sync(\"max\",d),f.autocolorscale)&&(o=p*d<0?s.colorscale.diverging:p>=0?s.colorscale.sequential:s.colorscale.sequentialminus,f._sync(\"colorscale\",o))}},{\"../../lib\":799,\"./helpers\":673,\"fast-isnumeric\":245}],671:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./helpers\").hasColorscale,a=t(\"./helpers\").extractOpts;e.exports=function(t,e){function r(t,e){var r=t[\"_\"+e];void 0!==r&&(t[e]=r)}function o(t,i){var o=i.container?n.nestedProperty(t,i.container).get():t;if(o)if(o.coloraxis)o._colorAx=e[o.coloraxis];else{var s=a(o),l=s.auto;(l||void 0===s.min)&&r(o,i.min),(l||void 0===s.max)&&r(o,i.max),s.autocolorscale&&r(o,\"colorscale\")}}for(var s=0;s<t.length;s++){var l=t[s],c=l._module.colorbar;if(c)if(Array.isArray(c))for(var u=0;u<c.length;u++)o(l,c[u]);else o(l,c);i(l,\"marker.line\")&&o(l,{container:\"marker.line\",min:\"cmin\",max:\"cmax\"})}for(var f in e._colorAxes)o(e[f],{min:\"cmin\",max:\"cmax\"})}},{\"../../lib\":799,\"./helpers\":673}],672:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../colorbar/has_colorbar\"),o=t(\"../colorbar/defaults\"),s=t(\"./scales\").isValid,l=t(\"../../registry\").traceIs;function c(t,e){var r=e.slice(0,e.length-1);return e?i.nestedProperty(t,r).get()||{}:t}e.exports=function t(e,r,u,f,h){var p=h.prefix,d=h.cLetter,m=\"_module\"in r,g=c(e,p),v=c(r,p),y=c(r._template||{},p)||{},x=function(){return delete e.coloraxis,delete r.coloraxis,t(e,r,u,f,h)};if(m){var b=u._colorAxes||{},_=f(p+\"coloraxis\");if(_){var w=l(r,\"contour\")&&i.nestedProperty(r,\"contours.coloring\").get()||\"heatmap\",T=b[_];return void(T?(T[2].push(x),T[0]!==w&&(T[0]=!1,i.warn([\"Ignoring coloraxis:\",_,\"setting\",\"as it is linked to incompatible colorscales.\"].join(\" \")))):b[_]=[w,r,[x]])}}var k=g[d+\"min\"],M=g[d+\"max\"],A=n(k)&&n(M)&&k<M;f(p+d+\"auto\",!A)?f(p+d+\"mid\"):(f(p+d+\"min\"),f(p+d+\"max\"));var S,E,L=g.colorscale,C=y.colorscale;(void 0!==L&&(S=!s(L)),void 0!==C&&(S=!s(C)),f(p+\"autocolorscale\",S),f(p+\"colorscale\"),f(p+\"reversescale\"),\"marker.line.\"!==p)&&(p&&m&&(E=a(g)),f(p+\"showscale\",E)&&(p&&y&&(v._template=y),o(g,v,u)))}},{\"../../lib\":799,\"../../registry\":927,\"../colorbar/defaults\":665,\"../colorbar/has_colorbar\":667,\"./scales\":677,\"fast-isnumeric\":245}],673:[function(t,e,r){\"use strict\";var n=t(\"@plotly/d3\"),i=t(\"tinycolor2\"),a=t(\"fast-isnumeric\"),o=t(\"../../lib\"),s=t(\"../color\"),l=t(\"./scales\").isValid;var c=[\"showscale\",\"autocolorscale\",\"colorscale\",\"reversescale\",\"colorbar\"],u=[\"min\",\"max\",\"mid\",\"auto\"];function f(t){var e,r,n,i=t._colorAx,a=i||t,o={};for(r=0;r<c.length;r++)o[n=c[r]]=a[n];if(i)for(e=\"c\",r=0;r<u.length;r++)o[n=u[r]]=a[\"c\"+n];else{var s;for(r=0;r<u.length;r++)((s=\"c\"+(n=u[r]))in a||(s=\"z\"+n)in a)&&(o[n]=a[s]);e=s.charAt(0)}return o._sync=function(t,r){var n=-1!==u.indexOf(t)?e+t:t;a[n]=a[\"_\"+n]=r},o}function h(t){for(var e=f(t),r=e.min,n=e.max,i=e.reversescale?p(e.colorscale):e.colorscale,a=i.length,o=new Array(a),s=new Array(a),l=0;l<a;l++){var c=i[l];o[l]=r+c[0]*(n-r),s[l]=c[1]}return{domain:o,range:s}}function p(t){for(var e=t.length,r=new Array(e),n=e-1,i=0;n>=0;n--,i++){var a=t[n];r[i]=[1-a[0],a[1]]}return r}function d(t,e){e=e||{};for(var r=t.domain,o=t.range,l=o.length,c=new Array(l),u=0;u<l;u++){var f=i(o[u]).toRgb();c[u]=[f.r,f.g,f.b,f.a]}var h,p=n.scale.linear().domain(r).range(c).clamp(!0),d=e.noNumericCheck,g=e.returnArray;return(h=d&&g?p:d?function(t){return m(p(t))}:g?function(t){return a(t)?p(t):i(t).isValid()?t:s.defaultLine}:function(t){return a(t)?m(p(t)):i(t).isValid()?t:s.defaultLine}).domain=p.domain,h.range=function(){return o},h}function m(t){var e={r:t[0],g:t[1],b:t[2],a:t[3]};return i(e).toRgbString()}e.exports={hasColorscale:function(t,e,r){var n=e?o.nestedProperty(t,e).get()||{}:t,i=n[r||\"color\"],s=!1;if(o.isArrayOrTypedArray(i))for(var c=0;c<i.length;c++)if(a(i[c])){s=!0;break}return o.isPlainObject(n)&&(s||!0===n.showscale||a(n.cmin)&&a(n.cmax)||l(n.colorscale)||o.isPlainObject(n.colorbar))},extractOpts:f,extractScale:h,flipScale:p,makeColorScaleFunc:d,makeColorScaleFuncFromTrace:function(t,e){return d(h(t),e)}}},{\"../../lib\":799,\"../color\":662,\"./scales\":677,\"@plotly/d3\":58,\"fast-isnumeric\":245,tinycolor2:594}],674:[function(t,e,r){\"use strict\";var n=t(\"./scales\"),i=t(\"./helpers\");e.exports={moduleType:\"component\",name:\"colorscale\",attributes:t(\"./attributes\"),layoutAttributes:t(\"./layout_attributes\"),supplyLayoutDefaults:t(\"./layout_defaults\"),handleDefaults:t(\"./defaults\"),crossTraceDefaults:t(\"./cross_trace_defaults\"),calc:t(\"./calc\"),scales:n.scales,defaultScale:n.defaultScale,getScale:n.get,isValidScale:n.isValid,hasColorscale:i.hasColorscale,extractOpts:i.extractOpts,extractScale:i.extractScale,flipScale:i.flipScale,makeColorScaleFunc:i.makeColorScaleFunc,makeColorScaleFuncFromTrace:i.makeColorScaleFuncFromTrace}},{\"./attributes\":669,\"./calc\":670,\"./cross_trace_defaults\":671,\"./defaults\":672,\"./helpers\":673,\"./layout_attributes\":675,\"./layout_defaults\":676,\"./scales\":677}],675:[function(t,e,r){\"use strict\";var n=t(\"../../lib/extend\").extendFlat,i=t(\"./attributes\"),a=t(\"./scales\").scales;e.exports={editType:\"calc\",colorscale:{editType:\"calc\",sequential:{valType:\"colorscale\",dflt:a.Reds,editType:\"calc\"},sequentialminus:{valType:\"colorscale\",dflt:a.Blues,editType:\"calc\"},diverging:{valType:\"colorscale\",dflt:a.RdBu,editType:\"calc\"}},coloraxis:n({_isSubplotObj:!0,editType:\"calc\"},i(\"\",{colorAttr:\"corresponding trace color array(s)\",noColorAxis:!0,showScaleDflt:!0}))}},{\"../../lib/extend\":789,\"./attributes\":669,\"./scales\":677}],676:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plot_api/plot_template\"),a=t(\"./layout_attributes\"),o=t(\"./defaults\");e.exports=function(t,e){function r(r,i){return n.coerce(t,e,a,r,i)}r(\"colorscale.sequential\"),r(\"colorscale.sequentialminus\"),r(\"colorscale.diverging\");var s,l,c=e._colorAxes;function u(t,e){return n.coerce(s,l,a.coloraxis,t,e)}for(var f in c){var h=c[f];if(h[0])s=t[f]||{},(l=i.newContainer(e,f,\"coloraxis\"))._name=f,o(s,l,e,u,{prefix:\"\",cLetter:\"c\"});else{for(var p=0;p<h[2].length;p++)h[2][p]();delete e._colorAxes[f]}}}},{\"../../lib\":799,\"../../plot_api/plot_template\":838,\"./defaults\":672,\"./layout_attributes\":675}],677:[function(t,e,r){\"use strict\";var n=t(\"tinycolor2\"),i={Greys:[[0,\"rgb(0,0,0)\"],[1,\"rgb(255,255,255)\"]],YlGnBu:[[0,\"rgb(8,29,88)\"],[.125,\"rgb(37,52,148)\"],[.25,\"rgb(34,94,168)\"],[.375,\"rgb(29,145,192)\"],[.5,\"rgb(65,182,196)\"],[.625,\"rgb(127,205,187)\"],[.75,\"rgb(199,233,180)\"],[.875,\"rgb(237,248,217)\"],[1,\"rgb(255,255,217)\"]],Greens:[[0,\"rgb(0,68,27)\"],[.125,\"rgb(0,109,44)\"],[.25,\"rgb(35,139,69)\"],[.375,\"rgb(65,171,93)\"],[.5,\"rgb(116,196,118)\"],[.625,\"rgb(161,217,155)\"],[.75,\"rgb(199,233,192)\"],[.875,\"rgb(229,245,224)\"],[1,\"rgb(247,252,245)\"]],YlOrRd:[[0,\"rgb(128,0,38)\"],[.125,\"rgb(189,0,38)\"],[.25,\"rgb(227,26,28)\"],[.375,\"rgb(252,78,42)\"],[.5,\"rgb(253,141,60)\"],[.625,\"rgb(254,178,76)\"],[.75,\"rgb(254,217,118)\"],[.875,\"rgb(255,237,160)\"],[1,\"rgb(255,255,204)\"]],Bluered:[[0,\"rgb(0,0,255)\"],[1,\"rgb(255,0,0)\"]],RdBu:[[0,\"rgb(5,10,172)\"],[.35,\"rgb(106,137,247)\"],[.5,\"rgb(190,190,190)\"],[.6,\"rgb(220,170,132)\"],[.7,\"rgb(230,145,90)\"],[1,\"rgb(178,10,28)\"]],Reds:[[0,\"rgb(220,220,220)\"],[.2,\"rgb(245,195,157)\"],[.4,\"rgb(245,160,105)\"],[1,\"rgb(178,10,28)\"]],Blues:[[0,\"rgb(5,10,172)\"],[.35,\"rgb(40,60,190)\"],[.5,\"rgb(70,100,245)\"],[.6,\"rgb(90,120,245)\"],[.7,\"rgb(106,137,247)\"],[1,\"rgb(220,220,220)\"]],Picnic:[[0,\"rgb(0,0,255)\"],[.1,\"rgb(51,153,255)\"],[.2,\"rgb(102,204,255)\"],[.3,\"rgb(153,204,255)\"],[.4,\"rgb(204,204,255)\"],[.5,\"rgb(255,255,255)\"],[.6,\"rgb(255,204,255)\"],[.7,\"rgb(255,153,255)\"],[.8,\"rgb(255,102,204)\"],[.9,\"rgb(255,102,102)\"],[1,\"rgb(255,0,0)\"]],Rainbow:[[0,\"rgb(150,0,90)\"],[.125,\"rgb(0,0,200)\"],[.25,\"rgb(0,25,255)\"],[.375,\"rgb(0,152,255)\"],[.5,\"rgb(44,255,150)\"],[.625,\"rgb(151,255,0)\"],[.75,\"rgb(255,234,0)\"],[.875,\"rgb(255,111,0)\"],[1,\"rgb(255,0,0)\"]],Portland:[[0,\"rgb(12,51,131)\"],[.25,\"rgb(10,136,186)\"],[.5,\"rgb(242,211,56)\"],[.75,\"rgb(242,143,56)\"],[1,\"rgb(217,30,30)\"]],Jet:[[0,\"rgb(0,0,131)\"],[.125,\"rgb(0,60,170)\"],[.375,\"rgb(5,255,255)\"],[.625,\"rgb(255,255,0)\"],[.875,\"rgb(250,0,0)\"],[1,\"rgb(128,0,0)\"]],Hot:[[0,\"rgb(0,0,0)\"],[.3,\"rgb(230,0,0)\"],[.6,\"rgb(255,210,0)\"],[1,\"rgb(255,255,255)\"]],Blackbody:[[0,\"rgb(0,0,0)\"],[.2,\"rgb(230,0,0)\"],[.4,\"rgb(230,210,0)\"],[.7,\"rgb(255,255,255)\"],[1,\"rgb(160,200,255)\"]],Earth:[[0,\"rgb(0,0,130)\"],[.1,\"rgb(0,180,180)\"],[.2,\"rgb(40,210,40)\"],[.4,\"rgb(230,230,50)\"],[.6,\"rgb(120,70,20)\"],[1,\"rgb(255,255,255)\"]],Electric:[[0,\"rgb(0,0,0)\"],[.15,\"rgb(30,0,100)\"],[.4,\"rgb(120,0,100)\"],[.6,\"rgb(160,90,0)\"],[.8,\"rgb(230,200,0)\"],[1,\"rgb(255,250,220)\"]],Viridis:[[0,\"#440154\"],[.06274509803921569,\"#48186a\"],[.12549019607843137,\"#472d7b\"],[.18823529411764706,\"#424086\"],[.25098039215686274,\"#3b528b\"],[.3137254901960784,\"#33638d\"],[.3764705882352941,\"#2c728e\"],[.4392156862745098,\"#26828e\"],[.5019607843137255,\"#21918c\"],[.5647058823529412,\"#1fa088\"],[.6274509803921569,\"#28ae80\"],[.6901960784313725,\"#3fbc73\"],[.7529411764705882,\"#5ec962\"],[.8156862745098039,\"#84d44b\"],[.8784313725490196,\"#addc30\"],[.9411764705882353,\"#d8e219\"],[1,\"#fde725\"]],Cividis:[[0,\"rgb(0,32,76)\"],[.058824,\"rgb(0,42,102)\"],[.117647,\"rgb(0,52,110)\"],[.176471,\"rgb(39,63,108)\"],[.235294,\"rgb(60,74,107)\"],[.294118,\"rgb(76,85,107)\"],[.352941,\"rgb(91,95,109)\"],[.411765,\"rgb(104,106,112)\"],[.470588,\"rgb(117,117,117)\"],[.529412,\"rgb(131,129,120)\"],[.588235,\"rgb(146,140,120)\"],[.647059,\"rgb(161,152,118)\"],[.705882,\"rgb(176,165,114)\"],[.764706,\"rgb(192,177,109)\"],[.823529,\"rgb(209,191,102)\"],[.882353,\"rgb(225,204,92)\"],[.941176,\"rgb(243,219,79)\"],[1,\"rgb(255,233,69)\"]]},a=i.RdBu;function o(t){var e=0;if(!Array.isArray(t)||t.length<2)return!1;if(!t[0]||!t[t.length-1])return!1;if(0!=+t[0][0]||1!=+t[t.length-1][0])return!1;for(var r=0;r<t.length;r++){var i=t[r];if(2!==i.length||+i[0]<e||!n(i[1]).isValid())return!1;e=+i[0]}return!0}e.exports={scales:i,defaultScale:a,get:function(t,e){if(e||(e=a),!t)return e;function r(){try{t=i[t]||JSON.parse(t)}catch(r){t=e}}return\"string\"==typeof t&&(r(),\"string\"==typeof t&&r()),o(t)?t:e},isValid:function(t){return void 0!==i[t]||o(t)}}},{tinycolor2:594}],678:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,i){var a=(t-r)/(n-r),o=a+e/(n-r),s=(a+o)/2;return\"left\"===i||\"bottom\"===i?a:\"center\"===i||\"middle\"===i?s:\"right\"===i||\"top\"===i?o:a<2/3-s?a:o>4/3-s?o:s}},{}],679:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=[[\"sw-resize\",\"s-resize\",\"se-resize\"],[\"w-resize\",\"move\",\"e-resize\"],[\"nw-resize\",\"n-resize\",\"ne-resize\"]];e.exports=function(t,e,r,a){return t=\"left\"===r?0:\"center\"===r?1:\"right\"===r?2:n.constrain(Math.floor(3*t),0,2),e=\"bottom\"===a?0:\"middle\"===a?1:\"top\"===a?2:n.constrain(Math.floor(3*e),0,2),i[e][t]}},{\"../../lib\":799}],680:[function(t,e,r){\"use strict\";r.selectMode=function(t){return\"lasso\"===t||\"select\"===t},r.drawMode=function(t){return\"drawclosedpath\"===t||\"drawopenpath\"===t||\"drawline\"===t||\"drawrect\"===t||\"drawcircle\"===t},r.openMode=function(t){return\"drawline\"===t||\"drawopenpath\"===t},r.rectMode=function(t){return\"select\"===t||\"drawline\"===t||\"drawrect\"===t||\"drawcircle\"===t},r.freeMode=function(t){return\"lasso\"===t||\"drawclosedpath\"===t||\"drawopenpath\"===t},r.selectingOrDrawing=function(t){return r.freeMode(t)||r.rectMode(t)}},{}],681:[function(t,e,r){\"use strict\";var n=t(\"mouse-event-offset\"),i=t(\"has-hover\"),a=t(\"has-passive-events\"),o=t(\"../../lib\").removeElement,s=t(\"../../plots/cartesian/constants\"),l=e.exports={};l.align=t(\"./align\"),l.getCursor=t(\"./cursor\");var c=t(\"./unhover\");function u(){var t=document.createElement(\"div\");t.className=\"dragcover\";var e=t.style;return e.position=\"fixed\",e.left=0,e.right=0,e.top=0,e.bottom=0,e.zIndex=999999999,e.background=\"none\",document.body.appendChild(t),t}function f(t){return n(t.changedTouches?t.changedTouches[0]:t,document.body)}l.unhover=c.wrapped,l.unhoverRaw=c.raw,l.init=function(t){var e,r,n,c,h,p,d,m,g=t.gd,v=1,y=g._context.doubleClickDelay,x=t.element;g._mouseDownTime||(g._mouseDownTime=0),x.style.pointerEvents=\"all\",x.onmousedown=_,a?(x._ontouchstart&&x.removeEventListener(\"touchstart\",x._ontouchstart),x._ontouchstart=_,x.addEventListener(\"touchstart\",_,{passive:!1})):x.ontouchstart=_;var b=t.clampFn||function(t,e,r){return Math.abs(t)<r&&(t=0),Math.abs(e)<r&&(e=0),[t,e]};function _(a){g._dragged=!1,g._dragging=!0;var o=f(a);e=o[0],r=o[1],d=a.target,p=a,m=2===a.buttons||a.ctrlKey,void 0===a.clientX&&void 0===a.clientY&&(a.clientX=e,a.clientY=r),(n=(new Date).getTime())-g._mouseDownTime<y?v+=1:(v=1,g._mouseDownTime=n),t.prepFn&&t.prepFn(a,e,r),i&&!m?(h=u()).style.cursor=window.getComputedStyle(x).cursor:i||(h=document,c=window.getComputedStyle(document.documentElement).cursor,document.documentElement.style.cursor=window.getComputedStyle(x).cursor),document.addEventListener(\"mouseup\",T),document.addEventListener(\"touchend\",T),!1!==t.dragmode&&(a.preventDefault(),document.addEventListener(\"mousemove\",w),document.addEventListener(\"touchmove\",w,{passive:!1}))}function w(n){n.preventDefault();var i=f(n),a=t.minDrag||s.MINDRAG,o=b(i[0]-e,i[1]-r,a),c=o[0],u=o[1];(c||u)&&(g._dragged=!0,l.unhover(g,n)),g._dragged&&t.moveFn&&!m&&(g._dragdata={element:x,dx:c,dy:u},t.moveFn(c,u))}function T(e){if(delete g._dragdata,!1!==t.dragmode&&(e.preventDefault(),document.removeEventListener(\"mousemove\",w),document.removeEventListener(\"touchmove\",w)),document.removeEventListener(\"mouseup\",T),document.removeEventListener(\"touchend\",T),i?o(h):c&&(h.documentElement.style.cursor=c,c=null),g._dragging){if(g._dragging=!1,(new Date).getTime()-g._mouseDownTime>y&&(v=Math.max(v-1,1)),g._dragged)t.doneFn&&t.doneFn();else if(t.clickFn&&t.clickFn(v,p),!m){var r;try{r=new MouseEvent(\"click\",e)}catch(t){var n=f(e);(r=document.createEvent(\"MouseEvents\")).initMouseEvent(\"click\",e.bubbles,e.cancelable,e.view,e.detail,e.screenX,e.screenY,n[0],n[1],e.ctrlKey,e.altKey,e.shiftKey,e.metaKey,e.button,e.relatedTarget)}d.dispatchEvent(r)}g._dragging=!1,g._dragged=!1}else g._dragged=!1}},l.coverSlip=u},{\"../../lib\":799,\"../../plots/cartesian/constants\":856,\"./align\":678,\"./cursor\":679,\"./unhover\":682,\"has-hover\":439,\"has-passive-events\":440,\"mouse-event-offset\":467}],682:[function(t,e,r){\"use strict\";var n=t(\"../../lib/events\"),i=t(\"../../lib/throttle\"),a=t(\"../../lib/dom\").getGraphDiv,o=t(\"../fx/constants\"),s=e.exports={};s.wrapped=function(t,e,r){(t=a(t))._fullLayout&&i.clear(t._fullLayout._uid+o.HOVERID),s.raw(t,e,r)},s.raw=function(t,e){var r=t._fullLayout,i=t._hoverdata;e||(e={}),e.target&&!t._dragged&&!1===n.triggerHandler(t,\"plotly_beforehover\",e)||(r._hoverlayer.selectAll(\"g\").remove(),r._hoverlayer.selectAll(\"line\").remove(),r._hoverlayer.selectAll(\"circle\").remove(),t._hoverdata=void 0,e.target&&i&&t.emit(\"plotly_unhover\",{event:e,points:i}))}},{\"../../lib/dom\":787,\"../../lib/events\":788,\"../../lib/throttle\":825,\"../fx/constants\":696}],683:[function(t,e,r){\"use strict\";r.dash={valType:\"string\",values:[\"solid\",\"dot\",\"dash\",\"longdash\",\"dashdot\",\"longdashdot\"],dflt:\"solid\",editType:\"style\"},r.pattern={shape:{valType:\"enumerated\",values:[\"\",\"/\",\"\\\\\",\"x\",\"-\",\"|\",\"+\",\".\"],dflt:\"\",arrayOk:!0,editType:\"style\"},fillmode:{valType:\"enumerated\",values:[\"replace\",\"overlay\"],dflt:\"replace\",editType:\"style\"},bgcolor:{valType:\"color\",arrayOk:!0,editType:\"style\"},fgcolor:{valType:\"color\",arrayOk:!0,editType:\"style\"},fgopacity:{valType:\"number\",editType:\"style\",min:0,max:1},size:{valType:\"number\",min:0,dflt:8,arrayOk:!0,editType:\"style\"},solidity:{valType:\"number\",min:0,max:1,dflt:.3,arrayOk:!0,editType:\"style\"},editType:\"style\"}},{}],684:[function(t,e,r){\"use strict\";var n=t(\"@plotly/d3\"),i=t(\"fast-isnumeric\"),a=t(\"tinycolor2\"),o=t(\"../../registry\"),s=t(\"../color\"),l=t(\"../colorscale\"),c=t(\"../../lib\"),u=c.strTranslate,f=t(\"../../lib/svg_text_utils\"),h=t(\"../../constants/xmlns_namespaces\"),p=t(\"../../constants/alignment\").LINE_SPACING,d=t(\"../../constants/interactions\").DESELECTDIM,m=t(\"../../traces/scatter/subtypes\"),g=t(\"../../traces/scatter/make_bubble_size_func\"),v=t(\"../../components/fx/helpers\").appendArrayPointValue,y=e.exports={};y.font=function(t,e,r,n){c.isPlainObject(e)&&(n=e.color,r=e.size,e=e.family),e&&t.style(\"font-family\",e),r+1&&t.style(\"font-size\",r+\"px\"),n&&t.call(s.fill,n)},y.setPosition=function(t,e,r){t.attr(\"x\",e).attr(\"y\",r)},y.setSize=function(t,e,r){t.attr(\"width\",e).attr(\"height\",r)},y.setRect=function(t,e,r,n,i){t.call(y.setPosition,e,r).call(y.setSize,n,i)},y.translatePoint=function(t,e,r,n){var a=r.c2p(t.x),o=n.c2p(t.y);return!!(i(a)&&i(o)&&e.node())&&(\"text\"===e.node().nodeName?e.attr(\"x\",a).attr(\"y\",o):e.attr(\"transform\",u(a,o)),!0)},y.translatePoints=function(t,e,r){t.each((function(t){var i=n.select(this);y.translatePoint(t,i,e,r)}))},y.hideOutsideRangePoint=function(t,e,r,n,i,a){e.attr(\"display\",r.isPtWithinRange(t,i)&&n.isPtWithinRange(t,a)?null:\"none\")},y.hideOutsideRangePoints=function(t,e){if(e._hasClipOnAxisFalse){var r=e.xaxis,i=e.yaxis;t.each((function(e){var a=e[0].trace,s=a.xcalendar,l=a.ycalendar,c=o.traceIs(a,\"bar-like\")?\".bartext\":\".point,.textpoint\";t.selectAll(c).each((function(t){y.hideOutsideRangePoint(t,n.select(this),r,i,s,l)}))}))}},y.crispRound=function(t,e,r){return e&&i(e)?t._context.staticPlot?e:e<1?1:Math.round(e):r||0},y.singleLineStyle=function(t,e,r,n,i){e.style(\"fill\",\"none\");var a=(((t||[])[0]||{}).trace||{}).line||{},o=r||a.width||0,l=i||a.dash||\"\";s.stroke(e,n||a.color),y.dashLine(e,l,o)},y.lineGroupStyle=function(t,e,r,i){t.style(\"fill\",\"none\").each((function(t){var a=(((t||[])[0]||{}).trace||{}).line||{},o=e||a.width||0,l=i||a.dash||\"\";n.select(this).call(s.stroke,r||a.color).call(y.dashLine,l,o)}))},y.dashLine=function(t,e,r){r=+r||0,e=y.dashStyle(e,r),t.style({\"stroke-dasharray\":e,\"stroke-width\":r+\"px\"})},y.dashStyle=function(t,e){e=+e||1;var r=Math.max(e,3);return\"solid\"===t?t=\"\":\"dot\"===t?t=r+\"px,\"+r+\"px\":\"dash\"===t?t=3*r+\"px,\"+3*r+\"px\":\"longdash\"===t?t=5*r+\"px,\"+5*r+\"px\":\"dashdot\"===t?t=3*r+\"px,\"+r+\"px,\"+r+\"px,\"+r+\"px\":\"longdashdot\"===t&&(t=5*r+\"px,\"+2*r+\"px,\"+r+\"px,\"+2*r+\"px\"),t},y.singleFillStyle=function(t){var e=(((n.select(t.node()).data()[0]||[])[0]||{}).trace||{}).fillcolor;e&&t.call(s.fill,e)},y.fillGroupStyle=function(t){t.style(\"stroke-width\",0).each((function(t){var e=n.select(this);t[0].trace&&e.call(s.fill,t[0].trace.fillcolor)}))};var x=t(\"./symbol_defs\");y.symbolNames=[],y.symbolFuncs=[],y.symbolNeedLines={},y.symbolNoDot={},y.symbolNoFill={},y.symbolList=[],Object.keys(x).forEach((function(t){var e=x[t],r=e.n;y.symbolList.push(r,String(r),t,r+100,String(r+100),t+\"-open\"),y.symbolNames[r]=t,y.symbolFuncs[r]=e.f,e.needLine&&(y.symbolNeedLines[r]=!0),e.noDot?y.symbolNoDot[r]=!0:y.symbolList.push(r+200,String(r+200),t+\"-dot\",r+300,String(r+300),t+\"-open-dot\"),e.noFill&&(y.symbolNoFill[r]=!0)}));var b=y.symbolNames.length;function _(t,e){var r=t%100;return y.symbolFuncs[r](e)+(t>=200?\"M0,0.5L0.5,0L0,-0.5L-0.5,0Z\":\"\")}y.symbolNumber=function(t){if(i(t))t=+t;else if(\"string\"==typeof t){var e=0;t.indexOf(\"-open\")>0&&(e=100,t=t.replace(\"-open\",\"\")),t.indexOf(\"-dot\")>0&&(e+=200,t=t.replace(\"-dot\",\"\")),(t=y.symbolNames.indexOf(t))>=0&&(t+=e)}return t%100>=b||t>=400?0:Math.floor(Math.max(t,0))};var w={x1:1,x2:0,y1:0,y2:0},T={x1:0,x2:0,y1:1,y2:0},k=n.format(\"~.1f\"),M={radial:{node:\"radialGradient\"},radialreversed:{node:\"radialGradient\",reversed:!0},horizontal:{node:\"linearGradient\",attrs:w},horizontalreversed:{node:\"linearGradient\",attrs:w,reversed:!0},vertical:{node:\"linearGradient\",attrs:T},verticalreversed:{node:\"linearGradient\",attrs:T,reversed:!0}};y.gradient=function(t,e,r,i,o,l){for(var u=o.length,f=M[i],h=new Array(u),p=0;p<u;p++)f.reversed?h[u-1-p]=[k(100*(1-o[p][0])),o[p][1]]:h[p]=[k(100*o[p][0]),o[p][1]];var d=e._fullLayout,m=\"g\"+d._uid+\"-\"+r,g=d._defs.select(\".gradients\").selectAll(\"#\"+m).data([i+h.join(\";\")],c.identity);g.exit().remove(),g.enter().append(f.node).each((function(){var t=n.select(this);f.attrs&&t.attr(f.attrs),t.attr(\"id\",m);var e=t.selectAll(\"stop\").data(h);e.exit().remove(),e.enter().append(\"stop\"),e.each((function(t){var e=a(t[1]);n.select(this).attr({offset:t[0]+\"%\",\"stop-color\":s.tinyRGB(e),\"stop-opacity\":e.getAlpha()})}))})),t.style(l,z(m,e)).style(l+\"-opacity\",null);var v=function(t){return\".\"+t.attr(\"class\").replace(/\\s/g,\".\")},y=v(n.select(t.node().parentNode))+\">\"+v(t);d._gradientUrlQueryParts[y]=1},y.pattern=function(t,e,r,i,a,o,l,u,f,h,p,d){var m=\"legend\"===e;u&&(\"overlay\"===f?(h=u,p=s.contrast(h)):(h=void 0,p=u));var g,v,y,x,b,_,w,T,k,M,A,S=r._fullLayout,E=\"p\"+S._uid+\"-\"+i,L={};switch(a){case\"/\":g=o*Math.sqrt(2),v=o*Math.sqrt(2),_=\"path\",L={d:y=\"M-\"+g/4+\",\"+v/4+\"l\"+g/2+\",-\"+v/2+\"M0,\"+v+\"L\"+g+\",0M\"+g/4*3+\",\"+v/4*5+\"l\"+g/2+\",-\"+v/2,opacity:d,stroke:p,\"stroke-width\":(x=l*o)+\"px\"};break;case\"\\\\\":g=o*Math.sqrt(2),v=o*Math.sqrt(2),_=\"path\",L={d:y=\"M\"+g/4*3+\",-\"+v/4+\"l\"+g/2+\",\"+v/2+\"M0,0L\"+g+\",\"+v+\"M-\"+g/4+\",\"+v/4*3+\"l\"+g/2+\",\"+v/2,opacity:d,stroke:p,\"stroke-width\":(x=l*o)+\"px\"};break;case\"x\":g=o*Math.sqrt(2),v=o*Math.sqrt(2),y=\"M-\"+g/4+\",\"+v/4+\"l\"+g/2+\",-\"+v/2+\"M0,\"+v+\"L\"+g+\",0M\"+g/4*3+\",\"+v/4*5+\"l\"+g/2+\",-\"+v/2+\"M\"+g/4*3+\",-\"+v/4+\"l\"+g/2+\",\"+v/2+\"M0,0L\"+g+\",\"+v+\"M-\"+g/4+\",\"+v/4*3+\"l\"+g/2+\",\"+v/2,x=o-o*Math.sqrt(1-l),_=\"path\",L={d:y,opacity:d,stroke:p,\"stroke-width\":x+\"px\"};break;case\"|\":_=\"path\",_=\"path\",L={d:y=\"M\"+(g=o)/2+\",0L\"+g/2+\",\"+(v=o),opacity:d,stroke:p,\"stroke-width\":(x=l*o)+\"px\"};break;case\"-\":_=\"path\",_=\"path\",L={d:y=\"M0,\"+(v=o)/2+\"L\"+(g=o)+\",\"+v/2,opacity:d,stroke:p,\"stroke-width\":(x=l*o)+\"px\"};break;case\"+\":_=\"path\",y=\"M\"+(g=o)/2+\",0L\"+g/2+\",\"+(v=o)+\"M0,\"+v/2+\"L\"+g+\",\"+v/2,x=o-o*Math.sqrt(1-l),_=\"path\",L={d:y,opacity:d,stroke:p,\"stroke-width\":x+\"px\"};break;case\".\":g=o,v=o,l<Math.PI/4?b=Math.sqrt(l*o*o/Math.PI):(w=l,T=Math.PI/4,k=1,M=o/2,A=o/Math.sqrt(2),b=M+(A-M)*(w-T)/(k-T)),_=\"circle\",L={cx:g/2,cy:v/2,r:b,opacity:d,fill:p}}var C=[a||\"noSh\",h||\"noBg\",p||\"noFg\",o,l].join(\";\"),P=S._defs.select(\".patterns\").selectAll(\"#\"+E).data([C],c.identity);P.exit().remove(),P.enter().append(\"pattern\").each((function(){var t=n.select(this);if(t.attr({id:E,width:g+\"px\",height:v+\"px\",patternUnits:\"userSpaceOnUse\",patternTransform:m?\"scale(0.8)\":\"\"}),h){var e=t.selectAll(\"rect\").data([0]);e.exit().remove(),e.enter().append(\"rect\").attr({width:g+\"px\",height:v+\"px\",fill:h})}var r=t.selectAll(_).data([0]);r.exit().remove(),r.enter().append(_).attr(L)})),t.style(\"fill\",z(E,r)).style(\"fill-opacity\",null),t.classed(\"pattern_filled\",!0);var I=\".\"+n.select(t.node().parentNode).attr(\"class\").replace(/\\s/g,\".\")+\">.pattern_filled\";S._patternUrlQueryParts[I]=1},y.initGradients=function(t){var e=t._fullLayout;c.ensureSingle(e._defs,\"g\",\"gradients\").selectAll(\"linearGradient,radialGradient\").remove(),e._gradientUrlQueryParts={}},y.initPatterns=function(t){var e=t._fullLayout;c.ensureSingle(e._defs,\"g\",\"patterns\").selectAll(\"pattern\").remove(),e._patternUrlQueryParts={}},y.getPatternAttr=function(t,e,r){return t&&c.isArrayOrTypedArray(t)?e<t.length?t[e]:r:t},y.pointStyle=function(t,e,r){if(t.size()){var i=y.makePointStyleFns(e);t.each((function(t){y.singlePointStyle(t,n.select(this),e,i,r)}))}},y.singlePointStyle=function(t,e,r,n,i){var a=r.marker,o=a.line;if(e.style(\"opacity\",n.selectedOpacityFn?n.selectedOpacityFn(t):void 0===t.mo?a.opacity:t.mo),n.ms2mrc){var l;l=\"various\"===t.ms||\"various\"===a.size?3:n.ms2mrc(t.ms),t.mrc=l,n.selectedSizeFn&&(l=t.mrc=n.selectedSizeFn(t));var u=y.symbolNumber(t.mx||a.symbol)||0;t.om=u%200>=100,e.attr(\"d\",_(u,l))}var f,h,p,d=!1;if(t.so)p=o.outlierwidth,h=o.outliercolor,f=a.outliercolor;else{var m=(o||{}).width;p=(t.mlw+1||m+1||(t.trace?(t.trace.marker.line||{}).width:0)+1)-1||0,h=\"mlc\"in t?t.mlcc=n.lineScale(t.mlc):c.isArrayOrTypedArray(o.color)?s.defaultLine:o.color,c.isArrayOrTypedArray(a.color)&&(f=s.defaultLine,d=!0),f=\"mc\"in t?t.mcc=n.markerScale(t.mc):a.color||\"rgba(0,0,0,0)\",n.selectedColorFn&&(f=n.selectedColorFn(t))}if(t.om)e.call(s.stroke,f).style({\"stroke-width\":(p||1)+\"px\",fill:\"none\"});else{e.style(\"stroke-width\",(t.isBlank?0:p)+\"px\");var g=a.gradient,v=t.mgt;v?d=!0:v=g&&g.type,c.isArrayOrTypedArray(v)&&(v=v[0],M[v]||(v=0));var x=a.pattern,b=x&&y.getPatternAttr(x.shape,t.i,\"\");if(v&&\"none\"!==v){var w=t.mgc;w?d=!0:w=g.color;var T=r.uid;d&&(T+=\"-\"+t.i),y.gradient(e,i,T,v,[[0,w],[1,f]],\"fill\")}else if(b){var k=y.getPatternAttr(x.bgcolor,t.i,null),A=y.getPatternAttr(x.fgcolor,t.i,null),S=x.fgopacity,E=y.getPatternAttr(x.size,t.i,8),L=y.getPatternAttr(x.solidity,t.i,.3),C=t.mcc||c.isArrayOrTypedArray(x.shape)||c.isArrayOrTypedArray(x.bgcolor)||c.isArrayOrTypedArray(x.size)||c.isArrayOrTypedArray(x.solidity),P=r.uid;C&&(P+=\"-\"+t.i),y.pattern(e,\"point\",i,P,b,E,L,t.mcc,x.fillmode,k,A,S)}else s.fill(e,f);p&&s.stroke(e,h)}},y.makePointStyleFns=function(t){var e={},r=t.marker;return e.markerScale=y.tryColorscale(r,\"\"),e.lineScale=y.tryColorscale(r,\"line\"),o.traceIs(t,\"symbols\")&&(e.ms2mrc=m.isBubble(t)?g(t):function(){return(r.size||6)/2}),t.selectedpoints&&c.extendFlat(e,y.makeSelectedPointStyleFns(t)),e},y.makeSelectedPointStyleFns=function(t){var e={},r=t.selected||{},n=t.unselected||{},i=t.marker||{},a=r.marker||{},s=n.marker||{},l=i.opacity,u=a.opacity,f=s.opacity,h=void 0!==u,p=void 0!==f;(c.isArrayOrTypedArray(l)||h||p)&&(e.selectedOpacityFn=function(t){var e=void 0===t.mo?i.opacity:t.mo;return t.selected?h?u:e:p?f:d*e});var m=i.color,g=a.color,v=s.color;(g||v)&&(e.selectedColorFn=function(t){var e=t.mcc||m;return t.selected?g||e:v||e});var y=i.size,x=a.size,b=s.size,_=void 0!==x,w=void 0!==b;return o.traceIs(t,\"symbols\")&&(_||w)&&(e.selectedSizeFn=function(t){var e=t.mrc||y/2;return t.selected?_?x/2:e:w?b/2:e}),e},y.makeSelectedTextStyleFns=function(t){var e={},r=t.selected||{},n=t.unselected||{},i=t.textfont||{},a=r.textfont||{},o=n.textfont||{},l=i.color,c=a.color,u=o.color;return e.selectedTextColorFn=function(t){var e=t.tc||l;return t.selected?c||e:u||(c?e:s.addOpacity(e,d))},e},y.selectedPointStyle=function(t,e){if(t.size()&&e.selectedpoints){var r=y.makeSelectedPointStyleFns(e),i=e.marker||{},a=[];r.selectedOpacityFn&&a.push((function(t,e){t.style(\"opacity\",r.selectedOpacityFn(e))})),r.selectedColorFn&&a.push((function(t,e){s.fill(t,r.selectedColorFn(e))})),r.selectedSizeFn&&a.push((function(t,e){var n=e.mx||i.symbol||0,a=r.selectedSizeFn(e);t.attr(\"d\",_(y.symbolNumber(n),a)),e.mrc2=a})),a.length&&t.each((function(t){for(var e=n.select(this),r=0;r<a.length;r++)a[r](e,t)}))}},y.tryColorscale=function(t,e){var r=e?c.nestedProperty(t,e).get():t;if(r){var n=r.color;if((r.colorscale||r._colorAx)&&c.isArrayOrTypedArray(n))return l.makeColorScaleFuncFromTrace(r)}return c.identity};var A={start:1,end:-1,middle:0,bottom:1,top:-1};function S(t,e,r,i){var a=n.select(t.node().parentNode),o=-1!==e.indexOf(\"top\")?\"top\":-1!==e.indexOf(\"bottom\")?\"bottom\":\"middle\",s=-1!==e.indexOf(\"left\")?\"end\":-1!==e.indexOf(\"right\")?\"start\":\"middle\",l=i?i/.8+1:0,c=(f.lineCount(t)-1)*p+1,h=A[s]*l,d=.75*r+A[o]*l+(A[o]-1)*c*r/2;t.attr(\"text-anchor\",s),a.attr(\"transform\",u(h,d))}function E(t,e){var r=t.ts||e.textfont.size;return i(r)&&r>0?r:0}y.textPointStyle=function(t,e,r){if(t.size()){var i;if(e.selectedpoints){var a=y.makeSelectedTextStyleFns(e);i=a.selectedTextColorFn}var o=e.texttemplate,s=r._fullLayout;t.each((function(t){var a=n.select(this),l=o?c.extractOption(t,e,\"txt\",\"texttemplate\"):c.extractOption(t,e,\"tx\",\"text\");if(l||0===l){if(o){var u=e._module.formatLabels,h=u?u(t,e,s):{},p={};v(p,e,t.i);var d=e._meta||{};l=c.texttemplateString(l,h,s._d3locale,p,t,d)}var m=t.tp||e.textposition,g=E(t,e),x=i?i(t):t.tc||e.textfont.color;a.call(y.font,t.tf||e.textfont.family,g,x).text(l).call(f.convertToTspans,r).call(S,m,g,t.mrc)}else a.remove()}))}},y.selectedTextStyle=function(t,e){if(t.size()&&e.selectedpoints){var r=y.makeSelectedTextStyleFns(e);t.each((function(t){var i=n.select(this),a=r.selectedTextColorFn(t),o=t.tp||e.textposition,l=E(t,e);s.fill(i,a),S(i,o,l,t.mrc2||t.mrc)}))}};function L(t,e,r,i){var a=t[0]-e[0],o=t[1]-e[1],s=r[0]-e[0],l=r[1]-e[1],c=Math.pow(a*a+o*o,.25),u=Math.pow(s*s+l*l,.25),f=(u*u*a-c*c*s)*i,h=(u*u*o-c*c*l)*i,p=3*u*(c+u),d=3*c*(c+u);return[[n.round(e[0]+(p&&f/p),2),n.round(e[1]+(p&&h/p),2)],[n.round(e[0]-(d&&f/d),2),n.round(e[1]-(d&&h/d),2)]]}y.smoothopen=function(t,e){if(t.length<3)return\"M\"+t.join(\"L\");var r,n=\"M\"+t[0],i=[];for(r=1;r<t.length-1;r++)i.push(L(t[r-1],t[r],t[r+1],e));for(n+=\"Q\"+i[0][0]+\" \"+t[1],r=2;r<t.length-1;r++)n+=\"C\"+i[r-2][1]+\" \"+i[r-1][0]+\" \"+t[r];return n+=\"Q\"+i[t.length-3][1]+\" \"+t[t.length-1]},y.smoothclosed=function(t,e){if(t.length<3)return\"M\"+t.join(\"L\")+\"Z\";var r,n=\"M\"+t[0],i=t.length-1,a=[L(t[i],t[0],t[1],e)];for(r=1;r<i;r++)a.push(L(t[r-1],t[r],t[r+1],e));for(a.push(L(t[i-1],t[i],t[0],e)),r=1;r<=i;r++)n+=\"C\"+a[r-1][1]+\" \"+a[r][0]+\" \"+t[r];return n+=\"C\"+a[i][1]+\" \"+a[0][0]+\" \"+t[0]+\"Z\"};var C={hv:function(t,e){return\"H\"+n.round(e[0],2)+\"V\"+n.round(e[1],2)},vh:function(t,e){return\"V\"+n.round(e[1],2)+\"H\"+n.round(e[0],2)},hvh:function(t,e){return\"H\"+n.round((t[0]+e[0])/2,2)+\"V\"+n.round(e[1],2)+\"H\"+n.round(e[0],2)},vhv:function(t,e){return\"V\"+n.round((t[1]+e[1])/2,2)+\"H\"+n.round(e[0],2)+\"V\"+n.round(e[1],2)}},P=function(t,e){return\"L\"+n.round(e[0],2)+\",\"+n.round(e[1],2)};y.steps=function(t){var e=C[t]||P;return function(t){for(var r=\"M\"+n.round(t[0][0],2)+\",\"+n.round(t[0][1],2),i=1;i<t.length;i++)r+=e(t[i-1],t[i]);return r}},y.makeTester=function(){var t=c.ensureSingleById(n.select(\"body\"),\"svg\",\"js-plotly-tester\",(function(t){t.attr(h.svgAttrs).style({position:\"absolute\",left:\"-10000px\",top:\"-10000px\",width:\"9000px\",height:\"9000px\",\"z-index\":\"1\"})})),e=c.ensureSingle(t,\"path\",\"js-reference-point\",(function(t){t.attr(\"d\",\"M0,0H1V1H0Z\").style({\"stroke-width\":0,fill:\"black\"})}));y.tester=t,y.testref=e},y.savedBBoxes={};var I=0;function O(t){var e=t.getAttribute(\"data-unformatted\");if(null!==e)return e+t.getAttribute(\"data-math\")+t.getAttribute(\"text-anchor\")+t.getAttribute(\"style\")}function z(t,e){if(!t)return null;var r=e._context,n=r._exportedPlot?\"\":r._baseUrl||\"\";return n?\"url('\"+n+\"#\"+t+\"')\":\"url(#\"+t+\")\"}y.bBox=function(t,e,r){var i,a,o;if(r||(r=O(t)),r){if(i=y.savedBBoxes[r])return c.extendFlat({},i)}else if(1===t.childNodes.length){var s=t.childNodes[0];if(r=O(s)){var l=+s.getAttribute(\"x\")||0,u=+s.getAttribute(\"y\")||0,h=s.getAttribute(\"transform\");if(!h){var p=y.bBox(s,!1,r);return l&&(p.left+=l,p.right+=l),u&&(p.top+=u,p.bottom+=u),p}if(r+=\"~\"+l+\"~\"+u+\"~\"+h,i=y.savedBBoxes[r])return c.extendFlat({},i)}}e?a=t:(o=y.tester.node(),a=t.cloneNode(!0),o.appendChild(a)),n.select(a).attr(\"transform\",null).call(f.positionText,0,0);var d=a.getBoundingClientRect(),m=y.testref.node().getBoundingClientRect();e||o.removeChild(a);var g={height:d.height,width:d.width,left:d.left-m.left,top:d.top-m.top,right:d.right-m.left,bottom:d.bottom-m.top};return I>=1e4&&(y.savedBBoxes={},I=0),r&&(y.savedBBoxes[r]=g),I++,c.extendFlat({},g)},y.setClipUrl=function(t,e,r){t.attr(\"clip-path\",z(e,r))},y.getTranslate=function(t){var e=(t[t.attr?\"attr\":\"getAttribute\"](\"transform\")||\"\").replace(/.*\\btranslate\\((-?\\d*\\.?\\d*)[^-\\d]*(-?\\d*\\.?\\d*)[^\\d].*/,(function(t,e,r){return[e,r].join(\" \")})).split(\" \");return{x:+e[0]||0,y:+e[1]||0}},y.setTranslate=function(t,e,r){var n=t.attr?\"attr\":\"getAttribute\",i=t.attr?\"attr\":\"setAttribute\",a=t[n](\"transform\")||\"\";return e=e||0,r=r||0,a=a.replace(/(\\btranslate\\(.*?\\);?)/,\"\").trim(),a=(a+=u(e,r)).trim(),t[i](\"transform\",a),a},y.getScale=function(t){var e=(t[t.attr?\"attr\":\"getAttribute\"](\"transform\")||\"\").replace(/.*\\bscale\\((\\d*\\.?\\d*)[^\\d]*(\\d*\\.?\\d*)[^\\d].*/,(function(t,e,r){return[e,r].join(\" \")})).split(\" \");return{x:+e[0]||1,y:+e[1]||1}},y.setScale=function(t,e,r){var n=t.attr?\"attr\":\"getAttribute\",i=t.attr?\"attr\":\"setAttribute\",a=t[n](\"transform\")||\"\";return e=e||1,r=r||1,a=a.replace(/(\\bscale\\(.*?\\);?)/,\"\").trim(),a=(a+=\"scale(\"+e+\",\"+r+\")\").trim(),t[i](\"transform\",a),a};var D=/\\s*sc.*/;y.setPointGroupScale=function(t,e,r){if(e=e||1,r=r||1,t){var n=1===e&&1===r?\"\":\"scale(\"+e+\",\"+r+\")\";t.each((function(){var t=(this.getAttribute(\"transform\")||\"\").replace(D,\"\");t=(t+=n).trim(),this.setAttribute(\"transform\",t)}))}};var R=/translate\\([^)]*\\)\\s*$/;y.setTextPointsScale=function(t,e,r){t&&t.each((function(){var t,i=n.select(this),a=i.select(\"text\");if(a.node()){var o=parseFloat(a.attr(\"x\")||0),s=parseFloat(a.attr(\"y\")||0),l=(i.attr(\"transform\")||\"\").match(R);t=1===e&&1===r?[]:[u(o,s),\"scale(\"+e+\",\"+r+\")\",u(-o,-s)],l&&t.push(l),i.attr(\"transform\",t.join(\"\"))}}))}},{\"../../components/fx/helpers\":698,\"../../constants/alignment\":767,\"../../constants/interactions\":774,\"../../constants/xmlns_namespaces\":776,\"../../lib\":799,\"../../lib/svg_text_utils\":824,\"../../registry\":927,\"../../traces/scatter/make_bubble_size_func\":1231,\"../../traces/scatter/subtypes\":1239,\"../color\":662,\"../colorscale\":674,\"./symbol_defs\":685,\"@plotly/d3\":58,\"fast-isnumeric\":245,tinycolor2:594}],685:[function(t,e,r){\"use strict\";var n=t(\"@plotly/d3\");e.exports={circle:{n:0,f:function(t){var e=n.round(t,2);return\"M\"+e+\",0A\"+e+\",\"+e+\" 0 1,1 0,-\"+e+\"A\"+e+\",\"+e+\" 0 0,1 \"+e+\",0Z\"}},square:{n:1,f:function(t){var e=n.round(t,2);return\"M\"+e+\",\"+e+\"H-\"+e+\"V-\"+e+\"H\"+e+\"Z\"}},diamond:{n:2,f:function(t){var e=n.round(1.3*t,2);return\"M\"+e+\",0L0,\"+e+\"L-\"+e+\",0L0,-\"+e+\"Z\"}},cross:{n:3,f:function(t){var e=n.round(.4*t,2),r=n.round(1.2*t,2);return\"M\"+r+\",\"+e+\"H\"+e+\"V\"+r+\"H-\"+e+\"V\"+e+\"H-\"+r+\"V-\"+e+\"H-\"+e+\"V-\"+r+\"H\"+e+\"V-\"+e+\"H\"+r+\"Z\"}},x:{n:4,f:function(t){var e=n.round(.8*t/Math.sqrt(2),2),r=\"l\"+e+\",\"+e,i=\"l\"+e+\",-\"+e,a=\"l-\"+e+\",-\"+e,o=\"l-\"+e+\",\"+e;return\"M0,\"+e+r+i+a+i+a+o+a+o+r+o+r+\"Z\"}},\"triangle-up\":{n:5,f:function(t){var e=n.round(2*t/Math.sqrt(3),2);return\"M-\"+e+\",\"+n.round(t/2,2)+\"H\"+e+\"L0,-\"+n.round(t,2)+\"Z\"}},\"triangle-down\":{n:6,f:function(t){var e=n.round(2*t/Math.sqrt(3),2);return\"M-\"+e+\",-\"+n.round(t/2,2)+\"H\"+e+\"L0,\"+n.round(t,2)+\"Z\"}},\"triangle-left\":{n:7,f:function(t){var e=n.round(2*t/Math.sqrt(3),2);return\"M\"+n.round(t/2,2)+\",-\"+e+\"V\"+e+\"L-\"+n.round(t,2)+\",0Z\"}},\"triangle-right\":{n:8,f:function(t){var e=n.round(2*t/Math.sqrt(3),2);return\"M-\"+n.round(t/2,2)+\",-\"+e+\"V\"+e+\"L\"+n.round(t,2)+\",0Z\"}},\"triangle-ne\":{n:9,f:function(t){var e=n.round(.6*t,2),r=n.round(1.2*t,2);return\"M-\"+r+\",-\"+e+\"H\"+e+\"V\"+r+\"Z\"}},\"triangle-se\":{n:10,f:function(t){var e=n.round(.6*t,2),r=n.round(1.2*t,2);return\"M\"+e+\",-\"+r+\"V\"+e+\"H-\"+r+\"Z\"}},\"triangle-sw\":{n:11,f:function(t){var e=n.round(.6*t,2),r=n.round(1.2*t,2);return\"M\"+r+\",\"+e+\"H-\"+e+\"V-\"+r+\"Z\"}},\"triangle-nw\":{n:12,f:function(t){var e=n.round(.6*t,2),r=n.round(1.2*t,2);return\"M-\"+e+\",\"+r+\"V-\"+e+\"H\"+r+\"Z\"}},pentagon:{n:13,f:function(t){var e=n.round(.951*t,2),r=n.round(.588*t,2),i=n.round(-t,2),a=n.round(-.309*t,2);return\"M\"+e+\",\"+a+\"L\"+r+\",\"+n.round(.809*t,2)+\"H-\"+r+\"L-\"+e+\",\"+a+\"L0,\"+i+\"Z\"}},hexagon:{n:14,f:function(t){var e=n.round(t,2),r=n.round(t/2,2),i=n.round(t*Math.sqrt(3)/2,2);return\"M\"+i+\",-\"+r+\"V\"+r+\"L0,\"+e+\"L-\"+i+\",\"+r+\"V-\"+r+\"L0,-\"+e+\"Z\"}},hexagon2:{n:15,f:function(t){var e=n.round(t,2),r=n.round(t/2,2),i=n.round(t*Math.sqrt(3)/2,2);return\"M-\"+r+\",\"+i+\"H\"+r+\"L\"+e+\",0L\"+r+\",-\"+i+\"H-\"+r+\"L-\"+e+\",0Z\"}},octagon:{n:16,f:function(t){var e=n.round(.924*t,2),r=n.round(.383*t,2);return\"M-\"+r+\",-\"+e+\"H\"+r+\"L\"+e+\",-\"+r+\"V\"+r+\"L\"+r+\",\"+e+\"H-\"+r+\"L-\"+e+\",\"+r+\"V-\"+r+\"Z\"}},star:{n:17,f:function(t){var e=1.4*t,r=n.round(.225*e,2),i=n.round(.951*e,2),a=n.round(.363*e,2),o=n.round(.588*e,2),s=n.round(-e,2),l=n.round(-.309*e,2),c=n.round(.118*e,2),u=n.round(.809*e,2);return\"M\"+r+\",\"+l+\"H\"+i+\"L\"+a+\",\"+c+\"L\"+o+\",\"+u+\"L0,\"+n.round(.382*e,2)+\"L-\"+o+\",\"+u+\"L-\"+a+\",\"+c+\"L-\"+i+\",\"+l+\"H-\"+r+\"L0,\"+s+\"Z\"}},hexagram:{n:18,f:function(t){var e=n.round(.66*t,2),r=n.round(.38*t,2),i=n.round(.76*t,2);return\"M-\"+i+\",0l-\"+r+\",-\"+e+\"h\"+i+\"l\"+r+\",-\"+e+\"l\"+r+\",\"+e+\"h\"+i+\"l-\"+r+\",\"+e+\"l\"+r+\",\"+e+\"h-\"+i+\"l-\"+r+\",\"+e+\"l-\"+r+\",-\"+e+\"h-\"+i+\"Z\"}},\"star-triangle-up\":{n:19,f:function(t){var e=n.round(t*Math.sqrt(3)*.8,2),r=n.round(.8*t,2),i=n.round(1.6*t,2),a=n.round(4*t,2),o=\"A \"+a+\",\"+a+\" 0 0 1 \";return\"M-\"+e+\",\"+r+o+e+\",\"+r+o+\"0,-\"+i+o+\"-\"+e+\",\"+r+\"Z\"}},\"star-triangle-down\":{n:20,f:function(t){var e=n.round(t*Math.sqrt(3)*.8,2),r=n.round(.8*t,2),i=n.round(1.6*t,2),a=n.round(4*t,2),o=\"A \"+a+\",\"+a+\" 0 0 1 \";return\"M\"+e+\",-\"+r+o+\"-\"+e+\",-\"+r+o+\"0,\"+i+o+e+\",-\"+r+\"Z\"}},\"star-square\":{n:21,f:function(t){var e=n.round(1.1*t,2),r=n.round(2*t,2),i=\"A \"+r+\",\"+r+\" 0 0 1 \";return\"M-\"+e+\",-\"+e+i+\"-\"+e+\",\"+e+i+e+\",\"+e+i+e+\",-\"+e+i+\"-\"+e+\",-\"+e+\"Z\"}},\"star-diamond\":{n:22,f:function(t){var e=n.round(1.4*t,2),r=n.round(1.9*t,2),i=\"A \"+r+\",\"+r+\" 0 0 1 \";return\"M-\"+e+\",0\"+i+\"0,\"+e+i+e+\",0\"+i+\"0,-\"+e+i+\"-\"+e+\",0Z\"}},\"diamond-tall\":{n:23,f:function(t){var e=n.round(.7*t,2),r=n.round(1.4*t,2);return\"M0,\"+r+\"L\"+e+\",0L0,-\"+r+\"L-\"+e+\",0Z\"}},\"diamond-wide\":{n:24,f:function(t){var e=n.round(1.4*t,2),r=n.round(.7*t,2);return\"M0,\"+r+\"L\"+e+\",0L0,-\"+r+\"L-\"+e+\",0Z\"}},hourglass:{n:25,f:function(t){var e=n.round(t,2);return\"M\"+e+\",\"+e+\"H-\"+e+\"L\"+e+\",-\"+e+\"H-\"+e+\"Z\"},noDot:!0},bowtie:{n:26,f:function(t){var e=n.round(t,2);return\"M\"+e+\",\"+e+\"V-\"+e+\"L-\"+e+\",\"+e+\"V-\"+e+\"Z\"},noDot:!0},\"circle-cross\":{n:27,f:function(t){var e=n.round(t,2);return\"M0,\"+e+\"V-\"+e+\"M\"+e+\",0H-\"+e+\"M\"+e+\",0A\"+e+\",\"+e+\" 0 1,1 0,-\"+e+\"A\"+e+\",\"+e+\" 0 0,1 \"+e+\",0Z\"},needLine:!0,noDot:!0},\"circle-x\":{n:28,f:function(t){var e=n.round(t,2),r=n.round(t/Math.sqrt(2),2);return\"M\"+r+\",\"+r+\"L-\"+r+\",-\"+r+\"M\"+r+\",-\"+r+\"L-\"+r+\",\"+r+\"M\"+e+\",0A\"+e+\",\"+e+\" 0 1,1 0,-\"+e+\"A\"+e+\",\"+e+\" 0 0,1 \"+e+\",0Z\"},needLine:!0,noDot:!0},\"square-cross\":{n:29,f:function(t){var e=n.round(t,2);return\"M0,\"+e+\"V-\"+e+\"M\"+e+\",0H-\"+e+\"M\"+e+\",\"+e+\"H-\"+e+\"V-\"+e+\"H\"+e+\"Z\"},needLine:!0,noDot:!0},\"square-x\":{n:30,f:function(t){var e=n.round(t,2);return\"M\"+e+\",\"+e+\"L-\"+e+\",-\"+e+\"M\"+e+\",-\"+e+\"L-\"+e+\",\"+e+\"M\"+e+\",\"+e+\"H-\"+e+\"V-\"+e+\"H\"+e+\"Z\"},needLine:!0,noDot:!0},\"diamond-cross\":{n:31,f:function(t){var e=n.round(1.3*t,2);return\"M\"+e+\",0L0,\"+e+\"L-\"+e+\",0L0,-\"+e+\"ZM0,-\"+e+\"V\"+e+\"M-\"+e+\",0H\"+e},needLine:!0,noDot:!0},\"diamond-x\":{n:32,f:function(t){var e=n.round(1.3*t,2),r=n.round(.65*t,2);return\"M\"+e+\",0L0,\"+e+\"L-\"+e+\",0L0,-\"+e+\"ZM-\"+r+\",-\"+r+\"L\"+r+\",\"+r+\"M-\"+r+\",\"+r+\"L\"+r+\",-\"+r},needLine:!0,noDot:!0},\"cross-thin\":{n:33,f:function(t){var e=n.round(1.4*t,2);return\"M0,\"+e+\"V-\"+e+\"M\"+e+\",0H-\"+e},needLine:!0,noDot:!0,noFill:!0},\"x-thin\":{n:34,f:function(t){var e=n.round(t,2);return\"M\"+e+\",\"+e+\"L-\"+e+\",-\"+e+\"M\"+e+\",-\"+e+\"L-\"+e+\",\"+e},needLine:!0,noDot:!0,noFill:!0},asterisk:{n:35,f:function(t){var e=n.round(1.2*t,2),r=n.round(.85*t,2);return\"M0,\"+e+\"V-\"+e+\"M\"+e+\",0H-\"+e+\"M\"+r+\",\"+r+\"L-\"+r+\",-\"+r+\"M\"+r+\",-\"+r+\"L-\"+r+\",\"+r},needLine:!0,noDot:!0,noFill:!0},hash:{n:36,f:function(t){var e=n.round(t/2,2),r=n.round(t,2);return\"M\"+e+\",\"+r+\"V-\"+r+\"m-\"+r+\",0V\"+r+\"M\"+r+\",\"+e+\"H-\"+r+\"m0,-\"+r+\"H\"+r},needLine:!0,noFill:!0},\"y-up\":{n:37,f:function(t){var e=n.round(1.2*t,2),r=n.round(1.6*t,2),i=n.round(.8*t,2);return\"M-\"+e+\",\"+i+\"L0,0M\"+e+\",\"+i+\"L0,0M0,-\"+r+\"L0,0\"},needLine:!0,noDot:!0,noFill:!0},\"y-down\":{n:38,f:function(t){var e=n.round(1.2*t,2),r=n.round(1.6*t,2),i=n.round(.8*t,2);return\"M-\"+e+\",-\"+i+\"L0,0M\"+e+\",-\"+i+\"L0,0M0,\"+r+\"L0,0\"},needLine:!0,noDot:!0,noFill:!0},\"y-left\":{n:39,f:function(t){var e=n.round(1.2*t,2),r=n.round(1.6*t,2),i=n.round(.8*t,2);return\"M\"+i+\",\"+e+\"L0,0M\"+i+\",-\"+e+\"L0,0M-\"+r+\",0L0,0\"},needLine:!0,noDot:!0,noFill:!0},\"y-right\":{n:40,f:function(t){var e=n.round(1.2*t,2),r=n.round(1.6*t,2),i=n.round(.8*t,2);return\"M-\"+i+\",\"+e+\"L0,0M-\"+i+\",-\"+e+\"L0,0M\"+r+\",0L0,0\"},needLine:!0,noDot:!0,noFill:!0},\"line-ew\":{n:41,f:function(t){var e=n.round(1.4*t,2);return\"M\"+e+\",0H-\"+e},needLine:!0,noDot:!0,noFill:!0},\"line-ns\":{n:42,f:function(t){var e=n.round(1.4*t,2);return\"M0,\"+e+\"V-\"+e},needLine:!0,noDot:!0,noFill:!0},\"line-ne\":{n:43,f:function(t){var e=n.round(t,2);return\"M\"+e+\",-\"+e+\"L-\"+e+\",\"+e},needLine:!0,noDot:!0,noFill:!0},\"line-nw\":{n:44,f:function(t){var e=n.round(t,2);return\"M\"+e+\",\"+e+\"L-\"+e+\",-\"+e},needLine:!0,noDot:!0,noFill:!0},\"arrow-up\":{n:45,f:function(t){var e=n.round(t,2);return\"M0,0L-\"+e+\",\"+n.round(2*t,2)+\"H\"+e+\"Z\"},noDot:!0},\"arrow-down\":{n:46,f:function(t){var e=n.round(t,2);return\"M0,0L-\"+e+\",-\"+n.round(2*t,2)+\"H\"+e+\"Z\"},noDot:!0},\"arrow-left\":{n:47,f:function(t){var e=n.round(2*t,2),r=n.round(t,2);return\"M0,0L\"+e+\",-\"+r+\"V\"+r+\"Z\"},noDot:!0},\"arrow-right\":{n:48,f:function(t){var e=n.round(2*t,2),r=n.round(t,2);return\"M0,0L-\"+e+\",-\"+r+\"V\"+r+\"Z\"},noDot:!0},\"arrow-bar-up\":{n:49,f:function(t){var e=n.round(t,2);return\"M-\"+e+\",0H\"+e+\"M0,0L-\"+e+\",\"+n.round(2*t,2)+\"H\"+e+\"Z\"},needLine:!0,noDot:!0},\"arrow-bar-down\":{n:50,f:function(t){var e=n.round(t,2);return\"M-\"+e+\",0H\"+e+\"M0,0L-\"+e+\",-\"+n.round(2*t,2)+\"H\"+e+\"Z\"},needLine:!0,noDot:!0},\"arrow-bar-left\":{n:51,f:function(t){var e=n.round(2*t,2),r=n.round(t,2);return\"M0,-\"+r+\"V\"+r+\"M0,0L\"+e+\",-\"+r+\"V\"+r+\"Z\"},needLine:!0,noDot:!0},\"arrow-bar-right\":{n:52,f:function(t){var e=n.round(2*t,2),r=n.round(t,2);return\"M0,-\"+r+\"V\"+r+\"M0,0L-\"+e+\",-\"+r+\"V\"+r+\"Z\"},needLine:!0,noDot:!0}}},{\"@plotly/d3\":58}],686:[function(t,e,r){\"use strict\";e.exports={visible:{valType:\"boolean\",editType:\"calc\"},type:{valType:\"enumerated\",values:[\"percent\",\"constant\",\"sqrt\",\"data\"],editType:\"calc\"},symmetric:{valType:\"boolean\",editType:\"calc\"},array:{valType:\"data_array\",editType:\"calc\"},arrayminus:{valType:\"data_array\",editType:\"calc\"},value:{valType:\"number\",min:0,dflt:10,editType:\"calc\"},valueminus:{valType:\"number\",min:0,dflt:10,editType:\"calc\"},traceref:{valType:\"integer\",min:0,dflt:0,editType:\"style\"},tracerefminus:{valType:\"integer\",min:0,dflt:0,editType:\"style\"},copy_ystyle:{valType:\"boolean\",editType:\"plot\"},copy_zstyle:{valType:\"boolean\",editType:\"style\"},color:{valType:\"color\",editType:\"style\"},thickness:{valType:\"number\",min:0,dflt:2,editType:\"style\"},width:{valType:\"number\",min:0,editType:\"plot\"},editType:\"calc\",_deprecated:{opacity:{valType:\"number\",editType:\"style\"}}}},{}],687:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../registry\"),a=t(\"../../plots/cartesian/axes\"),o=t(\"../../lib\"),s=t(\"./compute_error\");function l(t,e,r,i){var l=e[\"error_\"+i]||{},c=[];if(l.visible&&-1!==[\"linear\",\"log\"].indexOf(r.type)){for(var u=s(l),f=0;f<t.length;f++){var h=t[f],p=h.i;if(void 0===p)p=f;else if(null===p)continue;var d=h[i];if(n(r.c2l(d))){var m=u(d,p);if(n(m[0])&&n(m[1])){var g=h[i+\"s\"]=d-m[0],v=h[i+\"h\"]=d+m[1];c.push(g,v)}}}var y=r._id,x=e._extremes[y],b=a.findExtremes(r,c,o.extendFlat({tozero:x.opts.tozero},{padded:!0}));x.min=x.min.concat(b.min),x.max=x.max.concat(b.max)}}e.exports=function(t){for(var e=t.calcdata,r=0;r<e.length;r++){var n=e[r],o=n[0].trace;if(!0===o.visible&&i.traceIs(o,\"errorBarsOK\")){var s=a.getFromId(t,o.xaxis),c=a.getFromId(t,o.yaxis);l(n,o,s,\"x\"),l(n,o,c,\"y\")}}}},{\"../../lib\":799,\"../../plots/cartesian/axes\":849,\"../../registry\":927,\"./compute_error\":688,\"fast-isnumeric\":245}],688:[function(t,e,r){\"use strict\";function n(t,e){return\"percent\"===t?function(t){return Math.abs(t*e/100)}:\"constant\"===t?function(){return Math.abs(e)}:\"sqrt\"===t?function(t){return Math.sqrt(Math.abs(t))}:void 0}e.exports=function(t){var e=t.type,r=t.symmetric;if(\"data\"===e){var i=t.array||[];if(r)return function(t,e){var r=+i[e];return[r,r]};var a=t.arrayminus||[];return function(t,e){var r=+i[e],n=+a[e];return isNaN(r)&&isNaN(n)?[NaN,NaN]:[n||0,r||0]}}var o=n(e,t.value),s=n(e,t.valueminus);return r||void 0===t.valueminus?function(t){var e=o(t);return[e,e]}:function(t){return[s(t),o(t)]}}},{}],689:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../registry\"),a=t(\"../../lib\"),o=t(\"../../plot_api/plot_template\"),s=t(\"./attributes\");e.exports=function(t,e,r,l){var c=\"error_\"+l.axis,u=o.newContainer(e,c),f=t[c]||{};function h(t,e){return a.coerce(f,u,s,t,e)}if(!1!==h(\"visible\",void 0!==f.array||void 0!==f.value||\"sqrt\"===f.type)){var p=h(\"type\",\"array\"in f?\"data\":\"percent\"),d=!0;\"sqrt\"!==p&&(d=h(\"symmetric\",!((\"data\"===p?\"arrayminus\":\"valueminus\")in f))),\"data\"===p?(h(\"array\"),h(\"traceref\"),d||(h(\"arrayminus\"),h(\"tracerefminus\"))):\"percent\"!==p&&\"constant\"!==p||(h(\"value\"),d||h(\"valueminus\"));var m=\"copy_\"+l.inherit+\"style\";if(l.inherit)(e[\"error_\"+l.inherit]||{}).visible&&h(m,!(f.color||n(f.thickness)||n(f.width)));l.inherit&&u[m]||(h(\"color\",r),h(\"thickness\"),h(\"width\",i.traceIs(e,\"gl3d\")?0:4))}}},{\"../../lib\":799,\"../../plot_api/plot_template\":838,\"../../registry\":927,\"./attributes\":686,\"fast-isnumeric\":245}],690:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plot_api/edit_types\").overrideAll,a=t(\"./attributes\"),o={error_x:n.extendFlat({},a),error_y:n.extendFlat({},a)};delete o.error_x.copy_zstyle,delete o.error_y.copy_zstyle,delete o.error_y.copy_ystyle;var s={error_x:n.extendFlat({},a),error_y:n.extendFlat({},a),error_z:n.extendFlat({},a)};delete s.error_x.copy_ystyle,delete s.error_y.copy_ystyle,delete s.error_z.copy_ystyle,delete s.error_z.copy_zstyle,e.exports={moduleType:\"component\",name:\"errorbars\",schema:{traces:{scatter:o,bar:o,histogram:o,scatter3d:i(s,\"calc\",\"nested\"),scattergl:i(o,\"calc\",\"nested\")}},supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\"),makeComputeError:t(\"./compute_error\"),plot:t(\"./plot\"),style:t(\"./style\"),hoverInfo:function(t,e,r){(e.error_y||{}).visible&&(r.yerr=t.yh-t.y,e.error_y.symmetric||(r.yerrneg=t.y-t.ys));(e.error_x||{}).visible&&(r.xerr=t.xh-t.x,e.error_x.symmetric||(r.xerrneg=t.x-t.xs))}}},{\"../../lib\":799,\"../../plot_api/edit_types\":831,\"./attributes\":686,\"./calc\":687,\"./compute_error\":688,\"./defaults\":689,\"./plot\":691,\"./style\":692}],691:[function(t,e,r){\"use strict\";var n=t(\"@plotly/d3\"),i=t(\"fast-isnumeric\"),a=t(\"../drawing\"),o=t(\"../../traces/scatter/subtypes\");e.exports=function(t,e,r,s){var l=r.xaxis,c=r.yaxis,u=s&&s.duration>0;e.each((function(e){var f,h=e[0].trace,p=h.error_x||{},d=h.error_y||{};h.ids&&(f=function(t){return t.id});var m=o.hasMarkers(h)&&h.marker.maxdisplayed>0;d.visible||p.visible||(e=[]);var g=n.select(this).selectAll(\"g.errorbar\").data(e,f);if(g.exit().remove(),e.length){p.visible||g.selectAll(\"path.xerror\").remove(),d.visible||g.selectAll(\"path.yerror\").remove(),g.style(\"opacity\",1);var v=g.enter().append(\"g\").classed(\"errorbar\",!0);u&&v.style(\"opacity\",0).transition().duration(s.duration).style(\"opacity\",1),a.setClipUrl(g,r.layerClipId,t),g.each((function(t){var e=n.select(this),r=function(t,e,r){var n={x:e.c2p(t.x),y:r.c2p(t.y)};void 0!==t.yh&&(n.yh=r.c2p(t.yh),n.ys=r.c2p(t.ys),i(n.ys)||(n.noYS=!0,n.ys=r.c2p(t.ys,!0)));void 0!==t.xh&&(n.xh=e.c2p(t.xh),n.xs=e.c2p(t.xs),i(n.xs)||(n.noXS=!0,n.xs=e.c2p(t.xs,!0)));return n}(t,l,c);if(!m||t.vis){var a,o=e.select(\"path.yerror\");if(d.visible&&i(r.x)&&i(r.yh)&&i(r.ys)){var f=d.width;a=\"M\"+(r.x-f)+\",\"+r.yh+\"h\"+2*f+\"m-\"+f+\",0V\"+r.ys,r.noYS||(a+=\"m-\"+f+\",0h\"+2*f),!o.size()?o=e.append(\"path\").style(\"vector-effect\",\"non-scaling-stroke\").classed(\"yerror\",!0):u&&(o=o.transition().duration(s.duration).ease(s.easing)),o.attr(\"d\",a)}else o.remove();var h=e.select(\"path.xerror\");if(p.visible&&i(r.y)&&i(r.xh)&&i(r.xs)){var g=(p.copy_ystyle?d:p).width;a=\"M\"+r.xh+\",\"+(r.y-g)+\"v\"+2*g+\"m0,-\"+g+\"H\"+r.xs,r.noXS||(a+=\"m0,-\"+g+\"v\"+2*g),!h.size()?h=e.append(\"path\").style(\"vector-effect\",\"non-scaling-stroke\").classed(\"xerror\",!0):u&&(h=h.transition().duration(s.duration).ease(s.easing)),h.attr(\"d\",a)}else h.remove()}}))}}))}},{\"../../traces/scatter/subtypes\":1239,\"../drawing\":684,\"@plotly/d3\":58,\"fast-isnumeric\":245}],692:[function(t,e,r){\"use strict\";var n=t(\"@plotly/d3\"),i=t(\"../color\");e.exports=function(t){t.each((function(t){var e=t[0].trace,r=e.error_y||{},a=e.error_x||{},o=n.select(this);o.selectAll(\"path.yerror\").style(\"stroke-width\",r.thickness+\"px\").call(i.stroke,r.color),a.copy_ystyle&&(a=r),o.selectAll(\"path.xerror\").style(\"stroke-width\",a.thickness+\"px\").call(i.stroke,a.color)}))}},{\"../color\":662,\"@plotly/d3\":58}],693:[function(t,e,r){\"use strict\";var n=t(\"../../plots/font_attributes\"),i=t(\"./layout_attributes\").hoverlabel,a=t(\"../../lib/extend\").extendFlat;e.exports={hoverlabel:{bgcolor:a({},i.bgcolor,{arrayOk:!0}),bordercolor:a({},i.bordercolor,{arrayOk:!0}),font:n({arrayOk:!0,editType:\"none\"}),align:a({},i.align,{arrayOk:!0}),namelength:a({},i.namelength,{arrayOk:!0}),editType:\"none\"}}},{\"../../lib/extend\":789,\"../../plots/font_attributes\":878,\"./layout_attributes\":703}],694:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../registry\");function a(t,e,r,i){i=i||n.identity,Array.isArray(t)&&(e[0][r]=i(t))}e.exports=function(t){var e=t.calcdata,r=t._fullLayout;function o(t){return function(e){return n.coerceHoverinfo({hoverinfo:e},{_module:t._module},r)}}for(var s=0;s<e.length;s++){var l=e[s],c=l[0].trace;if(!i.traceIs(c,\"pie-like\")){var u=i.traceIs(c,\"2dMap\")?a:n.fillArray;u(c.hoverinfo,l,\"hi\",o(c)),c.hovertemplate&&u(c.hovertemplate,l,\"ht\"),c.hoverlabel&&(u(c.hoverlabel.bgcolor,l,\"hbg\"),u(c.hoverlabel.bordercolor,l,\"hbc\"),u(c.hoverlabel.font.size,l,\"hts\"),u(c.hoverlabel.font.color,l,\"htc\"),u(c.hoverlabel.font.family,l,\"htf\"),u(c.hoverlabel.namelength,l,\"hnl\"),u(c.hoverlabel.align,l,\"hta\"))}}}},{\"../../lib\":799,\"../../registry\":927}],695:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"./hover\").hover;e.exports=function(t,e,r){var a=n.getComponentMethod(\"annotations\",\"onClick\")(t,t._hoverdata);function o(){t.emit(\"plotly_click\",{points:t._hoverdata,event:e})}void 0!==r&&i(t,e,r,!0),t._hoverdata&&e&&e.target&&(a&&a.then?a.then(o):o(),e.stopImmediatePropagation&&e.stopImmediatePropagation())}},{\"../../registry\":927,\"./hover\":699}],696:[function(t,e,r){\"use strict\";e.exports={YANGLE:60,HOVERARROWSIZE:6,HOVERTEXTPAD:3,HOVERFONTSIZE:13,HOVERFONT:\"Arial, sans-serif\",HOVERMINTIME:50,HOVERID:\"-hover\"}},{}],697:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\"),a=t(\"./hoverlabel_defaults\");e.exports=function(t,e,r,o){var s=n.extendFlat({},o.hoverlabel);e.hovertemplate&&(s.namelength=-1),a(t,e,(function(r,a){return n.coerce(t,e,i,r,a)}),s)}},{\"../../lib\":799,\"./attributes\":693,\"./hoverlabel_defaults\":700}],698:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");r.getSubplot=function(t){return t.subplot||t.xaxis+t.yaxis||t.geo},r.isTraceInSubplots=function(t,e){if(\"splom\"===t.type){for(var n=t.xaxes||[],i=t.yaxes||[],a=0;a<n.length;a++)for(var o=0;o<i.length;o++)if(-1!==e.indexOf(n[a]+i[o]))return!0;return!1}return-1!==e.indexOf(r.getSubplot(t))},r.flat=function(t,e){for(var r=new Array(t.length),n=0;n<t.length;n++)r[n]=e;return r},r.p2c=function(t,e){for(var r=new Array(t.length),n=0;n<t.length;n++)r[n]=t[n].p2c(e);return r},r.getDistanceFunction=function(t,e,n,i){return\"closest\"===t?i||r.quadrature(e,n):\"x\"===t.charAt(0)?e:n},r.getClosest=function(t,e,r){if(!1!==r.index)r.index>=0&&r.index<t.length?r.distance=0:r.index=!1;else for(var n=0;n<t.length;n++){var i=e(t[n]);i<=r.distance&&(r.index=n,r.distance=i)}return r},r.inbox=function(t,e,r){return t*e<0||0===t?r:1/0},r.quadrature=function(t,e){return function(r){var n=t(r),i=e(r);return Math.sqrt(n*n+i*i)}},r.makeEventData=function(t,e,n){var i=\"index\"in t?t.index:t.pointNumber,a={data:e._input,fullData:e,curveNumber:e.index,pointNumber:i};if(e._indexToPoints){var o=e._indexToPoints[i];1===o.length?a.pointIndex=o[0]:a.pointIndices=o}else a.pointIndex=i;return e._module.eventData?a=e._module.eventData(a,t,e,n,i):(\"xVal\"in t?a.x=t.xVal:\"x\"in t&&(a.x=t.x),\"yVal\"in t?a.y=t.yVal:\"y\"in t&&(a.y=t.y),t.xa&&(a.xaxis=t.xa),t.ya&&(a.yaxis=t.ya),void 0!==t.zLabelVal&&(a.z=t.zLabelVal)),r.appendArrayPointValue(a,e,i),a},r.appendArrayPointValue=function(t,e,r){var i=e._arrayAttrs;if(i)for(var s=0;s<i.length;s++){var l=i[s],c=a(l);if(void 0===t[c]){var u=o(n.nestedProperty(e,l).get(),r);void 0!==u&&(t[c]=u)}}},r.appendArrayMultiPointValues=function(t,e,r){var i=e._arrayAttrs;if(i)for(var s=0;s<i.length;s++){var l=i[s],c=a(l);if(void 0===t[c]){for(var u=n.nestedProperty(e,l).get(),f=new Array(r.length),h=0;h<r.length;h++)f[h]=o(u,r[h]);t[c]=f}}};var i={ids:\"id\",locations:\"location\",labels:\"label\",values:\"value\",\"marker.colors\":\"color\",parents:\"parent\"};function a(t){return i[t]||t}function o(t,e){return Array.isArray(e)?Array.isArray(t)&&Array.isArray(t[e[0]])?t[e[0]][e[1]]:void 0:t[e]}var s={x:!0,y:!0},l={\"x unified\":!0,\"y unified\":!0};r.isUnifiedHover=function(t){return\"string\"==typeof t&&!!l[t]},r.isXYhover=function(t){return\"string\"==typeof t&&!!s[t]}},{\"../../lib\":799}],699:[function(t,e,r){\"use strict\";var n=t(\"@plotly/d3\"),i=t(\"fast-isnumeric\"),a=t(\"tinycolor2\"),o=t(\"../../lib\"),s=o.strTranslate,l=o.strRotate,c=t(\"../../lib/events\"),u=t(\"../../lib/svg_text_utils\"),f=t(\"../../lib/override_cursor\"),h=t(\"../drawing\"),p=t(\"../color\"),d=t(\"../dragelement\"),m=t(\"../../plots/cartesian/axes\"),g=t(\"../../registry\"),v=t(\"./helpers\"),y=t(\"./constants\"),x=t(\"../legend/defaults\"),b=t(\"../legend/draw\"),_=y.YANGLE,w=Math.PI*_/180,T=1/Math.sin(w),k=Math.cos(w),M=Math.sin(w),A=y.HOVERARROWSIZE,S=y.HOVERTEXTPAD,E={box:!0,ohlc:!0,violin:!0,candlestick:!0};function L(t){return[t.trace.index,t.index,t.x0,t.y0,t.name,t.attr,t.xa,t.ya||\"\"].join(\",\")}r.hover=function(t,e,r,a){t=o.getGraphDiv(t),o.throttle(t._fullLayout._uid+y.HOVERID,y.HOVERMINTIME,(function(){!function(t,e,r,a){r||(r=\"xy\");var s=Array.isArray(r)?r:[r],l=t._fullLayout,u=l._plots||[],h=u[r],m=l._has(\"cartesian\");if(h){var y=h.overlays.map((function(t){return t.id}));s=s.concat(y)}for(var x=s.length,b=new Array(x),_=new Array(x),w=!1,k=0;k<x;k++){var M=s[k];if(u[M])w=!0,b[k]=u[M].xaxis,_[k]=u[M].yaxis;else{if(!l[M]||!l[M]._subplot)return void o.warn(\"Unrecognized subplot: \"+M);var A=l[M]._subplot;b[k]=A.xaxis,_[k]=A.yaxis}}var S=e.hovermode||l.hovermode;S&&!w&&(S=\"closest\");if(-1===[\"x\",\"y\",\"closest\",\"x unified\",\"y unified\"].indexOf(S)||!t.calcdata||t.querySelector(\".zoombox\")||t._dragging)return d.unhoverRaw(t,e);var C=l.hoverdistance;-1===C&&(C=1/0);var I=l.spikedistance;-1===I&&(I=1/0);var F,N,j,U,V,q,H,G,Y,W,X,Z,J,K=[],Q=[],$={hLinePoint:null,vLinePoint:null},tt=!1;if(Array.isArray(e))for(S=\"array\",j=0;j<e.length;j++)(V=t.calcdata[e[j].curveNumber||0])&&(q=V[0].trace,\"skip\"!==V[0].trace.hoverinfo&&(Q.push(V),\"h\"===q.orientation&&(tt=!0)));else{for(U=0;U<t.calcdata.length;U++)V=t.calcdata[U],\"skip\"!==(q=V[0].trace).hoverinfo&&v.isTraceInSubplots(q,s)&&(Q.push(V),\"h\"===q.orientation&&(tt=!0));var et,rt;if(!e.target)et=\"xpx\"in e?e.xpx:b[0]._length/2,rt=\"ypx\"in e?e.ypx:_[0]._length/2;else{if(!1===c.triggerHandler(t,\"plotly_beforehover\",e))return;var nt=e.composedPath&&e.composedPath()[0];nt||(nt=e.target);var it=nt.getBoundingClientRect();et=e.clientX-it.left,rt=e.clientY-it.top,l._calcInverseTransform(t);var at=o.apply3DTransform(l._invTransform)(et,rt);if(et=at[0],rt=at[1],et<0||et>b[0]._length||rt<0||rt>_[0]._length)return d.unhoverRaw(t,e)}if(e.pointerX=et+b[0]._offset,e.pointerY=rt+_[0]._offset,F=\"xval\"in e?v.flat(s,e.xval):v.p2c(b,et),N=\"yval\"in e?v.flat(s,e.yval):v.p2c(_,rt),!i(F[0])||!i(N[0]))return o.warn(\"Fx.hover failed\",e,t),d.unhoverRaw(t,e)}var ot=1/0;function st(t,r){for(U=0;U<Q.length;U++)if((V=Q[U])&&V[0]&&V[0].trace&&!0===(q=V[0].trace).visible&&0!==q._length&&-1===[\"carpet\",\"contourcarpet\"].indexOf(q._module.name)){if(\"splom\"===q.type?H=s[G=0]:(H=v.getSubplot(q),G=s.indexOf(H)),Y=S,v.isUnifiedHover(Y)&&(Y=Y.charAt(0)),Z={cd:V,trace:q,xa:b[G],ya:_[G],maxHoverDistance:C,maxSpikeDistance:I,index:!1,distance:Math.min(ot,C),spikeDistance:1/0,xSpike:void 0,ySpike:void 0,color:p.defaultLine,name:q.name,x0:void 0,x1:void 0,y0:void 0,y1:void 0,xLabelVal:void 0,yLabelVal:void 0,zLabelVal:void 0,text:void 0},l[H]&&(Z.subplot=l[H]._subplot),l._splomScenes&&l._splomScenes[q.uid]&&(Z.scene=l._splomScenes[q.uid]),J=K.length,\"array\"===Y){var n=e[U];\"pointNumber\"in n?(Z.index=n.pointNumber,Y=\"closest\"):(Y=\"\",\"xval\"in n&&(W=n.xval,Y=\"x\"),\"yval\"in n&&(X=n.yval,Y=Y?\"closest\":\"y\"))}else void 0!==t&&void 0!==r?(W=t,X=r):(W=F[G],X=N[G]);if(0!==C)if(q._module&&q._module.hoverPoints){var a=q._module.hoverPoints(Z,W,X,Y,{finiteRange:!0,hoverLayer:l._hoverlayer});if(a)for(var c,u=0;u<a.length;u++)c=a[u],i(c.x0)&&i(c.y0)&&K.push(z(c,S))}else o.log(\"Unrecognized trace type in hover:\",q);if(\"closest\"===S&&K.length>J&&(K.splice(0,J),ot=K[0].distance),m&&0!==I&&0===K.length){Z.distance=I,Z.index=!1;var f=q._module.hoverPoints(Z,W,X,\"closest\",{hoverLayer:l._hoverlayer});if(f&&(f=f.filter((function(t){return t.spikeDistance<=I}))),f&&f.length){var h,d=f.filter((function(t){return t.xa.showspikes&&\"hovered data\"!==t.xa.spikesnap}));if(d.length){var g=d[0];i(g.x0)&&i(g.y0)&&(h=ct(g),(!$.vLinePoint||$.vLinePoint.spikeDistance>h.spikeDistance)&&($.vLinePoint=h))}var y=f.filter((function(t){return t.ya.showspikes&&\"hovered data\"!==t.ya.spikesnap}));if(y.length){var x=y[0];i(x.x0)&&i(x.y0)&&(h=ct(x),(!$.hLinePoint||$.hLinePoint.spikeDistance>h.spikeDistance)&&($.hLinePoint=h))}}}}}function lt(t,e){for(var r,n=null,i=1/0,a=0;a<t.length;a++)(r=t[a].spikeDistance)<=i&&r<=e&&(n=t[a],i=r);return n}function ct(t){return t?{xa:t.xa,ya:t.ya,x:void 0!==t.xSpike?t.xSpike:(t.x0+t.x1)/2,y:void 0!==t.ySpike?t.ySpike:(t.y0+t.y1)/2,distance:t.distance,spikeDistance:t.spikeDistance,curveNumber:t.trace.index,color:t.color,pointNumber:t.index}:null}st();var ut={fullLayout:l,container:l._hoverlayer,outerContainer:l._paperdiv,event:e},ft=t._spikepoints,ht={vLinePoint:$.vLinePoint,hLinePoint:$.hLinePoint};if(t._spikepoints=ht,m&&0!==I&&0!==K.length){var pt=lt(K.filter((function(t){return t.ya.showspikes})),I);$.hLinePoint=ct(pt);var dt=lt(K.filter((function(t){return t.xa.showspikes})),I);$.vLinePoint=ct(dt)}if(0===K.length){var mt=d.unhoverRaw(t,e);return!m||null===$.hLinePoint&&null===$.vLinePoint||R(ft)&&D(t,$,ut),mt}m&&R(ft)&&D(t,$,ut);var gt=function(){K.sort((function(t,e){return t.distance-e.distance})),K=function(t,e){for(var r=e.charAt(0),n=[],i=[],a=[],o=0;o<t.length;o++){var s=t[o];g.traceIs(s.trace,\"bar-like\")||g.traceIs(s.trace,\"box-violin\")?a.push(s):s.trace[r+\"period\"]?i.push(s):n.push(s)}return n.concat(i).concat(a)}(K,S)};if(gt(),v.isXYhover(Y)&&0!==K[0].length&&\"splom\"!==K[0].trace.type){var vt=K[0],yt=(K=E[vt.trace.type]?K.filter((function(t){return t.trace.index===vt.trace.index})):[vt]).length,xt=B(\"x\",vt,l),bt=B(\"y\",vt,l);st(xt,bt);var _t,wt=[],Tt={},kt=0,Mt=function(t){var e=E[t.trace.type]?L(t):t.trace.index;if(Tt[e]){var r=Tt[e]-1,n=wt[r];r>0&&Math.abs(t.distance)<Math.abs(n.distance)&&(wt[r]=t)}else kt++,Tt[e]=kt,wt.push(t)};for(_t=0;_t<yt;_t++)Mt(K[_t]);for(_t=K.length-1;_t>yt-1;_t--)Mt(K[_t]);K=wt,gt()}var At=t._hoverdata,St=[];for(j=0;j<K.length;j++){var Et=K[j],Lt=v.makeEventData(Et,Et.trace,Et.cd);if(!1!==Et.hovertemplate){var Ct=!1;Et.cd[Et.index]&&Et.cd[Et.index].ht&&(Ct=Et.cd[Et.index].ht),Et.hovertemplate=Ct||Et.trace.hovertemplate||!1}Et.eventData=[Lt],St.push(Lt)}t._hoverdata=St;var Pt=\"y\"===S&&(Q.length>1||K.length>1)||\"closest\"===S&&tt&&K.length>1,It=p.combine(l.plot_bgcolor||p.background,l.paper_bgcolor),Ot={hovermode:S,rotateLabels:Pt,bgColor:It,container:l._hoverlayer,outerContainer:l._paperdiv,commonLabelOpts:l.hoverlabel,hoverdistance:l.hoverdistance},zt=P(K,Ot,t);v.isUnifiedHover(S)||(!function(t,e,r){var n,i,a,o,s,l,c,u=0,f=1,h=t.size(),p=new Array(h),d=0;function m(t){var e=t[0],r=t[t.length-1];if(i=e.pmin-e.pos-e.dp+e.size,a=r.pos+r.dp+r.size-e.pmax,i>.01){for(s=t.length-1;s>=0;s--)t[s].dp+=i;n=!1}if(!(a<.01)){if(i<-.01){for(s=t.length-1;s>=0;s--)t[s].dp-=a;n=!1}if(n){var c=0;for(o=0;o<t.length;o++)(l=t[o]).pos+l.dp+l.size>e.pmax&&c++;for(o=t.length-1;o>=0&&!(c<=0);o--)(l=t[o]).pos>e.pmax-1&&(l.del=!0,c--);for(o=0;o<t.length&&!(c<=0);o++)if((l=t[o]).pos<e.pmin+1)for(l.del=!0,c--,a=2*l.size,s=t.length-1;s>=0;s--)t[s].dp-=a;for(o=t.length-1;o>=0&&!(c<=0);o--)(l=t[o]).pos+l.dp+l.size>e.pmax&&(l.del=!0,c--)}}}t.each((function(t){var n=t[e],i=\"x\"===n._id.charAt(0),a=n.range;0===d&&a&&a[0]>a[1]!==i&&(f=-1),p[d++]=[{datum:t,traceIndex:t.trace.index,dp:0,pos:t.pos,posref:t.posref,size:t.by*(i?T:1)/2,pmin:0,pmax:i?r.width:r.height}]})),p.sort((function(t,e){return t[0].posref-e[0].posref||f*(e[0].traceIndex-t[0].traceIndex)}));for(;!n&&u<=h;){for(u++,n=!0,o=0;o<p.length-1;){var g=p[o],v=p[o+1],y=g[g.length-1],x=v[0];if((i=y.pos+y.dp+y.size-x.pos-x.dp+x.size)>.01&&y.pmin===x.pmin&&y.pmax===x.pmax){for(s=v.length-1;s>=0;s--)v[s].dp+=i;for(g.push.apply(g,v),p.splice(o+1,1),c=0,s=g.length-1;s>=0;s--)c+=g[s].dp;for(a=c/g.length,s=g.length-1;s>=0;s--)g[s].dp-=a;n=!1}else o++}p.forEach(m)}for(o=p.length-1;o>=0;o--){var b=p[o];for(s=b.length-1;s>=0;s--){var _=b[s],w=_.datum;w.offset=_.dp,w.del=_.del}}}(zt,Pt?\"xa\":\"ya\",l),O(zt,Pt,l._invScaleX,l._invScaleY));if(e.target&&e.target.tagName){var Dt=g.getComponentMethod(\"annotations\",\"hasClickToShow\")(t,St);f(n.select(e.target),Dt?\"pointer\":\"\")}if(!e.target||a||!function(t,e,r){if(!r||r.length!==t._hoverdata.length)return!0;for(var n=r.length-1;n>=0;n--){var i=r[n],a=t._hoverdata[n];if(i.curveNumber!==a.curveNumber||String(i.pointNumber)!==String(a.pointNumber)||String(i.pointNumbers)!==String(a.pointNumbers))return!0}return!1}(t,0,At))return;At&&t.emit(\"plotly_unhover\",{event:e,points:At});t.emit(\"plotly_hover\",{event:e,points:t._hoverdata,xaxes:b,yaxes:_,xvals:F,yvals:N})}(t,e,r,a)}))},r.loneHover=function(t,e){var r=!0;Array.isArray(t)||(r=!1,t=[t]);var i=t.map((function(t){return{color:t.color||p.defaultLine,x0:t.x0||t.x||0,x1:t.x1||t.x||0,y0:t.y0||t.y||0,y1:t.y1||t.y||0,xLabel:t.xLabel,yLabel:t.yLabel,zLabel:t.zLabel,text:t.text,name:t.name,idealAlign:t.idealAlign,borderColor:t.borderColor,fontFamily:t.fontFamily,fontSize:t.fontSize,fontColor:t.fontColor,nameLength:t.nameLength,textAlign:t.textAlign,trace:t.trace||{index:0,hoverinfo:\"\"},xa:{_offset:0},ya:{_offset:0},index:0,hovertemplate:t.hovertemplate||!1,eventData:t.eventData||!1,hovertemplateLabels:t.hovertemplateLabels||!1}})),a=n.select(e.container),o=e.outerContainer?n.select(e.outerContainer):a,s={hovermode:\"closest\",rotateLabels:!1,bgColor:e.bgColor||p.background,container:a,outerContainer:o},l=P(i,s,e.gd),c=0,u=0;l.sort((function(t,e){return t.y0-e.y0})).each((function(t,r){var n=t.y0-t.by/2;t.offset=n-5<c?c-n+5:0,c=n+t.by+t.offset,r===e.anchorIndex&&(u=t.offset)})).each((function(t){t.offset-=u}));var f=e.gd._fullLayout._invScaleX,h=e.gd._fullLayout._invScaleY;return O(l,s.rotateLabels,f,h),r?l:l.node()};var C=/<extra>([\\s\\S]*)<\\/extra>/;function P(t,e,r){var i=r._fullLayout,a=e.hovermode,c=e.rotateLabels,f=e.bgColor,d=e.container,m=e.outerContainer,g=e.commonLabelOpts||{},w=e.fontFamily||y.HOVERFONT,T=e.fontSize||y.HOVERFONTSIZE,k=t[0],M=k.xa,E=k.ya,C=a.charAt(0),P=k[C+\"Label\"],O=m.node().getBoundingClientRect(),z=O.top,D=O.width,R=O.height,F=void 0!==P&&k.distance<=e.hoverdistance&&(\"x\"===a||\"y\"===a);if(F){var B,N,j=!0;for(B=0;B<t.length;B++)if(j&&void 0===t[B].zLabel&&(j=!1),N=t[B].hoverinfo||t[B].trace.hoverinfo){var U=Array.isArray(N)?N:N.split(\"+\");if(-1===U.indexOf(\"all\")&&-1===U.indexOf(a)){F=!1;break}}j&&(F=!1)}var V=d.selectAll(\"g.axistext\").data(F?[0]:[]);if(V.enter().append(\"g\").classed(\"axistext\",!0),V.exit().remove(),V.each((function(){var t=n.select(this),e=o.ensureSingle(t,\"path\",\"\",(function(t){t.style({\"stroke-width\":\"1px\"})})),l=o.ensureSingle(t,\"text\",\"\",(function(t){t.attr(\"data-notex\",1)})),c=g.bgcolor||p.defaultLine,f=g.bordercolor||p.contrast(c),d=p.contrast(c),m={family:g.font.family||w,size:g.font.size||T,color:g.font.color||d};e.style({fill:c,stroke:f}),l.text(P).call(h.font,m).call(u.positionText,0,0).call(u.convertToTspans,r),t.attr(\"transform\",\"\");var v,y,x=l.node().getBoundingClientRect();if(\"x\"===a){var b=\"top\"===M.side?\"-\":\"\";l.attr(\"text-anchor\",\"middle\").call(u.positionText,0,\"top\"===M.side?z-x.bottom-A-S:z-x.top+A+S),v=M._offset+(k.x0+k.x1)/2,y=E._offset+(\"top\"===M.side?0:E._length);var _=x.width/2+S;v<_?(v=_,e.attr(\"d\",\"M-\"+(_-A)+\",0L-\"+(_-2*A)+\",\"+b+A+\"H\"+(S+x.width/2)+\"v\"+b+(2*S+x.height)+\"H-\"+_+\"V\"+b+A+\"Z\")):v>i.width-_?(v=i.width-_,e.attr(\"d\",\"M\"+(_-A)+\",0L\"+_+\",\"+b+A+\"v\"+b+(2*S+x.height)+\"H-\"+_+\"V\"+b+A+\"H\"+(_-2*A)+\"Z\")):e.attr(\"d\",\"M0,0L\"+A+\",\"+b+A+\"H\"+(S+x.width/2)+\"v\"+b+(2*S+x.height)+\"H-\"+(S+x.width/2)+\"V\"+b+A+\"H-\"+A+\"Z\")}else{var L,C,I;\"right\"===E.side?(L=\"start\",C=1,I=\"\",v=M._offset+M._length):(L=\"end\",C=-1,I=\"-\",v=M._offset),y=E._offset+(k.y0+k.y1)/2,l.attr(\"text-anchor\",L),e.attr(\"d\",\"M0,0L\"+I+A+\",\"+A+\"V\"+(S+x.height/2)+\"h\"+I+(2*S+x.width)+\"V-\"+(S+x.height/2)+\"H\"+I+A+\"V-\"+A+\"Z\");var O,D=x.height/2,R=z-x.top-D,F=\"clip\"+i._uid+\"commonlabel\"+E._id;if(v<x.width+2*S+A){O=\"M-\"+(A+S)+\"-\"+D+\"h-\"+(x.width-S)+\"V\"+D+\"h\"+(x.width-S)+\"Z\";var B=x.width-v+S;u.positionText(l,B,R),\"end\"===L&&l.selectAll(\"tspan\").each((function(){var t=n.select(this),e=h.tester.append(\"text\").text(t.text()).call(h.font,m),r=e.node().getBoundingClientRect();Math.round(r.width)<Math.round(x.width)&&t.attr(\"x\",B-r.width),e.remove()}))}else u.positionText(l,C*(S+A),R),O=null;var N=i._topclips.selectAll(\"#\"+F).data(O?[0]:[]);N.enter().append(\"clipPath\").attr(\"id\",F).append(\"path\"),N.exit().remove(),N.select(\"path\").attr(\"d\",O),h.setClipUrl(l,O?F:null,r)}t.attr(\"transform\",s(v,y))})),v.isUnifiedHover(a)){if(d.selectAll(\"g.hovertext\").remove(),0===t.length)return;var q={showlegend:!0,legend:{title:{text:P,font:i.hoverlabel.font},font:i.hoverlabel.font,bgcolor:i.hoverlabel.bgcolor,bordercolor:i.hoverlabel.bordercolor,borderwidth:1,tracegroupgap:7,traceorder:i.legend?i.legend.traceorder:void 0,orientation:\"v\"}},H={};x(q,H,r._fullData);var G=H.legend;G.entries=[];for(var Y=0;Y<t.length;Y++){var W=I(t[Y],!0,a,i,P),X=W[0],Z=W[1],J=t[Y];J.name=Z,J.text=\"\"!==Z?Z+\" : \"+X:X;var K=J.cd[J.index];K&&(K.mc&&(J.mc=K.mc),K.mcc&&(J.mc=K.mcc),K.mlc&&(J.mlc=K.mlc),K.mlcc&&(J.mlc=K.mlcc),K.mlw&&(J.mlw=K.mlw),K.mrc&&(J.mrc=K.mrc),K.dir&&(J.dir=K.dir)),J._distinct=!0,G.entries.push([J])}G.entries.sort((function(t,e){return t[0].trace.index-e[0].trace.index})),G.layer=d,G._inHover=!0,b(r,G);var Q=t[0],$=(Q.y0+Q.y1)/2,tt=(Q.x0+Q.x1)/2,et=d.select(\"g.legend\"),rt=et.node().getBoundingClientRect();tt+=M._offset,$+=E._offset-rt.height/2;var nt=rt.width+2*S;!(tt+nt<=D)&&tt-nt>=0?tt-=nt:tt+=2*S;var it=rt.height+2*S,at=$+it>=R;return it<=R&&($<=z?$=E._offset+2*S:at&&($=R-it)),et.attr(\"transform\",s(tt,$)),et}var ot=d.selectAll(\"g.hovertext\").data(t,(function(t){return L(t)}));return ot.enter().append(\"g\").classed(\"hovertext\",!0).each((function(){var t=n.select(this);t.append(\"rect\").call(p.fill,p.addOpacity(f,.8)),t.append(\"text\").classed(\"name\",!0),t.append(\"path\").style(\"stroke-width\",\"1px\"),t.append(\"text\").classed(\"nums\",!0).call(h.font,w,T)})),ot.exit().remove(),ot.each((function(t){var e=n.select(this).attr(\"transform\",\"\"),o=t.color;Array.isArray(o)&&(o=o[t.eventData[0].pointNumber]);var d=t.bgcolor||o,m=p.combine(p.opacity(d)?d:p.defaultLine,f),g=p.combine(p.opacity(o)?o:p.defaultLine,f),v=t.borderColor||p.contrast(m),y=I(t,F,a,i,P,e),x=y[0],b=y[1],k=e.select(\"text.nums\").call(h.font,t.fontFamily||w,t.fontSize||T,t.fontColor||v).text(x).attr(\"data-notex\",1).call(u.positionText,0,0).call(u.convertToTspans,r),M=e.select(\"text.name\"),E=0,L=0;if(b&&b!==x){M.call(h.font,t.fontFamily||w,t.fontSize||T,g).text(b).attr(\"data-notex\",1).call(u.positionText,0,0).call(u.convertToTspans,r);var C=M.node().getBoundingClientRect();E=C.width+2*S,L=C.height+2*S}else M.remove(),e.select(\"rect\").remove();e.select(\"path\").style({fill:m,stroke:v});var O,B,N=k.node().getBoundingClientRect(),j=t.xa._offset+(t.x0+t.x1)/2,U=t.ya._offset+(t.y0+t.y1)/2,V=Math.abs(t.x1-t.x0),q=Math.abs(t.y1-t.y0),H=N.width+A+S+E;if(t.ty0=z-N.top,t.bx=N.width+2*S,t.by=Math.max(N.height+2*S,L),t.anchor=\"start\",t.txwidth=N.width,t.tx2width=E,t.offset=0,c)t.pos=j,O=U+q/2+H<=R,B=U-q/2-H>=0,\"top\"!==t.idealAlign&&O||!B?O?(U+=q/2,t.anchor=\"start\"):t.anchor=\"middle\":(U-=q/2,t.anchor=\"end\");else if(t.pos=U,O=j+V/2+H<=D,B=j-V/2-H>=0,\"left\"!==t.idealAlign&&O||!B)if(O)j+=V/2,t.anchor=\"start\";else{t.anchor=\"middle\";var G=H/2,Y=j+G-D,W=j-G;Y>0&&(j-=Y),W<0&&(j+=-W)}else j-=V/2,t.anchor=\"end\";k.attr(\"text-anchor\",t.anchor),E&&M.attr(\"text-anchor\",t.anchor),e.attr(\"transform\",s(j,U)+(c?l(_):\"\"))})),ot}function I(t,e,r,n,i,a){var s=\"\",l=\"\";void 0!==t.nameOverride&&(t.name=t.nameOverride),t.name&&(t.trace._meta&&(t.name=o.templateString(t.name,t.trace._meta)),s=F(t.name,t.nameLength));var c=r.charAt(0),u=\"x\"===c?\"y\":\"x\";void 0!==t.zLabel?(void 0!==t.xLabel&&(l+=\"x: \"+t.xLabel+\"<br>\"),void 0!==t.yLabel&&(l+=\"y: \"+t.yLabel+\"<br>\"),\"choropleth\"!==t.trace.type&&\"choroplethmapbox\"!==t.trace.type&&(l+=(l?\"z: \":\"\")+t.zLabel)):e&&t[c+\"Label\"]===i?l=t[u+\"Label\"]||\"\":void 0===t.xLabel?void 0!==t.yLabel&&\"scattercarpet\"!==t.trace.type&&(l=t.yLabel):l=void 0===t.yLabel?t.xLabel:\"(\"+t.xLabel+\", \"+t.yLabel+\")\",!t.text&&0!==t.text||Array.isArray(t.text)||(l+=(l?\"<br>\":\"\")+t.text),void 0!==t.extraText&&(l+=(l?\"<br>\":\"\")+t.extraText),a&&\"\"===l&&!t.hovertemplate&&(\"\"===s&&a.remove(),l=s);var f=t.hovertemplate||!1;if(f){var h=t.hovertemplateLabels||t;t[c+\"Label\"]!==i&&(h[c+\"other\"]=h[c+\"Val\"],h[c+\"otherLabel\"]=h[c+\"Label\"]),l=(l=o.hovertemplateString(f,h,n._d3locale,t.eventData[0]||{},t.trace._meta)).replace(C,(function(e,r){return s=F(r,t.nameLength),\"\"}))}return[l,s]}function O(t,e,r,i){var a=function(t){return t*r},o=function(t){return t*i};t.each((function(t){var r=n.select(this);if(t.del)return r.remove();var i=r.select(\"text.nums\"),s=t.anchor,l=\"end\"===s?-1:1,c={start:1,end:-1,middle:0}[s],f=c*(A+S),p=f+c*(t.txwidth+S),d=0,m=t.offset,g=\"middle\"===s;g&&(f-=t.tx2width/2,p+=t.txwidth/2+S),e&&(m*=-M,d=t.offset*k),r.select(\"path\").attr(\"d\",g?\"M-\"+a(t.bx/2+t.tx2width/2)+\",\"+o(m-t.by/2)+\"h\"+a(t.bx)+\"v\"+o(t.by)+\"h-\"+a(t.bx)+\"Z\":\"M0,0L\"+a(l*A+d)+\",\"+o(A+m)+\"v\"+o(t.by/2-A)+\"h\"+a(l*t.bx)+\"v-\"+o(t.by)+\"H\"+a(l*A+d)+\"V\"+o(m-A)+\"Z\");var v=d+f,y=m+t.ty0-t.by/2+S,x=t.textAlign||\"auto\";\"auto\"!==x&&(\"left\"===x&&\"start\"!==s?(i.attr(\"text-anchor\",\"start\"),v=g?-t.bx/2-t.tx2width/2+S:-t.bx-S):\"right\"===x&&\"end\"!==s&&(i.attr(\"text-anchor\",\"end\"),v=g?t.bx/2-t.tx2width/2-S:t.bx+S)),i.call(u.positionText,a(v),o(y)),t.tx2width&&(r.select(\"text.name\").call(u.positionText,a(p+c*S+d),o(m+t.ty0-t.by/2+S)),r.select(\"rect\").call(h.setRect,a(p+(c-1)*t.tx2width/2+d),o(m-t.by/2-1),a(t.tx2width),o(t.by+2)))}))}function z(t,e){var r=t.index,n=t.trace||{},a=t.cd[0],s=t.cd[r]||{};function l(t){return t||i(t)&&0===t}var c=Array.isArray(r)?function(t,e){var i=o.castOption(a,r,t);return l(i)?i:o.extractOption({},n,\"\",e)}:function(t,e){return o.extractOption(s,n,t,e)};function u(e,r,n){var i=c(r,n);l(i)&&(t[e]=i)}if(u(\"hoverinfo\",\"hi\",\"hoverinfo\"),u(\"bgcolor\",\"hbg\",\"hoverlabel.bgcolor\"),u(\"borderColor\",\"hbc\",\"hoverlabel.bordercolor\"),u(\"fontFamily\",\"htf\",\"hoverlabel.font.family\"),u(\"fontSize\",\"hts\",\"hoverlabel.font.size\"),u(\"fontColor\",\"htc\",\"hoverlabel.font.color\"),u(\"nameLength\",\"hnl\",\"hoverlabel.namelength\"),u(\"textAlign\",\"hta\",\"hoverlabel.align\"),t.posref=\"y\"===e||\"closest\"===e&&\"h\"===n.orientation?t.xa._offset+(t.x0+t.x1)/2:t.ya._offset+(t.y0+t.y1)/2,t.x0=o.constrain(t.x0,0,t.xa._length),t.x1=o.constrain(t.x1,0,t.xa._length),t.y0=o.constrain(t.y0,0,t.ya._length),t.y1=o.constrain(t.y1,0,t.ya._length),void 0!==t.xLabelVal&&(t.xLabel=\"xLabel\"in t?t.xLabel:m.hoverLabelText(t.xa,t.xLabelVal,n.xhoverformat),t.xVal=t.xa.c2d(t.xLabelVal)),void 0!==t.yLabelVal&&(t.yLabel=\"yLabel\"in t?t.yLabel:m.hoverLabelText(t.ya,t.yLabelVal,n.yhoverformat),t.yVal=t.ya.c2d(t.yLabelVal)),void 0!==t.zLabelVal&&void 0===t.zLabel&&(t.zLabel=String(t.zLabelVal)),!(isNaN(t.xerr)||\"log\"===t.xa.type&&t.xerr<=0)){var f=m.tickText(t.xa,t.xa.c2l(t.xerr),\"hover\").text;void 0!==t.xerrneg?t.xLabel+=\" +\"+f+\" / -\"+m.tickText(t.xa,t.xa.c2l(t.xerrneg),\"hover\").text:t.xLabel+=\" \\xb1 \"+f,\"x\"===e&&(t.distance+=1)}if(!(isNaN(t.yerr)||\"log\"===t.ya.type&&t.yerr<=0)){var h=m.tickText(t.ya,t.ya.c2l(t.yerr),\"hover\").text;void 0!==t.yerrneg?t.yLabel+=\" +\"+h+\" / -\"+m.tickText(t.ya,t.ya.c2l(t.yerrneg),\"hover\").text:t.yLabel+=\" \\xb1 \"+h,\"y\"===e&&(t.distance+=1)}var p=t.hoverinfo||t.trace.hoverinfo;return p&&\"all\"!==p&&(-1===(p=Array.isArray(p)?p:p.split(\"+\")).indexOf(\"x\")&&(t.xLabel=void 0),-1===p.indexOf(\"y\")&&(t.yLabel=void 0),-1===p.indexOf(\"z\")&&(t.zLabel=void 0),-1===p.indexOf(\"text\")&&(t.text=void 0),-1===p.indexOf(\"name\")&&(t.name=void 0)),t}function D(t,e,r){var n,i,o=r.container,s=r.fullLayout,l=s._size,c=r.event,u=!!e.hLinePoint,f=!!e.vLinePoint;if(o.selectAll(\".spikeline\").remove(),f||u){var d=p.combine(s.plot_bgcolor,s.paper_bgcolor);if(u){var g,v,y=e.hLinePoint;n=y&&y.xa,\"cursor\"===(i=y&&y.ya).spikesnap?(g=c.pointerX,v=c.pointerY):(g=n._offset+y.x,v=i._offset+y.y);var x,b,_=a.readability(y.color,d)<1.5?p.contrast(d):y.color,w=i.spikemode,T=i.spikethickness,k=i.spikecolor||_,M=m.getPxPosition(t,i);if(-1!==w.indexOf(\"toaxis\")||-1!==w.indexOf(\"across\")){if(-1!==w.indexOf(\"toaxis\")&&(x=M,b=g),-1!==w.indexOf(\"across\")){var A=i._counterDomainMin,S=i._counterDomainMax;\"free\"===i.anchor&&(A=Math.min(A,i.position),S=Math.max(S,i.position)),x=l.l+A*l.w,b=l.l+S*l.w}o.insert(\"line\",\":first-child\").attr({x1:x,x2:b,y1:v,y2:v,\"stroke-width\":T,stroke:k,\"stroke-dasharray\":h.dashStyle(i.spikedash,T)}).classed(\"spikeline\",!0).classed(\"crisp\",!0),o.insert(\"line\",\":first-child\").attr({x1:x,x2:b,y1:v,y2:v,\"stroke-width\":T+2,stroke:d}).classed(\"spikeline\",!0).classed(\"crisp\",!0)}-1!==w.indexOf(\"marker\")&&o.insert(\"circle\",\":first-child\").attr({cx:M+(\"right\"!==i.side?T:-T),cy:v,r:T,fill:k}).classed(\"spikeline\",!0)}if(f){var E,L,C=e.vLinePoint;n=C&&C.xa,i=C&&C.ya,\"cursor\"===n.spikesnap?(E=c.pointerX,L=c.pointerY):(E=n._offset+C.x,L=i._offset+C.y);var P,I,O=a.readability(C.color,d)<1.5?p.contrast(d):C.color,z=n.spikemode,D=n.spikethickness,R=n.spikecolor||O,F=m.getPxPosition(t,n);if(-1!==z.indexOf(\"toaxis\")||-1!==z.indexOf(\"across\")){if(-1!==z.indexOf(\"toaxis\")&&(P=F,I=L),-1!==z.indexOf(\"across\")){var B=n._counterDomainMin,N=n._counterDomainMax;\"free\"===n.anchor&&(B=Math.min(B,n.position),N=Math.max(N,n.position)),P=l.t+(1-N)*l.h,I=l.t+(1-B)*l.h}o.insert(\"line\",\":first-child\").attr({x1:E,x2:E,y1:P,y2:I,\"stroke-width\":D,stroke:R,\"stroke-dasharray\":h.dashStyle(n.spikedash,D)}).classed(\"spikeline\",!0).classed(\"crisp\",!0),o.insert(\"line\",\":first-child\").attr({x1:E,x2:E,y1:P,y2:I,\"stroke-width\":D+2,stroke:d}).classed(\"spikeline\",!0).classed(\"crisp\",!0)}-1!==z.indexOf(\"marker\")&&o.insert(\"circle\",\":first-child\").attr({cx:E,cy:F-(\"top\"!==n.side?D:-D),r:D,fill:R}).classed(\"spikeline\",!0)}}}function R(t,e){return!e||(e.vLinePoint!==t._spikepoints.vLinePoint||e.hLinePoint!==t._spikepoints.hLinePoint)}function F(t,e){return u.plainText(t||\"\",{len:e,allowedTags:[\"br\",\"sub\",\"sup\",\"b\",\"i\",\"em\"]})}function B(t,e,r){var n=e[t+\"a\"],i=e[t+\"Val\"];\"category\"===n.type?i=n._categoriesMap[i]:\"date\"===n.type&&(i=n.d2c(i));var a=e.cd[e.index];return a&&a.t&&a.t.posLetter===n._id&&(\"group\"!==r.boxmode&&\"group\"!==r.violinmode||(i+=a.t.dPos)),i}},{\"../../lib\":799,\"../../lib/events\":788,\"../../lib/override_cursor\":810,\"../../lib/svg_text_utils\":824,\"../../plots/cartesian/axes\":849,\"../../registry\":927,\"../color\":662,\"../dragelement\":681,\"../drawing\":684,\"../legend/defaults\":714,\"../legend/draw\":715,\"./constants\":696,\"./helpers\":698,\"@plotly/d3\":58,\"fast-isnumeric\":245,tinycolor2:594}],700:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../color\"),a=t(\"./helpers\").isUnifiedHover;e.exports=function(t,e,r,o){function s(t){o.font[t]||(o.font[t]=e.legend?e.legend.font[t]:e.font[t])}o=o||{},e&&a(e.hovermode)&&(o.font||(o.font={}),s(\"size\"),s(\"family\"),s(\"color\"),e.legend?(o.bgcolor||(o.bgcolor=i.combine(e.legend.bgcolor,e.paper_bgcolor)),o.bordercolor||(o.bordercolor=e.legend.bordercolor)):o.bgcolor||(o.bgcolor=e.paper_bgcolor)),r(\"hoverlabel.bgcolor\",o.bgcolor),r(\"hoverlabel.bordercolor\",o.bordercolor),r(\"hoverlabel.namelength\",o.namelength),n.coerceFont(r,\"hoverlabel.font\",o.font),r(\"hoverlabel.align\",o.align)}},{\"../../lib\":799,\"../color\":662,\"./helpers\":698}],701:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\");e.exports=function(t,e){function r(r,a){return void 0!==e[r]?e[r]:n.coerce(t,e,i,r,a)}return r(\"clickmode\"),r(\"hovermode\")}},{\"../../lib\":799,\"./layout_attributes\":703}],702:[function(t,e,r){\"use strict\";var n=t(\"@plotly/d3\"),i=t(\"../../lib\"),a=t(\"../dragelement\"),o=t(\"./helpers\"),s=t(\"./layout_attributes\"),l=t(\"./hover\");e.exports={moduleType:\"component\",name:\"fx\",constants:t(\"./constants\"),schema:{layout:s},attributes:t(\"./attributes\"),layoutAttributes:s,supplyLayoutGlobalDefaults:t(\"./layout_global_defaults\"),supplyDefaults:t(\"./defaults\"),supplyLayoutDefaults:t(\"./layout_defaults\"),calc:t(\"./calc\"),getDistanceFunction:o.getDistanceFunction,getClosest:o.getClosest,inbox:o.inbox,quadrature:o.quadrature,appendArrayPointValue:o.appendArrayPointValue,castHoverOption:function(t,e,r){return i.castOption(t,e,\"hoverlabel.\"+r)},castHoverinfo:function(t,e,r){return i.castOption(t,r,\"hoverinfo\",(function(r){return i.coerceHoverinfo({hoverinfo:r},{_module:t._module},e)}))},hover:l.hover,unhover:a.unhover,loneHover:l.loneHover,loneUnhover:function(t){var e=i.isD3Selection(t)?t:n.select(t);e.selectAll(\"g.hovertext\").remove(),e.selectAll(\".spikeline\").remove()},click:t(\"./click\")}},{\"../../lib\":799,\"../dragelement\":681,\"./attributes\":693,\"./calc\":694,\"./click\":695,\"./constants\":696,\"./defaults\":697,\"./helpers\":698,\"./hover\":699,\"./layout_attributes\":703,\"./layout_defaults\":704,\"./layout_global_defaults\":705,\"@plotly/d3\":58}],703:[function(t,e,r){\"use strict\";var n=t(\"./constants\"),i=t(\"../../plots/font_attributes\")({editType:\"none\"});i.family.dflt=n.HOVERFONT,i.size.dflt=n.HOVERFONTSIZE,e.exports={clickmode:{valType:\"flaglist\",flags:[\"event\",\"select\"],dflt:\"event\",editType:\"plot\",extras:[\"none\"]},dragmode:{valType:\"enumerated\",values:[\"zoom\",\"pan\",\"select\",\"lasso\",\"drawclosedpath\",\"drawopenpath\",\"drawline\",\"drawrect\",\"drawcircle\",\"orbit\",\"turntable\",!1],dflt:\"zoom\",editType:\"modebar\"},hovermode:{valType:\"enumerated\",values:[\"x\",\"y\",\"closest\",!1,\"x unified\",\"y unified\"],dflt:\"closest\",editType:\"modebar\"},hoverdistance:{valType:\"integer\",min:-1,dflt:20,editType:\"none\"},spikedistance:{valType:\"integer\",min:-1,dflt:-1,editType:\"none\"},hoverlabel:{bgcolor:{valType:\"color\",editType:\"none\"},bordercolor:{valType:\"color\",editType:\"none\"},font:i,align:{valType:\"enumerated\",values:[\"left\",\"right\",\"auto\"],dflt:\"auto\",editType:\"none\"},namelength:{valType:\"integer\",min:-1,dflt:15,editType:\"none\"},editType:\"none\"},selectdirection:{valType:\"enumerated\",values:[\"h\",\"v\",\"d\",\"any\"],dflt:\"any\",editType:\"none\"}}},{\"../../plots/font_attributes\":878,\"./constants\":696}],704:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\"),a=t(\"./hovermode_defaults\"),o=t(\"./hoverlabel_defaults\");e.exports=function(t,e){function r(r,a){return n.coerce(t,e,i,r,a)}a(t,e)&&(r(\"hoverdistance\"),r(\"spikedistance\")),\"select\"===r(\"dragmode\")&&r(\"selectdirection\");var s=e._has(\"mapbox\"),l=e._has(\"geo\"),c=e._basePlotModules.length;\"zoom\"===e.dragmode&&((s||l)&&1===c||s&&l&&2===c)&&(e.dragmode=\"pan\"),o(t,e,r)}},{\"../../lib\":799,\"./hoverlabel_defaults\":700,\"./hovermode_defaults\":701,\"./layout_attributes\":703}],705:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./hoverlabel_defaults\"),a=t(\"./layout_attributes\");e.exports=function(t,e){i(t,e,(function(r,i){return n.coerce(t,e,a,r,i)}))}},{\"../../lib\":799,\"./hoverlabel_defaults\":700,\"./layout_attributes\":703}],706:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../lib/regex\").counter,a=t(\"../../plots/domain\").attributes,o=t(\"../../plots/cartesian/constants\").idRegex,s=t(\"../../plot_api/plot_template\"),l={rows:{valType:\"integer\",min:1,editType:\"plot\"},roworder:{valType:\"enumerated\",values:[\"top to bottom\",\"bottom to top\"],dflt:\"top to bottom\",editType:\"plot\"},columns:{valType:\"integer\",min:1,editType:\"plot\"},subplots:{valType:\"info_array\",freeLength:!0,dimensions:2,items:{valType:\"enumerated\",values:[i(\"xy\").toString(),\"\"],editType:\"plot\"},editType:\"plot\"},xaxes:{valType:\"info_array\",freeLength:!0,items:{valType:\"enumerated\",values:[o.x.toString(),\"\"],editType:\"plot\"},editType:\"plot\"},yaxes:{valType:\"info_array\",freeLength:!0,items:{valType:\"enumerated\",values:[o.y.toString(),\"\"],editType:\"plot\"},editType:\"plot\"},pattern:{valType:\"enumerated\",values:[\"independent\",\"coupled\"],dflt:\"coupled\",editType:\"plot\"},xgap:{valType:\"number\",min:0,max:1,editType:\"plot\"},ygap:{valType:\"number\",min:0,max:1,editType:\"plot\"},domain:a({name:\"grid\",editType:\"plot\",noGridCell:!0},{}),xside:{valType:\"enumerated\",values:[\"bottom\",\"bottom plot\",\"top plot\",\"top\"],dflt:\"bottom plot\",editType:\"plot\"},yside:{valType:\"enumerated\",values:[\"left\",\"left plot\",\"right plot\",\"right\"],dflt:\"left plot\",editType:\"plot\"},editType:\"plot\"};function c(t,e,r){var n=e[r+\"axes\"],i=Object.keys((t._splomAxes||{})[r]||{});return Array.isArray(n)?n:i.length?i:void 0}function u(t,e,r,n,i,a){var o=e(t+\"gap\",r),s=e(\"domain.\"+t);e(t+\"side\",n);for(var l=new Array(i),c=s[0],u=(s[1]-c)/(i-o),f=u*(1-o),h=0;h<i;h++){var p=c+u*h;l[a?i-1-h:h]=[p,p+f]}return l}function f(t,e,r,n,i){var a,o=new Array(r);function s(t,r){-1!==e.indexOf(r)&&void 0===n[r]?(o[t]=r,n[r]=t):o[t]=\"\"}if(Array.isArray(t))for(a=0;a<r;a++)s(a,t[a]);else for(s(0,i),a=1;a<r;a++)s(a,i+(a+1));return o}e.exports={moduleType:\"component\",name:\"grid\",schema:{layout:{grid:l}},layoutAttributes:l,sizeDefaults:function(t,e){var r=t.grid||{},i=c(e,r,\"x\"),a=c(e,r,\"y\");if(t.grid||i||a){var o,f,h=Array.isArray(r.subplots)&&Array.isArray(r.subplots[0]),p=Array.isArray(i),d=Array.isArray(a),m=p&&i!==r.xaxes&&d&&a!==r.yaxes;h?(o=r.subplots.length,f=r.subplots[0].length):(d&&(o=a.length),p&&(f=i.length));var g=s.newContainer(e,\"grid\"),v=k(\"rows\",o),y=k(\"columns\",f);if(v*y>1){if(!h&&!p&&!d)\"independent\"===k(\"pattern\")&&(h=!0);g._hasSubplotGrid=h;var x,b,_=\"top to bottom\"===k(\"roworder\"),w=h?.2:.1,T=h?.3:.1;m&&e._splomGridDflt&&(x=e._splomGridDflt.xside,b=e._splomGridDflt.yside),g._domains={x:u(\"x\",k,w,x,y),y:u(\"y\",k,T,b,v,_)}}else delete e.grid}function k(t,e){return n.coerce(r,g,l,t,e)}},contentDefaults:function(t,e){var r=e.grid;if(r&&r._domains){var n,i,a,o,s,l,u,h=t.grid||{},p=e._subplots,d=r._hasSubplotGrid,m=r.rows,g=r.columns,v=\"independent\"===r.pattern,y=r._axisMap={};if(d){var x=h.subplots||[];l=r.subplots=new Array(m);var b=1;for(n=0;n<m;n++){var _=l[n]=new Array(g),w=x[n]||[];for(i=0;i<g;i++)if(v?(s=1===b?\"xy\":\"x\"+b+\"y\"+b,b++):s=w[i],_[i]=\"\",-1!==p.cartesian.indexOf(s)){if(u=s.indexOf(\"y\"),a=s.slice(0,u),o=s.slice(u),void 0!==y[a]&&y[a]!==i||void 0!==y[o]&&y[o]!==n)continue;_[i]=s,y[a]=i,y[o]=n}}}else{var T=c(e,h,\"x\"),k=c(e,h,\"y\");r.xaxes=f(T,p.xaxis,g,y,\"x\"),r.yaxes=f(k,p.yaxis,m,y,\"y\")}var M=r._anchors={},A=\"top to bottom\"===r.roworder;for(var S in y){var E,L,C,P=S.charAt(0),I=r[P+\"side\"];if(I.length<8)M[S]=\"free\";else if(\"x\"===P){if(\"t\"===I.charAt(0)===A?(E=0,L=1,C=m):(E=m-1,L=-1,C=-1),d){var O=y[S];for(n=E;n!==C;n+=L)if((s=l[n][O])&&(u=s.indexOf(\"y\"),s.slice(0,u)===S)){M[S]=s.slice(u);break}}else for(n=E;n!==C;n+=L)if(o=r.yaxes[n],-1!==p.cartesian.indexOf(S+o)){M[S]=o;break}}else if(\"l\"===I.charAt(0)?(E=0,L=1,C=g):(E=g-1,L=-1,C=-1),d){var z=y[S];for(n=E;n!==C;n+=L)if((s=l[z][n])&&(u=s.indexOf(\"y\"),s.slice(u)===S)){M[S]=s.slice(0,u);break}}else for(n=E;n!==C;n+=L)if(a=r.xaxes[n],-1!==p.cartesian.indexOf(a+S)){M[S]=a;break}}}}}},{\"../../lib\":799,\"../../lib/regex\":816,\"../../plot_api/plot_template\":838,\"../../plots/cartesian/constants\":856,\"../../plots/domain\":877}],707:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/constants\"),i=t(\"../../plot_api/plot_template\").templatedArray;t(\"../../constants/axis_placeable_objects\");e.exports=i(\"image\",{visible:{valType:\"boolean\",dflt:!0,editType:\"arraydraw\"},source:{valType:\"string\",editType:\"arraydraw\"},layer:{valType:\"enumerated\",values:[\"below\",\"above\"],dflt:\"above\",editType:\"arraydraw\"},sizex:{valType:\"number\",dflt:0,editType:\"arraydraw\"},sizey:{valType:\"number\",dflt:0,editType:\"arraydraw\"},sizing:{valType:\"enumerated\",values:[\"fill\",\"contain\",\"stretch\"],dflt:\"contain\",editType:\"arraydraw\"},opacity:{valType:\"number\",min:0,max:1,dflt:1,editType:\"arraydraw\"},x:{valType:\"any\",dflt:0,editType:\"arraydraw\"},y:{valType:\"any\",dflt:0,editType:\"arraydraw\"},xanchor:{valType:\"enumerated\",values:[\"left\",\"center\",\"right\"],dflt:\"left\",editType:\"arraydraw\"},yanchor:{valType:\"enumerated\",values:[\"top\",\"middle\",\"bottom\"],dflt:\"top\",editType:\"arraydraw\"},xref:{valType:\"enumerated\",values:[\"paper\",n.idRegex.x.toString()],dflt:\"paper\",editType:\"arraydraw\"},yref:{valType:\"enumerated\",values:[\"paper\",n.idRegex.y.toString()],dflt:\"paper\",editType:\"arraydraw\"},editType:\"arraydraw\"})},{\"../../constants/axis_placeable_objects\":768,\"../../plot_api/plot_template\":838,\"../../plots/cartesian/constants\":856}],708:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib/to_log_range\");e.exports=function(t,e,r,a){e=e||{};var o=\"log\"===r&&\"linear\"===e.type,s=\"linear\"===r&&\"log\"===e.type;if(o||s)for(var l,c,u=t._fullLayout.images,f=e._id.charAt(0),h=0;h<u.length;h++)if(c=\"images[\"+h+\"].\",(l=u[h])[f+\"ref\"]===e._id){var p=l[f],d=l[\"size\"+f],m=null,g=null;if(o){m=i(p,e.range);var v=d/Math.pow(10,m)/2;g=2*Math.log(v+Math.sqrt(1+v*v))/Math.LN10}else g=(m=Math.pow(10,p))*(Math.pow(10,d/2)-Math.pow(10,-d/2));n(m)?n(g)||(g=null):(m=null,g=null),a(c+f,m),a(c+\"size\"+f,g)}}},{\"../../lib/to_log_range\":826,\"fast-isnumeric\":245}],709:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../../plots/array_container_defaults\"),o=t(\"./attributes\");function s(t,e,r){function a(r,i){return n.coerce(t,e,o,r,i)}var s=a(\"source\");if(!a(\"visible\",!!s))return e;a(\"layer\"),a(\"xanchor\"),a(\"yanchor\"),a(\"sizex\"),a(\"sizey\"),a(\"sizing\"),a(\"opacity\");for(var l={_fullLayout:r},c=[\"x\",\"y\"],u=0;u<2;u++){var f=c[u],h=i.coerceRef(t,e,l,f,\"paper\",void 0);if(\"paper\"!==h)i.getFromId(l,h)._imgIndices.push(e._index);i.coercePosition(e,l,a,h,f,0)}return e}e.exports=function(t,e){a(t,e,{name:\"images\",handleItemDefaults:s})}},{\"../../lib\":799,\"../../plots/array_container_defaults\":844,\"../../plots/cartesian/axes\":849,\"./attributes\":707}],710:[function(t,e,r){\"use strict\";var n=t(\"@plotly/d3\"),i=t(\"../drawing\"),a=t(\"../../plots/cartesian/axes\"),o=t(\"../../plots/cartesian/axis_ids\"),s=t(\"../../constants/xmlns_namespaces\");e.exports=function(t){var e,r,l=t._fullLayout,c=[],u={},f=[];for(r=0;r<l.images.length;r++){var h=l.images[r];if(h.visible)if(\"below\"===h.layer&&\"paper\"!==h.xref&&\"paper\"!==h.yref){e=o.ref2id(h.xref)+o.ref2id(h.yref);var p=l._plots[e];if(!p){f.push(h);continue}p.mainplot&&(e=p.mainplot.id),u[e]||(u[e]=[]),u[e].push(h)}else\"above\"===h.layer?c.push(h):f.push(h)}var d={left:{sizing:\"xMin\",offset:0},center:{sizing:\"xMid\",offset:-.5},right:{sizing:\"xMax\",offset:-1}},m={top:{sizing:\"YMin\",offset:0},middle:{sizing:\"YMid\",offset:-.5},bottom:{sizing:\"YMax\",offset:-1}};function g(e){var r=n.select(this);if(this._imgSrc!==e.source)if(r.attr(\"xmlns\",s.svg),e.source&&\"data:\"===e.source.slice(0,5))r.attr(\"xlink:href\",e.source),this._imgSrc=e.source;else{var i=new Promise(function(t){var n=new Image;function i(){r.remove(),t()}this.img=n,n.setAttribute(\"crossOrigin\",\"anonymous\"),n.onerror=i,n.onload=function(){var e=document.createElement(\"canvas\");e.width=this.width,e.height=this.height,e.getContext(\"2d\").drawImage(this,0,0);var n=e.toDataURL(\"image/png\");r.attr(\"xlink:href\",n),t()},r.on(\"error\",i),n.src=e.source,this._imgSrc=e.source}.bind(this));t._promises.push(i)}}function v(e){var r,o,s=n.select(this),c=a.getFromId(t,e.xref),u=a.getFromId(t,e.yref),f=\"domain\"===a.getRefType(e.xref),h=\"domain\"===a.getRefType(e.yref),p=l._size;r=void 0!==c?\"string\"==typeof e.xref&&f?c._length*e.sizex:Math.abs(c.l2p(e.sizex)-c.l2p(0)):e.sizex*p.w,o=void 0!==u?\"string\"==typeof e.yref&&h?u._length*e.sizey:Math.abs(u.l2p(e.sizey)-u.l2p(0)):e.sizey*p.h;var g,v,y=r*d[e.xanchor].offset,x=o*m[e.yanchor].offset,b=d[e.xanchor].sizing+m[e.yanchor].sizing;switch(g=void 0!==c?\"string\"==typeof e.xref&&f?c._length*e.x+c._offset:c.r2p(e.x)+c._offset:e.x*p.w+p.l,g+=y,v=void 0!==u?\"string\"==typeof e.yref&&h?u._length*(1-e.y)+u._offset:u.r2p(e.y)+u._offset:p.h-e.y*p.h+p.t,v+=x,e.sizing){case\"fill\":b+=\" slice\";break;case\"stretch\":b=\"none\"}s.attr({x:g,y:v,width:r,height:o,preserveAspectRatio:b,opacity:e.opacity});var _=(c&&\"domain\"!==a.getRefType(e.xref)?c._id:\"\")+(u&&\"domain\"!==a.getRefType(e.yref)?u._id:\"\");i.setClipUrl(s,_?\"clip\"+l._uid+_:null,t)}var y=l._imageLowerLayer.selectAll(\"image\").data(f),x=l._imageUpperLayer.selectAll(\"image\").data(c);y.enter().append(\"image\"),x.enter().append(\"image\"),y.exit().remove(),x.exit().remove(),y.each((function(t){g.bind(this)(t),v.bind(this)(t)})),x.each((function(t){g.bind(this)(t),v.bind(this)(t)}));var b=Object.keys(l._plots);for(r=0;r<b.length;r++){e=b[r];var _=l._plots[e];if(_.imagelayer){var w=_.imagelayer.selectAll(\"image\").data(u[e]||[]);w.enter().append(\"image\"),w.exit().remove(),w.each((function(t){g.bind(this)(t),v.bind(this)(t)}))}}}},{\"../../constants/xmlns_namespaces\":776,\"../../plots/cartesian/axes\":849,\"../../plots/cartesian/axis_ids\":853,\"../drawing\":684,\"@plotly/d3\":58}],711:[function(t,e,r){\"use strict\";e.exports={moduleType:\"component\",name:\"images\",layoutAttributes:t(\"./attributes\"),supplyLayoutDefaults:t(\"./defaults\"),includeBasePlot:t(\"../../plots/cartesian/include_components\")(\"images\"),draw:t(\"./draw\"),convertCoords:t(\"./convert_coords\")}},{\"../../plots/cartesian/include_components\":862,\"./attributes\":707,\"./convert_coords\":708,\"./defaults\":709,\"./draw\":710}],712:[function(t,e,r){\"use strict\";var n=t(\"../../plots/font_attributes\"),i=t(\"../color/attributes\");e.exports={bgcolor:{valType:\"color\",editType:\"legend\"},bordercolor:{valType:\"color\",dflt:i.defaultLine,editType:\"legend\"},borderwidth:{valType:\"number\",min:0,dflt:0,editType:\"legend\"},font:n({editType:\"legend\"}),orientation:{valType:\"enumerated\",values:[\"v\",\"h\"],dflt:\"v\",editType:\"legend\"},traceorder:{valType:\"flaglist\",flags:[\"reversed\",\"grouped\"],extras:[\"normal\"],editType:\"legend\"},tracegroupgap:{valType:\"number\",min:0,dflt:10,editType:\"legend\"},itemsizing:{valType:\"enumerated\",values:[\"trace\",\"constant\"],dflt:\"trace\",editType:\"legend\"},itemwidth:{valType:\"number\",min:30,dflt:30,editType:\"legend\"},itemclick:{valType:\"enumerated\",values:[\"toggle\",\"toggleothers\",!1],dflt:\"toggle\",editType:\"legend\"},itemdoubleclick:{valType:\"enumerated\",values:[\"toggle\",\"toggleothers\",!1],dflt:\"toggleothers\",editType:\"legend\"},x:{valType:\"number\",min:-2,max:3,editType:\"legend\"},xanchor:{valType:\"enumerated\",values:[\"auto\",\"left\",\"center\",\"right\"],dflt:\"left\",editType:\"legend\"},y:{valType:\"number\",min:-2,max:3,editType:\"legend\"},yanchor:{valType:\"enumerated\",values:[\"auto\",\"top\",\"middle\",\"bottom\"],editType:\"legend\"},uirevision:{valType:\"any\",editType:\"none\"},valign:{valType:\"enumerated\",values:[\"top\",\"middle\",\"bottom\"],dflt:\"middle\",editType:\"legend\"},title:{text:{valType:\"string\",dflt:\"\",editType:\"legend\"},font:n({editType:\"legend\"}),side:{valType:\"enumerated\",values:[\"top\",\"left\",\"top left\"],editType:\"legend\"},editType:\"legend\"},editType:\"legend\"}},{\"../../plots/font_attributes\":878,\"../color/attributes\":661}],713:[function(t,e,r){\"use strict\";e.exports={scrollBarWidth:6,scrollBarMinHeight:20,scrollBarColor:\"#808BA4\",scrollBarMargin:4,scrollBarEnterAttrs:{rx:20,ry:3,width:0,height:0},titlePad:2,itemGap:5}},{}],714:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"../../plot_api/plot_template\"),o=t(\"./attributes\"),s=t(\"../../plots/layout_attributes\"),l=t(\"./helpers\");e.exports=function(t,e,r){for(var c=t.legend||{},u=0,f=!1,h=\"normal\",p=0;p<r.length;p++){var d=r[p];d.visible&&((d.showlegend||d._dfltShowLegend&&!(d._module&&d._module.attributes&&d._module.attributes.showlegend&&!1===d._module.attributes.showlegend.dflt))&&(u++,d.showlegend&&(f=!0,(n.traceIs(d,\"pie-like\")||!0===d._input.showlegend)&&u++)),(n.traceIs(d,\"bar\")&&\"stack\"===e.barmode||-1!==[\"tonextx\",\"tonexty\"].indexOf(d.fill))&&(h=l.isGrouped({traceorder:h})?\"grouped+reversed\":\"reversed\"),void 0!==d.legendgroup&&\"\"!==d.legendgroup&&(h=l.isReversed({traceorder:h})?\"reversed+grouped\":\"grouped\"))}var m=i.coerce(t,e,s,\"showlegend\",f&&u>1);if(!1!==m||c.uirevision){var g=a.newContainer(e,\"legend\");if(T(\"uirevision\",e.uirevision),!1!==m){T(\"bgcolor\",e.paper_bgcolor),T(\"bordercolor\"),T(\"borderwidth\");var v,y,x,b=i.coerceFont(T,\"font\",e.font),_=\"h\"===T(\"orientation\");if(_?(v=0,n.getComponentMethod(\"rangeslider\",\"isVisible\")(t.xaxis)?(y=1.1,x=\"bottom\"):(y=-.1,x=\"top\")):(v=1.02,y=1,x=\"auto\"),T(\"traceorder\",h),l.isGrouped(e.legend)&&T(\"tracegroupgap\"),T(\"itemsizing\"),T(\"itemwidth\"),T(\"itemclick\"),T(\"itemdoubleclick\"),T(\"x\",v),T(\"xanchor\"),T(\"y\",y),T(\"yanchor\",x),T(\"valign\"),i.noneOrAll(c,g,[\"x\",\"y\"]),T(\"title.text\")){T(\"title.side\",_?\"left\":\"top\");var w=i.extendFlat({},b,{size:i.bigFont(b.size)});i.coerceFont(T,\"title.font\",w)}}}function T(t,e){return i.coerce(c,g,o,t,e)}}},{\"../../lib\":799,\"../../plot_api/plot_template\":838,\"../../plots/layout_attributes\":904,\"../../registry\":927,\"./attributes\":712,\"./helpers\":718}],715:[function(t,e,r){\"use strict\";var n=t(\"@plotly/d3\"),i=t(\"../../lib\"),a=t(\"../../plots/plots\"),o=t(\"../../registry\"),s=t(\"../../lib/events\"),l=t(\"../dragelement\"),c=t(\"../drawing\"),u=t(\"../color\"),f=t(\"../../lib/svg_text_utils\"),h=t(\"./handle_click\"),p=t(\"./constants\"),d=t(\"../../constants/alignment\"),m=d.LINE_SPACING,g=d.FROM_TL,v=d.FROM_BR,y=t(\"./get_legend_data\"),x=t(\"./style\"),b=t(\"./helpers\");function _(t,e,r,n,i){var a=r.data()[0][0].trace,l={event:i,node:r.node(),curveNumber:a.index,expandedIndex:a._expandedIndex,data:t.data,layout:t.layout,frames:t._transitionData._frames,config:t._context,fullData:t._fullData,fullLayout:t._fullLayout};if(a._group&&(l.group=a._group),o.traceIs(a,\"pie-like\")&&(l.label=r.datum()[0].label),!1!==s.triggerHandler(t,\"plotly_legendclick\",l))if(1===n)e._clickTimeout=setTimeout((function(){t._fullLayout&&h(r,t,n)}),t._context.doubleClickDelay);else if(2===n){e._clickTimeout&&clearTimeout(e._clickTimeout),t._legendMouseDownTime=0,!1!==s.triggerHandler(t,\"plotly_legenddoubleclick\",l)&&h(r,t,n)}}function w(t,e,r){var n,a,s=t.data()[0][0],l=s.trace,u=o.traceIs(l,\"pie-like\"),h=!r._inHover&&e._context.edits.legendText&&!u,d=r._maxNameLength;s.groupTitle?(n=s.groupTitle.text,a=s.groupTitle.font):(a=r.font,r.entries?n=s.text:(n=u?s.label:l.name,l._meta&&(n=i.templateString(n,l._meta))));var m=i.ensureSingle(t,\"text\",\"legendtext\");m.attr(\"text-anchor\",\"start\").call(c.font,a).text(h?T(n,d):n);var g=r.itemwidth+2*p.itemGap;f.positionText(m,g,0),h?m.call(f.makeEditable,{gd:e,text:n}).call(M,t,e,r).on(\"edit\",(function(n){this.text(T(n,d)).call(M,t,e,r);var a=s.trace._fullInput||{},c={};if(o.hasTransform(a,\"groupby\")){var u=o.getTransformIndices(a,\"groupby\"),f=u[u.length-1],h=i.keyedContainer(a,\"transforms[\"+f+\"].styles\",\"target\",\"value.name\");h.set(s.trace._group,n),c=h.constructUpdate()}else c.name=n;return o.call(\"_guiRestyle\",e,c,l.index)})):M(m,t,e,r)}function T(t,e){var r=Math.max(4,e);if(t&&t.trim().length>=r/2)return t;for(var n=r-(t=t||\"\").length;n>0;n--)t+=\" \";return t}function k(t,e){var r,a=e._context.doubleClickDelay,o=1,s=i.ensureSingle(t,\"rect\",\"legendtoggle\",(function(t){e._context.staticPlot||t.style(\"cursor\",\"pointer\").attr(\"pointer-events\",\"all\"),t.call(u.fill,\"rgba(0,0,0,0)\")}));e._context.staticPlot||(s.on(\"mousedown\",(function(){(r=(new Date).getTime())-e._legendMouseDownTime<a?o+=1:(o=1,e._legendMouseDownTime=r)})),s.on(\"mouseup\",(function(){if(!e._dragged&&!e._editing){var r=e._fullLayout.legend;(new Date).getTime()-e._legendMouseDownTime>a&&(o=Math.max(o-1,1)),_(e,r,t,o,n.event)}})))}function M(t,e,r,n,i){n._inHover&&t.attr(\"data-notex\",!0),f.convertToTspans(t,r,(function(){!function(t,e,r,n){var i=t.data()[0][0];if(!r._inHover&&i&&!i.trace.showlegend)return void t.remove();var a=t.select(\"g[class*=math-group]\"),o=a.node();r||(r=e._fullLayout.legend);var s,l=r.borderwidth;s=1===n?r.title.font:i.groupTitle?i.groupTitle.font:r.font;var u,h,d=s.size*m;if(o){var g=c.bBox(o);u=g.height,h=g.width,1===n?c.setTranslate(a,l,l+.75*u):c.setTranslate(a,0,.25*u)}else{var v=t.select(1===n?\".legendtitletext\":\".legendtext\"),y=f.lineCount(v),x=v.node();if(u=d*y,h=x?c.bBox(x).width:0,1===n)\"left\"===r.title.side&&(h+=2*p.itemGap),f.positionText(v,l+p.titlePad,l+d);else{var b=2*p.itemGap+r.itemwidth;i.groupTitle&&(b=p.itemGap,h-=r.itemwidth),f.positionText(v,b,-d*((y-1)/2-.3))}}1===n?(r._titleWidth=h,r._titleHeight=u):(i.lineHeight=d,i.height=Math.max(u,16)+3,i.width=h)}(e,r,n,i)}))}function A(t){return i.isRightAnchor(t)?\"right\":i.isCenterAnchor(t)?\"center\":\"left\"}function S(t){return i.isBottomAnchor(t)?\"bottom\":i.isMiddleAnchor(t)?\"middle\":\"top\"}e.exports=function(t,e){return e||(e=t._fullLayout.legend||{}),function(t,e){var r,s,f=t._fullLayout,h=\"legend\"+f._uid,d=e._inHover;d?(r=e.layer,h+=\"-hover\"):r=f._infolayer;if(!r)return;t._legendMouseDownTime||(t._legendMouseDownTime=0);if(d){if(!e.entries)return;s=y(e.entries,e)}else{if(!t.calcdata)return;s=f.showlegend&&y(t.calcdata,e)}var m=f.hiddenlabels||[];if(!(d||f.showlegend&&s.length))return r.selectAll(\".legend\").remove(),f._topdefs.select(\"#\"+h).remove(),a.autoMargin(t,\"legend\");var T=i.ensureSingle(r,\"g\",\"legend\",(function(t){d||t.attr(\"pointer-events\",\"all\")})),E=i.ensureSingleById(f._topdefs,\"clipPath\",h,(function(t){t.append(\"rect\")})),L=i.ensureSingle(T,\"rect\",\"bg\",(function(t){t.attr(\"shape-rendering\",\"crispEdges\")}));L.call(u.stroke,e.bordercolor).call(u.fill,e.bgcolor).style(\"stroke-width\",e.borderwidth+\"px\");var C=i.ensureSingle(T,\"g\",\"scrollbox\"),P=e.title;if(e._titleWidth=0,e._titleHeight=0,P.text){var I=i.ensureSingle(C,\"text\",\"legendtitletext\");I.attr(\"text-anchor\",\"start\").call(c.font,P.font).text(P.text),M(I,C,t,e,1)}else C.selectAll(\".legendtitletext\").remove();var O=i.ensureSingle(T,\"rect\",\"scrollbar\",(function(t){t.attr(p.scrollBarEnterAttrs).call(u.fill,p.scrollBarColor)})),z=C.selectAll(\"g.groups\").data(s);z.enter().append(\"g\").attr(\"class\",\"groups\"),z.exit().remove();var D=z.selectAll(\"g.traces\").data(i.identity);D.enter().append(\"g\").attr(\"class\",\"traces\"),D.exit().remove(),D.style(\"opacity\",(function(t){var e=t[0].trace;return o.traceIs(e,\"pie-like\")?-1!==m.indexOf(t[0].label)?.5:1:\"legendonly\"===e.visible?.5:1})).each((function(){n.select(this).call(w,t,e)})).call(x,t,e).each((function(){d||n.select(this).call(k,t)})),i.syncOrAsync([a.previousPromises,function(){return function(t,e,r,i){var a=t._fullLayout;i||(i=a.legend);var o=a._size,s=b.isVertical(i),l=b.isGrouped(i),u=i.borderwidth,f=2*u,h=p.itemGap,d=i.itemwidth+2*h,m=2*(u+h),g=S(i),v=i.y<0||0===i.y&&\"top\"===g,y=i.y>1||1===i.y&&\"bottom\"===g,x=i.tracegroupgap;i._maxHeight=Math.max(v||y?a.height/2:o.h,30);var _=0;i._width=0,i._height=0;var w=function(t){var e=0,r=0,n=t.title.side;n&&(-1!==n.indexOf(\"left\")&&(e=t._titleWidth),-1!==n.indexOf(\"top\")&&(r=t._titleHeight));return[e,r]}(i);if(s)r.each((function(t){var e=t[0].height;c.setTranslate(this,u+w[0],u+w[1]+i._height+e/2+h),i._height+=e,i._width=Math.max(i._width,t[0].width)})),_=d+i._width,i._width+=h+d+f,i._height+=m,l&&(e.each((function(t,e){c.setTranslate(this,0,e*i.tracegroupgap)})),i._height+=(i._lgroupsLength-1)*i.tracegroupgap);else{var T=A(i),k=i.x<0||0===i.x&&\"right\"===T,M=i.x>1||1===i.x&&\"left\"===T,E=y||v,L=a.width/2;i._maxWidth=Math.max(k?E&&\"left\"===T?o.l+o.w:L:M?E&&\"right\"===T?o.r+o.w:L:o.w,2*d);var C=0,P=0;r.each((function(t){var e=t[0].width+d;C=Math.max(C,e),P+=e})),_=null;var I=0;if(l){var O=0,z=0,D=0;e.each((function(){var t=0,e=0;n.select(this).selectAll(\"g.traces\").each((function(r){var n=r[0].height;c.setTranslate(this,w[0],w[1]+u+h+n/2+e),e+=n,t=Math.max(t,d+r[0].width)})),O=Math.max(O,e);var r=t+h;r+u+z>i._maxWidth&&(I=Math.max(I,z),z=0,D+=O+x,O=e),c.setTranslate(this,z,D),z+=r})),i._width=Math.max(I,z)+u,i._height=D+O+m}else{var R=r.size(),F=P+f+(R-1)*h<i._maxWidth,B=0,N=0,j=0,U=0;r.each((function(t){var e=t[0].height,r=d+t[0].width,n=(F?r:C)+h;n+u+N-h>=i._maxWidth&&(I=Math.max(I,U),N=0,j+=B,i._height+=B,B=0),c.setTranslate(this,w[0]+u+N,w[1]+u+j+e/2+h),U=N+r+h,N+=n,B=Math.max(B,e)})),F?(i._width=N+f,i._height=B+m):(i._width=Math.max(I,U)+f,i._height+=B+m)}}i._width=Math.ceil(Math.max(i._width+w[0],i._titleWidth+2*(u+p.titlePad))),i._height=Math.ceil(Math.max(i._height+w[1],i._titleHeight+2*(u+p.itemGap))),i._effHeight=Math.min(i._height,i._maxHeight);var V=t._context.edits,q=V.legendText||V.legendPosition;r.each((function(t){var e=n.select(this).select(\".legendtoggle\"),r=t[0].height,i=q?d:_||d+t[0].width;s||(i+=h/2),c.setRect(e,0,-r/2,i,r)}))}(t,z,D,e)},function(){if(d||!function(t){var e=t._fullLayout.legend,r=A(e),n=S(e);return a.autoMargin(t,\"legend\",{x:e.x,y:e.y,l:e._width*g[r],r:e._width*v[r],b:e._effHeight*v[n],t:e._effHeight*g[n]})}(t)){var s,u,m,y,x=f._size,b=e.borderwidth,w=x.l+x.w*e.x-g[A(e)]*e._width,k=x.t+x.h*(1-e.y)-g[S(e)]*e._effHeight;if(!d&&f.margin.autoexpand){var M=w,P=k;w=i.constrain(w,0,f.width-e._width),k=i.constrain(k,0,f.height-e._effHeight),w!==M&&i.log(\"Constrain legend.x to make legend fit inside graph\"),k!==P&&i.log(\"Constrain legend.y to make legend fit inside graph\")}if(d||c.setTranslate(T,w,k),O.on(\".drag\",null),T.on(\"wheel\",null),d||e._height<=e._maxHeight||t._context.staticPlot){var I=e._effHeight;d&&(I=e._height),L.attr({width:e._width-b,height:I-b,x:b/2,y:b/2}),c.setTranslate(C,0,0),E.select(\"rect\").attr({width:e._width-2*b,height:I-2*b,x:b,y:b}),c.setClipUrl(C,h,t),c.setRect(O,0,0,0,0),delete e._scrollY}else{var z,D,R,F=Math.max(p.scrollBarMinHeight,e._effHeight*e._effHeight/e._height),B=e._effHeight-F-2*p.scrollBarMargin,N=e._height-e._effHeight,j=B/N,U=Math.min(e._scrollY||0,N);L.attr({width:e._width-2*b+p.scrollBarWidth+p.scrollBarMargin,height:e._effHeight-b,x:b/2,y:b/2}),E.select(\"rect\").attr({width:e._width-2*b+p.scrollBarWidth+p.scrollBarMargin,height:e._effHeight-2*b,x:b,y:b+U}),c.setClipUrl(C,h,t),H(U,F,j),T.on(\"wheel\",(function(){H(U=i.constrain(e._scrollY+n.event.deltaY/B*N,0,N),F,j),0!==U&&U!==N&&n.event.preventDefault()}));var V=n.behavior.drag().on(\"dragstart\",(function(){var t=n.event.sourceEvent;z=\"touchstart\"===t.type?t.changedTouches[0].clientY:t.clientY,R=U})).on(\"drag\",(function(){var t=n.event.sourceEvent;2===t.buttons||t.ctrlKey||(D=\"touchmove\"===t.type?t.changedTouches[0].clientY:t.clientY,H(U=function(t,e,r){var n=(r-e)/j+t;return i.constrain(n,0,N)}(R,z,D),F,j))}));O.call(V);var q=n.behavior.drag().on(\"dragstart\",(function(){var t=n.event.sourceEvent;\"touchstart\"===t.type&&(z=t.changedTouches[0].clientY,R=U)})).on(\"drag\",(function(){var t=n.event.sourceEvent;\"touchmove\"===t.type&&(D=t.changedTouches[0].clientY,H(U=function(t,e,r){var n=(e-r)/j+t;return i.constrain(n,0,N)}(R,z,D),F,j))}));C.call(q)}if(t._context.edits.legendPosition)T.classed(\"cursor-move\",!0),l.init({element:T.node(),gd:t,prepFn:function(){var t=c.getTranslate(T);m=t.x,y=t.y},moveFn:function(t,r){var n=m+t,i=y+r;c.setTranslate(T,n,i),s=l.align(n,0,x.l,x.l+x.w,e.xanchor),u=l.align(i,0,x.t+x.h,x.t,e.yanchor)},doneFn:function(){void 0!==s&&void 0!==u&&o.call(\"_guiRelayout\",t,{\"legend.x\":s,\"legend.y\":u})},clickFn:function(e,n){var i=r.selectAll(\"g.traces\").filter((function(){var t=this.getBoundingClientRect();return n.clientX>=t.left&&n.clientX<=t.right&&n.clientY>=t.top&&n.clientY<=t.bottom}));i.size()>0&&_(t,T,i,e,n)}})}function H(r,n,i){e._scrollY=t._fullLayout.legend._scrollY=r,c.setTranslate(C,0,-r),c.setRect(O,e._width,p.scrollBarMargin+r*i,p.scrollBarWidth,n),E.select(\"rect\").attr(\"y\",b+r)}}],t)}(t,e)}},{\"../../constants/alignment\":767,\"../../lib\":799,\"../../lib/events\":788,\"../../lib/svg_text_utils\":824,\"../../plots/plots\":913,\"../../registry\":927,\"../color\":662,\"../dragelement\":681,\"../drawing\":684,\"./constants\":713,\"./get_legend_data\":716,\"./handle_click\":717,\"./helpers\":718,\"./style\":720,\"@plotly/d3\":58}],716:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"./helpers\");e.exports=function(t,e){var r,a,o=i.isGrouped(e),s=i.isReversed(e),l={},c=[],u=!1,f={},h=0,p=0;function d(t,r){if(\"\"!==t&&i.isGrouped(e))-1===c.indexOf(t)?(c.push(t),u=!0,l[t]=[r]):l[t].push(r);else{var n=\"~~i\"+h;c.push(n),l[n]=[r],h++}}for(r=0;r<t.length;r++){var m=t[r],g=m[0],v=g.trace,y=v.legendgroup;if(e._inHover||v.visible&&v.showlegend)if(n.traceIs(v,\"pie-like\"))for(f[y]||(f[y]={}),a=0;a<m.length;a++){var x=m[a].label;f[y][x]||(d(y,{label:x,color:m[a].color,i:m[a].i,trace:v,pts:m[a].pts}),f[y][x]=!0,p=Math.max(p,(x||\"\").length))}else d(y,g),p=Math.max(p,(v.name||\"\").length)}if(!c.length)return[];var b=!u||!o,_=[];for(r=0;r<c.length;r++){var w=l[c[r]];b?_.push(w[0]):_.push(w)}for(b&&(_=[_]),r=0;r<_.length;r++){var T=1/0;for(a=0;a<_[r].length;a++){var k=_[r][a].trace.legendrank;T>k&&(T=k)}_[r][0]._groupMinRank=T,_[r][0]._preGroupSort=r}var M=function(t,e){return t.trace.legendrank-e.trace.legendrank||t._preSort-e._preSort};for(_.forEach((function(t,e){t[0]._preGroupSort=e})),_.sort((function(t,e){return t[0]._groupMinRank-e[0]._groupMinRank||t[0]._preGroupSort-e[0]._preGroupSort})),r=0;r<_.length;r++){_[r].forEach((function(t,e){t._preSort=e})),_[r].sort(M);var A=_[r][0],S=null;for(a=0;a<_[r].length;a++){var E=_[r][a].trace.legendgrouptitle;if(E&&E.text){S=E;break}}for(s&&_[r].reverse(),S&&_[r].unshift({i:-1,groupTitle:S,trace:{showlegend:A.trace.showlegend}}),a=0;a<_[r].length;a++)_[r][a]=[_[r][a]]}return e._lgroupsLength=_.length,e._maxNameLength=p,_}},{\"../../registry\":927,\"./helpers\":718}],717:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../registry\"),a=!0;e.exports=function(t,e,r){var o=e._fullLayout;if(!e._dragged&&!e._editing){var s,l=o.legend.itemclick,c=o.legend.itemdoubleclick;if(1===r&&\"toggle\"===l&&\"toggleothers\"===c&&a&&e.data&&e._context.showTips?(n.notifier(n._(e,\"Double-click on legend to isolate one trace\"),\"long\"),a=!1):a=!1,1===r?s=l:2===r&&(s=c),s){var u=o.hiddenlabels?o.hiddenlabels.slice():[],f=t.data()[0][0];if(!f.groupTitle){var h,p,d,m,g,v=e._fullData,y=f.trace,x=y.legendgroup,b={},_=[],w=[],T=[];if(i.traceIs(y,\"pie-like\")){var k=f.label,M=u.indexOf(k);\"toggle\"===s?-1===M?u.push(k):u.splice(M,1):\"toggleothers\"===s&&(u=[],e.calcdata[0].forEach((function(t){k!==t.label&&u.push(t.label)})),e._fullLayout.hiddenlabels&&e._fullLayout.hiddenlabels.length===u.length&&-1===M&&(u=[])),i.call(\"_guiRelayout\",e,\"hiddenlabels\",u)}else{var A,S=x&&x.length,E=[];if(S)for(h=0;h<v.length;h++)(A=v[h]).visible&&A.legendgroup===x&&E.push(h);if(\"toggle\"===s){var L;switch(y.visible){case!0:L=\"legendonly\";break;case!1:L=!1;break;case\"legendonly\":L=!0}if(S)for(h=0;h<v.length;h++)!1!==v[h].visible&&v[h].legendgroup===x&&B(v[h],L);else B(y,L)}else if(\"toggleothers\"===s){var C,P,I,O,z=!0;for(h=0;h<v.length;h++)if(C=v[h]===y,I=!0!==v[h].showlegend,!(C||I||(P=S&&v[h].legendgroup===x)||!0!==v[h].visible||i.traceIs(v[h],\"notLegendIsolatable\"))){z=!1;break}for(h=0;h<v.length;h++)if(!1!==v[h].visible&&!i.traceIs(v[h],\"notLegendIsolatable\"))switch(y.visible){case\"legendonly\":B(v[h],!0);break;case!0:O=!!z||\"legendonly\",C=v[h]===y,I=!0!==v[h].showlegend&&!v[h].legendgroup,P=C||S&&v[h].legendgroup===x,B(v[h],!(!P&&!I)||O)}}for(h=0;h<w.length;h++)if(d=w[h]){var D=d.constructUpdate(),R=Object.keys(D);for(p=0;p<R.length;p++)m=R[p],(b[m]=b[m]||[])[T[h]]=D[m]}for(g=Object.keys(b),h=0;h<g.length;h++)for(m=g[h],p=0;p<_.length;p++)b[m].hasOwnProperty(p)||(b[m][p]=void 0);i.call(\"_guiRestyle\",e,b,_)}}}}function F(t,e,r){var n=_.indexOf(t),i=b[e];return i||(i=b[e]=[]),-1===_.indexOf(t)&&(_.push(t),n=_.length-1),i[n]=r,n}function B(t,e){var r=t._fullInput;if(i.hasTransform(r,\"groupby\")){var a=w[r.index];if(!a){var o=i.getTransformIndices(r,\"groupby\"),s=o[o.length-1];a=n.keyedContainer(r,\"transforms[\"+s+\"].styles\",\"target\",\"value.visible\"),w[r.index]=a}var l=a.get(t._group);void 0===l&&(l=!0),!1!==l&&a.set(t._group,e),T[r.index]=F(r.index,\"visible\",!1!==r.visible)}else{var c=!1!==r.visible&&e;F(r.index,\"visible\",c)}}}},{\"../../lib\":799,\"../../registry\":927}],718:[function(t,e,r){\"use strict\";r.isGrouped=function(t){return-1!==(t.traceorder||\"\").indexOf(\"grouped\")},r.isVertical=function(t){return\"h\"!==t.orientation},r.isReversed=function(t){return-1!==(t.traceorder||\"\").indexOf(\"reversed\")}},{}],719:[function(t,e,r){\"use strict\";e.exports={moduleType:\"component\",name:\"legend\",layoutAttributes:t(\"./attributes\"),supplyLayoutDefaults:t(\"./defaults\"),draw:t(\"./draw\"),style:t(\"./style\")}},{\"./attributes\":712,\"./defaults\":714,\"./draw\":715,\"./style\":720}],720:[function(t,e,r){\"use strict\";var n=t(\"@plotly/d3\"),i=t(\"../../registry\"),a=t(\"../../lib\"),o=a.strTranslate,s=t(\"../drawing\"),l=t(\"../color\"),c=t(\"../colorscale/helpers\").extractOpts,u=t(\"../../traces/scatter/subtypes\"),f=t(\"../../traces/pie/style_one\"),h=t(\"../../traces/pie/helpers\").castOption,p=t(\"./constants\");function d(t,e){return(e?\"radial\":\"horizontal\")+(t?\"\":\"reversed\")}function m(t){var e=t[0].trace,r=e.contours,n=u.hasLines(e),i=u.hasMarkers(e),a=e.visible&&e.fill&&\"none\"!==e.fill,o=!1,s=!1;if(r){var l=r.coloring;\"lines\"===l?o=!0:n=\"none\"===l||\"heatmap\"===l||r.showlines,\"constraint\"===r.type?a=\"=\"!==r._operation:\"fill\"!==l&&\"heatmap\"!==l||(s=!0)}return{showMarker:i,showLine:n,showFill:a,showGradientLine:o,showGradientFill:s,anyLine:n||o,anyFill:a||s}}function g(t,e,r){return t&&a.isArrayOrTypedArray(t)?e:t>r?r:t}e.exports=function(t,e,r){var v=e._fullLayout;r||(r=v.legend);var y=\"constant\"===r.itemsizing,x=r.itemwidth,b=(x+2*p.itemGap)/2,_=o(b,0),w=function(t,e,r,n){var i;if(t+1)i=t;else{if(!(e&&e.width>0))return 0;i=e.width}return y?n:Math.min(i,r)};function T(t,a,o){var u=t[0].trace,f=u.marker||{},h=f.line||{},p=o?u.visible&&u.type===o:i.traceIs(u,\"bar\"),d=n.select(a).select(\"g.legendpoints\").selectAll(\"path.legend\"+o).data(p?[t]:[]);d.enter().append(\"path\").classed(\"legend\"+o,!0).attr(\"d\",\"M6,6H-6V-6H6Z\").attr(\"transform\",_),d.exit().remove(),d.each((function(t){var i=n.select(this),a=t[0],o=w(a.mlw,f.line,5,2);i.style(\"stroke-width\",o+\"px\");var p=a.mcc;if(!r._inHover&&\"mc\"in a){var d=c(f),m=d.mid;void 0===m&&(m=(d.max+d.min)/2),p=s.tryColorscale(f,\"\")(m)}var v=p||a.mc||f.color,y=f.pattern,x=y&&s.getPatternAttr(y.shape,0,\"\");if(x){var b=s.getPatternAttr(y.bgcolor,0,null),_=s.getPatternAttr(y.fgcolor,0,null),T=y.fgopacity,k=g(y.size,8,10),M=g(y.solidity,.5,1),A=\"legend-\"+u.uid;i.call(s.pattern,\"legend\",e,A,x,k,M,p,y.fillmode,b,_,T)}else i.call(l.fill,v);o&&l.stroke(i,a.mlc||h.color)}))}function k(t,e,r){var o=t[0],s=o.trace,l=r?s.visible&&s.type===r:i.traceIs(s,r),c=n.select(e).select(\"g.legendpoints\").selectAll(\"path.legend\"+r).data(l?[t]:[]);if(c.enter().append(\"path\").classed(\"legend\"+r,!0).attr(\"d\",\"M6,6H-6V-6H6Z\").attr(\"transform\",_),c.exit().remove(),c.size()){var u=(s.marker||{}).line,p=w(h(u.width,o.pts),u,5,2),d=a.minExtend(s,{marker:{line:{width:p}}});d.marker.line.color=u.color;var m=a.minExtend(o,{trace:d});f(c,m,d)}}t.each((function(t){var e=n.select(this),i=a.ensureSingle(e,\"g\",\"layers\");i.style(\"opacity\",t[0].trace.opacity);var s=r.valign,l=t[0].lineHeight,c=t[0].height;if(\"middle\"!==s&&l&&c){var u={top:1,bottom:-1}[s]*(.5*(l-c+3));i.attr(\"transform\",o(0,u))}else i.attr(\"transform\",null);i.selectAll(\"g.legendfill\").data([t]).enter().append(\"g\").classed(\"legendfill\",!0),i.selectAll(\"g.legendlines\").data([t]).enter().append(\"g\").classed(\"legendlines\",!0);var f=i.selectAll(\"g.legendsymbols\").data([t]);f.enter().append(\"g\").classed(\"legendsymbols\",!0),f.selectAll(\"g.legendpoints\").data([t]).enter().append(\"g\").classed(\"legendpoints\",!0)})).each((function(t){var r,i=t[0].trace,o=[];if(i.visible)switch(i.type){case\"histogram2d\":case\"heatmap\":o=[[\"M-15,-2V4H15V-2Z\"]],r=!0;break;case\"choropleth\":case\"choroplethmapbox\":o=[[\"M-6,-6V6H6V-6Z\"]],r=!0;break;case\"densitymapbox\":o=[[\"M-6,0 a6,6 0 1,0 12,0 a 6,6 0 1,0 -12,0\"]],r=\"radial\";break;case\"cone\":o=[[\"M-6,2 A2,2 0 0,0 -6,6 V6L6,4Z\"],[\"M-6,-6 A2,2 0 0,0 -6,-2 L6,-4Z\"],[\"M-6,-2 A2,2 0 0,0 -6,2 L6,0Z\"]],r=!1;break;case\"streamtube\":o=[[\"M-6,2 A2,2 0 0,0 -6,6 H6 A2,2 0 0,1 6,2 Z\"],[\"M-6,-6 A2,2 0 0,0 -6,-2 H6 A2,2 0 0,1 6,-6 Z\"],[\"M-6,-2 A2,2 0 0,0 -6,2 H6 A2,2 0 0,1 6,-2 Z\"]],r=!1;break;case\"surface\":o=[[\"M-6,-6 A2,3 0 0,0 -6,0 H6 A2,3 0 0,1 6,-6 Z\"],[\"M-6,1 A2,3 0 0,1 -6,6 H6 A2,3 0 0,0 6,0 Z\"]],r=!0;break;case\"mesh3d\":o=[[\"M-6,6H0L-6,-6Z\"],[\"M6,6H0L6,-6Z\"],[\"M-6,-6H6L0,6Z\"]],r=!1;break;case\"volume\":o=[[\"M-6,6H0L-6,-6Z\"],[\"M6,6H0L6,-6Z\"],[\"M-6,-6H6L0,6Z\"]],r=!0;break;case\"isosurface\":o=[[\"M-6,6H0L-6,-6Z\"],[\"M6,6H0L6,-6Z\"],[\"M-6,-6 A12,24 0 0,0 6,-6 L0,6Z\"]],r=!1}var u=n.select(this).select(\"g.legendpoints\").selectAll(\"path.legend3dandfriends\").data(o);u.enter().append(\"path\").classed(\"legend3dandfriends\",!0).attr(\"transform\",_).style(\"stroke-miterlimit\",1),u.exit().remove(),u.each((function(t,o){var u,f=n.select(this),h=c(i),p=h.colorscale,m=h.reversescale;if(p){if(!r){var g=p.length;u=0===o?p[m?g-1:0][1]:1===o?p[m?0:g-1][1]:p[Math.floor((g-1)/2)][1]}}else{var v=i.vertexcolor||i.facecolor||i.color;u=a.isArrayOrTypedArray(v)?v[o]||v[0]:v}f.attr(\"d\",t[0]),u?f.call(l.fill,u):f.call((function(t){if(t.size()){var n=\"legendfill-\"+i.uid;s.gradient(t,e,n,d(m,\"radial\"===r),p,\"fill\")}}))}))})).each((function(t){var e=t[0].trace,r=\"waterfall\"===e.type;if(t[0]._distinct&&r){var i=t[0].trace[t[0].dir].marker;return t[0].mc=i.color,t[0].mlw=i.line.width,t[0].mlc=i.line.color,T(t,this,\"waterfall\")}var a=[];e.visible&&r&&(a=t[0].hasTotals?[[\"increasing\",\"M-6,-6V6H0Z\"],[\"totals\",\"M6,6H0L-6,-6H-0Z\"],[\"decreasing\",\"M6,6V-6H0Z\"]]:[[\"increasing\",\"M-6,-6V6H6Z\"],[\"decreasing\",\"M6,6V-6H-6Z\"]]);var o=n.select(this).select(\"g.legendpoints\").selectAll(\"path.legendwaterfall\").data(a);o.enter().append(\"path\").classed(\"legendwaterfall\",!0).attr(\"transform\",_).style(\"stroke-miterlimit\",1),o.exit().remove(),o.each((function(t){var r=n.select(this),i=e[t[0]].marker,a=w(void 0,i.line,5,2);r.attr(\"d\",t[1]).style(\"stroke-width\",a+\"px\").call(l.fill,i.color),a&&r.call(l.stroke,i.line.color)}))})).each((function(t){T(t,this,\"funnel\")})).each((function(t){T(t,this)})).each((function(t){var r=t[0].trace,o=n.select(this).select(\"g.legendpoints\").selectAll(\"path.legendbox\").data(r.visible&&i.traceIs(r,\"box-violin\")?[t]:[]);o.enter().append(\"path\").classed(\"legendbox\",!0).attr(\"d\",\"M6,6H-6V-6H6Z\").attr(\"transform\",_),o.exit().remove(),o.each((function(){var t=n.select(this);if(\"all\"!==r.boxpoints&&\"all\"!==r.points||0!==l.opacity(r.fillcolor)||0!==l.opacity((r.line||{}).color)){var i=w(void 0,r.line,5,2);t.style(\"stroke-width\",i+\"px\").call(l.fill,r.fillcolor),i&&l.stroke(t,r.line.color)}else{var c=a.minExtend(r,{marker:{size:y?12:a.constrain(r.marker.size,2,16),sizeref:1,sizemin:1,sizemode:\"diameter\"}});o.call(s.pointStyle,c,e)}}))})).each((function(t){k(t,this,\"funnelarea\")})).each((function(t){k(t,this,\"pie\")})).each((function(t){var r,i,o=m(t),l=o.showFill,f=o.showLine,h=o.showGradientLine,p=o.showGradientFill,g=o.anyFill,v=o.anyLine,y=t[0],b=y.trace,_=c(b),T=_.colorscale,k=_.reversescale,M=u.hasMarkers(b)||!g?\"M5,0\":v?\"M5,-2\":\"M5,-3\",A=n.select(this),S=A.select(\".legendfill\").selectAll(\"path\").data(l||p?[t]:[]);if(S.enter().append(\"path\").classed(\"js-fill\",!0),S.exit().remove(),S.attr(\"d\",M+\"h\"+x+\"v6h-\"+x+\"z\").call(l?s.fillGroupStyle:function(t){if(t.size()){var r=\"legendfill-\"+b.uid;s.gradient(t,e,r,d(k),T,\"fill\")}}),f||h){var E=w(void 0,b.line,10,5);i=a.minExtend(b,{line:{width:E}}),r=[a.minExtend(y,{trace:i})]}var L=A.select(\".legendlines\").selectAll(\"path\").data(f||h?[r]:[]);L.enter().append(\"path\").classed(\"js-line\",!0),L.exit().remove(),L.attr(\"d\",M+(h?\"l\"+x+\",0.0001\":\"h\"+x)).call(f?s.lineGroupStyle:function(t){if(t.size()){var r=\"legendline-\"+b.uid;s.lineGroupStyle(t),s.gradient(t,e,r,d(k),T,\"stroke\")}})})).each((function(t){var r,i,o=m(t),l=o.anyFill,c=o.anyLine,f=o.showLine,h=o.showMarker,p=t[0],d=p.trace,g=!h&&!c&&!l&&u.hasText(d);function v(t,e,r,n){var i=a.nestedProperty(d,t).get(),o=a.isArrayOrTypedArray(i)&&e?e(i):i;if(y&&o&&void 0!==n&&(o=n),r){if(o<r[0])return r[0];if(o>r[1])return r[1]}return o}function x(t){return p._distinct&&p.index&&t[p.index]?t[p.index]:t[0]}if(h||g||f){var b={},w={};if(h){b.mc=v(\"marker.color\",x),b.mx=v(\"marker.symbol\",x),b.mo=v(\"marker.opacity\",a.mean,[.2,1]),b.mlc=v(\"marker.line.color\",x),b.mlw=v(\"marker.line.width\",a.mean,[0,5],2),w.marker={sizeref:1,sizemin:1,sizemode:\"diameter\"};var T=v(\"marker.size\",a.mean,[2,16],12);b.ms=T,w.marker.size=T}f&&(w.line={width:v(\"line.width\",x,[0,10],5)}),g&&(b.tx=\"Aa\",b.tp=v(\"textposition\",x),b.ts=10,b.tc=v(\"textfont.color\",x),b.tf=v(\"textfont.family\",x)),r=[a.minExtend(p,b)],(i=a.minExtend(d,w)).selectedpoints=null,i.texttemplate=null}var k=n.select(this).select(\"g.legendpoints\"),M=k.selectAll(\"path.scatterpts\").data(h?r:[]);M.enter().insert(\"path\",\":first-child\").classed(\"scatterpts\",!0).attr(\"transform\",_),M.exit().remove(),M.call(s.pointStyle,i,e),h&&(r[0].mrc=3);var A=k.selectAll(\"g.pointtext\").data(g?r:[]);A.enter().append(\"g\").classed(\"pointtext\",!0).append(\"text\").attr(\"transform\",_),A.exit().remove(),A.selectAll(\"text\").call(s.textPointStyle,i,e)})).each((function(t){var e=t[0].trace,r=n.select(this).select(\"g.legendpoints\").selectAll(\"path.legendcandle\").data(e.visible&&\"candlestick\"===e.type?[t,t]:[]);r.enter().append(\"path\").classed(\"legendcandle\",!0).attr(\"d\",(function(t,e){return e?\"M-15,0H-8M-8,6V-6H8Z\":\"M15,0H8M8,-6V6H-8Z\"})).attr(\"transform\",_).style(\"stroke-miterlimit\",1),r.exit().remove(),r.each((function(t,r){var i=n.select(this),a=e[r?\"increasing\":\"decreasing\"],o=w(void 0,a.line,5,2);i.style(\"stroke-width\",o+\"px\").call(l.fill,a.fillcolor),o&&l.stroke(i,a.line.color)}))})).each((function(t){var e=t[0].trace,r=n.select(this).select(\"g.legendpoints\").selectAll(\"path.legendohlc\").data(e.visible&&\"ohlc\"===e.type?[t,t]:[]);r.enter().append(\"path\").classed(\"legendohlc\",!0).attr(\"d\",(function(t,e){return e?\"M-15,0H0M-8,-6V0\":\"M15,0H0M8,6V0\"})).attr(\"transform\",_).style(\"stroke-miterlimit\",1),r.exit().remove(),r.each((function(t,r){var i=n.select(this),a=e[r?\"increasing\":\"decreasing\"],o=w(void 0,a.line,5,2);i.style(\"fill\",\"none\").call(s.dashLine,a.line.dash,o),o&&l.stroke(i,a.line.color)}))}))}},{\"../../lib\":799,\"../../registry\":927,\"../../traces/pie/helpers\":1193,\"../../traces/pie/style_one\":1199,\"../../traces/scatter/subtypes\":1239,\"../color\":662,\"../colorscale/helpers\":673,\"../drawing\":684,\"./constants\":713,\"@plotly/d3\":58}],721:[function(t,e,r){\"use strict\";t(\"./constants\");e.exports={editType:\"modebar\",orientation:{valType:\"enumerated\",values:[\"v\",\"h\"],dflt:\"h\",editType:\"modebar\"},bgcolor:{valType:\"color\",editType:\"modebar\"},color:{valType:\"color\",editType:\"modebar\"},activecolor:{valType:\"color\",editType:\"modebar\"},uirevision:{valType:\"any\",editType:\"none\"},add:{valType:\"string\",arrayOk:!0,dflt:\"\",editType:\"modebar\"},remove:{valType:\"string\",arrayOk:!0,dflt:\"\",editType:\"modebar\"}}},{\"./constants\":723}],722:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../plots/plots\"),a=t(\"../../plots/cartesian/axis_ids\"),o=t(\"../../fonts/ploticon\"),s=t(\"../shapes/draw\").eraseActiveShape,l=t(\"../../lib\"),c=l._,u=e.exports={};function f(t,e){var r,i,o=e.currentTarget,s=o.getAttribute(\"data-attr\"),l=o.getAttribute(\"data-val\")||!0,c=t._fullLayout,u={},f=a.list(t,null,!0),h=c._cartesianSpikesEnabled;if(\"zoom\"===s){var p,d=\"in\"===l?.5:2,m=(1+d)/2,g=(1-d)/2;for(i=0;i<f.length;i++)if(!(r=f[i]).fixedrange)if(p=r._name,\"auto\"===l)u[p+\".autorange\"]=!0;else if(\"reset\"===l){if(void 0===r._rangeInitial)u[p+\".autorange\"]=!0;else{var v=r._rangeInitial.slice();u[p+\".range[0]\"]=v[0],u[p+\".range[1]\"]=v[1]}void 0!==r._showSpikeInitial&&(u[p+\".showspikes\"]=r._showSpikeInitial,\"on\"!==h||r._showSpikeInitial||(h=\"off\"))}else{var y=[r.r2l(r.range[0]),r.r2l(r.range[1])],x=[m*y[0]+g*y[1],m*y[1]+g*y[0]];u[p+\".range[0]\"]=r.l2r(x[0]),u[p+\".range[1]\"]=r.l2r(x[1])}}else\"hovermode\"!==s||\"x\"!==l&&\"y\"!==l||(l=c._isHoriz?\"y\":\"x\",o.setAttribute(\"data-val\",l)),u[s]=l;c._cartesianSpikesEnabled=h,n.call(\"_guiRelayout\",t,u)}function h(t,e){for(var r=e.currentTarget,i=r.getAttribute(\"data-attr\"),a=r.getAttribute(\"data-val\")||!0,o=t._fullLayout._subplots.gl3d||[],s={},l=i.split(\".\"),c=0;c<o.length;c++)s[o[c]+\".\"+l[1]]=a;var u=\"pan\"===a?a:\"zoom\";s.dragmode=u,n.call(\"_guiRelayout\",t,s)}function p(t,e){for(var r=e.currentTarget.getAttribute(\"data-attr\"),i=\"resetLastSave\"===r,a=\"resetDefault\"===r,o=t._fullLayout,s=o._subplots.gl3d||[],l={},c=0;c<s.length;c++){var u,f=s[c],h=f+\".camera\",p=f+\".aspectratio\",d=f+\".aspectmode\",m=o[f]._scene;i?(l[h+\".up\"]=m.viewInitial.up,l[h+\".eye\"]=m.viewInitial.eye,l[h+\".center\"]=m.viewInitial.center,u=!0):a&&(l[h+\".up\"]=null,l[h+\".eye\"]=null,l[h+\".center\"]=null,u=!0),u&&(l[p+\".x\"]=m.viewInitial.aspectratio.x,l[p+\".y\"]=m.viewInitial.aspectratio.y,l[p+\".z\"]=m.viewInitial.aspectratio.z,l[d]=m.viewInitial.aspectmode)}n.call(\"_guiRelayout\",t,l)}function d(t,e){var r=e.currentTarget,n=r._previousVal,i=t._fullLayout,a=i._subplots.gl3d||[],o=[\"xaxis\",\"yaxis\",\"zaxis\"],s={},l={};if(n)l=n,r._previousVal=null;else{for(var c=0;c<a.length;c++){var u=a[c],f=i[u],h=u+\".hovermode\";s[h]=f.hovermode,l[h]=!1;for(var p=0;p<3;p++){var d=o[p],m=u+\".\"+d+\".showspikes\";l[m]=!1,s[m]=f[d].showspikes}}r._previousVal=s}return l}function m(t,e){for(var r=e.currentTarget,i=r.getAttribute(\"data-attr\"),a=r.getAttribute(\"data-val\")||!0,o=t._fullLayout,s=o._subplots.geo||[],l=0;l<s.length;l++){var c=s[l],u=o[c];if(\"zoom\"===i){var f=u.projection.scale,h=\"in\"===a?2*f:.5*f;n.call(\"_guiRelayout\",t,c+\".projection.scale\",h)}}\"reset\"===i&&x(t,\"geo\")}function g(t){var e=t._fullLayout;return!e.hovermode&&(e._has(\"cartesian\")?e._isHoriz?\"y\":\"x\":\"closest\")}function v(t){var e=g(t);n.call(\"_guiRelayout\",t,\"hovermode\",e)}function y(t,e){for(var r=e.currentTarget.getAttribute(\"data-val\"),i=t._fullLayout,a=i._subplots.mapbox||[],o={},s=0;s<a.length;s++){var l=a[s],c=i[l].zoom,u=\"in\"===r?1.05*c:c/1.05;o[l+\".zoom\"]=u}n.call(\"_guiRelayout\",t,o)}function x(t,e){for(var r=t._fullLayout,i=r._subplots[e]||[],a={},o=0;o<i.length;o++)for(var s=i[o],l=r[s]._subplot.viewInitial,c=Object.keys(l),u=0;u<c.length;u++){var f=c[u];a[s+\".\"+f]=l[f]}n.call(\"_guiRelayout\",t,a)}u.toImage={name:\"toImage\",title:function(t){var e=(t._context.toImageButtonOptions||{}).format||\"png\";return c(t,\"png\"===e?\"Download plot as a png\":\"Download plot\")},icon:o.camera,click:function(t){var e=t._context.toImageButtonOptions,r={format:e.format||\"png\"};l.notifier(c(t,\"Taking snapshot - this may take a few seconds\"),\"long\"),\"svg\"!==r.format&&l.isIE()&&(l.notifier(c(t,\"IE only supports svg.  Changing format to svg.\"),\"long\"),r.format=\"svg\"),[\"filename\",\"width\",\"height\",\"scale\"].forEach((function(t){t in e&&(r[t]=e[t])})),n.call(\"downloadImage\",t,r).then((function(e){l.notifier(c(t,\"Snapshot succeeded\")+\" - \"+e,\"long\")})).catch((function(){l.notifier(c(t,\"Sorry, there was a problem downloading your snapshot!\"),\"long\")}))}},u.sendDataToCloud={name:\"sendDataToCloud\",title:function(t){return c(t,\"Edit in Chart Studio\")},icon:o.disk,click:function(t){i.sendDataToCloud(t)}},u.editInChartStudio={name:\"editInChartStudio\",title:function(t){return c(t,\"Edit in Chart Studio\")},icon:o.pencil,click:function(t){i.sendDataToCloud(t)}},u.zoom2d={name:\"zoom2d\",_cat:\"zoom\",title:function(t){return c(t,\"Zoom\")},attr:\"dragmode\",val:\"zoom\",icon:o.zoombox,click:f},u.pan2d={name:\"pan2d\",_cat:\"pan\",title:function(t){return c(t,\"Pan\")},attr:\"dragmode\",val:\"pan\",icon:o.pan,click:f},u.select2d={name:\"select2d\",_cat:\"select\",title:function(t){return c(t,\"Box Select\")},attr:\"dragmode\",val:\"select\",icon:o.selectbox,click:f},u.lasso2d={name:\"lasso2d\",_cat:\"lasso\",title:function(t){return c(t,\"Lasso Select\")},attr:\"dragmode\",val:\"lasso\",icon:o.lasso,click:f},u.drawclosedpath={name:\"drawclosedpath\",title:function(t){return c(t,\"Draw closed freeform\")},attr:\"dragmode\",val:\"drawclosedpath\",icon:o.drawclosedpath,click:f},u.drawopenpath={name:\"drawopenpath\",title:function(t){return c(t,\"Draw open freeform\")},attr:\"dragmode\",val:\"drawopenpath\",icon:o.drawopenpath,click:f},u.drawline={name:\"drawline\",title:function(t){return c(t,\"Draw line\")},attr:\"dragmode\",val:\"drawline\",icon:o.drawline,click:f},u.drawrect={name:\"drawrect\",title:function(t){return c(t,\"Draw rectangle\")},attr:\"dragmode\",val:\"drawrect\",icon:o.drawrect,click:f},u.drawcircle={name:\"drawcircle\",title:function(t){return c(t,\"Draw circle\")},attr:\"dragmode\",val:\"drawcircle\",icon:o.drawcircle,click:f},u.eraseshape={name:\"eraseshape\",title:function(t){return c(t,\"Erase active shape\")},icon:o.eraseshape,click:s},u.zoomIn2d={name:\"zoomIn2d\",_cat:\"zoomin\",title:function(t){return c(t,\"Zoom in\")},attr:\"zoom\",val:\"in\",icon:o.zoom_plus,click:f},u.zoomOut2d={name:\"zoomOut2d\",_cat:\"zoomout\",title:function(t){return c(t,\"Zoom out\")},attr:\"zoom\",val:\"out\",icon:o.zoom_minus,click:f},u.autoScale2d={name:\"autoScale2d\",_cat:\"autoscale\",title:function(t){return c(t,\"Autoscale\")},attr:\"zoom\",val:\"auto\",icon:o.autoscale,click:f},u.resetScale2d={name:\"resetScale2d\",_cat:\"resetscale\",title:function(t){return c(t,\"Reset axes\")},attr:\"zoom\",val:\"reset\",icon:o.home,click:f},u.hoverClosestCartesian={name:\"hoverClosestCartesian\",_cat:\"hoverclosest\",title:function(t){return c(t,\"Show closest data on hover\")},attr:\"hovermode\",val:\"closest\",icon:o.tooltip_basic,gravity:\"ne\",click:f},u.hoverCompareCartesian={name:\"hoverCompareCartesian\",_cat:\"hoverCompare\",title:function(t){return c(t,\"Compare data on hover\")},attr:\"hovermode\",val:function(t){return t._fullLayout._isHoriz?\"y\":\"x\"},icon:o.tooltip_compare,gravity:\"ne\",click:f},u.zoom3d={name:\"zoom3d\",_cat:\"zoom\",title:function(t){return c(t,\"Zoom\")},attr:\"scene.dragmode\",val:\"zoom\",icon:o.zoombox,click:h},u.pan3d={name:\"pan3d\",_cat:\"pan\",title:function(t){return c(t,\"Pan\")},attr:\"scene.dragmode\",val:\"pan\",icon:o.pan,click:h},u.orbitRotation={name:\"orbitRotation\",title:function(t){return c(t,\"Orbital rotation\")},attr:\"scene.dragmode\",val:\"orbit\",icon:o[\"3d_rotate\"],click:h},u.tableRotation={name:\"tableRotation\",title:function(t){return c(t,\"Turntable rotation\")},attr:\"scene.dragmode\",val:\"turntable\",icon:o[\"z-axis\"],click:h},u.resetCameraDefault3d={name:\"resetCameraDefault3d\",_cat:\"resetCameraDefault\",title:function(t){return c(t,\"Reset camera to default\")},attr:\"resetDefault\",icon:o.home,click:p},u.resetCameraLastSave3d={name:\"resetCameraLastSave3d\",_cat:\"resetCameraLastSave\",title:function(t){return c(t,\"Reset camera to last save\")},attr:\"resetLastSave\",icon:o.movie,click:p},u.hoverClosest3d={name:\"hoverClosest3d\",_cat:\"hoverclosest\",title:function(t){return c(t,\"Toggle show closest data on hover\")},attr:\"hovermode\",val:null,toggle:!0,icon:o.tooltip_basic,gravity:\"ne\",click:function(t,e){var r=d(t,e);n.call(\"_guiRelayout\",t,r)}},u.zoomInGeo={name:\"zoomInGeo\",_cat:\"zoomin\",title:function(t){return c(t,\"Zoom in\")},attr:\"zoom\",val:\"in\",icon:o.zoom_plus,click:m},u.zoomOutGeo={name:\"zoomOutGeo\",_cat:\"zoomout\",title:function(t){return c(t,\"Zoom out\")},attr:\"zoom\",val:\"out\",icon:o.zoom_minus,click:m},u.resetGeo={name:\"resetGeo\",_cat:\"reset\",title:function(t){return c(t,\"Reset\")},attr:\"reset\",val:null,icon:o.autoscale,click:m},u.hoverClosestGeo={name:\"hoverClosestGeo\",_cat:\"hoverclosest\",title:function(t){return c(t,\"Toggle show closest data on hover\")},attr:\"hovermode\",val:null,toggle:!0,icon:o.tooltip_basic,gravity:\"ne\",click:v},u.hoverClosestGl2d={name:\"hoverClosestGl2d\",_cat:\"hoverclosest\",title:function(t){return c(t,\"Toggle show closest data on hover\")},attr:\"hovermode\",val:null,toggle:!0,icon:o.tooltip_basic,gravity:\"ne\",click:v},u.hoverClosestPie={name:\"hoverClosestPie\",_cat:\"hoverclosest\",title:function(t){return c(t,\"Toggle show closest data on hover\")},attr:\"hovermode\",val:\"closest\",icon:o.tooltip_basic,gravity:\"ne\",click:v},u.resetViewSankey={name:\"resetSankeyGroup\",title:function(t){return c(t,\"Reset view\")},icon:o.home,click:function(t){for(var e={\"node.groups\":[],\"node.x\":[],\"node.y\":[]},r=0;r<t._fullData.length;r++){var i=t._fullData[r]._viewInitial;e[\"node.groups\"].push(i.node.groups.slice()),e[\"node.x\"].push(i.node.x.slice()),e[\"node.y\"].push(i.node.y.slice())}n.call(\"restyle\",t,e)}},u.toggleHover={name:\"toggleHover\",title:function(t){return c(t,\"Toggle show closest data on hover\")},attr:\"hovermode\",val:null,toggle:!0,icon:o.tooltip_basic,gravity:\"ne\",click:function(t,e){var r=d(t,e);r.hovermode=g(t),n.call(\"_guiRelayout\",t,r)}},u.resetViews={name:\"resetViews\",title:function(t){return c(t,\"Reset views\")},icon:o.home,click:function(t,e){var r=e.currentTarget;r.setAttribute(\"data-attr\",\"zoom\"),r.setAttribute(\"data-val\",\"reset\"),f(t,e),r.setAttribute(\"data-attr\",\"resetLastSave\"),p(t,e),x(t,\"geo\"),x(t,\"mapbox\")}},u.toggleSpikelines={name:\"toggleSpikelines\",title:function(t){return c(t,\"Toggle Spike Lines\")},icon:o.spikeline,attr:\"_cartesianSpikesEnabled\",val:\"on\",click:function(t){var e=t._fullLayout,r=e._cartesianSpikesEnabled;e._cartesianSpikesEnabled=\"on\"===r?\"off\":\"on\",n.call(\"_guiRelayout\",t,function(t){for(var e=\"on\"===t._fullLayout._cartesianSpikesEnabled,r=a.list(t,null,!0),n={},i=0;i<r.length;i++){var o=r[i];n[o._name+\".showspikes\"]=!!e||o._showSpikeInitial}return n}(t))}},u.resetViewMapbox={name:\"resetViewMapbox\",_cat:\"resetView\",title:function(t){return c(t,\"Reset view\")},attr:\"reset\",icon:o.home,click:function(t){x(t,\"mapbox\")}},u.zoomInMapbox={name:\"zoomInMapbox\",_cat:\"zoomin\",title:function(t){return c(t,\"Zoom in\")},attr:\"zoom\",val:\"in\",icon:o.zoom_plus,click:y},u.zoomOutMapbox={name:\"zoomOutMapbox\",_cat:\"zoomout\",title:function(t){return c(t,\"Zoom out\")},attr:\"zoom\",val:\"out\",icon:o.zoom_minus,click:y}},{\"../../fonts/ploticon\":778,\"../../lib\":799,\"../../plots/cartesian/axis_ids\":853,\"../../plots/plots\":913,\"../../registry\":927,\"../shapes/draw\":746}],723:[function(t,e,r){\"use strict\";var n=t(\"./buttons\"),i=Object.keys(n),a=[\"drawline\",\"drawopenpath\",\"drawclosedpath\",\"drawcircle\",\"drawrect\",\"eraseshape\"],o=[\"v1hovermode\",\"hoverclosest\",\"hovercompare\",\"togglehover\",\"togglespikelines\"].concat(a),s=[];i.forEach((function(t){!function(t){if(-1===o.indexOf(t._cat||t.name)){var e=t.name,r=(t._cat||t.name).toLowerCase();-1===s.indexOf(e)&&s.push(e),-1===s.indexOf(r)&&s.push(r)}}(n[t])})),s.sort(),e.exports={DRAW_MODES:a,backButtons:o,foreButtons:s}},{\"./buttons\":722}],724:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../color\"),a=t(\"../../plot_api/plot_template\"),o=t(\"./attributes\");e.exports=function(t,e){var r=t.modebar||{},s=a.newContainer(e,\"modebar\");function l(t,e){return n.coerce(r,s,o,t,e)}l(\"orientation\"),l(\"bgcolor\",i.addOpacity(e.paper_bgcolor,.5));var c=i.contrast(i.rgb(e.modebar.bgcolor));l(\"color\",i.addOpacity(c,.3)),l(\"activecolor\",i.addOpacity(c,.7)),l(\"uirevision\",e.uirevision),l(\"add\"),l(\"remove\")}},{\"../../lib\":799,\"../../plot_api/plot_template\":838,\"../color\":662,\"./attributes\":721}],725:[function(t,e,r){\"use strict\";e.exports={moduleType:\"component\",name:\"modebar\",layoutAttributes:t(\"./attributes\"),supplyLayoutDefaults:t(\"./defaults\"),manage:t(\"./manage\")}},{\"./attributes\":721,\"./defaults\":724,\"./manage\":726}],726:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axis_ids\"),i=t(\"../../traces/scatter/subtypes\"),a=t(\"../../registry\"),o=t(\"../fx/helpers\").isUnifiedHover,s=t(\"./modebar\"),l=t(\"./buttons\"),c=t(\"./constants\").DRAW_MODES;e.exports=function(t){var e=t._fullLayout,r=t._context,u=e._modeBar;if(r.displayModeBar||r.watermark){if(!Array.isArray(r.modeBarButtonsToRemove))throw new Error([\"*modeBarButtonsToRemove* configuration options\",\"must be an array.\"].join(\" \"));if(!Array.isArray(r.modeBarButtonsToAdd))throw new Error([\"*modeBarButtonsToAdd* configuration options\",\"must be an array.\"].join(\" \"));var f,h=r.modeBarButtons;f=Array.isArray(h)&&h.length?function(t){for(var e=0;e<t.length;e++)for(var r=t[e],n=0;n<r.length;n++){var i=r[n];if(\"string\"==typeof i){if(void 0===l[i])throw new Error([\"*modeBarButtons* configuration options\",\"invalid button name\"].join(\" \"));t[e][n]=l[i]}}return t}(h):!r.displayModeBar&&r.watermark?[]:function(t){var e=t._fullLayout,r=t._fullData,s=t._context;function u(t,e){if(\"string\"==typeof e){if(e.toLowerCase()===t.toLowerCase())return!0}else{var r=e.name,n=e._cat||e.name;if(r===t||n===t.toLowerCase())return!0}return!1}var f=e.modebar.add;\"string\"==typeof f&&(f=[f]);var h=e.modebar.remove;\"string\"==typeof h&&(h=[h]);var p=s.modeBarButtonsToAdd.concat(f.filter((function(t){for(var e=0;e<s.modeBarButtonsToRemove.length;e++)if(u(t,s.modeBarButtonsToRemove[e]))return!1;return!0}))),d=s.modeBarButtonsToRemove.concat(h.filter((function(t){for(var e=0;e<s.modeBarButtonsToAdd.length;e++)if(u(t,s.modeBarButtonsToAdd[e]))return!1;return!0}))),m=e._has(\"cartesian\"),g=e._has(\"gl3d\"),v=e._has(\"geo\"),y=e._has(\"pie\"),x=e._has(\"funnelarea\"),b=e._has(\"gl2d\"),_=e._has(\"ternary\"),w=e._has(\"mapbox\"),T=e._has(\"polar\"),k=e._has(\"sankey\"),M=function(t){for(var e=n.list({_fullLayout:t},null,!0),r=0;r<e.length;r++)if(!e[r].fixedrange)return!1;return!0}(e),A=o(e.hovermode),S=[];function E(t){if(t.length){for(var e=[],r=0;r<t.length;r++){for(var n=t[r],i=l[n],a=i.name.toLowerCase(),o=(i._cat||i.name).toLowerCase(),s=!1,c=0;c<d.length;c++){var u=d[c].toLowerCase();if(u===a||u===o){s=!0;break}}s||e.push(l[n])}S.push(e)}}var L=[\"toImage\"];s.showEditInChartStudio?L.push(\"editInChartStudio\"):s.showSendToCloud&&L.push(\"sendDataToCloud\");E(L);var C=[],P=[],I=[],O=[];(m||b||y||x||_)+v+g+w+T>1?(P=[\"toggleHover\"],I=[\"resetViews\"]):v?(C=[\"zoomInGeo\",\"zoomOutGeo\"],P=[\"hoverClosestGeo\"],I=[\"resetGeo\"]):g?(P=[\"hoverClosest3d\"],I=[\"resetCameraDefault3d\",\"resetCameraLastSave3d\"]):w?(C=[\"zoomInMapbox\",\"zoomOutMapbox\"],P=[\"toggleHover\"],I=[\"resetViewMapbox\"]):b?P=[\"hoverClosestGl2d\"]:y?P=[\"hoverClosestPie\"]:k?(P=[\"hoverClosestCartesian\",\"hoverCompareCartesian\"],I=[\"resetViewSankey\"]):P=[\"toggleHover\"];m&&(P=[\"toggleSpikelines\",\"hoverClosestCartesian\",\"hoverCompareCartesian\"]);(function(t){for(var e=0;e<t.length;e++)if(!a.traceIs(t[e],\"noHover\"))return!1;return!0}(r)||A)&&(P=[]);!m&&!b||M||(C=[\"zoomIn2d\",\"zoomOut2d\",\"autoScale2d\"],\"resetViews\"!==I[0]&&(I=[\"resetScale2d\"]));g?O=[\"zoom3d\",\"pan3d\",\"orbitRotation\",\"tableRotation\"]:(m||b)&&!M||_?O=[\"zoom2d\",\"pan2d\"]:w||v?O=[\"pan2d\"]:T&&(O=[\"zoom2d\"]);(function(t){for(var e=!1,r=0;r<t.length&&!e;r++){var n=t[r];n._module&&n._module.selectPoints&&(a.traceIs(n,\"scatter-like\")?(i.hasMarkers(n)||i.hasText(n))&&(e=!0):a.traceIs(n,\"box-violin\")&&\"all\"!==n.boxpoints&&\"all\"!==n.points||(e=!0))}return e})(r)&&O.push(\"select2d\",\"lasso2d\");var z=[],D=function(t){-1===z.indexOf(t)&&-1!==P.indexOf(t)&&z.push(t)};if(Array.isArray(p)){for(var R=[],F=0;F<p.length;F++){var B=p[F];\"string\"==typeof B?(B=B.toLowerCase(),-1!==c.indexOf(B)?(e._has(\"mapbox\")||e._has(\"cartesian\"))&&O.push(B):\"togglespikelines\"===B?D(\"toggleSpikelines\"):\"togglehover\"===B?D(\"toggleHover\"):\"hovercompare\"===B?D(\"hoverCompareCartesian\"):\"hoverclosest\"===B?(D(\"hoverClosestCartesian\"),D(\"hoverClosestGeo\"),D(\"hoverClosest3d\"),D(\"hoverClosestGl2d\"),D(\"hoverClosestPie\")):\"v1hovermode\"===B&&(D(\"toggleHover\"),D(\"hoverClosestCartesian\"),D(\"hoverCompareCartesian\"),D(\"hoverClosestGeo\"),D(\"hoverClosest3d\"),D(\"hoverClosestGl2d\"),D(\"hoverClosestPie\"))):R.push(B)}p=R}return E(O),E(C.concat(I)),E(z),function(t,e){if(e.length)if(Array.isArray(e[0]))for(var r=0;r<e.length;r++)t.push(e[r]);else t.push(e);return t}(S,p)}(t),u?u.update(t,f):e._modeBar=s(t,f)}else u&&(u.destroy(),delete e._modeBar)}},{\"../../plots/cartesian/axis_ids\":853,\"../../registry\":927,\"../../traces/scatter/subtypes\":1239,\"../fx/helpers\":698,\"./buttons\":722,\"./constants\":723,\"./modebar\":727}],727:[function(t,e,r){\"use strict\";var n=t(\"@plotly/d3\"),i=t(\"fast-isnumeric\"),a=t(\"../../lib\"),o=t(\"../../fonts/ploticon\"),s=new DOMParser;function l(t){this.container=t.container,this.element=document.createElement(\"div\"),this.update(t.graphInfo,t.buttons),this.container.appendChild(this.element)}var c=l.prototype;c.update=function(t,e){this.graphInfo=t;var r=this.graphInfo._context,n=this.graphInfo._fullLayout,i=\"modebar-\"+n._uid;this.element.setAttribute(\"id\",i),this._uid=i,this.element.className=\"modebar\",\"hover\"===r.displayModeBar&&(this.element.className+=\" modebar--hover ease-bg\"),\"v\"===n.modebar.orientation&&(this.element.className+=\" vertical\",e=e.reverse());var o=n.modebar,s=\"hover\"===r.displayModeBar?\".js-plotly-plot .plotly:hover \":\"\";a.deleteRelatedStyleRule(i),a.addRelatedStyleRule(i,s+\"#\"+i+\" .modebar-group\",\"background-color: \"+o.bgcolor),a.addRelatedStyleRule(i,\"#\"+i+\" .modebar-btn .icon path\",\"fill: \"+o.color),a.addRelatedStyleRule(i,\"#\"+i+\" .modebar-btn:hover .icon path\",\"fill: \"+o.activecolor),a.addRelatedStyleRule(i,\"#\"+i+\" .modebar-btn.active .icon path\",\"fill: \"+o.activecolor);var l=!this.hasButtons(e),c=this.hasLogo!==r.displaylogo,u=this.locale!==r.locale;if(this.locale=r.locale,(l||c||u)&&(this.removeAllButtons(),this.updateButtons(e),r.watermark||r.displaylogo)){var f=this.getLogo();r.watermark&&(f.className=f.className+\" watermark\"),\"v\"===n.modebar.orientation?this.element.insertBefore(f,this.element.childNodes[0]):this.element.appendChild(f),this.hasLogo=!0}this.updateActiveButton()},c.updateButtons=function(t){var e=this;this.buttons=t,this.buttonElements=[],this.buttonsNames=[],this.buttons.forEach((function(t){var r=e.createGroup();t.forEach((function(t){var n=t.name;if(!n)throw new Error(\"must provide button 'name' in button config\");if(-1!==e.buttonsNames.indexOf(n))throw new Error(\"button name '\"+n+\"' is taken\");e.buttonsNames.push(n);var i=e.createButton(t);e.buttonElements.push(i),r.appendChild(i)})),e.element.appendChild(r)}))},c.createGroup=function(){var t=document.createElement(\"div\");return t.className=\"modebar-group\",t},c.createButton=function(t){var e=this,r=document.createElement(\"a\");r.setAttribute(\"rel\",\"tooltip\"),r.className=\"modebar-btn\";var i=t.title;void 0===i?i=t.name:\"function\"==typeof i&&(i=i(this.graphInfo)),(i||0===i)&&r.setAttribute(\"data-title\",i),void 0!==t.attr&&r.setAttribute(\"data-attr\",t.attr);var a=t.val;if(void 0!==a&&(\"function\"==typeof a&&(a=a(this.graphInfo)),r.setAttribute(\"data-val\",a)),\"function\"!=typeof t.click)throw new Error(\"must provide button 'click' function in button config\");r.addEventListener(\"click\",(function(r){t.click(e.graphInfo,r),e.updateActiveButton(r.currentTarget)})),r.setAttribute(\"data-toggle\",t.toggle||!1),t.toggle&&n.select(r).classed(\"active\",!0);var s=t.icon;return\"function\"==typeof s?r.appendChild(s()):r.appendChild(this.createIcon(s||o.question)),r.setAttribute(\"data-gravity\",t.gravity||\"n\"),r},c.createIcon=function(t){var e,r=i(t.height)?Number(t.height):t.ascent-t.descent,n=\"http://www.w3.org/2000/svg\";if(t.path){(e=document.createElementNS(n,\"svg\")).setAttribute(\"viewBox\",[0,0,t.width,r].join(\" \")),e.setAttribute(\"class\",\"icon\");var a=document.createElementNS(n,\"path\");a.setAttribute(\"d\",t.path),t.transform?a.setAttribute(\"transform\",t.transform):void 0!==t.ascent&&a.setAttribute(\"transform\",\"matrix(1 0 0 -1 0 \"+t.ascent+\")\"),e.appendChild(a)}t.svg&&(e=s.parseFromString(t.svg,\"application/xml\").childNodes[0]);return e.setAttribute(\"height\",\"1em\"),e.setAttribute(\"width\",\"1em\"),e},c.updateActiveButton=function(t){var e=this.graphInfo._fullLayout,r=void 0!==t?t.getAttribute(\"data-attr\"):null;this.buttonElements.forEach((function(t){var i=t.getAttribute(\"data-val\")||!0,o=t.getAttribute(\"data-attr\"),s=\"true\"===t.getAttribute(\"data-toggle\"),l=n.select(t);if(s)o===r&&l.classed(\"active\",!l.classed(\"active\"));else{var c=null===o?o:a.nestedProperty(e,o).get();l.classed(\"active\",c===i)}}))},c.hasButtons=function(t){var e=this.buttons;if(!e)return!1;if(t.length!==e.length)return!1;for(var r=0;r<t.length;++r){if(t[r].length!==e[r].length)return!1;for(var n=0;n<t[r].length;n++)if(t[r][n].name!==e[r][n].name)return!1}return!0},c.getLogo=function(){var t=this.createGroup(),e=document.createElement(\"a\");return e.href=\"https://plotly.com/\",e.target=\"_blank\",e.setAttribute(\"data-title\",a._(this.graphInfo,\"Produced with Plotly\")),e.className=\"modebar-btn plotlyjsicon modebar-btn--logo\",e.appendChild(this.createIcon(o.newplotlylogo)),t.appendChild(e),t},c.removeAllButtons=function(){for(;this.element.firstChild;)this.element.removeChild(this.element.firstChild);this.hasLogo=!1},c.destroy=function(){a.removeElement(this.container.querySelector(\".modebar\")),a.deleteRelatedStyleRule(this._uid)},e.exports=function(t,e){var r=t._fullLayout,i=new l({graphInfo:t,container:r._modebardiv.node(),buttons:e});return r._privateplot&&n.select(i.element).append(\"span\").classed(\"badge-private float--left\",!0).text(\"PRIVATE\"),i}},{\"../../fonts/ploticon\":778,\"../../lib\":799,\"@plotly/d3\":58,\"fast-isnumeric\":245}],728:[function(t,e,r){\"use strict\";var n=t(\"../../plots/font_attributes\"),i=t(\"../color/attributes\"),a=(0,t(\"../../plot_api/plot_template\").templatedArray)(\"button\",{visible:{valType:\"boolean\",dflt:!0,editType:\"plot\"},step:{valType:\"enumerated\",values:[\"month\",\"year\",\"day\",\"hour\",\"minute\",\"second\",\"all\"],dflt:\"month\",editType:\"plot\"},stepmode:{valType:\"enumerated\",values:[\"backward\",\"todate\"],dflt:\"backward\",editType:\"plot\"},count:{valType:\"number\",min:0,dflt:1,editType:\"plot\"},label:{valType:\"string\",editType:\"plot\"},editType:\"plot\"});e.exports={visible:{valType:\"boolean\",editType:\"plot\"},buttons:a,x:{valType:\"number\",min:-2,max:3,editType:\"plot\"},xanchor:{valType:\"enumerated\",values:[\"auto\",\"left\",\"center\",\"right\"],dflt:\"left\",editType:\"plot\"},y:{valType:\"number\",min:-2,max:3,editType:\"plot\"},yanchor:{valType:\"enumerated\",values:[\"auto\",\"top\",\"middle\",\"bottom\"],dflt:\"bottom\",editType:\"plot\"},font:n({editType:\"plot\"}),bgcolor:{valType:\"color\",dflt:i.lightLine,editType:\"plot\"},activecolor:{valType:\"color\",editType:\"plot\"},bordercolor:{valType:\"color\",dflt:i.defaultLine,editType:\"plot\"},borderwidth:{valType:\"number\",min:0,dflt:0,editType:\"plot\"},editType:\"plot\"}},{\"../../plot_api/plot_template\":838,\"../../plots/font_attributes\":878,\"../color/attributes\":661}],729:[function(t,e,r){\"use strict\";e.exports={yPad:.02,minButtonWidth:30,rx:3,ry:3,lightAmount:25,darkAmount:10}},{}],730:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../color\"),a=t(\"../../plot_api/plot_template\"),o=t(\"../../plots/array_container_defaults\"),s=t(\"./attributes\"),l=t(\"./constants\");function c(t,e,r,i){var a=i.calendar;function o(r,i){return n.coerce(t,e,s.buttons,r,i)}if(o(\"visible\")){var l=o(\"step\");\"all\"!==l&&(!a||\"gregorian\"===a||\"month\"!==l&&\"year\"!==l?o(\"stepmode\"):e.stepmode=\"backward\",o(\"count\")),o(\"label\")}}e.exports=function(t,e,r,u,f){var h=t.rangeselector||{},p=a.newContainer(e,\"rangeselector\");function d(t,e){return n.coerce(h,p,s,t,e)}if(d(\"visible\",o(h,p,{name:\"buttons\",handleItemDefaults:c,calendar:f}).length>0)){var m=function(t,e,r){for(var n=r.filter((function(r){return e[r].anchor===t._id})),i=0,a=0;a<n.length;a++){var o=e[n[a]].domain;o&&(i=Math.max(o[1],i))}return[t.domain[0],i+l.yPad]}(e,r,u);d(\"x\",m[0]),d(\"y\",m[1]),n.noneOrAll(t,e,[\"x\",\"y\"]),d(\"xanchor\"),d(\"yanchor\"),n.coerceFont(d,\"font\",r.font);var g=d(\"bgcolor\");d(\"activecolor\",i.contrast(g,l.lightAmount,l.darkAmount)),d(\"bordercolor\"),d(\"borderwidth\")}}},{\"../../lib\":799,\"../../plot_api/plot_template\":838,\"../../plots/array_container_defaults\":844,\"../color\":662,\"./attributes\":728,\"./constants\":729}],731:[function(t,e,r){\"use strict\";var n=t(\"@plotly/d3\"),i=t(\"../../registry\"),a=t(\"../../plots/plots\"),o=t(\"../color\"),s=t(\"../drawing\"),l=t(\"../../lib\"),c=l.strTranslate,u=t(\"../../lib/svg_text_utils\"),f=t(\"../../plots/cartesian/axis_ids\"),h=t(\"../../constants/alignment\"),p=h.LINE_SPACING,d=h.FROM_TL,m=h.FROM_BR,g=t(\"./constants\"),v=t(\"./get_update_object\");function y(t){return t._id}function x(t,e,r){var n=l.ensureSingle(t,\"rect\",\"selector-rect\",(function(t){t.attr(\"shape-rendering\",\"crispEdges\")}));n.attr({rx:g.rx,ry:g.ry}),n.call(o.stroke,e.bordercolor).call(o.fill,function(t,e){return e._isActive||e._isHovered?t.activecolor:t.bgcolor}(e,r)).style(\"stroke-width\",e.borderwidth+\"px\")}function b(t,e,r,n){l.ensureSingle(t,\"text\",\"selector-text\",(function(t){t.attr(\"text-anchor\",\"middle\")})).call(s.font,e.font).text(function(t,e){if(t.label)return e?l.templateString(t.label,e):t.label;return\"all\"===t.step?\"all\":t.count+t.step.charAt(0)}(r,n._fullLayout._meta)).call((function(t){u.convertToTspans(t,n)}))}e.exports=function(t){var e=t._fullLayout._infolayer.selectAll(\".rangeselector\").data(function(t){for(var e=f.list(t,\"x\",!0),r=[],n=0;n<e.length;n++){var i=e[n];i.rangeselector&&i.rangeselector.visible&&r.push(i)}return r}(t),y);e.enter().append(\"g\").classed(\"rangeselector\",!0),e.exit().remove(),e.style({cursor:\"pointer\",\"pointer-events\":\"all\"}),e.each((function(e){var r=n.select(this),o=e,f=o.rangeselector,h=r.selectAll(\"g.button\").data(l.filterVisible(f.buttons));h.enter().append(\"g\").classed(\"button\",!0),h.exit().remove(),h.each((function(e){var r=n.select(this),a=v(o,e);e._isActive=function(t,e,r){if(\"all\"===e.step)return!0===t.autorange;var n=Object.keys(r);return t.range[0]===r[n[0]]&&t.range[1]===r[n[1]]}(o,e,a),r.call(x,f,e),r.call(b,f,e,t),r.on(\"click\",(function(){t._dragged||i.call(\"_guiRelayout\",t,a)})),r.on(\"mouseover\",(function(){e._isHovered=!0,r.call(x,f,e)})),r.on(\"mouseout\",(function(){e._isHovered=!1,r.call(x,f,e)}))})),function(t,e,r,i,o){var f=0,h=0,v=r.borderwidth;e.each((function(){var t=n.select(this).select(\".selector-text\"),e=r.font.size*p,i=Math.max(e*u.lineCount(t),16)+3;h=Math.max(h,i)})),e.each((function(){var t=n.select(this),e=t.select(\".selector-rect\"),i=t.select(\".selector-text\"),a=i.node()&&s.bBox(i.node()).width,o=r.font.size*p,l=u.lineCount(i),d=Math.max(a+10,g.minButtonWidth);t.attr(\"transform\",c(v+f,v)),e.attr({x:0,y:0,width:d,height:h}),u.positionText(i,d/2,h/2-(l-1)*o/2+3),f+=d+5}));var y=t._fullLayout._size,x=y.l+y.w*r.x,b=y.t+y.h*(1-r.y),_=\"left\";l.isRightAnchor(r)&&(x-=f,_=\"right\");l.isCenterAnchor(r)&&(x-=f/2,_=\"center\");var w=\"top\";l.isBottomAnchor(r)&&(b-=h,w=\"bottom\");l.isMiddleAnchor(r)&&(b-=h/2,w=\"middle\");f=Math.ceil(f),h=Math.ceil(h),x=Math.round(x),b=Math.round(b),a.autoMargin(t,i+\"-range-selector\",{x:r.x,y:r.y,l:f*d[_],r:f*m[_],b:h*m[w],t:h*d[w]}),o.attr(\"transform\",c(x,b))}(t,h,f,o._name,r)}))}},{\"../../constants/alignment\":767,\"../../lib\":799,\"../../lib/svg_text_utils\":824,\"../../plots/cartesian/axis_ids\":853,\"../../plots/plots\":913,\"../../registry\":927,\"../color\":662,\"../drawing\":684,\"./constants\":729,\"./get_update_object\":732,\"@plotly/d3\":58}],732:[function(t,e,r){\"use strict\";var n=t(\"@plotly/d3\");e.exports=function(t,e){var r=t._name,i={};if(\"all\"===e.step)i[r+\".autorange\"]=!0;else{var a=function(t,e){var r,i=t.range,a=new Date(t.r2l(i[1])),o=e.step,s=e.count;switch(e.stepmode){case\"backward\":r=t.l2r(+n.time[o].utc.offset(a,-s));break;case\"todate\":var l=n.time[o].utc.offset(a,-s);r=t.l2r(+n.time[o].utc.ceil(l))}var c=i[1];return[r,c]}(t,e);i[r+\".range[0]\"]=a[0],i[r+\".range[1]\"]=a[1]}return i}},{\"@plotly/d3\":58}],733:[function(t,e,r){\"use strict\";e.exports={moduleType:\"component\",name:\"rangeselector\",schema:{subplots:{xaxis:{rangeselector:t(\"./attributes\")}}},layoutAttributes:t(\"./attributes\"),handleDefaults:t(\"./defaults\"),draw:t(\"./draw\")}},{\"./attributes\":728,\"./defaults\":730,\"./draw\":731}],734:[function(t,e,r){\"use strict\";var n=t(\"../color/attributes\");e.exports={bgcolor:{valType:\"color\",dflt:n.background,editType:\"plot\"},bordercolor:{valType:\"color\",dflt:n.defaultLine,editType:\"plot\"},borderwidth:{valType:\"integer\",dflt:0,min:0,editType:\"plot\"},autorange:{valType:\"boolean\",dflt:!0,editType:\"calc\",impliedEdits:{\"range[0]\":void 0,\"range[1]\":void 0}},range:{valType:\"info_array\",items:[{valType:\"any\",editType:\"calc\",impliedEdits:{\"^autorange\":!1}},{valType:\"any\",editType:\"calc\",impliedEdits:{\"^autorange\":!1}}],editType:\"calc\",impliedEdits:{autorange:!1}},thickness:{valType:\"number\",dflt:.15,min:0,max:1,editType:\"plot\"},visible:{valType:\"boolean\",dflt:!0,editType:\"calc\"},editType:\"calc\"}},{\"../color/attributes\":661}],735:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axis_ids\").list,i=t(\"../../plots/cartesian/autorange\").getAutoRange,a=t(\"./constants\");e.exports=function(t){for(var e=n(t,\"x\",!0),r=0;r<e.length;r++){var o=e[r],s=o[a.name];s&&s.visible&&s.autorange&&(s._input.autorange=!0,s._input.range=s.range=i(t,o))}}},{\"../../plots/cartesian/autorange\":848,\"../../plots/cartesian/axis_ids\":853,\"./constants\":736}],736:[function(t,e,r){\"use strict\";e.exports={name:\"rangeslider\",containerClassName:\"rangeslider-container\",bgClassName:\"rangeslider-bg\",rangePlotClassName:\"rangeslider-rangeplot\",maskMinClassName:\"rangeslider-mask-min\",maskMaxClassName:\"rangeslider-mask-max\",slideBoxClassName:\"rangeslider-slidebox\",grabberMinClassName:\"rangeslider-grabber-min\",grabAreaMinClassName:\"rangeslider-grabarea-min\",handleMinClassName:\"rangeslider-handle-min\",grabberMaxClassName:\"rangeslider-grabber-max\",grabAreaMaxClassName:\"rangeslider-grabarea-max\",handleMaxClassName:\"rangeslider-handle-max\",maskMinOppAxisClassName:\"rangeslider-mask-min-opp-axis\",maskMaxOppAxisClassName:\"rangeslider-mask-max-opp-axis\",maskColor:\"rgba(0,0,0,0.4)\",maskOppAxisColor:\"rgba(0,0,0,0.2)\",slideBoxFill:\"transparent\",slideBoxCursor:\"ew-resize\",grabAreaFill:\"transparent\",grabAreaCursor:\"col-resize\",grabAreaWidth:10,handleWidth:4,handleRadius:1,handleStrokeWidth:1,extraPad:15}},{}],737:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plot_api/plot_template\"),a=t(\"../../plots/cartesian/axis_ids\"),o=t(\"./attributes\"),s=t(\"./oppaxis_attributes\");e.exports=function(t,e,r){var l=t[r],c=e[r];if(l.rangeslider||e._requestRangeslider[c._id]){n.isPlainObject(l.rangeslider)||(l.rangeslider={});var u,f,h=l.rangeslider,p=i.newContainer(c,\"rangeslider\");if(_(\"visible\")){_(\"bgcolor\",e.plot_bgcolor),_(\"bordercolor\"),_(\"borderwidth\"),_(\"thickness\"),_(\"autorange\",!c.isValidRange(h.range)),_(\"range\");var d=e._subplots;if(d)for(var m=d.cartesian.filter((function(t){return t.substr(0,t.indexOf(\"y\"))===a.name2id(r)})).map((function(t){return t.substr(t.indexOf(\"y\"),t.length)})),g=n.simpleMap(m,a.id2name),v=0;v<g.length;v++){var y=g[v];u=h[y]||{},f=i.newContainer(p,y,\"yaxis\");var x,b=e[y];u.range&&b.isValidRange(u.range)&&(x=\"fixed\"),\"match\"!==w(\"rangemode\",x)&&w(\"range\",b.range.slice())}p._input=h}}function _(t,e){return n.coerce(h,p,o,t,e)}function w(t,e){return n.coerce(u,f,s,t,e)}}},{\"../../lib\":799,\"../../plot_api/plot_template\":838,\"../../plots/cartesian/axis_ids\":853,\"./attributes\":734,\"./oppaxis_attributes\":741}],738:[function(t,e,r){\"use strict\";var n=t(\"@plotly/d3\"),i=t(\"../../registry\"),a=t(\"../../plots/plots\"),o=t(\"../../lib\"),s=o.strTranslate,l=t(\"../drawing\"),c=t(\"../color\"),u=t(\"../titles\"),f=t(\"../../plots/cartesian\"),h=t(\"../../plots/cartesian/axis_ids\"),p=t(\"../dragelement\"),d=t(\"../../lib/setcursor\"),m=t(\"./constants\");function g(t,e,r,n){var i=o.ensureSingle(t,\"rect\",m.bgClassName,(function(t){t.attr({x:0,y:0,\"shape-rendering\":\"crispEdges\"})})),a=n.borderwidth%2==0?n.borderwidth:n.borderwidth-1,c=-n._offsetShift,u=l.crispRound(e,n.borderwidth);i.attr({width:n._width+a,height:n._height+a,transform:s(c,c),fill:n.bgcolor,stroke:n.bordercolor,\"stroke-width\":u})}function v(t,e,r,n){var i=e._fullLayout;o.ensureSingleById(i._topdefs,\"clipPath\",n._clipId,(function(t){t.append(\"rect\").attr({x:0,y:0})})).select(\"rect\").attr({width:n._width,height:n._height})}function y(t,e,r,i){var s,c=e.calcdata,u=t.selectAll(\"g.\"+m.rangePlotClassName).data(r._subplotsWith,o.identity);u.enter().append(\"g\").attr(\"class\",(function(t){return m.rangePlotClassName+\" \"+t})).call(l.setClipUrl,i._clipId,e),u.order(),u.exit().remove(),u.each((function(t,o){var l=n.select(this),u=0===o,p=h.getFromId(e,t,\"y\"),d=p._name,m=i[d],g={data:[],layout:{xaxis:{type:r.type,domain:[0,1],range:i.range.slice(),calendar:r.calendar},width:i._width,height:i._height,margin:{t:0,b:0,l:0,r:0}},_context:e._context};r.rangebreaks&&(g.layout.xaxis.rangebreaks=r.rangebreaks),g.layout[d]={type:p.type,domain:[0,1],range:\"match\"!==m.rangemode?m.range.slice():p.range.slice(),calendar:p.calendar},p.rangebreaks&&(g.layout[d].rangebreaks=p.rangebreaks),a.supplyDefaults(g);var v=g._fullLayout.xaxis,y=g._fullLayout[d];v.clearCalc(),v.setScale(),y.clearCalc(),y.setScale();var x={id:t,plotgroup:l,xaxis:v,yaxis:y,isRangePlot:!0};u?s=x:(x.mainplot=\"xy\",x.mainplotinfo=s),f.rangePlot(e,x,function(t,e){for(var r=[],n=0;n<t.length;n++){var i=t[n],a=i[0].trace;a.xaxis+a.yaxis===e&&r.push(i)}return r}(c,t))}))}function x(t,e,r,n,i){(o.ensureSingle(t,\"rect\",m.maskMinClassName,(function(t){t.attr({x:0,y:0,\"shape-rendering\":\"crispEdges\"})})).attr(\"height\",n._height).call(c.fill,m.maskColor),o.ensureSingle(t,\"rect\",m.maskMaxClassName,(function(t){t.attr({y:0,\"shape-rendering\":\"crispEdges\"})})).attr(\"height\",n._height).call(c.fill,m.maskColor),\"match\"!==i.rangemode)&&(o.ensureSingle(t,\"rect\",m.maskMinOppAxisClassName,(function(t){t.attr({y:0,\"shape-rendering\":\"crispEdges\"})})).attr(\"width\",n._width).call(c.fill,m.maskOppAxisColor),o.ensureSingle(t,\"rect\",m.maskMaxOppAxisClassName,(function(t){t.attr({y:0,\"shape-rendering\":\"crispEdges\"})})).attr(\"width\",n._width).style(\"border-top\",m.maskOppBorder).call(c.fill,m.maskOppAxisColor))}function b(t,e,r,n){e._context.staticPlot||o.ensureSingle(t,\"rect\",m.slideBoxClassName,(function(t){t.attr({y:0,cursor:m.slideBoxCursor,\"shape-rendering\":\"crispEdges\"})})).attr({height:n._height,fill:m.slideBoxFill})}function _(t,e,r,n){var i=o.ensureSingle(t,\"g\",m.grabberMinClassName),a=o.ensureSingle(t,\"g\",m.grabberMaxClassName),s={x:0,width:m.handleWidth,rx:m.handleRadius,fill:c.background,stroke:c.defaultLine,\"stroke-width\":m.handleStrokeWidth,\"shape-rendering\":\"crispEdges\"},l={y:Math.round(n._height/4),height:Math.round(n._height/2)};o.ensureSingle(i,\"rect\",m.handleMinClassName,(function(t){t.attr(s)})).attr(l),o.ensureSingle(a,\"rect\",m.handleMaxClassName,(function(t){t.attr(s)})).attr(l);var u={width:m.grabAreaWidth,x:0,y:0,fill:m.grabAreaFill,cursor:e._context.staticPlot?void 0:m.grabAreaCursor};o.ensureSingle(i,\"rect\",m.grabAreaMinClassName,(function(t){t.attr(u)})).attr(\"height\",n._height),o.ensureSingle(a,\"rect\",m.grabAreaMaxClassName,(function(t){t.attr(u)})).attr(\"height\",n._height)}e.exports=function(t){for(var e=t._fullLayout,r=e._rangeSliderData,a=0;a<r.length;a++){var l=r[a][m.name];l._clipId=l._id+\"-\"+e._uid}var c=e._infolayer.selectAll(\"g.\"+m.containerClassName).data(r,(function(t){return t._name}));c.exit().each((function(t){var r=t[m.name];e._topdefs.select(\"#\"+r._clipId).remove()})).remove(),0!==r.length&&(c.enter().append(\"g\").classed(m.containerClassName,!0).attr(\"pointer-events\",\"all\"),c.each((function(r){var a=n.select(this),l=r[m.name],c=e[h.id2name(r.anchor)],f=l[h.id2name(r.anchor)];if(l.range){var w,T=o.simpleMap(l.range,r.r2l),k=o.simpleMap(r.range,r.r2l);w=k[0]<k[1]?[Math.min(T[0],k[0]),Math.max(T[1],k[1])]:[Math.max(T[0],k[0]),Math.min(T[1],k[1])],l.range=l._input.range=o.simpleMap(w,r.l2r)}r.cleanRange(\"rangeslider.range\");var M=e._size,A=r.domain;l._width=M.w*(A[1]-A[0]);var S=Math.round(M.l+M.w*A[0]),E=Math.round(M.t+M.h*(1-r._counterDomainMin)+(\"bottom\"===r.side?r._depth:0)+l._offsetShift+m.extraPad);a.attr(\"transform\",s(S,E)),l._rl=o.simpleMap(l.range,r.r2l);var L=l._rl[0],C=l._rl[1],P=C-L;if(l.p2d=function(t){return t/l._width*P+L},l.d2p=function(t){return(t-L)/P*l._width},r.rangebreaks){var I=r.locateBreaks(L,C);if(I.length){var O,z,D=0;for(O=0;O<I.length;O++)D+=(z=I[O]).max-z.min;var R=l._width/(C-L-D),F=[-R*L];for(O=0;O<I.length;O++)z=I[O],F.push(F[F.length-1]-R*(z.max-z.min));for(l.d2p=function(t){for(var e=F[0],r=0;r<I.length;r++){var n=I[r];if(t>=n.max)e=F[r+1];else if(t<n.min)break}return e+R*t},O=0;O<I.length;O++)(z=I[O]).pmin=l.d2p(z.min),z.pmax=l.d2p(z.max);l.p2d=function(t){for(var e=F[0],r=0;r<I.length;r++){var n=I[r];if(t>=n.pmax)e=F[r+1];else if(t<n.pmin)break}return(t-e)/R}}}if(\"match\"!==f.rangemode){var B=c.r2l(f.range[0]),N=c.r2l(f.range[1])-B;l.d2pOppAxis=function(t){return(t-B)/N*l._height}}a.call(g,t,r,l).call(v,t,r,l).call(y,t,r,l).call(x,t,r,l,f).call(b,t,r,l).call(_,t,r,l),function(t,e,r,a){if(e._context.staticPlot)return;var s=t.select(\"rect.\"+m.slideBoxClassName).node(),l=t.select(\"rect.\"+m.grabAreaMinClassName).node(),c=t.select(\"rect.\"+m.grabAreaMaxClassName).node();function u(){var u=n.event,f=u.target,h=u.clientX||u.touches[0].clientX,m=h-t.node().getBoundingClientRect().left,g=a.d2p(r._rl[0]),v=a.d2p(r._rl[1]),y=p.coverSlip();function x(t){var u,p,x,b=+(t.clientX||t.touches[0].clientX)-h;switch(f){case s:x=\"ew-resize\",u=g+b,p=v+b;break;case l:x=\"col-resize\",u=g+b,p=v;break;case c:x=\"col-resize\",u=g,p=v+b;break;default:x=\"ew-resize\",u=m,p=m+b}if(p<u){var _=p;p=u,u=_}a._pixelMin=u,a._pixelMax=p,d(n.select(y),x),function(t,e,r,n){function a(t){return r.l2r(o.constrain(t,n._rl[0],n._rl[1]))}var s=a(n.p2d(n._pixelMin)),l=a(n.p2d(n._pixelMax));window.requestAnimationFrame((function(){i.call(\"_guiRelayout\",e,r._name+\".range\",[s,l])}))}(0,e,r,a)}function b(){y.removeEventListener(\"mousemove\",x),y.removeEventListener(\"mouseup\",b),this.removeEventListener(\"touchmove\",x),this.removeEventListener(\"touchend\",b),o.removeElement(y)}this.addEventListener(\"touchmove\",x),this.addEventListener(\"touchend\",b),y.addEventListener(\"mousemove\",x),y.addEventListener(\"mouseup\",b)}t.on(\"mousedown\",u),t.on(\"touchstart\",u)}(a,t,r,l),function(t,e,r,n,i,a){var l=m.handleWidth/2;function c(t){return o.constrain(t,0,n._width)}function u(t){return o.constrain(t,0,n._height)}function f(t){return o.constrain(t,-l,n._width+l)}var h=c(n.d2p(r._rl[0])),p=c(n.d2p(r._rl[1]));if(t.select(\"rect.\"+m.slideBoxClassName).attr(\"x\",h).attr(\"width\",p-h),t.select(\"rect.\"+m.maskMinClassName).attr(\"width\",h),t.select(\"rect.\"+m.maskMaxClassName).attr(\"x\",p).attr(\"width\",n._width-p),\"match\"!==a.rangemode){var d=n._height-u(n.d2pOppAxis(i._rl[1])),g=n._height-u(n.d2pOppAxis(i._rl[0]));t.select(\"rect.\"+m.maskMinOppAxisClassName).attr(\"x\",h).attr(\"height\",d).attr(\"width\",p-h),t.select(\"rect.\"+m.maskMaxOppAxisClassName).attr(\"x\",h).attr(\"y\",g).attr(\"height\",n._height-g).attr(\"width\",p-h),t.select(\"rect.\"+m.slideBoxClassName).attr(\"y\",d).attr(\"height\",g-d)}var v=Math.round(f(h-l))-.5,y=Math.round(f(p-l))+.5;t.select(\"g.\"+m.grabberMinClassName).attr(\"transform\",s(v,.5)),t.select(\"g.\"+m.grabberMaxClassName).attr(\"transform\",s(y,.5))}(a,0,r,l,c,f),\"bottom\"===r.side&&u.draw(t,r._id+\"title\",{propContainer:r,propName:r._name+\".title\",placeholder:e._dfltTitle.x,attributes:{x:r._offset+r._length/2,y:E+l._height+l._offsetShift+10+1.5*r.title.font.size,\"text-anchor\":\"middle\"}})})))}},{\"../../lib\":799,\"../../lib/setcursor\":820,\"../../plots/cartesian\":863,\"../../plots/cartesian/axis_ids\":853,\"../../plots/plots\":913,\"../../registry\":927,\"../color\":662,\"../dragelement\":681,\"../drawing\":684,\"../titles\":760,\"./constants\":736,\"@plotly/d3\":58}],739:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axis_ids\"),i=t(\"../../lib/svg_text_utils\"),a=t(\"./constants\"),o=t(\"../../constants/alignment\").LINE_SPACING,s=a.name;function l(t){var e=t&&t[s];return e&&e.visible}r.isVisible=l,r.makeData=function(t){var e=n.list({_fullLayout:t},\"x\",!0),r=t.margin,i=[];if(!t._has(\"gl2d\"))for(var a=0;a<e.length;a++){var o=e[a];if(l(o)){i.push(o);var c=o[s];c._id=s+o._id,c._height=(t.height-r.b-r.t)*c.thickness,c._offsetShift=Math.floor(c.borderwidth/2)}}t._rangeSliderData=i},r.autoMarginOpts=function(t,e){var r=t._fullLayout,n=e[s],l=e._id.charAt(0),c=0,u=0;\"bottom\"===e.side&&(c=e._depth,e.title.text!==r._dfltTitle[l]&&(u=1.5*e.title.font.size+10+n._offsetShift,u+=(e.title.text.match(i.BR_TAG_ALL)||[]).length*e.title.font.size*o));return{x:0,y:e._counterDomainMin,l:0,r:0,t:0,b:n._height+c+Math.max(r.margin.b,u),pad:a.extraPad+2*n._offsetShift}}},{\"../../constants/alignment\":767,\"../../lib/svg_text_utils\":824,\"../../plots/cartesian/axis_ids\":853,\"./constants\":736}],740:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\"),a=t(\"./oppaxis_attributes\"),o=t(\"./helpers\");e.exports={moduleType:\"component\",name:\"rangeslider\",schema:{subplots:{xaxis:{rangeslider:n.extendFlat({},i,{yaxis:a})}}},layoutAttributes:t(\"./attributes\"),handleDefaults:t(\"./defaults\"),calcAutorange:t(\"./calc_autorange\"),draw:t(\"./draw\"),isVisible:o.isVisible,makeData:o.makeData,autoMarginOpts:o.autoMarginOpts}},{\"../../lib\":799,\"./attributes\":734,\"./calc_autorange\":735,\"./defaults\":737,\"./draw\":738,\"./helpers\":739,\"./oppaxis_attributes\":741}],741:[function(t,e,r){\"use strict\";e.exports={_isSubplotObj:!0,rangemode:{valType:\"enumerated\",values:[\"auto\",\"fixed\",\"match\"],dflt:\"match\",editType:\"calc\"},range:{valType:\"info_array\",items:[{valType:\"any\",editType:\"plot\"},{valType:\"any\",editType:\"plot\"}],editType:\"plot\"},editType:\"calc\"}},{}],742:[function(t,e,r){\"use strict\";var n=t(\"../annotations/attributes\"),i=t(\"../../traces/scatter/attributes\").line,a=t(\"../drawing/attributes\").dash,o=t(\"../../lib/extend\").extendFlat,s=t(\"../../plot_api/plot_template\").templatedArray;t(\"../../constants/axis_placeable_objects\");e.exports=s(\"shape\",{visible:{valType:\"boolean\",dflt:!0,editType:\"calc+arraydraw\"},type:{valType:\"enumerated\",values:[\"circle\",\"rect\",\"path\",\"line\"],editType:\"calc+arraydraw\"},layer:{valType:\"enumerated\",values:[\"below\",\"above\"],dflt:\"above\",editType:\"arraydraw\"},xref:o({},n.xref,{}),xsizemode:{valType:\"enumerated\",values:[\"scaled\",\"pixel\"],dflt:\"scaled\",editType:\"calc+arraydraw\"},xanchor:{valType:\"any\",editType:\"calc+arraydraw\"},x0:{valType:\"any\",editType:\"calc+arraydraw\"},x1:{valType:\"any\",editType:\"calc+arraydraw\"},yref:o({},n.yref,{}),ysizemode:{valType:\"enumerated\",values:[\"scaled\",\"pixel\"],dflt:\"scaled\",editType:\"calc+arraydraw\"},yanchor:{valType:\"any\",editType:\"calc+arraydraw\"},y0:{valType:\"any\",editType:\"calc+arraydraw\"},y1:{valType:\"any\",editType:\"calc+arraydraw\"},path:{valType:\"string\",editType:\"calc+arraydraw\"},opacity:{valType:\"number\",min:0,max:1,dflt:1,editType:\"arraydraw\"},line:{color:o({},i.color,{editType:\"arraydraw\"}),width:o({},i.width,{editType:\"calc+arraydraw\"}),dash:o({},a,{editType:\"arraydraw\"}),editType:\"calc+arraydraw\"},fillcolor:{valType:\"color\",dflt:\"rgba(0,0,0,0)\",editType:\"arraydraw\"},fillrule:{valType:\"enumerated\",values:[\"evenodd\",\"nonzero\"],dflt:\"evenodd\",editType:\"arraydraw\"},editable:{valType:\"boolean\",dflt:!1,editType:\"calc+arraydraw\"},editType:\"arraydraw\"})},{\"../../constants/axis_placeable_objects\":768,\"../../lib/extend\":789,\"../../plot_api/plot_template\":838,\"../../traces/scatter/attributes\":1214,\"../annotations/attributes\":645,\"../drawing/attributes\":683}],743:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"./constants\"),o=t(\"./helpers\");function s(t){return c(t.line.width,t.xsizemode,t.x0,t.x1,t.path,!1)}function l(t){return c(t.line.width,t.ysizemode,t.y0,t.y1,t.path,!0)}function c(t,e,r,i,s,l){var c=t/2,u=l;if(\"pixel\"===e){var f=s?o.extractPathCoords(s,l?a.paramIsY:a.paramIsX):[r,i],h=n.aggNums(Math.max,null,f),p=n.aggNums(Math.min,null,f),d=p<0?Math.abs(p)+c:c,m=h>0?h+c:c;return{ppad:c,ppadplus:u?d:m,ppadminus:u?m:d}}return{ppad:c}}function u(t,e,r,n,i){var s=\"category\"===t.type||\"multicategory\"===t.type?t.r2c:t.d2c;if(void 0!==e)return[s(e),s(r)];if(n){var l,c,u,f,h=1/0,p=-1/0,d=n.match(a.segmentRE);for(\"date\"===t.type&&(s=o.decodeDate(s)),l=0;l<d.length;l++)void 0!==(c=i[d[l].charAt(0)].drawn)&&(!(u=d[l].substr(1).match(a.paramRE))||u.length<c||((f=s(u[c]))<h&&(h=f),f>p&&(p=f)));return p>=h?[h,p]:void 0}}e.exports=function(t){var e=t._fullLayout,r=n.filterVisible(e.shapes);if(r.length&&t._fullData.length)for(var o=0;o<r.length;o++){var c,f,h=r[o];h._extremes={};var p=i.getRefType(h.xref),d=i.getRefType(h.yref);if(\"paper\"!==h.xref&&\"domain\"!==p){var m=\"pixel\"===h.xsizemode?h.xanchor:h.x0,g=\"pixel\"===h.xsizemode?h.xanchor:h.x1;(f=u(c=i.getFromId(t,h.xref),m,g,h.path,a.paramIsX))&&(h._extremes[c._id]=i.findExtremes(c,f,s(h)))}if(\"paper\"!==h.yref&&\"domain\"!==d){var v=\"pixel\"===h.ysizemode?h.yanchor:h.y0,y=\"pixel\"===h.ysizemode?h.yanchor:h.y1;(f=u(c=i.getFromId(t,h.yref),v,y,h.path,a.paramIsY))&&(h._extremes[c._id]=i.findExtremes(c,f,l(h)))}}}},{\"../../lib\":799,\"../../plots/cartesian/axes\":849,\"./constants\":744,\"./helpers\":753}],744:[function(t,e,r){\"use strict\";e.exports={segmentRE:/[MLHVQCTSZ][^MLHVQCTSZ]*/g,paramRE:/[^\\s,]+/g,paramIsX:{M:{0:!0,drawn:0},L:{0:!0,drawn:0},H:{0:!0,drawn:0},V:{},Q:{0:!0,2:!0,drawn:2},C:{0:!0,2:!0,4:!0,drawn:4},T:{0:!0,drawn:0},S:{0:!0,2:!0,drawn:2},Z:{}},paramIsY:{M:{1:!0,drawn:1},L:{1:!0,drawn:1},H:{},V:{0:!0,drawn:0},Q:{1:!0,3:!0,drawn:3},C:{1:!0,3:!0,5:!0,drawn:5},T:{1:!0,drawn:1},S:{1:!0,3:!0,drawn:5},Z:{}},numParams:{M:2,L:2,H:1,V:1,Q:4,C:6,T:2,S:4,Z:0}}},{}],745:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../../plots/array_container_defaults\"),o=t(\"./attributes\"),s=t(\"./helpers\");function l(t,e,r){function a(r,i){return n.coerce(t,e,o,r,i)}if(a(\"visible\")){var l=a(\"path\"),c=a(\"type\",l?\"path\":\"rect\");\"path\"!==e.type&&delete e.path,a(\"editable\"),a(\"layer\"),a(\"opacity\"),a(\"fillcolor\"),a(\"fillrule\"),a(\"line.width\")&&(a(\"line.color\"),a(\"line.dash\"));for(var u=a(\"xsizemode\"),f=a(\"ysizemode\"),h=[\"x\",\"y\"],p=0;p<2;p++){var d,m,g,v=h[p],y=v+\"anchor\",x=\"x\"===v?u:f,b={_fullLayout:r},_=i.coerceRef(t,e,b,v,void 0,\"paper\");if(\"range\"===i.getRefType(_)?((d=i.getFromId(b,_))._shapeIndices.push(e._index),g=s.rangeToShapePosition(d),m=s.shapePositionToRange(d)):m=g=n.identity,\"path\"!==c){var w=v+\"0\",T=v+\"1\",k=t[w],M=t[T];t[w]=m(t[w],!0),t[T]=m(t[T],!0),\"pixel\"===x?(a(w,0),a(T,10)):(i.coercePosition(e,b,a,_,w,.25),i.coercePosition(e,b,a,_,T,.75)),e[w]=g(e[w]),e[T]=g(e[T]),t[w]=k,t[T]=M}if(\"pixel\"===x){var A=t[y];t[y]=m(t[y],!0),i.coercePosition(e,b,a,_,y,.25),e[y]=g(e[y]),t[y]=A}}\"path\"===c?a(\"path\"):n.noneOrAll(t,e,[\"x0\",\"x1\",\"y0\",\"y1\"])}}e.exports=function(t,e){a(t,e,{name:\"shapes\",handleItemDefaults:l})}},{\"../../lib\":799,\"../../plots/array_container_defaults\":844,\"../../plots/cartesian/axes\":849,\"./attributes\":742,\"./helpers\":753}],746:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"../../plots/cartesian/axes\"),o=t(\"./draw_newshape/helpers\").readPaths,s=t(\"./draw_newshape/display_outlines\"),l=t(\"../../plots/cartesian/handle_outline\").clearOutlineControllers,c=t(\"../color\"),u=t(\"../drawing\"),f=t(\"../../plot_api/plot_template\").arrayEditor,h=t(\"../dragelement\"),p=t(\"../../lib/setcursor\"),d=t(\"./constants\"),m=t(\"./helpers\");function g(t){var e=t._fullLayout;for(var r in e._shapeUpperLayer.selectAll(\"path\").remove(),e._shapeLowerLayer.selectAll(\"path\").remove(),e._plots){var n=e._plots[r].shapelayer;n&&n.selectAll(\"path\").remove()}for(var i=0;i<e.shapes.length;i++)e.shapes[i].visible&&x(t,i)}function v(t){return!!t._fullLayout._drawing}function y(t){return!t._context.edits.shapePosition}function x(t,e){t._fullLayout._paperdiv.selectAll('.shapelayer [data-index=\"'+e+'\"]').remove();var r=m.makeOptionsAndPlotinfo(t,e),l=r.options,x=r.plotinfo;if(l._input&&!1!==l.visible)if(\"below\"!==l.layer)k(t._fullLayout._shapeUpperLayer);else if(\"paper\"===l.xref||\"paper\"===l.yref)k(t._fullLayout._shapeLowerLayer);else{if(x._hadPlotinfo)k((x.mainplotinfo||x).shapelayer);else k(t._fullLayout._shapeLowerLayer)}function k(r){var k=_(t,l),M={\"data-index\":e,\"fill-rule\":l.fillrule,d:k},A=l.opacity,S=l.fillcolor,E=l.line.width?l.line.color:\"rgba(0,0,0,0)\",L=l.line.width,C=l.line.dash;L||!0!==l.editable||(L=5,C=\"solid\");var P=\"Z\"!==k[k.length-1],I=y(t)&&l.editable&&t._fullLayout._activeShapeIndex===e;I&&(S=P?\"rgba(0,0,0,0)\":t._fullLayout.activeshape.fillcolor,A=t._fullLayout.activeshape.opacity);var O,z=r.append(\"path\").attr(M).style(\"opacity\",A).call(c.stroke,E).call(c.fill,S).call(u.dashLine,C,L);if(b(z,t,l),(I||t._context.edits.shapePosition)&&(O=f(t.layout,\"shapes\",l)),I){z.style({cursor:\"move\"});var D={element:z.node(),plotinfo:x,gd:t,editHelpers:O,isActiveShape:!0},R=o(k,t);s(R,z,D)}else t._context.edits.shapePosition?function(t,e,r,o,s,l){var c,f,g,y,x,T,k,M,A,S,E,L,C,P,I,O,z=\"pixel\"===r.xsizemode,D=\"pixel\"===r.ysizemode,R=\"line\"===r.type,F=\"path\"===r.type,B=l.modifyItem,N=a.getFromId(t,r.xref),j=a.getRefType(r.xref),U=a.getFromId(t,r.yref),V=a.getRefType(r.yref),q=m.getDataToPixel(t,N,!1,j),H=m.getDataToPixel(t,U,!0,V),G=m.getPixelToData(t,N,!1,j),Y=m.getPixelToData(t,U,!0,V),W=R?function(){var t=Math.max(r.line.width,10),n=s.append(\"g\").attr(\"data-index\",o);n.append(\"path\").attr(\"d\",e.attr(\"d\")).style({cursor:\"move\",\"stroke-width\":t,\"stroke-opacity\":\"0\"});var i={\"fill-opacity\":\"0\"},a=Math.max(t/2,10);return n.append(\"circle\").attr({\"data-line-point\":\"start-point\",cx:z?q(r.xanchor)+r.x0:q(r.x0),cy:D?H(r.yanchor)-r.y0:H(r.y0),r:a}).style(i).classed(\"cursor-grab\",!0),n.append(\"circle\").attr({\"data-line-point\":\"end-point\",cx:z?q(r.xanchor)+r.x1:q(r.x1),cy:D?H(r.yanchor)-r.y1:H(r.y1),r:a}).style(i).classed(\"cursor-grab\",!0),n}():e,X={element:W.node(),gd:t,prepFn:function(n){if(v(t))return;z&&(x=q(r.xanchor));D&&(T=H(r.yanchor));\"path\"===r.type?I=r.path:(c=z?r.x0:q(r.x0),f=D?r.y0:H(r.y0),g=z?r.x1:q(r.x1),y=D?r.y1:H(r.y1));c<g?(A=c,C=\"x0\",S=g,P=\"x1\"):(A=g,C=\"x1\",S=c,P=\"x0\");!D&&f<y||D&&f>y?(k=f,E=\"y0\",M=y,L=\"y1\"):(k=y,E=\"y1\",M=f,L=\"y0\");Z(n),Q(s,r),function(t,e,r){var n=e.xref,i=e.yref,o=a.getFromId(r,n),s=a.getFromId(r,i),l=\"\";\"paper\"===n||o.autorange||(l+=n);\"paper\"===i||s.autorange||(l+=i);u.setClipUrl(t,l?\"clip\"+r._fullLayout._uid+l:null,r)}(e,r,t),X.moveFn=\"move\"===O?J:K,X.altKey=n.altKey},doneFn:function(){if(v(t))return;p(e),$(s),b(e,t,r),n.call(\"_guiRelayout\",t,l.getUpdateObj())},clickFn:function(){if(v(t))return;$(s)}};function Z(r){if(v(t))O=null;else if(R)O=\"path\"===r.target.tagName?\"move\":\"start-point\"===r.target.attributes[\"data-line-point\"].value?\"resize-over-start-point\":\"resize-over-end-point\";else{var n=X.element.getBoundingClientRect(),i=n.right-n.left,a=n.bottom-n.top,o=r.clientX-n.left,s=r.clientY-n.top,l=!F&&i>10&&a>10&&!r.shiftKey?h.getCursor(o/i,1-s/a):\"move\";p(e,l),O=l.split(\"-\")[0]}}function J(n,i){if(\"path\"===r.type){var a=function(t){return t},o=a,l=a;z?B(\"xanchor\",r.xanchor=G(x+n)):(o=function(t){return G(q(t)+n)},N&&\"date\"===N.type&&(o=m.encodeDate(o))),D?B(\"yanchor\",r.yanchor=Y(T+i)):(l=function(t){return Y(H(t)+i)},U&&\"date\"===U.type&&(l=m.encodeDate(l))),B(\"path\",r.path=w(I,o,l))}else z?B(\"xanchor\",r.xanchor=G(x+n)):(B(\"x0\",r.x0=G(c+n)),B(\"x1\",r.x1=G(g+n))),D?B(\"yanchor\",r.yanchor=Y(T+i)):(B(\"y0\",r.y0=Y(f+i)),B(\"y1\",r.y1=Y(y+i)));e.attr(\"d\",_(t,r)),Q(s,r)}function K(n,i){if(F){var a=function(t){return t},o=a,l=a;z?B(\"xanchor\",r.xanchor=G(x+n)):(o=function(t){return G(q(t)+n)},N&&\"date\"===N.type&&(o=m.encodeDate(o))),D?B(\"yanchor\",r.yanchor=Y(T+i)):(l=function(t){return Y(H(t)+i)},U&&\"date\"===U.type&&(l=m.encodeDate(l))),B(\"path\",r.path=w(I,o,l))}else if(R){if(\"resize-over-start-point\"===O){var u=c+n,h=D?f-i:f+i;B(\"x0\",r.x0=z?u:G(u)),B(\"y0\",r.y0=D?h:Y(h))}else if(\"resize-over-end-point\"===O){var p=g+n,d=D?y-i:y+i;B(\"x1\",r.x1=z?p:G(p)),B(\"y1\",r.y1=D?d:Y(d))}}else{var v=function(t){return-1!==O.indexOf(t)},b=v(\"n\"),j=v(\"s\"),V=v(\"w\"),W=v(\"e\"),X=b?k+i:k,Z=j?M+i:M,J=V?A+n:A,K=W?S+n:S;D&&(b&&(X=k-i),j&&(Z=M-i)),(!D&&Z-X>10||D&&X-Z>10)&&(B(E,r[E]=D?X:Y(X)),B(L,r[L]=D?Z:Y(Z))),K-J>10&&(B(C,r[C]=z?J:G(J)),B(P,r[P]=z?K:G(K)))}e.attr(\"d\",_(t,r)),Q(s,r)}function Q(t,e){(z||D)&&function(){var r=\"path\"!==e.type,n=t.selectAll(\".visual-cue\").data([0]);n.enter().append(\"path\").attr({fill:\"#fff\",\"fill-rule\":\"evenodd\",stroke:\"#000\",\"stroke-width\":1}).classed(\"visual-cue\",!0);var a=q(z?e.xanchor:i.midRange(r?[e.x0,e.x1]:m.extractPathCoords(e.path,d.paramIsX))),o=H(D?e.yanchor:i.midRange(r?[e.y0,e.y1]:m.extractPathCoords(e.path,d.paramIsY)));if(a=m.roundPositionForSharpStrokeRendering(a,1),o=m.roundPositionForSharpStrokeRendering(o,1),z&&D){var s=\"M\"+(a-1-1)+\",\"+(o-1-1)+\"h-8v2h8 v8h2v-8 h8v-2h-8 v-8h-2 Z\";n.attr(\"d\",s)}else if(z){var l=\"M\"+(a-1-1)+\",\"+(o-9-1)+\"v18 h2 v-18 Z\";n.attr(\"d\",l)}else{var c=\"M\"+(a-9-1)+\",\"+(o-1-1)+\"h18 v2 h-18 Z\";n.attr(\"d\",c)}}()}function $(t){t.selectAll(\".visual-cue\").remove()}h.init(X),W.node().onmousemove=Z}(t,z,l,e,r,O):!0===l.editable&&z.style(\"pointer-events\",P||c.opacity(S)*A<=.5?\"stroke\":\"all\");z.node().addEventListener(\"click\",(function(){return function(t,e){if(!y(t))return;var r=+e.node().getAttribute(\"data-index\");if(r>=0){if(r===t._fullLayout._activeShapeIndex)return void T(t);t._fullLayout._activeShapeIndex=r,t._fullLayout._deactivateShape=T,g(t)}}(t,z)}))}}function b(t,e,r){var n=(r.xref+r.yref).replace(/paper/g,\"\").replace(/[xyz][1-9]* *domain/g,\"\");u.setClipUrl(t,n?\"clip\"+e._fullLayout._uid+n:null,e)}function _(t,e){var r,n,o,s,l,c,u,f,h=e.type,p=a.getRefType(e.xref),g=a.getRefType(e.yref),v=a.getFromId(t,e.xref),y=a.getFromId(t,e.yref),x=t._fullLayout._size;if(v?\"domain\"===p?n=function(t){return v._offset+v._length*t}:(r=m.shapePositionToRange(v),n=function(t){return v._offset+v.r2p(r(t,!0))}):n=function(t){return x.l+x.w*t},y?\"domain\"===g?s=function(t){return y._offset+y._length*(1-t)}:(o=m.shapePositionToRange(y),s=function(t){return y._offset+y.r2p(o(t,!0))}):s=function(t){return x.t+x.h*(1-t)},\"path\"===h)return v&&\"date\"===v.type&&(n=m.decodeDate(n)),y&&\"date\"===y.type&&(s=m.decodeDate(s)),function(t,e,r){var n=t.path,a=t.xsizemode,o=t.ysizemode,s=t.xanchor,l=t.yanchor;return n.replace(d.segmentRE,(function(t){var n=0,c=t.charAt(0),u=d.paramIsX[c],f=d.paramIsY[c],h=d.numParams[c],p=t.substr(1).replace(d.paramRE,(function(t){return u[n]?t=\"pixel\"===a?e(s)+Number(t):e(t):f[n]&&(t=\"pixel\"===o?r(l)-Number(t):r(t)),++n>h&&(t=\"X\"),t}));return n>h&&(p=p.replace(/[\\s,]*X.*/,\"\"),i.log(\"Ignoring extra params in segment \"+t)),c+p}))}(e,n,s);if(\"pixel\"===e.xsizemode){var b=n(e.xanchor);l=b+e.x0,c=b+e.x1}else l=n(e.x0),c=n(e.x1);if(\"pixel\"===e.ysizemode){var _=s(e.yanchor);u=_-e.y0,f=_-e.y1}else u=s(e.y0),f=s(e.y1);if(\"line\"===h)return\"M\"+l+\",\"+u+\"L\"+c+\",\"+f;if(\"rect\"===h)return\"M\"+l+\",\"+u+\"H\"+c+\"V\"+f+\"H\"+l+\"Z\";var w=(l+c)/2,T=(u+f)/2,k=Math.abs(w-l),M=Math.abs(T-u),A=\"A\"+k+\",\"+M,S=w+k+\",\"+T;return\"M\"+S+A+\" 0 1,1 \"+(w+\",\"+(T-M))+A+\" 0 0,1 \"+S+\"Z\"}function w(t,e,r){return t.replace(d.segmentRE,(function(t){var n=0,i=t.charAt(0),a=d.paramIsX[i],o=d.paramIsY[i],s=d.numParams[i];return i+t.substr(1).replace(d.paramRE,(function(t){return n>=s||(a[n]?t=e(t):o[n]&&(t=r(t)),n++),t}))}))}function T(t){y(t)&&(t._fullLayout._activeShapeIndex>=0&&(l(t),delete t._fullLayout._activeShapeIndex,g(t)))}e.exports={draw:g,drawOne:x,eraseActiveShape:function(t){if(!y(t))return;l(t);var e=t._fullLayout._activeShapeIndex,r=(t.layout||{}).shapes||[];if(e<r.length){for(var i=[],a=0;a<r.length;a++)a!==e&&i.push(r[a]);delete t._fullLayout._activeShapeIndex,n.call(\"_guiRelayout\",t,{shapes:i})}}}},{\"../../lib\":799,\"../../lib/setcursor\":820,\"../../plot_api/plot_template\":838,\"../../plots/cartesian/axes\":849,\"../../plots/cartesian/handle_outline\":860,\"../../registry\":927,\"../color\":662,\"../dragelement\":681,\"../drawing\":684,\"./constants\":744,\"./draw_newshape/display_outlines\":750,\"./draw_newshape/helpers\":751,\"./helpers\":753}],747:[function(t,e,r){\"use strict\";var n=t(\"../../drawing/attributes\").dash,i=t(\"../../../lib/extend\").extendFlat;e.exports={newshape:{line:{color:{valType:\"color\",editType:\"none\"},width:{valType:\"number\",min:0,dflt:4,editType:\"none\"},dash:i({},n,{dflt:\"solid\",editType:\"none\"}),editType:\"none\"},fillcolor:{valType:\"color\",dflt:\"rgba(0,0,0,0)\",editType:\"none\"},fillrule:{valType:\"enumerated\",values:[\"evenodd\",\"nonzero\"],dflt:\"evenodd\",editType:\"none\"},opacity:{valType:\"number\",min:0,max:1,dflt:1,editType:\"none\"},layer:{valType:\"enumerated\",values:[\"below\",\"above\"],dflt:\"above\",editType:\"none\"},drawdirection:{valType:\"enumerated\",values:[\"ortho\",\"horizontal\",\"vertical\",\"diagonal\"],dflt:\"diagonal\",editType:\"none\"},editType:\"none\"},activeshape:{fillcolor:{valType:\"color\",dflt:\"rgb(255,0,255)\",editType:\"none\"},opacity:{valType:\"number\",min:0,max:1,dflt:.5,editType:\"none\"},editType:\"none\"}}},{\"../../../lib/extend\":789,\"../../drawing/attributes\":683}],748:[function(t,e,r){\"use strict\";e.exports={CIRCLE_SIDES:32,i000:0,i090:8,i180:16,i270:24,cos45:Math.cos(Math.PI/4),sin45:Math.sin(Math.PI/4),SQRT2:Math.sqrt(2)}},{}],749:[function(t,e,r){\"use strict\";var n=t(\"../../color\");e.exports=function(t,e,r){if(r(\"newshape.drawdirection\"),r(\"newshape.layer\"),r(\"newshape.fillcolor\"),r(\"newshape.fillrule\"),r(\"newshape.opacity\"),r(\"newshape.line.width\")){var i=(t||{}).plot_bgcolor||\"#FFF\";r(\"newshape.line.color\",n.contrast(i)),r(\"newshape.line.dash\")}r(\"activeshape.fillcolor\"),r(\"activeshape.opacity\")}},{\"../../color\":662}],750:[function(t,e,r){\"use strict\";var n=t(\"../../dragelement\"),i=t(\"../../dragelement/helpers\").drawMode,a=t(\"../../../registry\"),o=t(\"./constants\"),s=o.i000,l=o.i090,c=o.i180,u=o.i270,f=t(\"../../../plots/cartesian/handle_outline\").clearOutlineControllers,h=t(\"./helpers\"),p=h.pointsShapeRectangle,d=h.pointsShapeEllipse,m=h.writePaths,g=t(\"./newshapes\");e.exports=function t(e,r,o,h){h||(h=0);var v=o.gd;function y(){t(e,r,o,h++),d(e[0])&&x({redrawing:!0})}function x(t){o.isActiveShape=!1;var e=g(r,o);Object.keys(e).length&&a.call((t||{}).redrawing?\"relayout\":\"_guiRelayout\",v,e)}var b,_,w,T,k,M=o.isActiveShape,A=v._fullLayout._zoomlayer,S=o.dragmode;(i(S)?v._fullLayout._drawing=!0:v._fullLayout._activeShapeIndex>=0&&f(v),r.attr(\"d\",m(e)),M&&!h)&&(k=function(t,e){for(var r=0;r<e.length;r++){var n=e[r];t[r]=[];for(var i=0;i<n.length;i++){t[r][i]=[];for(var a=0;a<n[i].length;a++)t[r][i][a]=n[i][a]}}return t}([],e),function(t){b=[];for(var r=0;r<e.length;r++){var i=e[r],a=!p(i)&&d(i);b[r]=[];for(var o=0;o<i.length;o++)if(\"Z\"!==i[o][0]&&(!a||o===s||o===l||o===c||o===u)){var f=i[o][1],h=i[o][2],m=t.append(\"circle\").classed(\"cursor-grab\",!0).attr(\"data-i\",r).attr(\"data-j\",o).attr(\"cx\",f).attr(\"cy\",h).attr(\"r\",4).style({\"mix-blend-mode\":\"luminosity\",fill:\"black\",stroke:\"white\",\"stroke-width\":1});b[r][o]={element:m.node(),gd:v,prepFn:E,doneFn:C,clickFn:P},n.init(b[r][o])}}}(A.append(\"g\").attr(\"class\",\"outline-controllers\")),function(){if(_=[],!e.length)return;_[0]={element:r[0][0],gd:v,prepFn:O,doneFn:z},n.init(_[0])}());function E(t){w=+t.srcElement.getAttribute(\"data-i\"),T=+t.srcElement.getAttribute(\"data-j\"),b[w][T].moveFn=L}function L(t,r){if(e.length){var n=k[w][T][1],i=k[w][T][2],a=e[w],o=a.length;if(p(a)){for(var s=0;s<o;s++)if(s!==T){var l=a[s];l[1]===a[T][1]&&(l[1]=n+t),l[2]===a[T][2]&&(l[2]=i+r)}if(a[T][1]=n+t,a[T][2]=i+r,!p(a))for(var c=0;c<o;c++)for(var u=0;u<a[c].length;u++)a[c][u]=k[w][c][u]}else a[T][1]=n+t,a[T][2]=i+r;y()}}function C(){x()}function P(t,r){if(2===t){w=+r.srcElement.getAttribute(\"data-i\"),T=+r.srcElement.getAttribute(\"data-j\");var n=e[w];p(n)||d(n)||function(){if(e.length&&e[w]&&e[w].length){for(var t=[],r=0;r<e[w].length;r++)r!==T&&t.push(e[w][r]);t.length>1&&(2!==t.length||\"Z\"!==t[1][0])&&(0===T&&(t[0][0]=\"M\"),e[w]=t,y(),x())}}()}}function I(t,r){!function(t,r){if(e.length)for(var n=0;n<e.length;n++)for(var i=0;i<e[n].length;i++)for(var a=0;a+2<e[n][i].length;a+=2)e[n][i][a+1]=k[n][i][a+1]+t,e[n][i][a+2]=k[n][i][a+2]+r}(t,r),y()}function O(t){(w=+t.srcElement.getAttribute(\"data-i\"))||(w=0),_[w].moveFn=I}function z(){x()}}},{\"../../../plots/cartesian/handle_outline\":860,\"../../../registry\":927,\"../../dragelement\":681,\"../../dragelement/helpers\":680,\"./constants\":748,\"./helpers\":751,\"./newshapes\":752}],751:[function(t,e,r){\"use strict\";var n=t(\"parse-svg-path\"),i=t(\"./constants\"),a=i.CIRCLE_SIDES,o=i.SQRT2,s=t(\"../../../plots/cartesian/helpers\"),l=s.p2r,c=s.r2p,u=[0,3,4,5,6,1,2],f=[0,3,4,1,2];function h(t,e){return Math.abs(t-e)<=1e-6}function p(t,e){var r=e[1]-t[1],n=e[2]-t[2];return Math.sqrt(r*r+n*n)}r.writePaths=function(t){var e=t.length;if(!e)return\"M0,0Z\";for(var r=\"\",n=0;n<e;n++)for(var i=t[n].length,a=0;a<i;a++){var o=t[n][a][0];if(\"Z\"===o)r+=\"Z\";else for(var s=t[n][a].length,l=0;l<s;l++){var c=l;\"Q\"===o||\"S\"===o?c=f[l]:\"C\"===o&&(c=u[l]),r+=t[n][a][c],l>0&&l<s-1&&(r+=\",\")}}return r},r.readPaths=function(t,e,r,i){var o,s,u,f=n(t),h=[],p=-1,d=0,m=0,g=function(){s=d,u=m};g();for(var v=0;v<f.length;v++){var y,x,b,_,w=[],T=f[v][0],k=T;switch(T){case\"M\":p++,h[p]=[],d=+f[v][1],m=+f[v][2],w.push([k,d,m]),g();break;case\"Q\":case\"S\":y=+f[v][1],b=+f[v][2],d=+f[v][3],m=+f[v][4],w.push([k,d,m,y,b]);break;case\"C\":y=+f[v][1],b=+f[v][2],x=+f[v][3],_=+f[v][4],d=+f[v][5],m=+f[v][6],w.push([k,d,m,y,b,x,_]);break;case\"T\":case\"L\":d=+f[v][1],m=+f[v][2],w.push([k,d,m]);break;case\"H\":k=\"L\",d=+f[v][1],w.push([k,d,m]);break;case\"V\":k=\"L\",m=+f[v][1],w.push([k,d,m]);break;case\"A\":k=\"L\";var M=+f[v][1],A=+f[v][2];+f[v][4]||(M=-M,A=-A);var S=d-M,E=m;for(o=1;o<=a/2;o++){var L=2*Math.PI*o/a;w.push([k,S+M*Math.cos(L),E+A*Math.sin(L)])}break;case\"Z\":d===s&&m===u||(d=s,m=u,w.push([k,d,m]))}for(var C=(r||{}).domain,P=e._fullLayout._size,I=r&&\"pixel\"===r.xsizemode,O=r&&\"pixel\"===r.ysizemode,z=!1===i,D=0;D<w.length;D++){for(o=0;o+2<7;o+=2){var R=w[D][o+1],F=w[D][o+2];void 0!==R&&void 0!==F&&(d=R,m=F,r&&(r.xaxis&&r.xaxis.p2r?(z&&(R-=r.xaxis._offset),R=I?c(r.xaxis,r.xanchor)+R:l(r.xaxis,R)):(z&&(R-=P.l),C?R=C.x[0]+R/P.w:R/=P.w),r.yaxis&&r.yaxis.p2r?(z&&(F-=r.yaxis._offset),F=O?c(r.yaxis,r.yanchor)-F:l(r.yaxis,F)):(z&&(F-=P.t),F=C?C.y[1]-F/P.h:1-F/P.h)),w[D][o+1]=R,w[D][o+2]=F)}h[p].push(w[D].slice())}}return h},r.pointsShapeRectangle=function(t){if(5!==t.length)return!1;for(var e=1;e<3;e++){if(!h(t[0][e]-t[1][e],t[3][e]-t[2][e]))return!1;if(!h(t[0][e]-t[3][e],t[1][e]-t[2][e]))return!1}return!(!h(t[0][1],t[1][1])&&!h(t[0][1],t[3][1]))&&!!(p(t[0],t[1])*p(t[0],t[3]))},r.pointsShapeEllipse=function(t){var e=t.length;if(e!==a+1)return!1;e=a;for(var r=0;r<e;r++){var n=(2*e-r)%e,i=(e/2+n)%e,o=(e/2+r)%e;if(!h(p(t[r],t[o]),p(t[n],t[i])))return!1}return!0},r.handleEllipse=function(t,e,n){if(!t)return[e,n];var i=r.ellipseOver({x0:e[0],y0:e[1],x1:n[0],y1:n[1]}),s=(i.x1+i.x0)/2,l=(i.y1+i.y0)/2,c=(i.x1-i.x0)/2,u=(i.y1-i.y0)/2;c||(c=u/=o),u||(u=c/=o);for(var f=[],h=0;h<a;h++){var p=2*h*Math.PI/a;f.push([s+c*Math.cos(p),l+u*Math.sin(p)])}return f},r.ellipseOver=function(t){var e=t.x0,r=t.y0,n=t.x1,i=t.y1,a=n-e,s=i-r,l=((e-=a)+n)/2,c=((r-=s)+i)/2;return{x0:l-(a*=o),y0:c-(s*=o),x1:l+a,y1:c+s}}},{\"../../../plots/cartesian/helpers\":861,\"./constants\":748,\"parse-svg-path\":489}],752:[function(t,e,r){\"use strict\";var n=t(\"../../dragelement/helpers\"),i=n.drawMode,a=n.openMode,o=t(\"./constants\"),s=o.i000,l=o.i090,c=o.i180,u=o.i270,f=o.cos45,h=o.sin45,p=t(\"../../../plots/cartesian/helpers\"),d=p.p2r,m=p.r2p,g=t(\"../../../plots/cartesian/handle_outline\").clearSelect,v=t(\"./helpers\"),y=v.readPaths,x=v.writePaths,b=v.ellipseOver;e.exports=function(t,e){if(t.length){var r=t[0][0];if(r){var n=r.getAttribute(\"d\"),o=e.gd,p=o._fullLayout.newshape,v=e.plotinfo,_=v.xaxis,w=v.yaxis,T=!!v.domain||!v.xaxis,k=!!v.domain||!v.yaxis,M=e.isActiveShape,A=e.dragmode,S=(o.layout||{}).shapes||[];if(!i(A)&&void 0!==M){var E=o._fullLayout._activeShapeIndex;if(E<S.length)switch(o._fullLayout.shapes[E].type){case\"rect\":A=\"drawrect\";break;case\"circle\":A=\"drawcircle\";break;case\"line\":A=\"drawline\";break;case\"path\":var L=S[E].path||\"\";A=\"Z\"===L[L.length-1]?\"drawclosedpath\":\"drawopenpath\"}}var C,P=a(A),I=y(n,o,v,M),O={editable:!0,xref:T?\"paper\":_._id,yref:k?\"paper\":w._id,layer:p.layer,opacity:p.opacity,line:{color:p.line.color,width:p.line.width,dash:p.line.dash}};if(P||(O.fillcolor=p.fillcolor,O.fillrule=p.fillrule),1===I.length&&(C=I[0]),C&&\"drawrect\"===A)O.type=\"rect\",O.x0=C[0][1],O.y0=C[0][2],O.x1=C[2][1],O.y1=C[2][2];else if(C&&\"drawline\"===A)O.type=\"line\",O.x0=C[0][1],O.y0=C[0][2],O.x1=C[1][1],O.y1=C[1][2];else if(C&&\"drawcircle\"===A){O.type=\"circle\";var z=C[s][1],D=C[l][1],R=C[c][1],F=C[u][1],B=C[s][2],N=C[l][2],j=C[c][2],U=C[u][2],V=v.xaxis&&(\"date\"===v.xaxis.type||\"log\"===v.xaxis.type),q=v.yaxis&&(\"date\"===v.yaxis.type||\"log\"===v.yaxis.type);V&&(z=m(v.xaxis,z),D=m(v.xaxis,D),R=m(v.xaxis,R),F=m(v.xaxis,F)),q&&(B=m(v.yaxis,B),N=m(v.yaxis,N),j=m(v.yaxis,j),U=m(v.yaxis,U));var H=(D+F)/2,G=(B+j)/2,Y=b({x0:H,y0:G,x1:H+(F-D+R-z)/2*f,y1:G+(U-N+j-B)/2*h});V&&(Y.x0=d(v.xaxis,Y.x0),Y.x1=d(v.xaxis,Y.x1)),q&&(Y.y0=d(v.yaxis,Y.y0),Y.y1=d(v.yaxis,Y.y1)),O.x0=Y.x0,O.y0=Y.y0,O.x1=Y.x1,O.y1=Y.y1}else O.type=\"path\",_&&w&&function(t,e,r){var n=\"date\"===e.type,i=\"date\"===r.type;if(!n&&!i)return t;for(var a=0;a<t.length;a++)for(var o=0;o<t[a].length;o++)for(var s=0;s+2<t[a][o].length;s+=2)n&&(t[a][o][s+1]=t[a][o][s+1].replace(\" \",\"_\")),i&&(t[a][o][s+2]=t[a][o][s+2].replace(\" \",\"_\"))}(I,_,w),O.path=x(I),C=null;g(o);for(var W=e.editHelpers,X=(W||{}).modifyItem,Z=[],J=0;J<S.length;J++){var K=o._fullLayout.shapes[J];if(Z[J]=K._input,void 0!==M&&J===o._fullLayout._activeShapeIndex){var Q=O;switch(K.type){case\"line\":case\"rect\":case\"circle\":X(\"x0\",Q.x0),X(\"x1\",Q.x1),X(\"y0\",Q.y0),X(\"y1\",Q.y1);break;case\"path\":X(\"path\",Q.path)}}}return void 0===M?(Z.push(O),Z):W?W.getUpdateObj():{}}}}},{\"../../../plots/cartesian/handle_outline\":860,\"../../../plots/cartesian/helpers\":861,\"../../dragelement/helpers\":680,\"./constants\":748,\"./helpers\":751}],753:[function(t,e,r){\"use strict\";var n=t(\"./constants\"),i=t(\"../../lib\");r.rangeToShapePosition=function(t){return\"log\"===t.type?t.r2d:function(t){return t}},r.shapePositionToRange=function(t){return\"log\"===t.type?t.d2r:function(t){return t}},r.decodeDate=function(t){return function(e){return e.replace&&(e=e.replace(\"_\",\" \")),t(e)}},r.encodeDate=function(t){return function(e){return t(e).replace(\" \",\"_\")}},r.extractPathCoords=function(t,e){var r=[];return t.match(n.segmentRE).forEach((function(t){var a=e[t.charAt(0)].drawn;if(void 0!==a){var o=t.substr(1).match(n.paramRE);!o||o.length<a||r.push(i.cleanNumber(o[a]))}})),r},r.getDataToPixel=function(t,e,n,i){var a,o=t._fullLayout._size;if(e)if(\"domain\"===i)a=function(t){return e._length*(n?1-t:t)+e._offset};else{var s=r.shapePositionToRange(e);a=function(t){return e._offset+e.r2p(s(t,!0))},\"date\"===e.type&&(a=r.decodeDate(a))}else a=n?function(t){return o.t+o.h*(1-t)}:function(t){return o.l+o.w*t};return a},r.getPixelToData=function(t,e,n,i){var a,o=t._fullLayout._size;if(e)if(\"domain\"===i)a=function(t){var r=(t-e._offset)/e._length;return n?1-r:r};else{var s=r.rangeToShapePosition(e);a=function(t){return s(e.p2r(t-e._offset))}}else a=n?function(t){return 1-(t-o.t)/o.h}:function(t){return(t-o.l)/o.w};return a},r.roundPositionForSharpStrokeRendering=function(t,e){var r=1===Math.round(e%2),n=Math.round(t);return r?n+.5:n},r.makeOptionsAndPlotinfo=function(t,e){var r=t._fullLayout.shapes[e]||{},n=t._fullLayout._plots[r.xref+r.yref];return!!n?n._hadPlotinfo=!0:(n={},r.xref&&\"paper\"!==r.xref&&(n.xaxis=t._fullLayout[r.xref+\"axis\"]),r.yref&&\"paper\"!==r.yref&&(n.yaxis=t._fullLayout[r.yref+\"axis\"])),n.xsizemode=r.xsizemode,n.ysizemode=r.ysizemode,n.xanchor=r.xanchor,n.yanchor=r.yanchor,{options:r,plotinfo:n}}},{\"../../lib\":799,\"./constants\":744}],754:[function(t,e,r){\"use strict\";var n=t(\"./draw\");e.exports={moduleType:\"component\",name:\"shapes\",layoutAttributes:t(\"./attributes\"),supplyLayoutDefaults:t(\"./defaults\"),supplyDrawNewShapeDefaults:t(\"./draw_newshape/defaults\"),includeBasePlot:t(\"../../plots/cartesian/include_components\")(\"shapes\"),calcAutorange:t(\"./calc_autorange\"),draw:n.draw,drawOne:n.drawOne}},{\"../../plots/cartesian/include_components\":862,\"./attributes\":742,\"./calc_autorange\":743,\"./defaults\":745,\"./draw\":746,\"./draw_newshape/defaults\":749}],755:[function(t,e,r){\"use strict\";var n=t(\"../../plots/font_attributes\"),i=t(\"../../plots/pad_attributes\"),a=t(\"../../lib/extend\").extendDeepAll,o=t(\"../../plot_api/edit_types\").overrideAll,s=t(\"../../plots/animation_attributes\"),l=t(\"../../plot_api/plot_template\").templatedArray,c=t(\"./constants\"),u=l(\"step\",{visible:{valType:\"boolean\",dflt:!0},method:{valType:\"enumerated\",values:[\"restyle\",\"relayout\",\"animate\",\"update\",\"skip\"],dflt:\"restyle\"},args:{valType:\"info_array\",freeLength:!0,items:[{valType:\"any\"},{valType:\"any\"},{valType:\"any\"}]},label:{valType:\"string\"},value:{valType:\"string\"},execute:{valType:\"boolean\",dflt:!0}});e.exports=o(l(\"slider\",{visible:{valType:\"boolean\",dflt:!0},active:{valType:\"number\",min:0,dflt:0},steps:u,lenmode:{valType:\"enumerated\",values:[\"fraction\",\"pixels\"],dflt:\"fraction\"},len:{valType:\"number\",min:0,dflt:1},x:{valType:\"number\",min:-2,max:3,dflt:0},pad:a(i({editType:\"arraydraw\"}),{},{t:{dflt:20}}),xanchor:{valType:\"enumerated\",values:[\"auto\",\"left\",\"center\",\"right\"],dflt:\"left\"},y:{valType:\"number\",min:-2,max:3,dflt:0},yanchor:{valType:\"enumerated\",values:[\"auto\",\"top\",\"middle\",\"bottom\"],dflt:\"top\"},transition:{duration:{valType:\"number\",min:0,dflt:150},easing:{valType:\"enumerated\",values:s.transition.easing.values,dflt:\"cubic-in-out\"}},currentvalue:{visible:{valType:\"boolean\",dflt:!0},xanchor:{valType:\"enumerated\",values:[\"left\",\"center\",\"right\"],dflt:\"left\"},offset:{valType:\"number\",dflt:10},prefix:{valType:\"string\"},suffix:{valType:\"string\"},font:n({})},font:n({}),activebgcolor:{valType:\"color\",dflt:c.gripBgActiveColor},bgcolor:{valType:\"color\",dflt:c.railBgColor},bordercolor:{valType:\"color\",dflt:c.railBorderColor},borderwidth:{valType:\"number\",min:0,dflt:c.railBorderWidth},ticklen:{valType:\"number\",min:0,dflt:c.tickLength},tickcolor:{valType:\"color\",dflt:c.tickColor},tickwidth:{valType:\"number\",min:0,dflt:1},minorticklen:{valType:\"number\",min:0,dflt:c.minorTickLength}}),\"arraydraw\",\"from-root\")},{\"../../lib/extend\":789,\"../../plot_api/edit_types\":831,\"../../plot_api/plot_template\":838,\"../../plots/animation_attributes\":843,\"../../plots/font_attributes\":878,\"../../plots/pad_attributes\":912,\"./constants\":756}],756:[function(t,e,r){\"use strict\";e.exports={name:\"sliders\",containerClassName:\"slider-container\",groupClassName:\"slider-group\",inputAreaClass:\"slider-input-area\",railRectClass:\"slider-rail-rect\",railTouchRectClass:\"slider-rail-touch-rect\",gripRectClass:\"slider-grip-rect\",tickRectClass:\"slider-tick-rect\",inputProxyClass:\"slider-input-proxy\",labelsClass:\"slider-labels\",labelGroupClass:\"slider-label-group\",labelClass:\"slider-label\",currentValueClass:\"slider-current-value\",railHeight:5,menuIndexAttrName:\"slider-active-index\",autoMarginIdRoot:\"slider-\",minWidth:30,minHeight:30,textPadX:40,arrowOffsetX:4,railRadius:2,railWidth:5,railBorder:4,railBorderWidth:1,railBorderColor:\"#bec8d9\",railBgColor:\"#f8fafc\",railInset:8,stepInset:10,gripRadius:10,gripWidth:20,gripHeight:20,gripBorder:20,gripBorderWidth:1,gripBorderColor:\"#bec8d9\",gripBgColor:\"#f6f8fa\",gripBgActiveColor:\"#dbdde0\",labelPadding:8,labelOffset:0,tickWidth:1,tickColor:\"#333\",tickOffset:25,tickLength:7,minorTickOffset:25,minorTickColor:\"#333\",minorTickLength:4,currentValuePadding:8,currentValueInset:0}},{}],757:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/array_container_defaults\"),a=t(\"./attributes\"),o=t(\"./constants\").name,s=a.steps;function l(t,e,r){function o(r,i){return n.coerce(t,e,a,r,i)}for(var s=i(t,e,{name:\"steps\",handleItemDefaults:c}),l=0,u=0;u<s.length;u++)s[u].visible&&l++;if(l<2?e.visible=!1:o(\"visible\")){e._stepCount=l;var f=e._visibleSteps=n.filterVisible(s);(s[o(\"active\")]||{}).visible||(e.active=f[0]._index),o(\"x\"),o(\"y\"),n.noneOrAll(t,e,[\"x\",\"y\"]),o(\"xanchor\"),o(\"yanchor\"),o(\"len\"),o(\"lenmode\"),o(\"pad.t\"),o(\"pad.r\"),o(\"pad.b\"),o(\"pad.l\"),n.coerceFont(o,\"font\",r.font),o(\"currentvalue.visible\")&&(o(\"currentvalue.xanchor\"),o(\"currentvalue.prefix\"),o(\"currentvalue.suffix\"),o(\"currentvalue.offset\"),n.coerceFont(o,\"currentvalue.font\",e.font)),o(\"transition.duration\"),o(\"transition.easing\"),o(\"bgcolor\"),o(\"activebgcolor\"),o(\"bordercolor\"),o(\"borderwidth\"),o(\"ticklen\"),o(\"tickwidth\"),o(\"tickcolor\"),o(\"minorticklen\")}}function c(t,e){function r(r,i){return n.coerce(t,e,s,r,i)}if(\"skip\"===t.method||Array.isArray(t.args)?r(\"visible\"):e.visible=!1){r(\"method\"),r(\"args\");var i=r(\"label\",\"step-\"+e._index);r(\"value\",i),r(\"execute\")}}e.exports=function(t,e){i(t,e,{name:o,handleItemDefaults:l})}},{\"../../lib\":799,\"../../plots/array_container_defaults\":844,\"./attributes\":755,\"./constants\":756}],758:[function(t,e,r){\"use strict\";var n=t(\"@plotly/d3\"),i=t(\"../../plots/plots\"),a=t(\"../color\"),o=t(\"../drawing\"),s=t(\"../../lib\"),l=s.strTranslate,c=t(\"../../lib/svg_text_utils\"),u=t(\"../../plot_api/plot_template\").arrayEditor,f=t(\"./constants\"),h=t(\"../../constants/alignment\"),p=h.LINE_SPACING,d=h.FROM_TL,m=h.FROM_BR;function g(t){return f.autoMarginIdRoot+t._index}function v(t){return t._index}function y(t,e){var r=o.tester.selectAll(\"g.\"+f.labelGroupClass).data(e._visibleSteps);r.enter().append(\"g\").classed(f.labelGroupClass,!0);var a=0,l=0;r.each((function(t){var r=_(n.select(this),{step:t},e).node();if(r){var i=o.bBox(r);l=Math.max(l,i.height),a=Math.max(a,i.width)}})),r.remove();var u=e._dims={};u.inputAreaWidth=Math.max(f.railWidth,f.gripHeight);var h=t._fullLayout._size;u.lx=h.l+h.w*e.x,u.ly=h.t+h.h*(1-e.y),\"fraction\"===e.lenmode?u.outerLength=Math.round(h.w*e.len):u.outerLength=e.len,u.inputAreaStart=0,u.inputAreaLength=Math.round(u.outerLength-e.pad.l-e.pad.r);var p=(u.inputAreaLength-2*f.stepInset)/(e._stepCount-1),v=a+f.labelPadding;if(u.labelStride=Math.max(1,Math.ceil(v/p)),u.labelHeight=l,u.currentValueMaxWidth=0,u.currentValueHeight=0,u.currentValueTotalHeight=0,u.currentValueMaxLines=1,e.currentvalue.visible){var y=o.tester.append(\"g\");r.each((function(t){var r=x(y,e,t.label),n=r.node()&&o.bBox(r.node())||{width:0,height:0},i=c.lineCount(r);u.currentValueMaxWidth=Math.max(u.currentValueMaxWidth,Math.ceil(n.width)),u.currentValueHeight=Math.max(u.currentValueHeight,Math.ceil(n.height)),u.currentValueMaxLines=Math.max(u.currentValueMaxLines,i)})),u.currentValueTotalHeight=u.currentValueHeight+e.currentvalue.offset,y.remove()}u.height=u.currentValueTotalHeight+f.tickOffset+e.ticklen+f.labelOffset+u.labelHeight+e.pad.t+e.pad.b;var b=\"left\";s.isRightAnchor(e)&&(u.lx-=u.outerLength,b=\"right\"),s.isCenterAnchor(e)&&(u.lx-=u.outerLength/2,b=\"center\");var w=\"top\";s.isBottomAnchor(e)&&(u.ly-=u.height,w=\"bottom\"),s.isMiddleAnchor(e)&&(u.ly-=u.height/2,w=\"middle\"),u.outerLength=Math.ceil(u.outerLength),u.height=Math.ceil(u.height),u.lx=Math.round(u.lx),u.ly=Math.round(u.ly);var T={y:e.y,b:u.height*m[w],t:u.height*d[w]};\"fraction\"===e.lenmode?(T.l=0,T.xl=e.x-e.len*d[b],T.r=0,T.xr=e.x+e.len*m[b]):(T.x=e.x,T.l=u.outerLength*d[b],T.r=u.outerLength*m[b]),i.autoMargin(t,g(e),T)}function x(t,e,r){if(e.currentvalue.visible){var n,i,a=e._dims;switch(e.currentvalue.xanchor){case\"right\":n=a.inputAreaLength-f.currentValueInset-a.currentValueMaxWidth,i=\"left\";break;case\"center\":n=.5*a.inputAreaLength,i=\"middle\";break;default:n=f.currentValueInset,i=\"left\"}var l=s.ensureSingle(t,\"text\",f.labelClass,(function(t){t.attr({\"text-anchor\":i,\"data-notex\":1})})),u=e.currentvalue.prefix?e.currentvalue.prefix:\"\";if(\"string\"==typeof r)u+=r;else{var h=e.steps[e.active].label,d=e._gd._fullLayout._meta;d&&(h=s.templateString(h,d)),u+=h}e.currentvalue.suffix&&(u+=e.currentvalue.suffix),l.call(o.font,e.currentvalue.font).text(u).call(c.convertToTspans,e._gd);var m=c.lineCount(l),g=(a.currentValueMaxLines+1-m)*e.currentvalue.font.size*p;return c.positionText(l,n,g),l}}function b(t,e,r){s.ensureSingle(t,\"rect\",f.gripRectClass,(function(n){n.call(M,e,t,r).style(\"pointer-events\",\"all\")})).attr({width:f.gripWidth,height:f.gripHeight,rx:f.gripRadius,ry:f.gripRadius}).call(a.stroke,r.bordercolor).call(a.fill,r.bgcolor).style(\"stroke-width\",r.borderwidth+\"px\")}function _(t,e,r){var n=s.ensureSingle(t,\"text\",f.labelClass,(function(t){t.attr({\"text-anchor\":\"middle\",\"data-notex\":1})})),i=e.step.label,a=r._gd._fullLayout._meta;return a&&(i=s.templateString(i,a)),n.call(o.font,r.font).text(i).call(c.convertToTspans,r._gd),n}function w(t,e){var r=s.ensureSingle(t,\"g\",f.labelsClass),i=e._dims,a=r.selectAll(\"g.\"+f.labelGroupClass).data(i.labelSteps);a.enter().append(\"g\").classed(f.labelGroupClass,!0),a.exit().remove(),a.each((function(t){var r=n.select(this);r.call(_,t,e),o.setTranslate(r,E(e,t.fraction),f.tickOffset+e.ticklen+e.font.size*p+f.labelOffset+i.currentValueTotalHeight)}))}function T(t,e,r,n,i){var a=Math.round(n*(r._stepCount-1)),o=r._visibleSteps[a]._index;o!==r.active&&k(t,e,r,o,!0,i)}function k(t,e,r,n,a,o){var s=r.active;r.active=n,u(t.layout,f.name,r).applyUpdate(\"active\",n);var l=r.steps[r.active];e.call(S,r,o),e.call(x,r),t.emit(\"plotly_sliderchange\",{slider:r,step:r.steps[r.active],interaction:a,previousActive:s}),l&&l.method&&a&&(e._nextMethod?(e._nextMethod.step=l,e._nextMethod.doCallback=a,e._nextMethod.doTransition=o):(e._nextMethod={step:l,doCallback:a,doTransition:o},e._nextMethodRaf=window.requestAnimationFrame((function(){var r=e._nextMethod.step;r.method&&(r.execute&&i.executeAPICommand(t,r.method,r.args),e._nextMethod=null,e._nextMethodRaf=null)}))))}function M(t,e,r){var i=r.node(),o=n.select(e);function s(){return r.data()[0]}t.on(\"mousedown\",(function(){var t=s();e.emit(\"plotly_sliderstart\",{slider:t});var l=r.select(\".\"+f.gripRectClass);n.event.stopPropagation(),n.event.preventDefault(),l.call(a.fill,t.activebgcolor);var c=L(t,n.mouse(i)[0]);T(e,r,t,c,!0),t._dragging=!0,o.on(\"mousemove\",(function(){var t=s(),a=L(t,n.mouse(i)[0]);T(e,r,t,a,!1)})),o.on(\"mouseup\",(function(){var t=s();t._dragging=!1,l.call(a.fill,t.bgcolor),o.on(\"mouseup\",null),o.on(\"mousemove\",null),e.emit(\"plotly_sliderend\",{slider:t,step:t.steps[t.active]})}))}))}function A(t,e){var r=t.selectAll(\"rect.\"+f.tickRectClass).data(e._visibleSteps),i=e._dims;r.enter().append(\"rect\").classed(f.tickRectClass,!0),r.exit().remove(),r.attr({width:e.tickwidth+\"px\",\"shape-rendering\":\"crispEdges\"}),r.each((function(t,r){var s=r%i.labelStride==0,l=n.select(this);l.attr({height:s?e.ticklen:e.minorticklen}).call(a.fill,e.tickcolor),o.setTranslate(l,E(e,r/(e._stepCount-1))-.5*e.tickwidth,(s?f.tickOffset:f.minorTickOffset)+i.currentValueTotalHeight)}))}function S(t,e,r){for(var n=t.select(\"rect.\"+f.gripRectClass),i=0,a=0;a<e._stepCount;a++)if(e._visibleSteps[a]._index===e.active){i=a;break}var o=E(e,i/(e._stepCount-1));if(!e._invokingCommand){var s=n;r&&e.transition.duration>0&&(s=s.transition().duration(e.transition.duration).ease(e.transition.easing)),s.attr(\"transform\",l(o-.5*f.gripWidth,e._dims.currentValueTotalHeight))}}function E(t,e){var r=t._dims;return r.inputAreaStart+f.stepInset+(r.inputAreaLength-2*f.stepInset)*Math.min(1,Math.max(0,e))}function L(t,e){var r=t._dims;return Math.min(1,Math.max(0,(e-f.stepInset-r.inputAreaStart)/(r.inputAreaLength-2*f.stepInset-2*r.inputAreaStart)))}function C(t,e,r){var n=r._dims,i=s.ensureSingle(t,\"rect\",f.railTouchRectClass,(function(n){n.call(M,e,t,r).style(\"pointer-events\",\"all\")}));i.attr({width:n.inputAreaLength,height:Math.max(n.inputAreaWidth,f.tickOffset+r.ticklen+n.labelHeight)}).call(a.fill,r.bgcolor).attr(\"opacity\",0),o.setTranslate(i,0,n.currentValueTotalHeight)}function P(t,e){var r=e._dims,n=r.inputAreaLength-2*f.railInset,i=s.ensureSingle(t,\"rect\",f.railRectClass);i.attr({width:n,height:f.railWidth,rx:f.railRadius,ry:f.railRadius,\"shape-rendering\":\"crispEdges\"}).call(a.stroke,e.bordercolor).call(a.fill,e.bgcolor).style(\"stroke-width\",e.borderwidth+\"px\"),o.setTranslate(i,f.railInset,.5*(r.inputAreaWidth-f.railWidth)+r.currentValueTotalHeight)}e.exports=function(t){var e=t._fullLayout,r=function(t,e){for(var r=t[f.name],n=[],i=0;i<r.length;i++){var a=r[i];a.visible&&(a._gd=e,n.push(a))}return n}(e,t),a=e._infolayer.selectAll(\"g.\"+f.containerClassName).data(r.length>0?[0]:[]);function s(e){e._commandObserver&&(e._commandObserver.remove(),delete e._commandObserver),i.autoMargin(t,g(e))}if(a.enter().append(\"g\").classed(f.containerClassName,!0).style(\"cursor\",\"ew-resize\"),a.exit().each((function(){n.select(this).selectAll(\"g.\"+f.groupClassName).each(s)})).remove(),0!==r.length){var l=a.selectAll(\"g.\"+f.groupClassName).data(r,v);l.enter().append(\"g\").classed(f.groupClassName,!0),l.exit().each(s).remove();for(var c=0;c<r.length;c++){var u=r[c];y(t,u)}l.each((function(e){var r=n.select(this);!function(t){var e=t._dims;e.labelSteps=[];for(var r=t._stepCount,n=0;n<r;n+=e.labelStride)e.labelSteps.push({fraction:n/(r-1),step:t._visibleSteps[n]})}(e),i.manageCommandObserver(t,e,e._visibleSteps,(function(e){var n=r.data()[0];n.active!==e.index&&(n._dragging||k(t,r,n,e.index,!1,!0))})),function(t,e,r){(r.steps[r.active]||{}).visible||(r.active=r._visibleSteps[0]._index);e.call(x,r).call(P,r).call(w,r).call(A,r).call(C,t,r).call(b,t,r);var n=r._dims;o.setTranslate(e,n.lx+r.pad.l,n.ly+r.pad.t),e.call(S,r,!1),e.call(x,r)}(t,n.select(this),e)}))}}},{\"../../constants/alignment\":767,\"../../lib\":799,\"../../lib/svg_text_utils\":824,\"../../plot_api/plot_template\":838,\"../../plots/plots\":913,\"../color\":662,\"../drawing\":684,\"./constants\":756,\"@plotly/d3\":58}],759:[function(t,e,r){\"use strict\";var n=t(\"./constants\");e.exports={moduleType:\"component\",name:n.name,layoutAttributes:t(\"./attributes\"),supplyLayoutDefaults:t(\"./defaults\"),draw:t(\"./draw\")}},{\"./attributes\":755,\"./constants\":756,\"./defaults\":757,\"./draw\":758}],760:[function(t,e,r){\"use strict\";var n=t(\"@plotly/d3\"),i=t(\"fast-isnumeric\"),a=t(\"../../plots/plots\"),o=t(\"../../registry\"),s=t(\"../../lib\"),l=s.strTranslate,c=t(\"../drawing\"),u=t(\"../color\"),f=t(\"../../lib/svg_text_utils\"),h=t(\"../../constants/interactions\"),p=t(\"../../constants/alignment\").OPPOSITE_SIDE,d=/ [XY][0-9]* /;e.exports={draw:function(t,e,r){var m,g=r.propContainer,v=r.propName,y=r.placeholder,x=r.traceIndex,b=r.avoid||{},_=r.attributes,w=r.transform,T=r.containerGroup,k=t._fullLayout,M=1,A=!1,S=g.title,E=(S&&S.text?S.text:\"\").trim(),L=S&&S.font?S.font:{},C=L.family,P=L.size,I=L.color;\"title.text\"===v?m=\"titleText\":-1!==v.indexOf(\"axis\")?m=\"axisTitleText\":v.indexOf(!0)&&(m=\"colorbarTitleText\");var O=t._context.edits[m];\"\"===E?M=0:E.replace(d,\" % \")===y.replace(d,\" % \")&&(M=.2,A=!0,O||(E=\"\")),r._meta?E=s.templateString(E,r._meta):k._meta&&(E=s.templateString(E,k._meta));var z=E||O;T||(T=s.ensureSingle(k._infolayer,\"g\",\"g-\"+e));var D=T.selectAll(\"text\").data(z?[0]:[]);if(D.enter().append(\"text\"),D.text(E).attr(\"class\",e),D.exit().remove(),!z)return T;function R(t){s.syncOrAsync([F,B],t)}function F(e){var r;return w?(r=\"\",w.rotate&&(r+=\"rotate(\"+[w.rotate,_.x,_.y]+\")\"),w.offset&&(r+=l(0,w.offset))):r=null,e.attr(\"transform\",r),e.style({\"font-family\":C,\"font-size\":n.round(P,2)+\"px\",fill:u.rgb(I),opacity:M*u.opacity(I),\"font-weight\":a.fontWeight}).attr(_).call(f.convertToTspans,t),a.previousPromises(t)}function B(t){var e=n.select(t.node().parentNode);if(b&&b.selection&&b.side&&E){e.attr(\"transform\",null);var r=p[b.side],a=\"left\"===b.side||\"top\"===b.side?-1:1,o=i(b.pad)?b.pad:2,u=c.bBox(e.node()),f={left:0,top:0,right:k.width,bottom:k.height},h=b.maxShift||a*(f[b.side]-u[b.side]),d=0;if(h<0)d=h;else{var m=b.offsetLeft||0,g=b.offsetTop||0;u.left-=m,u.right-=m,u.top-=g,u.bottom-=g,b.selection.each((function(){var t=c.bBox(this);s.bBoxIntersect(u,t,o)&&(d=Math.max(d,a*(t[b.side]-u[r])+o))})),d=Math.min(h,d)}if(d>0||h<0){var v={left:[-d,0],right:[d,0],top:[0,-d],bottom:[0,d]}[b.side];e.attr(\"transform\",l(v[0],v[1]))}}}return D.call(R),O&&(E?D.on(\".opacity\",null):(M=0,A=!0,D.text(y).on(\"mouseover.opacity\",(function(){n.select(this).transition().duration(h.SHOW_PLACEHOLDER).style(\"opacity\",1)})).on(\"mouseout.opacity\",(function(){n.select(this).transition().duration(h.HIDE_PLACEHOLDER).style(\"opacity\",0)}))),D.call(f.makeEditable,{gd:t}).on(\"edit\",(function(e){void 0!==x?o.call(\"_guiRestyle\",t,v,e,x):o.call(\"_guiRelayout\",t,v,e)})).on(\"cancel\",(function(){this.text(this.attr(\"data-unformatted\")).call(R)})).on(\"input\",(function(t){this.text(t||\" \").call(f.positionText,_.x,_.y)}))),D.classed(\"js-placeholder\",A),T}}},{\"../../constants/alignment\":767,\"../../constants/interactions\":774,\"../../lib\":799,\"../../lib/svg_text_utils\":824,\"../../plots/plots\":913,\"../../registry\":927,\"../color\":662,\"../drawing\":684,\"@plotly/d3\":58,\"fast-isnumeric\":245}],761:[function(t,e,r){\"use strict\";var n=t(\"../../plots/font_attributes\"),i=t(\"../color/attributes\"),a=t(\"../../lib/extend\").extendFlat,o=t(\"../../plot_api/edit_types\").overrideAll,s=t(\"../../plots/pad_attributes\"),l=t(\"../../plot_api/plot_template\").templatedArray,c=l(\"button\",{visible:{valType:\"boolean\"},method:{valType:\"enumerated\",values:[\"restyle\",\"relayout\",\"animate\",\"update\",\"skip\"],dflt:\"restyle\"},args:{valType:\"info_array\",freeLength:!0,items:[{valType:\"any\"},{valType:\"any\"},{valType:\"any\"}]},args2:{valType:\"info_array\",freeLength:!0,items:[{valType:\"any\"},{valType:\"any\"},{valType:\"any\"}]},label:{valType:\"string\",dflt:\"\"},execute:{valType:\"boolean\",dflt:!0}});e.exports=o(l(\"updatemenu\",{_arrayAttrRegexps:[/^updatemenus\\[(0|[1-9][0-9]+)\\]\\.buttons/],visible:{valType:\"boolean\"},type:{valType:\"enumerated\",values:[\"dropdown\",\"buttons\"],dflt:\"dropdown\"},direction:{valType:\"enumerated\",values:[\"left\",\"right\",\"up\",\"down\"],dflt:\"down\"},active:{valType:\"integer\",min:-1,dflt:0},showactive:{valType:\"boolean\",dflt:!0},buttons:c,x:{valType:\"number\",min:-2,max:3,dflt:-.05},xanchor:{valType:\"enumerated\",values:[\"auto\",\"left\",\"center\",\"right\"],dflt:\"right\"},y:{valType:\"number\",min:-2,max:3,dflt:1},yanchor:{valType:\"enumerated\",values:[\"auto\",\"top\",\"middle\",\"bottom\"],dflt:\"top\"},pad:a(s({editType:\"arraydraw\"}),{}),font:n({}),bgcolor:{valType:\"color\"},bordercolor:{valType:\"color\",dflt:i.borderLine},borderwidth:{valType:\"number\",min:0,dflt:1,editType:\"arraydraw\"}}),\"arraydraw\",\"from-root\")},{\"../../lib/extend\":789,\"../../plot_api/edit_types\":831,\"../../plot_api/plot_template\":838,\"../../plots/font_attributes\":878,\"../../plots/pad_attributes\":912,\"../color/attributes\":661}],762:[function(t,e,r){\"use strict\";e.exports={name:\"updatemenus\",containerClassName:\"updatemenu-container\",headerGroupClassName:\"updatemenu-header-group\",headerClassName:\"updatemenu-header\",headerArrowClassName:\"updatemenu-header-arrow\",dropdownButtonGroupClassName:\"updatemenu-dropdown-button-group\",dropdownButtonClassName:\"updatemenu-dropdown-button\",buttonClassName:\"updatemenu-button\",itemRectClassName:\"updatemenu-item-rect\",itemTextClassName:\"updatemenu-item-text\",menuIndexAttrName:\"updatemenu-active-index\",autoMarginIdRoot:\"updatemenu-\",blankHeaderOpts:{label:\"  \"},minWidth:30,minHeight:30,textPadX:24,arrowPadX:16,rx:2,ry:2,textOffsetX:12,textOffsetY:3,arrowOffsetX:4,gapButtonHeader:5,gapButton:2,activeColor:\"#F4FAFF\",hoverColor:\"#F4FAFF\",arrowSymbol:{left:\"\\u25c4\",right:\"\\u25ba\",up:\"\\u25b2\",down:\"\\u25bc\"}}},{}],763:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/array_container_defaults\"),a=t(\"./attributes\"),o=t(\"./constants\").name,s=a.buttons;function l(t,e,r){function o(r,i){return n.coerce(t,e,a,r,i)}o(\"visible\",i(t,e,{name:\"buttons\",handleItemDefaults:c}).length>0)&&(o(\"active\"),o(\"direction\"),o(\"type\"),o(\"showactive\"),o(\"x\"),o(\"y\"),n.noneOrAll(t,e,[\"x\",\"y\"]),o(\"xanchor\"),o(\"yanchor\"),o(\"pad.t\"),o(\"pad.r\"),o(\"pad.b\"),o(\"pad.l\"),n.coerceFont(o,\"font\",r.font),o(\"bgcolor\",r.paper_bgcolor),o(\"bordercolor\"),o(\"borderwidth\"))}function c(t,e){function r(r,i){return n.coerce(t,e,s,r,i)}r(\"visible\",\"skip\"===t.method||Array.isArray(t.args))&&(r(\"method\"),r(\"args\"),r(\"args2\"),r(\"label\"),r(\"execute\"))}e.exports=function(t,e){i(t,e,{name:o,handleItemDefaults:l})}},{\"../../lib\":799,\"../../plots/array_container_defaults\":844,\"./attributes\":761,\"./constants\":762}],764:[function(t,e,r){\"use strict\";var n=t(\"@plotly/d3\"),i=t(\"../../plots/plots\"),a=t(\"../color\"),o=t(\"../drawing\"),s=t(\"../../lib\"),l=t(\"../../lib/svg_text_utils\"),c=t(\"../../plot_api/plot_template\").arrayEditor,u=t(\"../../constants/alignment\").LINE_SPACING,f=t(\"./constants\"),h=t(\"./scrollbox\");function p(t){return t._index}function d(t,e){return+t.attr(f.menuIndexAttrName)===e._index}function m(t,e,r,n,i,a,o,s){e.active=o,c(t.layout,f.name,e).applyUpdate(\"active\",o),\"buttons\"===e.type?v(t,n,null,null,e):\"dropdown\"===e.type&&(i.attr(f.menuIndexAttrName,\"-1\"),g(t,n,i,a,e),s||v(t,n,i,a,e))}function g(t,e,r,n,i){var a=s.ensureSingle(e,\"g\",f.headerClassName,(function(t){t.style(\"pointer-events\",\"all\")})),l=i._dims,c=i.active,u=i.buttons[c]||f.blankHeaderOpts,h={y:i.pad.t,yPad:0,x:i.pad.l,xPad:0,index:0},p={width:l.headerWidth,height:l.headerHeight};a.call(y,i,u,t).call(A,i,h,p),s.ensureSingle(e,\"text\",f.headerArrowClassName,(function(t){t.attr(\"text-anchor\",\"end\").call(o.font,i.font).text(f.arrowSymbol[i.direction])})).attr({x:l.headerWidth-f.arrowOffsetX+i.pad.l,y:l.headerHeight/2+f.textOffsetY+i.pad.t}),a.on(\"click\",(function(){r.call(S,String(d(r,i)?-1:i._index)),v(t,e,r,n,i)})),a.on(\"mouseover\",(function(){a.call(w)})),a.on(\"mouseout\",(function(){a.call(T,i)})),o.setTranslate(e,l.lx,l.ly)}function v(t,e,r,a,o){r||(r=e).attr(\"pointer-events\",\"all\");var l=function(t){return-1==+t.attr(f.menuIndexAttrName)}(r)&&\"buttons\"!==o.type?[]:o.buttons,c=\"dropdown\"===o.type?f.dropdownButtonClassName:f.buttonClassName,u=r.selectAll(\"g.\"+c).data(s.filterVisible(l)),h=u.enter().append(\"g\").classed(c,!0),p=u.exit();\"dropdown\"===o.type?(h.attr(\"opacity\",\"0\").transition().attr(\"opacity\",\"1\"),p.transition().attr(\"opacity\",\"0\").remove()):p.remove();var d=0,g=0,v=o._dims,x=-1!==[\"up\",\"down\"].indexOf(o.direction);\"dropdown\"===o.type&&(x?g=v.headerHeight+f.gapButtonHeader:d=v.headerWidth+f.gapButtonHeader),\"dropdown\"===o.type&&\"up\"===o.direction&&(g=-f.gapButtonHeader+f.gapButton-v.openHeight),\"dropdown\"===o.type&&\"left\"===o.direction&&(d=-f.gapButtonHeader+f.gapButton-v.openWidth);var b={x:v.lx+d+o.pad.l,y:v.ly+g+o.pad.t,yPad:f.gapButton,xPad:f.gapButton,index:0},k={l:b.x+o.borderwidth,t:b.y+o.borderwidth};u.each((function(s,l){var c=n.select(this);c.call(y,o,s,t).call(A,o,b),c.on(\"click\",(function(){n.event.defaultPrevented||(s.execute&&(s.args2&&o.active===l?(m(t,o,0,e,r,a,-1),i.executeAPICommand(t,s.method,s.args2)):(m(t,o,0,e,r,a,l),i.executeAPICommand(t,s.method,s.args))),t.emit(\"plotly_buttonclicked\",{menu:o,button:s,active:o.active}))})),c.on(\"mouseover\",(function(){c.call(w)})),c.on(\"mouseout\",(function(){c.call(T,o),u.call(_,o)}))})),u.call(_,o),x?(k.w=Math.max(v.openWidth,v.headerWidth),k.h=b.y-k.t):(k.w=b.x-k.l,k.h=Math.max(v.openHeight,v.headerHeight)),k.direction=o.direction,a&&(u.size()?function(t,e,r,n,i,a){var o,s,l,c=i.direction,u=\"up\"===c||\"down\"===c,h=i._dims,p=i.active;if(u)for(s=0,l=0;l<p;l++)s+=h.heights[l]+f.gapButton;else for(o=0,l=0;l<p;l++)o+=h.widths[l]+f.gapButton;n.enable(a,o,s),n.hbar&&n.hbar.attr(\"opacity\",\"0\").transition().attr(\"opacity\",\"1\");n.vbar&&n.vbar.attr(\"opacity\",\"0\").transition().attr(\"opacity\",\"1\")}(0,0,0,a,o,k):function(t){var e=!!t.hbar,r=!!t.vbar;e&&t.hbar.transition().attr(\"opacity\",\"0\").each(\"end\",(function(){e=!1,r||t.disable()}));r&&t.vbar.transition().attr(\"opacity\",\"0\").each(\"end\",(function(){r=!1,e||t.disable()}))}(a))}function y(t,e,r,n){t.call(x,e).call(b,e,r,n)}function x(t,e){s.ensureSingle(t,\"rect\",f.itemRectClassName,(function(t){t.attr({rx:f.rx,ry:f.ry,\"shape-rendering\":\"crispEdges\"})})).call(a.stroke,e.bordercolor).call(a.fill,e.bgcolor).style(\"stroke-width\",e.borderwidth+\"px\")}function b(t,e,r,n){var i=s.ensureSingle(t,\"text\",f.itemTextClassName,(function(t){t.attr({\"text-anchor\":\"start\",\"data-notex\":1})})),a=r.label,c=n._fullLayout._meta;c&&(a=s.templateString(a,c)),i.call(o.font,e.font).text(a).call(l.convertToTspans,n)}function _(t,e){var r=e.active;t.each((function(t,i){var o=n.select(this);i===r&&e.showactive&&o.select(\"rect.\"+f.itemRectClassName).call(a.fill,f.activeColor)}))}function w(t){t.select(\"rect.\"+f.itemRectClassName).call(a.fill,f.hoverColor)}function T(t,e){t.select(\"rect.\"+f.itemRectClassName).call(a.fill,e.bgcolor)}function k(t,e){var r=e._dims={width1:0,height1:0,heights:[],widths:[],totalWidth:0,totalHeight:0,openWidth:0,openHeight:0,lx:0,ly:0},a=o.tester.selectAll(\"g.\"+f.dropdownButtonClassName).data(s.filterVisible(e.buttons));a.enter().append(\"g\").classed(f.dropdownButtonClassName,!0);var c=-1!==[\"up\",\"down\"].indexOf(e.direction);a.each((function(i,a){var s=n.select(this);s.call(y,e,i,t);var h=s.select(\".\"+f.itemTextClassName),p=h.node()&&o.bBox(h.node()).width,d=Math.max(p+f.textPadX,f.minWidth),m=e.font.size*u,g=l.lineCount(h),v=Math.max(m*g,f.minHeight)+f.textOffsetY;v=Math.ceil(v),d=Math.ceil(d),r.widths[a]=d,r.heights[a]=v,r.height1=Math.max(r.height1,v),r.width1=Math.max(r.width1,d),c?(r.totalWidth=Math.max(r.totalWidth,d),r.openWidth=r.totalWidth,r.totalHeight+=v+f.gapButton,r.openHeight+=v+f.gapButton):(r.totalWidth+=d+f.gapButton,r.openWidth+=d+f.gapButton,r.totalHeight=Math.max(r.totalHeight,v),r.openHeight=r.totalHeight)})),c?r.totalHeight-=f.gapButton:r.totalWidth-=f.gapButton,r.headerWidth=r.width1+f.arrowPadX,r.headerHeight=r.height1,\"dropdown\"===e.type&&(c?(r.width1+=f.arrowPadX,r.totalHeight=r.height1):r.totalWidth=r.width1,r.totalWidth+=f.arrowPadX),a.remove();var h=r.totalWidth+e.pad.l+e.pad.r,p=r.totalHeight+e.pad.t+e.pad.b,d=t._fullLayout._size;r.lx=d.l+d.w*e.x,r.ly=d.t+d.h*(1-e.y);var m=\"left\";s.isRightAnchor(e)&&(r.lx-=h,m=\"right\"),s.isCenterAnchor(e)&&(r.lx-=h/2,m=\"center\");var g=\"top\";s.isBottomAnchor(e)&&(r.ly-=p,g=\"bottom\"),s.isMiddleAnchor(e)&&(r.ly-=p/2,g=\"middle\"),r.totalWidth=Math.ceil(r.totalWidth),r.totalHeight=Math.ceil(r.totalHeight),r.lx=Math.round(r.lx),r.ly=Math.round(r.ly),i.autoMargin(t,M(e),{x:e.x,y:e.y,l:h*({right:1,center:.5}[m]||0),r:h*({left:1,center:.5}[m]||0),b:p*({top:1,middle:.5}[g]||0),t:p*({bottom:1,middle:.5}[g]||0)})}function M(t){return f.autoMarginIdRoot+t._index}function A(t,e,r,n){n=n||{};var i=t.select(\".\"+f.itemRectClassName),a=t.select(\".\"+f.itemTextClassName),s=e.borderwidth,c=r.index,h=e._dims;o.setTranslate(t,s+r.x,s+r.y);var p=-1!==[\"up\",\"down\"].indexOf(e.direction),d=n.height||(p?h.heights[c]:h.height1);i.attr({x:0,y:0,width:n.width||(p?h.width1:h.widths[c]),height:d});var m=e.font.size*u,g=(l.lineCount(a)-1)*m/2;l.positionText(a,f.textOffsetX,d/2-g+f.textOffsetY),p?r.y+=h.heights[c]+r.yPad:r.x+=h.widths[c]+r.xPad,r.index++}function S(t,e){t.attr(f.menuIndexAttrName,e||\"-1\").selectAll(\"g.\"+f.dropdownButtonClassName).remove()}e.exports=function(t){var e=t._fullLayout,r=s.filterVisible(e[f.name]);function a(e){i.autoMargin(t,M(e))}var o=e._menulayer.selectAll(\"g.\"+f.containerClassName).data(r.length>0?[0]:[]);if(o.enter().append(\"g\").classed(f.containerClassName,!0).style(\"cursor\",\"pointer\"),o.exit().each((function(){n.select(this).selectAll(\"g.\"+f.headerGroupClassName).each(a)})).remove(),0!==r.length){var l=o.selectAll(\"g.\"+f.headerGroupClassName).data(r,p);l.enter().append(\"g\").classed(f.headerGroupClassName,!0);for(var c=s.ensureSingle(o,\"g\",f.dropdownButtonGroupClassName,(function(t){t.style(\"pointer-events\",\"all\")})),u=0;u<r.length;u++){var y=r[u];k(t,y)}var x=\"updatemenus\"+e._uid,b=new h(t,c,x);l.enter().size()&&(c.node().parentNode.appendChild(c.node()),c.call(S)),l.exit().each((function(t){c.call(S),a(t)})).remove(),l.each((function(e){var r=n.select(this),a=\"dropdown\"===e.type?c:null;i.manageCommandObserver(t,e,e.buttons,(function(n){m(t,e,e.buttons[n.index],r,a,b,n.index,!0)})),\"dropdown\"===e.type?(g(t,r,c,b,e),d(c,e)&&v(t,r,c,b,e)):v(t,r,null,null,e)}))}}},{\"../../constants/alignment\":767,\"../../lib\":799,\"../../lib/svg_text_utils\":824,\"../../plot_api/plot_template\":838,\"../../plots/plots\":913,\"../color\":662,\"../drawing\":684,\"./constants\":762,\"./scrollbox\":766,\"@plotly/d3\":58}],765:[function(t,e,r){arguments[4][759][0].apply(r,arguments)},{\"./attributes\":761,\"./constants\":762,\"./defaults\":763,\"./draw\":764,dup:759}],766:[function(t,e,r){\"use strict\";e.exports=s;var n=t(\"@plotly/d3\"),i=t(\"../color\"),a=t(\"../drawing\"),o=t(\"../../lib\");function s(t,e,r){this.gd=t,this.container=e,this.id=r,this.position=null,this.translateX=null,this.translateY=null,this.hbar=null,this.vbar=null,this.bg=this.container.selectAll(\"rect.scrollbox-bg\").data([0]),this.bg.exit().on(\".drag\",null).on(\"wheel\",null).remove(),this.bg.enter().append(\"rect\").classed(\"scrollbox-bg\",!0).style(\"pointer-events\",\"all\").attr({opacity:0,x:0,y:0,width:0,height:0})}s.barWidth=2,s.barLength=20,s.barRadius=2,s.barPad=1,s.barColor=\"#808BA4\",s.prototype.enable=function(t,e,r){var o=this.gd._fullLayout,l=o.width,c=o.height;this.position=t;var u,f,h,p,d=this.position.l,m=this.position.w,g=this.position.t,v=this.position.h,y=this.position.direction,x=\"down\"===y,b=\"left\"===y,_=\"up\"===y,w=m,T=v;x||b||\"right\"===y||_||(this.position.direction=\"down\",x=!0),x||_?(f=(u=d)+w,x?(h=g,T=(p=Math.min(h+T,c))-h):T=(p=g+T)-(h=Math.max(p-T,0))):(p=(h=g)+T,b?w=(f=d+w)-(u=Math.max(f-w,0)):(u=d,w=(f=Math.min(u+w,l))-u)),this._box={l:u,t:h,w:w,h:T};var k=m>w,M=s.barLength+2*s.barPad,A=s.barWidth+2*s.barPad,S=d,E=g+v;E+A>c&&(E=c-A);var L=this.container.selectAll(\"rect.scrollbar-horizontal\").data(k?[0]:[]);L.exit().on(\".drag\",null).remove(),L.enter().append(\"rect\").classed(\"scrollbar-horizontal\",!0).call(i.fill,s.barColor),k?(this.hbar=L.attr({rx:s.barRadius,ry:s.barRadius,x:S,y:E,width:M,height:A}),this._hbarXMin=S+M/2,this._hbarTranslateMax=w-M):(delete this.hbar,delete this._hbarXMin,delete this._hbarTranslateMax);var C=v>T,P=s.barWidth+2*s.barPad,I=s.barLength+2*s.barPad,O=d+m,z=g;O+P>l&&(O=l-P);var D=this.container.selectAll(\"rect.scrollbar-vertical\").data(C?[0]:[]);D.exit().on(\".drag\",null).remove(),D.enter().append(\"rect\").classed(\"scrollbar-vertical\",!0).call(i.fill,s.barColor),C?(this.vbar=D.attr({rx:s.barRadius,ry:s.barRadius,x:O,y:z,width:P,height:I}),this._vbarYMin=z+I/2,this._vbarTranslateMax=T-I):(delete this.vbar,delete this._vbarYMin,delete this._vbarTranslateMax);var R=this.id,F=u-.5,B=C?f+P+.5:f+.5,N=h-.5,j=k?p+A+.5:p+.5,U=o._topdefs.selectAll(\"#\"+R).data(k||C?[0]:[]);if(U.exit().remove(),U.enter().append(\"clipPath\").attr(\"id\",R).append(\"rect\"),k||C?(this._clipRect=U.select(\"rect\").attr({x:Math.floor(F),y:Math.floor(N),width:Math.ceil(B)-Math.floor(F),height:Math.ceil(j)-Math.floor(N)}),this.container.call(a.setClipUrl,R,this.gd),this.bg.attr({x:d,y:g,width:m,height:v})):(this.bg.attr({width:0,height:0}),this.container.on(\"wheel\",null).on(\".drag\",null).call(a.setClipUrl,null),delete this._clipRect),k||C){var V=n.behavior.drag().on(\"dragstart\",(function(){n.event.sourceEvent.preventDefault()})).on(\"drag\",this._onBoxDrag.bind(this));this.container.on(\"wheel\",null).on(\"wheel\",this._onBoxWheel.bind(this)).on(\".drag\",null).call(V);var q=n.behavior.drag().on(\"dragstart\",(function(){n.event.sourceEvent.preventDefault(),n.event.sourceEvent.stopPropagation()})).on(\"drag\",this._onBarDrag.bind(this));k&&this.hbar.on(\".drag\",null).call(q),C&&this.vbar.on(\".drag\",null).call(q)}this.setTranslate(e,r)},s.prototype.disable=function(){(this.hbar||this.vbar)&&(this.bg.attr({width:0,height:0}),this.container.on(\"wheel\",null).on(\".drag\",null).call(a.setClipUrl,null),delete this._clipRect),this.hbar&&(this.hbar.on(\".drag\",null),this.hbar.remove(),delete this.hbar,delete this._hbarXMin,delete this._hbarTranslateMax),this.vbar&&(this.vbar.on(\".drag\",null),this.vbar.remove(),delete this.vbar,delete this._vbarYMin,delete this._vbarTranslateMax)},s.prototype._onBoxDrag=function(){var t=this.translateX,e=this.translateY;this.hbar&&(t-=n.event.dx),this.vbar&&(e-=n.event.dy),this.setTranslate(t,e)},s.prototype._onBoxWheel=function(){var t=this.translateX,e=this.translateY;this.hbar&&(t+=n.event.deltaY),this.vbar&&(e+=n.event.deltaY),this.setTranslate(t,e)},s.prototype._onBarDrag=function(){var t=this.translateX,e=this.translateY;if(this.hbar){var r=t+this._hbarXMin,i=r+this._hbarTranslateMax;t=(o.constrain(n.event.x,r,i)-r)/(i-r)*(this.position.w-this._box.w)}if(this.vbar){var a=e+this._vbarYMin,s=a+this._vbarTranslateMax;e=(o.constrain(n.event.y,a,s)-a)/(s-a)*(this.position.h-this._box.h)}this.setTranslate(t,e)},s.prototype.setTranslate=function(t,e){var r=this.position.w-this._box.w,n=this.position.h-this._box.h;if(t=o.constrain(t||0,0,r),e=o.constrain(e||0,0,n),this.translateX=t,this.translateY=e,this.container.call(a.setTranslate,this._box.l-this.position.l-t,this._box.t-this.position.t-e),this._clipRect&&this._clipRect.attr({x:Math.floor(this.position.l+t-.5),y:Math.floor(this.position.t+e-.5)}),this.hbar){var i=t/r;this.hbar.call(a.setTranslate,t+i*this._hbarTranslateMax,e)}if(this.vbar){var s=e/n;this.vbar.call(a.setTranslate,t,e+s*this._vbarTranslateMax)}}},{\"../../lib\":799,\"../color\":662,\"../drawing\":684,\"@plotly/d3\":58}],767:[function(t,e,r){\"use strict\";e.exports={FROM_BL:{left:0,center:.5,right:1,bottom:0,middle:.5,top:1},FROM_TL:{left:0,center:.5,right:1,bottom:1,middle:.5,top:0},FROM_BR:{left:1,center:.5,right:0,bottom:0,middle:.5,top:1},LINE_SPACING:1.3,CAP_SHIFT:.7,MID_SHIFT:.35,OPPOSITE_SIDE:{left:\"right\",right:\"left\",top:\"bottom\",bottom:\"top\"}}},{}],768:[function(t,e,r){\"use strict\";e.exports={axisRefDescription:function(t,e,r){return[\"If set to a\",t,\"axis id (e.g. *\"+t+\"* or\",\"*\"+t+\"2*), the `\"+t+\"` position refers to a\",t,\"coordinate. If set to *paper*, the `\"+t+\"`\",\"position refers to the distance from the\",e,\"of the plotting\",\"area in normalized coordinates where *0* (*1*) corresponds to the\",e,\"(\"+r+\"). If set to a\",t,\"axis ID followed by\",\"*domain* (separated by a space), the position behaves like for\",\"*paper*, but refers to the distance in fractions of the domain\",\"length from the\",e,\"of the domain of that axis: e.g.,\",\"*\"+t+\"2 domain* refers to the domain of the second\",t,\" axis and a\",t,\"position of 0.5 refers to the\",\"point between the\",e,\"and the\",r,\"of the domain of the\",\"second\",t,\"axis.\"].join(\" \")}}},{}],769:[function(t,e,r){\"use strict\";e.exports={INCREASING:{COLOR:\"#3D9970\",SYMBOL:\"\\u25b2\"},DECREASING:{COLOR:\"#FF4136\",SYMBOL:\"\\u25bc\"}}},{}],770:[function(t,e,r){\"use strict\";e.exports={FORMAT_LINK:\"https://github.com/d3/d3-3.x-api-reference/blob/master/Formatting.md#d3_format\",DATE_FORMAT_LINK:\"https://github.com/d3/d3-time-format#locale_format\"}},{}],771:[function(t,e,r){\"use strict\";e.exports={COMPARISON_OPS:[\"=\",\"!=\",\"<\",\">=\",\">\",\"<=\"],COMPARISON_OPS2:[\"=\",\"<\",\">=\",\">\",\"<=\"],INTERVAL_OPS:[\"[]\",\"()\",\"[)\",\"(]\",\"][\",\")(\",\"](\",\")[\"],SET_OPS:[\"{}\",\"}{\"],CONSTRAINT_REDUCTION:{\"=\":\"=\",\"<\":\"<\",\"<=\":\"<\",\">\":\">\",\">=\":\">\",\"[]\":\"[]\",\"()\":\"[]\",\"[)\":\"[]\",\"(]\":\"[]\",\"][\":\"][\",\")(\":\"][\",\"](\":\"][\",\")[\":\"][\"}}},{}],772:[function(t,e,r){\"use strict\";e.exports={solid:[[],0],dot:[[.5,1],200],dash:[[.5,1],50],longdash:[[.5,1],10],dashdot:[[.5,.625,.875,1],50],longdashdot:[[.5,.7,.8,1],10]}},{}],773:[function(t,e,r){\"use strict\";e.exports={circle:\"\\u25cf\",\"circle-open\":\"\\u25cb\",square:\"\\u25a0\",\"square-open\":\"\\u25a1\",diamond:\"\\u25c6\",\"diamond-open\":\"\\u25c7\",cross:\"+\",x:\"\\u274c\"}},{}],774:[function(t,e,r){\"use strict\";e.exports={SHOW_PLACEHOLDER:100,HIDE_PLACEHOLDER:1e3,DESELECTDIM:.2}},{}],775:[function(t,e,r){\"use strict\";e.exports={BADNUM:void 0,FP_SAFE:1e-4*Number.MAX_VALUE,ONEMAXYEAR:316224e5,ONEAVGYEAR:315576e5,ONEMINYEAR:31536e6,ONEMAXQUARTER:79488e5,ONEAVGQUARTER:78894e5,ONEMINQUARTER:76896e5,ONEMAXMONTH:26784e5,ONEAVGMONTH:26298e5,ONEMINMONTH:24192e5,ONEWEEK:6048e5,ONEDAY:864e5,ONEHOUR:36e5,ONEMIN:6e4,ONESEC:1e3,EPOCHJD:2440587.5,ALMOST_EQUAL:.999999,LOG_CLIP:10,MINUS_SIGN:\"\\u2212\"}},{}],776:[function(t,e,r){\"use strict\";r.xmlns=\"http://www.w3.org/2000/xmlns/\",r.svg=\"http://www.w3.org/2000/svg\",r.xlink=\"http://www.w3.org/1999/xlink\",r.svgAttrs={xmlns:r.svg,\"xmlns:xlink\":r.xlink}},{}],777:[function(t,e,r){\"use strict\";r.version=t(\"./version\").version,t(\"native-promise-only\"),t(\"../build/plotcss\");for(var n=t(\"./registry\"),i=r.register=n.register,a=t(\"./plot_api\"),o=Object.keys(a),s=0;s<o.length;s++){var l=o[s];\"_\"!==l.charAt(0)&&(r[l]=a[l]),i({moduleType:\"apiMethod\",name:l,fn:a[l]})}i(t(\"./traces/scatter\")),i([t(\"./components/legend\"),t(\"./components/fx\"),t(\"./components/annotations\"),t(\"./components/annotations3d\"),t(\"./components/shapes\"),t(\"./components/images\"),t(\"./components/updatemenus\"),t(\"./components/sliders\"),t(\"./components/rangeslider\"),t(\"./components/rangeselector\"),t(\"./components/grid\"),t(\"./components/errorbars\"),t(\"./components/colorscale\"),t(\"./components/colorbar\"),t(\"./components/modebar\")]),i([t(\"./locale-en\"),t(\"./locale-en-us\")]),window.PlotlyLocales&&Array.isArray(window.PlotlyLocales)&&(i(window.PlotlyLocales),delete window.PlotlyLocales),r.Icons=t(\"./fonts/ploticon\");var c=t(\"./components/fx\"),u=t(\"./plots/plots\");r.Plots={resize:u.resize,graphJson:u.graphJson,sendDataToCloud:u.sendDataToCloud},r.Fx={hover:c.hover,unhover:c.unhover,loneHover:c.loneHover,loneUnhover:c.loneUnhover},r.Snapshot=t(\"./snapshot\"),r.PlotSchema=t(\"./plot_api/plot_schema\")},{\"../build/plotcss\":1,\"./components/annotations\":653,\"./components/annotations3d\":658,\"./components/colorbar\":668,\"./components/colorscale\":674,\"./components/errorbars\":690,\"./components/fx\":702,\"./components/grid\":706,\"./components/images\":711,\"./components/legend\":719,\"./components/modebar\":725,\"./components/rangeselector\":733,\"./components/rangeslider\":740,\"./components/shapes\":754,\"./components/sliders\":759,\"./components/updatemenus\":765,\"./fonts/ploticon\":778,\"./locale-en\":829,\"./locale-en-us\":828,\"./plot_api\":833,\"./plot_api/plot_schema\":837,\"./plots/plots\":913,\"./registry\":927,\"./snapshot\":932,\"./traces/scatter\":1226,\"./version\":1400,\"native-promise-only\":470}],778:[function(t,e,r){\"use strict\";e.exports={undo:{width:857.1,height:1e3,path:\"m857 350q0-87-34-166t-91-137-137-92-166-34q-96 0-183 41t-147 114q-4 6-4 13t5 11l76 77q6 5 14 5 9-1 13-7 41-53 100-82t126-29q58 0 110 23t92 61 61 91 22 111-22 111-61 91-92 61-110 23q-55 0-105-20t-90-57l77-77q17-16 8-38-10-23-33-23h-250q-15 0-25 11t-11 25v250q0 24 22 33 22 10 39-8l72-72q60 57 137 88t159 31q87 0 166-34t137-92 91-137 34-166z\",transform:\"matrix(1 0 0 -1 0 850)\"},home:{width:928.6,height:1e3,path:\"m786 296v-267q0-15-11-26t-25-10h-214v214h-143v-214h-214q-15 0-25 10t-11 26v267q0 1 0 2t0 2l321 264 321-264q1-1 1-4z m124 39l-34-41q-5-5-12-6h-2q-7 0-12 3l-386 322-386-322q-7-4-13-4-7 2-12 7l-35 41q-4 5-3 13t6 12l401 334q18 15 42 15t43-15l136-114v109q0 8 5 13t13 5h107q8 0 13-5t5-13v-227l122-102q5-5 6-12t-4-13z\",transform:\"matrix(1 0 0 -1 0 850)\"},\"camera-retro\":{width:1e3,height:1e3,path:\"m518 386q0 8-5 13t-13 5q-37 0-63-27t-26-63q0-8 5-13t13-5 12 5 5 13q0 23 16 38t38 16q8 0 13 5t5 13z m125-73q0-59-42-101t-101-42-101 42-42 101 42 101 101 42 101-42 42-101z m-572-320h858v71h-858v-71z m643 320q0 89-62 152t-152 62-151-62-63-152 63-151 151-63 152 63 62 151z m-571 358h214v72h-214v-72z m-72-107h858v143h-462l-36-71h-360v-72z m929 143v-714q0-30-21-51t-50-21h-858q-29 0-50 21t-21 51v714q0 30 21 51t50 21h858q29 0 50-21t21-51z\",transform:\"matrix(1 0 0 -1 0 850)\"},zoombox:{width:1e3,height:1e3,path:\"m1000-25l-250 251c40 63 63 138 63 218 0 224-182 406-407 406-224 0-406-182-406-406s183-406 407-406c80 0 155 22 218 62l250-250 125 125z m-812 250l0 438 437 0 0-438-437 0z m62 375l313 0 0-312-313 0 0 312z\",transform:\"matrix(1 0 0 -1 0 850)\"},pan:{width:1e3,height:1e3,path:\"m1000 350l-187 188 0-125-250 0 0 250 125 0-188 187-187-187 125 0 0-250-250 0 0 125-188-188 186-187 0 125 252 0 0-250-125 0 187-188 188 188-125 0 0 250 250 0 0-126 187 188z\",transform:\"matrix(1 0 0 -1 0 850)\"},zoom_plus:{width:875,height:1e3,path:\"m1 787l0-875 875 0 0 875-875 0z m687-500l-187 0 0-187-125 0 0 187-188 0 0 125 188 0 0 187 125 0 0-187 187 0 0-125z\",transform:\"matrix(1 0 0 -1 0 850)\"},zoom_minus:{width:875,height:1e3,path:\"m0 788l0-876 875 0 0 876-875 0z m688-500l-500 0 0 125 500 0 0-125z\",transform:\"matrix(1 0 0 -1 0 850)\"},autoscale:{width:1e3,height:1e3,path:\"m250 850l-187 0-63 0 0-62 0-188 63 0 0 188 187 0 0 62z m688 0l-188 0 0-62 188 0 0-188 62 0 0 188 0 62-62 0z m-875-938l0 188-63 0 0-188 0-62 63 0 187 0 0 62-187 0z m875 188l0-188-188 0 0-62 188 0 62 0 0 62 0 188-62 0z m-125 188l-1 0-93-94-156 156 156 156 92-93 2 0 0 250-250 0 0-2 93-92-156-156-156 156 94 92 0 2-250 0 0-250 0 0 93 93 157-156-157-156-93 94 0 0 0-250 250 0 0 0-94 93 156 157 156-157-93-93 0 0 250 0 0 250z\",transform:\"matrix(1 0 0 -1 0 850)\"},tooltip_basic:{width:1500,height:1e3,path:\"m375 725l0 0-375-375 375-374 0-1 1125 0 0 750-1125 0z\",transform:\"matrix(1 0 0 -1 0 850)\"},tooltip_compare:{width:1125,height:1e3,path:\"m187 786l0 2-187-188 188-187 0 0 937 0 0 373-938 0z m0-499l0 1-187-188 188-188 0 0 937 0 0 376-938-1z\",transform:\"matrix(1 0 0 -1 0 850)\"},plotlylogo:{width:1542,height:1e3,path:\"m0-10h182v-140h-182v140z m228 146h183v-286h-183v286z m225 714h182v-1000h-182v1000z m225-285h182v-715h-182v715z m225 142h183v-857h-183v857z m231-428h182v-429h-182v429z m225-291h183v-138h-183v138z\",transform:\"matrix(1 0 0 -1 0 850)\"},\"z-axis\":{width:1e3,height:1e3,path:\"m833 5l-17 108v41l-130-65 130-66c0 0 0 38 0 39 0-1 36-14 39-25 4-15-6-22-16-30-15-12-39-16-56-20-90-22-187-23-279-23-261 0-341 34-353 59 3 60 228 110 228 110-140-8-351-35-351-116 0-120 293-142 474-142 155 0 477 22 477 142 0 50-74 79-163 96z m-374 94c-58-5-99-21-99-40 0-24 65-43 144-43 79 0 143 19 143 43 0 19-42 34-98 40v216h87l-132 135-133-135h88v-216z m167 515h-136v1c16 16 31 34 46 52l84 109v54h-230v-71h124v-1c-16-17-28-32-44-51l-89-114v-51h245v72z\",transform:\"matrix(1 0 0 -1 0 850)\"},\"3d_rotate\":{width:1e3,height:1e3,path:\"m922 660c-5 4-9 7-14 11-359 263-580-31-580-31l-102 28 58-400c0 1 1 1 2 2 118 108 351 249 351 249s-62 27-100 42c88 83 222 183 347 122 16-8 30-17 44-27-2 1-4 2-6 4z m36-329c0 0 64 229-88 296-62 27-124 14-175-11 157-78 225-208 249-266 8-19 11-31 11-31 2 5 6 15 11 32-5-13-8-20-8-20z m-775-239c70-31 117-50 198-32-121 80-199 346-199 346l-96-15-58-12c0 0 55-226 155-287z m603 133l-317-139c0 0 4-4 19-14 7-5 24-15 24-15s-177-147-389 4c235-287 536-112 536-112l31-22 100 299-4-1z m-298-153c6-4 14-9 24-15 0 0-17 10-24 15z\",transform:\"matrix(1 0 0 -1 0 850)\"},camera:{width:1e3,height:1e3,path:\"m500 450c-83 0-150-67-150-150 0-83 67-150 150-150 83 0 150 67 150 150 0 83-67 150-150 150z m400 150h-120c-16 0-34 13-39 29l-31 93c-6 15-23 28-40 28h-340c-16 0-34-13-39-28l-31-94c-6-15-23-28-40-28h-120c-55 0-100-45-100-100v-450c0-55 45-100 100-100h800c55 0 100 45 100 100v450c0 55-45 100-100 100z m-400-550c-138 0-250 112-250 250 0 138 112 250 250 250 138 0 250-112 250-250 0-138-112-250-250-250z m365 380c-19 0-35 16-35 35 0 19 16 35 35 35 19 0 35-16 35-35 0-19-16-35-35-35z\",transform:\"matrix(1 0 0 -1 0 850)\"},movie:{width:1e3,height:1e3,path:\"m938 413l-188-125c0 37-17 71-44 94 64 38 107 107 107 187 0 121-98 219-219 219-121 0-219-98-219-219 0-61 25-117 66-156h-115c30 33 49 76 49 125 0 103-84 187-187 187s-188-84-188-187c0-57 26-107 65-141-38-22-65-62-65-109v-250c0-70 56-126 125-126h500c69 0 125 56 125 126l188-126c34 0 62 28 62 63v375c0 35-28 63-62 63z m-750 0c-69 0-125 56-125 125s56 125 125 125 125-56 125-125-56-125-125-125z m406-1c-87 0-157 70-157 157 0 86 70 156 157 156s156-70 156-156-70-157-156-157z\",transform:\"matrix(1 0 0 -1 0 850)\"},question:{width:857.1,height:1e3,path:\"m500 82v107q0 8-5 13t-13 5h-107q-8 0-13-5t-5-13v-107q0-8 5-13t13-5h107q8 0 13 5t5 13z m143 375q0 49-31 91t-77 65-95 23q-136 0-207-119-9-14 4-24l74-55q4-4 10-4 9 0 14 7 30 38 48 51 19 14 48 14 27 0 48-15t21-33q0-21-11-34t-38-25q-35-16-65-48t-29-70v-20q0-8 5-13t13-5h107q8 0 13 5t5 13q0 10 12 27t30 28q18 10 28 16t25 19 25 27 16 34 7 45z m214-107q0-117-57-215t-156-156-215-58-216 58-155 156-58 215 58 215 155 156 216 58 215-58 156-156 57-215z\",transform:\"matrix(1 0 0 -1 0 850)\"},disk:{width:857.1,height:1e3,path:\"m214-7h429v214h-429v-214z m500 0h72v500q0 8-6 21t-11 20l-157 156q-5 6-19 12t-22 5v-232q0-22-15-38t-38-16h-322q-22 0-37 16t-16 38v232h-72v-714h72v232q0 22 16 38t37 16h465q22 0 38-16t15-38v-232z m-214 518v178q0 8-5 13t-13 5h-107q-7 0-13-5t-5-13v-178q0-8 5-13t13-5h107q7 0 13 5t5 13z m357-18v-518q0-22-15-38t-38-16h-750q-23 0-38 16t-16 38v750q0 22 16 38t38 16h517q23 0 50-12t42-26l156-157q16-15 27-42t11-49z\",transform:\"matrix(1 0 0 -1 0 850)\"},drawopenpath:{width:70,height:70,path:\"M33.21,85.65a7.31,7.31,0,0,1-2.59-.48c-8.16-3.11-9.27-19.8-9.88-41.3-.1-3.58-.19-6.68-.35-9-.15-2.1-.67-3.48-1.43-3.79-2.13-.88-7.91,2.32-12,5.86L3,32.38c1.87-1.64,11.55-9.66,18.27-6.9,2.13.87,4.75,3.14,5.17,9,.17,2.43.26,5.59.36,9.25a224.17,224.17,0,0,0,1.5,23.4c1.54,10.76,4,12.22,4.48,12.4.84.32,2.79-.46,5.76-3.59L43,80.07C41.53,81.57,37.68,85.64,33.21,85.65ZM74.81,69a11.34,11.34,0,0,0,6.09-6.72L87.26,44.5,74.72,32,56.9,38.35c-2.37.86-5.57,3.42-6.61,6L38.65,72.14l8.42,8.43ZM55,46.27a7.91,7.91,0,0,1,3.64-3.17l14.8-5.3,8,8L76.11,60.6l-.06.19a6.37,6.37,0,0,1-3,3.43L48.25,74.59,44.62,71Zm16.57,7.82A6.9,6.9,0,1,0,64.64,61,6.91,6.91,0,0,0,71.54,54.09Zm-4.05,0a2.85,2.85,0,1,1-2.85-2.85A2.86,2.86,0,0,1,67.49,54.09Zm-4.13,5.22L60.5,56.45,44.26,72.7l2.86,2.86ZM97.83,35.67,84.14,22l-8.57,8.57L89.26,44.24Zm-13.69-8,8,8-2.85,2.85-8-8Z\",transform:\"matrix(1 0 0 1 -15 -15)\"},drawclosedpath:{width:90,height:90,path:\"M88.41,21.12a26.56,26.56,0,0,0-36.18,0l-2.07,2-2.07-2a26.57,26.57,0,0,0-36.18,0,23.74,23.74,0,0,0,0,34.8L48,90.12a3.22,3.22,0,0,0,4.42,0l36-34.21a23.73,23.73,0,0,0,0-34.79ZM84,51.24,50.16,83.35,16.35,51.25a17.28,17.28,0,0,1,0-25.47,20,20,0,0,1,27.3,0l4.29,4.07a3.23,3.23,0,0,0,4.44,0l4.29-4.07a20,20,0,0,1,27.3,0,17.27,17.27,0,0,1,0,25.46ZM66.76,47.68h-33v6.91h33ZM53.35,35H46.44V68h6.91Z\",transform:\"matrix(1 0 0 1 -5 -5)\"},lasso:{width:1031,height:1e3,path:\"m1018 538c-36 207-290 336-568 286-277-48-473-256-436-463 10-57 36-108 76-151-13-66 11-137 68-183 34-28 75-41 114-42l-55-70 0 0c-2-1-3-2-4-3-10-14-8-34 5-45 14-11 34-8 45 4 1 1 2 3 2 5l0 0 113 140c16 11 31 24 45 40 4 3 6 7 8 11 48-3 100 0 151 9 278 48 473 255 436 462z m-624-379c-80 14-149 48-197 96 42 42 109 47 156 9 33-26 47-66 41-105z m-187-74c-19 16-33 37-39 60 50-32 109-55 174-68-42-25-95-24-135 8z m360 75c-34-7-69-9-102-8 8 62-16 128-68 170-73 59-175 54-244-5-9 20-16 40-20 61-28 159 121 317 333 354s407-60 434-217c28-159-121-318-333-355z\",transform:\"matrix(1 0 0 -1 0 850)\"},selectbox:{width:1e3,height:1e3,path:\"m0 850l0-143 143 0 0 143-143 0z m286 0l0-143 143 0 0 143-143 0z m285 0l0-143 143 0 0 143-143 0z m286 0l0-143 143 0 0 143-143 0z m-857-286l0-143 143 0 0 143-143 0z m857 0l0-143 143 0 0 143-143 0z m-857-285l0-143 143 0 0 143-143 0z m857 0l0-143 143 0 0 143-143 0z m-857-286l0-143 143 0 0 143-143 0z m286 0l0-143 143 0 0 143-143 0z m285 0l0-143 143 0 0 143-143 0z m286 0l0-143 143 0 0 143-143 0z\",transform:\"matrix(1 0 0 -1 0 850)\"},drawline:{width:70,height:70,path:\"M60.64,62.3a11.29,11.29,0,0,0,6.09-6.72l6.35-17.72L60.54,25.31l-17.82,6.4c-2.36.86-5.57,3.41-6.6,6L24.48,65.5l8.42,8.42ZM40.79,39.63a7.89,7.89,0,0,1,3.65-3.17l14.79-5.31,8,8L61.94,54l-.06.19a6.44,6.44,0,0,1-3,3.43L34.07,68l-3.62-3.63Zm16.57,7.81a6.9,6.9,0,1,0-6.89,6.9A6.9,6.9,0,0,0,57.36,47.44Zm-4,0a2.86,2.86,0,1,1-2.85-2.85A2.86,2.86,0,0,1,53.32,47.44Zm-4.13,5.22L46.33,49.8,30.08,66.05l2.86,2.86ZM83.65,29,70,15.34,61.4,23.9,75.09,37.59ZM70,21.06l8,8-2.84,2.85-8-8ZM87,80.49H10.67V87H87Z\",transform:\"matrix(1 0 0 1 -15 -15)\"},drawrect:{width:80,height:80,path:\"M78,22V79H21V22H78m9-9H12V88H87V13ZM68,46.22H31V54H68ZM53,32H45.22V69H53Z\",transform:\"matrix(1 0 0 1 -10 -10)\"},drawcircle:{width:80,height:80,path:\"M50,84.72C26.84,84.72,8,69.28,8,50.3S26.84,15.87,50,15.87,92,31.31,92,50.3,73.16,84.72,50,84.72Zm0-60.59c-18.6,0-33.74,11.74-33.74,26.17S31.4,76.46,50,76.46,83.74,64.72,83.74,50.3,68.6,24.13,50,24.13Zm17.15,22h-34v7.11h34Zm-13.8-13H46.24v34h7.11Z\",transform:\"matrix(1 0 0 1 -10 -10)\"},eraseshape:{width:80,height:80,path:\"M82.77,78H31.85L6,49.57,31.85,21.14H82.77a8.72,8.72,0,0,1,8.65,8.77V69.24A8.72,8.72,0,0,1,82.77,78ZM35.46,69.84H82.77a.57.57,0,0,0,.49-.6V29.91a.57.57,0,0,0-.49-.61H35.46L17,49.57Zm32.68-34.7-24,24,5,5,24-24Zm-19,.53-5,5,24,24,5-5Z\",transform:\"matrix(1 0 0 1 -10 -10)\"},spikeline:{width:1e3,height:1e3,path:\"M512 409c0-57-46-104-103-104-57 0-104 47-104 104 0 57 47 103 104 103 57 0 103-46 103-103z m-327-39l92 0 0 92-92 0z m-185 0l92 0 0 92-92 0z m370-186l92 0 0 93-92 0z m0-184l92 0 0 92-92 0z\",transform:\"matrix(1.5 0 0 -1.5 0 850)\"},pencil:{width:1792,height:1792,path:\"M491 1536l91-91-235-235-91 91v107h128v128h107zm523-928q0-22-22-22-10 0-17 7l-542 542q-7 7-7 17 0 22 22 22 10 0 17-7l542-542q7-7 7-17zm-54-192l416 416-832 832h-416v-416zm683 96q0 53-37 90l-166 166-416-416 166-165q36-38 90-38 53 0 91 38l235 234q37 39 37 91z\",transform:\"matrix(1 0 0 1 0 1)\"},newplotlylogo:{name:\"newplotlylogo\",svg:\"<svg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 132 132'><defs><style>.cls-1 {fill: #3f4f75;} .cls-2 {fill: #80cfbe;} .cls-3 {fill: #fff;}</style></defs><title>plotly-logomark</title><g id='symbol'><rect class='cls-1' width='132' height='132' rx='6' ry='6'/><circle class='cls-2' cx='78' cy='54' r='6'/><circle class='cls-2' cx='102' cy='30' r='6'/><circle class='cls-2' cx='78' cy='30' r='6'/><circle class='cls-2' cx='54' cy='30' r='6'/><circle class='cls-2' cx='30' cy='30' r='6'/><circle class='cls-2' cx='30' cy='54' r='6'/><path class='cls-3' d='M30,72a6,6,0,0,0-6,6v24a6,6,0,0,0,12,0V78A6,6,0,0,0,30,72Z'/><path class='cls-3' d='M78,72a6,6,0,0,0-6,6v24a6,6,0,0,0,12,0V78A6,6,0,0,0,78,72Z'/><path class='cls-3' d='M54,48a6,6,0,0,0-6,6v48a6,6,0,0,0,12,0V54A6,6,0,0,0,54,48Z'/><path class='cls-3' d='M102,48a6,6,0,0,0-6,6v48a6,6,0,0,0,12,0V54A6,6,0,0,0,102,48Z'/></g></svg>\"}}},{}],779:[function(t,e,r){\"use strict\";r.isLeftAnchor=function(t){return\"left\"===t.xanchor||\"auto\"===t.xanchor&&t.x<=1/3},r.isCenterAnchor=function(t){return\"center\"===t.xanchor||\"auto\"===t.xanchor&&t.x>1/3&&t.x<2/3},r.isRightAnchor=function(t){return\"right\"===t.xanchor||\"auto\"===t.xanchor&&t.x>=2/3},r.isTopAnchor=function(t){return\"top\"===t.yanchor||\"auto\"===t.yanchor&&t.y>=2/3},r.isMiddleAnchor=function(t){return\"middle\"===t.yanchor||\"auto\"===t.yanchor&&t.y>1/3&&t.y<2/3},r.isBottomAnchor=function(t){return\"bottom\"===t.yanchor||\"auto\"===t.yanchor&&t.y<=1/3}},{}],780:[function(t,e,r){\"use strict\";var n=t(\"./mod\"),i=n.mod,a=n.modHalf,o=Math.PI,s=2*o;function l(t){return Math.abs(t[1]-t[0])>s-1e-14}function c(t,e){return a(e-t,s)}function u(t,e){if(l(e))return!0;var r,n;e[0]<e[1]?(r=e[0],n=e[1]):(r=e[1],n=e[0]),(r=i(r,s))>(n=i(n,s))&&(n+=s);var a=i(t,s),o=a+s;return a>=r&&a<=n||o>=r&&o<=n}function f(t,e,r,n,i,a,c){i=i||0,a=a||0;var u,f,h,p,d,m=l([r,n]);function g(t,e){return[t*Math.cos(e)+i,a-t*Math.sin(e)]}m?(u=0,f=o,h=s):r<n?(u=r,h=n):(u=n,h=r),t<e?(p=t,d=e):(p=e,d=t);var v,y=Math.abs(h-u)<=o?0:1;function x(t,e,r){return\"A\"+[t,t]+\" \"+[0,y,r]+\" \"+g(t,e)}return m?v=null===p?\"M\"+g(d,u)+x(d,f,0)+x(d,h,0)+\"Z\":\"M\"+g(p,u)+x(p,f,0)+x(p,h,0)+\"ZM\"+g(d,u)+x(d,f,1)+x(d,h,1)+\"Z\":null===p?(v=\"M\"+g(d,u)+x(d,h,0),c&&(v+=\"L0,0Z\")):v=\"M\"+g(p,u)+\"L\"+g(d,u)+x(d,h,0)+\"L\"+g(p,h)+x(p,u,1)+\"Z\",v}e.exports={deg2rad:function(t){return t/180*o},rad2deg:function(t){return t/o*180},angleDelta:c,angleDist:function(t,e){return Math.abs(c(t,e))},isFullCircle:l,isAngleInsideSector:u,isPtInsideSector:function(t,e,r,n){return!!u(e,n)&&(r[0]<r[1]?(i=r[0],a=r[1]):(i=r[1],a=r[0]),t>=i&&t<=a);var i,a},pathArc:function(t,e,r,n,i){return f(null,t,e,r,n,i,0)},pathSector:function(t,e,r,n,i){return f(null,t,e,r,n,i,1)},pathAnnulus:function(t,e,r,n,i,a){return f(t,e,r,n,i,a,1)}}},{\"./mod\":806}],781:[function(t,e,r){\"use strict\";var n=Array.isArray,i=ArrayBuffer,a=DataView;function o(t){return i.isView(t)&&!(t instanceof a)}function s(t){return n(t)||o(t)}function l(t,e,r){if(s(t)){if(s(t[0])){for(var n=r,i=0;i<t.length;i++)n=e(n,t[i].length);return n}return t.length}return 0}r.isTypedArray=o,r.isArrayOrTypedArray=s,r.isArray1D=function(t){return!s(t[0])},r.ensureArray=function(t,e){return n(t)||(t=[]),t.length=e,t},r.concat=function(){var t,e,r,i,a,o,s,l,c=[],u=!0,f=0;for(r=0;r<arguments.length;r++)(o=(i=arguments[r]).length)&&(e?c.push(i):(e=i,a=o),n(i)?t=!1:(u=!1,f?t!==i.constructor&&(t=!1):t=i.constructor),f+=o);if(!f)return[];if(!c.length)return e;if(u)return e.concat.apply(e,c);if(t){for((s=new t(f)).set(e),r=0;r<c.length;r++)i=c[r],s.set(i,a),a+=i.length;return s}for(s=new Array(f),l=0;l<e.length;l++)s[l]=e[l];for(r=0;r<c.length;r++){for(i=c[r],l=0;l<i.length;l++)s[a+l]=i[l];a+=l}return s},r.maxRowLength=function(t){return l(t,Math.max,0)},r.minRowLength=function(t){return l(t,Math.min,1/0)}},{}],782:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../constants/numerical\").BADNUM,a=/^['\"%,$#\\s']+|[, ]|['\"%,$#\\s']+$/g;e.exports=function(t){return\"string\"==typeof t&&(t=t.replace(a,\"\")),n(t)?Number(t):i}},{\"../constants/numerical\":775,\"fast-isnumeric\":245}],783:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t._fullLayout;e._glcanvas&&e._glcanvas.size()&&e._glcanvas.each((function(t){t.regl&&t.regl.clear({color:!0,depth:!0})}))}},{}],784:[function(t,e,r){\"use strict\";e.exports=function(t){t._responsiveChartHandler&&(window.removeEventListener(\"resize\",t._responsiveChartHandler),delete t._responsiveChartHandler)}},{}],785:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"tinycolor2\"),a=t(\"../plots/attributes\"),o=t(\"../components/colorscale/scales\"),s=t(\"../components/color\"),l=t(\"../constants/interactions\").DESELECTDIM,c=t(\"./nested_property\"),u=t(\"./regex\").counter,f=t(\"./mod\").modHalf,h=t(\"./array\").isArrayOrTypedArray;function p(t,e){var n=r.valObjectMeta[e.valType];if(e.arrayOk&&h(t))return!0;if(n.validateFunction)return n.validateFunction(t,e);var i={},a=i,o={set:function(t){a=t}};return n.coerceFunction(t,o,i,e),a!==i}r.valObjectMeta={data_array:{coerceFunction:function(t,e,r){h(t)?e.set(t):void 0!==r&&e.set(r)}},enumerated:{coerceFunction:function(t,e,r,n){n.coerceNumber&&(t=+t),-1===n.values.indexOf(t)?e.set(r):e.set(t)},validateFunction:function(t,e){e.coerceNumber&&(t=+t);for(var r=e.values,n=0;n<r.length;n++){var i=String(r[n]);if(\"/\"===i.charAt(0)&&\"/\"===i.charAt(i.length-1)){if(new RegExp(i.substr(1,i.length-2)).test(t))return!0}else if(t===r[n])return!0}return!1}},boolean:{coerceFunction:function(t,e,r){!0===t||!1===t?e.set(t):e.set(r)}},number:{coerceFunction:function(t,e,r,i){!n(t)||void 0!==i.min&&t<i.min||void 0!==i.max&&t>i.max?e.set(r):e.set(+t)}},integer:{coerceFunction:function(t,e,r,i){t%1||!n(t)||void 0!==i.min&&t<i.min||void 0!==i.max&&t>i.max?e.set(r):e.set(+t)}},string:{coerceFunction:function(t,e,r,n){if(\"string\"!=typeof t){var i=\"number\"==typeof t;!0!==n.strict&&i?e.set(String(t)):e.set(r)}else n.noBlank&&!t?e.set(r):e.set(t)}},color:{coerceFunction:function(t,e,r){i(t).isValid()?e.set(t):e.set(r)}},colorlist:{coerceFunction:function(t,e,r){Array.isArray(t)&&t.length&&t.every((function(t){return i(t).isValid()}))?e.set(t):e.set(r)}},colorscale:{coerceFunction:function(t,e,r){e.set(o.get(t,r))}},angle:{coerceFunction:function(t,e,r){\"auto\"===t?e.set(\"auto\"):n(t)?e.set(f(+t,360)):e.set(r)}},subplotid:{coerceFunction:function(t,e,r,n){var i=n.regex||u(r);\"string\"==typeof t&&i.test(t)?e.set(t):e.set(r)},validateFunction:function(t,e){var r=e.dflt;return t===r||\"string\"==typeof t&&!!u(r).test(t)}},flaglist:{coerceFunction:function(t,e,r,n){if(\"string\"==typeof t)if(-1===(n.extras||[]).indexOf(t)){for(var i=t.split(\"+\"),a=0;a<i.length;){var o=i[a];-1===n.flags.indexOf(o)||i.indexOf(o)<a?i.splice(a,1):a++}i.length?e.set(i.join(\"+\")):e.set(r)}else e.set(t);else e.set(r)}},any:{coerceFunction:function(t,e,r){void 0===t?e.set(r):e.set(t)}},info_array:{coerceFunction:function(t,e,n,i){function a(t,e,n){var i,a={set:function(t){i=t}};return void 0===n&&(n=e.dflt),r.valObjectMeta[e.valType].coerceFunction(t,a,n,e),i}var o=2===i.dimensions||\"1-2\"===i.dimensions&&Array.isArray(t)&&Array.isArray(t[0]);if(Array.isArray(t)){var s,l,c,u,f,h,p=i.items,d=[],m=Array.isArray(p),g=m&&o&&Array.isArray(p[0]),v=o&&m&&!g,y=m&&!v?p.length:t.length;if(n=Array.isArray(n)?n:[],o)for(s=0;s<y;s++)for(d[s]=[],c=Array.isArray(t[s])?t[s]:[],f=v?p.length:m?p[s].length:c.length,l=0;l<f;l++)u=v?p[l]:m?p[s][l]:p,void 0!==(h=a(c[l],u,(n[s]||[])[l]))&&(d[s][l]=h);else for(s=0;s<y;s++)void 0!==(h=a(t[s],m?p[s]:p,n[s]))&&(d[s]=h);e.set(d)}else e.set(n)},validateFunction:function(t,e){if(!Array.isArray(t))return!1;var r=e.items,n=Array.isArray(r),i=2===e.dimensions;if(!e.freeLength&&t.length!==r.length)return!1;for(var a=0;a<t.length;a++)if(i){if(!Array.isArray(t[a])||!e.freeLength&&t[a].length!==r[a].length)return!1;for(var o=0;o<t[a].length;o++)if(!p(t[a][o],n?r[a][o]:r))return!1}else if(!p(t[a],n?r[a]:r))return!1;return!0}}},r.coerce=function(t,e,n,i,a){var o=c(n,i).get(),s=c(t,i),l=c(e,i),u=s.get(),f=e._template;if(void 0===u&&f&&(u=c(f,i).get(),f=0),void 0===a&&(a=o.dflt),o.arrayOk&&h(u))return l.set(u),u;var d=r.valObjectMeta[o.valType].coerceFunction;d(u,l,a,o);var m=l.get();return f&&m===a&&!p(u,o)&&(d(u=c(f,i).get(),l,a,o),m=l.get()),m},r.coerce2=function(t,e,n,i,a){var o=c(t,i),s=r.coerce(t,e,n,i,a),l=o.get();return null!=l&&s},r.coerceFont=function(t,e,r){var n={};return r=r||{},n.family=t(e+\".family\",r.family),n.size=t(e+\".size\",r.size),n.color=t(e+\".color\",r.color),n},r.coercePattern=function(t,e,r,n){if(t(e+\".shape\")){t(e+\".solidity\"),t(e+\".size\");var i=\"overlay\"===t(e+\".fillmode\");if(!n){var a=t(e+\".bgcolor\",i?r:void 0);t(e+\".fgcolor\",i?s.contrast(a):r)}t(e+\".fgopacity\",i?.5:1)}},r.coerceHoverinfo=function(t,e,n){var i,o=e._module.attributes,s=o.hoverinfo?o:a,l=s.hoverinfo;if(1===n._dataLength){var c=\"all\"===l.dflt?l.flags.slice():l.dflt.split(\"+\");c.splice(c.indexOf(\"name\"),1),i=c.join(\"+\")}return r.coerce(t,e,s,\"hoverinfo\",i)},r.coerceSelectionMarkerOpacity=function(t,e){if(t.marker){var r,n,i=t.marker.opacity;if(void 0!==i)h(i)||t.selected||t.unselected||(r=i,n=l*i),e(\"selected.marker.opacity\",r),e(\"unselected.marker.opacity\",n)}},r.validate=p},{\"../components/color\":662,\"../components/colorscale/scales\":677,\"../constants/interactions\":774,\"../plots/attributes\":845,\"./array\":781,\"./mod\":806,\"./nested_property\":807,\"./regex\":816,\"fast-isnumeric\":245,tinycolor2:594}],786:[function(t,e,r){\"use strict\";var n,i,a=t(\"d3-time-format\").timeFormat,o=t(\"fast-isnumeric\"),s=t(\"./loggers\"),l=t(\"./mod\").mod,c=t(\"../constants/numerical\"),u=c.BADNUM,f=c.ONEDAY,h=c.ONEHOUR,p=c.ONEMIN,d=c.ONESEC,m=c.EPOCHJD,g=t(\"../registry\"),v=t(\"d3-time-format\").utcFormat,y=/^\\s*(-?\\d\\d\\d\\d|\\d\\d)(-(\\d?\\d)(-(\\d?\\d)([ Tt]([01]?\\d|2[0-3])(:([0-5]\\d)(:([0-5]\\d(\\.\\d+)?))?(Z|z|[+\\-]\\d\\d(:?\\d\\d)?)?)?)?)?)?\\s*$/m,x=/^\\s*(-?\\d\\d\\d\\d|\\d\\d)(-(\\d?\\di?)(-(\\d?\\d)([ Tt]([01]?\\d|2[0-3])(:([0-5]\\d)(:([0-5]\\d(\\.\\d+)?))?(Z|z|[+\\-]\\d\\d(:?\\d\\d)?)?)?)?)?)?\\s*$/m,b=(new Date).getFullYear()-70;function _(t){return t&&g.componentsRegistry.calendars&&\"string\"==typeof t&&\"gregorian\"!==t}function w(t,e){return String(t+Math.pow(10,e)).substr(1)}r.dateTick0=function(t,e){var n=function(t,e){return _(t)?e?g.getComponentMethod(\"calendars\",\"CANONICAL_SUNDAY\")[t]:g.getComponentMethod(\"calendars\",\"CANONICAL_TICK\")[t]:e?\"2000-01-02\":\"2000-01-01\"}(t,!!e);if(e<2)return n;var i=r.dateTime2ms(n,t);return i+=f*(e-1),r.ms2DateTime(i,0,t)},r.dfltRange=function(t){return _(t)?g.getComponentMethod(\"calendars\",\"DFLTRANGE\")[t]:[\"2000-01-01\",\"2001-01-01\"]},r.isJSDate=function(t){return\"object\"==typeof t&&null!==t&&\"function\"==typeof t.getTime},r.dateTime2ms=function(t,e){if(r.isJSDate(t)){var a=t.getTimezoneOffset()*p,o=(t.getUTCMinutes()-t.getMinutes())*p+(t.getUTCSeconds()-t.getSeconds())*d+(t.getUTCMilliseconds()-t.getMilliseconds());if(o){var s=3*p;a=a-s/2+l(o-a+s/2,s)}return(t=Number(t)-a)>=n&&t<=i?t:u}if(\"string\"!=typeof t&&\"number\"!=typeof t)return u;t=String(t);var c=_(e),v=t.charAt(0);!c||\"G\"!==v&&\"g\"!==v||(t=t.substr(1),e=\"\");var w=c&&\"chinese\"===e.substr(0,7),T=t.match(w?x:y);if(!T)return u;var k=T[1],M=T[3]||\"1\",A=Number(T[5]||1),S=Number(T[7]||0),E=Number(T[9]||0),L=Number(T[11]||0);if(c){if(2===k.length)return u;var C;k=Number(k);try{var P=g.getComponentMethod(\"calendars\",\"getCal\")(e);if(w){var I=\"i\"===M.charAt(M.length-1);M=parseInt(M,10),C=P.newDate(k,P.toMonthIndex(k,M,I),A)}else C=P.newDate(k,Number(M),A)}catch(t){return u}return C?(C.toJD()-m)*f+S*h+E*p+L*d:u}k=2===k.length?(Number(k)+2e3-b)%100+b:Number(k),M-=1;var O=new Date(Date.UTC(2e3,M,A,S,E));return O.setUTCFullYear(k),O.getUTCMonth()!==M||O.getUTCDate()!==A?u:O.getTime()+L*d},n=r.MIN_MS=r.dateTime2ms(\"-9999\"),i=r.MAX_MS=r.dateTime2ms(\"9999-12-31 23:59:59.9999\"),r.isDateTime=function(t,e){return r.dateTime2ms(t,e)!==u};var T=90*f,k=3*h,M=5*p;function A(t,e,r,n,i){if((e||r||n||i)&&(t+=\" \"+w(e,2)+\":\"+w(r,2),(n||i)&&(t+=\":\"+w(n,2),i))){for(var a=4;i%10==0;)a-=1,i/=10;t+=\".\"+w(i,a)}return t}r.ms2DateTime=function(t,e,r){if(\"number\"!=typeof t||!(t>=n&&t<=i))return u;e||(e=0);var a,o,s,c,y,x,b=Math.floor(10*l(t+.05,1)),w=Math.round(t-b/10);if(_(r)){var S=Math.floor(w/f)+m,E=Math.floor(l(t,f));try{a=g.getComponentMethod(\"calendars\",\"getCal\")(r).fromJD(S).formatDate(\"yyyy-mm-dd\")}catch(t){a=v(\"G%Y-%m-%d\")(new Date(w))}if(\"-\"===a.charAt(0))for(;a.length<11;)a=\"-0\"+a.substr(1);else for(;a.length<10;)a=\"0\"+a;o=e<T?Math.floor(E/h):0,s=e<T?Math.floor(E%h/p):0,c=e<k?Math.floor(E%p/d):0,y=e<M?E%d*10+b:0}else x=new Date(w),a=v(\"%Y-%m-%d\")(x),o=e<T?x.getUTCHours():0,s=e<T?x.getUTCMinutes():0,c=e<k?x.getUTCSeconds():0,y=e<M?10*x.getUTCMilliseconds()+b:0;return A(a,o,s,c,y)},r.ms2DateTimeLocal=function(t){if(!(t>=n+f&&t<=i-f))return u;var e=Math.floor(10*l(t+.05,1)),r=new Date(Math.round(t-e/10));return A(a(\"%Y-%m-%d\")(r),r.getHours(),r.getMinutes(),r.getSeconds(),10*r.getUTCMilliseconds()+e)},r.cleanDate=function(t,e,n){if(t===u)return e;if(r.isJSDate(t)||\"number\"==typeof t&&isFinite(t)){if(_(n))return s.error(\"JS Dates and milliseconds are incompatible with world calendars\",t),e;if(!(t=r.ms2DateTimeLocal(+t))&&void 0!==e)return e}else if(!r.isDateTime(t,n))return s.error(\"unrecognized date\",t),e;return t};var S=/%\\d?f/g,E=/%h/g,L={1:\"1\",2:\"1\",3:\"2\",4:\"2\"};function C(t,e,r,n){t=t.replace(S,(function(t){var r=Math.min(+t.charAt(1)||6,6);return(e/1e3%1+2).toFixed(r).substr(2).replace(/0+$/,\"\")||\"0\"}));var i=new Date(Math.floor(e+.05));if(t=t.replace(E,(function(){return L[r(\"%q\")(i)]})),_(n))try{t=g.getComponentMethod(\"calendars\",\"worldCalFmt\")(t,e,n)}catch(t){return\"Invalid\"}return r(t)(i)}var P=[59,59.9,59.99,59.999,59.9999];r.formatDate=function(t,e,r,n,i,a){if(i=_(i)&&i,!e)if(\"y\"===r)e=a.year;else if(\"m\"===r)e=a.month;else{if(\"d\"!==r)return function(t,e){var r=l(t+.05,f),n=w(Math.floor(r/h),2)+\":\"+w(l(Math.floor(r/p),60),2);if(\"M\"!==e){o(e)||(e=0);var i=(100+Math.min(l(t/d,60),P[e])).toFixed(e).substr(1);e>0&&(i=i.replace(/0+$/,\"\").replace(/[\\.]$/,\"\")),n+=\":\"+i}return n}(t,r)+\"\\n\"+C(a.dayMonthYear,t,n,i);e=a.dayMonth+\"\\n\"+a.year}return C(e,t,n,i)};var I=3*f;r.incrementMonth=function(t,e,r){r=_(r)&&r;var n=l(t,f);if(t=Math.round(t-n),r)try{var i=Math.round(t/f)+m,a=g.getComponentMethod(\"calendars\",\"getCal\")(r),o=a.fromJD(i);return e%12?a.add(o,e,\"m\"):a.add(o,e/12,\"y\"),(o.toJD()-m)*f+n}catch(e){s.error(\"invalid ms \"+t+\" in calendar \"+r)}var c=new Date(t+I);return c.setUTCMonth(c.getUTCMonth()+e)+n-I},r.findExactDates=function(t,e){for(var r,n,i=0,a=0,s=0,l=0,c=_(e)&&g.getComponentMethod(\"calendars\",\"getCal\")(e),u=0;u<t.length;u++)if(n=t[u],o(n)){if(!(n%f))if(c)try{1===(r=c.fromJD(n/f+m)).day()?1===r.month()?i++:a++:s++}catch(t){}else 1===(r=new Date(n)).getUTCDate()?0===r.getUTCMonth()?i++:a++:s++}else l++;s+=a+=i;var h=t.length-l;return{exactYears:i/h,exactMonths:a/h,exactDays:s/h}}},{\"../constants/numerical\":775,\"../registry\":927,\"./loggers\":803,\"./mod\":806,\"d3-time-format\":172,\"fast-isnumeric\":245}],787:[function(t,e,r){\"use strict\";var n=t(\"@plotly/d3\"),i=t(\"./loggers\"),a=t(\"./matrix\"),o=t(\"gl-mat4\");function s(t){var e=t&&t.parentNode;e&&e.removeChild(t)}function l(t,e,r){var n=\"plotly.js-style-\"+t,a=document.getElementById(n);a||((a=document.createElement(\"style\")).setAttribute(\"id\",n),a.appendChild(document.createTextNode(\"\")),document.head.appendChild(a));var o=a.sheet;o.insertRule?o.insertRule(e+\"{\"+r+\"}\",0):o.addRule?o.addRule(e,r,0):i.warn(\"addStyleRule failed\")}function c(t){var e=window.getComputedStyle(t,null),r=e.getPropertyValue(\"-webkit-transform\")||e.getPropertyValue(\"-moz-transform\")||e.getPropertyValue(\"-ms-transform\")||e.getPropertyValue(\"-o-transform\")||e.getPropertyValue(\"transform\");return\"none\"===r?null:r.replace(\"matrix\",\"\").replace(\"3d\",\"\").slice(1,-1).split(\",\").map((function(t){return+t}))}function u(t){for(var e=[];f(t);)e.push(t),t=t.parentNode;return e}function f(t){return t&&(t instanceof Element||t instanceof HTMLElement)}e.exports={getGraphDiv:function(t){var e;if(\"string\"==typeof t){if(null===(e=document.getElementById(t)))throw new Error(\"No DOM element with id '\"+t+\"' exists on the page.\");return e}if(null==t)throw new Error(\"DOM element provided is null or undefined\");return t},isPlotDiv:function(t){var e=n.select(t);return e.node()instanceof HTMLElement&&e.size()&&e.classed(\"js-plotly-plot\")},removeElement:s,addStyleRule:function(t,e){l(\"global\",t,e)},addRelatedStyleRule:l,deleteRelatedStyleRule:function(t){var e=\"plotly.js-style-\"+t,r=document.getElementById(e);r&&s(r)},getFullTransformMatrix:function(t){var e=u(t),r=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1];return e.forEach((function(t){var e=c(t);if(e){var n=a.convertCssMatrix(e);r=o.multiply(r,r,n)}})),r},getElementTransformMatrix:c,getElementAndAncestors:u,equalDomRects:function(t,e){return t&&e&&t.x===e.x&&t.y===e.y&&t.top===e.top&&t.left===e.left&&t.right===e.right&&t.bottom===e.bottom}}},{\"./loggers\":803,\"./matrix\":805,\"@plotly/d3\":58,\"gl-mat4\":294}],788:[function(t,e,r){\"use strict\";var n=t(\"events\").EventEmitter,i={init:function(t){if(t._ev instanceof n)return t;var e=new n,r=new n;return t._ev=e,t._internalEv=r,t.on=e.on.bind(e),t.once=e.once.bind(e),t.removeListener=e.removeListener.bind(e),t.removeAllListeners=e.removeAllListeners.bind(e),t._internalOn=r.on.bind(r),t._internalOnce=r.once.bind(r),t._removeInternalListener=r.removeListener.bind(r),t._removeAllInternalListeners=r.removeAllListeners.bind(r),t.emit=function(n,i){\"undefined\"!=typeof jQuery&&jQuery(t).trigger(n,i),e.emit(n,i),r.emit(n,i)},t},triggerHandler:function(t,e,r){var n,i;\"undefined\"!=typeof jQuery&&(n=jQuery(t).triggerHandler(e,r));var a=t._ev;if(!a)return n;var o,s=a._events[e];if(!s)return n;function l(t){return t.listener?(a.removeListener(e,t.listener),t.fired?void 0:(t.fired=!0,t.listener.apply(a,[r]))):t.apply(a,[r])}for(s=Array.isArray(s)?s:[s],o=0;o<s.length-1;o++)l(s[o]);return i=l(s[o]),void 0!==n?n:i},purge:function(t){return delete t._ev,delete t.on,delete t.once,delete t.removeListener,delete t.removeAllListeners,delete t.emit,delete t._ev,delete t._internalEv,delete t._internalOn,delete t._internalOnce,delete t._removeInternalListener,delete t._removeAllInternalListeners,t}};e.exports=i},{events:116}],789:[function(t,e,r){\"use strict\";var n=t(\"./is_plain_object.js\"),i=Array.isArray;function a(t,e,r,o){var s,l,c,u,f,h,p=t[0],d=t.length;if(2===d&&i(p)&&i(t[1])&&0===p.length){if(function(t,e){var r,n;for(r=0;r<t.length;r++){if(null!==(n=t[r])&&\"object\"==typeof n)return!1;void 0!==n&&(e[r]=n)}return!0}(t[1],p))return p;p.splice(0,p.length)}for(var m=1;m<d;m++)for(l in s=t[m])c=p[l],u=s[l],o&&i(u)?p[l]=u:e&&u&&(n(u)||(f=i(u)))?(f?(f=!1,h=c&&i(c)?c:[]):h=c&&n(c)?c:{},p[l]=a([h,u],e,r,o)):(void 0!==u||r)&&(p[l]=u);return p}r.extendFlat=function(){return a(arguments,!1,!1,!1)},r.extendDeep=function(){return a(arguments,!0,!1,!1)},r.extendDeepAll=function(){return a(arguments,!0,!0,!1)},r.extendDeepNoArrays=function(){return a(arguments,!0,!1,!0)}},{\"./is_plain_object.js\":800}],790:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e={},r=[],n=0,i=0;i<t.length;i++){var a=t[i];1!==e[a]&&(e[a]=1,r[n++]=a)}return r}},{}],791:[function(t,e,r){\"use strict\";function n(t){return!0===t.visible}function i(t){var e=t[0].trace;return!0===e.visible&&0!==e._length}e.exports=function(t){for(var e,r=(e=t,Array.isArray(e)&&Array.isArray(e[0])&&e[0][0]&&e[0][0].trace?i:n),a=[],o=0;o<t.length;o++){var s=t[o];r(s)&&a.push(s)}return a}},{}],792:[function(t,e,r){\"use strict\";var n=t(\"@plotly/d3\"),i=t(\"country-regex\"),a=t(\"@turf/area\"),o=t(\"@turf/centroid\"),s=t(\"@turf/bbox\"),l=t(\"./identity\"),c=t(\"./loggers\"),u=t(\"./is_plain_object\"),f=t(\"./nested_property\"),h=t(\"./polygon\"),p=Object.keys(i),d={\"ISO-3\":l,\"USA-states\":l,\"country names\":function(t){for(var e=0;e<p.length;e++){var r=p[e];if(new RegExp(i[r]).test(t.trim().toLowerCase()))return r}return c.log(\"Unrecognized country name: \"+t+\".\"),!1}};function m(t){var e=t.geojson,r=window.PlotlyGeoAssets||{},n=\"string\"==typeof e?r[e]:e;return u(n)?n:(c.error(\"Oops ... something went wrong when fetching \"+e),!1)}e.exports={locationToFeature:function(t,e,r){if(!e||\"string\"!=typeof e)return!1;var n,i,a,o=d[t](e);if(o){if(\"USA-states\"===t)for(n=[],a=0;a<r.length;a++)(i=r[a]).properties&&i.properties.gu&&\"USA\"===i.properties.gu&&n.push(i);else n=r;for(a=0;a<n.length;a++)if((i=n[a]).id===o)return i;c.log([\"Location with id\",o,\"does not have a matching topojson feature at this resolution.\"].join(\" \"))}return!1},feature2polygons:function(t){var e,r,n,i,a=t.geometry,o=a.coordinates,s=t.id,l=[];function c(t){for(var e=0;e<t.length-1;e++)if(t[e][0]>0&&t[e+1][0]<0)return e;return null}switch(e=\"RUS\"===s||\"FJI\"===s?function(t){var e;if(null===c(t))e=t;else for(e=new Array(t.length),i=0;i<t.length;i++)e[i]=[t[i][0]<0?t[i][0]+360:t[i][0],t[i][1]];l.push(h.tester(e))}:\"ATA\"===s?function(t){var e=c(t);if(null===e)return l.push(h.tester(t));var r=new Array(t.length+1),n=0;for(i=0;i<t.length;i++)i>e?r[n++]=[t[i][0]+360,t[i][1]]:i===e?(r[n++]=t[i],r[n++]=[t[i][0],-90]):r[n++]=t[i];var a=h.tester(r);a.pts.pop(),l.push(a)}:function(t){l.push(h.tester(t))},a.type){case\"MultiPolygon\":for(r=0;r<o.length;r++)for(n=0;n<o[r].length;n++)e(o[r][n]);break;case\"Polygon\":for(r=0;r<o.length;r++)e(o[r])}return l},getTraceGeojson:m,extractTraceFeature:function(t){var e=t[0].trace,r=m(e);if(!r)return!1;var n,i={},s=[];for(n=0;n<e._length;n++){var l=t[n];(l.loc||0===l.loc)&&(i[l.loc]=l)}function u(t){var r=f(t,e.featureidkey||\"id\").get(),n=i[r];if(n){var l=t.geometry;if(\"Polygon\"===l.type||\"MultiPolygon\"===l.type){var u={type:\"Feature\",id:r,geometry:l,properties:{}};u.properties.ct=function(t){var e,r=t.geometry;if(\"MultiPolygon\"===r.type)for(var n=r.coordinates,i=0,s=0;s<n.length;s++){var l={type:\"Polygon\",coordinates:n[s]},c=a.default(l);c>i&&(i=c,e=l)}else e=r;return o.default(e).geometry.coordinates}(u),n.fIn=t,n.fOut=u,s.push(u)}else c.log([\"Location\",n.loc,\"does not have a valid GeoJSON geometry.\",\"Traces with locationmode *geojson-id* only support\",\"*Polygon* and *MultiPolygon* geometries.\"].join(\" \"))}delete i[r]}switch(r.type){case\"FeatureCollection\":var h=r.features;for(n=0;n<h.length;n++)u(h[n]);break;case\"Feature\":u(r);break;default:return c.warn([\"Invalid GeoJSON type\",(r.type||\"none\")+\".\",\"Traces with locationmode *geojson-id* only support\",\"*FeatureCollection* and *Feature* types.\"].join(\" \")),!1}for(var p in i)c.log([\"Location *\"+p+\"*\",\"does not have a matching feature with id-key\",\"*\"+e.featureidkey+\"*.\"].join(\" \"));return s},fetchTraceGeoData:function(t){var e=window.PlotlyGeoAssets||{},r=[];function i(t){return new Promise((function(r,i){n.json(t,(function(n,a){if(n){delete e[t];var o=404===n.status?'GeoJSON at URL \"'+t+'\" does not exist.':\"Unexpected error while fetching from \"+t;return i(new Error(o))}return e[t]=a,r(a)}))}))}function a(t){return new Promise((function(r,n){var i=0,a=setInterval((function(){return e[t]&&\"pending\"!==e[t]?(clearInterval(a),r(e[t])):i>100?(clearInterval(a),n(\"Unexpected error while fetching from \"+t)):void i++}),50)}))}for(var o=0;o<t.length;o++){var s=t[o][0].trace.geojson;\"string\"==typeof s&&(e[s]?\"pending\"===e[s]&&r.push(a(s)):(e[s]=\"pending\",r.push(i(s))))}return r},computeBbox:function(t){return s.default(t)}}},{\"./identity\":797,\"./is_plain_object\":800,\"./loggers\":803,\"./nested_property\":807,\"./polygon\":811,\"@plotly/d3\":58,\"@turf/area\":61,\"@turf/bbox\":64,\"@turf/centroid\":67,\"country-regex\":145}],793:[function(t,e,r){\"use strict\";var n=t(\"../constants/numerical\").BADNUM;r.calcTraceToLineCoords=function(t){for(var e=t[0].trace.connectgaps,r=[],i=[],a=0;a<t.length;a++){var o=t[a].lonlat;o[0]!==n?i.push(o):!e&&i.length>0&&(r.push(i),i=[])}return i.length>0&&r.push(i),r},r.makeLine=function(t){return 1===t.length?{type:\"LineString\",coordinates:t[0]}:{type:\"MultiLineString\",coordinates:t}},r.makePolygon=function(t){if(1===t.length)return{type:\"Polygon\",coordinates:t};for(var e=new Array(t.length),r=0;r<t.length;r++)e[r]=[t[r]];return{type:\"MultiPolygon\",coordinates:e}},r.makeBlank=function(){return{type:\"Point\",coordinates:[]}}},{\"../constants/numerical\":775}],794:[function(t,e,r){\"use strict\";var n,i,a,o=t(\"./mod\").mod;function s(t,e,r,n,i,a,o,s){var l=r-t,c=i-t,u=o-i,f=n-e,h=a-e,p=s-a,d=l*p-u*f;if(0===d)return null;var m=(c*p-u*h)/d,g=(c*f-l*h)/d;return g<0||g>1||m<0||m>1?null:{x:t+l*m,y:e+f*m}}function l(t,e,r,n,i){var a=n*t+i*e;if(a<0)return n*n+i*i;if(a>r){var o=n-t,s=i-e;return o*o+s*s}var l=n*e-i*t;return l*l/r}r.segmentsIntersect=s,r.segmentDistance=function(t,e,r,n,i,a,o,c){if(s(t,e,r,n,i,a,o,c))return 0;var u=r-t,f=n-e,h=o-i,p=c-a,d=u*u+f*f,m=h*h+p*p,g=Math.min(l(u,f,d,i-t,a-e),l(u,f,d,o-t,c-e),l(h,p,m,t-i,e-a),l(h,p,m,r-i,n-a));return Math.sqrt(g)},r.getTextLocation=function(t,e,r,s){if(t===i&&s===a||(n={},i=t,a=s),n[r])return n[r];var l=t.getPointAtLength(o(r-s/2,e)),c=t.getPointAtLength(o(r+s/2,e)),u=Math.atan((c.y-l.y)/(c.x-l.x)),f=t.getPointAtLength(o(r,e)),h={x:(4*f.x+l.x+c.x)/6,y:(4*f.y+l.y+c.y)/6,theta:u};return n[r]=h,h},r.clearLocationCache=function(){i=null},r.getVisibleSegment=function(t,e,r){var n,i,a=e.left,o=e.right,s=e.top,l=e.bottom,c=0,u=t.getTotalLength(),f=u;function h(e){var r=t.getPointAtLength(e);0===e?n=r:e===u&&(i=r);var c=r.x<a?a-r.x:r.x>o?r.x-o:0,f=r.y<s?s-r.y:r.y>l?r.y-l:0;return Math.sqrt(c*c+f*f)}for(var p=h(c);p;){if((c+=p+r)>f)return;p=h(c)}for(p=h(f);p;){if(c>(f-=p+r))return;p=h(f)}return{min:c,max:f,len:f-c,total:u,isClosed:0===c&&f===u&&Math.abs(n.x-i.x)<.1&&Math.abs(n.y-i.y)<.1}},r.findPointOnPath=function(t,e,r,n){for(var i,a,o,s=(n=n||{}).pathLength||t.getTotalLength(),l=n.tolerance||.001,c=n.iterationLimit||30,u=t.getPointAtLength(0)[r]>t.getPointAtLength(s)[r]?-1:1,f=0,h=0,p=s;f<c;){if(i=(h+p)/2,o=(a=t.getPointAtLength(i))[r]-e,Math.abs(o)<l)return a;u*o>0?p=i:h=i,f++}return a}},{\"./mod\":806}],795:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"tinycolor2\"),a=t(\"color-normalize\"),o=t(\"../components/colorscale\"),s=t(\"../components/color/attributes\").defaultLine,l=t(\"./array\").isArrayOrTypedArray,c=a(s);function u(t,e){var r=t;return r[3]*=e,r}function f(t){if(n(t))return c;var e=a(t);return e.length?e:c}function h(t){return n(t)?t:1}e.exports={formatColor:function(t,e,r){var n,i,s,p,d,m=t.color,g=l(m),v=l(e),y=o.extractOpts(t),x=[];if(n=void 0!==y.colorscale?o.makeColorScaleFuncFromTrace(t):f,i=g?function(t,e){return void 0===t[e]?c:a(n(t[e]))}:f,s=v?function(t,e){return void 0===t[e]?1:h(t[e])}:h,g||v)for(var b=0;b<r;b++)p=i(m,b),d=s(e,b),x[b]=u(p,d);else x=u(a(m),e);return x},parseColorScale:function(t){var e=o.extractOpts(t),r=e.colorscale;return e.reversescale&&(r=o.flipScale(e.colorscale)),r.map((function(t){var e=t[0],r=i(t[1]).toRgb();return{index:e,rgb:[r.r,r.g,r.b,r.a]}}))}}},{\"../components/color/attributes\":661,\"../components/colorscale\":674,\"./array\":781,\"color-normalize\":131,\"fast-isnumeric\":245,tinycolor2:594}],796:[function(t,e,r){\"use strict\";var n=t(\"./identity\");function i(t){return[t]}e.exports={keyFun:function(t){return t.key},repeat:i,descend:n,wrap:i,unwrap:function(t){return t[0]}}},{\"./identity\":797}],797:[function(t,e,r){\"use strict\";e.exports=function(t){return t}},{}],798:[function(t,e,r){\"use strict\";e.exports=function(t,e){if(!e)return t;var r=1/Math.abs(e),n=r>1?(r*t+r*e)/r:t+e,i=String(n).length;if(i>16){var a=String(e).length;if(i>=String(t).length+a){var o=parseFloat(n).toPrecision(12);-1===o.indexOf(\"e+\")&&(n=+o)}}return n}},{}],799:[function(t,e,r){\"use strict\";var n=t(\"@plotly/d3\"),i=t(\"d3-time-format\").utcFormat,a=t(\"fast-isnumeric\"),o=t(\"../constants/numerical\"),s=o.FP_SAFE,l=-s,c=o.BADNUM,u=e.exports={};u.nestedProperty=t(\"./nested_property\"),u.keyedContainer=t(\"./keyed_container\"),u.relativeAttr=t(\"./relative_attr\"),u.isPlainObject=t(\"./is_plain_object\"),u.toLogRange=t(\"./to_log_range\"),u.relinkPrivateKeys=t(\"./relink_private\");var f=t(\"./array\");u.isTypedArray=f.isTypedArray,u.isArrayOrTypedArray=f.isArrayOrTypedArray,u.isArray1D=f.isArray1D,u.ensureArray=f.ensureArray,u.concat=f.concat,u.maxRowLength=f.maxRowLength,u.minRowLength=f.minRowLength;var h=t(\"./mod\");u.mod=h.mod,u.modHalf=h.modHalf;var p=t(\"./coerce\");u.valObjectMeta=p.valObjectMeta,u.coerce=p.coerce,u.coerce2=p.coerce2,u.coerceFont=p.coerceFont,u.coercePattern=p.coercePattern,u.coerceHoverinfo=p.coerceHoverinfo,u.coerceSelectionMarkerOpacity=p.coerceSelectionMarkerOpacity,u.validate=p.validate;var d=t(\"./dates\");u.dateTime2ms=d.dateTime2ms,u.isDateTime=d.isDateTime,u.ms2DateTime=d.ms2DateTime,u.ms2DateTimeLocal=d.ms2DateTimeLocal,u.cleanDate=d.cleanDate,u.isJSDate=d.isJSDate,u.formatDate=d.formatDate,u.incrementMonth=d.incrementMonth,u.dateTick0=d.dateTick0,u.dfltRange=d.dfltRange,u.findExactDates=d.findExactDates,u.MIN_MS=d.MIN_MS,u.MAX_MS=d.MAX_MS;var m=t(\"./search\");u.findBin=m.findBin,u.sorterAsc=m.sorterAsc,u.sorterDes=m.sorterDes,u.distinctVals=m.distinctVals,u.roundUp=m.roundUp,u.sort=m.sort,u.findIndexOfMin=m.findIndexOfMin;var g=t(\"./stats\");u.aggNums=g.aggNums,u.len=g.len,u.mean=g.mean,u.median=g.median,u.midRange=g.midRange,u.variance=g.variance,u.stdev=g.stdev,u.interp=g.interp;var v=t(\"./matrix\");u.init2dArray=v.init2dArray,u.transposeRagged=v.transposeRagged,u.dot=v.dot,u.translationMatrix=v.translationMatrix,u.rotationMatrix=v.rotationMatrix,u.rotationXYMatrix=v.rotationXYMatrix,u.apply3DTransform=v.apply3DTransform,u.apply2DTransform=v.apply2DTransform,u.apply2DTransform2=v.apply2DTransform2,u.convertCssMatrix=v.convertCssMatrix,u.inverseTransformMatrix=v.inverseTransformMatrix;var y=t(\"./angles\");u.deg2rad=y.deg2rad,u.rad2deg=y.rad2deg,u.angleDelta=y.angleDelta,u.angleDist=y.angleDist,u.isFullCircle=y.isFullCircle,u.isAngleInsideSector=y.isAngleInsideSector,u.isPtInsideSector=y.isPtInsideSector,u.pathArc=y.pathArc,u.pathSector=y.pathSector,u.pathAnnulus=y.pathAnnulus;var x=t(\"./anchor_utils\");u.isLeftAnchor=x.isLeftAnchor,u.isCenterAnchor=x.isCenterAnchor,u.isRightAnchor=x.isRightAnchor,u.isTopAnchor=x.isTopAnchor,u.isMiddleAnchor=x.isMiddleAnchor,u.isBottomAnchor=x.isBottomAnchor;var b=t(\"./geometry2d\");u.segmentsIntersect=b.segmentsIntersect,u.segmentDistance=b.segmentDistance,u.getTextLocation=b.getTextLocation,u.clearLocationCache=b.clearLocationCache,u.getVisibleSegment=b.getVisibleSegment,u.findPointOnPath=b.findPointOnPath;var _=t(\"./extend\");u.extendFlat=_.extendFlat,u.extendDeep=_.extendDeep,u.extendDeepAll=_.extendDeepAll,u.extendDeepNoArrays=_.extendDeepNoArrays;var w=t(\"./loggers\");u.log=w.log,u.warn=w.warn,u.error=w.error;var T=t(\"./regex\");u.counterRegex=T.counter;var k=t(\"./throttle\");u.throttle=k.throttle,u.throttleDone=k.done,u.clearThrottle=k.clear;var M=t(\"./dom\");function A(t){var e={};for(var r in t)for(var n=t[r],i=0;i<n.length;i++)e[n[i]]=+r;return e}u.getGraphDiv=M.getGraphDiv,u.isPlotDiv=M.isPlotDiv,u.removeElement=M.removeElement,u.addStyleRule=M.addStyleRule,u.addRelatedStyleRule=M.addRelatedStyleRule,u.deleteRelatedStyleRule=M.deleteRelatedStyleRule,u.getFullTransformMatrix=M.getFullTransformMatrix,u.getElementTransformMatrix=M.getElementTransformMatrix,u.getElementAndAncestors=M.getElementAndAncestors,u.equalDomRects=M.equalDomRects,u.clearResponsive=t(\"./clear_responsive\"),u.preserveDrawingBuffer=t(\"./preserve_drawing_buffer\"),u.makeTraceGroups=t(\"./make_trace_groups\"),u._=t(\"./localize\"),u.notifier=t(\"./notifier\"),u.filterUnique=t(\"./filter_unique\"),u.filterVisible=t(\"./filter_visible\"),u.pushUnique=t(\"./push_unique\"),u.increment=t(\"./increment\"),u.cleanNumber=t(\"./clean_number\"),u.ensureNumber=function(t){return a(t)?(t=Number(t))>s||t<l?c:t:c},u.isIndex=function(t,e){return!(void 0!==e&&t>=e)&&(a(t)&&t>=0&&t%1==0)},u.noop=t(\"./noop\"),u.identity=t(\"./identity\"),u.repeat=function(t,e){for(var r=new Array(e),n=0;n<e;n++)r[n]=t;return r},u.swapAttrs=function(t,e,r,n){r||(r=\"x\"),n||(n=\"y\");for(var i=0;i<e.length;i++){var a=e[i],o=u.nestedProperty(t,a.replace(\"?\",r)),s=u.nestedProperty(t,a.replace(\"?\",n)),l=o.get();o.set(s.get()),s.set(l)}},u.raiseToTop=function(t){t.parentNode.appendChild(t)},u.cancelTransition=function(t){return t.transition().duration(0)},u.constrain=function(t,e,r){return e>r?Math.max(r,Math.min(e,t)):Math.max(e,Math.min(r,t))},u.bBoxIntersect=function(t,e,r){return r=r||0,t.left<=e.right+r&&e.left<=t.right+r&&t.top<=e.bottom+r&&e.top<=t.bottom+r},u.simpleMap=function(t,e,r,n,i){for(var a=t.length,o=new Array(a),s=0;s<a;s++)o[s]=e(t[s],r,n,i);return o},u.randstr=function t(e,r,n,i){if(n||(n=16),void 0===r&&(r=24),r<=0)return\"0\";var a,o,s=Math.log(Math.pow(2,r))/Math.log(n),l=\"\";for(a=2;s===1/0;a*=2)s=Math.log(Math.pow(2,r/a))/Math.log(n)*a;var c=s-Math.floor(s);for(a=0;a<Math.floor(s);a++)l=Math.floor(Math.random()*n).toString(n)+l;c&&(o=Math.pow(n,c),l=Math.floor(Math.random()*o).toString(n)+l);var f=parseInt(l,n);return e&&e[l]||f!==1/0&&f>=Math.pow(2,r)?i>10?(u.warn(\"randstr failed uniqueness\"),l):t(e,r,n,(i||0)+1):l},u.OptionControl=function(t,e){t||(t={}),e||(e=\"opt\");var r={optionList:[],_newoption:function(n){n[e]=t,r[n.name]=n,r.optionList.push(n)}};return r[\"_\"+e]=t,r},u.smooth=function(t,e){if((e=Math.round(e)||0)<2)return t;var r,n,i,a,o=t.length,s=2*o,l=2*e-1,c=new Array(l),u=new Array(o);for(r=0;r<l;r++)c[r]=(1-Math.cos(Math.PI*(r+1)/e))/(2*e);for(r=0;r<o;r++){for(a=0,n=0;n<l;n++)(i=r+n+1-e)<-o?i-=s*Math.round(i/s):i>=s&&(i-=s*Math.floor(i/s)),i<0?i=-1-i:i>=o&&(i=s-1-i),a+=t[i]*c[n];u[r]=a}return u},u.syncOrAsync=function(t,e,r){var n;function i(){return u.syncOrAsync(t,e,r)}for(;t.length;)if((n=(0,t.splice(0,1)[0])(e))&&n.then)return n.then(i).then(void 0,u.promiseError);return r&&r(e)},u.stripTrailingSlash=function(t){return\"/\"===t.substr(-1)?t.substr(0,t.length-1):t},u.noneOrAll=function(t,e,r){if(t){var n,i=!1,a=!0;for(n=0;n<r.length;n++)null!=t[r[n]]?i=!0:a=!1;if(i&&!a)for(n=0;n<r.length;n++)t[r[n]]=e[r[n]]}},u.mergeArray=function(t,e,r,n){var i=\"function\"==typeof n;if(u.isArrayOrTypedArray(t))for(var a=Math.min(t.length,e.length),o=0;o<a;o++){var s=t[o];e[o][r]=i?n(s):s}},u.mergeArrayCastPositive=function(t,e,r){return u.mergeArray(t,e,r,(function(t){var e=+t;return isFinite(e)&&e>0?e:0}))},u.fillArray=function(t,e,r,n){if(n=n||u.identity,u.isArrayOrTypedArray(t))for(var i=0;i<e.length;i++)e[i][r]=n(t[i])},u.castOption=function(t,e,r,n){n=n||u.identity;var i=u.nestedProperty(t,r).get();return u.isArrayOrTypedArray(i)?Array.isArray(e)&&u.isArrayOrTypedArray(i[e[0]])?n(i[e[0]][e[1]]):n(i[e]):i},u.extractOption=function(t,e,r,n){if(r in t)return t[r];var i=u.nestedProperty(e,n).get();return Array.isArray(i)?void 0:i},u.tagSelected=function(t,e,r){var n,i,a=e.selectedpoints,o=e._indexToPoints;o&&(n=A(o));for(var s=0;s<a.length;s++){var l=a[s];if(u.isIndex(l)||u.isArrayOrTypedArray(l)&&u.isIndex(l[0])&&u.isIndex(l[1])){var c=n?n[l]:l,f=r?r[c]:c;void 0!==(i=f)&&i<t.length&&(t[f].selected=1)}}},u.selIndices2selPoints=function(t){var e=t.selectedpoints,r=t._indexToPoints;if(r){for(var n=A(r),i=[],a=0;a<e.length;a++){var o=e[a];if(u.isIndex(o)){var s=n[o];u.isIndex(s)&&i.push(s)}}return i}return e},u.getTargetArray=function(t,e){var r=e.target;if(\"string\"==typeof r&&r){var n=u.nestedProperty(t,r).get();return!!Array.isArray(n)&&n}return!!Array.isArray(r)&&r},u.minExtend=function(t,e){var r={};\"object\"!=typeof e&&(e={});var n,i,a,o=Object.keys(t);for(n=0;n<o.length;n++)a=t[i=o[n]],\"_\"!==i.charAt(0)&&\"function\"!=typeof a&&(\"module\"===i?r[i]=a:Array.isArray(a)?r[i]=\"colorscale\"===i?a.slice():a.slice(0,3):u.isTypedArray(a)?r[i]=a.subarray(0,3):r[i]=a&&\"object\"==typeof a?u.minExtend(t[i],e[i]):a);for(o=Object.keys(e),n=0;n<o.length;n++)\"object\"==typeof(a=e[i=o[n]])&&i in r&&\"object\"==typeof r[i]||(r[i]=a);return r},u.titleCase=function(t){return t.charAt(0).toUpperCase()+t.substr(1)},u.containsAny=function(t,e){for(var r=0;r<e.length;r++)if(-1!==t.indexOf(e[r]))return!0;return!1},u.isIE=function(){return void 0!==window.navigator.msSaveBlob};var S=/Version\\/[\\d\\.]+.*Safari/;u.isSafari=function(){return S.test(window.navigator.userAgent)};var E=/iPad|iPhone|iPod/;u.isIOS=function(){return E.test(window.navigator.userAgent)};var L=/Firefox\\/(\\d+)\\.\\d+/;u.getFirefoxVersion=function(){var t=L.exec(window.navigator.userAgent);if(t&&2===t.length){var e=parseInt(t[1]);if(!isNaN(e))return e}return null},u.isD3Selection=function(t){return t instanceof n.selection},u.ensureSingle=function(t,e,r,n){var i=t.select(e+(r?\".\"+r:\"\"));if(i.size())return i;var a=t.append(e);return r&&a.classed(r,!0),n&&a.call(n),a},u.ensureSingleById=function(t,e,r,n){var i=t.select(e+\"#\"+r);if(i.size())return i;var a=t.append(e).attr(\"id\",r);return n&&a.call(n),a},u.objectFromPath=function(t,e){for(var r,n=t.split(\".\"),i=r={},a=0;a<n.length;a++){var o=n[a],s=null,l=n[a].match(/(.*)\\[([0-9]+)\\]/);l?(o=l[1],s=l[2],r=r[o]=[],a===n.length-1?r[s]=e:r[s]={},r=r[s]):(a===n.length-1?r[o]=e:r[o]={},r=r[o])}return i};var C=/^([^\\[\\.]+)\\.(.+)?/,P=/^([^\\.]+)\\[([0-9]+)\\](\\.)?(.+)?/;u.expandObjectPaths=function(t){var e,r,n,i,a,o,s;if(\"object\"==typeof t&&!Array.isArray(t))for(r in t)t.hasOwnProperty(r)&&((e=r.match(C))?(i=t[r],n=e[1],delete t[r],t[n]=u.extendDeepNoArrays(t[n]||{},u.objectFromPath(r,u.expandObjectPaths(i))[n])):(e=r.match(P))?(i=t[r],n=e[1],a=parseInt(e[2]),delete t[r],t[n]=t[n]||[],\".\"===e[3]?(s=e[4],o=t[n][a]=t[n][a]||{},u.extendDeepNoArrays(o,u.objectFromPath(s,u.expandObjectPaths(i)))):t[n][a]=u.expandObjectPaths(i)):t[r]=u.expandObjectPaths(t[r]));return t},u.numSeparate=function(t,e,r){if(r||(r=!1),\"string\"!=typeof e||0===e.length)throw new Error(\"Separator string required for formatting!\");\"number\"==typeof t&&(t=String(t));var n=/(\\d+)(\\d{3})/,i=e.charAt(0),a=e.charAt(1),o=t.split(\".\"),s=o[0],l=o.length>1?i+o[1]:\"\";if(a&&(o.length>1||s.length>4||r))for(;n.test(s);)s=s.replace(n,\"$1\"+a+\"$2\");return s+l},u.TEMPLATE_STRING_REGEX=/%{([^\\s%{}:]*)([:|\\|][^}]*)?}/g;var I=/^\\w*$/;u.templateString=function(t,e){var r={};return t.replace(u.TEMPLATE_STRING_REGEX,(function(t,n){var i;return I.test(n)?i=e[n]:(r[n]=r[n]||u.nestedProperty(e,n).get,i=r[n]()),u.isValidTextValue(i)?i:\"\"}))};var O={max:10,count:0,name:\"hovertemplate\"};u.hovertemplateString=function(){return R.apply(O,arguments)};var z={max:10,count:0,name:\"texttemplate\"};u.texttemplateString=function(){return R.apply(z,arguments)};var D=/^[:|\\|]/;function R(t,e,r){var a=this,o=arguments;e||(e={});var s={};return t.replace(u.TEMPLATE_STRING_REGEX,(function(t,l,c){var f,h,p,d=\"_xother\"===l||\"_yother\"===l,m=\"_xother_\"===l||\"_yother_\"===l,g=\"xother_\"===l||\"yother_\"===l,v=\"xother\"===l||\"yother\"===l||d||g||m,y=l;if((d||m)&&(y=y.substring(1)),(g||m)&&(y=y.substring(0,y.length-1)),v){if(void 0===(f=e[y]))return\"\"}else for(p=3;p<o.length;p++)if(h=o[p]){if(h.hasOwnProperty(y)){f=h[y];break}if(I.test(y)||(f=u.nestedProperty(h,y).get(),(f=s[y]||u.nestedProperty(h,y).get())&&(s[y]=f)),void 0!==f)break}if(void 0===f&&a)return a.count<a.max&&(u.warn(\"Variable '\"+y+\"' in \"+a.name+\" could not be found!\"),f=t),a.count===a.max&&u.warn(\"Too many \"+a.name+\" warnings - additional warnings will be suppressed\"),a.count++,t;if(c){var x;if(\":\"===c[0]&&(f=(x=r?r.numberFormat:n.format)(c.replace(D,\"\"))(f)),\"|\"===c[0]){x=r?r.timeFormat:i;var b=u.dateTime2ms(f);f=u.formatDate(b,c.replace(D,\"\"),!1,x)}}else{var _=y+\"Label\";e.hasOwnProperty(_)&&(f=e[_])}return v&&(f=\"(\"+f+\")\",(d||m)&&(f=\" \"+f),(g||m)&&(f+=\" \")),f}))}u.subplotSort=function(t,e){for(var r=Math.min(t.length,e.length)+1,n=0,i=0,a=0;a<r;a++){var o=t.charCodeAt(a)||0,s=e.charCodeAt(a)||0,l=o>=48&&o<=57,c=s>=48&&s<=57;if(l&&(n=10*n+o-48),c&&(i=10*i+s-48),!l||!c){if(n!==i)return n-i;if(o!==s)return o-s}}return i-n};var F=2e9;u.seedPseudoRandom=function(){F=2e9},u.pseudoRandom=function(){var t=F;return F=(69069*F+1)%4294967296,Math.abs(F-t)<429496729?u.pseudoRandom():F/4294967296},u.fillText=function(t,e,r){var n=Array.isArray(r)?function(t){r.push(t)}:function(t){r.text=t},i=u.extractOption(t,e,\"htx\",\"hovertext\");if(u.isValidTextValue(i))return n(i);var a=u.extractOption(t,e,\"tx\",\"text\");return u.isValidTextValue(a)?n(a):void 0},u.isValidTextValue=function(t){return t||0===t},u.formatPercent=function(t,e){e=e||0;for(var r=(Math.round(100*t*Math.pow(10,e))*Math.pow(.1,e)).toFixed(e)+\"%\",n=0;n<e;n++)-1!==r.indexOf(\".\")&&(r=(r=r.replace(\"0%\",\"%\")).replace(\".%\",\"%\"));return r},u.isHidden=function(t){var e=window.getComputedStyle(t).display;return!e||\"none\"===e},u.strTranslate=function(t,e){return t||e?\"translate(\"+t+\",\"+e+\")\":\"\"},u.strRotate=function(t){return t?\"rotate(\"+t+\")\":\"\"},u.strScale=function(t){return 1!==t?\"scale(\"+t+\")\":\"\"},u.getTextTransform=function(t){var e=t.noCenter,r=t.textX,n=t.textY,i=t.targetX,a=t.targetY,o=t.anchorX||0,s=t.anchorY||0,l=t.rotate,c=t.scale;return c?c>1&&(c=1):c=0,u.strTranslate(i-c*(r+o),a-c*(n+s))+u.strScale(c)+(l?\"rotate(\"+l+(e?\"\":\" \"+r+\" \"+n)+\")\":\"\")},u.ensureUniformFontSize=function(t,e){var r=u.extendFlat({},e);return r.size=Math.max(e.size,t._fullLayout.uniformtext.minsize||0),r},u.join2=function(t,e,r){var n=t.length;return n>1?t.slice(0,-1).join(e)+r+t[n-1]:t.join(e)},u.bigFont=function(t){return Math.round(1.2*t)};var B=u.getFirefoxVersion(),N=null!==B&&B<86;u.getPositionFromD3Event=function(){return N?[n.event.layerX,n.event.layerY]:[n.event.offsetX,n.event.offsetY]}},{\"../constants/numerical\":775,\"./anchor_utils\":779,\"./angles\":780,\"./array\":781,\"./clean_number\":782,\"./clear_responsive\":784,\"./coerce\":785,\"./dates\":786,\"./dom\":787,\"./extend\":789,\"./filter_unique\":790,\"./filter_visible\":791,\"./geometry2d\":794,\"./identity\":797,\"./increment\":798,\"./is_plain_object\":800,\"./keyed_container\":801,\"./localize\":802,\"./loggers\":803,\"./make_trace_groups\":804,\"./matrix\":805,\"./mod\":806,\"./nested_property\":807,\"./noop\":808,\"./notifier\":809,\"./preserve_drawing_buffer\":813,\"./push_unique\":814,\"./regex\":816,\"./relative_attr\":817,\"./relink_private\":818,\"./search\":819,\"./stats\":822,\"./throttle\":825,\"./to_log_range\":826,\"@plotly/d3\":58,\"d3-time-format\":172,\"fast-isnumeric\":245}],800:[function(t,e,r){\"use strict\";e.exports=function(t){return window&&window.process&&window.process.versions?\"[object Object]\"===Object.prototype.toString.call(t):\"[object Object]\"===Object.prototype.toString.call(t)&&Object.getPrototypeOf(t).hasOwnProperty(\"hasOwnProperty\")}},{}],801:[function(t,e,r){\"use strict\";var n=t(\"./nested_property\"),i=/^\\w*$/;e.exports=function(t,e,r,a){var o,s,l;r=r||\"name\",a=a||\"value\";var c={};e&&e.length?(l=n(t,e),s=l.get()):s=t,e=e||\"\";var u={};if(s)for(o=0;o<s.length;o++)u[s[o][r]]=o;var f=i.test(a),h={set:function(t,e){var i=null===e?4:0;if(!s){if(!l||4===i)return;s=[],l.set(s)}var o=u[t];if(void 0===o){if(4===i)return;i|=3,o=s.length,u[t]=o}else e!==(f?s[o][a]:n(s[o],a).get())&&(i|=2);var p=s[o]=s[o]||{};return p[r]=t,f?p[a]=e:n(p,a).set(e),null!==e&&(i&=-5),c[o]=c[o]|i,h},get:function(t){if(s){var e=u[t];return void 0===e?void 0:f?s[e][a]:n(s[e],a).get()}},rename:function(t,e){var n=u[t];return void 0===n||(c[n]=1|c[n],u[e]=n,delete u[t],s[n][r]=e),h},remove:function(t){var e=u[t];if(void 0===e)return h;var i=s[e];if(Object.keys(i).length>2)return c[e]=2|c[e],h.set(t,null);if(f){for(o=e;o<s.length;o++)c[o]=3|c[o];for(o=e;o<s.length;o++)u[s[o][r]]--;s.splice(e,1),delete u[t]}else n(i,a).set(null),c[e]=6|c[e];return h},constructUpdate:function(){for(var t,i,o={},l=Object.keys(c),u=0;u<l.length;u++)i=l[u],t=e+\"[\"+i+\"]\",s[i]?(1&c[i]&&(o[t+\".\"+r]=s[i][r]),2&c[i]&&(o[t+\".\"+a]=f?4&c[i]?null:s[i][a]:4&c[i]?null:n(s[i],a).get())):o[t]=null;return o}};return h}},{\"./nested_property\":807}],802:[function(t,e,r){\"use strict\";var n=t(\"../registry\");e.exports=function(t,e){for(var r=t._context.locale,i=0;i<2;i++){for(var a=t._context.locales,o=0;o<2;o++){var s=(a[r]||{}).dictionary;if(s){var l=s[e];if(l)return l}a=n.localeRegistry}var c=r.split(\"-\")[0];if(c===r)break;r=c}return e}},{\"../registry\":927}],803:[function(t,e,r){\"use strict\";var n=t(\"../plot_api/plot_config\").dfltConfig,i=t(\"./notifier\"),a=e.exports={};a.log=function(){var t;if(n.logging>1){var e=[\"LOG:\"];for(t=0;t<arguments.length;t++)e.push(arguments[t]);console.trace.apply(console,e)}if(n.notifyOnLogging>1){var r=[];for(t=0;t<arguments.length;t++)r.push(arguments[t]);i(r.join(\"<br>\"),\"long\")}},a.warn=function(){var t;if(n.logging>0){var e=[\"WARN:\"];for(t=0;t<arguments.length;t++)e.push(arguments[t]);console.trace.apply(console,e)}if(n.notifyOnLogging>0){var r=[];for(t=0;t<arguments.length;t++)r.push(arguments[t]);i(r.join(\"<br>\"),\"stick\")}},a.error=function(){var t;if(n.logging>0){var e=[\"ERROR:\"];for(t=0;t<arguments.length;t++)e.push(arguments[t]);console.error.apply(console,e)}if(n.notifyOnLogging>0){var r=[];for(t=0;t<arguments.length;t++)r.push(arguments[t]);i(r.join(\"<br>\"),\"stick\")}}},{\"../plot_api/plot_config\":836,\"./notifier\":809}],804:[function(t,e,r){\"use strict\";var n=t(\"@plotly/d3\");e.exports=function(t,e,r){var i=t.selectAll(\"g.\"+r.replace(/\\s/g,\".\")).data(e,(function(t){return t[0].trace.uid}));i.exit().remove(),i.enter().append(\"g\").attr(\"class\",r),i.order();var a=t.classed(\"rangeplot\")?\"nodeRangePlot3\":\"node3\";return i.each((function(t){t[0][a]=n.select(this)})),i}},{\"@plotly/d3\":58}],805:[function(t,e,r){\"use strict\";var n=t(\"gl-mat4\");r.init2dArray=function(t,e){for(var r=new Array(t),n=0;n<t;n++)r[n]=new Array(e);return r},r.transposeRagged=function(t){var e,r,n=0,i=t.length;for(e=0;e<i;e++)n=Math.max(n,t[e].length);var a=new Array(n);for(e=0;e<n;e++)for(a[e]=new Array(i),r=0;r<i;r++)a[e][r]=t[r][e];return a},r.dot=function(t,e){if(!t.length||!e.length||t.length!==e.length)return null;var n,i,a=t.length;if(t[0].length)for(n=new Array(a),i=0;i<a;i++)n[i]=r.dot(t[i],e);else if(e[0].length){var o=r.transposeRagged(e);for(n=new Array(o.length),i=0;i<o.length;i++)n[i]=r.dot(t,o[i])}else for(n=0,i=0;i<a;i++)n+=t[i]*e[i];return n},r.translationMatrix=function(t,e){return[[1,0,t],[0,1,e],[0,0,1]]},r.rotationMatrix=function(t){var e=t*Math.PI/180;return[[Math.cos(e),-Math.sin(e),0],[Math.sin(e),Math.cos(e),0],[0,0,1]]},r.rotationXYMatrix=function(t,e,n){return r.dot(r.dot(r.translationMatrix(e,n),r.rotationMatrix(t)),r.translationMatrix(-e,-n))},r.apply3DTransform=function(t){return function(){var e=arguments,n=1===arguments.length?e[0]:[e[0],e[1],e[2]||0];return r.dot(t,[n[0],n[1],n[2],1]).slice(0,3)}},r.apply2DTransform=function(t){return function(){var e=arguments;3===e.length&&(e=e[0]);var n=1===arguments.length?e[0]:[e[0],e[1]];return r.dot(t,[n[0],n[1],1]).slice(0,2)}},r.apply2DTransform2=function(t){var e=r.apply2DTransform(t);return function(t){return e(t.slice(0,2)).concat(e(t.slice(2,4)))}},r.convertCssMatrix=function(t){if(t){var e=t.length;if(16===e)return t;if(6===e)return[t[0],t[1],0,0,t[2],t[3],0,0,0,0,1,0,t[4],t[5],0,1]}return[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1]},r.inverseTransformMatrix=function(t){var e=[];return n.invert(e,t),[[e[0],e[1],e[2],e[3]],[e[4],e[5],e[6],e[7]],[e[8],e[9],e[10],e[11]],[e[12],e[13],e[14],e[15]]]}},{\"gl-mat4\":294}],806:[function(t,e,r){\"use strict\";e.exports={mod:function(t,e){var r=t%e;return r<0?r+e:r},modHalf:function(t,e){return Math.abs(t)>e/2?t-Math.round(t/e)*e:t}}},{}],807:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"./array\").isArrayOrTypedArray;function a(t,e){return function(){var r,n,o,s,l,c=t;for(s=0;s<e.length-1;s++){if(-1===(r=e[s])){for(n=!0,o=[],l=0;l<c.length;l++)o[l]=a(c[l],e.slice(s+1))(),o[l]!==o[0]&&(n=!1);return n?o[0]:o}if(\"number\"==typeof r&&!i(c))return;if(\"object\"!=typeof(c=c[r])||null===c)return}if(\"object\"==typeof c&&null!==c&&null!==(o=c[e[s]]))return o}}e.exports=function(t,e){if(n(e))e=String(e);else if(\"string\"!=typeof e||\"[-1]\"===e.substr(e.length-4))throw\"bad property string\";for(var r,i,o,s=0,c=e.split(\".\");s<c.length;){if(r=String(c[s]).match(/^([^\\[\\]]*)((\\[\\-?[0-9]*\\])+)$/)){if(r[1])c[s]=r[1];else{if(0!==s)throw\"bad property string\";c.splice(0,1)}for(i=r[2].substr(1,r[2].length-2).split(\"][\"),o=0;o<i.length;o++)s++,c.splice(s,0,Number(i[o]))}s++}return\"object\"!=typeof t?function(t,e,r){return{set:function(){throw\"bad container\"},get:function(){},astr:e,parts:r,obj:t}}(t,e,c):{set:l(t,c,e),get:a(t,c),astr:e,parts:c,obj:t}};var o=/(^|\\.)args\\[/;function s(t,e){return void 0===t||null===t&&!e.match(o)}function l(t,e,r){return function(n){var a,o,l=t,h=\"\",p=[[t,h]],d=s(n,r);for(o=0;o<e.length-1;o++){if(\"number\"==typeof(a=e[o])&&!i(l))throw\"array index but container is not an array\";if(-1===a){if(d=!u(l,e.slice(o+1),n,r))break;return}if(!f(l,a,e[o+1],d))break;if(\"object\"!=typeof(l=l[a])||null===l)throw\"container is not an object\";h=c(h,a),p.push([l,h])}if(d){if(o===e.length-1&&(delete l[e[o]],Array.isArray(l)&&+e[o]==l.length-1))for(;l.length&&void 0===l[l.length-1];)l.pop()}else l[e[o]]=n}}function c(t,e){var r=e;return n(e)?r=\"[\"+e+\"]\":t&&(r=\".\"+e),t+r}function u(t,e,r,n){var a,o=i(r),c=!0,u=r,h=n.replace(\"-1\",0),p=!o&&s(r,h),d=e[0];for(a=0;a<t.length;a++)h=n.replace(\"-1\",a),o&&(p=s(u=r[a%r.length],h)),p&&(c=!1),f(t,a,d,p)&&l(t[a],e,n.replace(\"-1\",a))(u);return c}function f(t,e,r,n){if(void 0===t[e]){if(n)return!1;t[e]=\"number\"==typeof r?[]:{}}return!0}},{\"./array\":781,\"fast-isnumeric\":245}],808:[function(t,e,r){\"use strict\";e.exports=function(){}},{}],809:[function(t,e,r){\"use strict\";var n=t(\"@plotly/d3\"),i=t(\"fast-isnumeric\"),a=[];e.exports=function(t,e){if(-1===a.indexOf(t)){a.push(t);var r=1e3;i(e)?r=e:\"long\"===e&&(r=3e3);var o=n.select(\"body\").selectAll(\".plotly-notifier\").data([0]);o.enter().append(\"div\").classed(\"plotly-notifier\",!0),o.selectAll(\".notifier-note\").data(a).enter().append(\"div\").classed(\"notifier-note\",!0).style(\"opacity\",0).each((function(t){var i=n.select(this);i.append(\"button\").classed(\"notifier-close\",!0).html(\"&times;\").on(\"click\",(function(){i.transition().call(s)}));for(var a=i.append(\"p\"),o=t.split(/<br\\s*\\/?>/g),l=0;l<o.length;l++)l&&a.append(\"br\"),a.append(\"span\").text(o[l]);\"stick\"===e?i.transition().duration(350).style(\"opacity\",1):i.transition().duration(700).style(\"opacity\",1).transition().delay(r).call(s)}))}function s(t){t.duration(700).style(\"opacity\",0).each(\"end\",(function(t){var e=a.indexOf(t);-1!==e&&a.splice(e,1),n.select(this).remove()}))}}},{\"@plotly/d3\":58,\"fast-isnumeric\":245}],810:[function(t,e,r){\"use strict\";var n=t(\"./setcursor\"),i=\"data-savedcursor\";e.exports=function(t,e){var r=t.attr(i);if(e){if(!r){for(var a=(t.attr(\"class\")||\"\").split(\" \"),o=0;o<a.length;o++){var s=a[o];0===s.indexOf(\"cursor-\")&&t.attr(i,s.substr(7)).classed(s,!1)}t.attr(i)||t.attr(i,\"!!\")}n(t,e)}else r&&(t.attr(i,null),\"!!\"===r?n(t):n(t,r))}},{\"./setcursor\":820}],811:[function(t,e,r){\"use strict\";var n=t(\"./matrix\").dot,i=t(\"../constants/numerical\").BADNUM,a=e.exports={};a.tester=function(t){var e,r=t.slice(),n=r[0][0],a=n,o=r[0][1],s=o;for(r.push(r[0]),e=1;e<r.length;e++)n=Math.min(n,r[e][0]),a=Math.max(a,r[e][0]),o=Math.min(o,r[e][1]),s=Math.max(s,r[e][1]);var l,c=!1;5===r.length&&(r[0][0]===r[1][0]?r[2][0]===r[3][0]&&r[0][1]===r[3][1]&&r[1][1]===r[2][1]&&(c=!0,l=function(t){return t[0]===r[0][0]}):r[0][1]===r[1][1]&&r[2][1]===r[3][1]&&r[0][0]===r[3][0]&&r[1][0]===r[2][0]&&(c=!0,l=function(t){return t[1]===r[0][1]}));var u=!0,f=r[0];for(e=1;e<r.length;e++)if(f[0]!==r[e][0]||f[1]!==r[e][1]){u=!1;break}return{xmin:n,xmax:a,ymin:o,ymax:s,pts:r,contains:c?function(t,e){var r=t[0],c=t[1];return!(r===i||r<n||r>a||c===i||c<o||c>s)&&(!e||!l(t))}:function(t,e){var l=t[0],c=t[1];if(l===i||l<n||l>a||c===i||c<o||c>s)return!1;var u,f,h,p,d,m=r.length,g=r[0][0],v=r[0][1],y=0;for(u=1;u<m;u++)if(f=g,h=v,g=r[u][0],v=r[u][1],!(l<(p=Math.min(f,g))||l>Math.max(f,g)||c>Math.max(h,v)))if(c<Math.min(h,v))l!==p&&y++;else{if(c===(d=g===f?c:h+(l-f)*(v-h)/(g-f)))return 1!==u||!e;c<=d&&l!==p&&y++}return y%2==1},isRect:c,degenerate:u}},a.isSegmentBent=function(t,e,r,i){var a,o,s,l=t[e],c=[t[r][0]-l[0],t[r][1]-l[1]],u=n(c,c),f=Math.sqrt(u),h=[-c[1]/f,c[0]/f];for(a=e+1;a<r;a++)if(o=[t[a][0]-l[0],t[a][1]-l[1]],(s=n(o,c))<0||s>u||Math.abs(n(o,h))>i)return!0;return!1},a.filter=function(t,e){var r=[t[0]],n=0,i=0;function o(o){t.push(o);var s=r.length,l=n;r.splice(i+1);for(var c=l+1;c<t.length;c++)(c===t.length-1||a.isSegmentBent(t,l,c+1,e))&&(r.push(t[c]),r.length<s-2&&(n=c,i=r.length-1),l=c)}t.length>1&&o(t.pop());return{addPt:o,raw:t,filtered:r}}},{\"../constants/numerical\":775,\"./matrix\":805}],812:[function(t,e,r){(function(r){(function(){\"use strict\";var n=t(\"./show_no_webgl_msg\"),i=t(\"regl\");e.exports=function(t,e){var a=t._fullLayout,o=!0;return a._glcanvas.each((function(n){if(!n.regl&&(!n.pick||a._has(\"parcoords\"))){try{n.regl=i({canvas:this,attributes:{antialias:!n.pick,preserveDrawingBuffer:!0},pixelRatio:t._context.plotGlPixelRatio||r.devicePixelRatio,extensions:e||[]})}catch(t){o=!1}n.regl||(o=!1),o&&this.addEventListener(\"webglcontextlost\",(function(e){t&&t.emit&&t.emit(\"plotly_webglcontextlost\",{event:e,layer:n.key})}),!1)}})),o||n({container:a._glcontainer.node()}),o}}).call(this)}).call(this,\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{\"./show_no_webgl_msg\":821,regl:536}],813:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"is-mobile\");e.exports=function(t){var e;if(\"string\"!=typeof(e=t&&t.hasOwnProperty(\"userAgent\")?t.userAgent:function(){var t;\"undefined\"!=typeof navigator&&(t=navigator.userAgent);t&&t.headers&&\"string\"==typeof t.headers[\"user-agent\"]&&(t=t.headers[\"user-agent\"]);return t}()))return!0;var r=i({ua:{headers:{\"user-agent\":e}},tablet:!0,featureDetect:!1});if(!r)for(var a=e.split(\" \"),o=1;o<a.length;o++){if(-1!==a[o].indexOf(\"Safari\"))for(var s=o-1;s>-1;s--){var l=a[s];if(\"Version/\"===l.substr(0,8)){var c=l.substr(8).split(\".\")[0];if(n(c)&&(c=+c),c>=13)return!0}}}return r}},{\"fast-isnumeric\":245,\"is-mobile\":451}],814:[function(t,e,r){\"use strict\";e.exports=function(t,e){if(e instanceof RegExp){for(var r=e.toString(),n=0;n<t.length;n++)if(t[n]instanceof RegExp&&t[n].toString()===r)return t;t.push(e)}else!e&&0!==e||-1!==t.indexOf(e)||t.push(e);return t}},{}],815:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"../plot_api/plot_config\").dfltConfig;var a={add:function(t,e,r,n,a){var o,s;t.undoQueue=t.undoQueue||{index:0,queue:[],sequence:!1},s=t.undoQueue.index,t.autoplay?t.undoQueue.inSequence||(t.autoplay=!1):(!t.undoQueue.sequence||t.undoQueue.beginSequence?(o={undo:{calls:[],args:[]},redo:{calls:[],args:[]}},t.undoQueue.queue.splice(s,t.undoQueue.queue.length-s,o),t.undoQueue.index+=1):o=t.undoQueue.queue[s-1],t.undoQueue.beginSequence=!1,o&&(o.undo.calls.unshift(e),o.undo.args.unshift(r),o.redo.calls.push(n),o.redo.args.push(a)),t.undoQueue.queue.length>i.queueLength&&(t.undoQueue.queue.shift(),t.undoQueue.index--))},startSequence:function(t){t.undoQueue=t.undoQueue||{index:0,queue:[],sequence:!1},t.undoQueue.sequence=!0,t.undoQueue.beginSequence=!0},stopSequence:function(t){t.undoQueue=t.undoQueue||{index:0,queue:[],sequence:!1},t.undoQueue.sequence=!1,t.undoQueue.beginSequence=!1},undo:function(t){var e,r;if(!(void 0===t.undoQueue||isNaN(t.undoQueue.index)||t.undoQueue.index<=0)){for(t.undoQueue.index--,e=t.undoQueue.queue[t.undoQueue.index],t.undoQueue.inSequence=!0,r=0;r<e.undo.calls.length;r++)a.plotDo(t,e.undo.calls[r],e.undo.args[r]);t.undoQueue.inSequence=!1,t.autoplay=!1}},redo:function(t){var e,r;if(!(void 0===t.undoQueue||isNaN(t.undoQueue.index)||t.undoQueue.index>=t.undoQueue.queue.length)){for(e=t.undoQueue.queue[t.undoQueue.index],t.undoQueue.inSequence=!0,r=0;r<e.redo.calls.length;r++)a.plotDo(t,e.redo.calls[r],e.redo.args[r]);t.undoQueue.inSequence=!1,t.autoplay=!1,t.undoQueue.index++}}};a.plotDo=function(t,e,r){t.autoplay=!0,r=function(t,e){for(var r,i=[],a=0;a<e.length;a++)r=e[a],i[a]=r===t?r:\"object\"==typeof r?Array.isArray(r)?n.extendDeep([],r):n.extendDeepAll({},r):r;return i}(t,r),e.apply(null,r)},e.exports=a},{\"../lib\":799,\"../plot_api/plot_config\":836}],816:[function(t,e,r){\"use strict\";r.counter=function(t,e,r,n){var i=(e||\"\")+(r?\"\":\"$\"),a=!1===n?\"\":\"^\";return\"xy\"===t?new RegExp(a+\"x([2-9]|[1-9][0-9]+)?y([2-9]|[1-9][0-9]+)?\"+i):new RegExp(a+t+\"([2-9]|[1-9][0-9]+)?\"+i)}},{}],817:[function(t,e,r){\"use strict\";var n=/^(.*)(\\.[^\\.\\[\\]]+|\\[\\d\\])$/,i=/^[^\\.\\[\\]]+$/;e.exports=function(t,e){for(;e;){var r=t.match(n);if(r)t=r[1];else{if(!t.match(i))throw new Error(\"bad relativeAttr call:\"+[t,e]);t=\"\"}if(\"^\"!==e.charAt(0))break;e=e.slice(1)}return t&&\"[\"!==e.charAt(0)?t+\".\"+e:t+e}},{}],818:[function(t,e,r){\"use strict\";var n=t(\"./array\").isArrayOrTypedArray,i=t(\"./is_plain_object\");e.exports=function t(e,r){for(var a in r){var o=r[a],s=e[a];if(s!==o)if(\"_\"===a.charAt(0)||\"function\"==typeof o){if(a in e)continue;e[a]=o}else if(n(o)&&n(s)&&i(o[0])){if(\"customdata\"===a||\"ids\"===a)continue;for(var l=Math.min(o.length,s.length),c=0;c<l;c++)s[c]!==o[c]&&i(o[c])&&i(s[c])&&t(s[c],o[c])}else i(o)&&i(s)&&(t(s,o),Object.keys(s).length||delete e[a])}}},{\"./array\":781,\"./is_plain_object\":800}],819:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"./loggers\"),a=t(\"./identity\"),o=t(\"../constants/numerical\").BADNUM;function s(t,e){return t<e}function l(t,e){return t<=e}function c(t,e){return t>e}function u(t,e){return t>=e}r.findBin=function(t,e,r){if(n(e.start))return r?Math.ceil((t-e.start)/e.size-1e-9)-1:Math.floor((t-e.start)/e.size+1e-9);var a,o,f=0,h=e.length,p=0,d=h>1?(e[h-1]-e[0])/(h-1):1;for(o=d>=0?r?s:l:r?u:c,t+=1e-9*d*(r?-1:1)*(d>=0?1:-1);f<h&&p++<100;)o(e[a=Math.floor((f+h)/2)],t)?f=a+1:h=a;return p>90&&i.log(\"Long binary search...\"),f-1},r.sorterAsc=function(t,e){return t-e},r.sorterDes=function(t,e){return e-t},r.distinctVals=function(t){var e,n=t.slice();for(n.sort(r.sorterAsc),e=n.length-1;e>-1&&n[e]===o;e--);for(var i,a=n[e]-n[0]||1,s=a/(e||1)/1e4,l=[],c=0;c<=e;c++){var u=n[c],f=u-i;void 0===i?(l.push(u),i=u):f>s&&(a=Math.min(a,f),l.push(u),i=u)}return{vals:l,minDiff:a}},r.roundUp=function(t,e,r){for(var n,i=0,a=e.length-1,o=0,s=r?0:1,l=r?1:0,c=r?Math.ceil:Math.floor;i<a&&o++<100;)e[n=c((i+a)/2)]<=t?i=n+s:a=n-l;return e[i]},r.sort=function(t,e){for(var r=0,n=0,i=1;i<t.length;i++){var a=e(t[i],t[i-1]);if(a<0?r=1:a>0&&(n=1),r&&n)return t.sort(e)}return n?t:t.reverse()},r.findIndexOfMin=function(t,e){e=e||a;for(var r,n=1/0,i=0;i<t.length;i++){var o=e(t[i]);o<n&&(n=o,r=i)}return r}},{\"../constants/numerical\":775,\"./identity\":797,\"./loggers\":803,\"fast-isnumeric\":245}],820:[function(t,e,r){\"use strict\";e.exports=function(t,e){(t.attr(\"class\")||\"\").split(\" \").forEach((function(e){0===e.indexOf(\"cursor-\")&&t.classed(e,!1)})),e&&t.classed(\"cursor-\"+e,!0)}},{}],821:[function(t,e,r){\"use strict\";var n=t(\"../components/color\"),i=function(){};e.exports=function(t){for(var e in t)\"function\"==typeof t[e]&&(t[e]=i);t.destroy=function(){t.container.parentNode.removeChild(t.container)};var r=document.createElement(\"div\");r.className=\"no-webgl\",r.style.cursor=\"pointer\",r.style.fontSize=\"24px\",r.style.color=n.defaults[0],r.style.position=\"absolute\",r.style.left=r.style.top=\"0px\",r.style.width=r.style.height=\"100%\",r.style[\"background-color\"]=n.lightLine,r.style[\"z-index\"]=30;var a=document.createElement(\"p\");return a.textContent=\"WebGL is not supported by your browser - visit https://get.webgl.org for more info\",a.style.position=\"relative\",a.style.top=\"50%\",a.style.left=\"50%\",a.style.height=\"30%\",a.style.width=\"50%\",a.style.margin=\"-15% 0 0 -25%\",r.appendChild(a),t.container.appendChild(r),t.container.style.background=\"#FFFFFF\",t.container.onclick=function(){window.open(\"https://get.webgl.org\")},!1}},{\"../components/color\":662}],822:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"./array\").isArrayOrTypedArray;r.aggNums=function(t,e,a,o){var s,l;if((!o||o>a.length)&&(o=a.length),n(e)||(e=!1),i(a[0])){for(l=new Array(o),s=0;s<o;s++)l[s]=r.aggNums(t,e,a[s]);a=l}for(s=0;s<o;s++)n(e)?n(a[s])&&(e=t(+e,+a[s])):e=a[s];return e},r.len=function(t){return r.aggNums((function(t){return t+1}),0,t)},r.mean=function(t,e){return e||(e=r.len(t)),r.aggNums((function(t,e){return t+e}),0,t)/e},r.midRange=function(t){if(void 0!==t&&0!==t.length)return(r.aggNums(Math.max,null,t)+r.aggNums(Math.min,null,t))/2},r.variance=function(t,e,i){return e||(e=r.len(t)),n(i)||(i=r.mean(t,e)),r.aggNums((function(t,e){return t+Math.pow(e-i,2)}),0,t)/e},r.stdev=function(t,e,n){return Math.sqrt(r.variance(t,e,n))},r.median=function(t){var e=t.slice().sort();return r.interp(e,.5)},r.interp=function(t,e){if(!n(e))throw\"n should be a finite number\";if((e=e*t.length-.5)<0)return t[0];if(e>t.length-1)return t[t.length-1];var r=e%1;return r*t[Math.ceil(e)]+(1-r)*t[Math.floor(e)]}},{\"./array\":781,\"fast-isnumeric\":245}],823:[function(t,e,r){\"use strict\";var n=t(\"color-normalize\");e.exports=function(t){return t?n(t):[0,0,0,1]}},{\"color-normalize\":131}],824:[function(t,e,r){\"use strict\";var n=t(\"@plotly/d3\"),i=t(\"../lib\"),a=i.strTranslate,o=t(\"../constants/xmlns_namespaces\"),s=t(\"../constants/alignment\").LINE_SPACING;function l(t,e){return t.node().getBoundingClientRect()[e]}var c=/([^$]*)([$]+[^$]*[$]+)([^$]*)/;r.convertToTspans=function(t,e,A){var S=t.text(),L=!t.attr(\"data-notex\")&&\"undefined\"!=typeof MathJax&&S.match(c),C=n.select(t.node().parentNode);if(!C.empty()){var P=t.attr(\"class\")?t.attr(\"class\").split(\" \")[0]:\"text\";return P+=\"-math\",C.selectAll(\"svg.\"+P).remove(),C.selectAll(\"g.\"+P+\"-group\").remove(),t.style(\"display\",null).attr({\"data-unformatted\":S,\"data-math\":\"N\"}),L?(e&&e._promises||[]).push(new Promise((function(e){t.style(\"display\",\"none\");var r=parseInt(t.node().style.fontSize,10),o={fontSize:r};!function(t,e,r){var a,o,s,l;MathJax.Hub.Queue((function(){return o=i.extendDeepAll({},MathJax.Hub.config),s=MathJax.Hub.processSectionDelay,void 0!==MathJax.Hub.processSectionDelay&&(MathJax.Hub.processSectionDelay=0),MathJax.Hub.Config({messageStyle:\"none\",tex2jax:{inlineMath:[[\"$\",\"$\"],[\"\\\\(\",\"\\\\)\"]]},displayAlign:\"left\"})}),(function(){if(\"SVG\"!==(a=MathJax.Hub.config.menuSettings.renderer))return MathJax.Hub.setRenderer(\"SVG\")}),(function(){var r=\"math-output-\"+i.randstr({},64);return l=n.select(\"body\").append(\"div\").attr({id:r}).style({visibility:\"hidden\",position:\"absolute\"}).style({\"font-size\":e.fontSize+\"px\"}).text(t.replace(u,\"\\\\lt \").replace(f,\"\\\\gt \")),MathJax.Hub.Typeset(l.node())}),(function(){var e=n.select(\"body\").select(\"#MathJax_SVG_glyphs\");if(l.select(\".MathJax_SVG\").empty()||!l.select(\"svg\").node())i.log(\"There was an error in the tex syntax.\",t),r();else{var o=l.select(\"svg\").node().getBoundingClientRect();r(l.select(\".MathJax_SVG\"),e,o)}if(l.remove(),\"SVG\"!==a)return MathJax.Hub.setRenderer(a)}),(function(){return void 0!==s&&(MathJax.Hub.processSectionDelay=s),MathJax.Hub.Config(o)}))}(L[2],o,(function(n,i,o){C.selectAll(\"svg.\"+P).remove(),C.selectAll(\"g.\"+P+\"-group\").remove();var s=n&&n.select(\"svg\");if(!s||!s.node())return I(),void e();var c=C.append(\"g\").classed(P+\"-group\",!0).attr({\"pointer-events\":\"none\",\"data-unformatted\":S,\"data-math\":\"Y\"});c.node().appendChild(s.node()),i&&i.node()&&s.node().insertBefore(i.node().cloneNode(!0),s.node().firstChild),s.attr({class:P,height:o.height,preserveAspectRatio:\"xMinYMin meet\"}).style({overflow:\"visible\",\"pointer-events\":\"none\"});var u=t.node().style.fill||\"black\",f=s.select(\"g\");f.attr({fill:u,stroke:u});var h=l(f,\"width\"),p=l(f,\"height\"),d=+t.attr(\"x\")-h*{start:0,middle:.5,end:1}[t.attr(\"text-anchor\")||\"start\"],m=-(r||l(t,\"height\"))/4;\"y\"===P[0]?(c.attr({transform:\"rotate(\"+[-90,+t.attr(\"x\"),+t.attr(\"y\")]+\")\"+a(-h/2,m-p/2)}),s.attr({x:+t.attr(\"x\"),y:+t.attr(\"y\")})):\"l\"===P[0]?s.attr({x:t.attr(\"x\"),y:m-p/2}):\"a\"===P[0]&&0!==P.indexOf(\"atitle\")?s.attr({x:0,y:m}):s.attr({x:d,y:+t.attr(\"y\")+m-p/2}),A&&A.call(t,c),e(c)}))}))):I(),t}function I(){C.empty()||(P=t.attr(\"class\")+\"-math\",C.select(\"svg.\"+P).remove()),t.text(\"\").style(\"white-space\",\"pre\"),function(t,e){e=e.replace(g,\" \");var r,a=!1,l=[],c=-1;function u(){c++;var e=document.createElementNS(o.svg,\"tspan\");n.select(e).attr({class:\"line\",dy:c*s+\"em\"}),t.appendChild(e),r=e;var i=l;if(l=[{node:e}],i.length>1)for(var a=1;a<i.length;a++)f(i[a])}function f(t){var e,i=t.type,a={};if(\"a\"===i){e=\"a\";var s=t.target,c=t.href,u=t.popup;c&&(a={\"xlink:xlink:show\":\"_blank\"===s||\"_\"!==s.charAt(0)?\"new\":\"replace\",target:s,\"xlink:xlink:href\":c},u&&(a.onclick='window.open(this.href.baseVal,this.target.baseVal,\"'+u+'\");return false;'))}else e=\"tspan\";t.style&&(a.style=t.style);var f=document.createElementNS(o.svg,e);if(\"sup\"===i||\"sub\"===i){A(r,\"\\u200b\"),r.appendChild(f);var h=document.createElementNS(o.svg,\"tspan\");A(h,\"\\u200b\"),n.select(h).attr(\"dy\",d[i]),a.dy=p[i],r.appendChild(f),r.appendChild(h)}else r.appendChild(f);n.select(f).attr(a),r=t.node=f,l.push(t)}function A(t,e){t.appendChild(document.createTextNode(e))}function S(t){if(1!==l.length){var n=l.pop();t!==n.type&&i.log(\"Start tag <\"+n.type+\"> doesnt match end tag <\"+t+\">. Pretending it did match.\",e),r=l[l.length-1].node}else i.log(\"Ignoring unexpected end tag </\"+t+\">.\",e)}x.test(e)?u():(r=t,l=[{node:t}]);for(var L=e.split(v),C=0;C<L.length;C++){var P=L[C],I=P.match(y),O=I&&I[2].toLowerCase(),z=h[O];if(\"br\"===O)u();else if(void 0===z)A(r,E(P));else if(I[1])S(O);else{var D=I[4],R={type:O},F=k(D,b);if(F?(F=F.replace(M,\"$1 fill:\"),z&&(F+=\";\"+z)):z&&(F=z),F&&(R.style=F),\"a\"===O){a=!0;var B=k(D,_);if(B){var N=document.createElement(\"a\");N.href=B,-1!==m.indexOf(N.protocol)&&(R.href=encodeURI(decodeURI(B)),R.target=k(D,w)||\"_blank\",R.popup=k(D,T))}}f(R)}}return a}(t.node(),S)&&t.style(\"pointer-events\",\"all\"),r.positionText(t),A&&A.call(t)}};var u=/(<|&lt;|&#60;)/g,f=/(>|&gt;|&#62;)/g;var h={sup:\"font-size:70%\",sub:\"font-size:70%\",b:\"font-weight:bold\",i:\"font-style:italic\",a:\"cursor:pointer\",span:\"\",em:\"font-style:italic;font-weight:bold\"},p={sub:\"0.3em\",sup:\"-0.6em\"},d={sub:\"-0.21em\",sup:\"0.42em\"},m=[\"http:\",\"https:\",\"mailto:\",\"\",void 0,\":\"],g=r.NEWLINES=/(\\r\\n?|\\n)/g,v=/(<[^<>]*>)/,y=/<(\\/?)([^ >]*)(\\s+(.*))?>/i,x=/<br(\\s+.*)?>/i;r.BR_TAG_ALL=/<br(\\s+.*)?>/gi;var b=/(^|[\\s\"'])style\\s*=\\s*(\"([^\"]*);?\"|'([^']*);?')/i,_=/(^|[\\s\"'])href\\s*=\\s*(\"([^\"]*)\"|'([^']*)')/i,w=/(^|[\\s\"'])target\\s*=\\s*(\"([^\"\\s]*)\"|'([^'\\s]*)')/i,T=/(^|[\\s\"'])popup\\s*=\\s*(\"([\\w=,]*)\"|'([\\w=,]*)')/i;function k(t,e){if(!t)return null;var r=t.match(e),n=r&&(r[3]||r[4]);return n&&E(n)}var M=/(^|;)\\s*color:/;r.plainText=function(t,e){for(var r=void 0!==(e=e||{}).len&&-1!==e.len?e.len:1/0,n=void 0!==e.allowedTags?e.allowedTags:[\"br\"],i=\"...\".length,a=t.split(v),o=[],s=\"\",l=0,c=0;c<a.length;c++){var u=a[c],f=u.match(y),h=f&&f[2].toLowerCase();if(h)-1!==n.indexOf(h)&&(o.push(u),s=h);else{var p=u.length;if(l+p<r)o.push(u),l+=p;else if(l<r){var d=r-l;s&&(\"br\"!==s||d<=i||p<=i)&&o.pop(),r>i?o.push(u.substr(0,d-i)+\"...\"):o.push(u.substr(0,d));break}s=\"\"}}return o.join(\"\")};var A={mu:\"\\u03bc\",amp:\"&\",lt:\"<\",gt:\">\",nbsp:\"\\xa0\",times:\"\\xd7\",plusmn:\"\\xb1\",deg:\"\\xb0\"},S=/&(#\\d+|#x[\\da-fA-F]+|[a-z]+);/g;function E(t){return t.replace(S,(function(t,e){return(\"#\"===e.charAt(0)?function(t){if(t>1114111)return;var e=String.fromCodePoint;if(e)return e(t);var r=String.fromCharCode;return t<=65535?r(t):r(55232+(t>>10),t%1024+56320)}(\"x\"===e.charAt(1)?parseInt(e.substr(2),16):parseInt(e.substr(1),10)):A[e])||t}))}function L(t,e,r){var n,a,o,s=r.horizontalAlign,l=r.verticalAlign||\"top\",c=t.node().getBoundingClientRect(),u=e.node().getBoundingClientRect();return a=\"bottom\"===l?function(){return c.bottom-n.height}:\"middle\"===l?function(){return c.top+(c.height-n.height)/2}:function(){return c.top},o=\"right\"===s?function(){return c.right-n.width}:\"center\"===s?function(){return c.left+(c.width-n.width)/2}:function(){return c.left},function(){n=this.node().getBoundingClientRect();var t=o()-u.left,e=a()-u.top,s=r.gd||{};if(r.gd){s._fullLayout._calcInverseTransform(s);var l=i.apply3DTransform(s._fullLayout._invTransform)(t,e);t=l[0],e=l[1]}return this.style({top:e+\"px\",left:t+\"px\",\"z-index\":1e3}),this}}r.convertEntities=E,r.sanitizeHTML=function(t){t=t.replace(g,\" \");for(var e=document.createElement(\"p\"),r=e,i=[],a=t.split(v),o=0;o<a.length;o++){var s=a[o],l=s.match(y),c=l&&l[2].toLowerCase();if(c in h)if(l[1])i.length&&(r=i.pop());else{var u=l[4],f=k(u,b),p=f?{style:f}:{};if(\"a\"===c){var d=k(u,_);if(d){var x=document.createElement(\"a\");if(x.href=d,-1!==m.indexOf(x.protocol)){p.href=encodeURI(decodeURI(d));var T=k(u,w);T&&(p.target=T)}}}var M=document.createElement(c);r.appendChild(M),n.select(M).attr(p),r=M,i.push(M)}else r.appendChild(document.createTextNode(E(s)))}return e.innerHTML},r.lineCount=function(t){return t.selectAll(\"tspan.line\").size()||1},r.positionText=function(t,e,r){return t.each((function(){var t=n.select(this);function i(e,r){return void 0===r?null===(r=t.attr(e))&&(t.attr(e,0),r=0):t.attr(e,r),r}var a=i(\"x\",e),o=i(\"y\",r);\"text\"===this.nodeName&&t.selectAll(\"tspan.line\").attr({x:a,y:o})}))};r.makeTextShadow=function(t){var e=\"1px \",r=\"1px \",n=\"1px \";return e+r+n+t+\", -\"+e+\"-\"+r+n+t+\", \"+e+\"-\"+r+n+t+\", -\"+e+r+n+t},r.makeEditable=function(t,e){var r=e.gd,i=e.delegate,a=n.dispatch(\"edit\",\"input\",\"cancel\"),o=i||t;if(t.style({\"pointer-events\":i?\"none\":\"all\"}),1!==t.size())throw new Error(\"boo\");function s(){!function(){var i=n.select(r).select(\".svg-container\"),o=i.append(\"div\"),s=t.node().style,c=parseFloat(s.fontSize||12),u=e.text;void 0===u&&(u=t.attr(\"data-unformatted\"));o.classed(\"plugin-editable editable\",!0).style({position:\"absolute\",\"font-family\":s.fontFamily||\"Arial\",\"font-size\":c,color:e.fill||s.fill||\"black\",opacity:1,\"background-color\":e.background||\"transparent\",outline:\"#ffffff33 1px solid\",margin:[-c/8+1,0,0,-1].join(\"px \")+\"px\",padding:\"0\",\"box-sizing\":\"border-box\"}).attr({contenteditable:!0}).text(u).call(L(t,i,e)).on(\"blur\",(function(){r._editing=!1,t.text(this.textContent).style({opacity:1});var e,i=n.select(this).attr(\"class\");(e=i?\".\"+i.split(\" \")[0]+\"-math-group\":\"[class*=-math-group]\")&&n.select(t.node().parentNode).select(e).style({opacity:0});var o=this.textContent;n.select(this).transition().duration(0).remove(),n.select(document).on(\"mouseup\",null),a.edit.call(t,o)})).on(\"focus\",(function(){var t=this;r._editing=!0,n.select(document).on(\"mouseup\",(function(){if(n.event.target===t)return!1;document.activeElement===o.node()&&o.node().blur()}))})).on(\"keyup\",(function(){27===n.event.which?(r._editing=!1,t.style({opacity:1}),n.select(this).style({opacity:0}).on(\"blur\",(function(){return!1})).transition().remove(),a.cancel.call(t,this.textContent)):(a.input.call(t,this.textContent),n.select(this).call(L(t,i,e)))})).on(\"keydown\",(function(){13===n.event.which&&this.blur()})).call(l)}(),t.style({opacity:0});var i,s=o.attr(\"class\");(i=s?\".\"+s.split(\" \")[0]+\"-math-group\":\"[class*=-math-group]\")&&n.select(t.node().parentNode).select(i).style({opacity:0})}function l(t){var e=t.node(),r=document.createRange();r.selectNodeContents(e);var n=window.getSelection();n.removeAllRanges(),n.addRange(r),e.focus()}return e.immediate?s():o.on(\"click\",s),n.rebind(t,a,\"on\")}},{\"../constants/alignment\":767,\"../constants/xmlns_namespaces\":776,\"../lib\":799,\"@plotly/d3\":58}],825:[function(t,e,r){\"use strict\";var n={};function i(t){t&&null!==t.timer&&(clearTimeout(t.timer),t.timer=null)}r.throttle=function(t,e,r){var a=n[t],o=Date.now();if(!a){for(var s in n)n[s].ts<o-6e4&&delete n[s];a=n[t]={ts:0,timer:null}}function l(){r(),a.ts=Date.now(),a.onDone&&(a.onDone(),a.onDone=null)}i(a),o>a.ts+e?l():a.timer=setTimeout((function(){l(),a.timer=null}),e)},r.done=function(t){var e=n[t];return e&&e.timer?new Promise((function(t){var r=e.onDone;e.onDone=function(){r&&r(),t(),e.onDone=null}})):Promise.resolve()},r.clear=function(t){if(t)i(n[t]),delete n[t];else for(var e in n)r.clear(e)}},{}],826:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\");e.exports=function(t,e){if(t>0)return Math.log(t)/Math.LN10;var r=Math.log(Math.min(e[0],e[1]))/Math.LN10;return n(r)||(r=Math.log(Math.max(e[0],e[1]))/Math.LN10-6),r}},{\"fast-isnumeric\":245}],827:[function(t,e,r){\"use strict\";var n=e.exports={},i=t(\"../plots/geo/constants\").locationmodeToLayer,a=t(\"topojson-client\").feature;n.getTopojsonName=function(t){return[t.scope.replace(/ /g,\"-\"),\"_\",t.resolution.toString(),\"m\"].join(\"\")},n.getTopojsonPath=function(t,e){return t+e+\".json\"},n.getTopojsonFeatures=function(t,e){var r=i[t.locationmode],n=e.objects[r];return a(e,n).features}},{\"../plots/geo/constants\":880,\"topojson-client\":597}],828:[function(t,e,r){\"use strict\";e.exports={moduleType:\"locale\",name:\"en-US\",dictionary:{\"Click to enter Colorscale title\":\"Click to enter Colorscale title\"},format:{date:\"%m/%d/%Y\"}}},{}],829:[function(t,e,r){\"use strict\";e.exports={moduleType:\"locale\",name:\"en\",dictionary:{\"Click to enter Colorscale title\":\"Click to enter Colourscale title\"},format:{days:[\"Sunday\",\"Monday\",\"Tuesday\",\"Wednesday\",\"Thursday\",\"Friday\",\"Saturday\"],shortDays:[\"Sun\",\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\"],months:[\"January\",\"February\",\"March\",\"April\",\"May\",\"June\",\"July\",\"August\",\"September\",\"October\",\"November\",\"December\"],shortMonths:[\"Jan\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\"Jul\",\"Aug\",\"Sep\",\"Oct\",\"Nov\",\"Dec\"],periods:[\"AM\",\"PM\"],dateTime:\"%a %b %e %X %Y\",date:\"%d/%m/%Y\",time:\"%H:%M:%S\",decimal:\".\",thousands:\",\",grouping:[3],currency:[\"$\",\"\"],year:\"%Y\",month:\"%b %Y\",dayMonth:\"%b %-d\",dayMonthYear:\"%b %-d, %Y\"}}},{}],830:[function(t,e,r){\"use strict\";var n=t(\"../registry\");e.exports=function(t){for(var e,r,i=n.layoutArrayContainers,a=n.layoutArrayRegexes,o=t.split(\"[\")[0],s=0;s<a.length;s++)if((r=t.match(a[s]))&&0===r.index){e=r[0];break}if(e||(e=i[i.indexOf(o)]),!e)return!1;var l=t.substr(e.length);return l?!!(r=l.match(/^\\[(0|[1-9][0-9]*)\\](\\.(.+))?$/))&&{array:e,index:Number(r[1]),property:r[3]||\"\"}:{array:e,index:\"\",property:\"\"}}},{\"../registry\":927}],831:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=n.extendFlat,a=n.isPlainObject,o={valType:\"flaglist\",extras:[\"none\"],flags:[\"calc\",\"clearAxisTypes\",\"plot\",\"style\",\"markerSize\",\"colorbars\"]},s={valType:\"flaglist\",extras:[\"none\"],flags:[\"calc\",\"plot\",\"legend\",\"ticks\",\"axrange\",\"layoutstyle\",\"modebar\",\"camera\",\"arraydraw\",\"colorbars\"]},l=o.flags.slice().concat([\"fullReplot\"]),c=s.flags.slice().concat(\"layoutReplot\");function u(t){for(var e={},r=0;r<t.length;r++)e[t[r]]=!1;return e}function f(t,e,r){var n=i({},t);for(var o in n){var s=n[o];a(s)&&(n[o]=h(s,e,r,o))}return\"from-root\"===r&&(n.editType=e),n}function h(t,e,r,n){if(t.valType){var a=i({},t);if(a.editType=e,Array.isArray(t.items)){a.items=new Array(t.items.length);for(var o=0;o<t.items.length;o++)a.items[o]=h(t.items[o],e,\"from-root\")}return a}return f(t,e,\"_\"===n.charAt(0)?\"nested\":\"from-root\")}e.exports={traces:o,layout:s,traceFlags:function(){return u(l)},layoutFlags:function(){return u(c)},update:function(t,e){var r=e.editType;if(r&&\"none\"!==r)for(var n=r.split(\"+\"),i=0;i<n.length;i++)t[n[i]]=!0},overrideAll:f}},{\"../lib\":799}],832:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"gl-mat4/fromQuat\"),a=t(\"../registry\"),o=t(\"../lib\"),s=t(\"../plots/plots\"),l=t(\"../plots/cartesian/axis_ids\"),c=t(\"../components/color\"),u=l.cleanId,f=l.getFromTrace,h=a.traceIs;function p(t,e){var r=t[e],n=e.charAt(0);r&&\"paper\"!==r&&(t[e]=u(r,n,!0))}function d(t){function e(e,r){var n=t[e],i=t.title&&t.title[r];n&&!i&&(t.title||(t.title={}),t.title[r]=t[e],delete t[e])}t&&(\"string\"!=typeof t.title&&\"number\"!=typeof t.title||(t.title={text:t.title}),e(\"titlefont\",\"font\"),e(\"titleposition\",\"position\"),e(\"titleside\",\"side\"),e(\"titleoffset\",\"offset\"))}function m(t){if(!o.isPlainObject(t))return!1;var e=t.name;return delete t.name,delete t.showlegend,(\"string\"==typeof e||\"number\"==typeof e)&&String(e)}function g(t,e,r,n){if(r&&!n)return t;if(n&&!r)return e;if(!t.trim())return e;if(!e.trim())return t;var i,a=Math.min(t.length,e.length);for(i=0;i<a&&t.charAt(i)===e.charAt(i);i++);return t.substr(0,i).trim()}function v(t){var e=\"middle\",r=\"center\";return\"string\"==typeof t&&(-1!==t.indexOf(\"top\")?e=\"top\":-1!==t.indexOf(\"bottom\")&&(e=\"bottom\"),-1!==t.indexOf(\"left\")?r=\"left\":-1!==t.indexOf(\"right\")&&(r=\"right\")),e+\" \"+r}function y(t,e){return e in t&&\"object\"==typeof t[e]&&0===Object.keys(t[e]).length}r.clearPromiseQueue=function(t){Array.isArray(t._promises)&&t._promises.length>0&&o.log(\"Clearing previous rejected promises from queue.\"),t._promises=[]},r.cleanLayout=function(t){var e,n;t||(t={}),t.xaxis1&&(t.xaxis||(t.xaxis=t.xaxis1),delete t.xaxis1),t.yaxis1&&(t.yaxis||(t.yaxis=t.yaxis1),delete t.yaxis1),t.scene1&&(t.scene||(t.scene=t.scene1),delete t.scene1);var a=(s.subplotsRegistry.cartesian||{}).attrRegex,l=(s.subplotsRegistry.polar||{}).attrRegex,f=(s.subplotsRegistry.ternary||{}).attrRegex,h=(s.subplotsRegistry.gl3d||{}).attrRegex,m=Object.keys(t);for(e=0;e<m.length;e++){var g=m[e];if(a&&a.test(g)){var v=t[g];v.anchor&&\"free\"!==v.anchor&&(v.anchor=u(v.anchor)),v.overlaying&&(v.overlaying=u(v.overlaying)),v.type||(v.isdate?v.type=\"date\":v.islog?v.type=\"log\":!1===v.isdate&&!1===v.islog&&(v.type=\"linear\")),\"withzero\"!==v.autorange&&\"tozero\"!==v.autorange||(v.autorange=!0,v.rangemode=\"tozero\"),delete v.islog,delete v.isdate,delete v.categories,y(v,\"domain\")&&delete v.domain,void 0!==v.autotick&&(void 0===v.tickmode&&(v.tickmode=v.autotick?\"auto\":\"linear\"),delete v.autotick),d(v)}else if(l&&l.test(g)){d(t[g].radialaxis)}else if(f&&f.test(g)){var x=t[g];d(x.aaxis),d(x.baxis),d(x.caxis)}else if(h&&h.test(g)){var b=t[g],_=b.cameraposition;if(Array.isArray(_)&&4===_[0].length){var w=_[0],T=_[1],k=_[2],M=i([],w),A=[];for(n=0;n<3;++n)A[n]=T[n]+k*M[2+4*n];b.camera={eye:{x:A[0],y:A[1],z:A[2]},center:{x:T[0],y:T[1],z:T[2]},up:{x:0,y:0,z:1}},delete b.cameraposition}d(b.xaxis),d(b.yaxis),d(b.zaxis)}}var S=Array.isArray(t.annotations)?t.annotations.length:0;for(e=0;e<S;e++){var E=t.annotations[e];o.isPlainObject(E)&&(E.ref&&(\"paper\"===E.ref?(E.xref=\"paper\",E.yref=\"paper\"):\"data\"===E.ref&&(E.xref=\"x\",E.yref=\"y\"),delete E.ref),p(E,\"xref\"),p(E,\"yref\"))}var L=Array.isArray(t.shapes)?t.shapes.length:0;for(e=0;e<L;e++){var C=t.shapes[e];o.isPlainObject(C)&&(p(C,\"xref\"),p(C,\"yref\"))}var P=Array.isArray(t.images)?t.images.length:0;for(e=0;e<P;e++){var I=t.images[e];o.isPlainObject(I)&&(p(I,\"xref\"),p(I,\"yref\"))}var O=t.legend;return O&&(O.x>3?(O.x=1.02,O.xanchor=\"left\"):O.x<-2&&(O.x=-.02,O.xanchor=\"right\"),O.y>3?(O.y=1.02,O.yanchor=\"bottom\"):O.y<-2&&(O.y=-.02,O.yanchor=\"top\")),d(t),\"rotate\"===t.dragmode&&(t.dragmode=\"orbit\"),c.clean(t),t.template&&t.template.layout&&r.cleanLayout(t.template.layout),t},r.cleanData=function(t){for(var e=0;e<t.length;e++){var n,i=t[e];if(\"histogramy\"===i.type&&\"xbins\"in i&&!(\"ybins\"in i)&&(i.ybins=i.xbins,delete i.xbins),i.error_y&&\"opacity\"in i.error_y){var l=c.defaults,f=i.error_y.color||(h(i,\"bar\")?c.defaultLine:l[e%l.length]);i.error_y.color=c.addOpacity(c.rgb(f),c.opacity(f)*i.error_y.opacity),delete i.error_y.opacity}if(\"bardir\"in i&&(\"h\"!==i.bardir||!h(i,\"bar\")&&\"histogram\"!==i.type.substr(0,9)||(i.orientation=\"h\",r.swapXYData(i)),delete i.bardir),\"histogramy\"===i.type&&r.swapXYData(i),\"histogramx\"!==i.type&&\"histogramy\"!==i.type||(i.type=\"histogram\"),\"scl\"in i&&!(\"colorscale\"in i)&&(i.colorscale=i.scl,delete i.scl),\"reversescl\"in i&&!(\"reversescale\"in i)&&(i.reversescale=i.reversescl,delete i.reversescl),i.xaxis&&(i.xaxis=u(i.xaxis,\"x\")),i.yaxis&&(i.yaxis=u(i.yaxis,\"y\")),h(i,\"gl3d\")&&i.scene&&(i.scene=s.subplotsRegistry.gl3d.cleanId(i.scene)),!h(i,\"pie-like\")&&!h(i,\"bar-like\"))if(Array.isArray(i.textposition))for(n=0;n<i.textposition.length;n++)i.textposition[n]=v(i.textposition[n]);else i.textposition&&(i.textposition=v(i.textposition));var p=a.getModule(i);if(p&&p.colorbar){var x=p.colorbar.container,b=x?i[x]:i;b&&b.colorscale&&(\"YIGnBu\"===b.colorscale&&(b.colorscale=\"YlGnBu\"),\"YIOrRd\"===b.colorscale&&(b.colorscale=\"YlOrRd\"))}if(\"surface\"===i.type&&o.isPlainObject(i.contours)){var _=[\"x\",\"y\",\"z\"];for(n=0;n<_.length;n++){var w=i.contours[_[n]];o.isPlainObject(w)&&(w.highlightColor&&(w.highlightcolor=w.highlightColor,delete w.highlightColor),w.highlightWidth&&(w.highlightwidth=w.highlightWidth,delete w.highlightWidth))}}if(\"candlestick\"===i.type||\"ohlc\"===i.type){var T=!1!==(i.increasing||{}).showlegend,k=!1!==(i.decreasing||{}).showlegend,M=m(i.increasing),A=m(i.decreasing);if(!1!==M&&!1!==A){var S=g(M,A,T,k);S&&(i.name=S)}else!M&&!A||i.name||(i.name=M||A)}if(Array.isArray(i.transforms)){var E=i.transforms;for(n=0;n<E.length;n++){var L=E[n];if(o.isPlainObject(L))switch(L.type){case\"filter\":L.filtersrc&&(L.target=L.filtersrc,delete L.filtersrc),L.calendar&&(L.valuecalendar||(L.valuecalendar=L.calendar),delete L.calendar);break;case\"groupby\":if(L.styles=L.styles||L.style,L.styles&&!Array.isArray(L.styles)){var C=L.styles,P=Object.keys(C);L.styles=[];for(var I=0;I<P.length;I++)L.styles.push({target:P[I],value:C[P[I]]})}}}}y(i,\"line\")&&delete i.line,\"marker\"in i&&(y(i.marker,\"line\")&&delete i.marker.line,y(i,\"marker\")&&delete i.marker),c.clean(i),i.autobinx&&(delete i.autobinx,delete i.xbins),i.autobiny&&(delete i.autobiny,delete i.ybins),d(i),i.colorbar&&d(i.colorbar),i.marker&&i.marker.colorbar&&d(i.marker.colorbar),i.line&&i.line.colorbar&&d(i.line.colorbar),i.aaxis&&d(i.aaxis),i.baxis&&d(i.baxis)}},r.swapXYData=function(t){var e;if(o.swapAttrs(t,[\"?\",\"?0\",\"d?\",\"?bins\",\"nbins?\",\"autobin?\",\"?src\",\"error_?\"]),Array.isArray(t.z)&&Array.isArray(t.z[0])&&(t.transpose?delete t.transpose:t.transpose=!0),t.error_x&&t.error_y){var r=t.error_y,n=\"copy_ystyle\"in r?r.copy_ystyle:!(r.color||r.thickness||r.width);o.swapAttrs(t,[\"error_?.copy_ystyle\"]),n&&o.swapAttrs(t,[\"error_?.color\",\"error_?.thickness\",\"error_?.width\"])}if(\"string\"==typeof t.hoverinfo){var i=t.hoverinfo.split(\"+\");for(e=0;e<i.length;e++)\"x\"===i[e]?i[e]=\"y\":\"y\"===i[e]&&(i[e]=\"x\");t.hoverinfo=i.join(\"+\")}},r.coerceTraceIndices=function(t,e){if(n(e))return[e];if(!Array.isArray(e)||!e.length)return t.data.map((function(t,e){return e}));if(Array.isArray(e)){for(var r=[],i=0;i<e.length;i++)o.isIndex(e[i],t.data.length)?r.push(e[i]):o.warn(\"trace index (\",e[i],\") is not a number or is out of bounds\");return r}return e},r.manageArrayContainers=function(t,e,r){var i=t.obj,a=t.parts,s=a.length,l=a[s-1],c=n(l);if(c&&null===e){var u=a.slice(0,s-1).join(\".\");o.nestedProperty(i,u).get().splice(l,1)}else c&&void 0===t.get()?(void 0===t.get()&&(r[t.astr]=null),t.set(e)):t.set(e)};var x=/(\\.[^\\[\\]\\.]+|\\[[^\\[\\]\\.]+\\])$/;function b(t){var e=t.search(x);if(e>0)return t.substr(0,e)}r.hasParent=function(t,e){for(var r=b(e);r;){if(r in t)return!0;r=b(r)}return!1};var _=[\"x\",\"y\",\"z\"];r.clearAxisTypes=function(t,e,r){for(var n=0;n<e.length;n++)for(var i=t._fullData[n],a=0;a<3;a++){var s=f(t,i,_[a]);if(s&&\"log\"!==s.type){var l=s._name,c=s._id.substr(1);if(\"scene\"===c.substr(0,5)){if(void 0!==r[c])continue;l=c+\".\"+l}var u=l+\".type\";void 0===r[l]&&void 0===r[u]&&o.nestedProperty(t.layout,u).set(null)}}}},{\"../components/color\":662,\"../lib\":799,\"../plots/cartesian/axis_ids\":853,\"../plots/plots\":913,\"../registry\":927,\"fast-isnumeric\":245,\"gl-mat4/fromQuat\":284}],833:[function(t,e,r){\"use strict\";var n=t(\"./plot_api\");r._doPlot=n._doPlot,r.newPlot=n.newPlot,r.restyle=n.restyle,r.relayout=n.relayout,r.redraw=n.redraw,r.update=n.update,r._guiRestyle=n._guiRestyle,r._guiRelayout=n._guiRelayout,r._guiUpdate=n._guiUpdate,r._storeDirectGUIEdit=n._storeDirectGUIEdit,r.react=n.react,r.extendTraces=n.extendTraces,r.prependTraces=n.prependTraces,r.addTraces=n.addTraces,r.deleteTraces=n.deleteTraces,r.moveTraces=n.moveTraces,r.purge=n.purge,r.addFrames=n.addFrames,r.deleteFrames=n.deleteFrames,r.animate=n.animate,r.setPlotConfig=n.setPlotConfig,r.toImage=t(\"./to_image\"),r.validate=t(\"./validate\"),r.downloadImage=t(\"../snapshot/download\");var i=t(\"./template_api\");r.makeTemplate=i.makeTemplate,r.validateTemplate=i.validateTemplate},{\"../snapshot/download\":929,\"./plot_api\":835,\"./template_api\":840,\"./to_image\":841,\"./validate\":842}],834:[function(t,e,r){\"use strict\";var n=t(\"../lib/is_plain_object\"),i=t(\"../lib/noop\"),a=t(\"../lib/loggers\"),o=t(\"../lib/search\").sorterAsc,s=t(\"../registry\");r.containerArrayMatch=t(\"./container_array_match\");var l=r.isAddVal=function(t){return\"add\"===t||n(t)},c=r.isRemoveVal=function(t){return null===t||\"remove\"===t};r.applyContainerArrayChanges=function(t,e,r,n,u){var f=e.astr,h=s.getComponentMethod(f,\"supplyLayoutDefaults\"),p=s.getComponentMethod(f,\"draw\"),d=s.getComponentMethod(f,\"drawOne\"),m=n.replot||n.recalc||h===i||p===i,g=t.layout,v=t._fullLayout;if(r[\"\"]){Object.keys(r).length>1&&a.warn(\"Full array edits are incompatible with other edits\",f);var y=r[\"\"][\"\"];if(c(y))e.set(null);else{if(!Array.isArray(y))return a.warn(\"Unrecognized full array edit value\",f,y),!0;e.set(y)}return!m&&(h(g,v),p(t),!0)}var x,b,_,w,T,k,M,A,S=Object.keys(r).map(Number).sort(o),E=e.get(),L=E||[],C=u(v,f).get(),P=[],I=-1,O=L.length;for(x=0;x<S.length;x++)if(w=r[_=S[x]],T=Object.keys(w),k=w[\"\"],M=l(k),_<0||_>L.length-(M?0:1))a.warn(\"index out of range\",f,_);else if(void 0!==k)T.length>1&&a.warn(\"Insertion & removal are incompatible with edits to the same index.\",f,_),c(k)?P.push(_):M?(\"add\"===k&&(k={}),L.splice(_,0,k),C&&C.splice(_,0,{})):a.warn(\"Unrecognized full object edit value\",f,_,k),-1===I&&(I=_);else for(b=0;b<T.length;b++)A=f+\"[\"+_+\"].\",u(L[_],T[b],A).set(w[T[b]]);for(x=P.length-1;x>=0;x--)L.splice(P[x],1),C&&C.splice(P[x],1);if(L.length?E||e.set(L):e.set(null),m)return!1;if(h(g,v),d!==i){var z;if(-1===I)z=S;else{for(O=Math.max(L.length,O),z=[],x=0;x<S.length&&!((_=S[x])>=I);x++)z.push(_);for(x=I;x<O;x++)z.push(x)}for(x=0;x<z.length;x++)d(t,z[x])}else p(t);return!0}},{\"../lib/is_plain_object\":800,\"../lib/loggers\":803,\"../lib/noop\":808,\"../lib/search\":819,\"../registry\":927,\"./container_array_match\":830}],835:[function(t,e,r){\"use strict\";var n=t(\"@plotly/d3\"),i=t(\"fast-isnumeric\"),a=t(\"has-hover\"),o=t(\"../lib\"),s=o.nestedProperty,l=t(\"../lib/events\"),c=t(\"../lib/queue\"),u=t(\"../registry\"),f=t(\"./plot_schema\"),h=t(\"../plots/plots\"),p=t(\"../plots/cartesian/axes\"),d=t(\"../components/drawing\"),m=t(\"../components/color\"),g=t(\"../plots/cartesian/graph_interact\").initInteractions,v=t(\"../constants/xmlns_namespaces\"),y=t(\"../plots/cartesian/select\").clearSelect,x=t(\"./plot_config\").dfltConfig,b=t(\"./manage_arrays\"),_=t(\"./helpers\"),w=t(\"./subroutines\"),T=t(\"./edit_types\"),k=t(\"../plots/cartesian/constants\").AX_NAME_PATTERN,M=0;function A(t){var e=t._fullLayout;e._redrawFromAutoMarginCount?e._redrawFromAutoMarginCount--:t.emit(\"plotly_afterplot\")}function S(t,e){try{t._fullLayout._paper.style(\"background\",e)}catch(t){o.error(t)}}function E(t,e){S(t,m.combine(e,\"white\"))}function L(t,e){if(!t._context){t._context=o.extendDeep({},x);var r=n.select(\"base\");t._context._baseUrl=r.size()&&r.attr(\"href\")?window.location.href.split(\"#\")[0]:\"\"}var i,s,l,c=t._context;if(e){for(s=Object.keys(e),i=0;i<s.length;i++)\"editable\"!==(l=s[i])&&\"edits\"!==l&&l in c&&(\"setBackground\"===l&&\"opaque\"===e[l]?c[l]=E:c[l]=e[l]);e.plot3dPixelRatio&&!c.plotGlPixelRatio&&(c.plotGlPixelRatio=c.plot3dPixelRatio);var u=e.editable;if(void 0!==u)for(c.editable=u,s=Object.keys(c.edits),i=0;i<s.length;i++)c.edits[s[i]]=u;if(e.edits)for(s=Object.keys(e.edits),i=0;i<s.length;i++)(l=s[i])in c.edits&&(c.edits[l]=e.edits[l]);c._exportedPlot=e._exportedPlot}c.staticPlot&&(c.editable=!1,c.edits={},c.autosizable=!1,c.scrollZoom=!1,c.doubleClick=!1,c.showTips=!1,c.showLink=!1,c.displayModeBar=!1),\"hover\"!==c.displayModeBar||a||(c.displayModeBar=!0),\"transparent\"!==c.setBackground&&\"function\"==typeof c.setBackground||(c.setBackground=S),c._hasZeroHeight=c._hasZeroHeight||0===t.clientHeight,c._hasZeroWidth=c._hasZeroWidth||0===t.clientWidth;var f=c.scrollZoom,h=c._scrollZoom={};if(!0===f)h.cartesian=1,h.gl3d=1,h.geo=1,h.mapbox=1;else if(\"string\"==typeof f){var p=f.split(\"+\");for(i=0;i<p.length;i++)h[p[i]]=1}else!1!==f&&(h.gl3d=1,h.geo=1,h.mapbox=1)}function C(t,e){var r,n,i=e+1,a=[];for(r=0;r<t.length;r++)(n=t[r])<0?a.push(i+n):a.push(n);return a}function P(t,e,r){var n,i;for(n=0;n<e.length;n++){if((i=e[n])!==parseInt(i,10))throw new Error(\"all values in \"+r+\" must be integers\");if(i>=t.data.length||i<-t.data.length)throw new Error(r+\" must be valid indices for gd.data.\");if(e.indexOf(i,n+1)>-1||i>=0&&e.indexOf(-t.data.length+i)>-1||i<0&&e.indexOf(t.data.length+i)>-1)throw new Error(\"each index in \"+r+\" must be unique.\")}}function I(t,e,r){if(!Array.isArray(t.data))throw new Error(\"gd.data must be an array.\");if(void 0===e)throw new Error(\"currentIndices is a required argument.\");if(Array.isArray(e)||(e=[e]),P(t,e,\"currentIndices\"),void 0===r||Array.isArray(r)||(r=[r]),void 0!==r&&P(t,r,\"newIndices\"),void 0!==r&&e.length!==r.length)throw new Error(\"current and new indices must be of equal length.\")}function O(t,e,r,n,a){!function(t,e,r,n){var i=o.isPlainObject(n);if(!Array.isArray(t.data))throw new Error(\"gd.data must be an array\");if(!o.isPlainObject(e))throw new Error(\"update must be a key:value object\");if(void 0===r)throw new Error(\"indices must be an integer or array of integers\");for(var a in P(t,r,\"indices\"),e){if(!Array.isArray(e[a])||e[a].length!==r.length)throw new Error(\"attribute \"+a+\" must be an array of length equal to indices array length\");if(i&&(!(a in n)||!Array.isArray(n[a])||n[a].length!==e[a].length))throw new Error(\"when maxPoints is set as a key:value object it must contain a 1:1 corrispondence with the keys and number of traces in the update object\")}}(t,e,r,n);for(var l=function(t,e,r,n){var a,l,c,u,f,h=o.isPlainObject(n),p=[];for(var d in Array.isArray(r)||(r=[r]),r=C(r,t.data.length-1),e)for(var m=0;m<r.length;m++){if(a=t.data[r[m]],l=(c=s(a,d)).get(),u=e[d][m],!o.isArrayOrTypedArray(u))throw new Error(\"attribute: \"+d+\" index: \"+m+\" must be an array\");if(!o.isArrayOrTypedArray(l))throw new Error(\"cannot extend missing or non-array attribute: \"+d);if(l.constructor!==u.constructor)throw new Error(\"cannot extend array with an array of a different type: \"+d);f=h?n[d][m]:n,i(f)||(f=-1),p.push({prop:c,target:l,insert:u,maxp:Math.floor(f)})}return p}(t,e,r,n),c={},u={},f=0;f<l.length;f++){var h=l[f].prop,p=l[f].maxp,d=a(l[f].target,l[f].insert,p);h.set(d[0]),Array.isArray(c[h.astr])||(c[h.astr]=[]),c[h.astr].push(d[1]),Array.isArray(u[h.astr])||(u[h.astr]=[]),u[h.astr].push(l[f].target.length)}return{update:c,maxPoints:u}}function z(t,e){var r=new t.constructor(t.length+e.length);return r.set(t),r.set(e,t.length),r}function D(t,e,n,i){t=o.getGraphDiv(t),_.clearPromiseQueue(t);var a={};if(\"string\"==typeof e)a[e]=n;else{if(!o.isPlainObject(e))return o.warn(\"Restyle fail.\",e,n,i),Promise.reject();a=o.extendFlat({},e),void 0===i&&(i=n)}Object.keys(a).length&&(t.changed=!0);var s=_.coerceTraceIndices(t,i),l=N(t,a,s),u=l.flags;u.calc&&(t.calcdata=void 0),u.clearAxisTypes&&_.clearAxisTypes(t,s,{});var f=[];u.fullReplot?f.push(r._doPlot):(f.push(h.previousPromises),h.supplyDefaults(t),u.markerSize&&(h.doCalcdata(t),q(f)),u.style&&f.push(w.doTraceStyle),u.colorbars&&f.push(w.doColorBars),f.push(A)),f.push(h.rehover,h.redrag),c.add(t,D,[t,l.undoit,l.traces],D,[t,l.redoit,l.traces]);var p=o.syncOrAsync(f,t);return p&&p.then||(p=Promise.resolve()),p.then((function(){return t.emit(\"plotly_restyle\",l.eventData),t}))}function R(t){return void 0===t?null:t}function F(t,e){return e?function(e,r,n){var i=s(e,r),a=i.set;return i.set=function(e){B((n||\"\")+r,i.get(),e,t),a(e)},i}:s}function B(t,e,r,n){if(Array.isArray(e)||Array.isArray(r))for(var i=Array.isArray(e)?e:[],a=Array.isArray(r)?r:[],s=Math.max(i.length,a.length),l=0;l<s;l++)B(t+\"[\"+l+\"]\",i[l],a[l],n);else if(o.isPlainObject(e)||o.isPlainObject(r)){var c=o.isPlainObject(e)?e:{},u=o.isPlainObject(r)?r:{},f=o.extendFlat({},c,u);for(var h in f)B(t+\".\"+h,c[h],u[h],n)}else void 0===n[t]&&(n[t]=R(e))}function N(t,e,r){var n,i=t._fullLayout,a=t._fullData,l=t.data,c=i._guiEditing,d=F(i._preGUI,c),m=o.extendDeepAll({},e);j(e);var g,v=T.traceFlags(),y={},x={};function b(){return r.map((function(){}))}function w(t){var e=p.id2name(t);-1===g.indexOf(e)&&g.push(e)}function k(t){return\"LAYOUT\"+t+\".autorange\"}function M(t){return\"LAYOUT\"+t+\".range\"}function A(t){for(var e=t;e<a.length;e++)if(a[e]._input===l[t])return a[e]}function S(n,a,o){if(Array.isArray(n))n.forEach((function(t){S(t,a,o)}));else if(!(n in e)&&!_.hasParent(e,n)){var s;if(\"LAYOUT\"===n.substr(0,6))s=d(t.layout,n.replace(\"LAYOUT\",\"\"));else{var u=r[o];s=F(i._tracePreGUI[A(u)._fullInput.uid],c)(l[u],n)}n in x||(x[n]=b()),void 0===x[n][o]&&(x[n][o]=R(s.get())),void 0!==a&&s.set(a)}}function E(t){return function(e){return a[e][t]}}function L(t){return function(e,n){return!1===e?a[r[n]][t]:null}}for(var C in e){if(_.hasParent(e,C))throw new Error(\"cannot set \"+C+\" and a parent attribute simultaneously\");var P,I,O,z,D,B,N=e[C];if(\"autobinx\"!==C&&\"autobiny\"!==C||(C=C.charAt(C.length-1)+\"bins\",N=Array.isArray(N)?N.map(L(C)):!1===N?r.map(E(C)):null),y[C]=N,\"LAYOUT\"!==C.substr(0,6)){for(x[C]=b(),n=0;n<r.length;n++){if(P=l[r[n]],I=A(r[n]),z=(O=F(i._tracePreGUI[I._fullInput.uid],c)(P,C)).get(),void 0!==(D=Array.isArray(N)?N[n%N.length]:N)){var U=O.parts[O.parts.length-1],V=C.substr(0,C.length-U.length-1),q=V?V+\".\":\"\",H=V?s(I,V).get():I;if((B=f.getTraceValObject(I,O.parts))&&B.impliedEdits&&null!==D)for(var G in B.impliedEdits)S(o.relativeAttr(C,G),B.impliedEdits[G],n);else if(\"thicknessmode\"!==U&&\"lenmode\"!==U||z===D||\"fraction\"!==D&&\"pixels\"!==D||!H){if(\"type\"===C&&(\"pie\"===D!=(\"pie\"===z)||\"funnelarea\"===D!=(\"funnelarea\"===z))){var Y=\"x\",W=\"y\";\"bar\"!==D&&\"bar\"!==z||\"h\"!==P.orientation||(Y=\"y\",W=\"x\"),o.swapAttrs(P,[\"?\",\"?src\"],\"labels\",Y),o.swapAttrs(P,[\"d?\",\"?0\"],\"label\",Y),o.swapAttrs(P,[\"?\",\"?src\"],\"values\",W),\"pie\"===z||\"funnelarea\"===z?(s(P,\"marker.color\").set(s(P,\"marker.colors\").get()),i._pielayer.selectAll(\"g.trace\").remove()):u.traceIs(P,\"cartesian\")&&s(P,\"marker.colors\").set(s(P,\"marker.color\").get())}}else{var X=i._size,Z=H.orient,J=\"top\"===Z||\"bottom\"===Z;if(\"thicknessmode\"===U){var K=J?X.h:X.w;S(q+\"thickness\",H.thickness*(\"fraction\"===D?1/K:K),n)}else{var Q=J?X.w:X.h;S(q+\"len\",H.len*(\"fraction\"===D?1/Q:Q),n)}}x[C][n]=R(z);if(-1!==[\"swapxy\",\"swapxyaxes\",\"orientation\",\"orientationaxes\"].indexOf(C)){if(\"orientation\"===C){O.set(D);var $=P.x&&!P.y?\"h\":\"v\";if((O.get()||$)===I.orientation)continue}else\"orientationaxes\"===C&&(P.orientation={v:\"h\",h:\"v\"}[I.orientation]);_.swapXYData(P),v.calc=v.clearAxisTypes=!0}else-1!==h.dataArrayContainers.indexOf(O.parts[0])?(_.manageArrayContainers(O,D,x),v.calc=!0):(B?B.arrayOk&&!u.traceIs(I,\"regl\")&&(o.isArrayOrTypedArray(D)||o.isArrayOrTypedArray(z))?v.calc=!0:T.update(v,B):v.calc=!0,O.set(D))}}if(-1!==[\"swapxyaxes\",\"orientationaxes\"].indexOf(C)&&p.swap(t,r),\"orientationaxes\"===C){var tt=s(t.layout,\"hovermode\"),et=tt.get();\"x\"===et?tt.set(\"y\"):\"y\"===et?tt.set(\"x\"):\"x unified\"===et?tt.set(\"y unified\"):\"y unified\"===et&&tt.set(\"x unified\")}if(-1!==[\"orientation\",\"type\"].indexOf(C)){for(g=[],n=0;n<r.length;n++){var rt=l[r[n]];u.traceIs(rt,\"cartesian\")&&(w(rt.xaxis||\"x\"),w(rt.yaxis||\"y\"))}S(g.map(k),!0,0),S(g.map(M),[0,1],0)}}else O=d(t.layout,C.replace(\"LAYOUT\",\"\")),x[C]=[R(O.get())],O.set(Array.isArray(N)?N[0]:N),v.calc=!0}return(v.calc||v.plot)&&(v.fullReplot=!0),{flags:v,undoit:x,redoit:y,traces:r,eventData:o.extendDeepNoArrays([],[m,r])}}function j(t){var e,r,n,i=o.counterRegex(\"axis\",\".title\",!1,!1),a=/colorbar\\.title$/,s=Object.keys(t);for(e=0;e<s.length;e++)r=s[e],n=t[r],\"title\"!==r&&!i.test(r)&&!a.test(r)||\"string\"!=typeof n&&\"number\"!=typeof n?r.indexOf(\"titlefont\")>-1?l(r,r.replace(\"titlefont\",\"title.font\")):r.indexOf(\"titleposition\")>-1?l(r,r.replace(\"titleposition\",\"title.position\")):r.indexOf(\"titleside\")>-1?l(r,r.replace(\"titleside\",\"title.side\")):r.indexOf(\"titleoffset\")>-1&&l(r,r.replace(\"titleoffset\",\"title.offset\")):l(r,r.replace(\"title\",\"title.text\"));function l(e,r){t[r]=t[e],delete t[e]}}function U(t,e,r){t=o.getGraphDiv(t),_.clearPromiseQueue(t);var n={};if(\"string\"==typeof e)n[e]=r;else{if(!o.isPlainObject(e))return o.warn(\"Relayout fail.\",e,r),Promise.reject();n=o.extendFlat({},e)}Object.keys(n).length&&(t.changed=!0);var i=W(t,n),a=i.flags;a.calc&&(t.calcdata=void 0);var s=[h.previousPromises];a.layoutReplot?s.push(w.layoutReplot):Object.keys(n).length&&(V(t,a,i)||h.supplyDefaults(t),a.legend&&s.push(w.doLegend),a.layoutstyle&&s.push(w.layoutStyles),a.axrange&&q(s,i.rangesAltered),a.ticks&&s.push(w.doTicksRelayout),a.modebar&&s.push(w.doModeBar),a.camera&&s.push(w.doCamera),a.colorbars&&s.push(w.doColorBars),s.push(A)),s.push(h.rehover,h.redrag),c.add(t,U,[t,i.undoit],U,[t,i.redoit]);var l=o.syncOrAsync(s,t);return l&&l.then||(l=Promise.resolve(t)),l.then((function(){return t.emit(\"plotly_relayout\",i.eventData),t}))}function V(t,e,r){var n=t._fullLayout;if(!e.axrange)return!1;for(var i in e)if(\"axrange\"!==i&&e[i])return!1;for(var a in r.rangesAltered){var o=p.id2name(a),s=t.layout[o],l=n[o];if(l.autorange=s.autorange,s.range&&(l.range=s.range.slice()),l.cleanRange(),l._matchGroup)for(var c in l._matchGroup)if(c!==a){var u=n[p.id2name(c)];u.autorange=l.autorange,u.range=l.range.slice(),u._input.range=l.range.slice()}}return!0}function q(t,e){var r=e?function(t){var r=[],n=!0;for(var i in e){var a=p.getFromId(t,i);if(r.push(i),-1!==(a.ticklabelposition||\"\").indexOf(\"inside\")&&a._anchorAxis&&r.push(a._anchorAxis._id),a._matchGroup)for(var o in a._matchGroup)e[o]||r.push(o);a.automargin&&(n=!1)}return p.draw(t,r,{skipTitle:n})}:function(t){return p.draw(t,\"redraw\")};t.push(y,w.doAutoRangeAndConstraints,r,w.drawData,w.finalDraw)}var H=/^[xyz]axis[0-9]*\\.range(\\[[0|1]\\])?$/,G=/^[xyz]axis[0-9]*\\.autorange$/,Y=/^[xyz]axis[0-9]*\\.domain(\\[[0|1]\\])?$/;function W(t,e){var r,n,i,a=t.layout,l=t._fullLayout,c=l._guiEditing,h=F(l._preGUI,c),d=Object.keys(e),m=p.list(t),g=o.extendDeepAll({},e),v={};for(j(e),d=Object.keys(e),n=0;n<d.length;n++)if(0===d[n].indexOf(\"allaxes\")){for(i=0;i<m.length;i++){var y=m[i]._id.substr(1),x=-1!==y.indexOf(\"scene\")?y+\".\":\"\",w=d[n].replace(\"allaxes\",x+m[i]._name);e[w]||(e[w]=e[d[n]])}delete e[d[n]]}var M=T.layoutFlags(),A={},S={};function E(t,r){if(Array.isArray(t))t.forEach((function(t){E(t,r)}));else if(!(t in e)&&!_.hasParent(e,t)){var n=h(a,t);t in S||(S[t]=R(n.get())),void 0!==r&&n.set(r)}}var L,C={};function P(t){var e=p.name2id(t.split(\".\")[0]);return C[e]=1,e}for(var I in e){if(_.hasParent(e,I))throw new Error(\"cannot set \"+I+\" and a parent attribute simultaneously\");for(var O=h(a,I),z=e[I],D=O.parts.length-1;D>0&&\"string\"!=typeof O.parts[D];)D--;var B=O.parts[D],N=O.parts[D-1]+\".\"+B,U=O.parts.slice(0,D).join(\".\"),V=s(t.layout,U).get(),q=s(l,U).get(),W=O.get();if(void 0!==z){A[I]=z,S[I]=\"reverse\"===B?z:R(W);var Z=f.getLayoutValObject(l,O.parts);if(Z&&Z.impliedEdits&&null!==z)for(var J in Z.impliedEdits)E(o.relativeAttr(I,J),Z.impliedEdits[J]);if(-1!==[\"width\",\"height\"].indexOf(I))if(z){E(\"autosize\",null);var K=\"height\"===I?\"width\":\"height\";E(K,l[K])}else l[I]=t._initialAutoSize[I];else if(\"autosize\"===I)E(\"width\",z?null:l.width),E(\"height\",z?null:l.height);else if(N.match(H))P(N),s(l,U+\"._inputRange\").set(null);else if(N.match(G)){P(N),s(l,U+\"._inputRange\").set(null);var Q=s(l,U).get();Q._inputDomain&&(Q._input.domain=Q._inputDomain.slice())}else N.match(Y)&&s(l,U+\"._inputDomain\").set(null);if(\"type\"===B){L=V;var $=\"linear\"===q.type&&\"log\"===z,tt=\"log\"===q.type&&\"linear\"===z;if($||tt){if(L&&L.range)if(q.autorange)$&&(L.range=L.range[1]>L.range[0]?[1,2]:[2,1]);else{var et=L.range[0],rt=L.range[1];$?(et<=0&&rt<=0&&E(U+\".autorange\",!0),et<=0?et=rt/1e6:rt<=0&&(rt=et/1e6),E(U+\".range[0]\",Math.log(et)/Math.LN10),E(U+\".range[1]\",Math.log(rt)/Math.LN10)):(E(U+\".range[0]\",Math.pow(10,et)),E(U+\".range[1]\",Math.pow(10,rt)))}else E(U+\".autorange\",!0);Array.isArray(l._subplots.polar)&&l._subplots.polar.length&&l[O.parts[0]]&&\"radialaxis\"===O.parts[1]&&delete l[O.parts[0]]._subplot.viewInitial[\"radialaxis.range\"],u.getComponentMethod(\"annotations\",\"convertCoords\")(t,q,z,E),u.getComponentMethod(\"images\",\"convertCoords\")(t,q,z,E)}else E(U+\".autorange\",!0),E(U+\".range\",null);s(l,U+\"._inputRange\").set(null)}else if(B.match(k)){var nt=s(l,I).get(),it=(z||{}).type;it&&\"-\"!==it||(it=\"linear\"),u.getComponentMethod(\"annotations\",\"convertCoords\")(t,nt,it,E),u.getComponentMethod(\"images\",\"convertCoords\")(t,nt,it,E)}var at=b.containerArrayMatch(I);if(at){r=at.array,n=at.index;var ot=at.property,st=Z||{editType:\"calc\"};\"\"!==n&&\"\"===ot&&(b.isAddVal(z)?S[I]=null:b.isRemoveVal(z)?S[I]=(s(a,r).get()||[])[n]:o.warn(\"unrecognized full object value\",e)),T.update(M,st),v[r]||(v[r]={});var lt=v[r][n];lt||(lt=v[r][n]={}),lt[ot]=z,delete e[I]}else\"reverse\"===B?(V.range?V.range.reverse():(E(U+\".autorange\",!0),V.range=[1,0]),q.autorange?M.calc=!0:M.plot=!0):(l._has(\"scatter-like\")&&l._has(\"regl\")&&\"dragmode\"===I&&(\"lasso\"===z||\"select\"===z)&&\"lasso\"!==W&&\"select\"!==W||l._has(\"gl2d\")?M.plot=!0:Z?T.update(M,Z):M.calc=!0,O.set(z))}}for(r in v){b.applyContainerArrayChanges(t,h(a,r),v[r],M,h)||(M.plot=!0)}for(var ct in C){var ut=(L=p.getFromId(t,ct))&&L._constraintGroup;if(ut)for(var ft in M.calc=!0,ut)C[ft]||(p.getFromId(t,ft)._constraintShrinkable=!0)}return(X(t)||e.height||e.width)&&(M.plot=!0),(M.plot||M.calc)&&(M.layoutReplot=!0),{flags:M,rangesAltered:C,undoit:S,redoit:A,eventData:g}}function X(t){var e=t._fullLayout,r=e.width,n=e.height;return t.layout.autosize&&h.plotAutoSize(t,t.layout,e),e.width!==r||e.height!==n}function Z(t,e,n,i){t=o.getGraphDiv(t),_.clearPromiseQueue(t),o.isPlainObject(e)||(e={}),o.isPlainObject(n)||(n={}),Object.keys(e).length&&(t.changed=!0),Object.keys(n).length&&(t.changed=!0);var a=_.coerceTraceIndices(t,i),s=N(t,o.extendFlat({},e),a),l=s.flags,u=W(t,o.extendFlat({},n)),f=u.flags;(l.calc||f.calc)&&(t.calcdata=void 0),l.clearAxisTypes&&_.clearAxisTypes(t,a,n);var p=[];f.layoutReplot?p.push(w.layoutReplot):l.fullReplot?p.push(r._doPlot):(p.push(h.previousPromises),V(t,f,u)||h.supplyDefaults(t),l.style&&p.push(w.doTraceStyle),(l.colorbars||f.colorbars)&&p.push(w.doColorBars),f.legend&&p.push(w.doLegend),f.layoutstyle&&p.push(w.layoutStyles),f.axrange&&q(p,u.rangesAltered),f.ticks&&p.push(w.doTicksRelayout),f.modebar&&p.push(w.doModeBar),f.camera&&p.push(w.doCamera),p.push(A)),p.push(h.rehover,h.redrag),c.add(t,Z,[t,s.undoit,u.undoit,s.traces],Z,[t,s.redoit,u.redoit,s.traces]);var d=o.syncOrAsync(p,t);return d&&d.then||(d=Promise.resolve(t)),d.then((function(){return t.emit(\"plotly_update\",{data:s.eventData,layout:u.eventData}),t}))}function J(t){return function(e){e._fullLayout._guiEditing=!0;var r=t.apply(null,arguments);return e._fullLayout._guiEditing=!1,r}}var K=[{pattern:/^hiddenlabels/,attr:\"legend.uirevision\"},{pattern:/^((x|y)axis\\d*)\\.((auto)?range|title\\.text)/},{pattern:/axis\\d*\\.showspikes$/,attr:\"modebar.uirevision\"},{pattern:/(hover|drag)mode$/,attr:\"modebar.uirevision\"},{pattern:/^(scene\\d*)\\.camera/},{pattern:/^(geo\\d*)\\.(projection|center|fitbounds)/},{pattern:/^(ternary\\d*\\.[abc]axis)\\.(min|title\\.text)$/},{pattern:/^(polar\\d*\\.radialaxis)\\.((auto)?range|angle|title\\.text)/},{pattern:/^(polar\\d*\\.angularaxis)\\.rotation/},{pattern:/^(mapbox\\d*)\\.(center|zoom|bearing|pitch)/},{pattern:/^legend\\.(x|y)$/,attr:\"editrevision\"},{pattern:/^(shapes|annotations)/,attr:\"editrevision\"},{pattern:/^title\\.text$/,attr:\"editrevision\"}],Q=[{pattern:/^selectedpoints$/,attr:\"selectionrevision\"},{pattern:/(^|value\\.)visible$/,attr:\"legend.uirevision\"},{pattern:/^dimensions\\[\\d+\\]\\.constraintrange/},{pattern:/^node\\.(x|y|groups)/},{pattern:/^level$/},{pattern:/(^|value\\.)name$/},{pattern:/colorbar\\.title\\.text$/},{pattern:/colorbar\\.(x|y)$/,attr:\"editrevision\"}];function $(t,e){for(var r=0;r<e.length;r++){var n=e[r],i=t.match(n.pattern);if(i)return{head:i[1],attr:n.attr}}}function tt(t,e){var r=s(e,t).get();if(void 0!==r)return r;var n=t.split(\".\");for(n.pop();n.length>1;)if(n.pop(),void 0!==(r=s(e,n.join(\".\")+\".uirevision\").get()))return r;return e.uirevision}function et(t,e){for(var r=0;r<e.length;r++)if(e[r]._fullInput.uid===t)return r;return-1}function rt(t,e,r){for(var n=0;n<e.length;n++)if(e[n].uid===t)return n;return!e[r]||e[r].uid?-1:r}function nt(t,e){var r=o.isPlainObject(t),n=Array.isArray(t);return r||n?(r&&o.isPlainObject(e)||n&&Array.isArray(e))&&JSON.stringify(t)===JSON.stringify(e):t===e}function it(t,e,r,n){var i,a,l,c=n.getValObject,u=n.flags,f=n.immutable,h=n.inArray,p=n.arrayIndex;function d(){var t=i.editType;h&&-1!==t.indexOf(\"arraydraw\")?o.pushUnique(u.arrays[h],p):(T.update(u,i),\"none\"!==t&&u.nChanges++,n.transition&&i.anim&&u.nChangesAnim++,(H.test(l)||G.test(l))&&(u.rangesAltered[r[0]]=1),Y.test(l)&&s(e,\"_inputDomain\").set(null),\"datarevision\"===a&&(u.newDataRevision=1))}function m(t){return\"data_array\"===t.valType||t.arrayOk}for(a in t){if(u.calc&&!n.transition)return;var g=t[a],v=e[a],y=r.concat(a);if(l=y.join(\".\"),\"_\"!==a.charAt(0)&&\"function\"!=typeof g&&g!==v){if((\"tick0\"===a||\"dtick\"===a)&&\"geo\"!==r[0]){var x=e.tickmode;if(\"auto\"===x||\"array\"===x||!x)continue}if((\"range\"!==a||!e.autorange)&&(\"zmin\"!==a&&\"zmax\"!==a||\"contourcarpet\"!==e.type)&&(i=c(y))&&(!i._compareAsJSON||JSON.stringify(g)!==JSON.stringify(v))){var b,_=i.valType,w=m(i),k=Array.isArray(g),M=Array.isArray(v);if(k&&M){var A=\"_input_\"+a,S=t[A],E=e[A];if(Array.isArray(S)&&S===E)continue}if(void 0===v)w&&k?u.calc=!0:d();else if(i._isLinkedToArray){var L=[],C=!1;h||(u.arrays[a]=L);var P=Math.min(g.length,v.length),I=Math.max(g.length,v.length);if(P!==I){if(\"arraydraw\"!==i.editType){d();continue}C=!0}for(b=0;b<P;b++)it(g[b],v[b],y.concat(b),o.extendFlat({inArray:a,arrayIndex:b},n));if(C)for(b=P;b<I;b++)L.push(b)}else!_&&o.isPlainObject(g)?it(g,v,y,n):w?k&&M?(f&&(u.calc=!0),(f||n.newDataRevision)&&d()):k!==M?u.calc=!0:d():k&&M&&g.length===v.length&&String(g)===String(v)||d()}}}for(a in e)if(!(a in t)&&\"_\"!==a.charAt(0)&&\"function\"!=typeof e[a]){if(m(i=c(r.concat(a)))&&Array.isArray(e[a]))return void(u.calc=!0);d()}}function at(t){var e=t._fullLayout,r=t.getBoundingClientRect();if(!o.equalDomRects(r,e._lastBBox)){var n=e._invTransform=o.inverseTransformMatrix(o.getFullTransformMatrix(t));e._invScaleX=Math.sqrt(n[0][0]*n[0][0]+n[0][1]*n[0][1]+n[0][2]*n[0][2]),e._invScaleY=Math.sqrt(n[1][0]*n[1][0]+n[1][1]*n[1][1]+n[1][2]*n[1][2]),e._lastBBox=r}}r.animate=function(t,e,r){if(t=o.getGraphDiv(t),!o.isPlotDiv(t))throw new Error(\"This element is not a Plotly plot: \"+t+\". It's likely that you've failed to create a plot before animating it. For more details, see https://plotly.com/javascript/animations/\");var n=t._transitionData;n._frameQueue||(n._frameQueue=[]);var i=(r=h.supplyAnimationDefaults(r)).transition,a=r.frame;function s(t){return Array.isArray(i)?t>=i.length?i[0]:i[t]:i}function l(t){return Array.isArray(a)?t>=a.length?a[0]:a[t]:a}function c(t,e){var r=0;return function(){if(t&&++r===e)return t()}}return void 0===n._frameWaitingCnt&&(n._frameWaitingCnt=0),new Promise((function(a,u){function f(){n._currentFrame&&n._currentFrame.onComplete&&n._currentFrame.onComplete();var e=n._currentFrame=n._frameQueue.shift();if(e){var r=e.name?e.name.toString():null;t._fullLayout._currentFrame=r,n._lastFrameAt=Date.now(),n._timeToNext=e.frameOpts.duration,h.transition(t,e.frame.data,e.frame.layout,_.coerceTraceIndices(t,e.frame.traces),e.frameOpts,e.transitionOpts).then((function(){e.onComplete&&e.onComplete()})),t.emit(\"plotly_animatingframe\",{name:r,frame:e.frame,animation:{frame:e.frameOpts,transition:e.transitionOpts}})}else t.emit(\"plotly_animated\"),window.cancelAnimationFrame(n._animationRaf),n._animationRaf=null}function p(){t.emit(\"plotly_animating\"),n._lastFrameAt=-1/0,n._timeToNext=0,n._runningTransitions=0,n._currentFrame=null;var e=function(){n._animationRaf=window.requestAnimationFrame(e),Date.now()-n._lastFrameAt>n._timeToNext&&f()};e()}var d,m,g=0;function v(t){return Array.isArray(i)?g>=i.length?t.transitionOpts=i[g]:t.transitionOpts=i[0]:t.transitionOpts=i,g++,t}var y=[],x=null==e,b=Array.isArray(e);if(!x&&!b&&o.isPlainObject(e))y.push({type:\"object\",data:v(o.extendFlat({},e))});else if(x||-1!==[\"string\",\"number\"].indexOf(typeof e))for(d=0;d<n._frames.length;d++)(m=n._frames[d])&&(x||String(m.group)===String(e))&&y.push({type:\"byname\",name:String(m.name),data:v({name:m.name})});else if(b)for(d=0;d<e.length;d++){var w=e[d];-1!==[\"number\",\"string\"].indexOf(typeof w)?(w=String(w),y.push({type:\"byname\",name:w,data:v({name:w})})):o.isPlainObject(w)&&y.push({type:\"object\",data:v(o.extendFlat({},w))})}for(d=0;d<y.length;d++)if(\"byname\"===(m=y[d]).type&&!n._frameHash[m.data.name])return o.warn('animate failure: frame not found: \"'+m.data.name+'\"'),void u();-1!==[\"next\",\"immediate\"].indexOf(r.mode)&&function(){if(0!==n._frameQueue.length){for(;n._frameQueue.length;){var e=n._frameQueue.pop();e.onInterrupt&&e.onInterrupt()}t.emit(\"plotly_animationinterrupted\",[])}}(),\"reverse\"===r.direction&&y.reverse();var T=t._fullLayout._currentFrame;if(T&&r.fromcurrent){var k=-1;for(d=0;d<y.length;d++)if(\"byname\"===(m=y[d]).type&&m.name===T){k=d;break}if(k>0&&k<y.length-1){var M=[];for(d=0;d<y.length;d++)m=y[d],(\"byname\"!==y[d].type||d>k)&&M.push(m);y=M}}y.length>0?function(e){if(0!==e.length){for(var i=0;i<e.length;i++){var o;o=\"byname\"===e[i].type?h.computeFrame(t,e[i].name):e[i].data;var f=l(i),d=s(i);d.duration=Math.min(d.duration,f.duration);var m={frame:o,name:e[i].name,frameOpts:f,transitionOpts:d};i===e.length-1&&(m.onComplete=c(a,2),m.onInterrupt=u),n._frameQueue.push(m)}\"immediate\"===r.mode&&(n._lastFrameAt=-1/0),n._animationRaf||p()}}(y):(t.emit(\"plotly_animated\"),a())}))},r.addFrames=function(t,e,r){if(t=o.getGraphDiv(t),null==e)return Promise.resolve();if(!o.isPlotDiv(t))throw new Error(\"This element is not a Plotly plot: \"+t+\". It's likely that you've failed to create a plot before adding frames. For more details, see https://plotly.com/javascript/animations/\");var n,i,a,s,l=t._transitionData._frames,u=t._transitionData._frameHash;if(!Array.isArray(e))throw new Error(\"addFrames failure: frameList must be an Array of frame definitions\"+e);var f=l.length+2*e.length,p=[],d={};for(n=e.length-1;n>=0;n--)if(o.isPlainObject(e[n])){var m=e[n].name,g=(u[m]||d[m]||{}).name,v=e[n].name,y=u[g]||d[g];g&&v&&\"number\"==typeof v&&y&&M<5&&(M++,o.warn('addFrames: overwriting frame \"'+(u[g]||d[g]).name+'\" with a frame whose name of type \"number\" also equates to \"'+g+'\". This is valid but may potentially lead to unexpected behavior since all plotly.js frame names are stored internally as strings.'),5===M&&o.warn(\"addFrames: This API call has yielded too many of these warnings. For the rest of this call, further warnings about numeric frame names will be suppressed.\")),d[m]={name:m},p.push({frame:h.supplyFrameDefaults(e[n]),index:r&&void 0!==r[n]&&null!==r[n]?r[n]:f+n})}p.sort((function(t,e){return t.index>e.index?-1:t.index<e.index?1:0}));var x=[],b=[],_=l.length;for(n=p.length-1;n>=0;n--){if(\"number\"==typeof(i=p[n].frame).name&&o.warn(\"Warning: addFrames accepts frames with numeric names, but the numbers areimplicitly cast to strings\"),!i.name)for(;u[i.name=\"frame \"+t._transitionData._counter++];);if(u[i.name]){for(a=0;a<l.length&&(l[a]||{}).name!==i.name;a++);x.push({type:\"replace\",index:a,value:i}),b.unshift({type:\"replace\",index:a,value:l[a]})}else s=Math.max(0,Math.min(p[n].index,_)),x.push({type:\"insert\",index:s,value:i}),b.unshift({type:\"delete\",index:s}),_++}var w=h.modifyFrames,T=h.modifyFrames,k=[t,b],A=[t,x];return c&&c.add(t,w,k,T,A),h.modifyFrames(t,x)},r.deleteFrames=function(t,e){if(t=o.getGraphDiv(t),!o.isPlotDiv(t))throw new Error(\"This element is not a Plotly plot: \"+t);var r,n,i=t._transitionData._frames,a=[],s=[];if(!e)for(e=[],r=0;r<i.length;r++)e.push(r);for((e=e.slice()).sort(),r=e.length-1;r>=0;r--)n=e[r],a.push({type:\"delete\",index:n}),s.unshift({type:\"insert\",index:n,value:i[n]});var l=h.modifyFrames,u=h.modifyFrames,f=[t,s],p=[t,a];return c&&c.add(t,l,f,u,p),h.modifyFrames(t,a)},r.addTraces=function t(e,n,i){e=o.getGraphDiv(e);var a,s,l=[],u=r.deleteTraces,f=t,h=[e,l],p=[e,n];for(function(t,e,r){var n,i;if(!Array.isArray(t.data))throw new Error(\"gd.data must be an array.\");if(void 0===e)throw new Error(\"traces must be defined.\");for(Array.isArray(e)||(e=[e]),n=0;n<e.length;n++)if(\"object\"!=typeof(i=e[n])||Array.isArray(i)||null===i)throw new Error(\"all values in traces array must be non-array objects\");if(void 0===r||Array.isArray(r)||(r=[r]),void 0!==r&&r.length!==e.length)throw new Error(\"if indices is specified, traces.length must equal indices.length\")}(e,n,i),Array.isArray(n)||(n=[n]),n=n.map((function(t){return o.extendFlat({},t)})),_.cleanData(n),a=0;a<n.length;a++)e.data.push(n[a]);for(a=0;a<n.length;a++)l.push(-n.length+a);if(void 0===i)return s=r.redraw(e),c.add(e,u,h,f,p),s;Array.isArray(i)||(i=[i]);try{I(e,l,i)}catch(t){throw e.data.splice(e.data.length-n.length,n.length),t}return c.startSequence(e),c.add(e,u,h,f,p),s=r.moveTraces(e,l,i),c.stopSequence(e),s},r.deleteTraces=function t(e,n){e=o.getGraphDiv(e);var i,a,s=[],l=r.addTraces,u=t,f=[e,s,n],h=[e,n];if(void 0===n)throw new Error(\"indices must be an integer or array of integers.\");for(Array.isArray(n)||(n=[n]),P(e,n,\"indices\"),(n=C(n,e.data.length-1)).sort(o.sorterDes),i=0;i<n.length;i+=1)a=e.data.splice(n[i],1)[0],s.push(a);var p=r.redraw(e);return c.add(e,l,f,u,h),p},r.extendTraces=function t(e,n,i,a){function s(t,e,r){var n,i;if(o.isTypedArray(t))if(r<0){var a=new t.constructor(0),s=z(t,e);r<0?(n=s,i=a):(n=a,i=s)}else if(n=new t.constructor(r),i=new t.constructor(t.length+e.length-r),r===e.length)n.set(e),i.set(t);else if(r<e.length){var l=e.length-r;n.set(e.subarray(l)),i.set(t),i.set(e.subarray(0,l),t.length)}else{var c=r-e.length,u=t.length-c;n.set(t.subarray(u)),n.set(e,c),i.set(t.subarray(0,u))}else n=t.concat(e),i=r>=0&&r<n.length?n.splice(0,n.length-r):[];return[n,i]}var l=O(e=o.getGraphDiv(e),n,i,a,s),u=r.redraw(e),f=[e,l.update,i,l.maxPoints];return c.add(e,r.prependTraces,f,t,arguments),u},r.moveTraces=function t(e,n,i){var a,s=[],l=[],u=t,f=t,h=[e=o.getGraphDiv(e),i,n],p=[e,n,i];if(I(e,n,i),n=Array.isArray(n)?n:[n],void 0===i)for(i=[],a=0;a<n.length;a++)i.push(-n.length+a);for(i=Array.isArray(i)?i:[i],n=C(n,e.data.length-1),i=C(i,e.data.length-1),a=0;a<e.data.length;a++)-1===n.indexOf(a)&&s.push(e.data[a]);for(a=0;a<n.length;a++)l.push({newIndex:i[a],trace:e.data[n[a]]});for(l.sort((function(t,e){return t.newIndex-e.newIndex})),a=0;a<l.length;a+=1)s.splice(l[a].newIndex,0,l[a].trace);e.data=s;var d=r.redraw(e);return c.add(e,u,h,f,p),d},r.prependTraces=function t(e,n,i,a){function s(t,e,r){var n,i;if(o.isTypedArray(t))if(r<=0){var a=new t.constructor(0),s=z(e,t);r<0?(n=s,i=a):(n=a,i=s)}else if(n=new t.constructor(r),i=new t.constructor(t.length+e.length-r),r===e.length)n.set(e),i.set(t);else if(r<e.length){var l=e.length-r;n.set(e.subarray(0,l)),i.set(e.subarray(l)),i.set(t,l)}else{var c=r-e.length;n.set(e),n.set(t.subarray(0,c),e.length),i.set(t.subarray(c))}else n=e.concat(t),i=r>=0&&r<n.length?n.splice(r,n.length):[];return[n,i]}var l=O(e=o.getGraphDiv(e),n,i,a,s),u=r.redraw(e),f=[e,l.update,i,l.maxPoints];return c.add(e,r.extendTraces,f,t,arguments),u},r.newPlot=function(t,e,n,i){return t=o.getGraphDiv(t),h.cleanPlot([],{},t._fullData||[],t._fullLayout||{}),h.purge(t),r._doPlot(t,e,n,i)},r._doPlot=function(t,e,i,a){var s;if(t=o.getGraphDiv(t),l.init(t),o.isPlainObject(e)){var c=e;e=c.data,i=c.layout,a=c.config,s=c.frames}if(!1===l.triggerHandler(t,\"plotly_beforeplot\",[e,i,a]))return Promise.reject();e||i||o.isPlotDiv(t)||o.warn(\"Calling _doPlot as if redrawing but this container doesn't yet have a plot.\",t),L(t,a),i||(i={}),n.select(t).classed(\"js-plotly-plot\",!0),d.makeTester(),Array.isArray(t._promises)||(t._promises=[]);var f=0===(t.data||[]).length&&Array.isArray(e);Array.isArray(e)&&(_.cleanData(e),f?t.data=e:t.data.push.apply(t.data,e),t.empty=!1),t.layout&&!f||(t.layout=_.cleanLayout(i)),h.supplyDefaults(t);var m=t._fullLayout,y=m._has(\"cartesian\");m._replotting=!0,(f||m._shouldCreateBgLayer)&&(!function(t){var e=n.select(t),r=t._fullLayout;if(r._calcInverseTransform=at,r._calcInverseTransform(t),r._container=e.selectAll(\".plot-container\").data([0]),r._container.enter().insert(\"div\",\":first-child\").classed(\"plot-container\",!0).classed(\"plotly\",!0),r._paperdiv=r._container.selectAll(\".svg-container\").data([0]),r._paperdiv.enter().append(\"div\").classed(\"user-select-none\",!0).classed(\"svg-container\",!0).style(\"position\",\"relative\"),r._glcontainer=r._paperdiv.selectAll(\".gl-container\").data([{}]),r._glcontainer.enter().append(\"div\").classed(\"gl-container\",!0),r._paperdiv.selectAll(\".main-svg\").remove(),r._paperdiv.select(\".modebar-container\").remove(),r._paper=r._paperdiv.insert(\"svg\",\":first-child\").classed(\"main-svg\",!0),r._toppaper=r._paperdiv.append(\"svg\").classed(\"main-svg\",!0),r._modebardiv=r._paperdiv.append(\"div\"),delete r._modeBar,r._hoverpaper=r._paperdiv.append(\"svg\").classed(\"main-svg\",!0),!r._uid){var i={};n.selectAll(\"defs\").each((function(){this.id&&(i[this.id.split(\"-\")[1]]=1)})),r._uid=o.randstr(i)}r._paperdiv.selectAll(\".main-svg\").attr(v.svgAttrs),r._defs=r._paper.append(\"defs\").attr(\"id\",\"defs-\"+r._uid),r._clips=r._defs.append(\"g\").classed(\"clips\",!0),r._topdefs=r._toppaper.append(\"defs\").attr(\"id\",\"topdefs-\"+r._uid),r._topclips=r._topdefs.append(\"g\").classed(\"clips\",!0),r._bgLayer=r._paper.append(\"g\").classed(\"bglayer\",!0),r._draggers=r._paper.append(\"g\").classed(\"draglayer\",!0);var a=r._paper.append(\"g\").classed(\"layer-below\",!0);r._imageLowerLayer=a.append(\"g\").classed(\"imagelayer\",!0),r._shapeLowerLayer=a.append(\"g\").classed(\"shapelayer\",!0),r._cartesianlayer=r._paper.append(\"g\").classed(\"cartesianlayer\",!0),r._polarlayer=r._paper.append(\"g\").classed(\"polarlayer\",!0),r._ternarylayer=r._paper.append(\"g\").classed(\"ternarylayer\",!0),r._geolayer=r._paper.append(\"g\").classed(\"geolayer\",!0),r._funnelarealayer=r._paper.append(\"g\").classed(\"funnelarealayer\",!0),r._pielayer=r._paper.append(\"g\").classed(\"pielayer\",!0),r._iciclelayer=r._paper.append(\"g\").classed(\"iciclelayer\",!0),r._treemaplayer=r._paper.append(\"g\").classed(\"treemaplayer\",!0),r._sunburstlayer=r._paper.append(\"g\").classed(\"sunburstlayer\",!0),r._indicatorlayer=r._toppaper.append(\"g\").classed(\"indicatorlayer\",!0),r._glimages=r._paper.append(\"g\").classed(\"glimages\",!0);var s=r._toppaper.append(\"g\").classed(\"layer-above\",!0);r._imageUpperLayer=s.append(\"g\").classed(\"imagelayer\",!0),r._shapeUpperLayer=s.append(\"g\").classed(\"shapelayer\",!0),r._infolayer=r._toppaper.append(\"g\").classed(\"infolayer\",!0),r._menulayer=r._toppaper.append(\"g\").classed(\"menulayer\",!0),r._zoomlayer=r._toppaper.append(\"g\").classed(\"zoomlayer\",!0),r._hoverlayer=r._hoverpaper.append(\"g\").classed(\"hoverlayer\",!0),r._modebardiv.classed(\"modebar-container\",!0).style(\"position\",\"absolute\").style(\"top\",\"0px\").style(\"right\",\"0px\"),t.emit(\"plotly_framework\")}(t),m._shouldCreateBgLayer&&delete m._shouldCreateBgLayer),d.initGradients(t),d.initPatterns(t),f&&p.saveShowSpikeInitial(t);var x=!t.calcdata||t.calcdata.length!==(t._fullData||[]).length;x&&h.doCalcdata(t);for(var b=0;b<t.calcdata.length;b++)t.calcdata[b][0].trace=t._fullData[b];t._context.responsive?t._responsiveChartHandler||(t._responsiveChartHandler=function(){o.isHidden(t)||h.resize(t)},window.addEventListener(\"resize\",t._responsiveChartHandler)):o.clearResponsive(t);var T=o.extendFlat({},m._size),k=0;function M(){if(h.clearAutoMarginIds(t),w.drawMarginPushers(t),p.allowAutoMargin(t),m._has(\"pie\"))for(var e=t._fullData,r=0;r<e.length;r++){var n=e[r];\"pie\"===n.type&&n.automargin&&h.allowAutoMargin(t,\"pie.\"+n.uid+\".automargin\")}return h.doAutoMargin(t),h.previousPromises(t)}function S(){t._transitioning||(w.doAutoRangeAndConstraints(t),f&&p.saveRangeInitial(t),u.getComponentMethod(\"rangeslider\",\"calcAutorange\")(t))}var E=[h.previousPromises,function(){if(s)return r.addFrames(t,s)},function e(){for(var r=m._basePlotModules,n=0;n<r.length;n++)r[n].drawFramework&&r[n].drawFramework(t);if(!m._glcanvas&&m._has(\"gl\")&&(m._glcanvas=m._glcontainer.selectAll(\".gl-canvas\").data([{key:\"contextLayer\",context:!0,pick:!1},{key:\"focusLayer\",context:!1,pick:!1},{key:\"pickLayer\",context:!1,pick:!0}],(function(t){return t.key})),m._glcanvas.enter().append(\"canvas\").attr(\"class\",(function(t){return\"gl-canvas gl-canvas-\"+t.key.replace(\"Layer\",\"\")})).style({position:\"absolute\",top:0,left:0,overflow:\"visible\",\"pointer-events\":\"none\"})),m._glcanvas){m._glcanvas.attr(\"width\",m.width).attr(\"height\",m.height);var i=m._glcanvas.data()[0].regl;if(i&&(Math.floor(m.width)!==i._gl.drawingBufferWidth||Math.floor(m.height)!==i._gl.drawingBufferHeight)){var a=\"WebGL context buffer and canvas dimensions do not match due to browser/WebGL bug.\";if(!k)return o.log(a+\" Clearing graph and plotting again.\"),h.cleanPlot([],{},t._fullData,m),h.supplyDefaults(t),m=t._fullLayout,h.doCalcdata(t),k++,e();o.error(a)}}return\"h\"===m.modebar.orientation?m._modebardiv.style(\"height\",null).style(\"width\",\"100%\"):m._modebardiv.style(\"width\",null).style(\"height\",m.height+\"px\"),h.previousPromises(t)},M,function(){if(h.didMarginChange(T,m._size))return o.syncOrAsync([M,w.layoutStyles],t)}];y&&E.push((function(){if(x)return o.syncOrAsync([u.getComponentMethod(\"shapes\",\"calcAutorange\"),u.getComponentMethod(\"annotations\",\"calcAutorange\"),S],t);S()})),E.push(w.layoutStyles),y&&E.push((function(){return p.draw(t,f?\"\":\"redraw\")}),(function(t){t._fullLayout._insideTickLabelsAutorange&&U(t,t._fullLayout._insideTickLabelsAutorange).then((function(){t._fullLayout._insideTickLabelsAutorange=void 0}))})),E.push(w.drawData,w.finalDraw,g,h.addLinks,h.rehover,h.redrag,h.doAutoMargin,(function(t){t._fullLayout._insideTickLabelsAutorange&&f&&p.saveRangeInitial(t,!0)}),h.previousPromises);var C=o.syncOrAsync(E,t);return C&&C.then||(C=Promise.resolve()),C.then((function(){return A(t),t}))},r.purge=function(t){var e=(t=o.getGraphDiv(t))._fullLayout||{},r=t._fullData||[];return h.cleanPlot([],{},r,e),h.purge(t),l.purge(t),e._container&&e._container.remove(),delete t._context,t},r.react=function(t,e,n,i){var a,l;t=o.getGraphDiv(t),_.clearPromiseQueue(t);var c=t._fullData,p=t._fullLayout;if(o.isPlotDiv(t)&&c&&p){if(o.isPlainObject(e)){var d=e;e=d.data,n=d.layout,i=d.config,a=d.frames}var m=!1;if(i){var g=o.extendDeep({},t._context);t._context=void 0,L(t,i),m=function t(e,r){var n;for(n in e)if(\"_\"!==n.charAt(0)){var i=e[n],a=r[n];if(i!==a)if(o.isPlainObject(i)&&o.isPlainObject(a)){if(t(i,a))return!0}else{if(!Array.isArray(i)||!Array.isArray(a))return!0;if(i.length!==a.length)return!0;for(var s=0;s<i.length;s++)if(i[s]!==a[s]){if(!o.isPlainObject(i[s])||!o.isPlainObject(a[s]))return!0;if(t(i[s],a[s]))return!0}}}}(g,t._context)}t.data=e||[],_.cleanData(t.data),t.layout=n||{},_.cleanLayout(t.layout),function(t,e,r,n){var i,a,l,c,u,f,h,p,d=n._preGUI,m=[],g={};for(i in d){if(u=$(i,K)){if(a=u.attr||u.head+\".uirevision\",(c=(l=s(n,a).get())&&tt(a,e))&&c===l&&(null===(f=d[i])&&(f=void 0),nt(p=(h=s(e,i)).get(),f))){void 0===p&&\"autorange\"===i.substr(i.length-9)&&m.push(i.substr(0,i.length-10)),h.set(R(s(n,i).get()));continue}}else o.warn(\"unrecognized GUI edit: \"+i);delete d[i],\"range[\"===i.substr(i.length-8,6)&&(g[i.substr(0,i.length-9)]=1)}for(var v=0;v<m.length;v++){var y=m[v];if(g[y]){var x=s(e,y).get();x&&delete x.autorange}}var b=n._tracePreGUI;for(var _ in b){var w,T=b[_],k=null;for(i in T){if(!k){var M=et(_,r);if(M<0){delete b[_];break}var A=rt(_,t,(w=r[M]._fullInput).index);if(A<0){delete b[_];break}k=t[A]}if(u=$(i,Q)){if(u.attr?c=(l=s(n,u.attr).get())&&tt(u.attr,e):(l=w.uirevision,void 0===(c=k.uirevision)&&(c=e.uirevision)),c&&c===l&&(null===(f=T[i])&&(f=void 0),nt(p=(h=s(k,i)).get(),f))){h.set(R(s(w,i).get()));continue}}else o.warn(\"unrecognized GUI edit: \"+i+\" in trace uid \"+_);delete T[i]}}}(t.data,t.layout,c,p),h.supplyDefaults(t,{skipUpdateCalc:!0});var v=t._fullData,y=t._fullLayout,x=void 0===y.datarevision,b=y.transition,k=function(t,e,r,n,i){var a=T.layoutFlags();function o(t){return f.getLayoutValObject(r,t)}a.arrays={},a.rangesAltered={},a.nChanges=0,a.nChangesAnim=0,it(e,r,[],{getValObject:o,flags:a,immutable:n,transition:i,gd:t}),(a.plot||a.calc)&&(a.layoutReplot=!0);i&&a.nChanges&&a.nChangesAnim&&(a.anim=a.nChanges===a.nChangesAnim?\"all\":\"some\");return a}(t,p,y,x,b),M=k.newDataRevision,S=function(t,e,r,n,i,a){var o=e.length===r.length;if(!i&&!o)return{fullReplot:!0,calc:!0};var s,l,c=T.traceFlags();c.arrays={},c.nChanges=0,c.nChangesAnim=0;var u={getValObject:function(t){var e=f.getTraceValObject(l,t);return!l._module.animatable&&e.anim&&(e.anim=!1),e},flags:c,immutable:n,transition:i,newDataRevision:a,gd:t},p={};for(s=0;s<e.length;s++)if(r[s]){if(l=r[s]._fullInput,h.hasMakesDataTransform(l)&&(l=r[s]),p[l.uid])continue;p[l.uid]=1,it(e[s]._fullInput,l,[],u)}(c.calc||c.plot)&&(c.fullReplot=!0);i&&c.nChanges&&c.nChangesAnim&&(c.anim=c.nChanges===c.nChangesAnim&&o?\"all\":\"some\");return c}(t,c,v,x,b,M);if(X(t)&&(k.layoutReplot=!0),S.calc||k.calc){t.calcdata=void 0;for(var E=Object.getOwnPropertyNames(y),C=0;C<E.length;C++){var P=E[C],I=P.substring(0,5);if(\"xaxis\"===I||\"yaxis\"===I){var O=y[P]._emptyCategories;O&&O()}}}else h.supplyDefaultsUpdateCalc(t.calcdata,v);var z=[];if(a&&(t._transitionData={},h.createTransitionData(t),z.push((function(){return r.addFrames(t,a)}))),y.transition&&!m&&(S.anim||k.anim))k.ticks&&z.push(w.doTicksRelayout),h.doCalcdata(t),w.doAutoRangeAndConstraints(t),z.push((function(){return h.transitionFromReact(t,S,k,p)}));else if(S.fullReplot||k.layoutReplot||m)t._fullLayout._skipDefaults=!0,z.push(r._doPlot);else{for(var D in k.arrays){var F=k.arrays[D];if(F.length){var B=u.getComponentMethod(D,\"drawOne\");if(B!==o.noop)for(var N=0;N<F.length;N++)B(t,F[N]);else{var j=u.getComponentMethod(D,\"draw\");if(j===o.noop)throw new Error(\"cannot draw components: \"+D);j(t)}}}z.push(h.previousPromises),S.style&&z.push(w.doTraceStyle),(S.colorbars||k.colorbars)&&z.push(w.doColorBars),k.legend&&z.push(w.doLegend),k.layoutstyle&&z.push(w.layoutStyles),k.axrange&&q(z),k.ticks&&z.push(w.doTicksRelayout),k.modebar&&z.push(w.doModeBar),k.camera&&z.push(w.doCamera),z.push(A)}z.push(h.rehover,h.redrag),(l=o.syncOrAsync(z,t))&&l.then||(l=Promise.resolve(t))}else l=r.newPlot(t,e,n,i);return l.then((function(){return t.emit(\"plotly_react\",{data:e,layout:n}),t}))},r.redraw=function(t){if(t=o.getGraphDiv(t),!o.isPlotDiv(t))throw new Error(\"This element is not a Plotly plot: \"+t);return _.cleanData(t.data),_.cleanLayout(t.layout),t.calcdata=void 0,r._doPlot(t).then((function(){return t.emit(\"plotly_redraw\"),t}))},r.relayout=U,r.restyle=D,r.setPlotConfig=function(t){return o.extendFlat(x,t)},r.update=Z,r._guiRelayout=J(U),r._guiRestyle=J(D),r._guiUpdate=J(Z),r._storeDirectGUIEdit=function(t,e,r){for(var n in r){B(n,s(t,n).get(),r[n],e)}}},{\"../components/color\":662,\"../components/drawing\":684,\"../constants/xmlns_namespaces\":776,\"../lib\":799,\"../lib/events\":788,\"../lib/queue\":815,\"../plots/cartesian/axes\":849,\"../plots/cartesian/constants\":856,\"../plots/cartesian/graph_interact\":859,\"../plots/cartesian/select\":869,\"../plots/plots\":913,\"../registry\":927,\"./edit_types\":831,\"./helpers\":832,\"./manage_arrays\":834,\"./plot_config\":836,\"./plot_schema\":837,\"./subroutines\":839,\"@plotly/d3\":58,\"fast-isnumeric\":245,\"has-hover\":439}],836:[function(t,e,r){\"use strict\";var n={staticPlot:{valType:\"boolean\",dflt:!1},plotlyServerURL:{valType:\"string\",dflt:\"\"},editable:{valType:\"boolean\",dflt:!1},edits:{annotationPosition:{valType:\"boolean\",dflt:!1},annotationTail:{valType:\"boolean\",dflt:!1},annotationText:{valType:\"boolean\",dflt:!1},axisTitleText:{valType:\"boolean\",dflt:!1},colorbarPosition:{valType:\"boolean\",dflt:!1},colorbarTitleText:{valType:\"boolean\",dflt:!1},legendPosition:{valType:\"boolean\",dflt:!1},legendText:{valType:\"boolean\",dflt:!1},shapePosition:{valType:\"boolean\",dflt:!1},titleText:{valType:\"boolean\",dflt:!1}},autosizable:{valType:\"boolean\",dflt:!1},responsive:{valType:\"boolean\",dflt:!1},fillFrame:{valType:\"boolean\",dflt:!1},frameMargins:{valType:\"number\",dflt:0,min:0,max:.5},scrollZoom:{valType:\"flaglist\",flags:[\"cartesian\",\"gl3d\",\"geo\",\"mapbox\"],extras:[!0,!1],dflt:\"gl3d+geo+mapbox\"},doubleClick:{valType:\"enumerated\",values:[!1,\"reset\",\"autosize\",\"reset+autosize\"],dflt:\"reset+autosize\"},doubleClickDelay:{valType:\"number\",dflt:300,min:0},showAxisDragHandles:{valType:\"boolean\",dflt:!0},showAxisRangeEntryBoxes:{valType:\"boolean\",dflt:!0},showTips:{valType:\"boolean\",dflt:!0},showLink:{valType:\"boolean\",dflt:!1},linkText:{valType:\"string\",dflt:\"Edit chart\",noBlank:!0},sendData:{valType:\"boolean\",dflt:!0},showSources:{valType:\"any\",dflt:!1},displayModeBar:{valType:\"enumerated\",values:[\"hover\",!0,!1],dflt:\"hover\"},showSendToCloud:{valType:\"boolean\",dflt:!1},showEditInChartStudio:{valType:\"boolean\",dflt:!1},modeBarButtonsToRemove:{valType:\"any\",dflt:[]},modeBarButtonsToAdd:{valType:\"any\",dflt:[]},modeBarButtons:{valType:\"any\",dflt:!1},toImageButtonOptions:{valType:\"any\",dflt:{}},displaylogo:{valType:\"boolean\",dflt:!0},watermark:{valType:\"boolean\",dflt:!1},plotGlPixelRatio:{valType:\"number\",dflt:2,min:1,max:4},setBackground:{valType:\"any\",dflt:\"transparent\"},topojsonURL:{valType:\"string\",noBlank:!0,dflt:\"https://cdn.plot.ly/\"},mapboxAccessToken:{valType:\"string\",dflt:null},logging:{valType:\"integer\",min:0,max:2,dflt:1},notifyOnLogging:{valType:\"integer\",min:0,max:2,dflt:0},queueLength:{valType:\"integer\",min:0,dflt:0},globalTransforms:{valType:\"any\",dflt:[]},locale:{valType:\"string\",dflt:\"en-US\"},locales:{valType:\"any\",dflt:{}}},i={};!function t(e,r){for(var n in e){var i=e[n];i.valType?r[n]=i.dflt:(r[n]||(r[n]={}),t(i,r[n]))}}(n,i),e.exports={configAttributes:n,dfltConfig:i}},{}],837:[function(t,e,r){\"use strict\";var n=t(\"../registry\"),i=t(\"../lib\"),a=t(\"../plots/attributes\"),o=t(\"../plots/layout_attributes\"),s=t(\"../plots/frame_attributes\"),l=t(\"../plots/animation_attributes\"),c=t(\"./plot_config\").configAttributes,u=t(\"./edit_types\"),f=i.extendDeepAll,h=i.isPlainObject,p=i.isArrayOrTypedArray,d=i.nestedProperty,m=i.valObjectMeta,g=[\"_isSubplotObj\",\"_isLinkedToArray\",\"_arrayAttrRegexps\",\"_deprecated\"];function v(t,e,r){if(!t)return!1;if(t._isLinkedToArray)if(y(e[r]))r++;else if(r<e.length)return!1;for(;r<e.length;r++){var n=t[e[r]];if(!h(n))break;if(t=n,r===e.length-1)break;if(t._isLinkedToArray){if(!y(e[++r]))return!1}else if(\"info_array\"===t.valType){var i=e[++r];if(!y(i))return!1;var a=t.items;if(Array.isArray(a)){if(i>=a.length)return!1;if(2===t.dimensions){if(r++,e.length===r)return t;var o=e[r];if(!y(o))return!1;t=a[i][o]}else t=a[i]}else t=a}}return t}function y(t){return t===Math.round(t)&&t>=0}function x(){var t,e,r={};for(t in f(r,o),n.subplotsRegistry){if((e=n.subplotsRegistry[t]).layoutAttributes)if(Array.isArray(e.attr))for(var i=0;i<e.attr.length;i++)w(r,e,e.attr[i]);else w(r,e,\"subplot\"===e.attr?e.name:e.attr)}for(t in n.componentsRegistry){var a=(e=n.componentsRegistry[t]).schema;if(a&&(a.subplots||a.layout)){var s=a.subplots;if(s&&s.xaxis&&!s.yaxis)for(var l in s.xaxis)delete r.yaxis[l]}else\"colorscale\"===e.name?f(r,e.layoutAttributes):e.layoutAttributes&&T(r,e.layoutAttributes,e.name)}return{layoutAttributes:_(r)}}function b(){var t={frames:f({},s)};return _(t),t.frames}function _(t){return function(t){r.crawl(t,(function(t,e,n){r.isValObject(t)?!0!==t.arrayOk&&\"data_array\"!==t.valType||(n[e+\"src\"]={valType:\"string\",editType:\"none\"}):h(t)&&(t.role=\"object\")}))}(t),function(t){r.crawl(t,(function(t,e,r){if(t){var n=t._isLinkedToArray;n&&(delete t._isLinkedToArray,r[e]={items:{}},r[e].items[n]=t,r[e].role=\"object\")}}))}(t),function(t){!function t(e){for(var r in e)if(h(e[r]))t(e[r]);else if(Array.isArray(e[r]))for(var n=0;n<e[r].length;n++)t(e[r][n]);else e[r]instanceof RegExp&&(e[r]=e[r].toString())}(t)}(t),t}function w(t,e,r){var n=d(t,r),i=f({},e.layoutAttributes);i._isSubplotObj=!0,n.set(i)}function T(t,e,r){var n=d(t,r);n.set(f(n.get()||{},e))}r.IS_SUBPLOT_OBJ=\"_isSubplotObj\",r.IS_LINKED_TO_ARRAY=\"_isLinkedToArray\",r.DEPRECATED=\"_deprecated\",r.UNDERSCORE_ATTRS=g,r.get=function(){var t={};n.allTypes.forEach((function(e){t[e]=function(t){var e,i;e=n.modules[t]._module,i=e.basePlotModule;var o={type:null},s=f({},a),l=f({},e.attributes);r.crawl(l,(function(t,e,r,n,i){d(s,i).set(void 0),void 0===t&&d(l,i).set(void 0)})),f(o,s),n.traceIs(t,\"noOpacity\")&&delete o.opacity;n.traceIs(t,\"showLegend\")||(delete o.showlegend,delete o.legendgroup);n.traceIs(t,\"noHover\")&&(delete o.hoverinfo,delete o.hoverlabel);e.selectPoints||delete o.selectedpoints;f(o,l),i.attributes&&f(o,i.attributes);o.type=t;var c={meta:e.meta||{},categories:e.categories||{},animatable:Boolean(e.animatable),type:t,attributes:_(o)};if(e.layoutAttributes){var u={};f(u,e.layoutAttributes),c.layoutAttributes=_(u)}e.animatable||r.crawl(c,(function(t){r.isValObject(t)&&\"anim\"in t&&delete t.anim}));return c}(e)}));var e={};return Object.keys(n.transformsRegistry).forEach((function(t){e[t]=function(t){var e=n.transformsRegistry[t],r=f({},e.attributes);return Object.keys(n.componentsRegistry).forEach((function(e){var i=n.componentsRegistry[e];i.schema&&i.schema.transforms&&i.schema.transforms[t]&&Object.keys(i.schema.transforms[t]).forEach((function(e){T(r,i.schema.transforms[t][e],e)}))})),{attributes:_(r)}}(t)})),{defs:{valObjects:m,metaKeys:g.concat([\"description\",\"role\",\"editType\",\"impliedEdits\"]),editType:{traces:u.traces,layout:u.layout},impliedEdits:{}},traces:t,layout:x(),transforms:e,frames:b(),animation:_(l),config:_(c)}},r.crawl=function(t,e,n,i){var a=n||0;i=i||\"\",Object.keys(t).forEach((function(n){var o=t[n];if(-1===g.indexOf(n)){var s=(i?i+\".\":\"\")+n;e(o,n,t,a,s),r.isValObject(o)||h(o)&&\"impliedEdits\"!==n&&r.crawl(o,e,a+1,s)}}))},r.isValObject=function(t){return t&&void 0!==t.valType},r.findArrayAttributes=function(t){var e,n,i=[],o=[],s=[];function l(t,r,a,l){o=o.slice(0,l).concat([r]),s=s.slice(0,l).concat([t&&t._isLinkedToArray]),t&&(\"data_array\"===t.valType||!0===t.arrayOk)&&!(\"colorbar\"===o[l-1]&&(\"ticktext\"===r||\"tickvals\"===r))&&function t(e,r,a){var l=e[o[r]],c=a+o[r];if(r===o.length-1)p(l)&&i.push(n+c);else if(s[r]){if(Array.isArray(l))for(var u=0;u<l.length;u++)h(l[u])&&t(l[u],r+1,c+\"[\"+u+\"].\")}else h(l)&&t(l,r+1,c+\".\")}(e,0,\"\")}e=t,n=\"\",r.crawl(a,l),t._module&&t._module.attributes&&r.crawl(t._module.attributes,l);var c=t.transforms;if(c)for(var u=0;u<c.length;u++){var f=c[u],d=f._module;d&&(n=\"transforms[\"+u+\"].\",e=f,r.crawl(d.attributes,l))}return i},r.getTraceValObject=function(t,e){var r,i,o=e[0],s=1;if(\"transforms\"===o){if(1===e.length)return a.transforms;var l=t.transforms;if(!Array.isArray(l)||!l.length)return!1;var c=e[1];if(!y(c)||c>=l.length)return!1;i=(r=(n.transformsRegistry[l[c].type]||{}).attributes)&&r[e[2]],s=3}else{var u=t._module;if(u||(u=(n.modules[t.type||a.type.dflt]||{})._module),!u)return!1;if(!(i=(r=u.attributes)&&r[o])){var f=u.basePlotModule;f&&f.attributes&&(i=f.attributes[o])}i||(i=a[o])}return v(i,e,s)},r.getLayoutValObject=function(t,e){return v(function(t,e){var r,i,a,s,l=t._basePlotModules;if(l){var c;for(r=0;r<l.length;r++){if((a=l[r]).attrRegex&&a.attrRegex.test(e)){if(a.layoutAttrOverrides)return a.layoutAttrOverrides;!c&&a.layoutAttributes&&(c=a.layoutAttributes)}var u=a.baseLayoutAttrOverrides;if(u&&e in u)return u[e]}if(c)return c}var f=t._modules;if(f)for(r=0;r<f.length;r++)if((s=f[r].layoutAttributes)&&e in s)return s[e];for(i in n.componentsRegistry){if(\"colorscale\"===(a=n.componentsRegistry[i]).name&&0===e.indexOf(\"coloraxis\"))return a.layoutAttributes[e];if(!a.schema&&e===a.name)return a.layoutAttributes}return e in o&&o[e]}(t,e[0]),e,1)}},{\"../lib\":799,\"../plots/animation_attributes\":843,\"../plots/attributes\":845,\"../plots/frame_attributes\":879,\"../plots/layout_attributes\":904,\"../registry\":927,\"./edit_types\":831,\"./plot_config\":836}],838:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"../plots/attributes\"),a={name:{valType:\"string\",editType:\"none\"}};function o(t){return t&&\"string\"==typeof t}function s(t){var e=t.length-1;return\"s\"!==t.charAt(e)&&n.warn(\"bad argument to arrayDefaultKey: \"+t),t.substr(0,t.length-1)+\"defaults\"}a.templateitemname={valType:\"string\",editType:\"calc\"},r.templatedArray=function(t,e){return e._isLinkedToArray=t,e.name=a.name,e.templateitemname=a.templateitemname,e},r.traceTemplater=function(t){var e,r,a={};for(e in t)r=t[e],Array.isArray(r)&&r.length&&(a[e]=0);return{newTrace:function(o){var s={type:e=n.coerce(o,{},i,\"type\"),_template:null};if(e in a){r=t[e];var l=a[e]%r.length;a[e]++,s._template=r[l]}return s}}},r.newContainer=function(t,e,r){var i=t._template,a=i&&(i[e]||r&&i[r]);return n.isPlainObject(a)||(a=null),t[e]={_template:a}},r.arrayTemplater=function(t,e,r){var n=t._template,i=n&&n[s(e)],a=n&&n[e];Array.isArray(a)&&a.length||(a=[]);var l={};return{newItem:function(t){var e={name:t.name,_input:t},n=e.templateitemname=t.templateitemname;if(!o(n))return e._template=i,e;for(var s=0;s<a.length;s++){var c=a[s];if(c.name===n)return l[n]=1,e._template=c,e}return e[r]=t[r]||!1,e._template=!1,e},defaultItems:function(){for(var t=[],e=0;e<a.length;e++){var r=a[e],n=r.name;if(o(n)&&!l[n]){var i={_template:r,name:n,_input:{_templateitemname:n}};i.templateitemname=r.templateitemname,t.push(i),l[n]=1}}return t}}},r.arrayDefaultKey=s,r.arrayEditor=function(t,e,r){var i=(n.nestedProperty(t,e).get()||[]).length,a=r._index,o=a>=i&&(r._input||{})._templateitemname;o&&(a=i);var s,l=e+\"[\"+a+\"]\";function c(){s={},o&&(s[l]={},s[l].templateitemname=o)}function u(t,e){o?n.nestedProperty(s[l],t).set(e):s[l+\".\"+t]=e}function f(){var t=s;return c(),t}return c(),{modifyBase:function(t,e){s[t]=e},modifyItem:u,getUpdateObj:f,applyUpdate:function(e,r){e&&u(e,r);var i=f();for(var a in i)n.nestedProperty(t,a).set(i[a])}}}},{\"../lib\":799,\"../plots/attributes\":845}],839:[function(t,e,r){\"use strict\";var n=t(\"@plotly/d3\"),i=t(\"../registry\"),a=t(\"../plots/plots\"),o=t(\"../lib\"),s=t(\"../lib/clear_gl_canvases\"),l=t(\"../components/color\"),c=t(\"../components/drawing\"),u=t(\"../components/titles\"),f=t(\"../components/modebar\"),h=t(\"../plots/cartesian/axes\"),p=t(\"../constants/alignment\"),d=t(\"../plots/cartesian/constraints\"),m=d.enforce,g=d.clean,v=t(\"../plots/cartesian/autorange\").doAutoRange;function y(t,e,r){for(var n=0;n<r.length;n++){var i=r[n][0],a=r[n][1];if(!(i[0]>=t[1]||i[1]<=t[0])&&(a[0]<e[1]&&a[1]>e[0]))return!0}return!1}function x(t){var e,i,s,u,d,m,g=t._fullLayout,v=g._size,x=v.p,_=h.list(t,\"\",!0);if(g._paperdiv.style({width:t._context.responsive&&g.autosize&&!t._context._hasZeroWidth&&!t.layout.width?\"100%\":g.width+\"px\",height:t._context.responsive&&g.autosize&&!t._context._hasZeroHeight&&!t.layout.height?\"100%\":g.height+\"px\"}).selectAll(\".main-svg\").call(c.setSize,g.width,g.height),t._context.setBackground(t,g.paper_bgcolor),r.drawMainTitle(t),f.manage(t),!g._has(\"cartesian\"))return a.previousPromises(t);function T(t,e,r){var n=t._lw/2;return\"x\"===t._id.charAt(0)?e?\"top\"===r?e._offset-x-n:e._offset+e._length+x+n:v.t+v.h*(1-(t.position||0))+n%1:e?\"right\"===r?e._offset+e._length+x+n:e._offset-x-n:v.l+v.w*(t.position||0)+n%1}for(e=0;e<_.length;e++){var k=(u=_[e])._anchorAxis;u._linepositions={},u._lw=c.crispRound(t,u.linewidth,1),u._mainLinePosition=T(u,k,u.side),u._mainMirrorPosition=u.mirror&&k?T(u,k,p.OPPOSITE_SIDE[u.side]):null}var M=[],A=[],S=[],E=1===l.opacity(g.paper_bgcolor)&&1===l.opacity(g.plot_bgcolor)&&g.paper_bgcolor===g.plot_bgcolor;for(i in g._plots)if((s=g._plots[i]).mainplot)s.bg&&s.bg.remove(),s.bg=void 0;else{var L=s.xaxis.domain,C=s.yaxis.domain,P=s.plotgroup;if(y(L,C,S)){var I=P.node(),O=s.bg=o.ensureSingle(P,\"rect\",\"bg\");I.insertBefore(O.node(),I.childNodes[0]),A.push(i)}else P.select(\"rect.bg\").remove(),S.push([L,C]),E||(M.push(i),A.push(i))}var z,D,R,F,B,N,j,U,V,q,H,G,Y,W=g._bgLayer.selectAll(\".bg\").data(M);for(W.enter().append(\"rect\").classed(\"bg\",!0),W.exit().remove(),W.each((function(t){g._plots[t].bg=n.select(this)})),e=0;e<A.length;e++)s=g._plots[A[e]],d=s.xaxis,m=s.yaxis,s.bg&&void 0!==d._offset&&void 0!==m._offset&&s.bg.call(c.setRect,d._offset-x,m._offset-x,d._length+2*x,m._length+2*x).call(l.fill,g.plot_bgcolor).style(\"stroke-width\",0);if(!g._hasOnlyLargeSploms)for(i in g._plots){s=g._plots[i],d=s.xaxis,m=s.yaxis;var X,Z,J=s.clipId=\"clip\"+g._uid+i+\"plot\",K=o.ensureSingleById(g._clips,\"clipPath\",J,(function(t){t.classed(\"plotclip\",!0).append(\"rect\")}));s.clipRect=K.select(\"rect\").attr({width:d._length,height:m._length}),c.setTranslate(s.plot,d._offset,m._offset),s._hasClipOnAxisFalse?(X=null,Z=J):(X=J,Z=null),c.setClipUrl(s.plot,X,t),s.layerClipId=Z}function Q(t){return\"M\"+z+\",\"+t+\"H\"+D}function $(t){return\"M\"+d._offset+\",\"+t+\"h\"+d._length}function tt(t){return\"M\"+t+\",\"+U+\"V\"+j}function et(t){return\"M\"+t+\",\"+m._offset+\"v\"+m._length}function rt(t,e,r){if(!t.showline||i!==t._mainSubplot)return\"\";if(!t._anchorAxis)return r(t._mainLinePosition);var n=e(t._mainLinePosition);return t.mirror&&(n+=e(t._mainMirrorPosition)),n}for(i in g._plots){s=g._plots[i],d=s.xaxis,m=s.yaxis;var nt=\"M0,0\";b(d,i)&&(B=w(d,\"left\",m,_),z=d._offset-(B?x+B:0),N=w(d,\"right\",m,_),D=d._offset+d._length+(N?x+N:0),R=T(d,m,\"bottom\"),F=T(d,m,\"top\"),!(Y=!d._anchorAxis||i!==d._mainSubplot)||\"allticks\"!==d.mirror&&\"all\"!==d.mirror||(d._linepositions[i]=[R,F]),nt=rt(d,Q,$),Y&&d.showline&&(\"all\"===d.mirror||\"allticks\"===d.mirror)&&(nt+=Q(R)+Q(F)),s.xlines.style(\"stroke-width\",d._lw+\"px\").call(l.stroke,d.showline?d.linecolor:\"rgba(0,0,0,0)\")),s.xlines.attr(\"d\",nt);var it=\"M0,0\";b(m,i)&&(H=w(m,\"bottom\",d,_),j=m._offset+m._length+(H?x:0),G=w(m,\"top\",d,_),U=m._offset-(G?x:0),V=T(m,d,\"left\"),q=T(m,d,\"right\"),!(Y=!m._anchorAxis||i!==m._mainSubplot)||\"allticks\"!==m.mirror&&\"all\"!==m.mirror||(m._linepositions[i]=[V,q]),it=rt(m,tt,et),Y&&m.showline&&(\"all\"===m.mirror||\"allticks\"===m.mirror)&&(it+=tt(V)+tt(q)),s.ylines.style(\"stroke-width\",m._lw+\"px\").call(l.stroke,m.showline?m.linecolor:\"rgba(0,0,0,0)\")),s.ylines.attr(\"d\",it)}return h.makeClipPaths(t),a.previousPromises(t)}function b(t,e){return(t.ticks||t.showline)&&(e===t._mainSubplot||\"all\"===t.mirror||\"allticks\"===t.mirror)}function _(t,e,r){if(!r.showline||!r._lw)return!1;if(\"all\"===r.mirror||\"allticks\"===r.mirror)return!0;var n=r._anchorAxis;if(!n)return!1;var i=p.FROM_BL[e];return r.side===e?n.domain[i]===t.domain[i]:r.mirror&&n.domain[1-i]===t.domain[1-i]}function w(t,e,r,n){if(_(t,e,r))return r._lw;for(var i=0;i<n.length;i++){var a=n[i];if(a._mainAxis===r._mainAxis&&_(t,e,a))return a._lw}return 0}function T(t,e){var r=t.title,n=t._size,i=0;switch(\"start\"===e?i=r.pad.l:\"end\"===e&&(i=-r.pad.r),r.xref){case\"paper\":return n.l+n.w*r.x+i;case\"container\":default:return t.width*r.x+i}}function k(t,e){var r=t.title,n=t._size,i=0;if(\"0em\"!==e&&e?e===p.CAP_SHIFT+\"em\"&&(i=r.pad.t):i=-r.pad.b,\"auto\"===r.y)return n.t/2;switch(r.yref){case\"paper\":return n.t+n.h-n.h*r.y+i;case\"container\":default:return t.height-t.height*r.y+i}}r.layoutStyles=function(t){return o.syncOrAsync([a.doAutoMargin,x],t)},r.drawMainTitle=function(t){var e=t._fullLayout,r=function(t){var e=t.title,r=\"middle\";o.isRightAnchor(e)?r=\"end\":o.isLeftAnchor(e)&&(r=\"start\");return r}(e),n=function(t){var e=t.title,r=\"0em\";o.isTopAnchor(e)?r=p.CAP_SHIFT+\"em\":o.isMiddleAnchor(e)&&(r=p.MID_SHIFT+\"em\");return r}(e);u.draw(t,\"gtitle\",{propContainer:e,propName:\"title.text\",placeholder:e._dfltTitle.plot,attributes:{x:T(e,r),y:k(e,n),\"text-anchor\":r,dy:n}})},r.doTraceStyle=function(t){var e,n=t.calcdata,o=[];for(e=0;e<n.length;e++){var l=n[e],c=l[0]||{},u=c.trace||{},f=u._module||{},h=f.arraysToCalcdata;h&&h(l,u);var p=f.editStyle;p&&o.push({fn:p,cd0:c})}if(o.length){for(e=0;e<o.length;e++){var d=o[e];d.fn(t,d.cd0)}s(t),r.redrawReglTraces(t)}return a.style(t),i.getComponentMethod(\"legend\",\"draw\")(t),a.previousPromises(t)},r.doColorBars=function(t){return i.getComponentMethod(\"colorbar\",\"draw\")(t),a.previousPromises(t)},r.layoutReplot=function(t){var e=t.layout;return t.layout=void 0,i.call(\"_doPlot\",t,\"\",e)},r.doLegend=function(t){return i.getComponentMethod(\"legend\",\"draw\")(t),a.previousPromises(t)},r.doTicksRelayout=function(t){return h.draw(t,\"redraw\"),t._fullLayout._hasOnlyLargeSploms&&(i.subplotsRegistry.splom.updateGrid(t),s(t),r.redrawReglTraces(t)),r.drawMainTitle(t),a.previousPromises(t)},r.doModeBar=function(t){var e=t._fullLayout;f.manage(t);for(var r=0;r<e._basePlotModules.length;r++){var n=e._basePlotModules[r].updateFx;n&&n(t)}return a.previousPromises(t)},r.doCamera=function(t){for(var e=t._fullLayout,r=e._subplots.gl3d,n=0;n<r.length;n++){var i=e[r[n]];i._scene.setViewport(i)}},r.drawData=function(t){var e=t._fullLayout;s(t);for(var n=e._basePlotModules,o=0;o<n.length;o++)n[o].plot(t);return r.redrawReglTraces(t),a.style(t),i.getComponentMethod(\"shapes\",\"draw\")(t),i.getComponentMethod(\"annotations\",\"draw\")(t),i.getComponentMethod(\"images\",\"draw\")(t),e._replotting=!1,a.previousPromises(t)},r.redrawReglTraces=function(t){var e=t._fullLayout;if(e._has(\"regl\")){var r,n,i=t._fullData,a=[],s=[];for(e._hasOnlyLargeSploms&&e._splomGrid.draw(),r=0;r<i.length;r++){var l=i[r];!0===l.visible&&0!==l._length&&(\"splom\"===l.type?e._splomScenes[l.uid].draw():\"scattergl\"===l.type?o.pushUnique(a,l.xaxis+l.yaxis):\"scatterpolargl\"===l.type&&o.pushUnique(s,l.subplot))}for(r=0;r<a.length;r++)(n=e._plots[a[r]])._scene&&n._scene.draw();for(r=0;r<s.length;r++)(n=e[s[r]]._subplot)._scene&&n._scene.draw()}},r.doAutoRangeAndConstraints=function(t){for(var e,r=h.list(t,\"\",!0),n={},i=0;i<r.length;i++)if(!n[(e=r[i])._id]){n[e._id]=1,g(t,e),v(t,e);var a=e._matchGroup;if(a)for(var o in a){var s=h.getFromId(t,o);v(t,s,e.range),n[o]=1}}m(t)},r.finalDraw=function(t){i.getComponentMethod(\"rangeslider\",\"draw\")(t),i.getComponentMethod(\"rangeselector\",\"draw\")(t)},r.drawMarginPushers=function(t){i.getComponentMethod(\"legend\",\"draw\")(t),i.getComponentMethod(\"rangeselector\",\"draw\")(t),i.getComponentMethod(\"sliders\",\"draw\")(t),i.getComponentMethod(\"updatemenus\",\"draw\")(t),i.getComponentMethod(\"colorbar\",\"draw\")(t)}},{\"../components/color\":662,\"../components/drawing\":684,\"../components/modebar\":725,\"../components/titles\":760,\"../constants/alignment\":767,\"../lib\":799,\"../lib/clear_gl_canvases\":783,\"../plots/cartesian/autorange\":848,\"../plots/cartesian/axes\":849,\"../plots/cartesian/constraints\":857,\"../plots/plots\":913,\"../registry\":927,\"@plotly/d3\":58}],840:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=n.isPlainObject,a=t(\"./plot_schema\"),o=t(\"../plots/plots\"),s=t(\"../plots/attributes\"),l=t(\"./plot_template\"),c=t(\"./plot_config\").dfltConfig;function u(t,e){t=n.extendDeep({},t);var r,a,o=Object.keys(t).sort();function s(e,r,n){if(i(r)&&i(e))u(e,r);else if(Array.isArray(r)&&Array.isArray(e)){var o=l.arrayTemplater({_template:t},n);for(a=0;a<r.length;a++){var s=r[a],c=o.newItem(s)._template;c&&u(c,s)}var f=o.defaultItems();for(a=0;a<f.length;a++)r.push(f[a]._template);for(a=0;a<r.length;a++)delete r[a].templateitemname}}for(r=0;r<o.length;r++){var c=o[r],h=t[c];if(c in e?s(h,e[c],c):e[c]=h,f(c)===c)for(var p in e){var d=f(p);p===d||d!==c||p in t||s(h,e[p],c)}}}function f(t){return t.replace(/[0-9]+$/,\"\")}function h(t,e,r,a,o){var s=o&&r(o);for(var c in t){var u=t[c],p=m(t,c,a),d=m(t,c,o),g=r(d);if(!g){var v=f(c);v!==c&&(g=r(d=m(t,v,o)))}if((!s||s!==g)&&!(!g||g._noTemplating||\"data_array\"===g.valType||g.arrayOk&&Array.isArray(u)))if(!g.valType&&i(u))h(u,e,r,p,d);else if(g._isLinkedToArray&&Array.isArray(u))for(var y=!1,x=0,b={},_=0;_<u.length;_++){var w=u[_];if(i(w)){var T=w.name;if(T)b[T]||(h(w,e,r,m(u,x,p),m(u,x,d)),x++,b[T]=1);else if(!y){var k=m(t,l.arrayDefaultKey(c),a),M=m(u,x,p);h(w,e,r,M,m(u,x,d));var A=n.nestedProperty(e,M);n.nestedProperty(e,k).set(A.get()),A.set(null),y=!0}}}else{n.nestedProperty(e,p).set(u)}}}function p(t,e){return a.getLayoutValObject(t,n.nestedProperty({},e).parts)}function d(t,e){return a.getTraceValObject(t,n.nestedProperty({},e).parts)}function m(t,e,r){return r?Array.isArray(t)?r+\"[\"+e+\"]\":r+\".\"+e:e}function g(t){for(var e=0;e<t.length;e++)if(i(t[e]))return!0}function v(t){var e;switch(t.code){case\"data\":e=\"The template has no key data.\";break;case\"layout\":e=\"The template has no key layout.\";break;case\"missing\":e=t.path?\"There are no templates for item \"+t.path+\" with name \"+t.templateitemname:\"There are no templates for trace \"+t.index+\", of type \"+t.traceType+\".\";break;case\"unused\":e=t.path?\"The template item at \"+t.path+\" was not used in constructing the plot.\":t.dataCount?\"Some of the templates of type \"+t.traceType+\" were not used. The template has \"+t.templateCount+\" traces, the data only has \"+t.dataCount+\" of this type.\":\"The template has \"+t.templateCount+\" traces of type \"+t.traceType+\" but there are none in the data.\";break;case\"reused\":e=\"Some of the templates of type \"+t.traceType+\" were used more than once. The template has \"+t.templateCount+\" traces, the data has \"+t.dataCount+\" of this type.\"}return t.msg=e,t}r.makeTemplate=function(t){t=n.isPlainObject(t)?t:n.getGraphDiv(t),t=n.extendDeep({_context:c},{data:t.data,layout:t.layout}),o.supplyDefaults(t);var e=t.data||[],r=t.layout||{};r._basePlotModules=t._fullLayout._basePlotModules,r._modules=t._fullLayout._modules;var a={data:{},layout:{}};e.forEach((function(t){var e={};h(t,e,d.bind(null,t));var r=n.coerce(t,{},s,\"type\"),i=a.data[r];i||(i=a.data[r]=[]),i.push(e)})),h(r,a.layout,p.bind(null,r)),delete a.layout.template;var l=r.template;if(i(l)){var f,m,g,v,y,x,b=l.layout;i(b)&&u(b,a.layout);var _=l.data;if(i(_)){for(m in a.data)if(g=_[m],Array.isArray(g)){for(x=(y=a.data[m]).length,v=g.length,f=0;f<x;f++)u(g[f%v],y[f]);for(f=x;f<v;f++)y.push(n.extendDeep({},g[f]))}for(m in _)m in a.data||(a.data[m]=n.extendDeep([],_[m]))}}return a},r.validateTemplate=function(t,e){var r=n.extendDeep({},{_context:c,data:t.data,layout:t.layout}),a=r.layout||{};i(e)||(e=a.template||{});var s=e.layout,l=e.data,u=[];r.layout=a,r.layout.template=e,o.supplyDefaults(r);var h=r._fullLayout,p=r._fullData,d={};if(i(s)?(!function t(e,r){for(var n in e)if(\"_\"!==n.charAt(0)&&i(e[n])){var a,o=f(n),s=[];for(a=0;a<r.length;a++)s.push(m(e,n,r[a])),o!==n&&s.push(m(e,o,r[a]));for(a=0;a<s.length;a++)d[s[a]]=1;t(e[n],s)}}(h,[\"layout\"]),function t(e,r){for(var n in e)if(-1===n.indexOf(\"defaults\")&&i(e[n])){var a=m(e,n,r);d[a]?t(e[n],a):u.push({code:\"unused\",path:a})}}(s,\"layout\")):u.push({code:\"layout\"}),i(l)){for(var y,x={},b=0;b<p.length;b++){var _=p[b];x[y=_.type]=(x[y]||0)+1,_._fullInput._template||u.push({code:\"missing\",index:_._fullInput.index,traceType:y})}for(y in l){var w=l[y].length,T=x[y]||0;w>T?u.push({code:\"unused\",traceType:y,templateCount:w,dataCount:T}):T>w&&u.push({code:\"reused\",traceType:y,templateCount:w,dataCount:T})}}else u.push({code:\"data\"});if(function t(e,r){for(var n in e)if(\"_\"!==n.charAt(0)){var a=e[n],o=m(e,n,r);i(a)?(Array.isArray(e)&&!1===a._template&&a.templateitemname&&u.push({code:\"missing\",path:o,templateitemname:a.templateitemname}),t(a,o)):Array.isArray(a)&&g(a)&&t(a,o)}}({data:p,layout:h},\"\"),u.length)return u.map(v)}},{\"../lib\":799,\"../plots/attributes\":845,\"../plots/plots\":913,\"./plot_config\":836,\"./plot_schema\":837,\"./plot_template\":838}],841:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"./plot_api\"),a=t(\"../plots/plots\"),o=t(\"../lib\"),s=t(\"../snapshot/helpers\"),l=t(\"../snapshot/tosvg\"),c=t(\"../snapshot/svgtoimg\"),u=t(\"../version\").version,f={format:{valType:\"enumerated\",values:[\"png\",\"jpeg\",\"webp\",\"svg\",\"full-json\"],dflt:\"png\"},width:{valType:\"number\",min:1},height:{valType:\"number\",min:1},scale:{valType:\"number\",min:0,dflt:1},setBackground:{valType:\"any\",dflt:!1},imageDataOnly:{valType:\"boolean\",dflt:!1}};e.exports=function(t,e){var r,h,p,d;function m(t){return!(t in e)||o.validate(e[t],f[t])}if(e=e||{},o.isPlainObject(t)?(r=t.data||[],h=t.layout||{},p=t.config||{},d={}):(t=o.getGraphDiv(t),r=o.extendDeep([],t.data),h=o.extendDeep({},t.layout),p=t._context,d=t._fullLayout||{}),!m(\"width\")&&null!==e.width||!m(\"height\")&&null!==e.height)throw new Error(\"Height and width should be pixel values.\");if(!m(\"format\"))throw new Error(\"Export format is not \"+o.join2(f.format.values,\", \",\" or \")+\".\");var g={};function v(t,r){return o.coerce(e,g,f,t,r)}var y=v(\"format\"),x=v(\"width\"),b=v(\"height\"),_=v(\"scale\"),w=v(\"setBackground\"),T=v(\"imageDataOnly\"),k=document.createElement(\"div\");k.style.position=\"absolute\",k.style.left=\"-5000px\",document.body.appendChild(k);var M=o.extendFlat({},h);x?M.width=x:null===e.width&&n(d.width)&&(M.width=d.width),b?M.height=b:null===e.height&&n(d.height)&&(M.height=d.height);var A=o.extendFlat({},p,{_exportedPlot:!0,staticPlot:!0,setBackground:w}),S=s.getRedrawFunc(k);function E(){return new Promise((function(t){setTimeout(t,s.getDelay(k._fullLayout))}))}function L(){return new Promise((function(t,e){var r=l(k,y,_),n=k._fullLayout.width,f=k._fullLayout.height;function h(){i.purge(k),document.body.removeChild(k)}if(\"full-json\"===y){var p=a.graphJson(k,!1,\"keepdata\",\"object\",!0,!0);return p.version=u,p=JSON.stringify(p),h(),t(T?p:s.encodeJSON(p))}if(h(),\"svg\"===y)return t(T?r:s.encodeSVG(r));var d=document.createElement(\"canvas\");d.id=o.randstr(),c({format:y,width:n,height:f,scale:_,canvas:d,svg:r,promise:!0}).then(t).catch(e)}))}return new Promise((function(t,e){i.newPlot(k,r,M,A).then(S).then(E).then(L).then((function(e){t(function(t){return T?t.replace(s.IMAGE_URL_PREFIX,\"\"):t}(e))})).catch((function(t){e(t)}))}))}},{\"../lib\":799,\"../plots/plots\":913,\"../snapshot/helpers\":931,\"../snapshot/svgtoimg\":933,\"../snapshot/tosvg\":935,\"../version\":1400,\"./plot_api\":835,\"fast-isnumeric\":245}],842:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"../plots/plots\"),a=t(\"./plot_schema\"),o=t(\"./plot_config\").dfltConfig,s=n.isPlainObject,l=Array.isArray,c=n.isArrayOrTypedArray;function u(t,e,r,i,a,o){o=o||[];for(var f=Object.keys(t),h=0;h<f.length;h++){var p=f[h];if(\"transforms\"!==p){var v=o.slice();v.push(p);var y=t[p],x=e[p],b=g(r,p),_=(b||{}).valType,w=\"info_array\"===_,T=\"colorscale\"===_,k=(b||{}).items;if(m(r,p))if(s(y)&&s(x)&&\"any\"!==_)u(y,x,b,i,a,v);else if(w&&l(y)){y.length>x.length&&i.push(d(\"unused\",a,v.concat(x.length)));var M,A,S,E,L,C=x.length,P=Array.isArray(k);if(P&&(C=Math.min(C,k.length)),2===b.dimensions)for(A=0;A<C;A++)if(l(y[A])){y[A].length>x[A].length&&i.push(d(\"unused\",a,v.concat(A,x[A].length)));var I=x[A].length;for(M=0;M<(P?Math.min(I,k[A].length):I);M++)S=P?k[A][M]:k,E=y[A][M],L=x[A][M],n.validate(E,S)?L!==E&&L!==+E&&i.push(d(\"dynamic\",a,v.concat(A,M),E,L)):i.push(d(\"value\",a,v.concat(A,M),E))}else i.push(d(\"array\",a,v.concat(A),y[A]));else for(A=0;A<C;A++)S=P?k[A]:k,E=y[A],L=x[A],n.validate(E,S)?L!==E&&L!==+E&&i.push(d(\"dynamic\",a,v.concat(A),E,L)):i.push(d(\"value\",a,v.concat(A),E))}else if(b.items&&!w&&l(y)){var O,z,D=k[Object.keys(k)[0]],R=[];for(O=0;O<x.length;O++){var F=x[O]._index||O;if((z=v.slice()).push(F),s(y[F])&&s(x[O])){R.push(F);var B=y[F],N=x[O];s(B)&&!1!==B.visible&&!1===N.visible?i.push(d(\"invisible\",a,z)):u(B,N,D,i,a,z)}}for(O=0;O<y.length;O++)(z=v.slice()).push(O),s(y[O])?-1===R.indexOf(O)&&i.push(d(\"unused\",a,z)):i.push(d(\"object\",a,z,y[O]))}else!s(y)&&s(x)?i.push(d(\"object\",a,v,y)):c(y)||!c(x)||w||T?p in e?n.validate(y,b)?\"enumerated\"===b.valType&&(b.coerceNumber&&y!==+x||y!==x)&&i.push(d(\"dynamic\",a,v,y,x)):i.push(d(\"value\",a,v,y)):i.push(d(\"unused\",a,v,y)):i.push(d(\"array\",a,v,y));else i.push(d(\"schema\",a,v))}}return i}function f(t,e){for(var r=t.layout.layoutAttributes,i=0;i<e.length;i++){var a=e[i],o=t.traces[a.type],s=o.layoutAttributes;s&&(a.subplot?n.extendFlat(r[o.attributes.subplot.dflt],s):n.extendFlat(r,s))}return r}e.exports=function(t,e){void 0===t&&(t=[]),void 0===e&&(e={});var r,c,h=a.get(),p=[],m={_context:n.extendFlat({},o)};l(t)?(m.data=n.extendDeep([],t),r=t):(m.data=[],r=[],p.push(d(\"array\",\"data\"))),s(e)?(m.layout=n.extendDeep({},e),c=e):(m.layout={},c={},arguments.length>1&&p.push(d(\"object\",\"layout\"))),i.supplyDefaults(m);for(var g=m._fullData,v=r.length,y=0;y<v;y++){var x=r[y],b=[\"data\",y];if(s(x)){var _=g[y],w=_.type,T=h.traces[w].attributes;T.type={valType:\"enumerated\",values:[w]},!1===_.visible&&!1!==x.visible&&p.push(d(\"invisible\",b)),u(x,_,T,p,b);var k=x.transforms,M=_.transforms;if(k){l(k)||p.push(d(\"array\",b,[\"transforms\"])),b.push(\"transforms\");for(var A=0;A<k.length;A++){var S=[\"transforms\",A],E=k[A].type;if(s(k[A])){var L=h.transforms[E]?h.transforms[E].attributes:{};L.type={valType:\"enumerated\",values:Object.keys(h.transforms)},u(k[A],M[A],L,p,b,S)}else p.push(d(\"object\",b,S))}}}else p.push(d(\"object\",b))}var C=m._fullLayout,P=f(h,g);return u(c,C,P,p,\"layout\"),0===p.length?void 0:p};var h={object:function(t,e){return(\"layout\"===t&&\"\"===e?\"The layout argument\":\"data\"===t[0]&&\"\"===e?\"Trace \"+t[1]+\" in the data argument\":p(t)+\"key \"+e)+\" must be linked to an object container\"},array:function(t,e){return(\"data\"===t?\"The data argument\":p(t)+\"key \"+e)+\" must be linked to an array container\"},schema:function(t,e){return p(t)+\"key \"+e+\" is not part of the schema\"},unused:function(t,e,r){var n=s(r)?\"container\":\"key\";return p(t)+n+\" \"+e+\" did not get coerced\"},dynamic:function(t,e,r,n){return[p(t)+\"key\",e,\"(set to '\"+r+\"')\",\"got reset to\",\"'\"+n+\"'\",\"during defaults.\"].join(\" \")},invisible:function(t,e){return(e?p(t)+\"item \"+e:\"Trace \"+t[1])+\" got defaulted to be not visible\"},value:function(t,e,r){return[p(t)+\"key \"+e,\"is set to an invalid value (\"+r+\")\"].join(\" \")}};function p(t){return l(t)?\"In data trace \"+t[1]+\", \":\"In \"+t+\", \"}function d(t,e,r,i,a){var o,s;r=r||\"\",l(e)?(o=e[0],s=e[1]):(o=e,s=null);var c=function(t){if(!l(t))return String(t);for(var e=\"\",r=0;r<t.length;r++){var n=t[r];\"number\"==typeof n?e=e.substr(0,e.length-1)+\"[\"+n+\"]\":e+=n,r<t.length-1&&(e+=\".\")}return e}(r),u=h[t](e,c,i,a);return n.log(u),{code:t,container:o,trace:s,path:r,astr:c,msg:u}}function m(t,e){var r=y(e),n=r.keyMinusId,i=r.id;return!!(n in t&&t[n]._isSubplotObj&&i)||e in t}function g(t,e){return e in t?t[e]:t[y(e).keyMinusId]}var v=n.counterRegex(\"([a-z]+)\");function y(t){var e=t.match(v);return{keyMinusId:e&&e[1],id:e&&e[2]}}},{\"../lib\":799,\"../plots/plots\":913,\"./plot_config\":836,\"./plot_schema\":837}],843:[function(t,e,r){\"use strict\";e.exports={mode:{valType:\"enumerated\",dflt:\"afterall\",values:[\"immediate\",\"next\",\"afterall\"]},direction:{valType:\"enumerated\",values:[\"forward\",\"reverse\"],dflt:\"forward\"},fromcurrent:{valType:\"boolean\",dflt:!1},frame:{duration:{valType:\"number\",min:0,dflt:500},redraw:{valType:\"boolean\",dflt:!0}},transition:{duration:{valType:\"number\",min:0,dflt:500,editType:\"none\"},easing:{valType:\"enumerated\",dflt:\"cubic-in-out\",values:[\"linear\",\"quad\",\"cubic\",\"sin\",\"exp\",\"circle\",\"elastic\",\"back\",\"bounce\",\"linear-in\",\"quad-in\",\"cubic-in\",\"sin-in\",\"exp-in\",\"circle-in\",\"elastic-in\",\"back-in\",\"bounce-in\",\"linear-out\",\"quad-out\",\"cubic-out\",\"sin-out\",\"exp-out\",\"circle-out\",\"elastic-out\",\"back-out\",\"bounce-out\",\"linear-in-out\",\"quad-in-out\",\"cubic-in-out\",\"sin-in-out\",\"exp-in-out\",\"circle-in-out\",\"elastic-in-out\",\"back-in-out\",\"bounce-in-out\"],editType:\"none\"},ordering:{valType:\"enumerated\",values:[\"layout first\",\"traces first\"],dflt:\"layout first\",editType:\"none\"}}}},{}],844:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"../plot_api/plot_template\");e.exports=function(t,e,r){var a,o,s=r.name,l=r.inclusionAttr||\"visible\",c=e[s],u=n.isArrayOrTypedArray(t[s])?t[s]:[],f=e[s]=[],h=i.arrayTemplater(e,s,l);for(a=0;a<u.length;a++){var p=u[a];n.isPlainObject(p)?o=h.newItem(p):(o=h.newItem({}))[l]=!1,o._index=a,!1!==o[l]&&r.handleItemDefaults(p,o,e,r),f.push(o)}var d=h.defaultItems();for(a=0;a<d.length;a++)(o=d[a])._index=f.length,r.handleItemDefaults({},o,e,r,{}),f.push(o);if(n.isArrayOrTypedArray(c)){var m=Math.min(c.length,f.length);for(a=0;a<m;a++)n.relinkPrivateKeys(f[a],c[a])}return f}},{\"../lib\":799,\"../plot_api/plot_template\":838}],845:[function(t,e,r){\"use strict\";var n=t(\"./font_attributes\"),i=t(\"../components/fx/attributes\");e.exports={type:{valType:\"enumerated\",values:[],dflt:\"scatter\",editType:\"calc+clearAxisTypes\",_noTemplating:!0},visible:{valType:\"enumerated\",values:[!0,!1,\"legendonly\"],dflt:!0,editType:\"calc\"},showlegend:{valType:\"boolean\",dflt:!0,editType:\"style\"},legendgroup:{valType:\"string\",dflt:\"\",editType:\"style\"},legendgrouptitle:{text:{valType:\"string\",dflt:\"\",editType:\"style\"},font:n({editType:\"style\"}),editType:\"style\"},legendrank:{valType:\"number\",dflt:1e3,editType:\"style\"},opacity:{valType:\"number\",min:0,max:1,dflt:1,editType:\"style\"},name:{valType:\"string\",editType:\"style\"},uid:{valType:\"string\",editType:\"plot\",anim:!0},ids:{valType:\"data_array\",editType:\"calc\",anim:!0},customdata:{valType:\"data_array\",editType:\"calc\"},meta:{valType:\"any\",arrayOk:!0,editType:\"plot\"},selectedpoints:{valType:\"any\",editType:\"calc\"},hoverinfo:{valType:\"flaglist\",flags:[\"x\",\"y\",\"z\",\"text\",\"name\"],extras:[\"all\",\"none\",\"skip\"],arrayOk:!0,dflt:\"all\",editType:\"none\"},hoverlabel:i.hoverlabel,stream:{token:{valType:\"string\",noBlank:!0,strict:!0,editType:\"calc\"},maxpoints:{valType:\"number\",min:0,max:1e4,dflt:500,editType:\"calc\"},editType:\"calc\"},transforms:{_isLinkedToArray:\"transform\",editType:\"calc\"},uirevision:{valType:\"any\",editType:\"none\"}}},{\"../components/fx/attributes\":693,\"./font_attributes\":878}],846:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=i.dateTime2ms,o=i.incrementMonth,s=t(\"../../constants/numerical\").ONEAVGMONTH;e.exports=function(t,e,r,i){if(\"date\"!==e.type)return i;var l=t[r+\"periodalignment\"];if(!l)return i;var c,u=t[r+\"period\"];if(n(u)){if((u=+u)<=0)return i}else if(\"string\"==typeof u&&\"M\"===u.charAt(0)){var f=+u.substring(1);if(!(f>0&&Math.round(f)===f))return i;c=f}for(var h=e.calendar,p=\"start\"===l,d=\"end\"===l,m=t[r+\"period0\"],g=a(m,h)||0,v=[],y=i.length,x=0;x<y;x++){var b,_,w,T=i[x];if(c){for(b=Math.round((T-g)/(c*s)),w=o(g,c*b,h);w>T;)w=o(w,-c,h);for(;w<=T;)w=o(w,c,h);_=o(w,-c,h)}else{for(w=g+(b=Math.round((T-g)/u))*u;w>T;)w-=u;for(;w<=T;)w+=u;_=w-u}v[x]=p?_:d?w:(_+w)/2}return v}},{\"../../constants/numerical\":775,\"../../lib\":799,\"fast-isnumeric\":245}],847:[function(t,e,r){\"use strict\";e.exports={xaxis:{valType:\"subplotid\",dflt:\"x\",editType:\"calc+clearAxisTypes\"},yaxis:{valType:\"subplotid\",dflt:\"y\",editType:\"calc+clearAxisTypes\"}}},{}],848:[function(t,e,r){\"use strict\";var n=t(\"@plotly/d3\"),i=t(\"fast-isnumeric\"),a=t(\"../../lib\"),o=t(\"../../constants/numerical\").FP_SAFE,s=t(\"../../registry\"),l=t(\"../../components/drawing\"),c=t(\"./axis_ids\"),u=c.getFromId,f=c.isLinked;function h(t,e){var r,n,i=[],o=t._fullLayout,s=d(o,e,0),l=d(o,e,1),c=m(t,e),u=c.min,f=c.max;if(0===u.length||0===f.length)return a.simpleMap(e.range,e.r2l);var h=u[0].val,g=f[0].val;for(r=1;r<u.length&&h===g;r++)h=Math.min(h,u[r].val);for(r=1;r<f.length&&h===g;r++)g=Math.max(g,f[r].val);var v=!1;if(e.range){var y=a.simpleMap(e.range,e.r2l);v=y[1]<y[0]}\"reversed\"===e.autorange&&(v=!0,e.autorange=!0);var x,b,_,w,T,k,M=e.rangemode,A=\"tozero\"===M,S=\"nonnegative\"===M,E=e._length,L=E/10,C=0;for(r=0;r<u.length;r++)for(x=u[r],n=0;n<f.length;n++)(k=(b=f[n]).val-x.val-p(e,x.val,b.val))>0&&((T=E-s(x)-l(b))>L?k/T>C&&(_=x,w=b,C=k/T):k/E>C&&(_={val:x.val,nopad:1},w={val:b.val,nopad:1},C=k/E));if(h===g){var P=h-1,I=h+1;if(A)if(0===h)i=[0,1];else{var O=(h>0?f:u).reduce((function(t,e){return Math.max(t,l(e))}),0),z=h/(1-Math.min(.5,O/E));i=h>0?[0,z]:[z,0]}else i=S?[Math.max(0,P),Math.max(1,I)]:[P,I]}else A?(_.val>=0&&(_={val:0,nopad:1}),w.val<=0&&(w={val:0,nopad:1})):S&&(_.val-C*s(_)<0&&(_={val:0,nopad:1}),w.val<=0&&(w={val:1,nopad:1})),C=(w.val-_.val-p(e,x.val,b.val))/(E-s(_)-l(w)),i=[_.val-C*s(_),w.val+C*l(w)];return v&&i.reverse(),a.simpleMap(i,e.l2r||Number)}function p(t,e,r){var n=0;if(t.rangebreaks)for(var i=t.locateBreaks(e,r),a=0;a<i.length;a++){var o=i[a];n+=o.max-o.min}return n}function d(t,e,r){var i=.05*e._length,o=e._anchorAxis||{};if(-1!==(e.ticklabelposition||\"\").indexOf(\"inside\")||-1!==(o.ticklabelposition||\"\").indexOf(\"inside\")){var s=\"reversed\"===e.autorange;if(!s){var c=a.simpleMap(e.range,e.r2l);s=c[1]<c[0]}s&&(r=!r)}var u=0;return f(t,e._id)||(u=function(t,e,r){var i=0,o=\"x\"===e._id.charAt(0);for(var s in t._plots){var c=t._plots[s];if(e._id===c.xaxis._id||e._id===c.yaxis._id){var u=(o?c.yaxis:c.xaxis)||{};if(-1!==(u.ticklabelposition||\"\").indexOf(\"inside\")&&(!r&&(\"left\"===u.side||\"bottom\"===u.side)||r&&(\"top\"===u.side||\"right\"===u.side))){if(u._vals){var f=a.deg2rad(u._tickAngles[u._id+\"tick\"]||0),h=Math.abs(Math.cos(f)),p=Math.abs(Math.sin(f));if(!u._vals[0].bb){var d=u._id+\"tick\";u._selections[d].each((function(t){var e=n.select(this);e.select(\".text-math-group\").empty()&&(t.bb=l.bBox(e.node()))}))}for(var m=0;m<u._vals.length;m++){var g=u._vals[m].bb;if(g){var v=6+g.width,y=6+g.height;i=Math.max(i,o?Math.max(v*h,y*p):Math.max(y*h,v*p))}}}\"inside\"===u.ticks&&\"inside\"===u.ticklabelposition&&(i+=u.ticklen||0)}}}return i}(t,e,r)),i=Math.max(u,i),\"domain\"===e.constrain&&e._inputDomain&&(i*=(e._inputDomain[1]-e._inputDomain[0])/(e.domain[1]-e.domain[0])),function(t){return t.nopad?0:t.pad+(t.extrapad?i:u)}}e.exports={getAutoRange:h,makePadFn:d,doAutoRange:function(t,e,r){if(e.setScale(),e.autorange){e.range=r?r.slice():h(t,e),e._r=e.range.slice(),e._rl=a.simpleMap(e._r,e.r2l);var n=e._input,i={};i[e._attr+\".range\"]=e.range,i[e._attr+\".autorange\"]=e.autorange,s.call(\"_storeDirectGUIEdit\",t.layout,t._fullLayout._preGUI,i),n.range=e.range.slice(),n.autorange=e.autorange}var o=e._anchorAxis;if(o&&o.rangeslider){var l=o.rangeslider[e._name];l&&\"auto\"===l.rangemode&&(l.range=h(t,e)),o._input.rangeslider[e._name]=a.extendFlat({},l)}},findExtremes:function(t,e,r){r||(r={});t._m||t.setScale();var n,a,s,l,c,u,f,h,p,d=[],m=[],y=e.length,b=r.padded||!1,_=r.tozero&&(\"linear\"===t.type||\"-\"===t.type),w=\"log\"===t.type,T=!1,k=r.vpadLinearized||!1;function M(t){if(Array.isArray(t))return T=!0,function(e){return Math.max(Number(t[e]||0),0)};var e=Math.max(Number(t||0),0);return function(){return e}}var A=M((t._m>0?r.ppadplus:r.ppadminus)||r.ppad||0),S=M((t._m>0?r.ppadminus:r.ppadplus)||r.ppad||0),E=M(r.vpadplus||r.vpad),L=M(r.vpadminus||r.vpad);if(!T){if(h=1/0,p=-1/0,w)for(n=0;n<y;n++)(a=e[n])<h&&a>0&&(h=a),a>p&&a<o&&(p=a);else for(n=0;n<y;n++)(a=e[n])<h&&a>-o&&(h=a),a>p&&a<o&&(p=a);e=[h,p],y=2}var C={tozero:_,extrapad:b};function P(r){s=e[r],i(s)&&(u=A(r),f=S(r),k?(l=t.c2l(s)-L(r),c=t.c2l(s)+E(r)):(h=s-L(r),p=s+E(r),w&&h<p/10&&(h=p/10),l=t.c2l(h),c=t.c2l(p)),_&&(l=Math.min(0,l),c=Math.max(0,c)),x(l)&&g(d,l,f,C),x(c)&&v(m,c,u,C))}var I=Math.min(6,y);for(n=0;n<I;n++)P(n);for(n=y-1;n>=I;n--)P(n);return{min:d,max:m,opts:r}},concatExtremes:m};function m(t,e,r){var n,i,a,o=e._id,s=t._fullData,l=t._fullLayout,c=[],f=[];function h(t,e){for(n=0;n<e.length;n++){var r=t[e[n]],s=(r._extremes||{})[o];if(!0===r.visible&&s){for(i=0;i<s.min.length;i++)a=s.min[i],g(c,a.val,a.pad,{extrapad:a.extrapad});for(i=0;i<s.max.length;i++)a=s.max[i],v(f,a.val,a.pad,{extrapad:a.extrapad})}}}if(h(s,e._traceIndices),h(l.annotations||[],e._annIndices||[]),h(l.shapes||[],e._shapeIndices||[]),e._matchGroup&&!r)for(var p in e._matchGroup)if(p!==e._id){var d=u(t,p),y=m(t,d,!0),x=e._length/d._length;for(i=0;i<y.min.length;i++)a=y.min[i],g(c,a.val,a.pad*x,{extrapad:a.extrapad});for(i=0;i<y.max.length;i++)a=y.max[i],v(f,a.val,a.pad*x,{extrapad:a.extrapad})}return{min:c,max:f}}function g(t,e,r,n){y(t,e,r,n,b)}function v(t,e,r,n){y(t,e,r,n,_)}function y(t,e,r,n,i){for(var a=n.tozero,o=n.extrapad,s=!0,l=0;l<t.length&&s;l++){var c=t[l];if(i(c.val,e)&&c.pad>=r&&(c.extrapad||!o)){s=!1;break}i(e,c.val)&&c.pad<=r&&(o||!c.extrapad)&&(t.splice(l,1),l--)}if(s){var u=a&&0===e;t.push({val:e,pad:u?0:r,extrapad:!u&&o})}}function x(t){return i(t)&&Math.abs(t)<o}function b(t,e){return t<=e}function _(t,e){return t>=e}},{\"../../components/drawing\":684,\"../../constants/numerical\":775,\"../../lib\":799,\"../../registry\":927,\"./axis_ids\":853,\"@plotly/d3\":58,\"fast-isnumeric\":245}],849:[function(t,e,r){\"use strict\";var n=t(\"@plotly/d3\"),i=t(\"fast-isnumeric\"),a=t(\"../../plots/plots\"),o=t(\"../../registry\"),s=t(\"../../lib\"),l=s.strTranslate,c=t(\"../../lib/svg_text_utils\"),u=t(\"../../components/titles\"),f=t(\"../../components/color\"),h=t(\"../../components/drawing\"),p=t(\"./layout_attributes\"),d=t(\"./clean_ticks\"),m=t(\"../../constants/numerical\"),g=m.ONEMAXYEAR,v=m.ONEAVGYEAR,y=m.ONEMINYEAR,x=m.ONEMAXQUARTER,b=m.ONEAVGQUARTER,_=m.ONEMINQUARTER,w=m.ONEMAXMONTH,T=m.ONEAVGMONTH,k=m.ONEMINMONTH,M=m.ONEWEEK,A=m.ONEDAY,S=A/2,E=m.ONEHOUR,L=m.ONEMIN,C=m.ONESEC,P=m.MINUS_SIGN,I=m.BADNUM,O={K:\"zeroline\"},z={K:\"gridline\",L:\"path\"},D={K:\"tick\",L:\"path\"},R={K:\"tick\",L:\"text\"},F=t(\"../../constants/alignment\"),B=F.MID_SHIFT,N=F.CAP_SHIFT,j=F.LINE_SPACING,U=F.OPPOSITE_SIDE,V=e.exports={};V.setConvert=t(\"./set_convert\");var q=t(\"./axis_autotype\"),H=t(\"./axis_ids\"),G=H.idSort,Y=H.isLinked;V.id2name=H.id2name,V.name2id=H.name2id,V.cleanId=H.cleanId,V.list=H.list,V.listIds=H.listIds,V.getFromId=H.getFromId,V.getFromTrace=H.getFromTrace;var W=t(\"./autorange\");V.getAutoRange=W.getAutoRange,V.findExtremes=W.findExtremes;function X(t){var e=1e-4*(t[1]-t[0]);return[t[0]-e,t[1]+e]}V.coerceRef=function(t,e,r,n,i,a){var o=n.charAt(n.length-1),l=r._fullLayout._subplots[o+\"axis\"],c=n+\"ref\",u={};return i||(i=l[0]||(\"string\"==typeof a?a:a[0])),a||(a=i),l=l.concat(l.map((function(t){return t+\" domain\"}))),u[c]={valType:\"enumerated\",values:l.concat(a?\"string\"==typeof a?[a]:a:[]),dflt:i},s.coerce(t,e,u,c)},V.getRefType=function(t){return void 0===t?t:\"paper\"===t?\"paper\":\"pixel\"===t?\"pixel\":/( domain)$/.test(t)?\"domain\":\"range\"},V.coercePosition=function(t,e,r,n,i,a){var o,l;if(\"range\"!==V.getRefType(n))o=s.ensureNumber,l=r(i,a);else{var c=V.getFromId(e,n);l=r(i,a=c.fraction2r(a)),o=c.cleanPos}t[i]=o(l)},V.cleanPosition=function(t,e,r){return(\"paper\"===r||\"pixel\"===r?s.ensureNumber:V.getFromId(e,r).cleanPos)(t)},V.redrawComponents=function(t,e){e=e||V.listIds(t);var r=t._fullLayout;function n(n,i,a,s){for(var l=o.getComponentMethod(n,i),c={},u=0;u<e.length;u++)for(var f=r[V.id2name(e[u])][a],h=0;h<f.length;h++){var p=f[h];if(!c[p]&&(l(t,p),c[p]=1,s))return}}n(\"annotations\",\"drawOne\",\"_annIndices\"),n(\"shapes\",\"drawOne\",\"_shapeIndices\"),n(\"images\",\"draw\",\"_imgIndices\",!0)};var Z=V.getDataConversions=function(t,e,r,n){var i,a=\"x\"===r||\"y\"===r||\"z\"===r?r:n;if(Array.isArray(a)){if(i={type:q(n,void 0,{autotypenumbers:t._fullLayout.autotypenumbers}),_categories:[]},V.setConvert(i),\"category\"===i.type)for(var o=0;o<n.length;o++)i.d2c(n[o])}else i=V.getFromTrace(t,e,a);return i?{d2c:i.d2c,c2d:i.c2d}:\"ids\"===a?{d2c:K,c2d:K}:{d2c:J,c2d:J}};function J(t){return+t}function K(t){return String(t)}function Q(t){return+t.substring(1)}V.getDataToCoordFunc=function(t,e,r,n){return Z(t,e,r,n).d2c},V.counterLetter=function(t){var e=t.charAt(0);return\"x\"===e?\"y\":\"y\"===e?\"x\":void 0},V.minDtick=function(t,e,r,n){-1===[\"log\",\"category\",\"multicategory\"].indexOf(t.type)&&n?void 0===t._minDtick?(t._minDtick=e,t._forceTick0=r):t._minDtick&&((t._minDtick/e+1e-6)%1<2e-6&&((r-t._forceTick0)/e%1+1.000001)%1<2e-6?(t._minDtick=e,t._forceTick0=r):((e/t._minDtick+1e-6)%1>2e-6||((r-t._forceTick0)/t._minDtick%1+1.000001)%1>2e-6)&&(t._minDtick=0)):t._minDtick=0},V.saveRangeInitial=function(t,e){for(var r=V.list(t,\"\",!0),n=!1,i=0;i<r.length;i++){var a=r[i],o=void 0===a._rangeInitial,s=o||!(a.range[0]===a._rangeInitial[0]&&a.range[1]===a._rangeInitial[1]);(o&&!1===a.autorange||e&&s)&&(a._rangeInitial=a.range.slice(),n=!0)}return n},V.saveShowSpikeInitial=function(t,e){for(var r=V.list(t,\"\",!0),n=!1,i=\"on\",a=0;a<r.length;a++){var o=r[a],s=void 0===o._showSpikeInitial,l=s||!(o.showspikes===o._showspikes);(s||e&&l)&&(o._showSpikeInitial=o.showspikes,n=!0),\"on\"!==i||o.showspikes||(i=\"off\")}return t._fullLayout._cartesianSpikesEnabled=i,n},V.autoBin=function(t,e,r,n,a,o){var l,c=s.aggNums(Math.min,null,t),u=s.aggNums(Math.max,null,t);if(\"category\"===e.type||\"multicategory\"===e.type)return{start:c-.5,end:u+.5,size:Math.max(1,Math.round(o)||1),_dataSpan:u-c};if(a||(a=e.calendar),l=\"log\"===e.type?{type:\"linear\",range:[c,u]}:{type:e.type,range:s.simpleMap([c,u],e.c2r,0,a),calendar:a},V.setConvert(l),o=o&&d.dtick(o,l.type))l.dtick=o,l.tick0=d.tick0(void 0,l.type,a);else{var f;if(r)f=(u-c)/r;else{var h=s.distinctVals(t),p=Math.pow(10,Math.floor(Math.log(h.minDiff)/Math.LN10)),m=p*s.roundUp(h.minDiff/p,[.9,1.9,4.9,9.9],!0);f=Math.max(m,2*s.stdev(t)/Math.pow(t.length,n?.25:.4)),i(f)||(f=1)}V.autoTicks(l,f)}var g,v=l.dtick,y=V.tickIncrement(V.tickFirst(l),v,\"reverse\",a);if(\"number\"==typeof v)g=(y=function(t,e,r,n,a){var o=0,s=0,l=0,c=0;function u(e){return(1+100*(e-t)/r.dtick)%100<2}for(var f=0;f<e.length;f++)e[f]%1==0?l++:i(e[f])||c++,u(e[f])&&o++,u(e[f]+r.dtick/2)&&s++;var h=e.length-c;if(l===h&&\"date\"!==r.type)r.dtick<1?t=n-.5*r.dtick:(t-=.5)+r.dtick<n&&(t+=r.dtick);else if(s<.1*h&&(o>.3*h||u(n)||u(a))){var p=r.dtick/2;t+=t+p<n?p:-p}return t}(y,t,l,c,u))+(1+Math.floor((u-y)/v))*v;else for(\"M\"===l.dtick.charAt(0)&&(y=function(t,e,r,n,i){var a=s.findExactDates(e,i);if(a.exactDays>.8){var o=Number(r.substr(1));a.exactYears>.8&&o%12==0?t=V.tickIncrement(t,\"M6\",\"reverse\")+1.5*A:a.exactMonths>.8?t=V.tickIncrement(t,\"M1\",\"reverse\")+15.5*A:t-=S;var l=V.tickIncrement(t,r);if(l<=n)return l}return t}(y,t,v,c,a)),g=y,0;g<=u;)g=V.tickIncrement(g,v,!1,a);return{start:e.c2r(y,0,a),end:e.c2r(g,0,a),size:v,_dataSpan:u-c}},V.prepTicks=function(t,e){var r=s.simpleMap(t.range,t.r2l,void 0,void 0,e);if(t._dtickInit=t.dtick,t._tick0Init=t.tick0,\"auto\"===t.tickmode||!t.dtick){var n,a=t.nticks;a||(\"category\"===t.type||\"multicategory\"===t.type?(n=t.tickfont?s.bigFont(t.tickfont.size||12):15,a=t._length/n):(n=\"y\"===t._id.charAt(0)?40:80,a=s.constrain(t._length/n,4,9)+1),\"radialaxis\"===t._name&&(a*=2)),\"array\"===t.tickmode&&(a*=100),t._roughDTick=Math.abs(r[1]-r[0])/a,V.autoTicks(t,t._roughDTick),t._minDtick>0&&t.dtick<2*t._minDtick&&(t.dtick=t._minDtick,t.tick0=t.l2r(t._forceTick0))}\"period\"===t.ticklabelmode&&function(t){var e;function r(){return!(i(t.dtick)||\"M\"!==t.dtick.charAt(0))}var n=r(),a=V.getTickFormat(t);if(a){var o=t._dtickInit!==t.dtick;/%[fLQsSMX]/.test(a)||(/%[HI]/.test(a)?(e=E,o&&!n&&t.dtick<E&&(t.dtick=E)):/%p/.test(a)?(e=S,o&&!n&&t.dtick<S&&(t.dtick=S)):/%[Aadejuwx]/.test(a)?(e=A,o&&!n&&t.dtick<A&&(t.dtick=A)):/%[UVW]/.test(a)?(e=M,o&&!n&&t.dtick<M&&(t.dtick=M)):/%[Bbm]/.test(a)?(e=T,o&&(n?Q(t.dtick)<1:t.dtick<k)&&(t.dtick=\"M1\")):/%[q]/.test(a)?(e=b,o&&(n?Q(t.dtick)<3:t.dtick<_)&&(t.dtick=\"M3\")):/%[Yy]/.test(a)&&(e=v,o&&(n?Q(t.dtick)<12:t.dtick<y)&&(t.dtick=\"M12\")))}(n=r())&&t.tick0===t._dowTick0&&(t.tick0=t._rawTick0);t._definedDelta=e}(t),t.tick0||(t.tick0=\"date\"===t.type?\"2000-01-01\":0),\"date\"===t.type&&t.dtick<.1&&(t.dtick=.1),st(t)},V.calcTicks=function(t,e){V.prepTicks(t,e);var r=s.simpleMap(t.range,t.r2l,void 0,void 0,e);if(\"array\"===t.tickmode)return function(t){var e=t.tickvals,r=t.ticktext,n=new Array(e.length),i=X(s.simpleMap(t.range,t.r2l)),a=Math.min(i[0],i[1]),o=Math.max(i[0],i[1]),l=0;Array.isArray(r)||(r=[]);var c=\"category\"===t.type?t.d2l_noadd:t.d2l;\"log\"===t.type&&\"L\"!==String(t.dtick).charAt(0)&&(t.dtick=\"L\"+Math.pow(10,Math.floor(Math.min(t.range[0],t.range[1]))-1));for(var u=0;u<e.length;u++){var f=c(e[u]);f>a&&f<o&&(void 0===r[u]?n[l]=V.tickText(t,f):n[l]=lt(t,f,String(r[u])),l++)}l<e.length&&n.splice(l,e.length-l);t.rangebreaks&&(n=n.filter((function(e){return t.maskBreaks(e.x)!==I})));return n}(t);var n=X(r),a=n[0],o=n[1],l=r[1]<r[0],c=Math.min(r[0],r[1]),u=Math.max(r[0],r[1]),f=\"log\"===t.type&&!(i(t.dtick)||\"L\"===t.dtick.charAt(0)),h=\"period\"===t.ticklabelmode;if(t._tmin=V.tickFirst(t,e),t._tmin<a!==l)return[];\"category\"!==t.type&&\"multicategory\"!==t.type||(o=l?Math.max(-.5,o):Math.min(t._categories.length-.5,o));var p=t._tmin;t.rangebreaks&&t._tick0Init!==t.tick0&&(p=At(p,t),l||(p=V.tickIncrement(p,t.dtick,!l,t.calendar))),h&&(p=V.tickIncrement(p,t.dtick,!l,t.calendar));for(var d,m=Math.max(1e3,t._length||0),L=[],C=null;l?p>=o:p<=o;p=V.tickIncrement(p,t.dtick,l,t.calendar)){if(t.rangebreaks&&!l){if(p<a)continue;if(t.maskBreaks(p)===I&&At(p,t)>=u)break}if(L.length>m||p===C)break;C=p;var P=!1;f&&p!==(0|p)&&(P=!0),L.push({minor:P,value:p})}if(h&&function(t,e,r){for(var n=0;n<t.length;n++){var i=t[n].value,a=n,o=n+1;n<t.length-1?(a=n,o=n+1):n>0?(a=n-1,o=n):(a=n,o=n);var s,l=t[a].value,c=t[o].value,u=Math.abs(c-l),f=r||u,h=0;f>=y?h=u>=y&&u<=g?u:v:r===b&&f>=_?h=u>=_&&u<=x?u:b:f>=k?h=u>=k&&u<=w?u:T:r===M&&f>=M?h=M:f>=A?h=A:r===S&&f>=S?h=S:r===E&&f>=E&&(h=E),h>=u&&(h=u,s=!0);var p=i+h;if(e.rangebreaks&&h>0){for(var d=0,m=0;m<84;m++){var L=(m+.5)/84;e.maskBreaks(i*(1-L)+L*p)!==I&&d++}(h*=d/84)||(t[n].drop=!0),s&&u>M&&(h=u)}(h>0||0===n)&&(t[n].periodX=i+h/2)}}(L,t,t._definedDelta),t.rangebreaks){var O=\"y\"===t._id.charAt(0),z=1;\"auto\"===t.tickmode&&(z=t.tickfont?t.tickfont.size:12);var D=NaN;for(d=L.length-1;d>-1;d--)if(L[d].drop)L.splice(d,1);else{L[d].value=At(L[d].value,t);var R=t.c2p(L[d].value);(O?D>R-z:D<R+z)?L.splice(l?d+1:d,1):D=R}}Mt(t)&&360===Math.abs(r[1]-r[0])&&L.pop(),t._tmax=(L[L.length-1]||{}).value,t._prevDateHead=\"\",t._inCalcTicks=!0;var F,B,N=[];for(d=0;d<L.length;d++){var j=L[d].minor,U=L[d].value;F=V.tickText(t,U,!1,j),void 0!==(B=L[d].periodX)&&(F.periodX=B,(B>u||B<c)&&(B>u&&(F.periodX=u),B<c&&(F.periodX=c),F.text=\" \",t._prevDateHead=\"\")),N.push(F)}return t._inCalcTicks=!1,N};var $=[2,5,10],tt=[1,2,3,6,12],et=[1,2,5,10,15,30],rt=[1,2,3,7,14],nt=[-.046,0,.301,.477,.602,.699,.778,.845,.903,.954,1],it=[-.301,0,.301,.699,1],at=[15,30,45,90,180];function ot(t,e,r){return e*s.roundUp(t/e,r)}function st(t){var e=t.dtick;if(t._tickexponent=0,i(e)||\"string\"==typeof e||(e=1),\"category\"!==t.type&&\"multicategory\"!==t.type||(t._tickround=null),\"date\"===t.type){var r=t.r2l(t.tick0),n=t.l2r(r).replace(/(^-|i)/g,\"\"),a=n.length;if(\"M\"===String(e).charAt(0))a>10||\"01-01\"!==n.substr(5)?t._tickround=\"d\":t._tickround=+e.substr(1)%12==0?\"y\":\"m\";else if(e>=A&&a<=10||e>=15*A)t._tickround=\"d\";else if(e>=L&&a<=16||e>=E)t._tickround=\"M\";else if(e>=C&&a<=19||e>=L)t._tickround=\"S\";else{var o=t.l2r(r+e).replace(/^-/,\"\").length;t._tickround=Math.max(a,o)-20,t._tickround<0&&(t._tickround=4)}}else if(i(e)||\"L\"===e.charAt(0)){var s=t.range.map(t.r2d||Number);i(e)||(e=Number(e.substr(1))),t._tickround=2-Math.floor(Math.log(e)/Math.LN10+.01);var l=Math.max(Math.abs(s[0]),Math.abs(s[1])),c=Math.floor(Math.log(l)/Math.LN10+.01),u=void 0===t.minexponent?3:t.minexponent;Math.abs(c)>u&&(ut(t.exponentformat)&&!ft(c)?t._tickexponent=3*Math.round((c-1)/3):t._tickexponent=c)}else t._tickround=null}function lt(t,e,r){var n=t.tickfont||{};return{x:e,dx:0,dy:0,text:r||\"\",fontSize:n.size,font:n.family,fontColor:n.color}}V.autoTicks=function(t,e){var r;function n(t){return Math.pow(t,Math.floor(Math.log(e)/Math.LN10))}if(\"date\"===t.type){t.tick0=s.dateTick0(t.calendar,0);var a=2*e;if(a>v)e/=v,r=n(10),t.dtick=\"M\"+12*ot(e,r,$);else if(a>T)e/=T,t.dtick=\"M\"+ot(e,1,tt);else if(a>A){t.dtick=ot(e,A,t._hasDayOfWeekBreaks?[1,2,7,14]:rt);var o=V.getTickFormat(t),l=\"period\"===t.ticklabelmode;l&&(t._rawTick0=t.tick0),/%[uVW]/.test(o)?t.tick0=s.dateTick0(t.calendar,2):t.tick0=s.dateTick0(t.calendar,1),l&&(t._dowTick0=t.tick0)}else a>E?t.dtick=ot(e,E,tt):a>L?t.dtick=ot(e,L,et):a>C?t.dtick=ot(e,C,et):(r=n(10),t.dtick=ot(e,r,$))}else if(\"log\"===t.type){t.tick0=0;var c=s.simpleMap(t.range,t.r2l);if(e>.7)t.dtick=Math.ceil(e);else if(Math.abs(c[1]-c[0])<1){var u=1.5*Math.abs((c[1]-c[0])/e);e=Math.abs(Math.pow(10,c[1])-Math.pow(10,c[0]))/u,r=n(10),t.dtick=\"L\"+ot(e,r,$)}else t.dtick=e>.3?\"D2\":\"D1\"}else\"category\"===t.type||\"multicategory\"===t.type?(t.tick0=0,t.dtick=Math.ceil(Math.max(e,1))):Mt(t)?(t.tick0=0,r=1,t.dtick=ot(e,r,at)):(t.tick0=0,r=n(10),t.dtick=ot(e,r,$));if(0===t.dtick&&(t.dtick=1),!i(t.dtick)&&\"string\"!=typeof t.dtick){var f=t.dtick;throw t.dtick=1,\"ax.dtick error: \"+String(f)}},V.tickIncrement=function(t,e,r,a){var o=r?-1:1;if(i(e))return s.increment(t,o*e);var l=e.charAt(0),c=o*Number(e.substr(1));if(\"M\"===l)return s.incrementMonth(t,c,a);if(\"L\"===l)return Math.log(Math.pow(10,t)+c)/Math.LN10;if(\"D\"===l){var u=\"D2\"===e?it:nt,f=t+.01*o,h=s.roundUp(s.mod(f,1),u,r);return Math.floor(f)+Math.log(n.round(Math.pow(10,h),1))/Math.LN10}throw\"unrecognized dtick \"+String(e)},V.tickFirst=function(t,e){var r=t.r2l||Number,a=s.simpleMap(t.range,r,void 0,void 0,e),o=a[1]<a[0],l=o?Math.floor:Math.ceil,c=X(a)[0],u=t.dtick,f=r(t.tick0);if(i(u)){var h=l((c-f)/u)*u+f;return\"category\"!==t.type&&\"multicategory\"!==t.type||(h=s.constrain(h,0,t._categories.length-1)),h}var p=u.charAt(0),d=Number(u.substr(1));if(\"M\"===p){for(var m,g,v,y=0,x=f;y<10;){if(((m=V.tickIncrement(x,u,o,t.calendar))-c)*(x-c)<=0)return o?Math.min(x,m):Math.max(x,m);g=(c-(x+m)/2)/(m-x),v=p+(Math.abs(Math.round(g))||1)*d,x=V.tickIncrement(x,v,g<0?!o:o,t.calendar),y++}return s.error(\"tickFirst did not converge\",t),x}if(\"L\"===p)return Math.log(l((Math.pow(10,c)-f)/d)*d+f)/Math.LN10;if(\"D\"===p){var b=\"D2\"===u?it:nt,_=s.roundUp(s.mod(c,1),b,o);return Math.floor(c)+Math.log(n.round(Math.pow(10,_),1))/Math.LN10}throw\"unrecognized dtick \"+String(u)},V.tickText=function(t,e,r,n){var a,o=lt(t,e),l=\"array\"===t.tickmode,c=r||l,u=t.type,f=\"category\"===u?t.d2l_noadd:t.d2l;if(l&&Array.isArray(t.ticktext)){var h=s.simpleMap(t.range,t.r2l),p=(Math.abs(h[1]-h[0])-(t._lBreaks||0))/1e4;for(a=0;a<t.ticktext.length&&!(Math.abs(e-f(t.tickvals[a]))<p);a++);if(a<t.ticktext.length)return o.text=String(t.ticktext[a]),o}function d(n){if(void 0===n)return!0;if(r)return\"none\"===n;var i={first:t._tmin,last:t._tmax}[n];return\"all\"!==n&&e!==i}var m=r?\"never\":\"none\"!==t.exponentformat&&d(t.showexponent)?\"hide\":\"\";if(\"date\"===u?function(t,e,r,n){var a=t._tickround,o=r&&t.hoverformat||V.getTickFormat(t);n&&(a=i(a)?4:{y:\"m\",m:\"d\",d:\"M\",M:\"S\",S:4}[a]);var l,c=s.formatDate(e.x,o,a,t._dateFormat,t.calendar,t._extraFormat),u=c.indexOf(\"\\n\");-1!==u&&(l=c.substr(u+1),c=c.substr(0,u));n&&(\"00:00:00\"===c||\"00:00\"===c?(c=l,l=\"\"):8===c.length&&(c=c.replace(/:00$/,\"\")));if(l)if(r)\"d\"===a?c+=\", \"+l:c=l+(c?\", \"+c:\"\");else if(t._inCalcTicks&&t._prevDateHead===l){var f=St(t),h=t._realSide||t.side;(!f&&\"top\"===h||f&&\"bottom\"===h)&&(c+=\"<br> \")}else t._prevDateHead=l,c+=\"<br>\"+l;e.text=c}(t,o,r,c):\"log\"===u?function(t,e,r,n,a){var o=t.dtick,l=e.x,c=t.tickformat,u=\"string\"==typeof o&&o.charAt(0);\"never\"===a&&(a=\"\");n&&\"L\"!==u&&(o=\"L3\",u=\"L\");if(c||\"L\"===u)e.text=ht(Math.pow(10,l),t,a,n);else if(i(o)||\"D\"===u&&s.mod(l+.01,1)<.1){var f=Math.round(l),h=Math.abs(f),p=t.exponentformat;\"power\"===p||ut(p)&&ft(f)?(e.text=0===f?1:1===f?\"10\":\"10<sup>\"+(f>1?\"\":P)+h+\"</sup>\",e.fontSize*=1.25):(\"e\"===p||\"E\"===p)&&h>2?e.text=\"1\"+p+(f>0?\"+\":P)+h:(e.text=ht(Math.pow(10,l),t,\"\",\"fakehover\"),\"D1\"===o&&\"y\"===t._id.charAt(0)&&(e.dy-=e.fontSize/6))}else{if(\"D\"!==u)throw\"unrecognized dtick \"+String(o);e.text=String(Math.round(Math.pow(10,s.mod(l,1)))),e.fontSize*=.75}if(\"D1\"===t.dtick){var d=String(e.text).charAt(0);\"0\"!==d&&\"1\"!==d||(\"y\"===t._id.charAt(0)?e.dx-=e.fontSize/4:(e.dy+=e.fontSize/2,e.dx+=(t.range[1]>t.range[0]?1:-1)*e.fontSize*(l<0?.5:.25)))}}(t,o,0,c,m):\"category\"===u?function(t,e){var r=t._categories[Math.round(e.x)];void 0===r&&(r=\"\");e.text=String(r)}(t,o):\"multicategory\"===u?function(t,e,r){var n=Math.round(e.x),i=t._categories[n]||[],a=void 0===i[1]?\"\":String(i[1]),o=void 0===i[0]?\"\":String(i[0]);r?e.text=o+\" - \"+a:(e.text=a,e.text2=o)}(t,o,r):Mt(t)?function(t,e,r,n,i){if(\"radians\"!==t.thetaunit||r)e.text=ht(e.x,t,i,n);else{var a=e.x/180;if(0===a)e.text=\"0\";else{var o=function(t){function e(t,e){return Math.abs(t-e)<=1e-6}var r=function(t){for(var r=1;!e(Math.round(t*r)/r,t);)r*=10;return r}(t),n=t*r,i=Math.abs(function t(r,n){return e(n,0)?r:t(n,r%n)}(n,r));return[Math.round(n/i),Math.round(r/i)]}(a);if(o[1]>=100)e.text=ht(s.deg2rad(e.x),t,i,n);else{var l=e.x<0;1===o[1]?1===o[0]?e.text=\"\\u03c0\":e.text=o[0]+\"\\u03c0\":e.text=[\"<sup>\",o[0],\"</sup>\",\"\\u2044\",\"<sub>\",o[1],\"</sub>\",\"\\u03c0\"].join(\"\"),l&&(e.text=P+e.text)}}}}(t,o,r,c,m):function(t,e,r,n,i){\"never\"===i?i=\"\":\"all\"===t.showexponent&&Math.abs(e.x/t.dtick)<1e-6&&(i=\"hide\");e.text=ht(e.x,t,i,n)}(t,o,0,c,m),n||(t.tickprefix&&!d(t.showtickprefix)&&(o.text=t.tickprefix+o.text),t.ticksuffix&&!d(t.showticksuffix)&&(o.text+=t.ticksuffix)),\"boundaries\"===t.tickson||t.showdividers){var g=function(e){var r=t.l2p(e);return r>=0&&r<=t._length?e:null};o.xbnd=[g(o.x-.5),g(o.x+t.dtick-.5)]}return o},V.hoverLabelText=function(t,e,r){r&&(t=s.extendFlat({},t,{hoverformat:r}));var n=Array.isArray(e)?e[0]:e,i=Array.isArray(e)?e[1]:void 0;if(void 0!==i&&i!==n)return V.hoverLabelText(t,n,r)+\" - \"+V.hoverLabelText(t,i,r);var a=\"log\"===t.type&&n<=0,o=V.tickText(t,t.c2l(a?-n:n),\"hover\").text;return a?0===n?\"0\":P+o:o};var ct=[\"f\",\"p\",\"n\",\"\\u03bc\",\"m\",\"\",\"k\",\"M\",\"G\",\"T\"];function ut(t){return\"SI\"===t||\"B\"===t}function ft(t){return t>14||t<-15}function ht(t,e,r,n){var a=t<0,o=e._tickround,l=r||e.exponentformat||\"B\",c=e._tickexponent,u=V.getTickFormat(e),f=e.separatethousands;if(n){var h={exponentformat:l,minexponent:e.minexponent,dtick:\"none\"===e.showexponent?e.dtick:i(t)&&Math.abs(t)||1,range:\"none\"===e.showexponent?e.range.map(e.r2d):[0,t||1]};st(h),o=(Number(h._tickround)||0)+4,c=h._tickexponent,e.hoverformat&&(u=e.hoverformat)}if(u)return e._numFormat(u)(t).replace(/-/g,P);var p,d=Math.pow(10,-o)/2;if(\"none\"===l&&(c=0),(t=Math.abs(t))<d)t=\"0\",a=!1;else{if(t+=d,c&&(t*=Math.pow(10,-c),o+=c),0===o)t=String(Math.floor(t));else if(o<0){t=(t=String(Math.round(t))).substr(0,t.length+o);for(var m=o;m<0;m++)t+=\"0\"}else{var g=(t=String(t)).indexOf(\".\")+1;g&&(t=t.substr(0,g+o).replace(/\\.?0+$/,\"\"))}t=s.numSeparate(t,e._separators,f)}c&&\"hide\"!==l&&(ut(l)&&ft(c)&&(l=\"power\"),p=c<0?P+-c:\"power\"!==l?\"+\"+c:String(c),\"e\"===l||\"E\"===l?t+=l+p:\"power\"===l?t+=\"\\xd710<sup>\"+p+\"</sup>\":\"B\"===l&&9===c?t+=\"B\":ut(l)&&(t+=ct[c/3+5]));return a?P+t:t}function pt(t,e){for(var r=[],n={},i=0;i<e.length;i++){var a=e[i];n[a.text2]?n[a.text2].push(a.x):n[a.text2]=[a.x]}for(var o in n)r.push(lt(t,s.interp(n[o],.5),o));return r}function dt(t){return void 0!==t.periodX?t.periodX:t.x}function mt(t){return[t.text,t.x,t.axInfo,t.font,t.fontSize,t.fontColor].join(\"_\")}function gt(t){var e=t.title.font.size,r=(t.title.text.match(c.BR_TAG_ALL)||[]).length;return t.title.hasOwnProperty(\"standoff\")?r?e*(N+r*j):e*N:r?e*(r+1)*j:e}function vt(t,e){var r=t.l2p(e);return r>1&&r<t._length-1}function yt(t){var e=n.select(t),r=e.select(\".text-math-group\");return r.empty()?e.select(\"text\"):r}function xt(t){return t._id+\".automargin\"}function bt(t){return xt(t)+\".mirror\"}function _t(t){return t._id+\".rangeslider\"}function wt(t,e){for(var r=0;r<e.length;r++)-1===t.indexOf(e[r])&&t.push(e[r])}function Tt(t,e,r){var n,i,a=[],o=[],l=t.layout;for(n=0;n<e.length;n++)a.push(V.getFromId(t,e[n]));for(n=0;n<r.length;n++)o.push(V.getFromId(t,r[n]));var c=Object.keys(p),u=[\"anchor\",\"domain\",\"overlaying\",\"position\",\"side\",\"tickangle\",\"editType\"],f=[\"linear\",\"log\"];for(n=0;n<c.length;n++){var h=c[n],d=a[0][h],m=o[0][h],g=!0,v=!1,y=!1;if(\"_\"!==h.charAt(0)&&\"function\"!=typeof d&&-1===u.indexOf(h)){for(i=1;i<a.length&&g;i++){var x=a[i][h];\"type\"===h&&-1!==f.indexOf(d)&&-1!==f.indexOf(x)&&d!==x?v=!0:x!==d&&(g=!1)}for(i=1;i<o.length&&g;i++){var b=o[i][h];\"type\"===h&&-1!==f.indexOf(m)&&-1!==f.indexOf(b)&&m!==b?y=!0:o[i][h]!==m&&(g=!1)}g&&(v&&(l[a[0]._name].type=\"linear\"),y&&(l[o[0]._name].type=\"linear\"),kt(l,h,a,o,t._fullLayout._dfltTitle))}}for(n=0;n<t._fullLayout.annotations.length;n++){var _=t._fullLayout.annotations[n];-1!==e.indexOf(_.xref)&&-1!==r.indexOf(_.yref)&&s.swapAttrs(l.annotations[n],[\"?\"])}}function kt(t,e,r,n,i){var a,o=s.nestedProperty,l=o(t[r[0]._name],e).get(),c=o(t[n[0]._name],e).get();for(\"title\"===e&&(l&&l.text===i.x&&(l.text=i.y),c&&c.text===i.y&&(c.text=i.x)),a=0;a<r.length;a++)o(t,r[a]._name+\".\"+e).set(c);for(a=0;a<n.length;a++)o(t,n[a]._name+\".\"+e).set(l)}function Mt(t){return\"angularaxis\"===t._id}function At(t,e){for(var r=e._rangebreaks.length,n=0;n<r;n++){var i=e._rangebreaks[n];if(t>=i.min&&t<i.max)return i.max}return t}function St(t){return-1!==(t.ticklabelposition||\"\").indexOf(\"inside\")}function Et(t,e){St(t._anchorAxis||{})&&t._hideCounterAxisInsideTickLabels&&t._hideCounterAxisInsideTickLabels(e)}V.getTickFormat=function(t){var e,r,n,i,a,o,s,l;function c(t){return\"string\"!=typeof t?t:Number(t.replace(\"M\",\"\"))*T}function u(t,e){var r=[\"L\",\"D\"];if(typeof t==typeof e){if(\"number\"==typeof t)return t-e;var n=r.indexOf(t.charAt(0)),i=r.indexOf(e.charAt(0));return n===i?Number(t.replace(/(L|D)/g,\"\"))-Number(e.replace(/(L|D)/g,\"\")):n-i}return\"number\"==typeof t?1:-1}function f(t,e){var r=null===e[0],n=null===e[1],i=u(t,e[0])>=0,a=u(t,e[1])<=0;return(r||i)&&(n||a)}if(t.tickformatstops&&t.tickformatstops.length>0)switch(t.type){case\"date\":case\"linear\":for(e=0;e<t.tickformatstops.length;e++)if((n=t.tickformatstops[e]).enabled&&(i=t.dtick,a=n.dtickrange,o=void 0,s=void 0,l=void 0,o=c||function(t){return t},s=a[0],l=a[1],(!s&&\"number\"!=typeof s||o(s)<=o(i))&&(!l&&\"number\"!=typeof l||o(l)>=o(i)))){r=n;break}break;case\"log\":for(e=0;e<t.tickformatstops.length;e++)if((n=t.tickformatstops[e]).enabled&&f(t.dtick,n.dtickrange)){r=n;break}}return r?r.value:t.tickformat},V.getSubplots=function(t,e){var r=t._fullLayout._subplots,n=r.cartesian.concat(r.gl2d||[]),i=e?V.findSubplotsWithAxis(n,e):n;return i.sort((function(t,e){var r=t.substr(1).split(\"y\"),n=e.substr(1).split(\"y\");return r[0]===n[0]?+r[1]-+n[1]:+r[0]-+n[0]})),i},V.findSubplotsWithAxis=function(t,e){for(var r=new RegExp(\"x\"===e._id.charAt(0)?\"^\"+e._id+\"y\":e._id+\"$\"),n=[],i=0;i<t.length;i++){var a=t[i];r.test(a)&&n.push(a)}return n},V.makeClipPaths=function(t){var e=t._fullLayout;if(!e._hasOnlyLargeSploms){var r,i,a={_offset:0,_length:e.width,_id:\"\"},o={_offset:0,_length:e.height,_id:\"\"},s=V.list(t,\"x\",!0),l=V.list(t,\"y\",!0),c=[];for(r=0;r<s.length;r++)for(c.push({x:s[r],y:o}),i=0;i<l.length;i++)0===r&&c.push({x:a,y:l[i]}),c.push({x:s[r],y:l[i]});var u=e._clips.selectAll(\".axesclip\").data(c,(function(t){return t.x._id+t.y._id}));u.enter().append(\"clipPath\").classed(\"axesclip\",!0).attr(\"id\",(function(t){return\"clip\"+e._uid+t.x._id+t.y._id})).append(\"rect\"),u.exit().remove(),u.each((function(t){n.select(this).select(\"rect\").attr({x:t.x._offset||0,y:t.y._offset||0,width:t.x._length||1,height:t.y._length||1})}))}},V.draw=function(t,e,r){var n=t._fullLayout;\"redraw\"===e&&n._paper.selectAll(\"g.subplot\").each((function(t){var e=t[0],r=n._plots[e];if(r){var i=r.xaxis,a=r.yaxis;r.xaxislayer.selectAll(\".\"+i._id+\"tick\").remove(),r.yaxislayer.selectAll(\".\"+a._id+\"tick\").remove(),r.xaxislayer.selectAll(\".\"+i._id+\"tick2\").remove(),r.yaxislayer.selectAll(\".\"+a._id+\"tick2\").remove(),r.xaxislayer.selectAll(\".\"+i._id+\"divider\").remove(),r.yaxislayer.selectAll(\".\"+a._id+\"divider\").remove(),r.gridlayer&&r.gridlayer.selectAll(\"path\").remove(),r.zerolinelayer&&r.zerolinelayer.selectAll(\"path\").remove(),n._infolayer.select(\".g-\"+i._id+\"title\").remove(),n._infolayer.select(\".g-\"+a._id+\"title\").remove()}}));var i=e&&\"redraw\"!==e?e:V.listIds(t);return s.syncOrAsync(i.map((function(e){return function(){if(e){var n=V.getFromId(t,e),i=V.drawOne(t,n,r);return n._r=n.range.slice(),n._rl=s.simpleMap(n._r,n.r2l),i}}})))},V.drawOne=function(t,e,r){var n,i,l;r=r||{},e.setScale();var c=t._fullLayout,p=e._id,d=p.charAt(0),m=V.counterLetter(p),g=c._plots[e._mainSubplot];if(g){var v=g[d+\"axislayer\"],y=e._mainLinePosition,x=e._mainMirrorPosition,b=e._vals=V.calcTicks(e),_=[e.mirror,y,x].join(\"_\");for(n=0;n<b.length;n++)b[n].axInfo=_;e._selections={},e._tickAngles&&(e._prevTickAngles=e._tickAngles),e._tickAngles={},e._depth=null;var w={};if(e.visible){var T,k,M=V.makeTransTickFn(e),A=V.makeTransTickLabelFn(e),S=\"inside\"===e.ticks,E=\"outside\"===e.ticks;if(\"boundaries\"===e.tickson){var L=function(t,e){var r,n=[],i=function(t,e){var r=t.xbnd[e];null!==r&&n.push(s.extendFlat({},t,{x:r}))};if(e.length){for(r=0;r<e.length;r++)i(e[r],0);i(e[r-1],1)}return n}(0,b);k=V.clipEnds(e,L),T=S?k:L}else k=V.clipEnds(e,b),T=S&&\"period\"!==e.ticklabelmode?k:b;var C=e._gridVals=k,P=function(t,e){var r,n,i=[],a=e.length&&e[e.length-1].x<e[0].x,o=function(t,e){var r=t.xbnd[e];null!==r&&i.push(s.extendFlat({},t,{x:r}))};if(t.showdividers&&e.length){for(r=0;r<e.length;r++){var l=e[r];l.text2!==n&&o(l,a?1:0),n=l.text2}o(e[r-1],a?0:1)}return i}(e,b);if(!c._hasOnlyLargeSploms){var I=e._subplotsWith,O={};for(n=0;n<I.length;n++){i=I[n];var z=(l=c._plots[i])[m+\"axis\"],D=z._mainAxis._id;if(!O[D]){O[D]=1;var R=\"x\"===d?\"M0,\"+z._offset+\"v\"+z._length:\"M\"+z._offset+\",0h\"+z._length;V.drawGrid(t,e,{vals:C,counterAxis:z,layer:l.gridlayer.select(\".\"+p),path:R,transFn:M}),V.drawZeroLine(t,e,{counterAxis:z,layer:l.zerolinelayer,path:R,transFn:M})}}}var F=V.getTickSigns(e),B=[];if(e.ticks){var N,q,H,G=V.makeTickPath(e,y,F[2]);if(e._anchorAxis&&e.mirror&&!0!==e.mirror?(N=V.makeTickPath(e,x,F[3]),q=G+N):(N=\"\",q=G),e.showdividers&&E&&\"boundaries\"===e.tickson){var Y={};for(n=0;n<P.length;n++)Y[P[n].x]=1;H=function(t){return Y[t.x]?N:q}}else H=q;V.drawTicks(t,e,{vals:T,layer:v,path:H,transFn:M}),\"allticks\"===e.mirror&&(B=Object.keys(e._linepositions||{}))}for(n=0;n<B.length;n++){i=B[n],l=c._plots[i];var W=e._linepositions[i]||[],X=V.makeTickPath(e,W[0],F[0])+V.makeTickPath(e,W[1],F[1]);V.drawTicks(t,e,{vals:T,layer:l[d+\"axislayer\"],path:X,transFn:M})}var Z=[];if(Z.push((function(){return V.drawLabels(t,e,{vals:b,layer:v,plotinfo:l,transFn:A,labelFns:V.makeLabelFns(e,y)})})),\"multicategory\"===e.type){var J={x:2,y:10}[d];Z.push((function(){var r={x:\"height\",y:\"width\"}[d],n=Q()[r]+J+(e._tickAngles[p+\"tick\"]?e.tickfont.size*j:0);return V.drawLabels(t,e,{vals:pt(e,b),layer:v,cls:p+\"tick2\",repositionOnUpdate:!0,secondary:!0,transFn:M,labelFns:V.makeLabelFns(e,y+n*F[4])})})),Z.push((function(){return e._depth=F[4]*(Q(\"tick2\")[e.side]-y),function(t,e,r){var n=e._id+\"divider\",i=r.vals,a=r.layer.selectAll(\"path.\"+n).data(i,mt);a.exit().remove(),a.enter().insert(\"path\",\":first-child\").classed(n,1).classed(\"crisp\",1).call(f.stroke,e.dividercolor).style(\"stroke-width\",h.crispRound(t,e.dividerwidth,1)+\"px\"),a.attr(\"transform\",r.transFn).attr(\"d\",r.path)}(t,e,{vals:P,layer:v,path:V.makeTickPath(e,y,F[4],e._depth),transFn:M})}))}else e.title.hasOwnProperty(\"standoff\")&&Z.push((function(){e._depth=F[4]*(Q()[e.side]-y)}));var K=o.getComponentMethod(\"rangeslider\",\"isVisible\")(e);return Z.push((function(){var r,n,i,s,l=e.side.charAt(0),u=U[e.side].charAt(0),f=V.getPxPosition(t,e),h=E?e.ticklen:0;if((e.automargin||K)&&(\"multicategory\"===e.type?r=Q(\"tick2\"):(r=Q(),\"x\"===d&&\"b\"===l&&(e._depth=Math.max(r.width>0?r.bottom-f:0,h)))),e.automargin){n={x:0,y:0,r:0,l:0,t:0,b:0};var p=[0,1];if(\"x\"===d){if(\"b\"===l?n[l]=e._depth:(n[l]=e._depth=Math.max(r.width>0?f-r.top:0,h),p.reverse()),r.width>0){var g=r.right-(e._offset+e._length);g>0&&(n.xr=1,n.r=g);var v=e._offset-r.left;v>0&&(n.xl=0,n.l=v)}}else if(\"l\"===l?n[l]=e._depth=Math.max(r.height>0?f-r.left:0,h):(n[l]=e._depth=Math.max(r.height>0?r.right-f:0,h),p.reverse()),r.height>0){var y=r.bottom-(e._offset+e._length);y>0&&(n.yb=0,n.b=y);var x=e._offset-r.top;x>0&&(n.yt=1,n.t=x)}n[m]=\"free\"===e.anchor?e.position:e._anchorAxis.domain[p[0]],e.title.text!==c._dfltTitle[d]&&(n[l]+=gt(e)+(e.title.standoff||0)),e.mirror&&\"free\"!==e.anchor&&((i={x:0,y:0,r:0,l:0,t:0,b:0})[u]=e.linewidth,e.mirror&&!0!==e.mirror&&(i[u]+=h),!0===e.mirror||\"ticks\"===e.mirror?i[m]=e._anchorAxis.domain[p[1]]:\"all\"!==e.mirror&&\"allticks\"!==e.mirror||(i[m]=[e._counterDomainMin,e._counterDomainMax][p[1]]))}K&&(s=o.getComponentMethod(\"rangeslider\",\"autoMarginOpts\")(t,e)),a.autoMargin(t,xt(e),n),a.autoMargin(t,bt(e),i),a.autoMargin(t,_t(e),s)})),r.skipTitle||K&&\"bottom\"===e.side||Z.push((function(){return function(t,e){var r,n=t._fullLayout,i=e._id,a=i.charAt(0),o=e.title.font.size;if(e.title.hasOwnProperty(\"standoff\"))r=e._depth+e.title.standoff+gt(e);else{var s=St(e);if(\"multicategory\"===e.type)r=e._depth;else{var l=1.5*o;s&&(l=.5*o,\"outside\"===e.ticks&&(l+=e.ticklen)),r=10+l+(e.linewidth?e.linewidth-1:0)}s||(r+=\"x\"===a?\"top\"===e.side?o*(e.showticklabels?1:0):o*(e.showticklabels?1.5:.5):\"right\"===e.side?o*(e.showticklabels?1:.5):o*(e.showticklabels?.5:0))}var c,f,p,d,m=V.getPxPosition(t,e);\"x\"===a?(f=e._offset+e._length/2,p=\"top\"===e.side?m-r:m+r):(p=e._offset+e._length/2,f=\"right\"===e.side?m+r:m-r,c={rotate:\"-90\",offset:0});if(\"multicategory\"!==e.type){var g=e._selections[e._id+\"tick\"];if(d={selection:g,side:e.side},g&&g.node()&&g.node().parentNode){var v=h.getTranslate(g.node().parentNode);d.offsetLeft=v.x,d.offsetTop=v.y}e.title.hasOwnProperty(\"standoff\")&&(d.pad=0)}return u.draw(t,i+\"title\",{propContainer:e,propName:e._name+\".title.text\",placeholder:n._dfltTitle[a],avoid:d,transform:c,attributes:{x:f,y:p,\"text-anchor\":\"middle\"}})}(t,e)})),s.syncOrAsync(Z)}}function Q(t){var r=p+(t||\"tick\");return w[r]||(w[r]=function(t,e){var r,n,i,a;t._selections[e].size()?(r=1/0,n=-1/0,i=1/0,a=-1/0,t._selections[e].each((function(){var t=yt(this),e=h.bBox(t.node().parentNode);r=Math.min(r,e.top),n=Math.max(n,e.bottom),i=Math.min(i,e.left),a=Math.max(a,e.right)}))):(r=0,n=0,i=0,a=0);return{top:r,bottom:n,left:i,right:a,height:n-r,width:a-i}}(e,r)),w[r]}},V.getTickSigns=function(t){var e=t._id.charAt(0),r={x:\"top\",y:\"right\"}[e],n=t.side===r?1:-1,i=[-1,1,n,-n];return\"inside\"!==t.ticks==(\"x\"===e)&&(i=i.map((function(t){return-t}))),t.side&&i.push({l:-1,t:-1,r:1,b:1}[t.side.charAt(0)]),i},V.makeTransTickFn=function(t){return\"x\"===t._id.charAt(0)?function(e){return l(t._offset+t.l2p(e.x),0)}:function(e){return l(0,t._offset+t.l2p(e.x))}},V.makeTransTickLabelFn=function(t){var e=function(t){var e=t.ticklabelposition||\"\",r=function(t){return-1!==e.indexOf(t)},n=r(\"top\"),i=r(\"left\"),a=r(\"right\"),o=r(\"bottom\"),s=r(\"inside\"),l=o||i||n||a;if(!l&&!s)return[0,0];var c=t.side,u=l?(t.tickwidth||0)/2:0,f=3,h=t.tickfont?t.tickfont.size:12;(o||n)&&(u+=h*N,f+=(t.linewidth||0)/2);(i||a)&&(u+=(t.linewidth||0)/2,f+=3);s&&\"top\"===c&&(f-=h*(1-N));(i||n)&&(u=-u);\"bottom\"!==c&&\"right\"!==c||(f=-f);return[l?u:0,s?f:0]}(t),r=e[0],n=e[1];return\"x\"===t._id.charAt(0)?function(e){return l(r+t._offset+t.l2p(dt(e)),n)}:function(e){return l(n,r+t._offset+t.l2p(dt(e)))}},V.makeTickPath=function(t,e,r,n){n=void 0!==n?n:t.ticklen;var i=t._id.charAt(0),a=(t.linewidth||1)/2;return\"x\"===i?\"M0,\"+(e+a*r)+\"v\"+n*r:\"M\"+(e+a*r)+\",0h\"+n*r},V.makeLabelFns=function(t,e,r){var n=t.ticklabelposition||\"\",a=function(t){return-1!==n.indexOf(t)},o=a(\"top\"),l=a(\"left\"),c=a(\"right\"),u=a(\"bottom\")||l||o||c,f=a(\"inside\"),h=\"inside\"===n&&\"inside\"===t.ticks||!f&&\"outside\"===t.ticks&&\"boundaries\"!==t.tickson,p=0,d=0,m=h?t.ticklen:0;if(f?m*=-1:u&&(m=0),h&&(p+=m,r)){var g=s.deg2rad(r);p=m*Math.cos(g)+1,d=m*Math.sin(g)}t.showticklabels&&(h||t.showline)&&(p+=.2*t.tickfont.size);var v,y,x,b,_,w={labelStandoff:p+=(t.linewidth||1)/2*(f?-1:1),labelShift:d},T=0,k=t.side,M=t._id.charAt(0),A=t.tickangle;if(\"x\"===M)b=(_=!f&&\"bottom\"===k||f&&\"top\"===k)?1:-1,f&&(b*=-1),v=d*b,y=e+p*b,x=_?1:-.2,90===Math.abs(A)&&(f?x+=B:x=-90===A&&\"bottom\"===k?N:90===A&&\"top\"===k?B:.5,T=B/2*(A/90)),w.xFn=function(t){return t.dx+v+T*t.fontSize},w.yFn=function(t){return t.dy+y+t.fontSize*x},w.anchorFn=function(t,e){if(u){if(l)return\"end\";if(c)return\"start\"}return i(e)&&0!==e&&180!==e?e*b<0!==f?\"end\":\"start\":\"middle\"},w.heightFn=function(e,r,n){return r<-60||r>60?-.5*n:\"top\"===t.side!==f?-n:0};else if(\"y\"===M){if(b=(_=!f&&\"left\"===k||f&&\"right\"===k)?1:-1,f&&(b*=-1),v=p,y=d*b,x=0,f||90!==Math.abs(A)||(x=-90===A&&\"left\"===k||90===A&&\"right\"===k?N:.5),f){var S=i(A)?+A:0;if(0!==S){var E=s.deg2rad(S);T=Math.abs(Math.sin(E))*N*b,x=0}}w.xFn=function(t){return t.dx+e-(v+t.fontSize*x)*b+T*t.fontSize},w.yFn=function(t){return t.dy+y+t.fontSize*B},w.anchorFn=function(t,e){return i(e)&&90===Math.abs(e)?\"middle\":_?\"end\":\"start\"},w.heightFn=function(e,r,n){return\"right\"===t.side&&(r*=-1),r<-30?-n:r<30?-.5*n:0}}return w},V.drawTicks=function(t,e,r){r=r||{};var n=e._id+\"tick\",i=r.vals;\"period\"===e.ticklabelmode&&(i=i.slice()).shift();var a=r.layer.selectAll(\"path.\"+n).data(e.ticks?i:[],mt);a.exit().remove(),a.enter().append(\"path\").classed(n,1).classed(\"ticks\",1).classed(\"crisp\",!1!==r.crisp).call(f.stroke,e.tickcolor).style(\"stroke-width\",h.crispRound(t,e.tickwidth,1)+\"px\").attr(\"d\",r.path).style(\"display\",null),Et(e,[D]),a.attr(\"transform\",r.transFn)},V.drawGrid=function(t,e,r){r=r||{};var n=e._id+\"grid\",i=r.vals,a=r.counterAxis;if(!1===e.showgrid)i=[];else if(a&&V.shouldShowZeroLine(t,e,a))for(var o=\"array\"===e.tickmode,s=0;s<i.length;s++){var l=i[s].x;if(o?!l:Math.abs(l)<e.dtick/100){if(i=i.slice(0,s).concat(i.slice(s+1)),!o)break;s--}}var c=r.layer.selectAll(\"path.\"+n).data(i,mt);c.exit().remove(),c.enter().append(\"path\").classed(n,1).classed(\"crisp\",!1!==r.crisp),e._gw=h.crispRound(t,e.gridwidth,1),c.attr(\"transform\",r.transFn).attr(\"d\",r.path).call(f.stroke,e.gridcolor||\"#ddd\").style(\"stroke-width\",e._gw+\"px\").style(\"display\",null),Et(e,[z]),\"function\"==typeof r.path&&c.attr(\"d\",r.path)},V.drawZeroLine=function(t,e,r){r=r||r;var n=e._id+\"zl\",i=V.shouldShowZeroLine(t,e,r.counterAxis),a=r.layer.selectAll(\"path.\"+n).data(i?[{x:0,id:e._id}]:[]);a.exit().remove(),a.enter().append(\"path\").classed(n,1).classed(\"zl\",1).classed(\"crisp\",!1!==r.crisp).each((function(){r.layer.selectAll(\"path\").sort((function(t,e){return G(t.id,e.id)}))})),a.attr(\"transform\",r.transFn).attr(\"d\",r.path).call(f.stroke,e.zerolinecolor||f.defaultLine).style(\"stroke-width\",h.crispRound(t,e.zerolinewidth,e._gw||1)+\"px\").style(\"display\",null),Et(e,[O])},V.drawLabels=function(t,e,r){r=r||{};var a=t._fullLayout,o=e._id,u=o.charAt(0),f=r.cls||o+\"tick\",p=r.vals,d=r.labelFns,m=r.secondary?0:e.tickangle,g=(e._prevTickAngles||{})[f],v=r.layer.selectAll(\"g.\"+f).data(e.showticklabels?p:[],mt),y=[];function x(t,a){t.each((function(t){var o=n.select(this),s=o.select(\".text-math-group\"),u=d.anchorFn(t,a),f=r.transFn.call(o.node(),t)+(i(a)&&0!=+a?\" rotate(\"+a+\",\"+d.xFn(t)+\",\"+(d.yFn(t)-t.fontSize/2)+\")\":\"\"),p=c.lineCount(o),m=j*t.fontSize,g=d.heightFn(t,i(a)?+a:0,(p-1)*m);if(g&&(f+=l(0,g)),s.empty()){var v=o.select(\"text\");v.attr({transform:f,\"text-anchor\":u}),v.style(\"opacity\",1),e._adjustTickLabelsOverflow&&e._adjustTickLabelsOverflow()}else{var y=h.bBox(s.node()).width*{end:-.5,start:.5}[u];s.attr(\"transform\",f+l(y,0))}}))}v.enter().append(\"g\").classed(f,1).append(\"text\").attr(\"text-anchor\",\"middle\").each((function(e){var r=n.select(this),i=t._promises.length;r.call(c.positionText,d.xFn(e),d.yFn(e)).call(h.font,e.font,e.fontSize,e.fontColor).text(e.text).call(c.convertToTspans,t),t._promises[i]?y.push(t._promises.pop().then((function(){x(r,m)}))):x(r,m)})),Et(e,[R]),v.exit().remove(),r.repositionOnUpdate&&v.each((function(t){n.select(this).select(\"text\").call(c.positionText,d.xFn(t),d.yFn(t))})),e._adjustTickLabelsOverflow=function(){var r=e.ticklabeloverflow;if(r&&\"allow\"!==r){var i=-1!==r.indexOf(\"hide\"),o=\"x\"===e._id.charAt(0),l=0,c=o?t._fullLayout.width:t._fullLayout.height;if(-1!==r.indexOf(\"domain\")){var u=s.simpleMap(e.range,e.r2l);l=e.l2p(u[0])+e._offset,c=e.l2p(u[1])+e._offset}var f=Math.min(l,c),p=Math.max(l,c),d=e.side,m=1/0,g=-1/0;for(var y in v.each((function(t){var r=n.select(this);if(r.select(\".text-math-group\").empty()){var a=h.bBox(r.node()),s=0;o?(a.right>p||a.left<f)&&(s=1):(a.bottom>p||a.top+(e.tickangle?0:t.fontSize/4)<f)&&(s=1);var l=r.select(\"text\");s?i&&l.style(\"opacity\",0):(l.style(\"opacity\",1),m=\"bottom\"===d||\"right\"===d?Math.min(m,o?a.top:a.left):-1/0,g=\"top\"===d||\"left\"===d?Math.max(g,o?a.bottom:a.right):1/0)}})),a._plots){var x=a._plots[y];if(e._id===x.xaxis._id||e._id===x.yaxis._id){var b=o?x.yaxis:x.xaxis;b&&(b[\"_visibleLabelMin_\"+e._id]=m,b[\"_visibleLabelMax_\"+e._id]=g)}}}},e._hideCounterAxisInsideTickLabels=function(t){var r=\"x\"===e._id.charAt(0),i=[];for(var o in a._plots){var s=a._plots[o];e._id!==s.xaxis._id&&e._id!==s.yaxis._id||i.push(r?s.yaxis:s.xaxis)}i.forEach((function(r,i){r&&St(r)&&(t||[O,z,D,R]).forEach((function(t){var o=\"tick\"===t.K&&\"text\"===t.L&&\"period\"===e.ticklabelmode,s=a._plots[e._mainSubplot];(t.K===O.K?s.zerolinelayer.selectAll(\".\"+e._id+\"zl\"):t.K===z.K?s.gridlayer.selectAll(\".\"+e._id):s[e._id.charAt(0)+\"axislayer\"]).each((function(){var a=n.select(this);t.L&&(a=a.selectAll(t.L)),a.each((function(a){var s=e.l2p(o?dt(a):a.x)+e._offset,l=n.select(this);s<e[\"_visibleLabelMax_\"+r._id]&&s>e[\"_visibleLabelMin_\"+r._id]?l.style(\"display\",\"none\"):\"tick\"!==t.K||i||l.style(\"display\",null)}))}))}))}))},x(v,g+1?g:m);var b=null;e._selections&&(e._selections[f]=v);var _=[function(){return y.length&&Promise.all(y)}];e.automargin&&a._redrawFromAutoMarginCount&&90===g?(b=90,_.push((function(){x(v,g)}))):_.push((function(){if(x(v,m),p.length&&\"x\"===u&&!i(m)&&(\"log\"!==e.type||\"D\"!==String(e.dtick).charAt(0))){b=0;var t,n=0,a=[];if(v.each((function(t){n=Math.max(n,t.fontSize);var r=e.l2p(t.x),i=yt(this),o=h.bBox(i.node());a.push({top:0,bottom:10,height:10,left:r-o.width/2,right:r+o.width/2+2,width:o.width+2})})),\"boundaries\"!==e.tickson&&!e.showdividers||r.secondary){var o=p.length,l=Math.abs((p[o-1].x-p[0].x)*e._m)/(o-1),c=e.ticklabelposition||\"\",f=function(t){return-1!==c.indexOf(t)},d=f(\"top\"),g=f(\"left\"),y=f(\"right\"),_=f(\"bottom\")||g||d||y?(e.tickwidth||0)+6:0,w=l<2.5*n||\"multicategory\"===e.type;for(t=0;t<a.length-1;t++)if(s.bBoxIntersect(a[t],a[t+1],_)){b=w?90:30;break}}else{var T=2;for(e.ticks&&(T+=e.tickwidth/2),t=0;t<a.length;t++){var k=p[t].xbnd,M=a[t];if(null!==k[0]&&M.left-e.l2p(k[0])<T||null!==k[1]&&e.l2p(k[1])-M.right<T){b=90;break}}}b&&x(v,b)}})),e._tickAngles&&_.push((function(){e._tickAngles[f]=null===b?i(m)?m:0:b}));var w=e._anchorAxis;w&&w.autorange&&St(e)&&!Y(a,e._id)&&(a._insideTickLabelsAutorange||(a._insideTickLabelsAutorange={}),a._insideTickLabelsAutorange[w._name+\".autorange\"]=w.autorange,_.push((function(){v.each((function(t,r){var n=yt(this);n.select(\".text-math-group\").empty()&&(e._vals[r].bb=h.bBox(n.node()))}))})));var T=s.syncOrAsync(_);return T&&T.then&&t._promises.push(T),T},V.getPxPosition=function(t,e){var r,n=t._fullLayout._size,i=e._id.charAt(0),a=e.side;return\"free\"!==e.anchor?r=e._anchorAxis:\"x\"===i?r={_offset:n.t+(1-(e.position||0))*n.h,_length:0}:\"y\"===i&&(r={_offset:n.l+(e.position||0)*n.w,_length:0}),\"top\"===a||\"left\"===a?r._offset:\"bottom\"===a||\"right\"===a?r._offset+r._length:void 0},V.shouldShowZeroLine=function(t,e,r){var n=s.simpleMap(e.range,e.r2l);return n[0]*n[1]<=0&&e.zeroline&&(\"linear\"===e.type||\"-\"===e.type)&&!(e.rangebreaks&&e.maskBreaks(0)===I)&&(vt(e,0)||!function(t,e,r,n){var i=r._mainAxis;if(!i)return;var a=t._fullLayout,o=e._id.charAt(0),s=V.counterLetter(e._id),l=e._offset+(Math.abs(n[0])<Math.abs(n[1])==(\"x\"===o)?0:e._length);function c(t){if(!t.showline||!t.linewidth)return!1;var r=Math.max((t.linewidth+e.zerolinewidth)/2,1);function n(t){return\"number\"==typeof t&&Math.abs(t-l)<r}if(n(t._mainLinePosition)||n(t._mainMirrorPosition))return!0;var i=t._linepositions||{};for(var a in i)if(n(i[a][0])||n(i[a][1]))return!0}var u=a._plots[r._mainSubplot];if(!(u.mainplotinfo||u).overlays.length)return c(r);for(var f=V.list(t,s),h=0;h<f.length;h++){var p=f[h];if(p._mainAxis===i&&c(p))return!0}}(t,e,r,n)||function(t,e){for(var r=t._fullData,n=e._mainSubplot,i=e._id.charAt(0),a=0;a<r.length;a++){var s=r[a];if(!0===s.visible&&s.xaxis+s.yaxis===n){if(o.traceIs(s,\"bar-like\")&&s.orientation==={x:\"h\",y:\"v\"}[i])return!0;if(s.fill&&s.fill.charAt(s.fill.length-1)===i)return!0}}return!1}(t,e))},V.clipEnds=function(t,e){return e.filter((function(e){return vt(t,e.x)}))},V.allowAutoMargin=function(t){for(var e=V.list(t,\"\",!0),r=0;r<e.length;r++){var n=e[r];n.automargin&&(a.allowAutoMargin(t,xt(n)),n.mirror&&a.allowAutoMargin(t,bt(n))),o.getComponentMethod(\"rangeslider\",\"isVisible\")(n)&&a.allowAutoMargin(t,_t(n))}},V.swap=function(t,e){for(var r=function(t,e){var r,n,i=[];for(r=0;r<e.length;r++){var a=[],o=t._fullData[e[r]].xaxis,s=t._fullData[e[r]].yaxis;if(o&&s){for(n=0;n<i.length;n++)-1===i[n].x.indexOf(o)&&-1===i[n].y.indexOf(s)||a.push(n);if(a.length){var l,c=i[a[0]];if(a.length>1)for(n=1;n<a.length;n++)l=i[a[n]],wt(c.x,l.x),wt(c.y,l.y);wt(c.x,[o]),wt(c.y,[s])}else i.push({x:[o],y:[s]})}}return i}(t,e),n=0;n<r.length;n++)Tt(t,r[n].x,r[n].y)}},{\"../../components/color\":662,\"../../components/drawing\":684,\"../../components/titles\":760,\"../../constants/alignment\":767,\"../../constants/numerical\":775,\"../../lib\":799,\"../../lib/svg_text_utils\":824,\"../../plots/plots\":913,\"../../registry\":927,\"./autorange\":848,\"./axis_autotype\":850,\"./axis_ids\":853,\"./clean_ticks\":855,\"./layout_attributes\":864,\"./set_convert\":870,\"@plotly/d3\":58,\"fast-isnumeric\":245}],850:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../../constants/numerical\").BADNUM,o=i.isArrayOrTypedArray,s=i.isDateTime,l=i.cleanNumber,c=Math.round;function u(t,e){return e?n(t):\"number\"==typeof t}function f(t){return Math.max(1,(t-1)/1e3)}e.exports=function(t,e,r){var i=t,h=r.noMultiCategory;if(o(i)&&!i.length)return\"-\";if(!h&&function(t){return o(t[0])&&o(t[1])}(i))return\"multicategory\";if(h&&Array.isArray(i[0])){for(var p=[],d=0;d<i.length;d++)if(o(i[d]))for(var m=0;m<i[d].length;m++)p.push(i[d][m]);i=p}if(function(t,e){for(var r=t.length,i=f(r),a=0,o=0,l={},u=0;u<r;u+=i){var h=c(u),p=t[h],d=String(p);l[d]||(l[d]=1,s(p,e)&&a++,n(p)&&o++)}return a>2*o}(i,e))return\"date\";var g=\"strict\"!==r.autotypenumbers;return function(t,e){for(var r=t.length,n=f(r),i=0,o=0,s={},u=0;u<r;u+=n){var h=c(u),p=t[h],d=String(p);if(!s[d]){s[d]=1;var m=typeof p;\"boolean\"===m?o++:(e?l(p)!==a:\"number\"===m)?i++:\"string\"===m&&o++}}return o>2*i}(i,g)?\"category\":function(t,e){for(var r=t.length,n=0;n<r;n++)if(u(t[n],e))return!0;return!1}(i,g)?\"linear\":\"-\"}},{\"../../constants/numerical\":775,\"../../lib\":799,\"fast-isnumeric\":245}],851:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../registry\"),a=t(\"../../lib\"),o=t(\"../array_container_defaults\"),s=t(\"./layout_attributes\"),l=t(\"./tick_value_defaults\"),c=t(\"./tick_mark_defaults\"),u=t(\"./tick_label_defaults\"),f=t(\"./category_order_defaults\"),h=t(\"./line_grid_defaults\"),p=t(\"./set_convert\"),d=t(\"./constants\").WEEKDAY_PATTERN,m=t(\"./constants\").HOUR_PATTERN;function g(t,e,r){function i(r,n){return a.coerce(t,e,s.rangebreaks,r,n)}if(i(\"enabled\")){var o=i(\"bounds\");if(o&&o.length>=2){var l,c,u=\"\";if(2===o.length)for(l=0;l<2;l++)if(c=y(o[l])){u=d;break}var f=i(\"pattern\",u);if(f===d)for(l=0;l<2;l++)(c=y(o[l]))&&(e.bounds[l]=o[l]=c-1);if(f)for(l=0;l<2;l++)switch(c=o[l],f){case d:if(!n(c))return void(e.enabled=!1);if((c=+c)!==Math.floor(c)||c<0||c>=7)return void(e.enabled=!1);e.bounds[l]=o[l]=c;break;case m:if(!n(c))return void(e.enabled=!1);if((c=+c)<0||c>24)return void(e.enabled=!1);e.bounds[l]=o[l]=c}if(!1===r.autorange){var h=r.range;if(h[0]<h[1]){if(o[0]<h[0]&&o[1]>h[1])return void(e.enabled=!1)}else if(o[0]>h[0]&&o[1]<h[1])return void(e.enabled=!1)}}else{var p=i(\"values\");if(!p||!p.length)return void(e.enabled=!1);i(\"dvalue\")}}}e.exports=function(t,e,r,n,m){var v,y=n.letter,x=n.font||{},b=n.splomStash||{},_=r(\"visible\",!n.visibleDflt),w=e._template||{},T=e.type||w.type||\"-\";\"date\"===T&&(i.getComponentMethod(\"calendars\",\"handleDefaults\")(t,e,\"calendar\",n.calendar),n.noTicklabelmode||(v=r(\"ticklabelmode\")));var k=\"\";n.noTicklabelposition&&\"multicategory\"!==T||(k=a.coerce(t,e,{ticklabelposition:{valType:\"enumerated\",dflt:\"outside\",values:\"period\"===v?[\"outside\",\"inside\"]:\"x\"===y?[\"outside\",\"inside\",\"outside left\",\"inside left\",\"outside right\",\"inside right\"]:[\"outside\",\"inside\",\"outside top\",\"inside top\",\"outside bottom\",\"inside bottom\"]}},\"ticklabelposition\")),n.noTicklabeloverflow||r(\"ticklabeloverflow\",-1!==k.indexOf(\"inside\")?\"hide past domain\":\"category\"===T||\"multicategory\"===T?\"allow\":\"hide past div\"),p(e,m);var M=!e.isValidRange(t.range);M&&n.reverseDflt&&(M=\"reversed\"),!r(\"autorange\",M)||\"linear\"!==T&&\"-\"!==T||r(\"rangemode\"),r(\"range\"),e.cleanRange(),f(t,e,r,n),\"category\"===T||n.noHover||r(\"hoverformat\");var A=r(\"color\"),S=A!==s.color.dflt?A:x.color,E=b.label||m._dfltTitle[y];if(u(t,e,r,T,n,{pass:1}),!_)return e;r(\"title.text\",E),a.coerceFont(r,\"title.font\",{family:x.family,size:a.bigFont(x.size),color:S}),l(t,e,r,T),u(t,e,r,T,n,{pass:2}),c(t,e,r,n),h(t,e,r,{dfltColor:A,bgColor:n.bgColor,showGrid:n.showGrid,attributes:s}),(e.showline||e.ticks)&&r(\"mirror\"),n.automargin&&r(\"automargin\");var L,C=\"multicategory\"===T;n.noTickson||\"category\"!==T&&!C||!e.ticks&&!e.showgrid||(C&&(L=\"boundaries\"),\"boundaries\"===r(\"tickson\",L)&&delete e.ticklabelposition);C&&(r(\"showdividers\")&&(r(\"dividercolor\"),r(\"dividerwidth\")));if(\"date\"===T)if(o(t,e,{name:\"rangebreaks\",inclusionAttr:\"enabled\",handleItemDefaults:g}),e.rangebreaks.length){for(var P=0;P<e.rangebreaks.length;P++)if(e.rangebreaks[P].pattern===d){e._hasDayOfWeekBreaks=!0;break}if(p(e,m),m._has(\"scattergl\")||m._has(\"splom\"))for(var I=0;I<n.data.length;I++){var O=n.data[I];\"scattergl\"!==O.type&&\"splom\"!==O.type||(O.visible=!1,a.warn(O.type+\" traces do not work on axes with rangebreaks. Setting trace \"+O.index+\" to `visible: false`.\"))}}else delete e.rangebreaks;return e};var v={sun:1,mon:2,tue:3,wed:4,thu:5,fri:6,sat:7};function y(t){if(\"string\"==typeof t)return v[t.substr(0,3).toLowerCase()]}},{\"../../lib\":799,\"../../registry\":927,\"../array_container_defaults\":844,\"./category_order_defaults\":854,\"./constants\":856,\"./layout_attributes\":864,\"./line_grid_defaults\":866,\"./set_convert\":870,\"./tick_label_defaults\":871,\"./tick_mark_defaults\":872,\"./tick_value_defaults\":873,\"fast-isnumeric\":245}],852:[function(t,e,r){\"use strict\";var n=t(\"../../constants/docs\"),i=n.FORMAT_LINK,a=n.DATE_FORMAT_LINK;function o(t,e){return[\"Sets the \"+t+\" formatting rule\"+(e?\"for `\"+e+\"` \":\"\"),\"using d3 formatting mini-languages\",\"which are very similar to those in Python. For numbers, see: \"+i+\".\"].join(\" \")}function s(t,e){return o(t,e)+[\" And for dates see: \"+a+\".\",\"We add two items to d3's date formatter:\",\"*%h* for half of the year as a decimal number as well as\",\"*%{n}f* for fractional seconds\",\"with n digits. For example, *2016-10-13 09:15:23.456* with tickformat\",\"*%H~%M~%S.%2f* would display *09~15~23.46*\"].join(\" \")}e.exports={axisHoverFormat:function(t,e){return{valType:\"string\",dflt:\"\",editType:\"none\",description:(e?o:s)(\"hover text\",t)+[\"By default the values are formatted using \"+(e?\"generic number format\":\"`\"+t+\"axis.hoverformat`\")+\".\"].join(\" \")}},descriptionOnlyNumbers:o,descriptionWithDates:s}},{\"../../constants/docs\":770}],853:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"./constants\");function a(t,e){if(e&&e.length)for(var r=0;r<e.length;r++)if(e[r][t])return!0;return!1}r.id2name=function(t){if(\"string\"==typeof t&&t.match(i.AX_ID_PATTERN)){var e=t.split(\" \")[0].substr(1);return\"1\"===e&&(e=\"\"),t.charAt(0)+\"axis\"+e}},r.name2id=function(t){if(t.match(i.AX_NAME_PATTERN)){var e=t.substr(5);return\"1\"===e&&(e=\"\"),t.charAt(0)+e}},r.cleanId=function(t,e,r){var n=/( domain)$/.test(t);if(\"string\"==typeof t&&t.match(i.AX_ID_PATTERN)&&(!e||t.charAt(0)===e)&&(!n||r)){var a=t.split(\" \")[0].substr(1).replace(/^0+/,\"\");return\"1\"===a&&(a=\"\"),t.charAt(0)+a+(n&&r?\" domain\":\"\")}},r.list=function(t,e,n){var i=t._fullLayout;if(!i)return[];var a,o=r.listIds(t,e),s=new Array(o.length);for(a=0;a<o.length;a++){var l=o[a];s[a]=i[l.charAt(0)+\"axis\"+l.substr(1)]}if(!n){var c=i._subplots.gl3d||[];for(a=0;a<c.length;a++){var u=i[c[a]];e?s.push(u[e+\"axis\"]):s.push(u.xaxis,u.yaxis,u.zaxis)}}return s},r.listIds=function(t,e){var r=t._fullLayout;if(!r)return[];var n=r._subplots;return e?n[e+\"axis\"]:n.xaxis.concat(n.yaxis)},r.getFromId=function(t,e,n){var i=t._fullLayout;return e=void 0===e||\"string\"!=typeof e?e:e.replace(\" domain\",\"\"),\"x\"===n?e=e.replace(/y[0-9]*/,\"\"):\"y\"===n&&(e=e.replace(/x[0-9]*/,\"\")),i[r.id2name(e)]},r.getFromTrace=function(t,e,i){var a=t._fullLayout,o=null;if(n.traceIs(e,\"gl3d\")){var s=e.scene;\"scene\"===s.substr(0,5)&&(o=a[s][i+\"axis\"])}else o=r.getFromId(t,e[i+\"axis\"]||i);return o},r.idSort=function(t,e){var r=t.charAt(0),n=e.charAt(0);return r!==n?r>n?1:-1:+(t.substr(1)||1)-+(e.substr(1)||1)},r.ref2id=function(t){return!!/^[xyz]/.test(t)&&t.split(\" \")[0]},r.isLinked=function(t,e){return a(e,t._axisMatchGroups)||a(e,t._axisConstraintGroups)}},{\"../../registry\":927,\"./constants\":856}],854:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n){if(\"category\"===e.type){var i,a=t.categoryarray,o=Array.isArray(a)&&a.length>0;o&&(i=\"array\");var s,l=r(\"categoryorder\",i);\"array\"===l&&(s=r(\"categoryarray\")),o||\"array\"!==l||(l=e.categoryorder=\"trace\"),\"trace\"===l?e._initialCategories=[]:\"array\"===l?e._initialCategories=s.slice():(s=function(t,e){var r,n,i,a=e.dataAttr||t._id.charAt(0),o={};if(e.axData)r=e.axData;else for(r=[],n=0;n<e.data.length;n++){var s=e.data[n];s[a+\"axis\"]===t._id&&r.push(s)}for(n=0;n<r.length;n++){var l=r[n][a];for(i=0;i<l.length;i++){var c=l[i];null!=c&&(o[c]=1)}}return Object.keys(o)}(e,n).sort(),\"category ascending\"===l?e._initialCategories=s:\"category descending\"===l&&(e._initialCategories=s.reverse()))}}},{}],855:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../../constants/numerical\"),o=a.ONEDAY,s=a.ONEWEEK;r.dtick=function(t,e){var r=\"log\"===e,i=\"date\"===e,a=\"category\"===e,s=i?o:1;if(!t)return s;if(n(t))return(t=Number(t))<=0?s:a?Math.max(1,Math.round(t)):i?Math.max(.1,t):t;if(\"string\"!=typeof t||!i&&!r)return s;var l=t.charAt(0),c=t.substr(1);return(c=n(c)?Number(c):0)<=0||!(i&&\"M\"===l&&c===Math.round(c)||r&&\"L\"===l||r&&\"D\"===l&&(1===c||2===c))?s:t},r.tick0=function(t,e,r,a){return\"date\"===e?i.cleanDate(t,i.dateTick0(r,a%s==0?1:0)):\"D1\"!==a&&\"D2\"!==a?n(t)?Number(t):0:void 0}},{\"../../constants/numerical\":775,\"../../lib\":799,\"fast-isnumeric\":245}],856:[function(t,e,r){\"use strict\";var n=t(\"../../lib/regex\").counter;e.exports={idRegex:{x:n(\"x\",\"( domain)?\"),y:n(\"y\",\"( domain)?\")},attrRegex:n(\"[xy]axis\"),xAxisMatch:n(\"xaxis\"),yAxisMatch:n(\"yaxis\"),AX_ID_PATTERN:/^[xyz][0-9]*( domain)?$/,AX_NAME_PATTERN:/^[xyz]axis[0-9]*$/,SUBPLOT_PATTERN:/^x([0-9]*)y([0-9]*)$/,HOUR_PATTERN:\"hour\",WEEKDAY_PATTERN:\"day of week\",MINDRAG:8,MINSELECT:12,MINZOOM:20,DRAGGERSIZE:20,BENDPX:1.5,REDRAWDELAY:50,SELECTDELAY:100,SELECTID:\"-select\",DFLTRANGEX:[-1,6],DFLTRANGEY:[-1,4],traceLayerClasses:[\"imagelayer\",\"heatmaplayer\",\"contourcarpetlayer\",\"contourlayer\",\"funnellayer\",\"waterfalllayer\",\"barlayer\",\"carpetlayer\",\"violinlayer\",\"boxlayer\",\"ohlclayer\",\"scattercarpetlayer\",\"scatterlayer\"],clipOnAxisFalseQuery:[\".scatterlayer\",\".barlayer\",\".funnellayer\",\".waterfalllayer\"],layerValue2layerClass:{\"above traces\":\"above\",\"below traces\":\"below\"}}},{\"../../lib/regex\":816}],857:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./autorange\"),a=t(\"./axis_ids\").id2name,o=t(\"./layout_attributes\"),s=t(\"./scale_zoom\"),l=t(\"./set_convert\"),c=t(\"../../constants/numerical\").ALMOST_EQUAL,u=t(\"../../constants/alignment\").FROM_BL;function f(t,e,r){var i=r.axIds,s=r.layoutOut,l=r.hasImage,c=s._axisConstraintGroups,u=s._axisMatchGroups,f=e._id,m=f.charAt(0),g=((s._splomAxes||{})[m]||{})[f]||{},v=e._id,y=\"x\"===v.charAt(0);function x(r,i){return n.coerce(t,e,o,r,i)}e._matchGroup=null,e._constraintGroup=null,x(\"constrain\",l?\"domain\":\"range\"),n.coerce(t,e,{constraintoward:{valType:\"enumerated\",values:y?[\"left\",\"center\",\"right\"]:[\"bottom\",\"middle\",\"top\"],dflt:y?\"center\":\"middle\"}},\"constraintoward\");var b,_,w=e.type,T=[];for(b=0;b<i.length;b++){if((_=i[b])!==v)s[a(_)].type===w&&T.push(_)}var k=p(c,v);if(k){var M=[];for(b=0;b<T.length;b++)k[_=T[b]]||M.push(_);T=M}var A,S,E=T.length;E&&(t.matches||g.matches)&&(A=n.coerce(t,e,{matches:{valType:\"enumerated\",values:T,dflt:-1!==T.indexOf(g.matches)?g.matches:void 0}},\"matches\"));var L=l&&!y?e.anchor:void 0;if(E&&!A&&(t.scaleanchor||L)&&(S=n.coerce(t,e,{scaleanchor:{valType:\"enumerated\",values:T}},\"scaleanchor\",L)),A){e._matchGroup=d(u,v,A,1);var C=s[a(A)],P=h(s,e)/h(s,C);y!==(\"x\"===A.charAt(0))&&(P=(y?\"x\":\"y\")+P),d(c,v,A,P)}else t.matches&&-1!==i.indexOf(t.matches)&&n.warn(\"ignored \"+e._name+'.matches: \"'+t.matches+'\" to avoid an infinite loop');if(S){var I=x(\"scaleratio\");I||(I=e.scaleratio=1),d(c,v,S,I)}else t.scaleanchor&&-1!==i.indexOf(t.scaleanchor)&&n.warn(\"ignored \"+e._name+'.scaleanchor: \"'+t.scaleanchor+'\" to avoid either an infinite loop and possibly inconsistent scaleratios, or because this axis declares a *matches* constraint.')}function h(t,e){var r=e.domain;return r||(r=t[a(e.overlaying)].domain),r[1]-r[0]}function p(t,e){for(var r=0;r<t.length;r++)if(t[r][e])return t[r];return null}function d(t,e,r,n){var i,a,o,s,l,c=p(t,e);null===c?((c={})[e]=1,l=t.length,t.push(c)):l=t.indexOf(c);var u=Object.keys(c);for(i=0;i<t.length;i++)if(o=t[i],i!==l&&o[r]){var f=o[r];for(a=0;a<u.length;a++)o[s=u[a]]=m(f,m(n,c[s]));return void t.splice(l,1)}if(1!==n)for(a=0;a<u.length;a++){var h=u[a];c[h]=m(n,c[h])}c[r]=1}function m(t,e){var r,n,i=\"\",a=\"\";\"string\"==typeof t&&(r=(i=t.match(/^[xy]*/)[0]).length,t=+t.substr(r)),\"string\"==typeof e&&(n=(a=e.match(/^[xy]*/)[0]).length,e=+e.substr(n));var o=t*e;return r||n?r&&n&&i.charAt(0)!==a.charAt(0)?r===n?o:(r>n?i.substr(n):a.substr(r))+o:i+a+t*e:o}function g(t,e){for(var r=e._size,n=r.h/r.w,i={},a=Object.keys(t),o=0;o<a.length;o++){var s=a[o],l=t[s];if(\"string\"==typeof l){var c=l.match(/^[xy]*/)[0],u=c.length;l=+l.substr(u);for(var f=\"y\"===c.charAt(0)?n:1/n,h=0;h<u;h++)l*=f}i[s]=l}return i}function v(t,e){var r=t._inputDomain,n=u[t.constraintoward],i=r[0]+(r[1]-r[0])*n;t.domain=t._input.domain=[i+(r[0]-i)/e,i+(r[1]-i)/e],t.setScale()}r.handleDefaults=function(t,e,r){var i,o,s,c,u,h,p,d,m=r.axIds,g=r.axHasImage,v=e._axisConstraintGroups=[],y=e._axisMatchGroups=[];for(i=0;i<m.length;i++)f(u=t[c=a(m[i])],h=e[c],{axIds:m,layoutOut:e,hasImage:g[c]});function x(t,r){for(i=0;i<t.length;i++)for(s in o=t[i])e[a(s)][r]=o}for(x(y,\"_matchGroup\"),i=0;i<v.length;i++)for(s in o=v[i])if((h=e[a(s)]).fixedrange){for(var b in o){var _=a(b);!1===(t[_]||{}).fixedrange&&n.warn(\"fixedrange was specified as false for axis \"+_+\" but was overridden because another axis in its constraint group has fixedrange true\"),e[_].fixedrange=!0}break}for(i=0;i<v.length;){for(s in o=v[i]){(h=e[a(s)])._matchGroup&&Object.keys(h._matchGroup).length===Object.keys(o).length&&(v.splice(i,1),i--);break}i++}x(v,\"_constraintGroup\");var w=[\"constrain\",\"range\",\"autorange\",\"rangemode\",\"rangebreaks\",\"categoryorder\",\"categoryarray\"],T=!1,k=!1;function M(){d=h[p],\"rangebreaks\"===p&&(k=h._hasDayOfWeekBreaks)}for(i=0;i<y.length;i++){o=y[i];for(var A=0;A<w.length;A++){var S;for(s in p=w[A],d=null,o)if(u=t[c=a(s)],h=e[c],p in h){if(!h.matches&&(S=h,p in u)){M();break}null===d&&p in u&&M()}if(\"range\"===p&&d&&(T=!0),\"autorange\"===p&&null===d&&T&&(d=!1),null===d&&p in S&&(d=S[p]),null!==d)for(s in o)(h=e[a(s)])[p]=\"range\"===p?d.slice():d,\"rangebreaks\"===p&&(h._hasDayOfWeekBreaks=k,l(h,e))}}},r.enforce=function(t){var e,r,n,o,l,u,f,h,p=t._fullLayout,d=p._axisConstraintGroups||[];for(e=0;e<d.length;e++){n=g(d[e],p);var m=Object.keys(n),y=1/0,x=0,b=1/0,_={},w={},T=!1;for(r=0;r<m.length;r++)w[o=m[r]]=l=p[a(o)],l._inputDomain?l.domain=l._inputDomain.slice():l._inputDomain=l.domain.slice(),l._inputRange||(l._inputRange=l.range.slice()),l.setScale(),_[o]=u=Math.abs(l._m)/n[o],y=Math.min(y,u),\"domain\"!==l.constrain&&l._constraintShrinkable||(b=Math.min(b,u)),delete l._constraintShrinkable,x=Math.max(x,u),\"domain\"===l.constrain&&(T=!0);if(!(y>c*x)||T)for(r=0;r<m.length;r++)if(u=_[o=m[r]],f=(l=w[o]).constrain,u!==b||\"domain\"===f)if(h=u/b,\"range\"===f)s(l,h);else{var k=l._inputDomain,M=(l.domain[1]-l.domain[0])/(k[1]-k[0]),A=(l.r2l(l.range[1])-l.r2l(l.range[0]))/(l.r2l(l._inputRange[1])-l.r2l(l._inputRange[0]));if((h/=M)*A<1){l.domain=l._input.domain=k.slice(),s(l,h);continue}if(A<1&&(l.range=l._input.range=l._inputRange.slice(),h*=A),l.autorange){var S=l.r2l(l.range[0]),E=l.r2l(l.range[1]),L=(S+E)/2,C=L,P=L,I=Math.abs(E-L),O=L-I*h*1.0001,z=L+I*h*1.0001,D=i.makePadFn(p,l,0),R=i.makePadFn(p,l,1);v(l,h);var F,B,N=Math.abs(l._m),j=i.concatExtremes(t,l),U=j.min,V=j.max;for(B=0;B<U.length;B++)(F=U[B].val-D(U[B])/N)>O&&F<C&&(C=F);for(B=0;B<V.length;B++)(F=V[B].val+R(V[B])/N)<z&&F>P&&(P=F);h/=(P-C)/(2*I),C=l.l2r(C),P=l.l2r(P),l.range=l._input.range=S<E?[C,P]:[P,C]}v(l,h)}}},r.getAxisGroup=function(t,e){for(var r=t._axisMatchGroups,n=0;n<r.length;n++){if(r[n][e])return\"g\"+n}return e},r.clean=function(t,e){if(e._inputDomain){for(var r=!1,n=e._id,i=t._fullLayout._axisConstraintGroups,a=0;a<i.length;a++)if(i[a][n]){r=!0;break}r&&\"domain\"===e.constrain||(e._input.domain=e.domain=e._inputDomain,delete e._inputDomain)}}},{\"../../constants/alignment\":767,\"../../constants/numerical\":775,\"../../lib\":799,\"./autorange\":848,\"./axis_ids\":853,\"./layout_attributes\":864,\"./scale_zoom\":868,\"./set_convert\":870}],858:[function(t,e,r){\"use strict\";var n=t(\"@plotly/d3\"),i=t(\"tinycolor2\"),a=t(\"has-passive-events\"),o=t(\"../../registry\"),s=t(\"../../lib\"),l=s.strTranslate,c=t(\"../../lib/svg_text_utils\"),u=t(\"../../components/color\"),f=t(\"../../components/drawing\"),h=t(\"../../components/fx\"),p=t(\"./axes\"),d=t(\"../../lib/setcursor\"),m=t(\"../../components/dragelement\"),g=t(\"../../components/dragelement/helpers\"),v=g.selectingOrDrawing,y=g.freeMode,x=t(\"../../constants/alignment\").FROM_TL,b=t(\"../../lib/clear_gl_canvases\"),_=t(\"../../plot_api/subroutines\").redrawReglTraces,w=t(\"../plots\"),T=t(\"./axis_ids\").getFromId,k=t(\"./select\").prepSelect,M=t(\"./select\").clearSelect,A=t(\"./select\").selectOnClick,S=t(\"./scale_zoom\"),E=t(\"./constants\"),L=E.MINDRAG,C=E.MINZOOM,P=!0;function I(t,e,r,n){var i=s.ensureSingle(t.draglayer,e,r,(function(e){e.classed(\"drag\",!0).style({fill:\"transparent\",\"stroke-width\":0}).attr(\"data-subplot\",t.id)}));return i.call(d,n),i.node()}function O(t,e,r,i,a,o,s){var l=I(t,\"rect\",e,r);return n.select(l).call(f.setRect,i,a,o,s),l}function z(t,e){for(var r=0;r<t.length;r++)if(!t[r].fixedrange)return e;return\"\"}function D(t,e,r,n,i){for(var a=0;a<t.length;a++){var o=t[a];if(!o.fixedrange)if(o.rangebreaks){var s=\"y\"===o._id.charAt(0),l=s?1-e:e,c=s?1-r:r;n[o._name+\".range[0]\"]=o.l2r(o.p2l(l*o._length)),n[o._name+\".range[1]\"]=o.l2r(o.p2l(c*o._length))}else{var u=o._rl[0],f=o._rl[1]-u;n[o._name+\".range[0]\"]=o.l2r(u+f*e),n[o._name+\".range[1]\"]=o.l2r(u+f*r)}}if(i&&i.length){var h=(e+(1-r))/2;D(i,h,1-h,n,[])}}function R(t,e){for(var r=0;r<t.length;r++){var n=t[r];if(!n.fixedrange)if(n.rangebreaks){var i=n._length,a=(n.p2l(0+e)-n.p2l(0)+(n.p2l(i+e)-n.p2l(i)))/2;n.range=[n.l2r(n._rl[0]-a),n.l2r(n._rl[1]-a)]}else n.range=[n.l2r(n._rl[0]-e/n._m),n.l2r(n._rl[1]-e/n._m)]}}function F(t){return 1-(t>=0?Math.min(t,.9):1/(1/Math.max(t,-.3)+3.222))}function B(t,e,r,n,i){return t.append(\"path\").attr(\"class\",\"zoombox\").style({fill:e>.2?\"rgba(0,0,0,0)\":\"rgba(255,255,255,0)\",\"stroke-width\":0}).attr(\"transform\",l(r,n)).attr(\"d\",i+\"Z\")}function N(t,e,r){return t.append(\"path\").attr(\"class\",\"zoombox-corners\").style({fill:u.background,stroke:u.defaultLine,\"stroke-width\":1,opacity:0}).attr(\"transform\",l(e,r)).attr(\"d\",\"M0,0Z\")}function j(t,e,r,n,i,a){t.attr(\"d\",n+\"M\"+r.l+\",\"+r.t+\"v\"+r.h+\"h\"+r.w+\"v-\"+r.h+\"h-\"+r.w+\"Z\"),U(t,e,i,a)}function U(t,e,r,n){r||(t.transition().style(\"fill\",n>.2?\"rgba(0,0,0,0.4)\":\"rgba(255,255,255,0.3)\").duration(200),e.transition().style(\"opacity\",1).duration(200))}function V(t){n.select(t).selectAll(\".zoombox,.js-zoombox-backdrop,.js-zoombox-menu,.zoombox-corners\").remove()}function q(t){P&&t.data&&t._context.showTips&&(s.notifier(s._(t,\"Double-click to zoom back out\"),\"long\"),P=!1)}function H(t){var e=Math.floor(Math.min(t.b-t.t,t.r-t.l,C)/2);return\"M\"+(t.l-3.5)+\",\"+(t.t-.5+e)+\"h3v\"+-e+\"h\"+e+\"v-3h-\"+(e+3)+\"ZM\"+(t.r+3.5)+\",\"+(t.t-.5+e)+\"h-3v\"+-e+\"h\"+-e+\"v-3h\"+(e+3)+\"ZM\"+(t.r+3.5)+\",\"+(t.b+.5-e)+\"h-3v\"+e+\"h\"+-e+\"v3h\"+(e+3)+\"ZM\"+(t.l-3.5)+\",\"+(t.b+.5-e)+\"h3v\"+e+\"h\"+e+\"v3h-\"+(e+3)+\"Z\"}function G(t,e,r,n,i){for(var a,o,l,c,u=!1,f={},h={},p=(i||{}).xaHash,d=(i||{}).yaHash,m=0;m<e.length;m++){var g=e[m];for(a in r)if(g[a]){for(l in g)i&&(p[l]||d[l])||(\"x\"===l.charAt(0)?r:n)[l]||(f[l]=a);for(o in n)i&&(p[o]||d[o])||!g[o]||(u=!0)}for(o in n)if(g[o])for(c in g)i&&(p[c]||d[c])||(\"x\"===c.charAt(0)?r:n)[c]||(h[c]=o)}u&&(s.extendFlat(f,h),h={});var v={},y=[];for(l in f){var x=T(t,l);y.push(x),v[x._id]=x}var b={},_=[];for(c in h){var w=T(t,c);_.push(w),b[w._id]=w}return{xaHash:v,yaHash:b,xaxes:y,yaxes:_,xLinks:f,yLinks:h,isSubplotConstrained:u}}function Y(t,e){if(a){var r=void 0!==t.onwheel?\"wheel\":\"mousewheel\";t._onwheel&&t.removeEventListener(r,t._onwheel),t._onwheel=e,t.addEventListener(r,e,{passive:!1})}else void 0!==t.onwheel?t.onwheel=e:void 0!==t.onmousewheel?t.onmousewheel=e:t.isAddedWheelEvent||(t.isAddedWheelEvent=!0,t.addEventListener(\"wheel\",e,{passive:!1}))}function W(t){var e=[];for(var r in t)e.push(t[r]);return e}e.exports={makeDragBox:function(t,e,r,a,l,u,d,g){var P,I,U,X,Z,J,K,Q,$,tt,et,rt,nt,it,at,ot,st,lt,ct,ut,ft,ht,pt,dt=t._fullLayout._zoomlayer,mt=d+g===\"nsew\",gt=1===(d+g).length;function vt(){if(P=e.xaxis,I=e.yaxis,$=P._length,tt=I._length,K=P._offset,Q=I._offset,(U={})[P._id]=P,(X={})[I._id]=I,d&&g)for(var r=e.overlays,n=0;n<r.length;n++){var i=r[n].xaxis;U[i._id]=i;var a=r[n].yaxis;X[a._id]=a}Z=W(U),J=W(X),nt=z(Z,g),it=z(J,d),at=!it&&!nt,rt=G(t,t._fullLayout._axisMatchGroups,U,X);var o=(et=G(t,t._fullLayout._axisConstraintGroups,U,X,rt)).isSubplotConstrained||rt.isSubplotConstrained;ot=g||o,st=d||o;var s=t._fullLayout;lt=s._has(\"scattergl\"),ct=s._has(\"splom\"),ut=s._has(\"svg\")}vt();var yt=function(t,e,r){if(!t)return\"pointer\";if(\"nsew\"===t)return r?\"\":\"pan\"===e?\"move\":\"crosshair\";return t.toLowerCase()+\"-resize\"}(it+nt,t._fullLayout.dragmode,mt),xt=O(e,d+g+\"drag\",yt,r,a,l,u);if(at&&!mt)return xt.onmousedown=null,xt.style.pointerEvents=\"none\",xt;var bt,_t,wt,Tt,kt,Mt,At,St,Et,Lt,Ct={element:xt,gd:t,plotinfo:e};function Pt(){Ct.plotinfo.selection=!1,M(t)}function It(t,r){var i=Ct.gd;if(i._fullLayout._activeShapeIndex>=0)i._fullLayout._deactivateShape(i);else{var a=i._fullLayout.clickmode;if(V(i),2!==t||gt||qt(),mt)a.indexOf(\"select\")>-1&&A(r,i,Z,J,e.id,Ct),a.indexOf(\"event\")>-1&&h.click(i,r,e.id);else if(1===t&&gt){var s=d?I:P,l=\"s\"===d||\"w\"===g?0:1,u=s._name+\".range[\"+l+\"]\",f=function(t,e){var r,i=t.range[e],a=Math.abs(i-t.range[1-e]);return\"date\"===t.type?i:\"log\"===t.type?(r=Math.ceil(Math.max(0,-Math.log(a)/Math.LN10))+3,n.format(\".\"+r+\"g\")(Math.pow(10,i))):(r=Math.floor(Math.log(Math.abs(i))/Math.LN10)-Math.floor(Math.log(a)/Math.LN10)+4,n.format(\".\"+String(r)+\"g\")(i))}(s,l),p=\"left\",m=\"middle\";if(s.fixedrange)return;d?(m=\"n\"===d?\"top\":\"bottom\",\"right\"===s.side&&(p=\"right\")):\"e\"===g&&(p=\"right\"),i._context.showAxisRangeEntryBoxes&&n.select(xt).call(c.makeEditable,{gd:i,immediate:!0,background:i._fullLayout.paper_bgcolor,text:String(f),fill:s.tickfont?s.tickfont.color:\"#444\",horizontalAlign:p,verticalAlign:m}).on(\"edit\",(function(t){var e=s.d2r(t);void 0!==e&&o.call(\"_guiRelayout\",i,u,e)}))}}}function Ot(e,r){if(t._transitioningWithDuration)return!1;var n=Math.max(0,Math.min($,ht*e+bt)),i=Math.max(0,Math.min(tt,pt*r+_t)),a=Math.abs(n-bt),o=Math.abs(i-_t);function s(){At=\"\",wt.r=wt.l,wt.t=wt.b,Et.attr(\"d\",\"M0,0Z\")}if(wt.l=Math.min(bt,n),wt.r=Math.max(bt,n),wt.t=Math.min(_t,i),wt.b=Math.max(_t,i),et.isSubplotConstrained)a>C||o>C?(At=\"xy\",a/$>o/tt?(o=a*tt/$,_t>i?wt.t=_t-o:wt.b=_t+o):(a=o*$/tt,bt>n?wt.l=bt-a:wt.r=bt+a),Et.attr(\"d\",H(wt))):s();else if(rt.isSubplotConstrained)if(a>C||o>C){At=\"xy\";var l=Math.min(wt.l/$,(tt-wt.b)/tt),c=Math.max(wt.r/$,(tt-wt.t)/tt);wt.l=l*$,wt.r=c*$,wt.b=(1-l)*tt,wt.t=(1-c)*tt,Et.attr(\"d\",H(wt))}else s();else!it||o<Math.min(Math.max(.6*a,L),C)?a<L||!nt?s():(wt.t=0,wt.b=tt,At=\"x\",Et.attr(\"d\",function(t,e){return\"M\"+(t.l-.5)+\",\"+(e-C-.5)+\"h-3v\"+(2*C+1)+\"h3ZM\"+(t.r+.5)+\",\"+(e-C-.5)+\"h3v\"+(2*C+1)+\"h-3Z\"}(wt,_t))):!nt||a<Math.min(.6*o,C)?(wt.l=0,wt.r=$,At=\"y\",Et.attr(\"d\",function(t,e){return\"M\"+(e-C-.5)+\",\"+(t.t-.5)+\"v-3h\"+(2*C+1)+\"v3ZM\"+(e-C-.5)+\",\"+(t.b+.5)+\"v3h\"+(2*C+1)+\"v-3Z\"}(wt,bt))):(At=\"xy\",Et.attr(\"d\",H(wt)));wt.w=wt.r-wt.l,wt.h=wt.b-wt.t,At&&(Lt=!0),t._dragged=Lt,j(St,Et,wt,kt,Mt,Tt),zt(),t.emit(\"plotly_relayouting\",ft),Mt=!0}function zt(){ft={},\"xy\"!==At&&\"x\"!==At||(D(Z,wt.l/$,wt.r/$,ft,et.xaxes),Ut(\"x\",ft)),\"xy\"!==At&&\"y\"!==At||(D(J,(tt-wt.b)/tt,(tt-wt.t)/tt,ft,et.yaxes),Ut(\"y\",ft))}function Dt(){zt(),V(t),Ht(),q(t)}Ct.prepFn=function(e,r,n){var a=Ct.dragmode,o=t._fullLayout.dragmode;o!==a&&(Ct.dragmode=o),vt(),ht=t._fullLayout._invScaleX,pt=t._fullLayout._invScaleY,at||(mt?e.shiftKey?\"pan\"===o?o=\"zoom\":v(o)||(o=\"pan\"):e.ctrlKey&&(o=\"pan\"):o=\"pan\"),y(o)?Ct.minDrag=1:Ct.minDrag=void 0,v(o)?(Ct.xaxes=Z,Ct.yaxes=J,k(e,r,n,Ct,o)):(Ct.clickFn=It,v(a)&&Pt(),at||(\"zoom\"===o?(Ct.moveFn=Ot,Ct.doneFn=Dt,Ct.minDrag=1,function(e,r,n){var a=xt.getBoundingClientRect();bt=r-a.left,_t=n-a.top,t._fullLayout._calcInverseTransform(t);var o=s.apply3DTransform(t._fullLayout._invTransform)(bt,_t);bt=o[0],_t=o[1],wt={l:bt,r:bt,w:0,t:_t,b:_t,h:0},Tt=t._hmpixcount?t._hmlumcount/t._hmpixcount:i(t._fullLayout.plot_bgcolor).getLuminance(),Mt=!1,At=\"xy\",Lt=!1,St=B(dt,Tt,K,Q,kt=\"M0,0H\"+$+\"V\"+tt+\"H0V0\"),Et=N(dt,K,Q)}(0,r,n)):\"pan\"===o&&(Ct.moveFn=jt,Ct.doneFn=Ht))),t._fullLayout._redrag=function(){var e=t._dragdata;if(e&&e.element===xt){var r=t._fullLayout.dragmode;v(r)||(vt(),Gt([0,0,$,tt]),Ct.moveFn(e.dx,e.dy))}}},m.init(Ct);var Rt=[0,0,$,tt],Ft=null,Bt=E.REDRAWDELAY,Nt=e.mainplot?t._fullLayout._plots[e.mainplot]:e;function jt(e,r){if(e*=ht,r*=pt,!t._transitioningWithDuration){if(t._fullLayout._replotting=!0,\"ew\"===nt||\"ns\"===it){var n=nt?-e:0,i=it?-r:0;if(rt.isSubplotConstrained){if(nt&&it){var a=(e/$-r/tt)/2;n=-(e=a*$),i=-(r=-a*tt)}it?n=-i*$/tt:i=-n*tt/$}return nt&&(R(Z,e),Ut(\"x\")),it&&(R(J,r),Ut(\"y\")),Gt([n,i,$,tt]),Vt(),void t.emit(\"plotly_relayouting\",ft)}var o,s,l=\"w\"===nt==(\"n\"===it)?1:-1;if(nt&&it&&(et.isSubplotConstrained||rt.isSubplotConstrained)){var c=(e/$+l*r/tt)/2;e=c*$,r=l*c*tt}if(\"w\"===nt?e=p(Z,0,e):\"e\"===nt?e=p(Z,1,-e):nt||(e=0),\"n\"===it?r=p(J,1,r):\"s\"===it?r=p(J,0,-r):it||(r=0),o=\"w\"===nt?e:0,s=\"n\"===it?r:0,et.isSubplotConstrained&&!rt.isSubplotConstrained||rt.isSubplotConstrained&&nt&&it&&l>0){var u;if(rt.isSubplotConstrained||!nt&&1===it.length){for(u=0;u<Z.length;u++)Z[u].range=Z[u]._r.slice(),S(Z[u],1-r/tt);o=(e=r*$/tt)/2}if(rt.isSubplotConstrained||!it&&1===nt.length){for(u=0;u<J.length;u++)J[u].range=J[u]._r.slice(),S(J[u],1-e/$);s=(r=e*tt/$)/2}}rt.isSubplotConstrained&&it||Ut(\"x\"),rt.isSubplotConstrained&&nt||Ut(\"y\");var f=$-e,h=tt-r;!rt.isSubplotConstrained||nt&&it||(nt?(s=o?0:e*tt/$,h=f*tt/$):(o=s?0:r*$/tt,f=h*$/tt)),Gt([o,s,f,h]),Vt(),t.emit(\"plotly_relayouting\",ft)}function p(t,e,r){for(var n,i,a=1-e,o=0;o<t.length;o++){var s=t[o];if(!s.fixedrange){n=s,i=s._rl[a]+(s._rl[e]-s._rl[a])/F(r/s._length);var l=s.l2r(i);!1!==l&&void 0!==l&&(s.range[e]=l)}}return n._length*(n._rl[e]-i)/(n._rl[e]-n._rl[a])}}function Ut(t,e){for(var r=rt.isSubplotConstrained?{x:J,y:Z}[t]:rt[t+\"axes\"],n=rt.isSubplotConstrained?{x:Z,y:J}[t]:[],i=0;i<r.length;i++){var a=r[i],o=a._id,s=rt.xLinks[o]||rt.yLinks[o],l=n[0]||U[s]||X[s];l&&(e?(e[a._name+\".range[0]\"]=e[l._name+\".range[0]\"],e[a._name+\".range[1]\"]=e[l._name+\".range[1]\"]):a.range=l.range.slice())}}function Vt(){var e,r=[];function n(t){for(e=0;e<t.length;e++)t[e].fixedrange||r.push(t[e]._id)}for(ot&&(n(Z),n(et.xaxes),n(rt.xaxes)),st&&(n(J),n(et.yaxes),n(rt.yaxes)),ft={},e=0;e<r.length;e++){var i=r[e],a=T(t,i);p.drawOne(t,a,{skipTitle:!0}),ft[a._name+\".range[0]\"]=a.range[0],ft[a._name+\".range[1]\"]=a.range[1]}p.redrawComponents(t,r)}function qt(){if(!t._transitioningWithDuration){var e=t._context.doubleClick,r=[];nt&&(r=r.concat(Z)),it&&(r=r.concat(J)),rt.xaxes&&(r=r.concat(rt.xaxes)),rt.yaxes&&(r=r.concat(rt.yaxes));var n,i,a,s={};if(\"reset+autosize\"===e)for(e=\"autosize\",i=0;i<r.length;i++)if((n=r[i])._rangeInitial&&(n.range[0]!==n._rangeInitial[0]||n.range[1]!==n._rangeInitial[1])||!n._rangeInitial&&!n.autorange){e=\"reset\";break}if(\"autosize\"===e)for(i=0;i<r.length;i++)(n=r[i]).fixedrange||(s[n._name+\".autorange\"]=!0);else if(\"reset\"===e)for((nt||et.isSubplotConstrained)&&(r=r.concat(et.xaxes)),it&&!et.isSubplotConstrained&&(r=r.concat(et.yaxes)),et.isSubplotConstrained&&(nt?it||(r=r.concat(J)):r=r.concat(Z)),i=0;i<r.length;i++)(n=r[i]).fixedrange||(n._rangeInitial?(a=n._rangeInitial,s[n._name+\".range[0]\"]=a[0],s[n._name+\".range[1]\"]=a[1]):s[n._name+\".autorange\"]=!0);t.emit(\"plotly_doubleclick\",null),o.call(\"_guiRelayout\",t,s)}}function Ht(){Gt([0,0,$,tt]),s.syncOrAsync([w.previousPromises,function(){t._fullLayout._replotting=!1,o.call(\"_guiRelayout\",t,ft)}],t)}function Gt(e){var r,n,i,a,l=t._fullLayout,c=l._plots,u=l._subplots.cartesian;if(ct&&o.subplotsRegistry.splom.drag(t),lt)for(r=0;r<u.length;r++)if(i=(n=c[u[r]]).xaxis,a=n.yaxis,n._scene){var h=s.simpleMap(i.range,i.r2l),p=s.simpleMap(a.range,a.r2l);n._scene.update({range:[h[0],p[0],h[1],p[1]]})}if((ct||lt)&&(b(t),_(t)),ut){var m=e[2]/P._length,v=e[3]/I._length;for(r=0;r<u.length;r++){i=(n=c[u[r]]).xaxis,a=n.yaxis;var y,x,w,T,k=(ot||rt.isSubplotConstrained)&&!i.fixedrange&&U[i._id],M=(st||rt.isSubplotConstrained)&&!a.fixedrange&&X[a._id];if(k?(y=m,w=g||rt.isSubplotConstrained?e[0]:Xt(i,y)):rt.xaHash[i._id]?(y=m,w=e[0]*i._length/P._length):rt.yaHash[i._id]?(y=v,w=\"ns\"===it?-e[1]*i._length/I._length:Xt(i,y,{n:\"top\",s:\"bottom\"}[it])):w=Wt(i,y=Yt(i,m,v)),M?(x=v,T=d||rt.isSubplotConstrained?e[1]:Xt(a,x)):rt.yaHash[a._id]?(x=v,T=e[1]*a._length/I._length):rt.xaHash[a._id]?(x=m,T=\"ew\"===nt?-e[0]*a._length/P._length:Xt(a,x,{e:\"right\",w:\"left\"}[nt])):T=Wt(a,x=Yt(a,m,v)),y||x){y||(y=1),x||(x=1);var A=i._offset-w/y,S=a._offset-T/x;n.clipRect.call(f.setTranslate,w,T).call(f.setScale,y,x),n.plot.call(f.setTranslate,A,S).call(f.setScale,1/y,1/x),y===n.xScaleFactor&&x===n.yScaleFactor||(f.setPointGroupScale(n.zoomScalePts,y,x),f.setTextPointsScale(n.zoomScaleTxt,y,x)),f.hideOutsideRangePoints(n.clipOnAxisFalseTraces,n),n.xScaleFactor=y,n.yScaleFactor=x}}}}function Yt(t,e,r){return t.fixedrange?0:ot&&et.xaHash[t._id]?e:st&&(et.isSubplotConstrained?et.xaHash:et.yaHash)[t._id]?r:0}function Wt(t,e){return e?(t.range=t._r.slice(),S(t,e),Xt(t,e)):0}function Xt(t,e,r){return t._length*(1-e)*x[r||t.constraintoward||\"middle\"]}return d.length*g.length!=1&&Y(xt,(function(e){if(t._context._scrollZoom.cartesian||t._fullLayout._enablescrollzoom){if(Pt(),t._transitioningWithDuration)return e.preventDefault(),void e.stopPropagation();vt(),clearTimeout(Ft);var r=-e.deltaY;if(isFinite(r)||(r=e.wheelDelta/10),isFinite(r)){var n,i=Math.exp(-Math.min(Math.max(r,-20),20)/200),a=Nt.draglayer.select(\".nsewdrag\").node().getBoundingClientRect(),o=(e.clientX-a.left)/a.width,l=(a.bottom-e.clientY)/a.height;if(ot){for(g||(o=.5),n=0;n<Z.length;n++)c(Z[n],o,i);Ut(\"x\"),Rt[2]*=i,Rt[0]+=Rt[2]*o*(1/i-1)}if(st){for(d||(l=.5),n=0;n<J.length;n++)c(J[n],l,i);Ut(\"y\"),Rt[3]*=i,Rt[1]+=Rt[3]*(1-l)*(1/i-1)}Gt(Rt),Vt(),t.emit(\"plotly_relayouting\",ft),Ft=setTimeout((function(){t._fullLayout&&(Rt=[0,0,$,tt],Ht())}),Bt),e.preventDefault()}else s.log(\"Did not find wheel motion attributes: \",e)}function c(t,e,r){if(!t.fixedrange){var n=s.simpleMap(t.range,t.r2l),i=n[0]+(n[1]-n[0])*e;t.range=n.map((function(e){return t.l2r(i+(e-i)*r)}))}}})),xt},makeDragger:I,makeRectDragger:O,makeZoombox:B,makeCorners:N,updateZoombox:j,xyCorners:H,transitionZoombox:U,removeZoombox:V,showDoubleClickNotifier:q,attachWheelEventHandler:Y}},{\"../../components/color\":662,\"../../components/dragelement\":681,\"../../components/dragelement/helpers\":680,\"../../components/drawing\":684,\"../../components/fx\":702,\"../../constants/alignment\":767,\"../../lib\":799,\"../../lib/clear_gl_canvases\":783,\"../../lib/setcursor\":820,\"../../lib/svg_text_utils\":824,\"../../plot_api/subroutines\":839,\"../../registry\":927,\"../plots\":913,\"./axes\":849,\"./axis_ids\":853,\"./constants\":856,\"./scale_zoom\":868,\"./select\":869,\"@plotly/d3\":58,\"has-passive-events\":440,tinycolor2:594}],859:[function(t,e,r){\"use strict\";var n=t(\"@plotly/d3\"),i=t(\"../../components/fx\"),a=t(\"../../components/dragelement\"),o=t(\"../../lib/setcursor\"),s=t(\"./dragbox\").makeDragBox,l=t(\"./constants\").DRAGGERSIZE;r.initInteractions=function(t){var e=t._fullLayout;if(t._context.staticPlot)n.select(t).selectAll(\".drag\").remove();else if(e._has(\"cartesian\")||e._has(\"splom\")){Object.keys(e._plots||{}).sort((function(t,r){if((e._plots[t].mainplot&&!0)===(e._plots[r].mainplot&&!0)){var n=t.split(\"y\"),i=r.split(\"y\");return n[0]===i[0]?Number(n[1]||1)-Number(i[1]||1):Number(n[0]||1)-Number(i[0]||1)}return e._plots[t].mainplot?1:-1})).forEach((function(r){var n=e._plots[r],o=n.xaxis,c=n.yaxis;if(!n.mainplot){var u=s(t,n,o._offset,c._offset,o._length,c._length,\"ns\",\"ew\");u.onmousemove=function(e){t._fullLayout._rehover=function(){t._fullLayout._hoversubplot===r&&t._fullLayout._plots[r]&&i.hover(t,e,r)},i.hover(t,e,r),t._fullLayout._lasthover=u,t._fullLayout._hoversubplot=r},u.onmouseout=function(e){t._dragging||(t._fullLayout._hoversubplot=null,a.unhover(t,e))},t._context.showAxisDragHandles&&(s(t,n,o._offset-l,c._offset-l,l,l,\"n\",\"w\"),s(t,n,o._offset+o._length,c._offset-l,l,l,\"n\",\"e\"),s(t,n,o._offset-l,c._offset+c._length,l,l,\"s\",\"w\"),s(t,n,o._offset+o._length,c._offset+c._length,l,l,\"s\",\"e\"))}if(t._context.showAxisDragHandles){if(r===o._mainSubplot){var f=o._mainLinePosition;\"top\"===o.side&&(f-=l),s(t,n,o._offset+.1*o._length,f,.8*o._length,l,\"\",\"ew\"),s(t,n,o._offset,f,.1*o._length,l,\"\",\"w\"),s(t,n,o._offset+.9*o._length,f,.1*o._length,l,\"\",\"e\")}if(r===c._mainSubplot){var h=c._mainLinePosition;\"right\"!==c.side&&(h-=l),s(t,n,h,c._offset+.1*c._length,l,.8*c._length,\"ns\",\"\"),s(t,n,h,c._offset+.9*c._length,l,.1*c._length,\"s\",\"\"),s(t,n,h,c._offset,l,.1*c._length,\"n\",\"\")}}}));var o=e._hoverlayer.node();o.onmousemove=function(r){r.target=t._fullLayout._lasthover,i.hover(t,r,e._hoversubplot)},o.onclick=function(e){e.target=t._fullLayout._lasthover,i.click(t,e)},o.onmousedown=function(e){t._fullLayout._lasthover.onmousedown(e)},r.updateFx(t)}},r.updateFx=function(t){var e=t._fullLayout,r=\"pan\"===e.dragmode?\"move\":\"crosshair\";o(e._draggers,r)}},{\"../../components/dragelement\":681,\"../../components/fx\":702,\"../../lib/setcursor\":820,\"./constants\":856,\"./dragbox\":858,\"@plotly/d3\":58}],860:[function(t,e,r){\"use strict\";e.exports={clearOutlineControllers:function(t){var e=t._fullLayout._zoomlayer;e&&e.selectAll(\".outline-controllers\").remove()},clearSelect:function(t){var e=t._fullLayout._zoomlayer;e&&e.selectAll(\".select-outline\").remove(),t._fullLayout._drawing=!1}}},{}],861:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").strTranslate;function i(t,e){switch(t.type){case\"log\":return t.p2d(e);case\"date\":return t.p2r(e,0,t.calendar);default:return t.p2r(e)}}e.exports={p2r:i,r2p:function(t,e){switch(t.type){case\"log\":return t.d2p(e);case\"date\":return t.r2p(e,0,t.calendar);default:return t.r2p(e)}},axValue:function(t){var e=\"y\"===t._id.charAt(0)?1:0;return function(r){return i(t,r[e])}},getTransform:function(t){return n(t.xaxis._offset,t.yaxis._offset)}}},{\"../../lib\":799}],862:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"./axis_ids\");e.exports=function(t){return function(e,r){var o=e[t];if(Array.isArray(o))for(var s=n.subplotsRegistry.cartesian,l=s.idRegex,c=r._subplots,u=c.xaxis,f=c.yaxis,h=c.cartesian,p=r._has(\"cartesian\")||r._has(\"gl2d\"),d=0;d<o.length;d++){var m=o[d];if(i.isPlainObject(m)){var g=a.cleanId(m.xref,\"x\",!1),v=a.cleanId(m.yref,\"y\",!1),y=l.x.test(g),x=l.y.test(v);if(y||x){p||i.pushUnique(r._basePlotModules,s);var b=!1;y&&-1===u.indexOf(g)&&(u.push(g),b=!0),x&&-1===f.indexOf(v)&&(f.push(v),b=!0),b&&y&&x&&h.push(g+v)}}}}}},{\"../../lib\":799,\"../../registry\":927,\"./axis_ids\":853}],863:[function(t,e,r){\"use strict\";var n=t(\"@plotly/d3\"),i=t(\"../../registry\"),a=t(\"../../lib\"),o=t(\"../plots\"),s=t(\"../../components/drawing\"),l=t(\"../get_data\").getModuleCalcData,c=t(\"./axis_ids\"),u=t(\"./constants\"),f=t(\"../../constants/xmlns_namespaces\"),h=a.ensureSingle;function p(t,e,r){return a.ensureSingle(t,e,r,(function(t){t.datum(r)}))}function d(t,e,r,a,o){for(var c,f,h,p=u.traceLayerClasses,d=t._fullLayout,m=d._modules,g=[],v=[],y=0;y<m.length;y++){var x=(c=m[y]).name,b=i.modules[x].categories;if(b.svg){var _=c.layerName||x+\"layer\",w=c.plot;h=(f=l(r,w))[0],r=f[1],h.length&&g.push({i:p.indexOf(_),className:_,plotMethod:w,cdModule:h}),b.zoomScale&&v.push(\".\"+_)}}g.sort((function(t,e){return t.i-e.i}));var T=e.plot.selectAll(\"g.mlayer\").data(g,(function(t){return t.className}));if(T.enter().append(\"g\").attr(\"class\",(function(t){return t.className})).classed(\"mlayer\",!0).classed(\"rangeplot\",e.isRangePlot),T.exit().remove(),T.order(),T.each((function(r){var i=n.select(this),l=r.className;r.plotMethod(t,e,r.cdModule,i,a,o),-1===u.clipOnAxisFalseQuery.indexOf(\".\"+l)&&s.setClipUrl(i,e.layerClipId,t)})),d._has(\"scattergl\")&&(c=i.getModule(\"scattergl\"),h=l(r,c)[0],c.plot(t,e,h)),!t._context.staticPlot&&(e._hasClipOnAxisFalse&&(e.clipOnAxisFalseTraces=e.plot.selectAll(u.clipOnAxisFalseQuery.join(\",\")).selectAll(\".trace\")),v.length)){var k=e.plot.selectAll(v.join(\",\")).selectAll(\".trace\");e.zoomScalePts=k.selectAll(\"path.point\"),e.zoomScaleTxt=k.selectAll(\".textpoint\")}}function m(t,e){var r=e.plotgroup,n=e.id,i=u.layerValue2layerClass[e.xaxis.layer],a=u.layerValue2layerClass[e.yaxis.layer],o=t._fullLayout._hasOnlyLargeSploms;if(e.mainplot){var s=e.mainplotinfo,l=s.plotgroup,f=n+\"-x\",d=n+\"-y\";e.gridlayer=s.gridlayer,e.zerolinelayer=s.zerolinelayer,h(s.overlinesBelow,\"path\",f),h(s.overlinesBelow,\"path\",d),h(s.overaxesBelow,\"g\",f),h(s.overaxesBelow,\"g\",d),e.plot=h(s.overplot,\"g\",n),h(s.overlinesAbove,\"path\",f),h(s.overlinesAbove,\"path\",d),h(s.overaxesAbove,\"g\",f),h(s.overaxesAbove,\"g\",d),e.xlines=l.select(\".overlines-\"+i).select(\".\"+f),e.ylines=l.select(\".overlines-\"+a).select(\".\"+d),e.xaxislayer=l.select(\".overaxes-\"+i).select(\".\"+f),e.yaxislayer=l.select(\".overaxes-\"+a).select(\".\"+d)}else if(o)e.xlines=h(r,\"path\",\"xlines-above\"),e.ylines=h(r,\"path\",\"ylines-above\"),e.xaxislayer=h(r,\"g\",\"xaxislayer-above\"),e.yaxislayer=h(r,\"g\",\"yaxislayer-above\");else{var m=h(r,\"g\",\"layer-subplot\");e.shapelayer=h(m,\"g\",\"shapelayer\"),e.imagelayer=h(m,\"g\",\"imagelayer\"),e.gridlayer=h(r,\"g\",\"gridlayer\"),e.zerolinelayer=h(r,\"g\",\"zerolinelayer\"),h(r,\"path\",\"xlines-below\"),h(r,\"path\",\"ylines-below\"),e.overlinesBelow=h(r,\"g\",\"overlines-below\"),h(r,\"g\",\"xaxislayer-below\"),h(r,\"g\",\"yaxislayer-below\"),e.overaxesBelow=h(r,\"g\",\"overaxes-below\"),e.plot=h(r,\"g\",\"plot\"),e.overplot=h(r,\"g\",\"overplot\"),e.xlines=h(r,\"path\",\"xlines-above\"),e.ylines=h(r,\"path\",\"ylines-above\"),e.overlinesAbove=h(r,\"g\",\"overlines-above\"),h(r,\"g\",\"xaxislayer-above\"),h(r,\"g\",\"yaxislayer-above\"),e.overaxesAbove=h(r,\"g\",\"overaxes-above\"),e.xlines=r.select(\".xlines-\"+i),e.ylines=r.select(\".ylines-\"+a),e.xaxislayer=r.select(\".xaxislayer-\"+i),e.yaxislayer=r.select(\".yaxislayer-\"+a)}o||(p(e.gridlayer,\"g\",e.xaxis._id),p(e.gridlayer,\"g\",e.yaxis._id),e.gridlayer.selectAll(\"g\").map((function(t){return t[0]})).sort(c.idSort)),e.xlines.style(\"fill\",\"none\").classed(\"crisp\",!0),e.ylines.style(\"fill\",\"none\").classed(\"crisp\",!0)}function g(t,e){if(t){var r={};for(var i in t.each((function(t){var i=t[0];n.select(this).remove(),v(i,e),r[i]=!0})),e._plots)for(var a=e._plots[i].overlays||[],o=0;o<a.length;o++){var s=a[o];r[s.id]&&s.plot.selectAll(\".trace\").remove()}}}function v(t,e){e._draggers.selectAll(\"g.\"+t).remove(),e._defs.select(\"#clip\"+e._uid+t+\"plot\").remove()}r.name=\"cartesian\",r.attr=[\"xaxis\",\"yaxis\"],r.idRoot=[\"x\",\"y\"],r.idRegex=u.idRegex,r.attrRegex=u.attrRegex,r.attributes=t(\"./attributes\"),r.layoutAttributes=t(\"./layout_attributes\"),r.supplyLayoutDefaults=t(\"./layout_defaults\"),r.transitionAxes=t(\"./transition_axes\"),r.finalizeSubplots=function(t,e){var r,n,i,o=e._subplots,s=o.xaxis,l=o.yaxis,f=o.cartesian,h=f.concat(o.gl2d||[]),p={},d={};for(r=0;r<h.length;r++){var m=h[r].split(\"y\");p[m[0]]=1,d[\"y\"+m[1]]=1}for(r=0;r<s.length;r++)p[n=s[r]]||(i=(t[c.id2name(n)]||{}).anchor,u.idRegex.y.test(i)||(i=\"y\"),f.push(n+i),h.push(n+i),d[i]||(d[i]=1,a.pushUnique(l,i)));for(r=0;r<l.length;r++)d[i=l[r]]||(n=(t[c.id2name(i)]||{}).anchor,u.idRegex.x.test(n)||(n=\"x\"),f.push(n+i),h.push(n+i),p[n]||(p[n]=1,a.pushUnique(s,n)));if(!h.length){for(var g in n=\"\",i=\"\",t){if(u.attrRegex.test(g))\"x\"===g.charAt(0)?(!n||+g.substr(5)<+n.substr(5))&&(n=g):(!i||+g.substr(5)<+i.substr(5))&&(i=g)}n=n?c.name2id(n):\"x\",i=i?c.name2id(i):\"y\",s.push(n),l.push(i),f.push(n+i)}},r.plot=function(t,e,r,n){var i,a=t._fullLayout,o=a._subplots.cartesian,s=t.calcdata;if(!Array.isArray(e))for(e=[],i=0;i<s.length;i++)e.push(i);for(i=0;i<o.length;i++){for(var l,c=o[i],u=a._plots[c],f=[],h=0;h<s.length;h++){var p=s[h],m=p[0].trace;m.xaxis+m.yaxis===c&&((-1!==e.indexOf(m.index)||m.carpet)&&(l&&l[0].trace.xaxis+l[0].trace.yaxis===c&&-1!==[\"tonextx\",\"tonexty\",\"tonext\"].indexOf(m.fill)&&-1===f.indexOf(l)&&f.push(l),f.push(p)),l=p)}d(t,u,f,r,n)}},r.clean=function(t,e,r,n){var i,a,o,s=n._plots||{},l=e._plots||{},u=n._subplots||{};if(n._hasOnlyLargeSploms&&!e._hasOnlyLargeSploms)for(o in s)(i=s[o]).plotgroup&&i.plotgroup.remove();var f=n._has&&n._has(\"gl\"),h=e._has&&e._has(\"gl\");if(f&&!h)for(o in s)(i=s[o])._scene&&i._scene.destroy();if(u.xaxis&&u.yaxis){var p=c.listIds({_fullLayout:n});for(a=0;a<p.length;a++){var d=p[a];e[c.id2name(d)]||n._infolayer.selectAll(\".g-\"+d+\"title\").remove()}}var m=n._has&&n._has(\"cartesian\"),y=e._has&&e._has(\"cartesian\");if(m&&!y)g(n._cartesianlayer.selectAll(\".subplot\"),n),n._defs.selectAll(\".axesclip\").remove(),delete n._axisConstraintGroups,delete n._axisMatchGroups;else if(u.cartesian)for(a=0;a<u.cartesian.length;a++){var x=u.cartesian[a];if(!l[x]){var b=\".\"+x+\",.\"+x+\"-x,.\"+x+\"-y\";n._cartesianlayer.selectAll(b).remove(),v(x,n)}}},r.drawFramework=function(t){var e=t._fullLayout,r=function(t){var e,r,n,i,a,o,s=t._fullLayout,l=s._subplots.cartesian,c=l.length,u=[],f=[];for(e=0;e<c;e++){n=l[e],i=s._plots[n],a=i.xaxis,o=i.yaxis;var h=a._mainAxis,p=o._mainAxis,d=h._id+p._id,m=s._plots[d];i.overlays=[],d!==n&&m?(i.mainplot=d,i.mainplotinfo=m,f.push(n)):(i.mainplot=void 0,i.mainplotinfo=void 0,u.push(n))}for(e=0;e<f.length;e++)n=f[e],(i=s._plots[n]).mainplotinfo.overlays.push(i);var g=u.concat(f),v=new Array(c);for(e=0;e<c;e++){n=g[e],i=s._plots[n],a=i.xaxis,o=i.yaxis;var y=[n,a.layer,o.layer,a.overlaying||\"\",o.overlaying||\"\"];for(r=0;r<i.overlays.length;r++)y.push(i.overlays[r].id);v[e]=y}return v}(t),i=e._cartesianlayer.selectAll(\".subplot\").data(r,String);i.enter().append(\"g\").attr(\"class\",(function(t){return\"subplot \"+t[0]})),i.order(),i.exit().call(g,e),i.each((function(r){var i=r[0],a=e._plots[i];a.plotgroup=n.select(this),m(t,a),a.draglayer=h(e._draggers,\"g\",i)}))},r.rangePlot=function(t,e,r){m(t,e),d(t,e,r),o.style(t)},r.toSVG=function(t){var e=t._fullLayout._glimages,r=n.select(t).selectAll(\".svg-container\");r.filter((function(t,e){return e===r.size()-1})).selectAll(\".gl-canvas-context, .gl-canvas-focus\").each((function(){var t=this.toDataURL(\"image/png\");e.append(\"svg:image\").attr({xmlns:f.svg,\"xlink:href\":t,preserveAspectRatio:\"none\",x:0,y:0,width:this.width,height:this.height})}))},r.updateFx=t(\"./graph_interact\").updateFx},{\"../../components/drawing\":684,\"../../constants/xmlns_namespaces\":776,\"../../lib\":799,\"../../registry\":927,\"../get_data\":887,\"../plots\":913,\"./attributes\":847,\"./axis_ids\":853,\"./constants\":856,\"./graph_interact\":859,\"./layout_attributes\":864,\"./layout_defaults\":865,\"./transition_axes\":874,\"@plotly/d3\":58}],864:[function(t,e,r){\"use strict\";var n=t(\"../font_attributes\"),i=t(\"../../components/color/attributes\"),a=t(\"../../components/drawing/attributes\").dash,o=t(\"../../lib/extend\").extendFlat,s=t(\"../../plot_api/plot_template\").templatedArray,l=t(\"../../plots/cartesian/axis_format_attributes\").descriptionWithDates,c=t(\"../../constants/numerical\").ONEDAY,u=t(\"./constants\"),f=u.HOUR_PATTERN,h=u.WEEKDAY_PATTERN;e.exports={visible:{valType:\"boolean\",editType:\"plot\"},color:{valType:\"color\",dflt:i.defaultLine,editType:\"ticks\"},title:{text:{valType:\"string\",editType:\"ticks\"},font:n({editType:\"ticks\"}),standoff:{valType:\"number\",min:0,editType:\"ticks\"},editType:\"ticks\"},type:{valType:\"enumerated\",values:[\"-\",\"linear\",\"log\",\"date\",\"category\",\"multicategory\"],dflt:\"-\",editType:\"calc\",_noTemplating:!0},autotypenumbers:{valType:\"enumerated\",values:[\"convert types\",\"strict\"],dflt:\"convert types\",editType:\"calc\"},autorange:{valType:\"enumerated\",values:[!0,!1,\"reversed\"],dflt:!0,editType:\"axrange\",impliedEdits:{\"range[0]\":void 0,\"range[1]\":void 0}},rangemode:{valType:\"enumerated\",values:[\"normal\",\"tozero\",\"nonnegative\"],dflt:\"normal\",editType:\"plot\"},range:{valType:\"info_array\",items:[{valType:\"any\",editType:\"axrange\",impliedEdits:{\"^autorange\":!1},anim:!0},{valType:\"any\",editType:\"axrange\",impliedEdits:{\"^autorange\":!1},anim:!0}],editType:\"axrange\",impliedEdits:{autorange:!1},anim:!0},fixedrange:{valType:\"boolean\",dflt:!1,editType:\"calc\"},scaleanchor:{valType:\"enumerated\",values:[u.idRegex.x.toString(),u.idRegex.y.toString()],editType:\"plot\"},scaleratio:{valType:\"number\",min:0,dflt:1,editType:\"plot\"},constrain:{valType:\"enumerated\",values:[\"range\",\"domain\"],editType:\"plot\"},constraintoward:{valType:\"enumerated\",values:[\"left\",\"center\",\"right\",\"top\",\"middle\",\"bottom\"],editType:\"plot\"},matches:{valType:\"enumerated\",values:[u.idRegex.x.toString(),u.idRegex.y.toString()],editType:\"calc\"},rangebreaks:s(\"rangebreak\",{enabled:{valType:\"boolean\",dflt:!0,editType:\"calc\"},bounds:{valType:\"info_array\",items:[{valType:\"any\",editType:\"calc\"},{valType:\"any\",editType:\"calc\"}],editType:\"calc\"},pattern:{valType:\"enumerated\",values:[h,f,\"\"],editType:\"calc\"},values:{valType:\"info_array\",freeLength:!0,editType:\"calc\",items:{valType:\"any\",editType:\"calc\"}},dvalue:{valType:\"number\",editType:\"calc\",min:0,dflt:c},editType:\"calc\"}),tickmode:{valType:\"enumerated\",values:[\"auto\",\"linear\",\"array\"],editType:\"ticks\",impliedEdits:{tick0:void 0,dtick:void 0}},nticks:{valType:\"integer\",min:0,dflt:0,editType:\"ticks\"},tick0:{valType:\"any\",editType:\"ticks\",impliedEdits:{tickmode:\"linear\"}},dtick:{valType:\"any\",editType:\"ticks\",impliedEdits:{tickmode:\"linear\"}},tickvals:{valType:\"data_array\",editType:\"ticks\"},ticktext:{valType:\"data_array\",editType:\"ticks\"},ticks:{valType:\"enumerated\",values:[\"outside\",\"inside\",\"\"],editType:\"ticks\"},tickson:{valType:\"enumerated\",values:[\"labels\",\"boundaries\"],dflt:\"labels\",editType:\"ticks\"},ticklabelmode:{valType:\"enumerated\",values:[\"instant\",\"period\"],dflt:\"instant\",editType:\"ticks\"},ticklabelposition:{valType:\"enumerated\",values:[\"outside\",\"inside\",\"outside top\",\"inside top\",\"outside left\",\"inside left\",\"outside right\",\"inside right\",\"outside bottom\",\"inside bottom\"],dflt:\"outside\",editType:\"calc\"},ticklabeloverflow:{valType:\"enumerated\",values:[\"allow\",\"hide past div\",\"hide past domain\"],editType:\"calc\"},mirror:{valType:\"enumerated\",values:[!0,\"ticks\",!1,\"all\",\"allticks\"],dflt:!1,editType:\"ticks+layoutstyle\"},ticklen:{valType:\"number\",min:0,dflt:5,editType:\"ticks\"},tickwidth:{valType:\"number\",min:0,dflt:1,editType:\"ticks\"},tickcolor:{valType:\"color\",dflt:i.defaultLine,editType:\"ticks\"},showticklabels:{valType:\"boolean\",dflt:!0,editType:\"ticks\"},automargin:{valType:\"boolean\",dflt:!1,editType:\"ticks\"},showspikes:{valType:\"boolean\",dflt:!1,editType:\"modebar\"},spikecolor:{valType:\"color\",dflt:null,editType:\"none\"},spikethickness:{valType:\"number\",dflt:3,editType:\"none\"},spikedash:o({},a,{dflt:\"dash\",editType:\"none\"}),spikemode:{valType:\"flaglist\",flags:[\"toaxis\",\"across\",\"marker\"],dflt:\"toaxis\",editType:\"none\"},spikesnap:{valType:\"enumerated\",values:[\"data\",\"cursor\",\"hovered data\"],dflt:\"hovered data\",editType:\"none\"},tickfont:n({editType:\"ticks\"}),tickangle:{valType:\"angle\",dflt:\"auto\",editType:\"ticks\"},tickprefix:{valType:\"string\",dflt:\"\",editType:\"ticks\"},showtickprefix:{valType:\"enumerated\",values:[\"all\",\"first\",\"last\",\"none\"],dflt:\"all\",editType:\"ticks\"},ticksuffix:{valType:\"string\",dflt:\"\",editType:\"ticks\"},showticksuffix:{valType:\"enumerated\",values:[\"all\",\"first\",\"last\",\"none\"],dflt:\"all\",editType:\"ticks\"},showexponent:{valType:\"enumerated\",values:[\"all\",\"first\",\"last\",\"none\"],dflt:\"all\",editType:\"ticks\"},exponentformat:{valType:\"enumerated\",values:[\"none\",\"e\",\"E\",\"power\",\"SI\",\"B\"],dflt:\"B\",editType:\"ticks\"},minexponent:{valType:\"number\",dflt:3,min:0,editType:\"ticks\"},separatethousands:{valType:\"boolean\",dflt:!1,editType:\"ticks\"},tickformat:{valType:\"string\",dflt:\"\",editType:\"ticks\",description:l(\"tick label\")},tickformatstops:s(\"tickformatstop\",{enabled:{valType:\"boolean\",dflt:!0,editType:\"ticks\"},dtickrange:{valType:\"info_array\",items:[{valType:\"any\",editType:\"ticks\"},{valType:\"any\",editType:\"ticks\"}],editType:\"ticks\"},value:{valType:\"string\",dflt:\"\",editType:\"ticks\"},editType:\"ticks\"}),hoverformat:{valType:\"string\",dflt:\"\",editType:\"none\",description:l(\"hover text\")},showline:{valType:\"boolean\",dflt:!1,editType:\"ticks+layoutstyle\"},linecolor:{valType:\"color\",dflt:i.defaultLine,editType:\"layoutstyle\"},linewidth:{valType:\"number\",min:0,dflt:1,editType:\"ticks+layoutstyle\"},showgrid:{valType:\"boolean\",editType:\"ticks\"},gridcolor:{valType:\"color\",dflt:i.lightLine,editType:\"ticks\"},gridwidth:{valType:\"number\",min:0,dflt:1,editType:\"ticks\"},zeroline:{valType:\"boolean\",editType:\"ticks\"},zerolinecolor:{valType:\"color\",dflt:i.defaultLine,editType:\"ticks\"},zerolinewidth:{valType:\"number\",dflt:1,editType:\"ticks\"},showdividers:{valType:\"boolean\",dflt:!0,editType:\"ticks\"},dividercolor:{valType:\"color\",dflt:i.defaultLine,editType:\"ticks\"},dividerwidth:{valType:\"number\",dflt:1,editType:\"ticks\"},anchor:{valType:\"enumerated\",values:[\"free\",u.idRegex.x.toString(),u.idRegex.y.toString()],editType:\"plot\"},side:{valType:\"enumerated\",values:[\"top\",\"bottom\",\"left\",\"right\"],editType:\"plot\"},overlaying:{valType:\"enumerated\",values:[\"free\",u.idRegex.x.toString(),u.idRegex.y.toString()],editType:\"plot\"},layer:{valType:\"enumerated\",values:[\"above traces\",\"below traces\"],dflt:\"above traces\",editType:\"plot\"},domain:{valType:\"info_array\",items:[{valType:\"number\",min:0,max:1,editType:\"plot\"},{valType:\"number\",min:0,max:1,editType:\"plot\"}],dflt:[0,1],editType:\"plot\"},position:{valType:\"number\",min:0,max:1,dflt:0,editType:\"plot\"},categoryorder:{valType:\"enumerated\",values:[\"trace\",\"category ascending\",\"category descending\",\"array\",\"total ascending\",\"total descending\",\"min ascending\",\"min descending\",\"max ascending\",\"max descending\",\"sum ascending\",\"sum descending\",\"mean ascending\",\"mean descending\",\"median ascending\",\"median descending\"],dflt:\"trace\",editType:\"calc\"},categoryarray:{valType:\"data_array\",editType:\"calc\"},uirevision:{valType:\"any\",editType:\"none\"},editType:\"calc\",_deprecated:{autotick:{valType:\"boolean\",editType:\"ticks\"},title:{valType:\"string\",editType:\"ticks\"},titlefont:n({editType:\"ticks\"})}}},{\"../../components/color/attributes\":661,\"../../components/drawing/attributes\":683,\"../../constants/numerical\":775,\"../../lib/extend\":789,\"../../plot_api/plot_template\":838,\"../../plots/cartesian/axis_format_attributes\":852,\"../font_attributes\":878,\"./constants\":856}],865:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/color\"),a=t(\"../../components/fx/helpers\").isUnifiedHover,o=t(\"../../components/fx/hovermode_defaults\"),s=t(\"../../plot_api/plot_template\"),l=t(\"../layout_attributes\"),c=t(\"./layout_attributes\"),u=t(\"./type_defaults\"),f=t(\"./axis_defaults\"),h=t(\"./constraints\"),p=t(\"./position_defaults\"),d=t(\"./axis_ids\"),m=d.id2name,g=d.name2id,v=t(\"./constants\").AX_ID_PATTERN,y=t(\"../../registry\"),x=y.traceIs,b=y.getComponentMethod;function _(t,e,r){Array.isArray(t[e])?t[e].push(r):t[e]=[r]}e.exports=function(t,e,r){var y,w,T=e.autotypenumbers,k={},M={},A={},S={},E={},L={},C={},P={},I={},O={};for(y=0;y<r.length;y++){var z=r[y];if(x(z,\"cartesian\")||x(z,\"gl2d\")){var D,R;if(z.xaxis)D=m(z.xaxis),_(k,D,z);else if(z.xaxes)for(w=0;w<z.xaxes.length;w++)_(k,m(z.xaxes[w]),z);if(z.yaxis)R=m(z.yaxis),_(k,R,z);else if(z.yaxes)for(w=0;w<z.yaxes.length;w++)_(k,m(z.yaxes[w]),z);if(\"funnel\"===z.type?\"h\"===z.orientation?(D&&(M[D]=!0),R&&(C[R]=!0)):R&&(A[R]=!0):\"image\"===z.type?(R&&(P[R]=!0),D&&(P[D]=!0)):(R&&(E[R]=!0,L[R]=!0),x(z,\"carpet\")&&(\"carpet\"!==z.type||z._cheater)||D&&(S[D]=!0)),\"carpet\"===z.type&&z._cheater&&D&&(M[D]=!0),x(z,\"2dMap\")&&(I[D]=!0,I[R]=!0),x(z,\"oriented\"))O[\"h\"===z.orientation?R:D]=!0}}var F=e._subplots,B=F.xaxis,N=F.yaxis,j=n.simpleMap(B,m),U=n.simpleMap(N,m),V=j.concat(U),q=i.background;B.length&&N.length&&(q=n.coerce(t,e,l,\"plot_bgcolor\"));var H,G,Y,W,X,Z=i.combine(q,e.paper_bgcolor);function J(){var t=k[H]||[];X._traceIndices=t.map((function(t){return t._expandedIndex})),X._annIndices=[],X._shapeIndices=[],X._imgIndices=[],X._subplotsWith=[],X._counterAxes=[],X._name=X._attr=H,X._id=G}function K(t,e){return n.coerce(W,X,c,t,e)}function Q(t,e){return n.coerce2(W,X,c,t,e)}function $(t){return\"x\"===t?N:B}function tt(e,r){for(var n=\"x\"===e?j:U,i=[],a=0;a<n.length;a++){var o=n[a];o===r||(t[o]||{}).overlaying||i.push(g(o))}return i}var et={x:$(\"x\"),y:$(\"y\")},rt=et.x.concat(et.y),nt={},it=[];function at(){var t=W.matches;v.test(t)&&-1===rt.indexOf(t)&&(nt[t]=W.type,it=Object.keys(nt))}var ot=o(t,e),st=a(ot);for(y=0;y<V.length;y++){H=V[y],G=g(H),Y=H.charAt(0),n.isPlainObject(t[H])||(t[H]={}),W=t[H],X=s.newContainer(e,H,Y+\"axis\"),J();var lt=\"x\"===Y&&!S[H]&&M[H]||\"y\"===Y&&!E[H]&&A[H],ct=\"y\"===Y&&(!L[H]&&C[H]||P[H]),ut={letter:Y,font:e.font,outerTicks:I[H],showGrid:!O[H],data:k[H]||[],bgColor:Z,calendar:e.calendar,automargin:!0,visibleDflt:lt,reverseDflt:ct,autotypenumbersDflt:T,splomStash:((e._splomAxes||{})[Y]||{})[G]};K(\"uirevision\",e.uirevision),u(W,X,K,ut),f(W,X,K,ut,e);var ft=st&&Y===ot.charAt(0),ht=Q(\"spikecolor\",st?X.color:void 0),pt=Q(\"spikethickness\",st?1.5:void 0),dt=Q(\"spikedash\",st?\"dot\":void 0),mt=Q(\"spikemode\",st?\"across\":void 0),gt=Q(\"spikesnap\");K(\"showspikes\",!!(ft||ht||pt||dt||mt||gt))||(delete X.spikecolor,delete X.spikethickness,delete X.spikedash,delete X.spikemode,delete X.spikesnap),p(W,X,K,{letter:Y,counterAxes:et[Y],overlayableAxes:tt(Y,H),grid:e.grid}),K(\"title.standoff\"),at(),X._input=W}for(y=0;y<it.length;){G=it[y++],Y=(H=m(G)).charAt(0),n.isPlainObject(t[H])||(t[H]={}),W=t[H],X=s.newContainer(e,H,Y+\"axis\"),J();var vt={letter:Y,font:e.font,outerTicks:I[H],showGrid:!O[H],data:[],bgColor:Z,calendar:e.calendar,automargin:!0,visibleDflt:!1,reverseDflt:!1,autotypenumbersDflt:T,splomStash:((e._splomAxes||{})[Y]||{})[G]};K(\"uirevision\",e.uirevision),X.type=nt[G]||\"linear\",f(W,X,K,vt,e),p(W,X,K,{letter:Y,counterAxes:et[Y],overlayableAxes:tt(Y,H),grid:e.grid}),K(\"fixedrange\"),at(),X._input=W}var yt=b(\"rangeslider\",\"handleDefaults\"),xt=b(\"rangeselector\",\"handleDefaults\");for(y=0;y<j.length;y++)H=j[y],W=t[H],X=e[H],yt(t,e,H),\"date\"===X.type&&xt(W,X,e,U,X.calendar),K(\"fixedrange\");for(y=0;y<U.length;y++){H=U[y],W=t[H],X=e[H];var bt=e[m(X.anchor)];K(\"fixedrange\",b(\"rangeslider\",\"isVisible\")(bt))}h.handleDefaults(t,e,{axIds:rt.concat(it).sort(d.idSort),axHasImage:P})}},{\"../../components/color\":662,\"../../components/fx/helpers\":698,\"../../components/fx/hovermode_defaults\":701,\"../../lib\":799,\"../../plot_api/plot_template\":838,\"../../registry\":927,\"../layout_attributes\":904,\"./axis_defaults\":851,\"./axis_ids\":853,\"./constants\":856,\"./constraints\":857,\"./layout_attributes\":864,\"./position_defaults\":867,\"./type_defaults\":875}],866:[function(t,e,r){\"use strict\";var n=t(\"tinycolor2\").mix,i=t(\"../../components/color/attributes\").lightFraction,a=t(\"../../lib\");e.exports=function(t,e,r,o){var s=(o=o||{}).dfltColor;function l(r,n){return a.coerce2(t,e,o.attributes,r,n)}var c=l(\"linecolor\",s),u=l(\"linewidth\");r(\"showline\",o.showLine||!!c||!!u)||(delete e.linecolor,delete e.linewidth);var f=l(\"gridcolor\",n(s,o.bgColor,o.blend||i).toRgbString()),h=l(\"gridwidth\");if(r(\"showgrid\",o.showGrid||!!f||!!h)||(delete e.gridcolor,delete e.gridwidth),!o.noZeroLine){var p=l(\"zerolinecolor\",s),d=l(\"zerolinewidth\");r(\"zeroline\",o.showGrid||!!p||!!d)||(delete e.zerolinecolor,delete e.zerolinewidth)}}},{\"../../components/color/attributes\":661,\"../../lib\":799,tinycolor2:594}],867:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\");e.exports=function(t,e,r,a){var o,s,l,c,u=a.counterAxes||[],f=a.overlayableAxes||[],h=a.letter,p=a.grid;p&&(s=p._domains[h][p._axisMap[e._id]],o=p._anchors[e._id],s&&(l=p[h+\"side\"].split(\" \")[0],c=p.domain[h][\"right\"===l||\"top\"===l?1:0])),s=s||[0,1],o=o||(n(t.position)?\"free\":u[0]||\"free\"),l=l||(\"x\"===h?\"bottom\":\"left\"),c=c||0,\"free\"===i.coerce(t,e,{anchor:{valType:\"enumerated\",values:[\"free\"].concat(u),dflt:o}},\"anchor\")&&r(\"position\",c),i.coerce(t,e,{side:{valType:\"enumerated\",values:\"x\"===h?[\"bottom\",\"top\"]:[\"left\",\"right\"],dflt:l}},\"side\");var d=!1;if(f.length&&(d=i.coerce(t,e,{overlaying:{valType:\"enumerated\",values:[!1].concat(f),dflt:!1}},\"overlaying\")),!d){var m=r(\"domain\",s);m[0]>m[1]-1/4096&&(e.domain=s),i.noneOrAll(t.domain,e.domain,s)}return r(\"layer\"),e}},{\"../../lib\":799,\"fast-isnumeric\":245}],868:[function(t,e,r){\"use strict\";var n=t(\"../../constants/alignment\").FROM_BL;e.exports=function(t,e,r){void 0===r&&(r=n[t.constraintoward||\"center\"]);var i=[t.r2l(t.range[0]),t.r2l(t.range[1])],a=i[0]+(i[1]-i[0])*r;t.range=t._input.range=[t.l2r(a+(i[0]-a)*e),t.l2r(a+(i[1]-a)*e)],t.setScale()}},{\"../../constants/alignment\":767}],869:[function(t,e,r){\"use strict\";var n=t(\"polybooljs\"),i=t(\"../../registry\"),a=t(\"../../components/drawing\").dashStyle,o=t(\"../../components/color\"),s=t(\"../../components/fx\"),l=t(\"../../components/fx/helpers\").makeEventData,c=t(\"../../components/dragelement/helpers\"),u=c.freeMode,f=c.rectMode,h=c.drawMode,p=c.openMode,d=c.selectMode,m=t(\"../../components/shapes/draw_newshape/display_outlines\"),g=t(\"../../components/shapes/draw_newshape/helpers\").handleEllipse,v=t(\"../../components/shapes/draw_newshape/newshapes\"),y=t(\"../../lib\"),x=t(\"../../lib/polygon\"),b=t(\"../../lib/throttle\"),_=t(\"./axis_ids\").getFromId,w=t(\"../../lib/clear_gl_canvases\"),T=t(\"../../plot_api/subroutines\").redrawReglTraces,k=t(\"./constants\"),M=k.MINSELECT,A=x.filter,S=x.tester,E=t(\"./handle_outline\").clearSelect,L=t(\"./helpers\"),C=L.p2r,P=L.axValue,I=L.getTransform;function O(t,e,r,n,i,a,o){var s,l,c,u,f,h,d,g,v,y=e._hoverdata,x=e._fullLayout.clickmode.indexOf(\"event\")>-1,b=[];if(function(t){return t&&Array.isArray(t)&&!0!==t[0].hoverOnBox}(y)){F(t,e,a);var _=function(t,e){var r,n,i=t[0],a=-1,o=[];for(n=0;n<e.length;n++)if(r=e[n],i.fullData._expandedIndex===r.cd[0].trace._expandedIndex){if(!0===i.hoverOnBox)break;void 0!==i.pointNumber?a=i.pointNumber:void 0!==i.binNumber&&(a=i.binNumber,o=i.pointNumbers);break}return{pointNumber:a,pointNumbers:o,searchInfo:r}}(y,s=N(e,r,n,i));if(_.pointNumbers.length>0?function(t,e){var r,n,i,a=[];for(i=0;i<t.length;i++)(r=t[i]).cd[0].trace.selectedpoints&&r.cd[0].trace.selectedpoints.length>0&&a.push(r);if(1===a.length&&a[0]===e.searchInfo&&(n=e.searchInfo.cd[0].trace).selectedpoints.length===e.pointNumbers.length){for(i=0;i<e.pointNumbers.length;i++)if(n.selectedpoints.indexOf(e.pointNumbers[i])<0)return!1;return!0}return!1}(s,_):function(t){var e,r,n,i=0;for(n=0;n<t.length;n++)if(e=t[n],(r=e.cd[0].trace).selectedpoints){if(r.selectedpoints.length>1)return!1;if((i+=r.selectedpoints.length)>1)return!1}return 1===i}(s)&&(h=j(_))){for(o&&o.remove(),v=0;v<s.length;v++)(l=s[v])._module.selectPoints(l,!1);U(e,s),B(a),x&&e.emit(\"plotly_deselect\",null)}else{for(d=t.shiftKey&&(void 0!==h?h:j(_)),c=function(t,e,r){return{pointNumber:t,searchInfo:e,subtract:r}}(_.pointNumber,_.searchInfo,d),u=R(a.selectionDefs.concat([c])),v=0;v<s.length;v++)if(f=V(s[v]._module.selectPoints(s[v],u),s[v]),b.length)for(var w=0;w<f.length;w++)b.push(f[w]);else b=f;if(U(e,s,g={points:b}),c&&a&&a.selectionDefs.push(c),o){var T=a.mergedPolygons,k=p(a.dragmode);m(q(T,k),o,a)}x&&e.emit(\"plotly_selected\",g)}}}function z(t){return\"pointNumber\"in t&&\"searchInfo\"in t}function D(t){return{xmin:0,xmax:0,ymin:0,ymax:0,pts:[],contains:function(e,r,n,i){var a=t.searchInfo.cd[0].trace._expandedIndex;return i.cd[0].trace._expandedIndex===a&&n===t.pointNumber},isRect:!1,degenerate:!1,subtract:t.subtract}}function R(t){for(var e=[],r=z(t[0])?0:t[0][0][0],n=r,i=z(t[0])?0:t[0][0][1],a=i,o=0;o<t.length;o++)if(z(t[o]))e.push(D(t[o]));else{var s=x.tester(t[o]);s.subtract=t[o].subtract,e.push(s),r=Math.min(r,s.xmin),n=Math.max(n,s.xmax),i=Math.min(i,s.ymin),a=Math.max(a,s.ymax)}return{xmin:r,xmax:n,ymin:i,ymax:a,pts:[],contains:function(t,r,n,i){for(var a=!1,o=0;o<e.length;o++)e[o].contains(t,r,n,i)&&(a=!1===e[o].subtract);return a},isRect:!1,degenerate:!1}}function F(t,e,r){e._fullLayout._drawing=!1;var n=e._fullLayout,i=r.plotinfo,a=r.dragmode,o=n._lastSelectedSubplot&&n._lastSelectedSubplot===i.id,s=(t.shiftKey||t.altKey)&&!(h(a)&&p(a));o&&s&&i.selection&&i.selection.selectionDefs&&!r.selectionDefs?(r.selectionDefs=i.selection.selectionDefs,r.mergedPolygons=i.selection.mergedPolygons):s&&i.selection||B(r),o||(E(e),n._lastSelectedSubplot=i.id)}function B(t){var e=t.dragmode,r=t.plotinfo,n=t.gd;if(n._fullLayout._activeShapeIndex>=0&&n._fullLayout._deactivateShape(n),h(e)){var a=n._fullLayout._zoomlayer.selectAll(\".select-outline-\"+r.id);if(a&&n._fullLayout._drawing){var o=v(a,t);o&&i.call(\"_guiRelayout\",n,{shapes:o}),n._fullLayout._drawing=!1}}r.selection={},r.selection.selectionDefs=t.selectionDefs=[],r.selection.mergedPolygons=t.mergedPolygons=[]}function N(t,e,r,n){var i,a,o,s=[],l=e.map((function(t){return t._id})),c=r.map((function(t){return t._id}));for(o=0;o<t.calcdata.length;o++)if(!0===(a=(i=t.calcdata[o])[0].trace).visible&&a._module&&a._module.selectPoints)if(!n||a.subplot!==n&&a.geo!==n)if(\"splom\"===a.type&&a._xaxes[l[0]]&&a._yaxes[c[0]]){var u=h(a._module,i,e[0],r[0]);u.scene=t._fullLayout._splomScenes[a.uid],s.push(u)}else if(\"sankey\"===a.type){var f=h(a._module,i,e[0],r[0]);s.push(f)}else{if(-1===l.indexOf(a.xaxis))continue;if(-1===c.indexOf(a.yaxis))continue;s.push(h(a._module,i,_(t,a.xaxis),_(t,a.yaxis)))}else s.push(h(a._module,i,e[0],r[0]));return s;function h(t,e,r,n){return{_module:t,cd:e,xaxis:r,yaxis:n}}}function j(t){var e=t.searchInfo.cd[0].trace,r=t.pointNumber,n=t.pointNumbers,i=n.length>0?n[0]:r;return!!e.selectedpoints&&e.selectedpoints.indexOf(i)>-1}function U(t,e,r){var n,a,o,s;for(n=0;n<e.length;n++){var l=e[n].cd[0].trace._fullInput,c=t._fullLayout._tracePreGUI[l.uid]||{};void 0===c.selectedpoints&&(c.selectedpoints=l._input.selectedpoints||null)}if(r){var u=r.points||[];for(n=0;n<e.length;n++)(s=e[n].cd[0].trace)._input.selectedpoints=s._fullInput.selectedpoints=[],s._fullInput!==s&&(s.selectedpoints=[]);for(n=0;n<u.length;n++){var f=u[n],h=f.data,p=f.fullData;f.pointIndices?([].push.apply(h.selectedpoints,f.pointIndices),s._fullInput!==s&&[].push.apply(p.selectedpoints,f.pointIndices)):(h.selectedpoints.push(f.pointIndex),s._fullInput!==s&&p.selectedpoints.push(f.pointIndex))}}else for(n=0;n<e.length;n++)delete(s=e[n].cd[0].trace).selectedpoints,delete s._input.selectedpoints,s._fullInput!==s&&delete s._fullInput.selectedpoints;var d=!1;for(n=0;n<e.length;n++){s=(o=(a=e[n]).cd)[0].trace,i.traceIs(s,\"regl\")&&(d=!0);var m=a._module,g=m.styleOnSelect||m.style;g&&(g(t,o,o[0].node3),o[0].nodeRangePlot3&&g(t,o,o[0].nodeRangePlot3))}d&&(w(t),T(t))}function V(t,e){if(Array.isArray(t))for(var r=e.cd,n=e.cd[0].trace,i=0;i<t.length;i++)t[i]=l(t[i],n,r);return t}function q(t,e){for(var r=[],n=0;n<t.length;n++){r[n]=[];for(var i=0;i<t[n].length;i++){r[n][i]=[],r[n][i][0]=i?\"L\":\"M\";for(var a=0;a<t[n][i].length;a++)r[n][i].push(t[n][i][a])}e||r[n].push([\"Z\",r[n][0][1],r[n][0][2]])}return r}e.exports={prepSelect:function(t,e,r,i,l){var c=u(l),v=f(l),x=p(l),_=h(l),w=d(l),T=\"drawcircle\"===l,E=\"drawline\"===l||T,L=i.gd,z=L._fullLayout,D=z._zoomlayer,j=i.element.getBoundingClientRect(),H=i.plotinfo,G=I(H),Y=e-j.left,W=r-j.top;z._calcInverseTransform(L);var X=y.apply3DTransform(z._invTransform)(Y,W);Y=X[0],W=X[1];var Z,J,K,Q,$,tt,et,rt=z._invScaleX,nt=z._invScaleY,it=Y,at=W,ot=\"M\"+Y+\",\"+W,st=i.xaxes[0]._length,lt=i.yaxes[0]._length,ct=i.xaxes.concat(i.yaxes),ut=t.altKey&&!(h(l)&&x);F(t,L,i),c&&(Z=A([[Y,W]],k.BENDPX));var ft=D.selectAll(\"path.select-outline-\"+H.id).data(_?[0]:[1,2]),ht=z.newshape;ft.enter().append(\"path\").attr(\"class\",(function(t){return\"select-outline select-outline-\"+t+\" select-outline-\"+H.id})).style(_?{opacity:ht.opacity/2,fill:x?void 0:ht.fillcolor,stroke:ht.line.color,\"stroke-dasharray\":a(ht.line.dash,ht.line.width),\"stroke-width\":ht.line.width+\"px\"}:{}).attr(\"fill-rule\",ht.fillrule).classed(\"cursor-move\",!!_).attr(\"transform\",G).attr(\"d\",ot+\"Z\");var pt,dt=D.append(\"path\").attr(\"class\",\"zoombox-corners\").style({fill:o.background,stroke:o.defaultLine,\"stroke-width\":1}).attr(\"transform\",G).attr(\"d\",\"M0,0Z\"),mt=z._uid+k.SELECTID,gt=[],vt=N(L,i.xaxes,i.yaxes,i.subplot);function yt(t,e){return t-e}pt=H.fillRangeItems?H.fillRangeItems:v?function(t,e){var r=t.range={};for($=0;$<ct.length;$++){var n=ct[$],i=n._id.charAt(0);r[n._id]=[C(n,e[i+\"min\"]),C(n,e[i+\"max\"])].sort(yt)}}:function(t,e,r){var n=t.lassoPoints={};for($=0;$<ct.length;$++){var i=ct[$];n[i._id]=r.filtered.map(P(i))}},i.moveFn=function(t,e){it=Math.max(0,Math.min(st,rt*t+Y)),at=Math.max(0,Math.min(lt,nt*e+W));var r=Math.abs(it-Y),a=Math.abs(at-W);if(v){var o,s,l;if(w){var u=z.selectdirection;switch(o=\"any\"===u?a<Math.min(.6*r,M)?\"h\":r<Math.min(.6*a,M)?\"v\":\"d\":u){case\"h\":s=T?lt/2:0,l=lt;break;case\"v\":s=T?st/2:0,l=st}}if(_)switch(z.newshape.drawdirection){case\"vertical\":o=\"h\",s=T?lt/2:0,l=lt;break;case\"horizontal\":o=\"v\",s=T?st/2:0,l=st;break;case\"ortho\":r<a?(o=\"h\",s=W,l=at):(o=\"v\",s=Y,l=it);break;default:o=\"d\"}\"h\"===o?((Q=E?g(T,[it,s],[it,l]):[[Y,s],[Y,l],[it,l],[it,s]]).xmin=E?it:Math.min(Y,it),Q.xmax=E?it:Math.max(Y,it),Q.ymin=Math.min(s,l),Q.ymax=Math.max(s,l),dt.attr(\"d\",\"M\"+Q.xmin+\",\"+(W-M)+\"h-4v\"+2*M+\"h4ZM\"+(Q.xmax-1)+\",\"+(W-M)+\"h4v\"+2*M+\"h-4Z\")):\"v\"===o?((Q=E?g(T,[s,at],[l,at]):[[s,W],[s,at],[l,at],[l,W]]).xmin=Math.min(s,l),Q.xmax=Math.max(s,l),Q.ymin=E?at:Math.min(W,at),Q.ymax=E?at:Math.max(W,at),dt.attr(\"d\",\"M\"+(Y-M)+\",\"+Q.ymin+\"v-4h\"+2*M+\"v4ZM\"+(Y-M)+\",\"+(Q.ymax-1)+\"v4h\"+2*M+\"v-4Z\")):\"d\"===o&&((Q=E?g(T,[Y,W],[it,at]):[[Y,W],[Y,at],[it,at],[it,W]]).xmin=Math.min(Y,it),Q.xmax=Math.max(Y,it),Q.ymin=Math.min(W,at),Q.ymax=Math.max(W,at),dt.attr(\"d\",\"M0,0Z\"))}else c&&(Z.addPt([it,at]),Q=Z.filtered);i.selectionDefs&&i.selectionDefs.length?(K=function(t,e,r){if(r)return n.difference({regions:t,inverted:!1},{regions:[e],inverted:!1}).regions;return n.union({regions:t,inverted:!1},{regions:[e],inverted:!1}).regions}(i.mergedPolygons,Q,ut),Q.subtract=ut,J=R(i.selectionDefs.concat([Q]))):(K=[Q],J=S(Q)),m(q(K,x),ft,i),w&&b.throttle(mt,k.SELECTDELAY,(function(){var t;gt=[];var e,r=[];for($=0;$<vt.length;$++)if(e=(tt=vt[$])._module.selectPoints(tt,J),r.push(e),t=V(e,tt),gt.length)for(var n=0;n<t.length;n++)gt.push(t[n]);else gt=t;U(L,vt,et={points:gt}),pt(et,Q,Z),i.gd.emit(\"plotly_selecting\",et)}))},i.clickFn=function(t,e){if(dt.remove(),L._fullLayout._activeShapeIndex>=0)L._fullLayout._deactivateShape(L);else if(!_){var r=z.clickmode;b.done(mt).then((function(){if(b.clear(mt),2===t){for(ft.remove(),$=0;$<vt.length;$++)(tt=vt[$])._module.selectPoints(tt,!1);U(L,vt),B(i),L.emit(\"plotly_deselect\",null)}else r.indexOf(\"select\")>-1&&O(e,L,i.xaxes,i.yaxes,i.subplot,i,ft),\"event\"===r&&L.emit(\"plotly_selected\",void 0);s.click(L,e)})).catch(y.error)}},i.doneFn=function(){dt.remove(),b.done(mt).then((function(){b.clear(mt),i.gd.emit(\"plotly_selected\",et),Q&&i.selectionDefs&&(Q.subtract=ut,i.selectionDefs.push(Q),i.mergedPolygons.length=0,[].push.apply(i.mergedPolygons,K)),i.doneFnCompleted&&i.doneFnCompleted(gt)})).catch(y.error),_&&B(i)}},clearSelect:E,clearSelectionsCache:B,selectOnClick:O}},{\"../../components/color\":662,\"../../components/dragelement/helpers\":680,\"../../components/drawing\":684,\"../../components/fx\":702,\"../../components/fx/helpers\":698,\"../../components/shapes/draw_newshape/display_outlines\":750,\"../../components/shapes/draw_newshape/helpers\":751,\"../../components/shapes/draw_newshape/newshapes\":752,\"../../lib\":799,\"../../lib/clear_gl_canvases\":783,\"../../lib/polygon\":811,\"../../lib/throttle\":825,\"../../plot_api/subroutines\":839,\"../../registry\":927,\"./axis_ids\":853,\"./constants\":856,\"./handle_outline\":860,\"./helpers\":861,polybooljs:500}],870:[function(t,e,r){\"use strict\";var n=t(\"@plotly/d3\"),i=t(\"d3-time-format\").utcFormat,a=t(\"fast-isnumeric\"),o=t(\"../../lib\"),s=o.cleanNumber,l=o.ms2DateTime,c=o.dateTime2ms,u=o.ensureNumber,f=o.isArrayOrTypedArray,h=t(\"../../constants/numerical\"),p=h.FP_SAFE,d=h.BADNUM,m=h.LOG_CLIP,g=h.ONEWEEK,v=h.ONEDAY,y=h.ONEHOUR,x=h.ONEMIN,b=h.ONESEC,_=t(\"./axis_ids\"),w=t(\"./constants\"),T=w.HOUR_PATTERN,k=w.WEEKDAY_PATTERN;function M(t){return Math.pow(10,t)}function A(t){return null!=t}e.exports=function(t,e){e=e||{};var r=t._id||\"x\",h=r.charAt(0);function S(e,r){if(e>0)return Math.log(e)/Math.LN10;if(e<=0&&r&&t.range&&2===t.range.length){var n=t.range[0],i=t.range[1];return.5*(n+i-2*m*Math.abs(n-i))}return d}function E(e,r,n,i){if((i||{}).msUTC&&a(e))return+e;var s=c(e,n||t.calendar);if(s===d){if(!a(e))return d;e=+e;var l=Math.floor(10*o.mod(e+.05,1)),u=Math.round(e-l/10);s=c(new Date(u))+l/10}return s}function L(e,r,n){return l(e,r,n||t.calendar)}function C(e){return t._categories[Math.round(e)]}function P(e){if(A(e)){if(void 0===t._categoriesMap&&(t._categoriesMap={}),void 0!==t._categoriesMap[e])return t._categoriesMap[e];t._categories.push(\"number\"==typeof e?String(e):e);var r=t._categories.length-1;return t._categoriesMap[e]=r,r}return d}function I(e){if(t._categoriesMap)return t._categoriesMap[e]}function O(t){var e=I(t);return void 0!==e?e:a(t)?+t:void 0}function z(t){return a(t)?+t:I(t)}function D(t,e,r){return n.round(r+e*t,2)}function R(t,e,r){return(t-r)/e}var F=function(e){return a(e)?D(e,t._m,t._b):d},B=function(e){return R(e,t._m,t._b)};if(t.rangebreaks){var N=\"y\"===h;F=function(e){if(!a(e))return d;var r=t._rangebreaks.length;if(!r)return D(e,t._m,t._b);var n=N;t.range[0]>t.range[1]&&(n=!n);for(var i=n?-1:1,o=i*e,s=0,l=0;l<r;l++){var c=i*t._rangebreaks[l].min,u=i*t._rangebreaks[l].max;if(o<c)break;if(!(o>u)){s=o<(c+u)/2?l:l+1;break}s=l+1}var f=t._B[s]||0;return isFinite(f)?D(e,t._m2,f):0},B=function(e){var r=t._rangebreaks.length;if(!r)return R(e,t._m,t._b);for(var n=0,i=0;i<r&&!(e<t._rangebreaks[i].pmin);i++)e>t._rangebreaks[i].pmax&&(n=i+1);return R(e,t._m2,t._B[n])}}t.c2l=\"log\"===t.type?S:u,t.l2c=\"log\"===t.type?M:u,t.l2p=F,t.p2l=B,t.c2p=\"log\"===t.type?function(t,e){return F(S(t,e))}:F,t.p2c=\"log\"===t.type?function(t){return M(B(t))}:B,-1!==[\"linear\",\"-\"].indexOf(t.type)?(t.d2r=t.r2d=t.d2c=t.r2c=t.d2l=t.r2l=s,t.c2d=t.c2r=t.l2d=t.l2r=u,t.d2p=t.r2p=function(e){return t.l2p(s(e))},t.p2d=t.p2r=B,t.cleanPos=u):\"log\"===t.type?(t.d2r=t.d2l=function(t,e){return S(s(t),e)},t.r2d=t.r2c=function(t){return M(s(t))},t.d2c=t.r2l=s,t.c2d=t.l2r=u,t.c2r=S,t.l2d=M,t.d2p=function(e,r){return t.l2p(t.d2r(e,r))},t.p2d=function(t){return M(B(t))},t.r2p=function(e){return t.l2p(s(e))},t.p2r=B,t.cleanPos=u):\"date\"===t.type?(t.d2r=t.r2d=o.identity,t.d2c=t.r2c=t.d2l=t.r2l=E,t.c2d=t.c2r=t.l2d=t.l2r=L,t.d2p=t.r2p=function(e,r,n){return t.l2p(E(e,0,n))},t.p2d=t.p2r=function(t,e,r){return L(B(t),e,r)},t.cleanPos=function(e){return o.cleanDate(e,d,t.calendar)}):\"category\"===t.type?(t.d2c=t.d2l=P,t.r2d=t.c2d=t.l2d=C,t.d2r=t.d2l_noadd=O,t.r2c=function(e){var r=z(e);return void 0!==r?r:t.fraction2r(.5)},t.l2r=t.c2r=u,t.r2l=z,t.d2p=function(e){return t.l2p(t.r2c(e))},t.p2d=function(t){return C(B(t))},t.r2p=t.d2p,t.p2r=B,t.cleanPos=function(t){return\"string\"==typeof t&&\"\"!==t?t:u(t)}):\"multicategory\"===t.type&&(t.r2d=t.c2d=t.l2d=C,t.d2r=t.d2l_noadd=O,t.r2c=function(e){var r=O(e);return void 0!==r?r:t.fraction2r(.5)},t.r2c_just_indices=I,t.l2r=t.c2r=u,t.r2l=O,t.d2p=function(e){return t.l2p(t.r2c(e))},t.p2d=function(t){return C(B(t))},t.r2p=t.d2p,t.p2r=B,t.cleanPos=function(t){return Array.isArray(t)||\"string\"==typeof t&&\"\"!==t?t:u(t)},t.setupMultiCategory=function(n){var i,a,s=t._traceIndices,l=t._matchGroup;if(l&&0===t._categories.length)for(var c in l)if(c!==r){var u=e[_.id2name(c)];s=s.concat(u._traceIndices)}var p=[[0,{}],[0,{}]],d=[];for(i=0;i<s.length;i++){var m=n[s[i]];if(h in m){var g=m[h],v=m._length||o.minRowLength(g);if(f(g[0])&&f(g[1]))for(a=0;a<v;a++){var y=g[0][a],x=g[1][a];A(y)&&A(x)&&(d.push([y,x]),y in p[0][1]||(p[0][1][y]=p[0][0]++),x in p[1][1]||(p[1][1][x]=p[1][0]++))}}}for(d.sort((function(t,e){var r=p[0][1],n=r[t[0]]-r[e[0]];if(n)return n;var i=p[1][1];return i[t[1]]-i[e[1]]})),i=0;i<d.length;i++)P(d[i])}),t.fraction2r=function(e){var r=t.r2l(t.range[0]),n=t.r2l(t.range[1]);return t.l2r(r+e*(n-r))},t.r2fraction=function(e){var r=t.r2l(t.range[0]),n=t.r2l(t.range[1]);return(t.r2l(e)-r)/(n-r)},t.cleanRange=function(e,r){r||(r={}),e||(e=\"range\");var n,i,s=o.nestedProperty(t,e).get();if(i=(i=\"date\"===t.type?o.dfltRange(t.calendar):\"y\"===h?w.DFLTRANGEY:r.dfltRange||w.DFLTRANGEX).slice(),\"tozero\"!==t.rangemode&&\"nonnegative\"!==t.rangemode||(i[0]=0),s&&2===s.length)for(\"date\"!==t.type||t.autorange||(s[0]=o.cleanDate(s[0],d,t.calendar),s[1]=o.cleanDate(s[1],d,t.calendar)),n=0;n<2;n++)if(\"date\"===t.type){if(!o.isDateTime(s[n],t.calendar)){t[e]=i;break}if(t.r2l(s[0])===t.r2l(s[1])){var l=o.constrain(t.r2l(s[0]),o.MIN_MS+1e3,o.MAX_MS-1e3);s[0]=t.l2r(l-1e3),s[1]=t.l2r(l+1e3);break}}else{if(!a(s[n])){if(!a(s[1-n])){t[e]=i;break}s[n]=s[1-n]*(n?10:.1)}if(s[n]<-p?s[n]=-p:s[n]>p&&(s[n]=p),s[0]===s[1]){var c=Math.max(1,Math.abs(1e-6*s[0]));s[0]-=c,s[1]+=c}}else o.nestedProperty(t,e).set(i)},t.setScale=function(r){var n=e._size;if(t.overlaying){var i=_.getFromId({_fullLayout:e},t.overlaying);t.domain=i.domain}var a=r&&t._r?\"_r\":\"range\",o=t.calendar;t.cleanRange(a);var s,l,c=t.r2l(t[a][0],o),u=t.r2l(t[a][1],o),f=\"y\"===h;if((f?(t._offset=n.t+(1-t.domain[1])*n.h,t._length=n.h*(t.domain[1]-t.domain[0]),t._m=t._length/(c-u),t._b=-t._m*u):(t._offset=n.l+t.domain[0]*n.w,t._length=n.w*(t.domain[1]-t.domain[0]),t._m=t._length/(u-c),t._b=-t._m*c),t._rangebreaks=[],t._lBreaks=0,t._m2=0,t._B=[],t.rangebreaks)&&(t._rangebreaks=t.locateBreaks(Math.min(c,u),Math.max(c,u)),t._rangebreaks.length)){for(s=0;s<t._rangebreaks.length;s++)l=t._rangebreaks[s],t._lBreaks+=Math.abs(l.max-l.min);var p=f;c>u&&(p=!p),p&&t._rangebreaks.reverse();var d=p?-1:1;for(t._m2=d*t._length/(Math.abs(u-c)-t._lBreaks),t._B.push(-t._m2*(f?u:c)),s=0;s<t._rangebreaks.length;s++)l=t._rangebreaks[s],t._B.push(t._B[t._B.length-1]-d*t._m2*(l.max-l.min));for(s=0;s<t._rangebreaks.length;s++)(l=t._rangebreaks[s]).pmin=F(l.min),l.pmax=F(l.max)}if(!isFinite(t._m)||!isFinite(t._b)||t._length<0)throw e._replotting=!1,new Error(\"Something went wrong with axis scaling\")},t.maskBreaks=function(e){var r,n,i,a,l,c=t.rangebreaks||[];c._cachedPatterns||(c._cachedPatterns=c.map((function(e){return e.enabled&&e.bounds?o.simpleMap(e.bounds,e.pattern?s:t.d2c):null}))),c._cachedValues||(c._cachedValues=c.map((function(e){return e.enabled&&e.values?o.simpleMap(e.values,t.d2c).sort(o.sorterAsc):null})));for(var u=0;u<c.length;u++){var f=c[u];if(f.enabled)if(f.bounds){var h=f.pattern;switch(n=(r=c._cachedPatterns[u])[0],i=r[1],h){case k:a=(l=new Date(e)).getUTCDay(),n>i&&(i+=7,a<n&&(a+=7));break;case T:a=(l=new Date(e)).getUTCHours()+(l.getUTCMinutes()/60+l.getUTCSeconds()/3600+l.getUTCMilliseconds()/36e5),n>i&&(i+=24,a<n&&(a+=24));break;case\"\":a=e}if(a>=n&&a<i)return d}else for(var p=c._cachedValues[u],m=0;m<p.length;m++)if(i=(n=p[m])+f.dvalue,e>=n&&e<i)return d}return e},t.locateBreaks=function(e,r){var n,i,a,l,c=[];if(!t.rangebreaks)return c;var u=t.rangebreaks.slice().sort((function(t,e){return t.pattern===k&&e.pattern===T?-1:e.pattern===k&&t.pattern===T?1:0})),f=function(t,n){if((t=o.constrain(t,e,r))!==(n=o.constrain(n,e,r))){for(var i=!0,a=0;a<c.length;a++){var s=c[a];t<s.max&&n>=s.min&&(t<s.min&&(s.min=t),n>s.max&&(s.max=n),i=!1)}i&&c.push({min:t,max:n})}};for(n=0;n<u.length;n++){var h=u[n];if(h.enabled)if(h.bounds){var p=e,d=r;h.pattern&&(p=Math.floor(p)),a=(i=o.simpleMap(h.bounds,h.pattern?s:t.r2l))[0],l=i[1];var m,_,w=new Date(p);switch(h.pattern){case k:_=g,m=(l-a+(l<a?7:0))*v,p+=a*v-(w.getUTCDay()*v+w.getUTCHours()*y+w.getUTCMinutes()*x+w.getUTCSeconds()*b+w.getUTCMilliseconds());break;case T:_=v,m=(l-a+(l<a?24:0))*y,p+=a*y-(w.getUTCHours()*y+w.getUTCMinutes()*x+w.getUTCSeconds()*b+w.getUTCMilliseconds());break;default:p=Math.min(i[0],i[1]),m=_=(d=Math.max(i[0],i[1]))-p}for(var M=p;M<d;M+=_)f(M,M+m)}else for(var A=o.simpleMap(h.values,t.d2c),S=0;S<A.length;S++)f(a=A[S],l=a+h.dvalue)}return c.sort((function(t,e){return t.min-e.min})),c},t.makeCalcdata=function(e,r,n){var i,a,s,l,c=t.type,u=\"date\"===c&&e[r+\"calendar\"];if(r in e){if(i=e[r],l=e._length||o.minRowLength(i),o.isTypedArray(i)&&(\"linear\"===c||\"log\"===c)){if(l===i.length)return i;if(i.subarray)return i.subarray(0,l)}if(\"multicategory\"===c)return function(t,e){for(var r=new Array(e),n=0;n<e;n++){var i=(t[0]||[])[n],a=(t[1]||[])[n];r[n]=I([i,a])}return r}(i,l);for(a=new Array(l),s=0;s<l;s++)a[s]=t.d2c(i[s],0,u,n)}else{var f=r+\"0\"in e?t.d2c(e[r+\"0\"],0,u):0,h=e[\"d\"+r]?Number(e[\"d\"+r]):1;for(i=e[{x:\"y\",y:\"x\"}[r]],l=e._length||i.length,a=new Array(l),s=0;s<l;s++)a[s]=f+s*h}if(t.rangebreaks)for(s=0;s<l;s++)a[s]=t.maskBreaks(a[s]);return a},t.isValidRange=function(e){return Array.isArray(e)&&2===e.length&&a(t.r2l(e[0]))&&a(t.r2l(e[1]))},t.isPtWithinRange=function(e,r){var n=t.c2l(e[h],null,r),i=t.r2l(t.range[0]),a=t.r2l(t.range[1]);return i<a?i<=n&&n<=a:a<=n&&n<=i},t._emptyCategories=function(){t._categories=[],t._categoriesMap={}},t.clearCalc=function(){var r=t._matchGroup;if(r){var n=null,i=null;for(var a in r){var o=e[_.id2name(a)];if(o._categories){n=o._categories,i=o._categoriesMap;break}}n&&i?(t._categories=n,t._categoriesMap=i):t._emptyCategories()}else t._emptyCategories();if(t._initialCategories)for(var s=0;s<t._initialCategories.length;s++)P(t._initialCategories[s])},t.sortByInitialCategories=function(){var n=[];if(t._emptyCategories(),t._initialCategories)for(var i=0;i<t._initialCategories.length;i++)P(t._initialCategories[i]);n=n.concat(t._traceIndices);var a=t._matchGroup;for(var o in a)if(r!==o){var s=e[_.id2name(o)];s._categories=t._categories,s._categoriesMap=t._categoriesMap,n=n.concat(s._traceIndices)}return n};var j=e._d3locale;\"date\"===t.type&&(t._dateFormat=j?j.timeFormat:i,t._extraFormat=e._extraFormat),t._separators=e.separators,t._numFormat=j?j.numberFormat:n.format,delete t._minDtick,delete t._forceTick0}},{\"../../constants/numerical\":775,\"../../lib\":799,\"./axis_ids\":853,\"./constants\":856,\"@plotly/d3\":58,\"d3-time-format\":172,\"fast-isnumeric\":245}],871:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/color\").contrast,a=t(\"./layout_attributes\"),o=t(\"../array_container_defaults\");function s(t){var e=[\"showexponent\",\"showtickprefix\",\"showticksuffix\"].filter((function(e){return void 0!==t[e]}));if(e.every((function(r){return t[r]===t[e[0]]}))||1===e.length)return t[e[0]]}function l(t,e){function r(r,i){return n.coerce(t,e,a.tickformatstops,r,i)}r(\"enabled\")&&(r(\"dtickrange\"),r(\"value\"))}e.exports=function(t,e,r,c,u,f){f&&1!==f.pass||function(t,e,r,n,i){var a=s(t);r(\"tickprefix\")&&r(\"showtickprefix\",a);r(\"ticksuffix\",i.tickSuffixDflt)&&r(\"showticksuffix\",a)}(t,0,r,0,u),f&&2!==f.pass||function(t,e,r,c,u){var f=s(t);r(\"tickprefix\")&&r(\"showtickprefix\",f);r(\"ticksuffix\",u.tickSuffixDflt)&&r(\"showticksuffix\",f);if(r(\"showticklabels\")){var h=u.font||{},p=e.color,d=-1!==(e.ticklabelposition||\"\").indexOf(\"inside\")?i(u.bgColor):p&&p!==a.color.dflt?p:h.color;if(n.coerceFont(r,\"tickfont\",{family:h.family,size:h.size,color:d}),r(\"tickangle\"),\"category\"!==c){var m=r(\"tickformat\");o(t,e,{name:\"tickformatstops\",inclusionAttr:\"enabled\",handleItemDefaults:l}),e.tickformatstops.length||delete e.tickformatstops,m||\"date\"===c||(r(\"showexponent\",f),r(\"exponentformat\"),r(\"minexponent\"),r(\"separatethousands\"))}}}(t,e,r,c,u)}},{\"../../components/color\":662,\"../../lib\":799,\"../array_container_defaults\":844,\"./layout_attributes\":864}],872:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\");e.exports=function(t,e,r,a){var o=n.coerce2(t,e,i,\"ticklen\"),s=n.coerce2(t,e,i,\"tickwidth\"),l=n.coerce2(t,e,i,\"tickcolor\",e.color);r(\"ticks\",a.outerTicks||o||s||l?\"outside\":\"\")||(delete e.ticklen,delete e.tickwidth,delete e.tickcolor)}},{\"../../lib\":799,\"./layout_attributes\":864}],873:[function(t,e,r){\"use strict\";var n=t(\"./clean_ticks\"),i=t(\"../../lib\").isArrayOrTypedArray;e.exports=function(t,e,r,a){function o(r){var n=t[r];return void 0!==n?n:(e._template||{})[r]}var s=o(\"tick0\"),l=o(\"dtick\"),c=o(\"tickvals\"),u=r(\"tickmode\",i(c)?\"array\":l?\"linear\":\"auto\");if(\"auto\"===u)r(\"nticks\");else if(\"linear\"===u){var f=e.dtick=n.dtick(l,a);e.tick0=n.tick0(s,a,e.calendar,f)}else if(\"multicategory\"!==a){void 0===r(\"tickvals\")?e.tickmode=\"auto\":r(\"ticktext\")}}},{\"../../lib\":799,\"./clean_ticks\":855}],874:[function(t,e,r){\"use strict\";var n=t(\"@plotly/d3\"),i=t(\"../../registry\"),a=t(\"../../lib\"),o=t(\"../../components/drawing\"),s=t(\"./axes\");e.exports=function(t,e,r,l){var c=t._fullLayout;if(0!==e.length){var u,f,h,p;l&&(u=l());var d=n.ease(r.easing);return t._transitionData._interruptCallbacks.push((function(){return window.cancelAnimationFrame(p),p=null,function(){for(var r={},n=0;n<e.length;n++){var a=e[n],o=a.plotinfo.xaxis,s=a.plotinfo.yaxis;a.xr0&&(r[o._name+\".range\"]=a.xr0.slice()),a.yr0&&(r[s._name+\".range\"]=a.yr0.slice())}return i.call(\"relayout\",t,r).then((function(){for(var t=0;t<e.length;t++)m(e[t].plotinfo)}))}()})),f=Date.now(),p=window.requestAnimationFrame((function n(){h=Date.now();for(var a=Math.min(1,(h-f)/r.duration),o=d(a),s=0;s<e.length;s++)g(e[s],o);h-f>r.duration?(!function(){for(var r={},n=0;n<e.length;n++){var a=e[n],o=a.plotinfo.xaxis,s=a.plotinfo.yaxis;a.xr1&&(r[o._name+\".range\"]=a.xr1.slice()),a.yr1&&(r[s._name+\".range\"]=a.yr1.slice())}u&&u(),i.call(\"relayout\",t,r).then((function(){for(var t=0;t<e.length;t++)m(e[t].plotinfo)}))}(),p=window.cancelAnimationFrame(n)):p=window.requestAnimationFrame(n)})),Promise.resolve()}function m(t){var e=t.xaxis,r=t.yaxis;c._defs.select(\"#\"+t.clipId+\"> rect\").call(o.setTranslate,0,0).call(o.setScale,1,1),t.plot.call(o.setTranslate,e._offset,r._offset).call(o.setScale,1,1);var n=t.plot.selectAll(\".scatterlayer .trace\");n.selectAll(\".point\").call(o.setPointGroupScale,1,1),n.selectAll(\".textpoint\").call(o.setTextPointsScale,1,1),n.call(o.hideOutsideRangePoints,t)}function g(e,r){var n=e.plotinfo,i=n.xaxis,l=n.yaxis,c=i._length,u=l._length,f=!!e.xr1,h=!!e.yr1,p=[];if(f){var d=a.simpleMap(e.xr0,i.r2l),m=a.simpleMap(e.xr1,i.r2l),g=d[1]-d[0],v=m[1]-m[0];p[0]=(d[0]*(1-r)+r*m[0]-d[0])/(d[1]-d[0])*c,p[2]=c*(1-r+r*v/g),i.range[0]=i.l2r(d[0]*(1-r)+r*m[0]),i.range[1]=i.l2r(d[1]*(1-r)+r*m[1])}else p[0]=0,p[2]=c;if(h){var y=a.simpleMap(e.yr0,l.r2l),x=a.simpleMap(e.yr1,l.r2l),b=y[1]-y[0],_=x[1]-x[0];p[1]=(y[1]*(1-r)+r*x[1]-y[1])/(y[0]-y[1])*u,p[3]=u*(1-r+r*_/b),l.range[0]=i.l2r(y[0]*(1-r)+r*x[0]),l.range[1]=l.l2r(y[1]*(1-r)+r*x[1])}else p[1]=0,p[3]=u;s.drawOne(t,i,{skipTitle:!0}),s.drawOne(t,l,{skipTitle:!0}),s.redrawComponents(t,[i._id,l._id]);var w=f?c/p[2]:1,T=h?u/p[3]:1,k=f?p[0]:0,M=h?p[1]:0,A=f?p[0]/p[2]*c:0,S=h?p[1]/p[3]*u:0,E=i._offset-A,L=l._offset-S;n.clipRect.call(o.setTranslate,k,M).call(o.setScale,1/w,1/T),n.plot.call(o.setTranslate,E,L).call(o.setScale,w,T),o.setPointGroupScale(n.zoomScalePts,1/w,1/T),o.setTextPointsScale(n.zoomScaleTxt,1/w,1/T)}s.redrawComponents(t)}},{\"../../components/drawing\":684,\"../../lib\":799,\"../../registry\":927,\"./axes\":849,\"@plotly/d3\":58}],875:[function(t,e,r){\"use strict\";var n=t(\"../../registry\").traceIs,i=t(\"./axis_autotype\");function a(t){return{v:\"x\",h:\"y\"}[t.orientation||\"v\"]}function o(t,e){var r=a(t),i=n(t,\"box-violin\"),o=n(t._fullInput||{},\"candlestick\");return i&&!o&&e===r&&void 0===t[r]&&void 0===t[r+\"0\"]}e.exports=function(t,e,r,s){r(\"autotypenumbers\",s.autotypenumbersDflt),\"-\"===r(\"type\",(s.splomStash||{}).type)&&(!function(t,e){if(\"-\"!==t.type)return;var r,s=t._id,l=s.charAt(0);-1!==s.indexOf(\"scene\")&&(s=l);var c=function(t,e,r){for(var n=0;n<t.length;n++){var i=t[n];if(\"splom\"===i.type&&i._length>0&&(i[\"_\"+r+\"axes\"]||{})[e])return i;if((i[r+\"axis\"]||r)===e){if(o(i,r))return i;if((i[r]||[]).length||i[r+\"0\"])return i}}}(e,s,l);if(!c)return;if(\"histogram\"===c.type&&l==={v:\"y\",h:\"x\"}[c.orientation||\"v\"])return void(t.type=\"linear\");var u=l+\"calendar\",f=c[u],h={noMultiCategory:!n(c,\"cartesian\")||n(c,\"noMultiCategory\")};\"box\"===c.type&&c._hasPreCompStats&&l==={h:\"x\",v:\"y\"}[c.orientation||\"v\"]&&(h.noMultiCategory=!0);if(h.autotypenumbers=t.autotypenumbers,o(c,l)){var p=a(c),d=[];for(r=0;r<e.length;r++){var m=e[r];n(m,\"box-violin\")&&(m[l+\"axis\"]||l)===s&&(void 0!==m[p]?d.push(m[p][0]):void 0!==m.name?d.push(m.name):d.push(\"text\"),m[u]!==f&&(f=void 0))}t.type=i(d,f,h)}else if(\"splom\"===c.type){var g=c.dimensions[c._axesDim[s]];g.visible&&(t.type=i(g.values,f,h))}else t.type=i(c[l]||[c[l+\"0\"]],f,h)}(e,s.data),\"-\"===e.type?e.type=\"linear\":t.type=e.type)}},{\"../../registry\":927,\"./axis_autotype\":850}],876:[function(t,e,r){\"use strict\";var n=t(\"../registry\"),i=t(\"../lib\");function a(t,e,r){var n,a,o,s=!1;if(\"data\"===e.type)n=t._fullData[null!==e.traces?e.traces[0]:0];else{if(\"layout\"!==e.type)return!1;n=t._fullLayout}return a=i.nestedProperty(n,e.prop).get(),(o=r[e.type]=r[e.type]||{}).hasOwnProperty(e.prop)&&o[e.prop]!==a&&(s=!0),o[e.prop]=a,{changed:s,value:a}}function o(t,e){var r=[],n=e[0],a={};if(\"string\"==typeof n)a[n]=e[1];else{if(!i.isPlainObject(n))return r;a=n}return l(a,(function(t,e,n){r.push({type:\"layout\",prop:t,value:n})}),\"\",0),r}function s(t,e){var r,n,a,o,s=[];if(n=e[0],a=e[1],r=e[2],o={},\"string\"==typeof n)o[n]=a;else{if(!i.isPlainObject(n))return s;o=n,void 0===r&&(r=a)}return void 0===r&&(r=null),l(o,(function(e,n,i){var a,o;if(Array.isArray(i)){o=i.slice();var l=Math.min(o.length,t.data.length);r&&(l=Math.min(l,r.length)),a=[];for(var c=0;c<l;c++)a[c]=r?r[c]:c}else o=i,a=r?r.slice():null;if(null===a)Array.isArray(o)&&(o=o[0]);else if(Array.isArray(a)){if(!Array.isArray(o)){var u=o;o=[];for(var f=0;f<a.length;f++)o[f]=u}o.length=Math.min(a.length,o.length)}s.push({type:\"data\",prop:e,traces:a,value:o})}),\"\",0),s}function l(t,e,r,n){Object.keys(t).forEach((function(a){var o=t[a];if(\"_\"!==a[0]){var s=r+(n>0?\".\":\"\")+a;i.isPlainObject(o)?l(o,e,s,n+1):e(s,a,o)}}))}r.manageCommandObserver=function(t,e,n,o){var s={},l=!0;e&&e._commandObserver&&(s=e._commandObserver),s.cache||(s.cache={}),s.lookupTable={};var c=r.hasSimpleAPICommandBindings(t,n,s.lookupTable);if(e&&e._commandObserver){if(c)return s;if(e._commandObserver.remove)return e._commandObserver.remove(),e._commandObserver=null,s}if(c){a(t,c,s.cache),s.check=function(){if(l){var e=a(t,c,s.cache);return e.changed&&o&&void 0!==s.lookupTable[e.value]&&(s.disable(),Promise.resolve(o({value:e.value,type:c.type,prop:c.prop,traces:c.traces,index:s.lookupTable[e.value]})).then(s.enable,s.enable)),e.changed}};for(var u=[\"plotly_relayout\",\"plotly_redraw\",\"plotly_restyle\",\"plotly_update\",\"plotly_animatingframe\",\"plotly_afterplot\"],f=0;f<u.length;f++)t._internalOn(u[f],s.check);s.remove=function(){for(var e=0;e<u.length;e++)t._removeInternalListener(u[e],s.check)}}else i.log(\"Unable to automatically bind plot updates to API command\"),s.lookupTable={},s.remove=function(){};return s.disable=function(){l=!1},s.enable=function(){l=!0},e&&(e._commandObserver=s),s},r.hasSimpleAPICommandBindings=function(t,e,n){var i,a,o=e.length;for(i=0;i<o;i++){var s,l=e[i],c=l.method,u=l.args;if(Array.isArray(u)||(u=[]),!c)return!1;var f=r.computeAPICommandBindings(t,c,u);if(1!==f.length)return!1;if(a){if((s=f[0]).type!==a.type)return!1;if(s.prop!==a.prop)return!1;if(Array.isArray(a.traces)){if(!Array.isArray(s.traces))return!1;s.traces.sort();for(var h=0;h<a.traces.length;h++)if(a.traces[h]!==s.traces[h])return!1}else if(s.prop!==a.prop)return!1}else a=f[0],Array.isArray(a.traces)&&a.traces.sort();var p=(s=f[0]).value;if(Array.isArray(p)){if(1!==p.length)return!1;p=p[0]}n&&(n[p]=i)}return a},r.executeAPICommand=function(t,e,r){if(\"skip\"===e)return Promise.resolve();var a=n.apiMethodRegistry[e],o=[t];Array.isArray(r)||(r=[]);for(var s=0;s<r.length;s++)o.push(r[s]);return a.apply(null,o).catch((function(t){return i.warn(\"API call to Plotly.\"+e+\" rejected.\",t),Promise.reject(t)}))},r.computeAPICommandBindings=function(t,e,r){var n;switch(Array.isArray(r)||(r=[]),e){case\"restyle\":n=s(t,r);break;case\"relayout\":n=o(t,r);break;case\"update\":n=s(t,[r[0],r[2]]).concat(o(t,[r[1]]));break;case\"animate\":n=function(t,e){return Array.isArray(e[0])&&1===e[0].length&&-1!==[\"string\",\"number\"].indexOf(typeof e[0][0])?[{type:\"layout\",prop:\"_currentFrame\",value:e[0][0].toString()}]:[]}(0,r);break;default:n=[]}return n}},{\"../lib\":799,\"../registry\":927}],877:[function(t,e,r){\"use strict\";var n=t(\"../lib/extend\").extendFlat;r.attributes=function(t,e){e=e||{};var r={valType:\"info_array\",editType:(t=t||{}).editType,items:[{valType:\"number\",min:0,max:1,editType:t.editType},{valType:\"number\",min:0,max:1,editType:t.editType}],dflt:[0,1]},i=(t.name&&t.name,t.trace,e.description&&e.description,{x:n({},r,{}),y:n({},r,{}),editType:t.editType});return t.noGridCell||(i.row={valType:\"integer\",min:0,dflt:0,editType:t.editType},i.column={valType:\"integer\",min:0,dflt:0,editType:t.editType}),i},r.defaults=function(t,e,r,n){var i=n&&n.x||[0,1],a=n&&n.y||[0,1],o=e.grid;if(o){var s=r(\"domain.column\");void 0!==s&&(s<o.columns?i=o._domains.x[s]:delete t.domain.column);var l=r(\"domain.row\");void 0!==l&&(l<o.rows?a=o._domains.y[l]:delete t.domain.row)}var c=r(\"domain.x\",i),u=r(\"domain.y\",a);c[0]<c[1]||(t.domain.x=i.slice()),u[0]<u[1]||(t.domain.y=a.slice())}},{\"../lib/extend\":789}],878:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.editType,r=t.colorEditType;void 0===r&&(r=e);var n={family:{valType:\"string\",noBlank:!0,strict:!0,editType:e},size:{valType:\"number\",min:1,editType:e},color:{valType:\"color\",editType:r},editType:e};return t.arrayOk&&(n.family.arrayOk=!0,n.size.arrayOk=!0,n.color.arrayOk=!0),n}},{}],879:[function(t,e,r){\"use strict\";e.exports={_isLinkedToArray:\"frames_entry\",group:{valType:\"string\"},name:{valType:\"string\"},traces:{valType:\"any\"},baseframe:{valType:\"string\"},data:{valType:\"any\"},layout:{valType:\"any\"}}},{}],880:[function(t,e,r){\"use strict\";r.projNames={equirectangular:\"equirectangular\",mercator:\"mercator\",orthographic:\"orthographic\",\"natural earth\":\"naturalEarth\",kavrayskiy7:\"kavrayskiy7\",miller:\"miller\",robinson:\"robinson\",eckert4:\"eckert4\",\"azimuthal equal area\":\"azimuthalEqualArea\",\"azimuthal equidistant\":\"azimuthalEquidistant\",\"conic equal area\":\"conicEqualArea\",\"conic conformal\":\"conicConformal\",\"conic equidistant\":\"conicEquidistant\",gnomonic:\"gnomonic\",stereographic:\"stereographic\",mollweide:\"mollweide\",hammer:\"hammer\",\"transverse mercator\":\"transverseMercator\",\"albers usa\":\"albersUsa\",\"winkel tripel\":\"winkel3\",aitoff:\"aitoff\",sinusoidal:\"sinusoidal\"},r.axesNames=[\"lonaxis\",\"lataxis\"],r.lonaxisSpan={orthographic:180,\"azimuthal equal area\":360,\"azimuthal equidistant\":360,\"conic conformal\":180,gnomonic:160,stereographic:180,\"transverse mercator\":180,\"*\":360},r.lataxisSpan={\"conic conformal\":150,stereographic:179.5,\"*\":180},r.scopeDefaults={world:{lonaxisRange:[-180,180],lataxisRange:[-90,90],projType:\"equirectangular\",projRotate:[0,0,0]},usa:{lonaxisRange:[-180,-50],lataxisRange:[15,80],projType:\"albers usa\"},europe:{lonaxisRange:[-30,60],lataxisRange:[30,85],projType:\"conic conformal\",projRotate:[15,0,0],projParallels:[0,60]},asia:{lonaxisRange:[22,160],lataxisRange:[-15,55],projType:\"mercator\",projRotate:[0,0,0]},africa:{lonaxisRange:[-30,60],lataxisRange:[-40,40],projType:\"mercator\",projRotate:[0,0,0]},\"north america\":{lonaxisRange:[-180,-45],lataxisRange:[5,85],projType:\"conic conformal\",projRotate:[-100,0,0],projParallels:[29.5,45.5]},\"south america\":{lonaxisRange:[-100,-30],lataxisRange:[-60,15],projType:\"mercator\",projRotate:[0,0,0]}},r.clipPad=.001,r.precision=.1,r.landColor=\"#F0DC82\",r.waterColor=\"#3399FF\",r.locationmodeToLayer={\"ISO-3\":\"countries\",\"USA-states\":\"subunits\",\"country names\":\"countries\"},r.sphereSVG={type:\"Sphere\"},r.fillLayers={ocean:1,land:1,lakes:1},r.lineLayers={subunits:1,countries:1,coastlines:1,rivers:1,frame:1},r.layers=[\"bg\",\"ocean\",\"land\",\"lakes\",\"subunits\",\"countries\",\"coastlines\",\"rivers\",\"lataxis\",\"lonaxis\",\"frame\",\"backplot\",\"frontplot\"],r.layersForChoropleth=[\"bg\",\"ocean\",\"land\",\"subunits\",\"countries\",\"coastlines\",\"lataxis\",\"lonaxis\",\"frame\",\"backplot\",\"rivers\",\"lakes\",\"frontplot\"],r.layerNameToAdjective={ocean:\"ocean\",land:\"land\",lakes:\"lake\",subunits:\"subunit\",countries:\"country\",coastlines:\"coastline\",rivers:\"river\",frame:\"frame\"}},{}],881:[function(t,e,r){\"use strict\";var n=t(\"@plotly/d3\"),i=t(\"../../registry\"),a=t(\"../../lib\"),o=a.strTranslate,s=t(\"../../components/color\"),l=t(\"../../components/drawing\"),c=t(\"../../components/fx\"),u=t(\"../plots\"),f=t(\"../cartesian/axes\"),h=t(\"../cartesian/autorange\").getAutoRange,p=t(\"../../components/dragelement\"),d=t(\"../cartesian/select\").prepSelect,m=t(\"../cartesian/select\").clearSelect,g=t(\"../cartesian/select\").selectOnClick,v=t(\"./zoom\"),y=t(\"./constants\"),x=t(\"../../lib/geo_location_utils\"),b=t(\"../../lib/topojson_utils\"),_=t(\"topojson-client\").feature;function w(t){this.id=t.id,this.graphDiv=t.graphDiv,this.container=t.container,this.topojsonURL=t.topojsonURL,this.isStatic=t.staticPlot,this.topojsonName=null,this.topojson=null,this.projection=null,this.scope=null,this.viewInitial=null,this.fitScale=null,this.bounds=null,this.midPt=null,this.hasChoropleth=!1,this.traceHash={},this.layers={},this.basePaths={},this.dataPaths={},this.dataPoints={},this.clipDef=null,this.clipRect=null,this.bgRect=null,this.makeFramework()}t(\"./projections\")(n);var T=w.prototype;function k(t,e){var r=y.clipPad,n=t[0]+r,i=t[1]-r,a=e[0]+r,o=e[1]-r;n>0&&i<0&&(i+=360);var s=(i-n)/4;return{type:\"Polygon\",coordinates:[[[n,a],[n,o],[n+s,o],[n+2*s,o],[n+3*s,o],[i,o],[i,a],[i-s,a],[i-2*s,a],[i-3*s,a],[n,a]]]}}e.exports=function(t){return new w(t)},T.plot=function(t,e,r){var n=this,i=e[this.id],a=[],o=!1;for(var s in y.layerNameToAdjective)if(\"frame\"!==s&&i[\"show\"+s]){o=!0;break}for(var l=0;l<t.length;l++)if(t[0][0].trace.locationmode){o=!0;break}if(o){var c=b.getTopojsonName(i);null!==n.topojson&&c===n.topojsonName||(n.topojsonName=c,void 0===PlotlyGeoAssets.topojson[n.topojsonName]&&a.push(n.fetchTopojson()))}a=a.concat(x.fetchTraceGeoData(t)),r.push(new Promise((function(r,i){Promise.all(a).then((function(){n.topojson=PlotlyGeoAssets.topojson[n.topojsonName],n.update(t,e),r()})).catch(i)})))},T.fetchTopojson=function(){var t=this,e=b.getTopojsonPath(t.topojsonURL,t.topojsonName);return new Promise((function(r,i){n.json(e,(function(n,a){if(n)return 404===n.status?i(new Error([\"plotly.js could not find topojson file at\",e,\".\",\"Make sure the *topojsonURL* plot config option\",\"is set properly.\"].join(\" \"))):i(new Error([\"unexpected error while fetching topojson file at\",e].join(\" \")));PlotlyGeoAssets.topojson[t.topojsonName]=a,r()}))}))},T.update=function(t,e){var r=e[this.id];this.hasChoropleth=!1;for(var n=0;n<t.length;n++){var i=t[n],a=i[0].trace;\"choropleth\"===a.type&&(this.hasChoropleth=!0),!0===a.visible&&a._length>0&&a._module.calcGeoJSON(i,e)}if(!this.updateProjection(t,e)){this.viewInitial&&this.scope===r.scope||this.saveViewInitial(r),this.scope=r.scope,this.updateBaseLayers(e,r),this.updateDims(e,r),this.updateFx(e,r),u.generalUpdatePerTraceModule(this.graphDiv,this,t,r);var o=this.layers.frontplot.select(\".scatterlayer\");this.dataPoints.point=o.selectAll(\".point\"),this.dataPoints.text=o.selectAll(\"text\"),this.dataPaths.line=o.selectAll(\".js-line\");var s=this.layers.backplot.select(\".choroplethlayer\");this.dataPaths.choropleth=s.selectAll(\"path\"),this.render()}},T.updateProjection=function(t,e){var r=this.graphDiv,o=e[this.id],s=e._size,l=o.domain,c=o.projection,u=o.lonaxis,f=o.lataxis,p=u._ax,d=f._ax,m=this.projection=function(t){for(var e=t.projection.type,r=n.geo[y.projNames[e]](),i=t._isClipped?y.lonaxisSpan[e]/2:null,a=[\"center\",\"rotate\",\"parallels\",\"clipExtent\"],o=function(t){return t?r:[]},s=0;s<a.length;s++){var l=a[s];\"function\"!=typeof r[l]&&(r[l]=o)}r.isLonLatOverEdges=function(t){if(null===r(t))return!0;if(i){var e=r.rotate();return n.geo.distance(t,[-e[0],-e[1]])>i*Math.PI/180}return!1},r.getPath=function(){return n.geo.path().projection(r)},r.getBounds=function(t){return r.getPath().bounds(t)},r.fitExtent=function(t,e){var n=t[1][0]-t[0][0],i=t[1][1]-t[0][1],a=r.clipExtent&&r.clipExtent();r.scale(150).translate([0,0]),a&&r.clipExtent(null);var o=r.getBounds(e),s=Math.min(n/(o[1][0]-o[0][0]),i/(o[1][1]-o[0][1])),l=+t[0][0]+(n-s*(o[1][0]+o[0][0]))/2,c=+t[0][1]+(i-s*(o[1][1]+o[0][1]))/2;return a&&r.clipExtent(a),r.scale(150*s).translate([l,c])},r.precision(y.precision),i&&r.clipAngle(i-y.clipPad);return r}(o),g=[[s.l+s.w*l.x[0],s.t+s.h*(1-l.y[1])],[s.l+s.w*l.x[1],s.t+s.h*(1-l.y[0])]],v=o.center||{},x=c.rotation||{},b=u.range||[],_=f.range||[];if(o.fitbounds){p._length=g[1][0]-g[0][0],d._length=g[1][1]-g[0][1],p.range=h(r,p),d.range=h(r,d);var w=(p.range[0]+p.range[1])/2,T=(d.range[0]+d.range[1])/2;if(o._isScoped)v={lon:w,lat:T};else if(o._isClipped){v={lon:w,lat:T},x={lon:w,lat:T,roll:x.roll};var M=c.type,A=y.lonaxisSpan[M]/2||180,S=y.lataxisSpan[M]/2||90;b=[w-A,w+A],_=[T-S,T+S]}else v={lon:w,lat:T},x={lon:w,lat:x.lat,roll:x.roll}}m.center([v.lon-x.lon,v.lat-x.lat]).rotate([-x.lon,-x.lat,x.roll]).parallels(c.parallels);var E=k(b,_);m.fitExtent(g,E);var L=this.bounds=m.getBounds(E),C=this.fitScale=m.scale(),P=m.translate();if(!isFinite(L[0][0])||!isFinite(L[0][1])||!isFinite(L[1][0])||!isFinite(L[1][1])||isNaN(P[0])||isNaN(P[0])){for(var I=[\"fitbounds\",\"projection.rotation\",\"center\",\"lonaxis.range\",\"lataxis.range\"],O=\"Invalid geo settings, relayout'ing to default view.\",z={},D=0;D<I.length;D++)z[this.id+\".\"+I[D]]=null;return this.viewInitial=null,a.warn(O),r._promises.push(i.call(\"relayout\",r,z)),O}if(o.fitbounds){var R=m.getBounds(k(p.range,d.range)),F=Math.min((L[1][0]-L[0][0])/(R[1][0]-R[0][0]),(L[1][1]-L[0][1])/(R[1][1]-R[0][1]));isFinite(F)?m.scale(F*C):a.warn(\"Something went wrong during\"+this.id+\"fitbounds computations.\")}else m.scale(c.scale*C);var B=this.midPt=[(L[0][0]+L[1][0])/2,(L[0][1]+L[1][1])/2];if(m.translate([P[0]+(B[0]-P[0]),P[1]+(B[1]-P[1])]).clipExtent(L),o._isAlbersUsa){var N=m([v.lon,v.lat]),j=m.translate();m.translate([j[0]-(N[0]-j[0]),j[1]-(N[1]-j[1])])}},T.updateBaseLayers=function(t,e){var r=this,i=r.topojson,a=r.layers,o=r.basePaths;function c(t){return\"lonaxis\"===t||\"lataxis\"===t}function u(t){return Boolean(y.lineLayers[t])}function h(t){return Boolean(y.fillLayers[t])}var p=(this.hasChoropleth?y.layersForChoropleth:y.layers).filter((function(t){return u(t)||h(t)?e[\"show\"+t]:!c(t)||e[t].showgrid})),d=r.framework.selectAll(\".layer\").data(p,String);d.exit().each((function(t){delete a[t],delete o[t],n.select(this).remove()})),d.enter().append(\"g\").attr(\"class\",(function(t){return\"layer \"+t})).each((function(t){var e=a[t]=n.select(this);\"bg\"===t?r.bgRect=e.append(\"rect\").style(\"pointer-events\",\"all\"):c(t)?o[t]=e.append(\"path\").style(\"fill\",\"none\"):\"backplot\"===t?e.append(\"g\").classed(\"choroplethlayer\",!0):\"frontplot\"===t?e.append(\"g\").classed(\"scatterlayer\",!0):u(t)?o[t]=e.append(\"path\").style(\"fill\",\"none\").style(\"stroke-miterlimit\",2):h(t)&&(o[t]=e.append(\"path\").style(\"stroke\",\"none\"))})),d.order(),d.each((function(r){var n=o[r],a=y.layerNameToAdjective[r];\"frame\"===r?n.datum(y.sphereSVG):u(r)||h(r)?n.datum(_(i,i.objects[r])):c(r)&&n.datum(function(t,e,r){var n,i,a,o=e[t],s=y.scopeDefaults[e.scope];\"lonaxis\"===t?(n=s.lonaxisRange,i=s.lataxisRange,a=function(t,e){return[t,e]}):\"lataxis\"===t&&(n=s.lataxisRange,i=s.lonaxisRange,a=function(t,e){return[e,t]});var l={type:\"linear\",range:[n[0],n[1]-1e-6],tick0:o.tick0,dtick:o.dtick};f.setConvert(l,r);var c=f.calcTicks(l);e.isScoped||\"lonaxis\"!==t||c.pop();for(var u=c.length,h=new Array(u),p=0;p<u;p++)for(var d=c[p].x,m=h[p]=[],g=i[0];g<i[1]+2.5;g+=2.5)m.push(a(d,g));return{type:\"MultiLineString\",coordinates:h}}(r,e,t)).call(s.stroke,e[r].gridcolor).call(l.dashLine,\"\",e[r].gridwidth),u(r)?n.call(s.stroke,e[a+\"color\"]).call(l.dashLine,\"\",e[a+\"width\"]):h(r)&&n.call(s.fill,e[a+\"color\"])}))},T.updateDims=function(t,e){var r=this.bounds,n=(e.framewidth||0)/2,i=r[0][0]-n,a=r[0][1]-n,o=r[1][0]-i+n,c=r[1][1]-a+n;l.setRect(this.clipRect,i,a,o,c),this.bgRect.call(l.setRect,i,a,o,c).call(s.fill,e.bgcolor),this.xaxis._offset=i,this.xaxis._length=o,this.yaxis._offset=a,this.yaxis._length=c},T.updateFx=function(t,e){var r=this,o=r.graphDiv,s=r.bgRect,l=t.dragmode,u=t.clickmode;if(!r.isStatic){var f;\"select\"===l?f=function(t,e){(t.range={})[r.id]=[y([e.xmin,e.ymin]),y([e.xmax,e.ymax])]}:\"lasso\"===l&&(f=function(t,e,n){(t.lassoPoints={})[r.id]=n.filtered.map(y)});var h={element:r.bgRect.node(),gd:o,plotinfo:{id:r.id,xaxis:r.xaxis,yaxis:r.yaxis,fillRangeItems:f},xaxes:[r.xaxis],yaxes:[r.yaxis],subplot:r.id,clickFn:function(t){2===t&&m(o)}};\"pan\"===l?(s.node().onmousedown=null,s.call(v(r,e)),s.on(\"dblclick.zoom\",(function(){var t=r.viewInitial,e={};for(var n in t)e[r.id+\".\"+n]=t[n];i.call(\"_guiRelayout\",o,e),o.emit(\"plotly_doubleclick\",null)})),o._context._scrollZoom.geo||s.on(\"wheel.zoom\",null)):\"select\"!==l&&\"lasso\"!==l||(s.on(\".zoom\",null),h.prepFn=function(t,e,r){d(t,e,r,h,l)},p.init(h)),s.on(\"mousemove\",(function(){var t=r.projection.invert(a.getPositionFromD3Event());if(!t||isNaN(t[0])||isNaN(t[1]))return p.unhover(o,n.event);r.xaxis.p2c=function(){return t[0]},r.yaxis.p2c=function(){return t[1]},c.hover(o,n.event,r.id)})),s.on(\"mouseout\",(function(){o._dragging||p.unhover(o,n.event)})),s.on(\"click\",(function(){\"select\"!==l&&\"lasso\"!==l&&(u.indexOf(\"select\")>-1&&g(n.event,o,[r.xaxis],[r.yaxis],r.id,h),u.indexOf(\"event\")>-1&&c.click(o,n.event))}))}function y(t){return r.projection.invert([t[0]+r.xaxis._offset,t[1]+r.yaxis._offset])}},T.makeFramework=function(){var t=this,e=t.graphDiv,r=e._fullLayout,i=\"clip\"+r._uid+t.id;t.clipDef=r._clips.append(\"clipPath\").attr(\"id\",i),t.clipRect=t.clipDef.append(\"rect\"),t.framework=n.select(t.container).append(\"g\").attr(\"class\",\"geo \"+t.id).call(l.setClipUrl,i,e),t.project=function(e){var r=t.projection(e);return r?[r[0]-t.xaxis._offset,r[1]-t.yaxis._offset]:[null,null]},t.xaxis={_id:\"x\",c2p:function(e){return t.project(e)[0]}},t.yaxis={_id:\"y\",c2p:function(e){return t.project(e)[1]}},t.mockAxis={type:\"linear\",showexponent:\"all\",exponentformat:\"B\"},f.setConvert(t.mockAxis,r)},T.saveViewInitial=function(t){var e,r=t.center||{},n=t.projection,i=n.rotation||{};this.viewInitial={fitbounds:t.fitbounds,\"projection.scale\":n.scale},e=t._isScoped?{\"center.lon\":r.lon,\"center.lat\":r.lat}:t._isClipped?{\"projection.rotation.lon\":i.lon,\"projection.rotation.lat\":i.lat}:{\"center.lon\":r.lon,\"center.lat\":r.lat,\"projection.rotation.lon\":i.lon},a.extendFlat(this.viewInitial,e)},T.render=function(){var t,e=this.projection,r=e.getPath();function n(t){var r=e(t.lonlat);return r?o(r[0],r[1]):null}function i(t){return e.isLonLatOverEdges(t.lonlat)?\"none\":null}for(t in this.basePaths)this.basePaths[t].attr(\"d\",r);for(t in this.dataPaths)this.dataPaths[t].attr(\"d\",(function(t){return r(t.geojson)}));for(t in this.dataPoints)this.dataPoints[t].attr(\"display\",i).attr(\"transform\",n)}},{\"../../components/color\":662,\"../../components/dragelement\":681,\"../../components/drawing\":684,\"../../components/fx\":702,\"../../lib\":799,\"../../lib/geo_location_utils\":792,\"../../lib/topojson_utils\":827,\"../../registry\":927,\"../cartesian/autorange\":848,\"../cartesian/axes\":849,\"../cartesian/select\":869,\"../plots\":913,\"./constants\":880,\"./projections\":885,\"./zoom\":886,\"@plotly/d3\":58,\"topojson-client\":597}],882:[function(t,e,r){\"use strict\";var n=t(\"../../plots/get_data\").getSubplotCalcData,i=t(\"../../lib\").counterRegex,a=t(\"./geo\"),o=\"geo\",s=i(o),l={};l.geo={valType:\"subplotid\",dflt:o,editType:\"calc\"},e.exports={attr:o,name:o,idRoot:o,idRegex:s,attrRegex:s,attributes:l,layoutAttributes:t(\"./layout_attributes\"),supplyLayoutDefaults:t(\"./layout_defaults\"),plot:function(t){for(var e=t._fullLayout,r=t.calcdata,i=e._subplots.geo,s=0;s<i.length;s++){var l=i[s],c=n(r,o,l),u=e[l]._subplot;u||(u=a({id:l,graphDiv:t,container:e._geolayer.node(),topojsonURL:t._context.topojsonURL,staticPlot:t._context.staticPlot}),e[l]._subplot=u),u.plot(c,e,t._promises)}},updateFx:function(t){for(var e=t._fullLayout,r=e._subplots.geo,n=0;n<r.length;n++){var i=e[r[n]];i._subplot.updateFx(e,i)}},clean:function(t,e,r,n){for(var i=n._subplots.geo||[],a=0;a<i.length;a++){var o=i[a],s=n[o]._subplot;!e[o]&&s&&(s.framework.remove(),s.clipDef.remove())}}}},{\"../../lib\":799,\"../../plots/get_data\":887,\"./geo\":881,\"./layout_attributes\":883,\"./layout_defaults\":884}],883:[function(t,e,r){\"use strict\";var n=t(\"../../components/color/attributes\"),i=t(\"../domain\").attributes,a=t(\"./constants\"),o=t(\"../../plot_api/edit_types\").overrideAll,s={range:{valType:\"info_array\",items:[{valType:\"number\"},{valType:\"number\"}]},showgrid:{valType:\"boolean\",dflt:!1},tick0:{valType:\"number\",dflt:0},dtick:{valType:\"number\"},gridcolor:{valType:\"color\",dflt:n.lightLine},gridwidth:{valType:\"number\",min:0,dflt:1}};(e.exports=o({domain:i({name:\"geo\"},{}),fitbounds:{valType:\"enumerated\",values:[!1,\"locations\",\"geojson\"],dflt:!1,editType:\"plot\"},resolution:{valType:\"enumerated\",values:[110,50],dflt:110,coerceNumber:!0},scope:{valType:\"enumerated\",values:Object.keys(a.scopeDefaults),dflt:\"world\"},projection:{type:{valType:\"enumerated\",values:Object.keys(a.projNames)},rotation:{lon:{valType:\"number\"},lat:{valType:\"number\"},roll:{valType:\"number\"}},parallels:{valType:\"info_array\",items:[{valType:\"number\"},{valType:\"number\"}]},scale:{valType:\"number\",min:0,dflt:1}},center:{lon:{valType:\"number\"},lat:{valType:\"number\"}},visible:{valType:\"boolean\",dflt:!0},showcoastlines:{valType:\"boolean\"},coastlinecolor:{valType:\"color\",dflt:n.defaultLine},coastlinewidth:{valType:\"number\",min:0,dflt:1},showland:{valType:\"boolean\",dflt:!1},landcolor:{valType:\"color\",dflt:a.landColor},showocean:{valType:\"boolean\",dflt:!1},oceancolor:{valType:\"color\",dflt:a.waterColor},showlakes:{valType:\"boolean\",dflt:!1},lakecolor:{valType:\"color\",dflt:a.waterColor},showrivers:{valType:\"boolean\",dflt:!1},rivercolor:{valType:\"color\",dflt:a.waterColor},riverwidth:{valType:\"number\",min:0,dflt:1},showcountries:{valType:\"boolean\"},countrycolor:{valType:\"color\",dflt:n.defaultLine},countrywidth:{valType:\"number\",min:0,dflt:1},showsubunits:{valType:\"boolean\"},subunitcolor:{valType:\"color\",dflt:n.defaultLine},subunitwidth:{valType:\"number\",min:0,dflt:1},showframe:{valType:\"boolean\"},framecolor:{valType:\"color\",dflt:n.defaultLine},framewidth:{valType:\"number\",min:0,dflt:1},bgcolor:{valType:\"color\",dflt:n.background},lonaxis:s,lataxis:s},\"plot\",\"from-root\")).uirevision={valType:\"any\",editType:\"none\"}},{\"../../components/color/attributes\":661,\"../../plot_api/edit_types\":831,\"../domain\":877,\"./constants\":880}],884:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../subplot_defaults\"),a=t(\"../get_data\").getSubplotData,o=t(\"./constants\"),s=t(\"./layout_attributes\"),l=o.axesNames;function c(t,e,r,i){var s=a(i.fullData,\"geo\",i.id).map((function(t){return t._expandedIndex})),c=r(\"resolution\"),u=r(\"scope\"),f=o.scopeDefaults[u],h=r(\"projection.type\",f.projType),p=e._isAlbersUsa=\"albers usa\"===h;p&&(u=e.scope=\"usa\");var d=e._isScoped=\"world\"!==u,m=e._isConic=-1!==h.indexOf(\"conic\"),g=e._isClipped=!!o.lonaxisSpan[h];if(!1===t.visible){var v=n.extendDeep({},e._template);v.showcoastlines=!1,v.showcountries=!1,v.showframe=!1,v.showlakes=!1,v.showland=!1,v.showocean=!1,v.showrivers=!1,v.showsubunits=!1,v.lonaxis&&(v.lonaxis.showgrid=!1),v.lataxis&&(v.lataxis.showgrid=!1),e._template=v}for(var y=r(\"visible\"),x=0;x<l.length;x++){var b,_=l[x],w=[30,10][x];if(d)b=f[_+\"Range\"];else{var T=o[_+\"Span\"],k=(T[h]||T[\"*\"])/2,M=r(\"projection.rotation.\"+_.substr(0,3),f.projRotate[x]);b=[M-k,M+k]}var A=r(_+\".range\",b);r(_+\".tick0\"),r(_+\".dtick\",w),r(_+\".showgrid\",!!y&&void 0)&&(r(_+\".gridcolor\"),r(_+\".gridwidth\")),e[_]._ax={type:\"linear\",_id:_.slice(0,3),_traceIndices:s,setScale:n.identity,c2l:n.identity,r2l:n.identity,autorange:!0,range:A.slice(),_m:1,_input:{}}}var S=e.lonaxis.range,E=e.lataxis.range,L=S[0],C=S[1];L>0&&C<0&&(C+=360);var P,I,O,z=(L+C)/2;if(!p){var D=d?f.projRotate:[z,0,0];P=r(\"projection.rotation.lon\",D[0]),r(\"projection.rotation.lat\",D[1]),r(\"projection.rotation.roll\",D[2]),r(\"showcoastlines\",!d&&y)&&(r(\"coastlinecolor\"),r(\"coastlinewidth\")),r(\"showocean\",!!y&&void 0)&&r(\"oceancolor\")}(p?(I=-96.6,O=38.7):(I=d?z:P,O=(E[0]+E[1])/2),r(\"center.lon\",I),r(\"center.lat\",O),m)&&r(\"projection.parallels\",f.projParallels||[0,60]);r(\"projection.scale\"),r(\"showland\",!!y&&void 0)&&r(\"landcolor\"),r(\"showlakes\",!!y&&void 0)&&r(\"lakecolor\"),r(\"showrivers\",!!y&&void 0)&&(r(\"rivercolor\"),r(\"riverwidth\")),r(\"showcountries\",d&&\"usa\"!==u&&y)&&(r(\"countrycolor\"),r(\"countrywidth\")),(\"usa\"===u||\"north america\"===u&&50===c)&&(r(\"showsubunits\",y),r(\"subunitcolor\"),r(\"subunitwidth\")),d||r(\"showframe\",y)&&(r(\"framecolor\"),r(\"framewidth\")),r(\"bgcolor\"),r(\"fitbounds\")&&(delete e.projection.scale,d?(delete e.center.lon,delete e.center.lat):g?(delete e.center.lon,delete e.center.lat,delete e.projection.rotation.lon,delete e.projection.rotation.lat,delete e.lonaxis.range,delete e.lataxis.range):(delete e.center.lon,delete e.center.lat,delete e.projection.rotation.lon))}e.exports=function(t,e,r){i(t,e,r,{type:\"geo\",attributes:s,handleDefaults:c,fullData:r,partition:\"y\"})}},{\"../../lib\":799,\"../get_data\":887,\"../subplot_defaults\":921,\"./constants\":880,\"./layout_attributes\":883}],885:[function(t,e,r){\"use strict\";e.exports=function(t){function e(t,e){return{type:\"Feature\",id:t.id,properties:t.properties,geometry:r(t.geometry,e)}}function r(e,n){if(!e)return null;if(\"GeometryCollection\"===e.type)return{type:\"GeometryCollection\",geometries:object.geometries.map((function(t){return r(t,n)}))};if(!c.hasOwnProperty(e.type))return null;var i=c[e.type];return t.geo.stream(e,n(i)),i.result()}t.geo.project=function(t,e){var i=e.stream;if(!i)throw new Error(\"not yet supported\");return(t&&n.hasOwnProperty(t.type)?n[t.type]:r)(t,i)};var n={Feature:e,FeatureCollection:function(t,r){return{type:\"FeatureCollection\",features:t.features.map((function(t){return e(t,r)}))}}},i=[],a=[],o={point:function(t,e){i.push([t,e])},result:function(){var t=i.length?i.length<2?{type:\"Point\",coordinates:i[0]}:{type:\"MultiPoint\",coordinates:i}:null;return i=[],t}},s={lineStart:u,point:function(t,e){i.push([t,e])},lineEnd:function(){i.length&&(a.push(i),i=[])},result:function(){var t=a.length?a.length<2?{type:\"LineString\",coordinates:a[0]}:{type:\"MultiLineString\",coordinates:a}:null;return a=[],t}},l={polygonStart:u,lineStart:u,point:function(t,e){i.push([t,e])},lineEnd:function(){var t=i.length;if(t){do{i.push(i[0].slice())}while(++t<4);a.push(i),i=[]}},polygonEnd:u,result:function(){if(!a.length)return null;var t=[],e=[];return a.forEach((function(r){!function(t){if((e=t.length)<4)return!1;var e,r=0,n=t[e-1][1]*t[0][0]-t[e-1][0]*t[0][1];for(;++r<e;)n+=t[r-1][1]*t[r][0]-t[r-1][0]*t[r][1];return n<=0}(r)?e.push(r):t.push([r])})),e.forEach((function(e){var r=e[0];t.some((function(t){if(function(t,e){for(var r=e[0],n=e[1],i=!1,a=0,o=t.length,s=o-1;a<o;s=a++){var l=t[a],c=l[0],u=l[1],f=t[s],h=f[0],p=f[1];u>n^p>n&&r<(h-c)*(n-u)/(p-u)+c&&(i=!i)}return i}(t[0],r))return t.push(e),!0}))||t.push([e])})),a=[],t.length?t.length>1?{type:\"MultiPolygon\",coordinates:t}:{type:\"Polygon\",coordinates:t[0]}:null}},c={Point:o,MultiPoint:o,LineString:s,MultiLineString:s,Polygon:l,MultiPolygon:l,Sphere:l};function u(){}var f=1e-6,h=Math.PI,p=h/2,d=(Math.sqrt(h),h/180),m=180/h;function g(t){return t>1?p:t<-1?-p:Math.asin(t)}function v(t){return t>1?0:t<-1?h:Math.acos(t)}var y=t.geo.projection,x=t.geo.projectionMutator;function b(t,e){var r=(2+p)*Math.sin(e);e/=2;for(var n=0,i=1/0;n<10&&Math.abs(i)>f;n++){var a=Math.cos(e);e-=i=(e+Math.sin(e)*(a+2)-r)/(2*a*(1+a))}return[2/Math.sqrt(h*(4+h))*t*(1+Math.cos(e)),2*Math.sqrt(h/(4+h))*Math.sin(e)]}t.geo.interrupt=function(e){var r,n=[[[[-h,0],[0,p],[h,0]]],[[[-h,0],[0,-p],[h,0]]]];function i(t,r){for(var i=r<0?-1:1,a=n[+(r<0)],o=0,s=a.length-1;o<s&&t>a[o][2][0];++o);var l=e(t-a[o][1][0],r);return l[0]+=e(a[o][1][0],i*r>i*a[o][0][1]?a[o][0][1]:r)[0],l}function a(){r=n.map((function(t){return t.map((function(t){var r,n=e(t[0][0],t[0][1])[0],i=e(t[2][0],t[2][1])[0],a=e(t[1][0],t[0][1])[1],o=e(t[1][0],t[1][1])[1];return a>o&&(r=a,a=o,o=r),[[n,a],[i,o]]}))}))}e.invert&&(i.invert=function(t,a){for(var o=r[+(a<0)],s=n[+(a<0)],l=0,u=o.length;l<u;++l){var f=o[l];if(f[0][0]<=t&&t<f[1][0]&&f[0][1]<=a&&a<f[1][1]){var h=e.invert(t-e(s[l][1][0],0)[0],a);return h[0]+=s[l][1][0],c(i(h[0],h[1]),[t,a])?h:null}}});var o=t.geo.projection(i),s=o.stream;function l(t,e){for(var r,n,i,a=-1,o=t.length,s=t[0],l=[];++a<o;){n=((r=t[a])[0]-s[0])/e,i=(r[1]-s[1])/e;for(var c=0;c<e;++c)l.push([s[0]+c*n,s[1]+c*i]);s=r}return l.push(r),l}function c(t,e){return Math.abs(t[0]-e[0])<f&&Math.abs(t[1]-e[1])<f}return o.stream=function(e){var r=o.rotate(),i=s(e),a=(o.rotate([0,0]),s(e));return o.rotate(r),i.sphere=function(){t.geo.stream(function(){for(var e=1e-6,r=[],i=0,a=n[0].length;i<a;++i){var o=180*(p=n[0][i])[0][0]/h,s=180*p[0][1]/h,c=180*p[1][1]/h,u=180*p[2][0]/h,f=180*p[2][1]/h;r.push(l([[o+e,s+e],[o+e,c-e],[u-e,c-e],[u-e,f+e]],30))}for(i=n[1].length-1;i>=0;--i){var p;o=180*(p=n[1][i])[0][0]/h,s=180*p[0][1]/h,c=180*p[1][1]/h,u=180*p[2][0]/h,f=180*p[2][1]/h;r.push(l([[u-e,f-e],[u-e,c+e],[o+e,c+e],[o+e,s-e]],30))}return{type:\"Polygon\",coordinates:[t.merge(r)]}}(),a)},i},o.lobes=function(t){return arguments.length?(n=t.map((function(t){return t.map((function(t){return[[t[0][0]*h/180,t[0][1]*h/180],[t[1][0]*h/180,t[1][1]*h/180],[t[2][0]*h/180,t[2][1]*h/180]]}))})),a(),o):n.map((function(t){return t.map((function(t){return[[180*t[0][0]/h,180*t[0][1]/h],[180*t[1][0]/h,180*t[1][1]/h],[180*t[2][0]/h,180*t[2][1]/h]]}))}))},o},b.invert=function(t,e){var r=.5*e*Math.sqrt((4+h)/h),n=g(r),i=Math.cos(n);return[t/(2/Math.sqrt(h*(4+h))*(1+i)),g((n+r*(i+2))/(2+p))]},(t.geo.eckert4=function(){return y(b)}).raw=b;var _=t.geo.azimuthalEqualArea.raw;function w(t,e){if(arguments.length<2&&(e=t),1===e)return _;if(e===1/0)return T;function r(r,n){var i=_(r/e,n);return i[0]*=t,i}return r.invert=function(r,n){var i=_.invert(r/t,n);return i[0]*=e,i},r}function T(t,e){return[t*Math.cos(e)/Math.cos(e/=2),2*Math.sin(e)]}function k(t,e){return[3*t/(2*h)*Math.sqrt(h*h/3-e*e),e]}function M(t,e){return[t,1.25*Math.log(Math.tan(h/4+.4*e))]}function A(t){return function(e){var r,n=t*Math.sin(e),i=30;do{e-=r=(e+Math.sin(e)-n)/(1+Math.cos(e))}while(Math.abs(r)>f&&--i>0);return e/2}}T.invert=function(t,e){var r=2*g(e/2);return[t*Math.cos(r/2)/Math.cos(r),r]},(t.geo.hammer=function(){var t=2,e=x(w),r=e(t);return r.coefficient=function(r){return arguments.length?e(t=+r):t},r}).raw=w,k.invert=function(t,e){return[2/3*h*t/Math.sqrt(h*h/3-e*e),e]},(t.geo.kavrayskiy7=function(){return y(k)}).raw=k,M.invert=function(t,e){return[t,2.5*Math.atan(Math.exp(.8*e))-.625*h]},(t.geo.miller=function(){return y(M)}).raw=M,A(h);var S=function(t,e,r){var n=A(r);function i(r,i){return[t*r*Math.cos(i=n(i)),e*Math.sin(i)]}return i.invert=function(n,i){var a=g(i/e);return[n/(t*Math.cos(a)),g((2*a+Math.sin(2*a))/r)]},i}(Math.SQRT2/p,Math.SQRT2,h);function E(t,e){var r=e*e,n=r*r;return[t*(.8707-.131979*r+n*(n*(.003971*r-.001529*n)-.013791)),e*(1.007226+r*(.015085+n*(.028874*r-.044475-.005916*n)))]}(t.geo.mollweide=function(){return y(S)}).raw=S,E.invert=function(t,e){var r,n=e,i=25;do{var a=n*n,o=a*a;n-=r=(n*(1.007226+a*(.015085+o*(.028874*a-.044475-.005916*o)))-e)/(1.007226+a*(.045255+o*(.259866*a-.311325-.005916*11*o)))}while(Math.abs(r)>f&&--i>0);return[t/(.8707+(a=n*n)*(a*(a*a*a*(.003971-.001529*a)-.013791)-.131979)),n]},(t.geo.naturalEarth=function(){return y(E)}).raw=E;var L=[[.9986,-.062],[1,0],[.9986,.062],[.9954,.124],[.99,.186],[.9822,.248],[.973,.31],[.96,.372],[.9427,.434],[.9216,.4958],[.8962,.5571],[.8679,.6176],[.835,.6769],[.7986,.7346],[.7597,.7903],[.7186,.8435],[.6732,.8936],[.6213,.9394],[.5722,.9761],[.5322,1]];function C(t,e){var r,n=Math.min(18,36*Math.abs(e)/h),i=Math.floor(n),a=n-i,o=(r=L[i])[0],s=r[1],l=(r=L[++i])[0],c=r[1],u=(r=L[Math.min(19,++i)])[0],f=r[1];return[t*(l+a*(u-o)/2+a*a*(u-2*l+o)/2),(e>0?p:-p)*(c+a*(f-s)/2+a*a*(f-2*c+s)/2)]}function P(t,e){return[t*Math.cos(e),e]}function I(t,e){var r,n=Math.cos(e),i=(r=v(n*Math.cos(t/=2)))?r/Math.sin(r):1;return[2*n*Math.sin(t)*i,Math.sin(e)*i]}function O(t,e){var r=I(t,e);return[(r[0]+t/p)/2,(r[1]+e)/2]}L.forEach((function(t){t[1]*=1.0144})),C.invert=function(t,e){var r=e/p,n=90*r,i=Math.min(18,Math.abs(n/5)),a=Math.max(0,Math.floor(i));do{var o=L[a][1],s=L[a+1][1],l=L[Math.min(19,a+2)][1],c=l-o,u=l-2*s+o,f=2*(Math.abs(r)-s)/c,h=u/c,g=f*(1-h*f*(1-2*h*f));if(g>=0||1===a){n=(e>=0?5:-5)*(g+i);var v,y=50;do{g=(i=Math.min(18,Math.abs(n)/5))-(a=Math.floor(i)),o=L[a][1],s=L[a+1][1],l=L[Math.min(19,a+2)][1],n-=(v=(e>=0?p:-p)*(s+g*(l-o)/2+g*g*(l-2*s+o)/2)-e)*m}while(Math.abs(v)>1e-12&&--y>0);break}}while(--a>=0);var x=L[a][0],b=L[a+1][0],_=L[Math.min(19,a+2)][0];return[t/(b+g*(_-x)/2+g*g*(_-2*b+x)/2),n*d]},(t.geo.robinson=function(){return y(C)}).raw=C,P.invert=function(t,e){return[t/Math.cos(e),e]},(t.geo.sinusoidal=function(){return y(P)}).raw=P,I.invert=function(t,e){if(!(t*t+4*e*e>h*h+f)){var r=t,n=e,i=25;do{var a,o=Math.sin(r),s=Math.sin(r/2),l=Math.cos(r/2),c=Math.sin(n),u=Math.cos(n),p=Math.sin(2*n),d=c*c,m=u*u,g=s*s,y=1-m*l*l,x=y?v(u*l)*Math.sqrt(a=1/y):a=0,b=2*x*u*s-t,_=x*c-e,w=a*(m*g+x*u*l*d),T=a*(.5*o*p-2*x*c*s),k=.25*a*(p*s-x*c*m*o),M=a*(d*l+x*g*u),A=T*k-M*w;if(!A)break;var S=(_*T-b*M)/A,E=(b*k-_*w)/A;r-=S,n-=E}while((Math.abs(S)>f||Math.abs(E)>f)&&--i>0);return[r,n]}},(t.geo.aitoff=function(){return y(I)}).raw=I,O.invert=function(t,e){var r=t,n=e,i=25;do{var a,o=Math.cos(n),s=Math.sin(n),l=Math.sin(2*n),c=s*s,u=o*o,h=Math.sin(r),d=Math.cos(r/2),m=Math.sin(r/2),g=m*m,y=1-u*d*d,x=y?v(o*d)*Math.sqrt(a=1/y):a=0,b=.5*(2*x*o*m+r/p)-t,_=.5*(x*s+n)-e,w=.5*a*(u*g+x*o*d*c)+.5/p,T=a*(h*l/4-x*s*m),k=.125*a*(l*m-x*s*u*h),M=.5*a*(c*d+x*g*o)+.5,A=T*k-M*w,S=(_*T-b*M)/A,E=(b*k-_*w)/A;r-=S,n-=E}while((Math.abs(S)>f||Math.abs(E)>f)&&--i>0);return[r,n]},(t.geo.winkel3=function(){return y(O)}).raw=O}},{}],886:[function(t,e,r){\"use strict\";var n=t(\"@plotly/d3\"),i=t(\"../../lib\"),a=t(\"../../registry\"),o=Math.PI/180,s=180/Math.PI,l={cursor:\"pointer\"},c={cursor:\"auto\"};function u(t,e){return n.behavior.zoom().translate(e.translate()).scale(e.scale())}function f(t,e,r){var n=t.id,o=t.graphDiv,s=o.layout,l=s[n],c=o._fullLayout,u=c[n],f={},h={};function p(t,e){f[n+\".\"+t]=i.nestedProperty(l,t).get(),a.call(\"_storeDirectGUIEdit\",s,c._preGUI,f);var r=i.nestedProperty(u,t);r.get()!==e&&(r.set(e),i.nestedProperty(l,t).set(e),h[n+\".\"+t]=e)}r(p),p(\"projection.scale\",e.scale()/t.fitScale),p(\"fitbounds\",!1),o.emit(\"plotly_relayout\",h)}function h(t,e){var r=u(0,e);function i(r){var n=e.invert(t.midPt);r(\"center.lon\",n[0]),r(\"center.lat\",n[1])}return r.on(\"zoomstart\",(function(){n.select(this).style(l)})).on(\"zoom\",(function(){e.scale(n.event.scale).translate(n.event.translate),t.render();var r=e.invert(t.midPt);t.graphDiv.emit(\"plotly_relayouting\",{\"geo.projection.scale\":e.scale()/t.fitScale,\"geo.center.lon\":r[0],\"geo.center.lat\":r[1]})})).on(\"zoomend\",(function(){n.select(this).style(c),f(t,e,i)})),r}function p(t,e){var r,i,a,o,s,h,p,d,m,g=u(0,e);function v(t){return e.invert(t)}function y(r){var n=e.rotate(),i=e.invert(t.midPt);r(\"projection.rotation.lon\",-n[0]),r(\"center.lon\",i[0]),r(\"center.lat\",i[1])}return g.on(\"zoomstart\",(function(){n.select(this).style(l),r=n.mouse(this),i=e.rotate(),a=e.translate(),o=i,s=v(r)})).on(\"zoom\",(function(){if(h=n.mouse(this),function(t){var r=v(t);if(!r)return!0;var n=e(r);return Math.abs(n[0]-t[0])>2||Math.abs(n[1]-t[1])>2}(r))return g.scale(e.scale()),void g.translate(e.translate());e.scale(n.event.scale),e.translate([a[0],n.event.translate[1]]),s?v(h)&&(d=v(h),p=[o[0]+(d[0]-s[0]),i[1],i[2]],e.rotate(p),o=p):s=v(r=h),m=!0,t.render();var l=e.rotate(),c=e.invert(t.midPt);t.graphDiv.emit(\"plotly_relayouting\",{\"geo.projection.scale\":e.scale()/t.fitScale,\"geo.center.lon\":c[0],\"geo.center.lat\":c[1],\"geo.projection.rotation.lon\":-l[0]})})).on(\"zoomend\",(function(){n.select(this).style(c),m&&f(t,e,y)})),g}function d(t,e){var r,i={r:e.rotate(),k:e.scale()},a=u(0,e),o=function(t){var e=0,r=arguments.length,i=[];for(;++e<r;)i.push(arguments[e]);var a=n.dispatch.apply(null,i);return a.of=function(e,r){return function(i){var o;try{o=i.sourceEvent=n.event,i.target=t,n.event=i,a[i.type].apply(e,r)}finally{n.event=o}}},a}(a,\"zoomstart\",\"zoom\",\"zoomend\"),s=0,h=a.on;function p(t){s++||t({type:\"zoomstart\"})}function d(t){t({type:\"zoom\"})}function b(t){--s||t({type:\"zoomend\"})}function _(t){var r=e.rotate();t(\"projection.rotation.lon\",-r[0]),t(\"projection.rotation.lat\",-r[1])}return a.on(\"zoomstart\",(function(){n.select(this).style(l);var t=n.mouse(this),s=e.rotate(),c=s,u=e.translate(),f=g(s);r=m(e,t),h.call(a,\"zoom\",(function(){var a=n.mouse(this);if(e.scale(i.k=n.event.scale),r){if(m(e,a)){e.rotate(s).translate(u);var l=m(e,a),h=y(r,l),p=T(v(f,h)),g=i.r=x(p,r,c);isFinite(g[0])&&isFinite(g[1])&&isFinite(g[2])||(g=c),e.rotate(g),c=g}}else r=m(e,t=a);d(o.of(this,arguments))})),p(o.of(this,arguments))})).on(\"zoomend\",(function(){n.select(this).style(c),h.call(a,\"zoom\",null),b(o.of(this,arguments)),f(t,e,_)})).on(\"zoom.redraw\",(function(){t.render();var r=e.rotate();t.graphDiv.emit(\"plotly_relayouting\",{\"geo.projection.scale\":e.scale()/t.fitScale,\"geo.projection.rotation.lon\":-r[0],\"geo.projection.rotation.lat\":-r[1]})})),n.rebind(a,o,\"on\")}function m(t,e){var r=t.invert(e);return r&&isFinite(r[0])&&isFinite(r[1])&&function(t){var e=t[0]*o,r=t[1]*o,n=Math.cos(r);return[n*Math.cos(e),n*Math.sin(e),Math.sin(r)]}(r)}function g(t){var e=.5*t[0]*o,r=.5*t[1]*o,n=.5*t[2]*o,i=Math.sin(e),a=Math.cos(e),s=Math.sin(r),l=Math.cos(r),c=Math.sin(n),u=Math.cos(n);return[a*l*u+i*s*c,i*l*u-a*s*c,a*s*u+i*l*c,a*l*c-i*s*u]}function v(t,e){var r=t[0],n=t[1],i=t[2],a=t[3],o=e[0],s=e[1],l=e[2],c=e[3];return[r*o-n*s-i*l-a*c,r*s+n*o+i*c-a*l,r*l-n*c+i*o+a*s,r*c+n*l-i*s+a*o]}function y(t,e){if(t&&e){var r=function(t,e){return[t[1]*e[2]-t[2]*e[1],t[2]*e[0]-t[0]*e[2],t[0]*e[1]-t[1]*e[0]]}(t,e),n=Math.sqrt(k(r,r)),i=.5*Math.acos(Math.max(-1,Math.min(1,k(t,e)))),a=Math.sin(i)/n;return n&&[Math.cos(i),r[2]*a,-r[1]*a,r[0]*a]}}function x(t,e,r){var n=w(e,2,t[0]);n=w(n,1,t[1]),n=w(n,0,t[2]-r[2]);var i,a,o=e[0],l=e[1],c=e[2],u=n[0],f=n[1],h=n[2],p=Math.atan2(l,o)*s,d=Math.sqrt(o*o+l*l);Math.abs(f)>d?(a=(f>0?90:-90)-p,i=0):(a=Math.asin(f/d)*s-p,i=Math.sqrt(d*d-f*f));var m=180-a-2*p,g=(Math.atan2(h,u)-Math.atan2(c,i))*s,v=(Math.atan2(h,u)-Math.atan2(c,-i))*s;return b(r[0],r[1],a,g)<=b(r[0],r[1],m,v)?[a,g,r[2]]:[m,v,r[2]]}function b(t,e,r,n){var i=_(r-t),a=_(n-e);return Math.sqrt(i*i+a*a)}function _(t){return(t%360+540)%360-180}function w(t,e,r){var n=r*o,i=t.slice(),a=0===e?1:0,s=2===e?1:2,l=Math.cos(n),c=Math.sin(n);return i[a]=t[a]*l-t[s]*c,i[s]=t[s]*l+t[a]*c,i}function T(t){return[Math.atan2(2*(t[0]*t[1]+t[2]*t[3]),1-2*(t[1]*t[1]+t[2]*t[2]))*s,Math.asin(Math.max(-1,Math.min(1,2*(t[0]*t[2]-t[3]*t[1]))))*s,Math.atan2(2*(t[0]*t[3]+t[1]*t[2]),1-2*(t[2]*t[2]+t[3]*t[3]))*s]}function k(t,e){for(var r=0,n=0,i=t.length;n<i;++n)r+=t[n]*e[n];return r}e.exports=function(t,e){var r=t.projection;return(e._isScoped?h:e._isClipped?d:p)(t,r)}},{\"../../lib\":799,\"../../registry\":927,\"@plotly/d3\":58}],887:[function(t,e,r){\"use strict\";var n=t(\"../registry\"),i=t(\"./cartesian/constants\").SUBPLOT_PATTERN;r.getSubplotCalcData=function(t,e,r){var i=n.subplotsRegistry[e];if(!i)return[];for(var a=i.attr,o=[],s=0;s<t.length;s++){var l=t[s];l[0].trace[a]===r&&o.push(l)}return o},r.getModuleCalcData=function(t,e){var r,i=[],a=[];if(!(r=\"string\"==typeof e?n.getModule(e).plot:\"function\"==typeof e?e:e.plot))return[i,t];for(var o=0;o<t.length;o++){var s=t[o],l=s[0].trace;!0===l.visible&&0!==l._length&&(l._module.plot===r?i.push(s):a.push(s))}return[i,a]},r.getSubplotData=function(t,e,r){if(!n.subplotsRegistry[e])return[];var a,o,s,l=n.subplotsRegistry[e].attr,c=[];if(\"gl2d\"===e){var u=r.match(i);o=\"x\"+u[1],s=\"y\"+u[2]}for(var f=0;f<t.length;f++)a=t[f],\"gl2d\"===e&&n.traceIs(a,\"gl2d\")?a[l[0]]===o&&a[l[1]]===s&&c.push(a):a[l]===r&&c.push(a);return c}},{\"../registry\":927,\"./cartesian/constants\":856}],888:[function(t,e,r){\"use strict\";var n=t(\"mouse-change\"),i=t(\"mouse-wheel\"),a=t(\"mouse-event-offset\"),o=t(\"../cartesian/constants\"),s=t(\"has-passive-events\");function l(t,e){this.element=t,this.plot=e,this.mouseListener=null,this.wheelListener=null,this.lastInputTime=Date.now(),this.lastPos=[0,0],this.boxEnabled=!1,this.boxInited=!1,this.boxStart=[0,0],this.boxEnd=[0,0],this.dragStart=[0,0]}e.exports=function(t){var e=t.mouseContainer,r=t.glplot,c=new l(e,r);function u(){t.xaxis.autorange=!1,t.yaxis.autorange=!1}function f(e,n,i){var a,s,l=t.calcDataBox(),f=r.viewBox,h=c.lastPos[0],p=c.lastPos[1],d=o.MINDRAG*r.pixelRatio,m=o.MINZOOM*r.pixelRatio;function g(e,r,n){var i=Math.min(r,n),a=Math.max(r,n);i!==a?(l[e]=i,l[e+2]=a,c.dataBox=l,t.setRanges(l)):(t.selectBox.selectBox=[0,0,1,1],t.glplot.setDirty())}switch(n*=r.pixelRatio,i*=r.pixelRatio,i=f[3]-f[1]-i,t.fullLayout.dragmode){case\"zoom\":if(e){var v=n/(f[2]-f[0])*(l[2]-l[0])+l[0],y=i/(f[3]-f[1])*(l[3]-l[1])+l[1];c.boxInited||(c.boxStart[0]=v,c.boxStart[1]=y,c.dragStart[0]=n,c.dragStart[1]=i),c.boxEnd[0]=v,c.boxEnd[1]=y,c.boxInited=!0,c.boxEnabled||c.boxStart[0]===c.boxEnd[0]&&c.boxStart[1]===c.boxEnd[1]||(c.boxEnabled=!0);var x=Math.abs(c.dragStart[0]-n)<m,b=Math.abs(c.dragStart[1]-i)<m;if(!function(){for(var e=t.graphDiv._fullLayout._axisConstraintGroups,r=t.xaxis._id,n=t.yaxis._id,i=0;i<e.length;i++)if(-1!==e[i][r]){if(-1!==e[i][n])return!0;break}return!1}()||x&&b)x&&(c.boxEnd[0]=c.boxStart[0]),b&&(c.boxEnd[1]=c.boxStart[1]);else{a=c.boxEnd[0]-c.boxStart[0],s=c.boxEnd[1]-c.boxStart[1];var _=(l[3]-l[1])/(l[2]-l[0]);Math.abs(a*_)>Math.abs(s)?(c.boxEnd[1]=c.boxStart[1]+Math.abs(a)*_*(s>=0?1:-1),c.boxEnd[1]<l[1]?(c.boxEnd[1]=l[1],c.boxEnd[0]=c.boxStart[0]+(l[1]-c.boxStart[1])/Math.abs(_)):c.boxEnd[1]>l[3]&&(c.boxEnd[1]=l[3],c.boxEnd[0]=c.boxStart[0]+(l[3]-c.boxStart[1])/Math.abs(_))):(c.boxEnd[0]=c.boxStart[0]+Math.abs(s)/_*(a>=0?1:-1),c.boxEnd[0]<l[0]?(c.boxEnd[0]=l[0],c.boxEnd[1]=c.boxStart[1]+(l[0]-c.boxStart[0])*Math.abs(_)):c.boxEnd[0]>l[2]&&(c.boxEnd[0]=l[2],c.boxEnd[1]=c.boxStart[1]+(l[2]-c.boxStart[0])*Math.abs(_)))}}else c.boxEnabled?(a=c.boxStart[0]!==c.boxEnd[0],s=c.boxStart[1]!==c.boxEnd[1],a||s?(a&&(g(0,c.boxStart[0],c.boxEnd[0]),t.xaxis.autorange=!1),s&&(g(1,c.boxStart[1],c.boxEnd[1]),t.yaxis.autorange=!1),t.relayoutCallback()):t.glplot.setDirty(),c.boxEnabled=!1,c.boxInited=!1):c.boxInited&&(c.boxInited=!1);break;case\"pan\":c.boxEnabled=!1,c.boxInited=!1,e?(c.panning||(c.dragStart[0]=n,c.dragStart[1]=i),Math.abs(c.dragStart[0]-n)<d&&(n=c.dragStart[0]),Math.abs(c.dragStart[1]-i)<d&&(i=c.dragStart[1]),a=(h-n)*(l[2]-l[0])/(r.viewBox[2]-r.viewBox[0]),s=(p-i)*(l[3]-l[1])/(r.viewBox[3]-r.viewBox[1]),l[0]+=a,l[2]+=a,l[1]+=s,l[3]+=s,t.setRanges(l),c.panning=!0,c.lastInputTime=Date.now(),u(),t.cameraChanged(),t.handleAnnotations()):c.panning&&(c.panning=!1,t.relayoutCallback())}c.lastPos[0]=n,c.lastPos[1]=i}return c.mouseListener=n(e,f),e.addEventListener(\"touchstart\",(function(t){var r=a(t.changedTouches[0],e);f(0,r[0],r[1]),f(1,r[0],r[1]),t.preventDefault()}),!!s&&{passive:!1}),e.addEventListener(\"touchmove\",(function(t){t.preventDefault();var r=a(t.changedTouches[0],e);f(1,r[0],r[1]),t.preventDefault()}),!!s&&{passive:!1}),e.addEventListener(\"touchend\",(function(t){f(0,c.lastPos[0],c.lastPos[1]),t.preventDefault()}),!!s&&{passive:!1}),c.wheelListener=i(e,(function(e,n){if(!t.scrollZoom)return!1;var i=t.calcDataBox(),a=r.viewBox,o=c.lastPos[0],s=c.lastPos[1],l=Math.exp(5*n/(a[3]-a[1])),f=o/(a[2]-a[0])*(i[2]-i[0])+i[0],h=s/(a[3]-a[1])*(i[3]-i[1])+i[1];return i[0]=(i[0]-f)*l+f,i[2]=(i[2]-f)*l+f,i[1]=(i[1]-h)*l+h,i[3]=(i[3]-h)*l+h,t.setRanges(i),c.lastInputTime=Date.now(),u(),t.cameraChanged(),t.handleAnnotations(),t.relayoutCallback(),!0}),!0),c}},{\"../cartesian/constants\":856,\"has-passive-events\":440,\"mouse-change\":466,\"mouse-event-offset\":467,\"mouse-wheel\":469}],889:[function(t,e,r){\"use strict\";var n=t(\"../cartesian/axes\"),i=t(\"../../lib/str2rgbarray\");function a(t){this.scene=t,this.gl=t.gl,this.pixelRatio=t.pixelRatio,this.screenBox=[0,0,1,1],this.viewBox=[0,0,1,1],this.dataBox=[-1,-1,1,1],this.borderLineEnable=[!1,!1,!1,!1],this.borderLineWidth=[1,1,1,1],this.borderLineColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.ticks=[[],[]],this.tickEnable=[!0,!0,!1,!1],this.tickPad=[15,15,15,15],this.tickAngle=[0,0,0,0],this.tickColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.tickMarkLength=[0,0,0,0],this.tickMarkWidth=[0,0,0,0],this.tickMarkColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.labels=[\"x\",\"y\"],this.labelEnable=[!0,!0,!1,!1],this.labelAngle=[0,Math.PI/2,0,3*Math.PI/2],this.labelPad=[15,15,15,15],this.labelSize=[12,12],this.labelFont=[\"sans-serif\",\"sans-serif\"],this.labelColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.title=\"\",this.titleEnable=!0,this.titleCenter=[0,0,0,0],this.titleAngle=0,this.titleColor=[0,0,0,1],this.titleFont=\"sans-serif\",this.titleSize=18,this.gridLineEnable=[!0,!0],this.gridLineColor=[[0,0,0,.5],[0,0,0,.5]],this.gridLineWidth=[1,1],this.zeroLineEnable=[!0,!0],this.zeroLineWidth=[1,1],this.zeroLineColor=[[0,0,0,1],[0,0,0,1]],this.borderColor=[0,0,0,0],this.backgroundColor=[0,0,0,0],this.static=this.scene.staticPlot}var o=a.prototype,s=[\"xaxis\",\"yaxis\"];o.merge=function(t){var e,r,n,a,o,l,c,u,f,h,p;for(this.titleEnable=!1,this.backgroundColor=i(t.plot_bgcolor),h=0;h<2;++h){var d=(e=s[h]).charAt(0);for(n=(r=t[this.scene[e]._name]).title.text===this.scene.fullLayout._dfltTitle[d]?\"\":r.title.text,p=0;p<=2;p+=2)this.labelEnable[h+p]=!1,this.labels[h+p]=n,this.labelColor[h+p]=i(r.title.font.color),this.labelFont[h+p]=r.title.font.family,this.labelSize[h+p]=r.title.font.size,this.labelPad[h+p]=this.getLabelPad(e,r),this.tickEnable[h+p]=!1,this.tickColor[h+p]=i((r.tickfont||{}).color),this.tickAngle[h+p]=\"auto\"===r.tickangle?0:Math.PI*-r.tickangle/180,this.tickPad[h+p]=this.getTickPad(r),this.tickMarkLength[h+p]=0,this.tickMarkWidth[h+p]=r.tickwidth||0,this.tickMarkColor[h+p]=i(r.tickcolor),this.borderLineEnable[h+p]=!1,this.borderLineColor[h+p]=i(r.linecolor),this.borderLineWidth[h+p]=r.linewidth||0;c=this.hasSharedAxis(r),o=this.hasAxisInDfltPos(e,r)&&!c,l=this.hasAxisInAltrPos(e,r)&&!c,a=r.mirror||!1,u=c?-1!==String(a).indexOf(\"all\"):!!a,f=c?\"allticks\"===a:-1!==String(a).indexOf(\"ticks\"),o?this.labelEnable[h]=!0:l&&(this.labelEnable[h+2]=!0),o?this.tickEnable[h]=r.showticklabels:l&&(this.tickEnable[h+2]=r.showticklabels),(o||u)&&(this.borderLineEnable[h]=r.showline),(l||u)&&(this.borderLineEnable[h+2]=r.showline),(o||f)&&(this.tickMarkLength[h]=this.getTickMarkLength(r)),(l||f)&&(this.tickMarkLength[h+2]=this.getTickMarkLength(r)),this.gridLineEnable[h]=r.showgrid,this.gridLineColor[h]=i(r.gridcolor),this.gridLineWidth[h]=r.gridwidth,this.zeroLineEnable[h]=r.zeroline,this.zeroLineColor[h]=i(r.zerolinecolor),this.zeroLineWidth[h]=r.zerolinewidth}},o.hasSharedAxis=function(t){var e=this.scene,r=e.fullLayout._subplots.gl2d;return 0!==n.findSubplotsWithAxis(r,t).indexOf(e.id)},o.hasAxisInDfltPos=function(t,e){var r=e.side;return\"xaxis\"===t?\"bottom\"===r:\"yaxis\"===t?\"left\"===r:void 0},o.hasAxisInAltrPos=function(t,e){var r=e.side;return\"xaxis\"===t?\"top\"===r:\"yaxis\"===t?\"right\"===r:void 0},o.getLabelPad=function(t,e){var r=e.title.font.size,n=e.showticklabels;return\"xaxis\"===t?\"top\"===e.side?r*(1.5+(n?1:0))-10:r*(1.5+(n?.5:0))-10:\"yaxis\"===t?\"right\"===e.side?10+r*(1.5+(n?1:.5)):10+r*(1.5+(n?.5:0)):void 0},o.getTickPad=function(t){return\"outside\"===t.ticks?10+t.ticklen:15},o.getTickMarkLength=function(t){if(!t.ticks)return 0;var e=t.ticklen;return\"inside\"===t.ticks?-e:e},e.exports=function(t){return new a(t)}},{\"../../lib/str2rgbarray\":823,\"../cartesian/axes\":849}],890:[function(t,e,r){\"use strict\";var n=t(\"../../plot_api/edit_types\").overrideAll,i=t(\"./scene2d\"),a=t(\"../layout_attributes\"),o=t(\"../../constants/xmlns_namespaces\"),s=t(\"../cartesian/constants\"),l=t(\"../cartesian\"),c=t(\"../../components/fx/layout_attributes\"),u=t(\"../get_data\").getSubplotData;r.name=\"gl2d\",r.attr=[\"xaxis\",\"yaxis\"],r.idRoot=[\"x\",\"y\"],r.idRegex=s.idRegex,r.attrRegex=s.attrRegex,r.attributes=t(\"../cartesian/attributes\"),r.supplyLayoutDefaults=function(t,e,r){e._has(\"cartesian\")||l.supplyLayoutDefaults(t,e,r)},r.layoutAttrOverrides=n(l.layoutAttributes,\"plot\",\"from-root\"),r.baseLayoutAttrOverrides=n({plot_bgcolor:a.plot_bgcolor,hoverlabel:c.hoverlabel},\"plot\",\"nested\"),r.plot=function(t){for(var e=t._fullLayout,r=t._fullData,n=e._subplots.gl2d,a=0;a<n.length;a++){var o=n[a],s=e._plots[o],l=u(r,\"gl2d\",o),c=s._scene2d;void 0===c&&(c=new i({id:o,graphDiv:t,container:t.querySelector(\".gl-container\"),staticPlot:t._context.staticPlot,plotGlPixelRatio:t._context.plotGlPixelRatio},e),s._scene2d=c),c.plot(l,t.calcdata,e,t.layout)}},r.clean=function(t,e,r,n){for(var i=n._subplots.gl2d||[],a=0;a<i.length;a++){var o=i[a],s=n._plots[o];if(s._scene2d){var c=u(t,\"gl2d\",o);0===c.length&&(s._scene2d.destroy(),delete n._plots[o])}}l.clean.apply(this,arguments)},r.drawFramework=function(t){t._context.staticPlot||l.drawFramework(t)},r.toSVG=function(t){for(var e=t._fullLayout,r=e._subplots.gl2d,n=0;n<r.length;n++){var i=e._plots[r[n]]._scene2d,a=i.toImage(\"png\");e._glimages.append(\"svg:image\").attr({xmlns:o.svg,\"xlink:href\":a,x:0,y:0,width:\"100%\",height:\"100%\",preserveAspectRatio:\"none\"}),i.destroy()}},r.updateFx=function(t){for(var e=t._fullLayout,r=e._subplots.gl2d,n=0;n<r.length;n++){e._plots[r[n]]._scene2d.updateFx(e.dragmode)}}},{\"../../components/fx/layout_attributes\":703,\"../../constants/xmlns_namespaces\":776,\"../../plot_api/edit_types\":831,\"../cartesian\":863,\"../cartesian/attributes\":847,\"../cartesian/constants\":856,\"../get_data\":887,\"../layout_attributes\":904,\"./scene2d\":891}],891:[function(t,e,r){\"use strict\";var n,i,a=t(\"../../registry\"),o=t(\"../../plots/cartesian/axes\"),s=t(\"../../components/fx\"),l=t(\"gl-plot2d\"),c=t(\"gl-spikes2d\"),u=t(\"gl-select-box\"),f=t(\"webgl-context\"),h=t(\"./convert\"),p=t(\"./camera\"),d=t(\"../../lib/show_no_webgl_msg\"),m=t(\"../cartesian/constraints\"),g=m.enforce,v=m.clean,y=t(\"../cartesian/autorange\").doAutoRange,x=t(\"../../components/dragelement/helpers\"),b=x.drawMode,_=x.selectMode,w=[\"xaxis\",\"yaxis\"],T=t(\"../cartesian/constants\").SUBPLOT_PATTERN;function k(t,e){this.container=t.container,this.graphDiv=t.graphDiv,this.pixelRatio=t.plotGlPixelRatio||window.devicePixelRatio,this.id=t.id,this.staticPlot=!!t.staticPlot,this.scrollZoom=this.graphDiv._context._scrollZoom.cartesian,this.fullData=null,this.updateRefs(e),this.makeFramework(),this.stopped||(this.glplotOptions=h(this),this.glplotOptions.merge(e),this.glplot=l(this.glplotOptions),this.camera=p(this),this.traces={},this.spikes=c(this.glplot),this.selectBox=u(this.glplot,{innerFill:!1,outerFill:!0}),this.lastButtonState=0,this.pickResult=null,this.isMouseOver=!0,this.stopped=!1,this.redraw=this.draw.bind(this),this.redraw())}e.exports=k;var M=k.prototype;M.makeFramework=function(){if(this.staticPlot){if(!(i||(n=document.createElement(\"canvas\"),i=f({canvas:n,preserveDrawingBuffer:!1,premultipliedAlpha:!0,antialias:!0}))))throw new Error(\"Error creating static canvas/context for image server\");this.canvas=n,this.gl=i}else{var t=this.container.querySelector(\".gl-canvas-focus\"),e=f({canvas:t,preserveDrawingBuffer:!0,premultipliedAlpha:!0});if(!e)return d(this),void(this.stopped=!0);this.canvas=t,this.gl=e}var r=this.canvas;r.style.width=\"100%\",r.style.height=\"100%\",r.style.position=\"absolute\",r.style.top=\"0px\",r.style.left=\"0px\",r.style[\"pointer-events\"]=\"none\",this.updateSize(r);var a=this.svgContainer=document.createElementNS(\"http://www.w3.org/2000/svg\",\"svg\");a.style.position=\"absolute\",a.style.top=a.style.left=\"0px\",a.style.width=a.style.height=\"100%\",a.style[\"z-index\"]=20,a.style[\"pointer-events\"]=\"none\";var o=this.mouseContainer=document.createElement(\"div\");o.style.position=\"absolute\",o.style[\"pointer-events\"]=\"auto\",this.pickCanvas=this.container.querySelector(\".gl-canvas-pick\");var s=this.container;s.appendChild(a),s.appendChild(o);var l=this;o.addEventListener(\"mouseout\",(function(){l.isMouseOver=!1,l.unhover()})),o.addEventListener(\"mouseover\",(function(){l.isMouseOver=!0}))},M.toImage=function(t){t||(t=\"png\"),this.stopped=!0,this.staticPlot&&this.container.appendChild(n),this.updateSize(this.canvas);var e=this.glplot.gl,r=e.drawingBufferWidth,i=e.drawingBufferHeight;e.clearColor(1,1,1,0),e.clear(e.COLOR_BUFFER_BIT|e.DEPTH_BUFFER_BIT),this.glplot.setDirty(),this.glplot.draw(),e.bindFramebuffer(e.FRAMEBUFFER,null);var a=new Uint8Array(r*i*4);e.readPixels(0,0,r,i,e.RGBA,e.UNSIGNED_BYTE,a);for(var o=0,s=i-1;o<s;++o,--s)for(var l=0;l<r;++l)for(var c=0;c<4;++c){var u=a[4*(r*o+l)+c];a[4*(r*o+l)+c]=a[4*(r*s+l)+c],a[4*(r*s+l)+c]=u}var f=document.createElement(\"canvas\");f.width=r,f.height=i;var h,p=f.getContext(\"2d\"),d=p.createImageData(r,i);switch(d.data.set(a),p.putImageData(d,0,0),t){case\"jpeg\":h=f.toDataURL(\"image/jpeg\");break;case\"webp\":h=f.toDataURL(\"image/webp\");break;default:h=f.toDataURL(\"image/png\")}return this.staticPlot&&this.container.removeChild(n),h},M.updateSize=function(t){t||(t=this.canvas);var e=this.pixelRatio,r=this.fullLayout,n=r.width,i=r.height,a=0|Math.ceil(e*n),o=0|Math.ceil(e*i);return t.width===a&&t.height===o||(t.width=a,t.height=o),t},M.computeTickMarks=function(){this.xaxis.setScale(),this.yaxis.setScale();for(var t=[o.calcTicks(this.xaxis),o.calcTicks(this.yaxis)],e=0;e<2;++e)for(var r=0;r<t[e].length;++r)t[e][r].text=t[e][r].text+\"\";return t},M.updateRefs=function(t){this.fullLayout=t;var e=this.id.match(T),r=\"xaxis\"+e[1],n=\"yaxis\"+e[2];this.xaxis=this.fullLayout[r],this.yaxis=this.fullLayout[n]},M.relayoutCallback=function(){var t=this.graphDiv,e=this.xaxis,r=this.yaxis,n=t.layout,i={},o=i[e._name+\".range\"]=e.range.slice(),s=i[r._name+\".range\"]=r.range.slice();i[e._name+\".autorange\"]=e.autorange,i[r._name+\".autorange\"]=r.autorange,a.call(\"_storeDirectGUIEdit\",t.layout,t._fullLayout._preGUI,i);var l=n[e._name];l.range=o,l.autorange=e.autorange;var c=n[r._name];c.range=s,c.autorange=r.autorange,i.lastInputTime=this.camera.lastInputTime,t.emit(\"plotly_relayout\",i)},M.cameraChanged=function(){var t=this.camera;this.glplot.setDataBox(this.calcDataBox());var e=this.computeTickMarks();(function(t,e){for(var r=0;r<2;++r){var n=t[r],i=e[r];if(n.length!==i.length)return!0;for(var a=0;a<n.length;++a)if(n[a].x!==i[a].x)return!0}return!1})(e,this.glplotOptions.ticks)&&(this.glplotOptions.ticks=e,this.glplotOptions.dataBox=t.dataBox,this.glplot.update(this.glplotOptions),this.handleAnnotations())},M.handleAnnotations=function(){for(var t=this.graphDiv,e=this.fullLayout.annotations,r=0;r<e.length;r++){var n=e[r];n.xref===this.xaxis._id&&n.yref===this.yaxis._id&&a.getComponentMethod(\"annotations\",\"drawOne\")(t,r)}},M.destroy=function(){if(this.glplot){var t=this.traces;t&&Object.keys(t).map((function(e){t[e].dispose(),delete t[e]})),this.glplot.dispose(),this.container.removeChild(this.svgContainer),this.container.removeChild(this.mouseContainer),this.fullData=null,this.glplot=null,this.stopped=!0,this.camera.mouseListener.enabled=!1,this.mouseContainer.removeEventListener(\"wheel\",this.camera.wheelListener),this.camera=null}},M.plot=function(t,e,r){var n=this.glplot;this.updateRefs(r),this.xaxis.clearCalc(),this.yaxis.clearCalc(),this.updateTraces(t,e),this.updateFx(r.dragmode);var i=r.width,a=r.height;this.updateSize(this.canvas);var o=this.glplotOptions;o.merge(r),o.screenBox=[0,0,i,a];var s={_fullLayout:{_axisConstraintGroups:r._axisConstraintGroups,xaxis:this.xaxis,yaxis:this.yaxis,_size:r._size}};v(s,this.xaxis),v(s,this.yaxis);var l,c,u=r._size,f=this.xaxis.domain,h=this.yaxis.domain;for(o.viewBox=[u.l+f[0]*u.w,u.b+h[0]*u.h,i-u.r-(1-f[1])*u.w,a-u.t-(1-h[1])*u.h],this.mouseContainer.style.width=u.w*(f[1]-f[0])+\"px\",this.mouseContainer.style.height=u.h*(h[1]-h[0])+\"px\",this.mouseContainer.height=u.h*(h[1]-h[0]),this.mouseContainer.style.left=u.l+f[0]*u.w+\"px\",this.mouseContainer.style.top=u.t+(1-h[1])*u.h+\"px\",c=0;c<2;++c)(l=this[w[c]])._length=o.viewBox[c+2]-o.viewBox[c],y(this.graphDiv,l),l.setScale();g(s),o.ticks=this.computeTickMarks(),o.dataBox=this.calcDataBox(),o.merge(r),n.update(o),this.glplot.draw()},M.calcDataBox=function(){var t=this.xaxis,e=this.yaxis,r=t.range,n=e.range,i=t.r2l,a=e.r2l;return[i(r[0]),a(n[0]),i(r[1]),a(n[1])]},M.setRanges=function(t){var e=this.xaxis,r=this.yaxis,n=e.l2r,i=r.l2r;e.range=[n(t[0]),n(t[2])],r.range=[i(t[1]),i(t[3])]},M.updateTraces=function(t,e){var r,n,i,a=Object.keys(this.traces);this.fullData=t;t:for(r=0;r<a.length;r++){var o=a[r],s=this.traces[o];for(n=0;n<t.length;n++)if((i=t[n]).uid===o&&i.type===s.type)continue t;s.dispose(),delete this.traces[o]}for(r=0;r<t.length;r++){i=t[r];var l=e[r],c=this.traces[i.uid];c?c.update(i,l):(c=i._module.plot(this,i,l),this.traces[i.uid]=c)}this.glplot.objects.sort((function(t,e){return t._trace.index-e._trace.index}))},M.updateFx=function(t){_(t)||b(t)?(this.pickCanvas.style[\"pointer-events\"]=\"none\",this.mouseContainer.style[\"pointer-events\"]=\"none\"):(this.pickCanvas.style[\"pointer-events\"]=\"auto\",this.mouseContainer.style[\"pointer-events\"]=\"auto\"),this.mouseContainer.style.cursor=\"pan\"===t?\"move\":\"zoom\"===t?\"crosshair\":null},M.emitPointAction=function(t,e){for(var r,n=t.trace.uid,i=t.pointIndex,a=0;a<this.fullData.length;a++)this.fullData[a].uid===n&&(r=this.fullData[a]);var o={x:t.traceCoord[0],y:t.traceCoord[1],curveNumber:r.index,pointNumber:i,data:r._input,fullData:this.fullData,xaxis:this.xaxis,yaxis:this.yaxis};s.appendArrayPointValue(o,r,i),this.graphDiv.emit(e,{points:[o]})},M.draw=function(){if(!this.stopped){requestAnimationFrame(this.redraw);var t=this.glplot,e=this.camera,r=e.mouseListener,n=1===this.lastButtonState&&0===r.buttons,i=this.fullLayout;this.lastButtonState=r.buttons,this.cameraChanged();var a,o=r.x*t.pixelRatio,l=this.canvas.height-t.pixelRatio*r.y;if(e.boxEnabled&&\"zoom\"===i.dragmode){this.selectBox.enabled=!0;for(var c=this.selectBox.selectBox=[Math.min(e.boxStart[0],e.boxEnd[0]),Math.min(e.boxStart[1],e.boxEnd[1]),Math.max(e.boxStart[0],e.boxEnd[0]),Math.max(e.boxStart[1],e.boxEnd[1])],u=0;u<2;u++)e.boxStart[u]===e.boxEnd[u]&&(c[u]=t.dataBox[u],c[u+2]=t.dataBox[u+2]);t.setDirty()}else if(!e.panning&&this.isMouseOver){this.selectBox.enabled=!1;var f=i._size,h=this.xaxis.domain,p=this.yaxis.domain,d=(a=t.pick(o/t.pixelRatio+f.l+h[0]*f.w,l/t.pixelRatio-(f.t+(1-p[1])*f.h)))&&a.object._trace.handlePick(a);if(d&&n&&this.emitPointAction(d,\"plotly_click\"),a&&\"skip\"!==a.object._trace.hoverinfo&&i.hovermode&&d&&(!this.lastPickResult||this.lastPickResult.traceUid!==d.trace.uid||this.lastPickResult.dataCoord[0]!==d.dataCoord[0]||this.lastPickResult.dataCoord[1]!==d.dataCoord[1])){var m=d;this.lastPickResult={traceUid:d.trace?d.trace.uid:null,dataCoord:d.dataCoord.slice()},this.spikes.update({center:a.dataCoord}),m.screenCoord=[((t.viewBox[2]-t.viewBox[0])*(a.dataCoord[0]-t.dataBox[0])/(t.dataBox[2]-t.dataBox[0])+t.viewBox[0])/t.pixelRatio,(this.canvas.height-(t.viewBox[3]-t.viewBox[1])*(a.dataCoord[1]-t.dataBox[1])/(t.dataBox[3]-t.dataBox[1])-t.viewBox[1])/t.pixelRatio],this.emitPointAction(d,\"plotly_hover\");var g=this.fullData[m.trace.index]||{},v=m.pointIndex,y=s.castHoverinfo(g,i,v);if(y&&\"all\"!==y){var x=y.split(\"+\");-1===x.indexOf(\"x\")&&(m.traceCoord[0]=void 0),-1===x.indexOf(\"y\")&&(m.traceCoord[1]=void 0),-1===x.indexOf(\"z\")&&(m.traceCoord[2]=void 0),-1===x.indexOf(\"text\")&&(m.textLabel=void 0),-1===x.indexOf(\"name\")&&(m.name=void 0)}s.loneHover({x:m.screenCoord[0],y:m.screenCoord[1],xLabel:this.hoverFormatter(\"xaxis\",m.traceCoord[0]),yLabel:this.hoverFormatter(\"yaxis\",m.traceCoord[1]),zLabel:m.traceCoord[2],text:m.textLabel,name:m.name,color:s.castHoverOption(g,v,\"bgcolor\")||m.color,borderColor:s.castHoverOption(g,v,\"bordercolor\"),fontFamily:s.castHoverOption(g,v,\"font.family\"),fontSize:s.castHoverOption(g,v,\"font.size\"),fontColor:s.castHoverOption(g,v,\"font.color\"),nameLength:s.castHoverOption(g,v,\"namelength\"),textAlign:s.castHoverOption(g,v,\"align\")},{container:this.svgContainer,gd:this.graphDiv})}}a||this.unhover(),t.draw()}},M.unhover=function(){this.lastPickResult&&(this.spikes.update({}),this.lastPickResult=null,this.graphDiv.emit(\"plotly_unhover\"),s.loneUnhover(this.svgContainer))},M.hoverFormatter=function(t,e){if(void 0!==e){var r=this[t];return o.tickText(r,r.c2l(e),\"hover\").text}}},{\"../../components/dragelement/helpers\":680,\"../../components/fx\":702,\"../../lib/show_no_webgl_msg\":821,\"../../plots/cartesian/axes\":849,\"../../registry\":927,\"../cartesian/autorange\":848,\"../cartesian/constants\":856,\"../cartesian/constraints\":857,\"./camera\":888,\"./convert\":889,\"gl-plot2d\":318,\"gl-select-box\":333,\"gl-spikes2d\":342,\"webgl-context\":625}],892:[function(t,e,r){\"use strict\";var n=t(\"../../plot_api/edit_types\").overrideAll,i=t(\"../../components/fx/layout_attributes\"),a=t(\"./scene\"),o=t(\"../get_data\").getSubplotData,s=t(\"../../lib\"),l=t(\"../../constants/xmlns_namespaces\");r.name=\"gl3d\",r.attr=\"scene\",r.idRoot=\"scene\",r.idRegex=r.attrRegex=s.counterRegex(\"scene\"),r.attributes=t(\"./layout/attributes\"),r.layoutAttributes=t(\"./layout/layout_attributes\"),r.baseLayoutAttrOverrides=n({hoverlabel:i.hoverlabel},\"plot\",\"nested\"),r.supplyLayoutDefaults=t(\"./layout/defaults\"),r.plot=function(t){for(var e=t._fullLayout,r=t._fullData,n=e._subplots.gl3d,i=0;i<n.length;i++){var s=n[i],l=o(r,\"gl3d\",s),c=e[s],u=c.camera,f=c._scene;f||(f=new a({id:s,graphDiv:t,container:t.querySelector(\".gl-container\"),staticPlot:t._context.staticPlot,plotGlPixelRatio:t._context.plotGlPixelRatio,camera:u},e),c._scene=f),f.viewInitial||(f.viewInitial={up:{x:u.up.x,y:u.up.y,z:u.up.z},eye:{x:u.eye.x,y:u.eye.y,z:u.eye.z},center:{x:u.center.x,y:u.center.y,z:u.center.z}}),f.plot(l,e,t.layout)}},r.clean=function(t,e,r,n){for(var i=n._subplots.gl3d||[],a=0;a<i.length;a++){var o=i[a];!e[o]&&n[o]._scene&&(n[o]._scene.destroy(),n._infolayer&&n._infolayer.selectAll(\".annotation-\"+o).remove())}},r.toSVG=function(t){for(var e=t._fullLayout,r=e._subplots.gl3d,n=e._size,i=0;i<r.length;i++){var a=e[r[i]],o=a.domain,s=a._scene,c=s.toImage(\"png\");e._glimages.append(\"svg:image\").attr({xmlns:l.svg,\"xlink:href\":c,x:n.l+n.w*o.x[0],y:n.t+n.h*(1-o.y[1]),width:n.w*(o.x[1]-o.x[0]),height:n.h*(o.y[1]-o.y[0]),preserveAspectRatio:\"none\"}),s.destroy()}},r.cleanId=function(t){if(t.match(/^scene[0-9]*$/)){var e=t.substr(5);return\"1\"===e&&(e=\"\"),\"scene\"+e}},r.updateFx=function(t){for(var e=t._fullLayout,r=e._subplots.gl3d,n=0;n<r.length;n++){e[r[n]]._scene.updateFx(e.dragmode,e.hovermode)}}},{\"../../components/fx/layout_attributes\":703,\"../../constants/xmlns_namespaces\":776,\"../../lib\":799,\"../../plot_api/edit_types\":831,\"../get_data\":887,\"./layout/attributes\":893,\"./layout/defaults\":897,\"./layout/layout_attributes\":898,\"./scene\":902}],893:[function(t,e,r){\"use strict\";e.exports={scene:{valType:\"subplotid\",dflt:\"scene\",editType:\"calc+clearAxisTypes\"}}},{}],894:[function(t,e,r){\"use strict\";var n=t(\"../../../components/color\"),i=t(\"../../cartesian/layout_attributes\"),a=t(\"../../../lib/extend\").extendFlat,o=t(\"../../../plot_api/edit_types\").overrideAll;e.exports=o({visible:i.visible,showspikes:{valType:\"boolean\",dflt:!0},spikesides:{valType:\"boolean\",dflt:!0},spikethickness:{valType:\"number\",min:0,dflt:2},spikecolor:{valType:\"color\",dflt:n.defaultLine},showbackground:{valType:\"boolean\",dflt:!1},backgroundcolor:{valType:\"color\",dflt:\"rgba(204, 204, 204, 0.5)\"},showaxeslabels:{valType:\"boolean\",dflt:!0},color:i.color,categoryorder:i.categoryorder,categoryarray:i.categoryarray,title:{text:i.title.text,font:i.title.font},type:a({},i.type,{values:[\"-\",\"linear\",\"log\",\"date\",\"category\"]}),autotypenumbers:i.autotypenumbers,autorange:i.autorange,rangemode:i.rangemode,range:a({},i.range,{items:[{valType:\"any\",editType:\"plot\",impliedEdits:{\"^autorange\":!1}},{valType:\"any\",editType:\"plot\",impliedEdits:{\"^autorange\":!1}}],anim:!1}),tickmode:i.tickmode,nticks:i.nticks,tick0:i.tick0,dtick:i.dtick,tickvals:i.tickvals,ticktext:i.ticktext,ticks:i.ticks,mirror:i.mirror,ticklen:i.ticklen,tickwidth:i.tickwidth,tickcolor:i.tickcolor,showticklabels:i.showticklabels,tickfont:i.tickfont,tickangle:i.tickangle,tickprefix:i.tickprefix,showtickprefix:i.showtickprefix,ticksuffix:i.ticksuffix,showticksuffix:i.showticksuffix,showexponent:i.showexponent,exponentformat:i.exponentformat,minexponent:i.minexponent,separatethousands:i.separatethousands,tickformat:i.tickformat,tickformatstops:i.tickformatstops,hoverformat:i.hoverformat,showline:i.showline,linecolor:i.linecolor,linewidth:i.linewidth,showgrid:i.showgrid,gridcolor:a({},i.gridcolor,{dflt:\"rgb(204, 204, 204)\"}),gridwidth:i.gridwidth,zeroline:i.zeroline,zerolinecolor:i.zerolinecolor,zerolinewidth:i.zerolinewidth,_deprecated:{title:i._deprecated.title,titlefont:i._deprecated.titlefont}},\"plot\",\"from-root\")},{\"../../../components/color\":662,\"../../../lib/extend\":789,\"../../../plot_api/edit_types\":831,\"../../cartesian/layout_attributes\":864}],895:[function(t,e,r){\"use strict\";var n=t(\"tinycolor2\").mix,i=t(\"../../../lib\"),a=t(\"../../../plot_api/plot_template\"),o=t(\"./axis_attributes\"),s=t(\"../../cartesian/type_defaults\"),l=t(\"../../cartesian/axis_defaults\"),c=[\"xaxis\",\"yaxis\",\"zaxis\"];e.exports=function(t,e,r){var u,f;function h(t,e){return i.coerce(u,f,o,t,e)}for(var p=0;p<c.length;p++){var d=c[p];u=t[d]||{},(f=a.newContainer(e,d))._id=d[0]+r.scene,f._name=d,s(u,f,h,r),l(u,f,h,{font:r.font,letter:d[0],data:r.data,showGrid:!0,noTickson:!0,noTicklabelmode:!0,noTicklabelposition:!0,noTicklabeloverflow:!0,bgColor:r.bgColor,calendar:r.calendar},r.fullLayout),h(\"gridcolor\",n(f.color,r.bgColor,13600/187).toRgbString()),h(\"title.text\",d[0]),f.setScale=i.noop,h(\"showspikes\")&&(h(\"spikesides\"),h(\"spikethickness\"),h(\"spikecolor\",f.color)),h(\"showaxeslabels\"),h(\"showbackground\")&&h(\"backgroundcolor\")}}},{\"../../../lib\":799,\"../../../plot_api/plot_template\":838,\"../../cartesian/axis_defaults\":851,\"../../cartesian/type_defaults\":875,\"./axis_attributes\":894,tinycolor2:594}],896:[function(t,e,r){\"use strict\";var n=t(\"../../../lib/str2rgbarray\"),i=t(\"../../../lib\"),a=[\"xaxis\",\"yaxis\",\"zaxis\"];function o(){this.bounds=[[-10,-10,-10],[10,10,10]],this.ticks=[[],[],[]],this.tickEnable=[!0,!0,!0],this.tickFont=[\"sans-serif\",\"sans-serif\",\"sans-serif\"],this.tickSize=[12,12,12],this.tickAngle=[0,0,0],this.tickColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.tickPad=[18,18,18],this.labels=[\"x\",\"y\",\"z\"],this.labelEnable=[!0,!0,!0],this.labelFont=[\"Open Sans\",\"Open Sans\",\"Open Sans\"],this.labelSize=[20,20,20],this.labelColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.labelPad=[30,30,30],this.lineEnable=[!0,!0,!0],this.lineMirror=[!1,!1,!1],this.lineWidth=[1,1,1],this.lineColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.lineTickEnable=[!0,!0,!0],this.lineTickMirror=[!1,!1,!1],this.lineTickLength=[10,10,10],this.lineTickWidth=[1,1,1],this.lineTickColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.gridEnable=[!0,!0,!0],this.gridWidth=[1,1,1],this.gridColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.zeroEnable=[!0,!0,!0],this.zeroLineColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.zeroLineWidth=[2,2,2],this.backgroundEnable=[!0,!0,!0],this.backgroundColor=[[.8,.8,.8,.5],[.8,.8,.8,.5],[.8,.8,.8,.5]],this._defaultTickPad=this.tickPad.slice(),this._defaultLabelPad=this.labelPad.slice(),this._defaultLineTickLength=this.lineTickLength.slice()}o.prototype.merge=function(t,e){for(var r=0;r<3;++r){var o=e[a[r]];o.visible?(this.labels[r]=t._meta?i.templateString(o.title.text,t._meta):o.title.text,\"font\"in o.title&&(o.title.font.color&&(this.labelColor[r]=n(o.title.font.color)),o.title.font.family&&(this.labelFont[r]=o.title.font.family),o.title.font.size&&(this.labelSize[r]=o.title.font.size)),\"showline\"in o&&(this.lineEnable[r]=o.showline),\"linecolor\"in o&&(this.lineColor[r]=n(o.linecolor)),\"linewidth\"in o&&(this.lineWidth[r]=o.linewidth),\"showgrid\"in o&&(this.gridEnable[r]=o.showgrid),\"gridcolor\"in o&&(this.gridColor[r]=n(o.gridcolor)),\"gridwidth\"in o&&(this.gridWidth[r]=o.gridwidth),\"log\"===o.type?this.zeroEnable[r]=!1:\"zeroline\"in o&&(this.zeroEnable[r]=o.zeroline),\"zerolinecolor\"in o&&(this.zeroLineColor[r]=n(o.zerolinecolor)),\"zerolinewidth\"in o&&(this.zeroLineWidth[r]=o.zerolinewidth),\"ticks\"in o&&o.ticks?this.lineTickEnable[r]=!0:this.lineTickEnable[r]=!1,\"ticklen\"in o&&(this.lineTickLength[r]=this._defaultLineTickLength[r]=o.ticklen),\"tickcolor\"in o&&(this.lineTickColor[r]=n(o.tickcolor)),\"tickwidth\"in o&&(this.lineTickWidth[r]=o.tickwidth),\"tickangle\"in o&&(this.tickAngle[r]=\"auto\"===o.tickangle?-3600:Math.PI*-o.tickangle/180),\"showticklabels\"in o&&(this.tickEnable[r]=o.showticklabels),\"tickfont\"in o&&(o.tickfont.color&&(this.tickColor[r]=n(o.tickfont.color)),o.tickfont.family&&(this.tickFont[r]=o.tickfont.family),o.tickfont.size&&(this.tickSize[r]=o.tickfont.size)),\"mirror\"in o?-1!==[\"ticks\",\"all\",\"allticks\"].indexOf(o.mirror)?(this.lineTickMirror[r]=!0,this.lineMirror[r]=!0):!0===o.mirror?(this.lineTickMirror[r]=!1,this.lineMirror[r]=!0):(this.lineTickMirror[r]=!1,this.lineMirror[r]=!1):this.lineMirror[r]=!1,\"showbackground\"in o&&!1!==o.showbackground?(this.backgroundEnable[r]=!0,this.backgroundColor[r]=n(o.backgroundcolor)):this.backgroundEnable[r]=!1):(this.tickEnable[r]=!1,this.labelEnable[r]=!1,this.lineEnable[r]=!1,this.lineTickEnable[r]=!1,this.gridEnable[r]=!1,this.zeroEnable[r]=!1,this.backgroundEnable[r]=!1)}},e.exports=function(t,e){var r=new o;return r.merge(t,e),r}},{\"../../../lib\":799,\"../../../lib/str2rgbarray\":823}],897:[function(t,e,r){\"use strict\";var n=t(\"../../../lib\"),i=t(\"../../../components/color\"),a=t(\"../../../registry\"),o=t(\"../../subplot_defaults\"),s=t(\"./axis_defaults\"),l=t(\"./layout_attributes\"),c=t(\"../../get_data\").getSubplotData;function u(t,e,r,n){for(var o=r(\"bgcolor\"),l=i.combine(o,n.paper_bgcolor),u=[\"up\",\"center\",\"eye\"],f=0;f<u.length;f++)r(\"camera.\"+u[f]+\".x\"),r(\"camera.\"+u[f]+\".y\"),r(\"camera.\"+u[f]+\".z\");r(\"camera.projection.type\");var h=!!r(\"aspectratio.x\")&&!!r(\"aspectratio.y\")&&!!r(\"aspectratio.z\"),p=r(\"aspectmode\",h?\"manual\":\"auto\");h||(t.aspectratio=e.aspectratio={x:1,y:1,z:1},\"manual\"===p&&(e.aspectmode=\"auto\"),t.aspectmode=e.aspectmode);var d=c(n.fullData,\"gl3d\",n.id);s(t,e,{font:n.font,scene:n.id,data:d,bgColor:l,calendar:n.calendar,autotypenumbersDflt:n.autotypenumbersDflt,fullLayout:n.fullLayout}),a.getComponentMethod(\"annotations3d\",\"handleDefaults\")(t,e,n);var m=n.getDfltFromLayout(\"dragmode\");if(!1!==m&&!m)if(m=\"orbit\",t.camera&&t.camera.up){var g=t.camera.up.x,v=t.camera.up.y,y=t.camera.up.z;0!==y&&(g&&v&&y?y/Math.sqrt(g*g+v*v+y*y)>.999&&(m=\"turntable\"):m=\"turntable\")}else m=\"turntable\";r(\"dragmode\",m),r(\"hovermode\",n.getDfltFromLayout(\"hovermode\"))}e.exports=function(t,e,r){var i=e._basePlotModules.length>1;o(t,e,r,{type:\"gl3d\",attributes:l,handleDefaults:u,fullLayout:e,font:e.font,fullData:r,getDfltFromLayout:function(e){if(!i)return n.validate(t[e],l[e])?t[e]:void 0},autotypenumbersDflt:e.autotypenumbers,paper_bgcolor:e.paper_bgcolor,calendar:e.calendar})}},{\"../../../components/color\":662,\"../../../lib\":799,\"../../../registry\":927,\"../../get_data\":887,\"../../subplot_defaults\":921,\"./axis_defaults\":895,\"./layout_attributes\":898}],898:[function(t,e,r){\"use strict\";var n=t(\"./axis_attributes\"),i=t(\"../../domain\").attributes,a=t(\"../../../lib/extend\").extendFlat,o=t(\"../../../lib\").counterRegex;function s(t,e,r){return{x:{valType:\"number\",dflt:t,editType:\"camera\"},y:{valType:\"number\",dflt:e,editType:\"camera\"},z:{valType:\"number\",dflt:r,editType:\"camera\"},editType:\"camera\"}}e.exports={_arrayAttrRegexps:[o(\"scene\",\".annotations\",!0)],bgcolor:{valType:\"color\",dflt:\"rgba(0,0,0,0)\",editType:\"plot\"},camera:{up:a(s(0,0,1),{}),center:a(s(0,0,0),{}),eye:a(s(1.25,1.25,1.25),{}),projection:{type:{valType:\"enumerated\",values:[\"perspective\",\"orthographic\"],dflt:\"perspective\",editType:\"calc\"},editType:\"calc\"},editType:\"camera\"},domain:i({name:\"scene\",editType:\"plot\"}),aspectmode:{valType:\"enumerated\",values:[\"auto\",\"cube\",\"data\",\"manual\"],dflt:\"auto\",editType:\"plot\",impliedEdits:{\"aspectratio.x\":void 0,\"aspectratio.y\":void 0,\"aspectratio.z\":void 0}},aspectratio:{x:{valType:\"number\",min:0,editType:\"plot\",impliedEdits:{\"^aspectmode\":\"manual\"}},y:{valType:\"number\",min:0,editType:\"plot\",impliedEdits:{\"^aspectmode\":\"manual\"}},z:{valType:\"number\",min:0,editType:\"plot\",impliedEdits:{\"^aspectmode\":\"manual\"}},editType:\"plot\",impliedEdits:{aspectmode:\"manual\"}},xaxis:n,yaxis:n,zaxis:n,dragmode:{valType:\"enumerated\",values:[\"orbit\",\"turntable\",\"zoom\",\"pan\",!1],editType:\"plot\"},hovermode:{valType:\"enumerated\",values:[\"closest\",!1],dflt:\"closest\",editType:\"modebar\"},uirevision:{valType:\"any\",editType:\"none\"},editType:\"plot\",_deprecated:{cameraposition:{valType:\"info_array\",editType:\"camera\"}}}},{\"../../../lib\":799,\"../../../lib/extend\":789,\"../../domain\":877,\"./axis_attributes\":894}],899:[function(t,e,r){\"use strict\";var n=t(\"../../../lib/str2rgbarray\"),i=[\"xaxis\",\"yaxis\",\"zaxis\"];function a(){this.enabled=[!0,!0,!0],this.colors=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.drawSides=[!0,!0,!0],this.lineWidth=[1,1,1]}a.prototype.merge=function(t){for(var e=0;e<3;++e){var r=t[i[e]];r.visible?(this.enabled[e]=r.showspikes,this.colors[e]=n(r.spikecolor),this.drawSides[e]=r.spikesides,this.lineWidth[e]=r.spikethickness):(this.enabled[e]=!1,this.drawSides[e]=!1)}},e.exports=function(t){var e=new a;return e.merge(t),e}},{\"../../../lib/str2rgbarray\":823}],900:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=t.axesOptions,r=t.glplot.axesPixels,s=t.fullSceneLayout,l=[[],[],[]],c=0;c<3;++c){var u=s[a[c]];if(u._length=(r[c].hi-r[c].lo)*r[c].pixelsPerDataUnit/t.dataScale[c],Math.abs(u._length)===1/0||isNaN(u._length))l[c]=[];else{u._input_range=u.range.slice(),u.range[0]=r[c].lo/t.dataScale[c],u.range[1]=r[c].hi/t.dataScale[c],u._m=1/(t.dataScale[c]*r[c].pixelsPerDataUnit),u.range[0]===u.range[1]&&(u.range[0]-=1,u.range[1]+=1);var f=u.tickmode;if(\"auto\"===u.tickmode){u.tickmode=\"linear\";var h=u.nticks||i.constrain(u._length/40,4,9);n.autoTicks(u,Math.abs(u.range[1]-u.range[0])/h)}for(var p=n.calcTicks(u,{msUTC:!0}),d=0;d<p.length;++d)p[d].x=p[d].x*t.dataScale[c],\"date\"===u.type&&(p[d].text=p[d].text.replace(/\\<br\\>/g,\" \"));l[c]=p,u.tickmode=f}}e.ticks=l;for(c=0;c<3;++c){o[c]=.5*(t.glplot.bounds[0][c]+t.glplot.bounds[1][c]);for(d=0;d<2;++d)e.bounds[d][c]=t.glplot.bounds[d][c]}t.contourLevels=function(t){for(var e=new Array(3),r=0;r<3;++r){for(var n=t[r],i=new Array(n.length),a=0;a<n.length;++a)i[a]=n[a].x;e[r]=i}return e}(l)};var n=t(\"../../cartesian/axes\"),i=t(\"../../../lib\"),a=[\"xaxis\",\"yaxis\",\"zaxis\"],o=[0,0,0]},{\"../../../lib\":799,\"../../cartesian/axes\":849}],901:[function(t,e,r){\"use strict\";function n(t,e){var r,n,i=[0,0,0,0];for(r=0;r<4;++r)for(n=0;n<4;++n)i[n]+=t[4*r+n]*e[r];return i}e.exports=function(t,e){return n(t.projection,n(t.view,n(t.model,[e[0],e[1],e[2],1])))}},{}],902:[function(t,e,r){\"use strict\";var n,i,a=t(\"gl-plot3d\"),o=a.createCamera,s=a.createScene,l=t(\"webgl-context\"),c=t(\"has-passive-events\"),u=t(\"../../registry\"),f=t(\"../../lib\"),h=f.preserveDrawingBuffer(),p=t(\"../../plots/cartesian/axes\"),d=t(\"../../components/fx\"),m=t(\"../../lib/str2rgbarray\"),g=t(\"../../lib/show_no_webgl_msg\"),v=t(\"./project\"),y=t(\"./layout/convert\"),x=t(\"./layout/spikes\"),b=t(\"./layout/tick_marks\");function _(t,e){var r=document.createElement(\"div\"),n=t.container;this.graphDiv=t.graphDiv;var i=document.createElementNS(\"http://www.w3.org/2000/svg\",\"svg\");i.style.position=\"absolute\",i.style.top=i.style.left=\"0px\",i.style.width=i.style.height=\"100%\",i.style[\"z-index\"]=20,i.style[\"pointer-events\"]=\"none\",r.appendChild(i),this.svgContainer=i,r.id=t.id,r.style.position=\"absolute\",r.style.top=r.style.left=\"0px\",r.style.width=r.style.height=\"100%\",n.appendChild(r),this.fullLayout=e,this.id=t.id||\"scene\",this.fullSceneLayout=e[this.id],this.plotArgs=[[],{},{}],this.axesOptions=y(e,e[this.id]),this.spikeOptions=x(e[this.id]),this.container=r,this.staticMode=!!t.staticPlot,this.pixelRatio=this.pixelRatio||t.plotGlPixelRatio||2,this.dataScale=[1,1,1],this.contourLevels=[[],[],[]],this.convertAnnotations=u.getComponentMethod(\"annotations3d\",\"convert\"),this.drawAnnotations=u.getComponentMethod(\"annotations3d\",\"draw\"),this.initializeGLPlot()}var w=_.prototype;w.prepareOptions=function(){var t={canvas:this.canvas,gl:this.gl,glOptions:{preserveDrawingBuffer:h,premultipliedAlpha:!0,antialias:!0},container:this.container,axes:this.axesOptions,spikes:this.spikeOptions,pickRadius:10,snapToData:!0,autoScale:!0,autoBounds:!1,cameraObject:this.camera,pixelRatio:this.pixelRatio};if(this.staticMode){if(!(i||(n=document.createElement(\"canvas\"),i=l({canvas:n,preserveDrawingBuffer:!0,premultipliedAlpha:!0,antialias:!0}))))throw new Error(\"error creating static canvas/context for image server\");t.gl=i,t.canvas=n}return t};var T=!0;w.tryCreatePlot=function(){var t=this.prepareOptions(),e=!0;try{this.glplot=s(t)}catch(r){if(this.staticMode||!T||h)e=!1;else{f.warn([\"webgl setup failed possibly due to\",\"false preserveDrawingBuffer config.\",\"The mobile/tablet device may not be detected by is-mobile module.\",\"Enabling preserveDrawingBuffer in second attempt to create webgl scene...\"].join(\" \"));try{h=t.glOptions.preserveDrawingBuffer=!0,this.glplot=s(t)}catch(r){h=t.glOptions.preserveDrawingBuffer=!1,e=!1}}}return T=!1,e},w.initializeGLCamera=function(){var t=this.fullSceneLayout.camera,e=\"orthographic\"===t.projection.type;this.camera=o(this.container,{center:[t.center.x,t.center.y,t.center.z],eye:[t.eye.x,t.eye.y,t.eye.z],up:[t.up.x,t.up.y,t.up.z],_ortho:e,zoomMin:.01,zoomMax:100,mode:\"orbit\"})},w.initializeGLPlot=function(){var t=this;if(t.initializeGLCamera(),!t.tryCreatePlot())return g(t);t.traces={},t.make4thDimension();var e=t.graphDiv,r=e.layout,n=function(){var e={};return t.isCameraChanged(r)&&(e[t.id+\".camera\"]=t.getCamera()),t.isAspectChanged(r)&&(e[t.id+\".aspectratio\"]=t.glplot.getAspectratio(),\"manual\"!==r[t.id].aspectmode&&(t.fullSceneLayout.aspectmode=r[t.id].aspectmode=e[t.id+\".aspectmode\"]=\"manual\")),e},i=function(t){if(!1!==t.fullSceneLayout.dragmode){var e=n();t.saveLayout(r),t.graphDiv.emit(\"plotly_relayout\",e)}};return t.glplot.canvas&&(t.glplot.canvas.addEventListener(\"mouseup\",(function(){i(t)})),t.glplot.canvas.addEventListener(\"wheel\",(function(r){if(e._context._scrollZoom.gl3d){if(t.camera._ortho){var n=r.deltaX>r.deltaY?1.1:1/1.1,a=t.glplot.getAspectratio();t.glplot.setAspectratio({x:n*a.x,y:n*a.y,z:n*a.z})}i(t)}}),!!c&&{passive:!1}),t.glplot.canvas.addEventListener(\"mousemove\",(function(){if(!1!==t.fullSceneLayout.dragmode&&0!==t.camera.mouseListener.buttons){var e=n();t.graphDiv.emit(\"plotly_relayouting\",e)}})),t.staticMode||t.glplot.canvas.addEventListener(\"webglcontextlost\",(function(r){e&&e.emit&&e.emit(\"plotly_webglcontextlost\",{event:r,layer:t.id})}),!1)),t.glplot.oncontextloss=function(){t.recoverContext()},t.glplot.onrender=function(){t.render()},!0},w.render=function(){var t,e=this,r=e.graphDiv,n=e.svgContainer,i=e.container.getBoundingClientRect();r._fullLayout._calcInverseTransform(r);var a=r._fullLayout._invScaleX,o=r._fullLayout._invScaleY,s=i.width*a,l=i.height*o;n.setAttributeNS(null,\"viewBox\",\"0 0 \"+s+\" \"+l),n.setAttributeNS(null,\"width\",s),n.setAttributeNS(null,\"height\",l),b(e),e.glplot.axes.update(e.axesOptions);for(var c,u=Object.keys(e.traces),h=null,m=e.glplot.selection,g=0;g<u.length;++g)\"skip\"!==(t=e.traces[u[g]]).data.hoverinfo&&t.handlePick(m)&&(h=t),t.setContourLevels&&t.setContourLevels();function y(t,r,n){var i=e.fullSceneLayout[t+\"axis\"];return\"log\"!==i.type&&(r=i.d2l(r)),p.hoverLabelText(i,r,n)}if(null!==h){var x=v(e.glplot.cameraParams,m.dataCoordinate);t=h.data;var _,w=r._fullData[t.index],T=m.index,k={xLabel:y(\"x\",m.traceCoordinate[0],t.xhoverformat),yLabel:y(\"y\",m.traceCoordinate[1],t.yhoverformat),zLabel:y(\"z\",m.traceCoordinate[2],t.zhoverformat)},M=d.castHoverinfo(w,e.fullLayout,T),A=(M||\"\").split(\"+\"),S=M&&\"all\"===M;w.hovertemplate||S||(-1===A.indexOf(\"x\")&&(k.xLabel=void 0),-1===A.indexOf(\"y\")&&(k.yLabel=void 0),-1===A.indexOf(\"z\")&&(k.zLabel=void 0),-1===A.indexOf(\"text\")&&(m.textLabel=void 0),-1===A.indexOf(\"name\")&&(h.name=void 0));var E=[];\"cone\"===t.type||\"streamtube\"===t.type?(k.uLabel=y(\"x\",m.traceCoordinate[3],t.uhoverformat),(S||-1!==A.indexOf(\"u\"))&&E.push(\"u: \"+k.uLabel),k.vLabel=y(\"y\",m.traceCoordinate[4],t.vhoverformat),(S||-1!==A.indexOf(\"v\"))&&E.push(\"v: \"+k.vLabel),k.wLabel=y(\"z\",m.traceCoordinate[5],t.whoverformat),(S||-1!==A.indexOf(\"w\"))&&E.push(\"w: \"+k.wLabel),k.normLabel=m.traceCoordinate[6].toPrecision(3),(S||-1!==A.indexOf(\"norm\"))&&E.push(\"norm: \"+k.normLabel),\"streamtube\"===t.type&&(k.divergenceLabel=m.traceCoordinate[7].toPrecision(3),(S||-1!==A.indexOf(\"divergence\"))&&E.push(\"divergence: \"+k.divergenceLabel)),m.textLabel&&E.push(m.textLabel),_=E.join(\"<br>\")):\"isosurface\"===t.type||\"volume\"===t.type?(k.valueLabel=p.hoverLabelText(e._mockAxis,e._mockAxis.d2l(m.traceCoordinate[3]),t.valuehoverformat),E.push(\"value: \"+k.valueLabel),m.textLabel&&E.push(m.textLabel),_=E.join(\"<br>\")):_=m.textLabel;var L={x:m.traceCoordinate[0],y:m.traceCoordinate[1],z:m.traceCoordinate[2],data:w._input,fullData:w,curveNumber:w.index,pointNumber:T};d.appendArrayPointValue(L,w,T),t._module.eventData&&(L=w._module.eventData(L,m,w,{},T));var C={points:[L]};e.fullSceneLayout.hovermode&&d.loneHover({trace:w,x:(.5+.5*x[0]/x[3])*s,y:(.5-.5*x[1]/x[3])*l,xLabel:k.xLabel,yLabel:k.yLabel,zLabel:k.zLabel,text:_,name:h.name,color:d.castHoverOption(w,T,\"bgcolor\")||h.color,borderColor:d.castHoverOption(w,T,\"bordercolor\"),fontFamily:d.castHoverOption(w,T,\"font.family\"),fontSize:d.castHoverOption(w,T,\"font.size\"),fontColor:d.castHoverOption(w,T,\"font.color\"),nameLength:d.castHoverOption(w,T,\"namelength\"),textAlign:d.castHoverOption(w,T,\"align\"),hovertemplate:f.castOption(w,T,\"hovertemplate\"),hovertemplateLabels:f.extendFlat({},L,k),eventData:[L]},{container:n,gd:r}),m.buttons&&m.distance<5?r.emit(\"plotly_click\",C):r.emit(\"plotly_hover\",C),c=C}else d.loneUnhover(n),r.emit(\"plotly_unhover\",c);e.drawAnnotations(e)},w.recoverContext=function(){var t=this;t.glplot.dispose();var e=function(){t.glplot.gl.isContextLost()?requestAnimationFrame(e):t.initializeGLPlot()?t.plot.apply(t,t.plotArgs):f.error(\"Catastrophic and unrecoverable WebGL error. Context lost.\")};requestAnimationFrame(e)};var k=[\"xaxis\",\"yaxis\",\"zaxis\"];function M(t,e,r){for(var n=t.fullSceneLayout,i=0;i<3;i++){var a=k[i],o=a.charAt(0),s=n[a],l=e[o],c=e[o+\"calendar\"],u=e[\"_\"+o+\"length\"];if(f.isArrayOrTypedArray(l))for(var h,p=0;p<(u||l.length);p++)if(f.isArrayOrTypedArray(l[p]))for(var d=0;d<l[p].length;++d)h=s.d2l(l[p][d],0,c),!isNaN(h)&&isFinite(h)&&(r[0][i]=Math.min(r[0][i],h),r[1][i]=Math.max(r[1][i],h));else h=s.d2l(l[p],0,c),!isNaN(h)&&isFinite(h)&&(r[0][i]=Math.min(r[0][i],h),r[1][i]=Math.max(r[1][i],h));else r[0][i]=Math.min(r[0][i],0),r[1][i]=Math.max(r[1][i],u-1)}}w.plot=function(t,e,r){if(this.plotArgs=[t,e,r],!this.glplot.contextLost){var n,i,a,o,s,l,c=e[this.id],u=r[this.id];this.fullLayout=e,this.fullSceneLayout=c,this.axesOptions.merge(e,c),this.spikeOptions.merge(c),this.setViewport(c),this.updateFx(c.dragmode,c.hovermode),this.camera.enableWheel=this.graphDiv._context._scrollZoom.gl3d,this.glplot.setClearColor(m(c.bgcolor)),this.setConvert(s),t?Array.isArray(t)||(t=[t]):t=[];var f=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]];for(a=0;a<t.length;++a)!0===(n=t[a]).visible&&0!==n._length&&M(this,n,f);!function(t,e){for(var r=t.fullSceneLayout,n=r.annotations||[],i=0;i<3;i++)for(var a=k[i],o=a.charAt(0),s=r[a],l=0;l<n.length;l++){var c=n[l];if(c.visible){var u=s.r2l(c[o]);!isNaN(u)&&isFinite(u)&&(e[0][i]=Math.min(e[0][i],u),e[1][i]=Math.max(e[1][i],u))}}}(this,f);var h=[1,1,1];for(o=0;o<3;++o)f[1][o]===f[0][o]?h[o]=1:h[o]=1/(f[1][o]-f[0][o]);for(this.dataScale=h,this.convertAnnotations(this),a=0;a<t.length;++a)!0===(n=t[a]).visible&&0!==n._length&&((i=this.traces[n.uid])?i.data.type===n.type?i.update(n):(i.dispose(),i=n._module.plot(this,n),this.traces[n.uid]=i):(i=n._module.plot(this,n),this.traces[n.uid]=i),i.name=n.name);var p=Object.keys(this.traces);t:for(a=0;a<p.length;++a){for(o=0;o<t.length;++o)if(t[o].uid===p[a]&&!0===t[o].visible&&0!==t[o]._length)continue t;(i=this.traces[p[a]]).dispose(),delete this.traces[p[a]]}this.glplot.objects.sort((function(t,e){return t._trace.data.index-e._trace.data.index}));var d,g=[[0,0,0],[0,0,0]],v=[],y={};for(a=0;a<3;++a){if((l=(s=c[k[a]]).type)in y?(y[l].acc*=h[a],y[l].count+=1):y[l]={acc:h[a],count:1},s.autorange){g[0][a]=1/0,g[1][a]=-1/0;var x=this.glplot.objects,b=this.fullSceneLayout.annotations||[],_=s._name.charAt(0);for(o=0;o<x.length;o++){var w=x[o],T=w.bounds,A=w._trace.data._pad||0;\"ErrorBars\"===w.constructor.name&&s._lowerLogErrorBound?g[0][a]=Math.min(g[0][a],s._lowerLogErrorBound):g[0][a]=Math.min(g[0][a],T[0][a]/h[a]-A),g[1][a]=Math.max(g[1][a],T[1][a]/h[a]+A)}for(o=0;o<b.length;o++){var S=b[o];if(S.visible){var E=s.r2l(S[_]);g[0][a]=Math.min(g[0][a],E),g[1][a]=Math.max(g[1][a],E)}}if(\"rangemode\"in s&&\"tozero\"===s.rangemode&&(g[0][a]=Math.min(g[0][a],0),g[1][a]=Math.max(g[1][a],0)),g[0][a]>g[1][a])g[0][a]=-1,g[1][a]=1;else{var L=g[1][a]-g[0][a];g[0][a]-=L/32,g[1][a]+=L/32}if(\"reversed\"===s.autorange){var C=g[0][a];g[0][a]=g[1][a],g[1][a]=C}}else{var P=s.range;g[0][a]=s.r2l(P[0]),g[1][a]=s.r2l(P[1])}g[0][a]===g[1][a]&&(g[0][a]-=1,g[1][a]+=1),v[a]=g[1][a]-g[0][a],this.glplot.setBounds(a,{min:g[0][a]*h[a],max:g[1][a]*h[a]})}var I=c.aspectmode;if(\"cube\"===I)d=[1,1,1];else if(\"manual\"===I){var O=c.aspectratio;d=[O.x,O.y,O.z]}else{if(\"auto\"!==I&&\"data\"!==I)throw new Error(\"scene.js aspectRatio was not one of the enumerated types\");var z=[1,1,1];for(a=0;a<3;++a){var D=y[l=(s=c[k[a]]).type];z[a]=Math.pow(D.acc,1/D.count)/h[a]}d=\"data\"===I||Math.max.apply(null,z)/Math.min.apply(null,z)<=4?z:[1,1,1]}c.aspectratio.x=u.aspectratio.x=d[0],c.aspectratio.y=u.aspectratio.y=d[1],c.aspectratio.z=u.aspectratio.z=d[2],this.glplot.setAspectratio(c.aspectratio),this.viewInitial.aspectratio||(this.viewInitial.aspectratio={x:c.aspectratio.x,y:c.aspectratio.y,z:c.aspectratio.z}),this.viewInitial.aspectmode||(this.viewInitial.aspectmode=c.aspectmode);var R=c.domain||null,F=e._size||null;if(R&&F){var B=this.container.style;B.position=\"absolute\",B.left=F.l+R.x[0]*F.w+\"px\",B.top=F.t+(1-R.y[1])*F.h+\"px\",B.width=F.w*(R.x[1]-R.x[0])+\"px\",B.height=F.h*(R.y[1]-R.y[0])+\"px\"}this.glplot.redraw()}},w.destroy=function(){this.glplot&&(this.camera.mouseListener.enabled=!1,this.container.removeEventListener(\"wheel\",this.camera.wheelListener),this.camera=null,this.glplot.dispose(),this.container.parentNode.removeChild(this.container),this.glplot=null)},w.getCamera=function(){var t;return this.camera.view.recalcMatrix(this.camera.view.lastT()),{up:{x:(t=this.camera).up[0],y:t.up[1],z:t.up[2]},center:{x:t.center[0],y:t.center[1],z:t.center[2]},eye:{x:t.eye[0],y:t.eye[1],z:t.eye[2]},projection:{type:!0===t._ortho?\"orthographic\":\"perspective\"}}},w.setViewport=function(t){var e,r=t.camera;this.camera.lookAt.apply(this,[[(e=r).eye.x,e.eye.y,e.eye.z],[e.center.x,e.center.y,e.center.z],[e.up.x,e.up.y,e.up.z]]),this.glplot.setAspectratio(t.aspectratio),\"orthographic\"===r.projection.type!==this.camera._ortho&&(this.glplot.redraw(),this.glplot.clearRGBA(),this.glplot.dispose(),this.initializeGLPlot())},w.isCameraChanged=function(t){var e=this.getCamera(),r=f.nestedProperty(t,this.id+\".camera\").get();function n(t,e,r,n){var i=[\"up\",\"center\",\"eye\"],a=[\"x\",\"y\",\"z\"];return e[i[r]]&&t[i[r]][a[n]]===e[i[r]][a[n]]}var i=!1;if(void 0===r)i=!0;else{for(var a=0;a<3;a++)for(var o=0;o<3;o++)if(!n(e,r,a,o)){i=!0;break}(!r.projection||e.projection&&e.projection.type!==r.projection.type)&&(i=!0)}return i},w.isAspectChanged=function(t){var e=this.glplot.getAspectratio(),r=f.nestedProperty(t,this.id+\".aspectratio\").get();return void 0===r||r.x!==e.x||r.y!==e.y||r.z!==e.z},w.saveLayout=function(t){var e,r,n,i,a,o,s=this.fullLayout,l=this.isCameraChanged(t),c=this.isAspectChanged(t),h=l||c;if(h){var p={};if(l&&(e=this.getCamera(),n=(r=f.nestedProperty(t,this.id+\".camera\")).get(),p[this.id+\".camera\"]=n),c&&(i=this.glplot.getAspectratio(),o=(a=f.nestedProperty(t,this.id+\".aspectratio\")).get(),p[this.id+\".aspectratio\"]=o),u.call(\"_storeDirectGUIEdit\",t,s._preGUI,p),l)r.set(e),f.nestedProperty(s,this.id+\".camera\").set(e);if(c)a.set(i),f.nestedProperty(s,this.id+\".aspectratio\").set(i),this.glplot.redraw()}return h},w.updateFx=function(t,e){var r=this.camera;if(r)if(\"orbit\"===t)r.mode=\"orbit\",r.keyBindingMode=\"rotate\";else if(\"turntable\"===t){r.up=[0,0,1],r.mode=\"turntable\",r.keyBindingMode=\"rotate\";var n=this.graphDiv,i=n._fullLayout,a=this.fullSceneLayout.camera,o=a.up.x,s=a.up.y,l=a.up.z;if(l/Math.sqrt(o*o+s*s+l*l)<.999){var c=this.id+\".camera.up\",h={x:0,y:0,z:1},p={};p[c]=h;var d=n.layout;u.call(\"_storeDirectGUIEdit\",d,i._preGUI,p),a.up=h,f.nestedProperty(d,c).set(h)}}else r.keyBindingMode=t;this.fullSceneLayout.hovermode=e},w.toImage=function(t){t||(t=\"png\"),this.staticMode&&this.container.appendChild(n),this.glplot.redraw();var e=this.glplot.gl,r=e.drawingBufferWidth,i=e.drawingBufferHeight;e.bindFramebuffer(e.FRAMEBUFFER,null);var a=new Uint8Array(r*i*4);e.readPixels(0,0,r,i,e.RGBA,e.UNSIGNED_BYTE,a),function(t,e,r){for(var n=0,i=r-1;n<i;++n,--i)for(var a=0;a<e;++a)for(var o=0;o<4;++o){var s=4*(e*n+a)+o,l=4*(e*i+a)+o,c=t[s];t[s]=t[l],t[l]=c}}(a,r,i),function(t,e,r){for(var n=0;n<r;++n)for(var i=0;i<e;++i){var a=4*(e*n+i),o=t[a+3];if(o>0)for(var s=255/o,l=0;l<3;++l)t[a+l]=Math.min(s*t[a+l],255)}}(a,r,i);var o=document.createElement(\"canvas\");o.width=r,o.height=i;var s,l=o.getContext(\"2d\"),c=l.createImageData(r,i);switch(c.data.set(a),l.putImageData(c,0,0),t){case\"jpeg\":s=o.toDataURL(\"image/jpeg\");break;case\"webp\":s=o.toDataURL(\"image/webp\");break;default:s=o.toDataURL(\"image/png\")}return this.staticMode&&this.container.removeChild(n),s},w.setConvert=function(){for(var t=0;t<3;t++){var e=this.fullSceneLayout[k[t]];p.setConvert(e,this.fullLayout),e.setScale=f.noop}},w.make4thDimension=function(){var t=this.graphDiv._fullLayout;this._mockAxis={type:\"linear\",showexponent:\"all\",exponentformat:\"B\"},p.setConvert(this._mockAxis,t)},e.exports=_},{\"../../components/fx\":702,\"../../lib\":799,\"../../lib/show_no_webgl_msg\":821,\"../../lib/str2rgbarray\":823,\"../../plots/cartesian/axes\":849,\"../../registry\":927,\"./layout/convert\":896,\"./layout/spikes\":899,\"./layout/tick_marks\":900,\"./project\":901,\"gl-plot3d\":322,\"has-passive-events\":440,\"webgl-context\":625}],903:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n){n=n||t.length;for(var i=new Array(n),a=0;a<n;a++)i[a]=[t[a],e[a],r[a]];return i}},{}],904:[function(t,e,r){\"use strict\";var n=t(\"./font_attributes\"),i=t(\"./animation_attributes\"),a=t(\"../components/color/attributes\"),o=t(\"../components/shapes/draw_newshape/attributes\"),s=t(\"./pad_attributes\"),l=t(\"../lib/extend\").extendFlat,c=n({editType:\"calc\"});c.family.dflt='\"Open Sans\", verdana, arial, sans-serif',c.size.dflt=12,c.color.dflt=a.defaultLine,e.exports={font:c,title:{text:{valType:\"string\",editType:\"layoutstyle\"},font:n({editType:\"layoutstyle\"}),xref:{valType:\"enumerated\",dflt:\"container\",values:[\"container\",\"paper\"],editType:\"layoutstyle\"},yref:{valType:\"enumerated\",dflt:\"container\",values:[\"container\",\"paper\"],editType:\"layoutstyle\"},x:{valType:\"number\",min:0,max:1,dflt:.5,editType:\"layoutstyle\"},y:{valType:\"number\",min:0,max:1,dflt:\"auto\",editType:\"layoutstyle\"},xanchor:{valType:\"enumerated\",dflt:\"auto\",values:[\"auto\",\"left\",\"center\",\"right\"],editType:\"layoutstyle\"},yanchor:{valType:\"enumerated\",dflt:\"auto\",values:[\"auto\",\"top\",\"middle\",\"bottom\"],editType:\"layoutstyle\"},pad:l(s({editType:\"layoutstyle\"}),{}),editType:\"layoutstyle\"},uniformtext:{mode:{valType:\"enumerated\",values:[!1,\"hide\",\"show\"],dflt:!1,editType:\"plot\"},minsize:{valType:\"number\",min:0,dflt:0,editType:\"plot\"},editType:\"plot\"},autosize:{valType:\"boolean\",dflt:!1,editType:\"none\"},width:{valType:\"number\",min:10,dflt:700,editType:\"plot\"},height:{valType:\"number\",min:10,dflt:450,editType:\"plot\"},margin:{l:{valType:\"number\",min:0,dflt:80,editType:\"plot\"},r:{valType:\"number\",min:0,dflt:80,editType:\"plot\"},t:{valType:\"number\",min:0,dflt:100,editType:\"plot\"},b:{valType:\"number\",min:0,dflt:80,editType:\"plot\"},pad:{valType:\"number\",min:0,dflt:0,editType:\"plot\"},autoexpand:{valType:\"boolean\",dflt:!0,editType:\"plot\"},editType:\"plot\"},computed:{valType:\"any\",editType:\"none\"},paper_bgcolor:{valType:\"color\",dflt:a.background,editType:\"plot\"},plot_bgcolor:{valType:\"color\",dflt:a.background,editType:\"layoutstyle\"},autotypenumbers:{valType:\"enumerated\",values:[\"convert types\",\"strict\"],dflt:\"convert types\",editType:\"calc\"},separators:{valType:\"string\",editType:\"plot\"},hidesources:{valType:\"boolean\",dflt:!1,editType:\"plot\"},showlegend:{valType:\"boolean\",editType:\"legend\"},colorway:{valType:\"colorlist\",dflt:a.defaults,editType:\"calc\"},datarevision:{valType:\"any\",editType:\"calc\"},uirevision:{valType:\"any\",editType:\"none\"},editrevision:{valType:\"any\",editType:\"none\"},selectionrevision:{valType:\"any\",editType:\"none\"},template:{valType:\"any\",editType:\"calc\"},newshape:o.newshape,activeshape:o.activeshape,meta:{valType:\"any\",arrayOk:!0,editType:\"plot\"},transition:l({},i.transition,{editType:\"none\"}),_deprecated:{title:{valType:\"string\",editType:\"layoutstyle\"},titlefont:n({editType:\"layoutstyle\"})}}},{\"../components/color/attributes\":661,\"../components/shapes/draw_newshape/attributes\":747,\"../lib/extend\":789,\"./animation_attributes\":843,\"./font_attributes\":878,\"./pad_attributes\":912}],905:[function(t,e,r){\"use strict\";var n='\\xa9 <a target=\"_blank\" href=\"https://www.openstreetmap.org/copyright\">OpenStreetMap</a> contributors',i=['\\xa9 <a target=\"_blank\" href=\"https://carto.com/\">Carto</a>',n].join(\" \"),a=['Map tiles by <a target=\"_blank\" href=\"https://stamen.com\">Stamen Design</a>','under <a target=\"_blank\" href=\"https://creativecommons.org/licenses/by/3.0\">CC BY 3.0</a>',\"|\",'Data by <a target=\"_blank\" href=\"https://openstreetmap.org\">OpenStreetMap</a> contributors','under <a target=\"_blank\" href=\"https://www.openstreetmap.org/copyright\">ODbL</a>'].join(\" \"),o={\"open-street-map\":{id:\"osm\",version:8,sources:{\"plotly-osm-tiles\":{type:\"raster\",attribution:n,tiles:[\"https://a.tile.openstreetmap.org/{z}/{x}/{y}.png\",\"https://b.tile.openstreetmap.org/{z}/{x}/{y}.png\"],tileSize:256}},layers:[{id:\"plotly-osm-tiles\",type:\"raster\",source:\"plotly-osm-tiles\",minzoom:0,maxzoom:22}]},\"white-bg\":{id:\"white-bg\",version:8,sources:{},layers:[{id:\"white-bg\",type:\"background\",paint:{\"background-color\":\"#FFFFFF\"},minzoom:0,maxzoom:22}]},\"carto-positron\":{id:\"carto-positron\",version:8,sources:{\"plotly-carto-positron\":{type:\"raster\",attribution:i,tiles:[\"https://cartodb-basemaps-c.global.ssl.fastly.net/light_all/{z}/{x}/{y}.png\"],tileSize:256}},layers:[{id:\"plotly-carto-positron\",type:\"raster\",source:\"plotly-carto-positron\",minzoom:0,maxzoom:22}]},\"carto-darkmatter\":{id:\"carto-darkmatter\",version:8,sources:{\"plotly-carto-darkmatter\":{type:\"raster\",attribution:i,tiles:[\"https://cartodb-basemaps-c.global.ssl.fastly.net/dark_all/{z}/{x}/{y}.png\"],tileSize:256}},layers:[{id:\"plotly-carto-darkmatter\",type:\"raster\",source:\"plotly-carto-darkmatter\",minzoom:0,maxzoom:22}]},\"stamen-terrain\":{id:\"stamen-terrain\",version:8,sources:{\"plotly-stamen-terrain\":{type:\"raster\",attribution:a,tiles:[\"https://stamen-tiles.a.ssl.fastly.net/terrain/{z}/{x}/{y}.png\"],tileSize:256}},layers:[{id:\"plotly-stamen-terrain\",type:\"raster\",source:\"plotly-stamen-terrain\",minzoom:0,maxzoom:22}]},\"stamen-toner\":{id:\"stamen-toner\",version:8,sources:{\"plotly-stamen-toner\":{type:\"raster\",attribution:a,tiles:[\"https://stamen-tiles.a.ssl.fastly.net/toner/{z}/{x}/{y}.png\"],tileSize:256}},layers:[{id:\"plotly-stamen-toner\",type:\"raster\",source:\"plotly-stamen-toner\",minzoom:0,maxzoom:22}]},\"stamen-watercolor\":{id:\"stamen-watercolor\",version:8,sources:{\"plotly-stamen-watercolor\":{type:\"raster\",attribution:['Map tiles by <a target=\"_blank\" href=\"https://stamen.com\">Stamen Design</a>','under <a target=\"_blank\" href=\"https://creativecommons.org/licenses/by/3.0\">CC BY 3.0</a>',\"|\",'Data by <a target=\"_blank\" href=\"https://openstreetmap.org\">OpenStreetMap</a> contributors','under <a target=\"_blank\" href=\"https://creativecommons.org/licenses/by-sa/3.0\">CC BY SA</a>'].join(\" \"),tiles:[\"https://stamen-tiles.a.ssl.fastly.net/watercolor/{z}/{x}/{y}.png\"],tileSize:256}},layers:[{id:\"plotly-stamen-watercolor\",type:\"raster\",source:\"plotly-stamen-watercolor\",minzoom:0,maxzoom:22}]}},s=Object.keys(o);e.exports={requiredVersion:\"1.10.1\",styleUrlPrefix:\"mapbox://styles/mapbox/\",styleUrlSuffix:\"v9\",styleValuesMapbox:[\"basic\",\"streets\",\"outdoors\",\"light\",\"dark\",\"satellite\",\"satellite-streets\"],styleValueDflt:\"basic\",stylesNonMapbox:o,styleValuesNonMapbox:s,traceLayerPrefix:\"plotly-trace-layer-\",layoutLayerPrefix:\"plotly-layout-layer-\",wrongVersionErrorMsg:[\"Your custom plotly.js bundle is not using the correct mapbox-gl version\",\"Please install mapbox-gl@1.10.1.\"].join(\"\\n\"),noAccessTokenErrorMsg:[\"Missing Mapbox access token.\",\"Mapbox trace type require a Mapbox access token to be registered.\",\"For example:\",\"  Plotly.newPlot(gd, data, layout, { mapboxAccessToken: 'my-access-token' });\",\"More info here: https://www.mapbox.com/help/define-access-token/\"].join(\"\\n\"),missingStyleErrorMsg:[\"No valid mapbox style found, please set `mapbox.style` to one of:\",s.join(\", \"),\"or register a Mapbox access token to use a Mapbox-served style.\"].join(\"\\n\"),multipleTokensErrorMsg:[\"Set multiple mapbox access token across different mapbox subplot,\",\"using first token found as mapbox-gl does not allow multipleaccess tokens on the same page.\"].join(\"\\n\"),mapOnErrorMsg:\"Mapbox error.\",mapboxLogo:{path0:\"m 10.5,1.24 c -5.11,0 -9.25,4.15 -9.25,9.25 0,5.1 4.15,9.25 9.25,9.25 5.1,0 9.25,-4.15 9.25,-9.25 0,-5.11 -4.14,-9.25 -9.25,-9.25 z m 4.39,11.53 c -1.93,1.93 -4.78,2.31 -6.7,2.31 -0.7,0 -1.41,-0.05 -2.1,-0.16 0,0 -1.02,-5.64 2.14,-8.81 0.83,-0.83 1.95,-1.28 3.13,-1.28 1.27,0 2.49,0.51 3.39,1.42 1.84,1.84 1.89,4.75 0.14,6.52 z\",path1:\"M 10.5,-0.01 C 4.7,-0.01 0,4.7 0,10.49 c 0,5.79 4.7,10.5 10.5,10.5 5.8,0 10.5,-4.7 10.5,-10.5 C 20.99,4.7 16.3,-0.01 10.5,-0.01 Z m 0,19.75 c -5.11,0 -9.25,-4.15 -9.25,-9.25 0,-5.1 4.14,-9.26 9.25,-9.26 5.11,0 9.25,4.15 9.25,9.25 0,5.13 -4.14,9.26 -9.25,9.26 z\",path2:\"M 14.74,6.25 C 12.9,4.41 9.98,4.35 8.23,6.1 5.07,9.27 6.09,14.91 6.09,14.91 c 0,0 5.64,1.02 8.81,-2.14 C 16.64,11 16.59,8.09 14.74,6.25 Z m -2.27,4.09 -0.91,1.87 -0.9,-1.87 -1.86,-0.91 1.86,-0.9 0.9,-1.87 0.91,1.87 1.86,0.9 z\",polygon:\"11.56,12.21 10.66,10.34 8.8,9.43 10.66,8.53 11.56,6.66 12.47,8.53 14.33,9.43 12.47,10.34\"},styleRules:{map:\"overflow:hidden;position:relative;\",\"missing-css\":\"display:none;\",canary:\"background-color:salmon;\",\"ctrl-bottom-left\":\"position: absolute; pointer-events: none; z-index: 2; bottom: 0; left: 0;\",\"ctrl-bottom-right\":\"position: absolute; pointer-events: none; z-index: 2; right: 0; bottom: 0;\",ctrl:\"clear: both; pointer-events: auto; transform: translate(0, 0);\",\"ctrl-attrib.mapboxgl-compact .mapboxgl-ctrl-attrib-inner\":\"display: none;\",\"ctrl-attrib.mapboxgl-compact:hover .mapboxgl-ctrl-attrib-inner\":\"display: block; margin-top:2px\",\"ctrl-attrib.mapboxgl-compact:hover\":\"padding: 2px 24px 2px 4px; visibility: visible; margin-top: 6px;\",\"ctrl-attrib.mapboxgl-compact::after\":'content: \"\"; cursor: pointer; position: absolute; background-image: url(\\'data:image/svg+xml;charset=utf-8,%3Csvg viewBox=\"0 0 20 20\" xmlns=\"http://www.w3.org/2000/svg\"%3E %3Cpath fill=\"%23333333\" fill-rule=\"evenodd\" d=\"M4,10a6,6 0 1,0 12,0a6,6 0 1,0 -12,0 M9,7a1,1 0 1,0 2,0a1,1 0 1,0 -2,0 M9,10a1,1 0 1,1 2,0l0,3a1,1 0 1,1 -2,0\"/%3E %3C/svg%3E\\'); background-color: rgba(255, 255, 255, 0.5); width: 24px; height: 24px; box-sizing: border-box; border-radius: 12px;',\"ctrl-attrib.mapboxgl-compact\":\"min-height: 20px; padding: 0; margin: 10px; position: relative; background-color: #fff; border-radius: 3px 12px 12px 3px;\",\"ctrl-bottom-right > .mapboxgl-ctrl-attrib.mapboxgl-compact::after\":\"bottom: 0; right: 0\",\"ctrl-bottom-left > .mapboxgl-ctrl-attrib.mapboxgl-compact::after\":\"bottom: 0; left: 0\",\"ctrl-bottom-left .mapboxgl-ctrl\":\"margin: 0 0 10px 10px; float: left;\",\"ctrl-bottom-right .mapboxgl-ctrl\":\"margin: 0 10px 10px 0; float: right;\",\"ctrl-attrib\":\"color: rgba(0, 0, 0, 0.75); text-decoration: none; font-size: 12px\",\"ctrl-attrib a\":\"color: rgba(0, 0, 0, 0.75); text-decoration: none; font-size: 12px\",\"ctrl-attrib a:hover\":\"color: inherit; text-decoration: underline;\",\"ctrl-attrib .mapbox-improve-map\":\"font-weight: bold; margin-left: 2px;\",\"attrib-empty\":\"display: none;\",\"ctrl-logo\":'display:block; width: 21px; height: 21px; background-image: url(\\'data:image/svg+xml;charset=utf-8,%3C?xml version=\"1.0\" encoding=\"utf-8\"?%3E %3Csvg version=\"1.1\" id=\"Layer_1\" xmlns=\"http://www.w3.org/2000/svg\" xmlns:xlink=\"http://www.w3.org/1999/xlink\" x=\"0px\" y=\"0px\" viewBox=\"0 0 21 21\" style=\"enable-background:new 0 0 21 21;\" xml:space=\"preserve\"%3E%3Cg transform=\"translate(0,0.01)\"%3E%3Cpath d=\"m 10.5,1.24 c -5.11,0 -9.25,4.15 -9.25,9.25 0,5.1 4.15,9.25 9.25,9.25 5.1,0 9.25,-4.15 9.25,-9.25 0,-5.11 -4.14,-9.25 -9.25,-9.25 z m 4.39,11.53 c -1.93,1.93 -4.78,2.31 -6.7,2.31 -0.7,0 -1.41,-0.05 -2.1,-0.16 0,0 -1.02,-5.64 2.14,-8.81 0.83,-0.83 1.95,-1.28 3.13,-1.28 1.27,0 2.49,0.51 3.39,1.42 1.84,1.84 1.89,4.75 0.14,6.52 z\" style=\"opacity:0.9;fill:%23ffffff;enable-background:new\" class=\"st0\"/%3E%3Cpath d=\"M 10.5,-0.01 C 4.7,-0.01 0,4.7 0,10.49 c 0,5.79 4.7,10.5 10.5,10.5 5.8,0 10.5,-4.7 10.5,-10.5 C 20.99,4.7 16.3,-0.01 10.5,-0.01 Z m 0,19.75 c -5.11,0 -9.25,-4.15 -9.25,-9.25 0,-5.1 4.14,-9.26 9.25,-9.26 5.11,0 9.25,4.15 9.25,9.25 0,5.13 -4.14,9.26 -9.25,9.26 z\" style=\"opacity:0.35;enable-background:new\" class=\"st1\"/%3E%3Cpath d=\"M 14.74,6.25 C 12.9,4.41 9.98,4.35 8.23,6.1 5.07,9.27 6.09,14.91 6.09,14.91 c 0,0 5.64,1.02 8.81,-2.14 C 16.64,11 16.59,8.09 14.74,6.25 Z m -2.27,4.09 -0.91,1.87 -0.9,-1.87 -1.86,-0.91 1.86,-0.9 0.9,-1.87 0.91,1.87 1.86,0.9 z\" style=\"opacity:0.35;enable-background:new\" class=\"st1\"/%3E%3Cpolygon points=\"11.56,12.21 10.66,10.34 8.8,9.43 10.66,8.53 11.56,6.66 12.47,8.53 14.33,9.43 12.47,10.34 \" style=\"opacity:0.9;fill:%23ffffff;enable-background:new\" class=\"st0\"/%3E%3C/g%3E%3C/svg%3E\\')'}}},{}],906:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e){var r=t.split(\" \"),i=r[0],a=r[1],o=n.isArrayOrTypedArray(e)?n.mean(e):e,s=.5+o/100,l=1.5+o/100,c=[\"\",\"\"],u=[0,0];switch(i){case\"top\":c[0]=\"top\",u[1]=-l;break;case\"bottom\":c[0]=\"bottom\",u[1]=l}switch(a){case\"left\":c[1]=\"right\",u[0]=-s;break;case\"right\":c[1]=\"left\",u[0]=s}return{anchor:c[0]&&c[1]?c.join(\"-\"):c[0]?c[0]:c[1]?c[1]:\"center\",offset:u}}},{\"../../lib\":799}],907:[function(t,e,r){\"use strict\";var n=t(\"mapbox-gl/dist/mapbox-gl-unminified\"),i=t(\"../../lib\"),a=i.strTranslate,o=i.strScale,s=t(\"../../plots/get_data\").getSubplotCalcData,l=t(\"../../constants/xmlns_namespaces\"),c=t(\"@plotly/d3\"),u=t(\"../../components/drawing\"),f=t(\"../../lib/svg_text_utils\"),h=t(\"./mapbox\"),p=r.constants=t(\"./constants\");function d(t){return\"string\"==typeof t&&(-1!==p.styleValuesMapbox.indexOf(t)||0===t.indexOf(\"mapbox://\"))}r.name=\"mapbox\",r.attr=\"subplot\",r.idRoot=\"mapbox\",r.idRegex=r.attrRegex=i.counterRegex(\"mapbox\"),r.attributes={subplot:{valType:\"subplotid\",dflt:\"mapbox\",editType:\"calc\"}},r.layoutAttributes=t(\"./layout_attributes\"),r.supplyLayoutDefaults=t(\"./layout_defaults\"),r.plot=function(t){var e=t._fullLayout,r=t.calcdata,a=e._subplots.mapbox;if(n.version!==p.requiredVersion)throw new Error(p.wrongVersionErrorMsg);var o=function(t,e){var r=t._fullLayout;if(\"\"===t._context.mapboxAccessToken)return\"\";for(var n=[],a=[],o=!1,s=!1,l=0;l<e.length;l++){var c=r[e[l]],u=c.accesstoken;d(c.style)&&(u?i.pushUnique(n,u):(d(c._input.style)&&(i.error(\"Uses Mapbox map style, but did not set an access token.\"),o=!0),s=!0)),u&&i.pushUnique(a,u)}if(s){var f=o?p.noAccessTokenErrorMsg:p.missingStyleErrorMsg;throw i.error(f),new Error(f)}return n.length?(n.length>1&&i.warn(p.multipleTokensErrorMsg),n[0]):(a.length&&i.log([\"Listed mapbox access token(s)\",a.join(\",\"),\"but did not use a Mapbox map style, ignoring token(s).\"].join(\" \")),\"\")}(t,a);n.accessToken=o;for(var l=0;l<a.length;l++){var c=a[l],u=s(r,\"mapbox\",c),f=e[c],m=f._subplot;m||(m=new h(t,c),e[c]._subplot=m),m.viewInitial||(m.viewInitial={center:i.extendFlat({},f.center),zoom:f.zoom,bearing:f.bearing,pitch:f.pitch}),m.plot(u,e,t._promises)}},r.clean=function(t,e,r,n){for(var i=n._subplots.mapbox||[],a=0;a<i.length;a++){var o=i[a];!e[o]&&n[o]._subplot&&n[o]._subplot.destroy()}},r.toSVG=function(t){for(var e=t._fullLayout,r=e._subplots.mapbox,n=e._size,i=0;i<r.length;i++){var s=e[r[i]],h=s.domain,d=s._subplot.toImage(\"png\");e._glimages.append(\"svg:image\").attr({xmlns:l.svg,\"xlink:href\":d,x:n.l+n.w*h.x[0],y:n.t+n.h*(1-h.y[1]),width:n.w*(h.x[1]-h.x[0]),height:n.h*(h.y[1]-h.y[0]),preserveAspectRatio:\"none\"});var m=c.select(s._subplot.div);if(!(null===m.select(\".mapboxgl-ctrl-logo\").node().offsetParent)){var g=e._glimages.append(\"g\");g.attr(\"transform\",a(n.l+n.w*h.x[0]+10,n.t+n.h*(1-h.y[0])-31)),g.append(\"path\").attr(\"d\",p.mapboxLogo.path0).style({opacity:.9,fill:\"#ffffff\",\"enable-background\":\"new\"}),g.append(\"path\").attr(\"d\",p.mapboxLogo.path1).style(\"opacity\",.35).style(\"enable-background\",\"new\"),g.append(\"path\").attr(\"d\",p.mapboxLogo.path2).style(\"opacity\",.35).style(\"enable-background\",\"new\"),g.append(\"polygon\").attr(\"points\",p.mapboxLogo.polygon).style({opacity:.9,fill:\"#ffffff\",\"enable-background\":\"new\"})}var v=m.select(\".mapboxgl-ctrl-attrib\").text().replace(\"Improve this map\",\"\"),y=e._glimages.append(\"g\"),x=y.append(\"text\");x.text(v).classed(\"static-attribution\",!0).attr({\"font-size\":12,\"font-family\":\"Arial\",color:\"rgba(0, 0, 0, 0.75)\",\"text-anchor\":\"end\",\"data-unformatted\":v});var b=u.bBox(x.node()),_=n.w*(h.x[1]-h.x[0]);if(b.width>_/2){var w=v.split(\"|\").join(\"<br>\");x.text(w).attr(\"data-unformatted\",w).call(f.convertToTspans,t),b=u.bBox(x.node())}x.attr(\"transform\",a(-3,8-b.height)),y.insert(\"rect\",\".static-attribution\").attr({x:-b.width-6,y:-b.height-3,width:b.width+6,height:b.height+3,fill:\"rgba(255, 255, 255, 0.75)\"});var T=1;b.width+6>_&&(T=_/(b.width+6));var k=[n.l+n.w*h.x[1],n.t+n.h*(1-h.y[0])];y.attr(\"transform\",a(k[0],k[1])+o(T))}},r.updateFx=function(t){for(var e=t._fullLayout,r=e._subplots.mapbox,n=0;n<r.length;n++){e[r[n]]._subplot.updateFx(e)}}},{\"../../components/drawing\":684,\"../../constants/xmlns_namespaces\":776,\"../../lib\":799,\"../../lib/svg_text_utils\":824,\"../../plots/get_data\":887,\"./constants\":905,\"./layout_attributes\":909,\"./layout_defaults\":910,\"./mapbox\":911,\"@plotly/d3\":58,\"mapbox-gl/dist/mapbox-gl-unminified\":457}],908:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../lib/svg_text_utils\").sanitizeHTML,a=t(\"./convert_text_opts\"),o=t(\"./constants\");function s(t,e){this.subplot=t,this.uid=t.uid+\"-\"+e,this.index=e,this.idSource=\"source-\"+this.uid,this.idLayer=o.layoutLayerPrefix+this.uid,this.sourceType=null,this.source=null,this.layerType=null,this.below=null,this.visible=!1}var l=s.prototype;function c(t){if(!t.visible)return!1;var e=t.source;if(Array.isArray(e)&&e.length>0){for(var r=0;r<e.length;r++)if(\"string\"!=typeof e[r]||0===e[r].length)return!1;return!0}return n.isPlainObject(e)||\"string\"==typeof e&&e.length>0}function u(t){var e={},r={};switch(t.type){case\"circle\":n.extendFlat(r,{\"circle-radius\":t.circle.radius,\"circle-color\":t.color,\"circle-opacity\":t.opacity});break;case\"line\":n.extendFlat(r,{\"line-width\":t.line.width,\"line-color\":t.color,\"line-opacity\":t.opacity,\"line-dasharray\":t.line.dash});break;case\"fill\":n.extendFlat(r,{\"fill-color\":t.color,\"fill-outline-color\":t.fill.outlinecolor,\"fill-opacity\":t.opacity});break;case\"symbol\":var i=t.symbol,o=a(i.textposition,i.iconsize);n.extendFlat(e,{\"icon-image\":i.icon+\"-15\",\"icon-size\":i.iconsize/10,\"text-field\":i.text,\"text-size\":i.textfont.size,\"text-anchor\":o.anchor,\"text-offset\":o.offset,\"symbol-placement\":i.placement}),n.extendFlat(r,{\"icon-color\":t.color,\"text-color\":i.textfont.color,\"text-opacity\":t.opacity});break;case\"raster\":n.extendFlat(r,{\"raster-fade-duration\":0,\"raster-opacity\":t.opacity})}return{layout:e,paint:r}}l.update=function(t){this.visible?this.needsNewImage(t)?this.updateImage(t):this.needsNewSource(t)?(this.removeLayer(),this.updateSource(t),this.updateLayer(t)):this.needsNewLayer(t)?this.updateLayer(t):this.updateStyle(t):(this.updateSource(t),this.updateLayer(t)),this.visible=c(t)},l.needsNewImage=function(t){return this.subplot.map.getSource(this.idSource)&&\"image\"===this.sourceType&&\"image\"===t.sourcetype&&(this.source!==t.source||JSON.stringify(this.coordinates)!==JSON.stringify(t.coordinates))},l.needsNewSource=function(t){return this.sourceType!==t.sourcetype||JSON.stringify(this.source)!==JSON.stringify(t.source)||this.layerType!==t.type},l.needsNewLayer=function(t){return this.layerType!==t.type||this.below!==this.subplot.belowLookup[\"layout-\"+this.index]},l.lookupBelow=function(){return this.subplot.belowLookup[\"layout-\"+this.index]},l.updateImage=function(t){this.subplot.map.getSource(this.idSource).updateImage({url:t.source,coordinates:t.coordinates});var e=this.findFollowingMapboxLayerId(this.lookupBelow());null!==e&&this.subplot.map.moveLayer(this.idLayer,e)},l.updateSource=function(t){var e=this.subplot.map;if(e.getSource(this.idSource)&&e.removeSource(this.idSource),this.sourceType=t.sourcetype,this.source=t.source,c(t)){var r=function(t){var e,r=t.sourcetype,n=t.source,a={type:r};\"geojson\"===r?e=\"data\":\"vector\"===r?e=\"string\"==typeof n?\"url\":\"tiles\":\"raster\"===r?(e=\"tiles\",a.tileSize=256):\"image\"===r&&(e=\"url\",a.coordinates=t.coordinates);a[e]=n,t.sourceattribution&&(a.attribution=i(t.sourceattribution));return a}(t);e.addSource(this.idSource,r)}},l.findFollowingMapboxLayerId=function(t){if(\"traces\"===t)for(var e=this.subplot.getMapLayers(),r=0;r<e.length;r++){var n=e[r].id;if(\"string\"==typeof n&&0===n.indexOf(o.traceLayerPrefix)){t=n;break}}return t},l.updateLayer=function(t){var e=this.subplot,r=u(t),n=this.lookupBelow(),i=this.findFollowingMapboxLayerId(n);this.removeLayer(),c(t)&&e.addLayer({id:this.idLayer,source:this.idSource,\"source-layer\":t.sourcelayer||\"\",type:t.type,minzoom:t.minzoom,maxzoom:t.maxzoom,layout:r.layout,paint:r.paint},i),this.layerType=t.type,this.below=n},l.updateStyle=function(t){if(c(t)){var e=u(t);this.subplot.setOptions(this.idLayer,\"setLayoutProperty\",e.layout),this.subplot.setOptions(this.idLayer,\"setPaintProperty\",e.paint)}},l.removeLayer=function(){var t=this.subplot.map;t.getLayer(this.idLayer)&&t.removeLayer(this.idLayer)},l.dispose=function(){var t=this.subplot.map;t.getLayer(this.idLayer)&&t.removeLayer(this.idLayer),t.getSource(this.idSource)&&t.removeSource(this.idSource)},e.exports=function(t,e,r){var n=new s(t,e);return n.update(r),n}},{\"../../lib\":799,\"../../lib/svg_text_utils\":824,\"./constants\":905,\"./convert_text_opts\":906}],909:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/color\").defaultLine,a=t(\"../domain\").attributes,o=t(\"../font_attributes\"),s=t(\"../../traces/scatter/attributes\").textposition,l=t(\"../../plot_api/edit_types\").overrideAll,c=t(\"../../plot_api/plot_template\").templatedArray,u=t(\"./constants\"),f=o({});f.family.dflt=\"Open Sans Regular, Arial Unicode MS Regular\",(e.exports=l({_arrayAttrRegexps:[n.counterRegex(\"mapbox\",\".layers\",!0)],domain:a({name:\"mapbox\"}),accesstoken:{valType:\"string\",noBlank:!0,strict:!0},style:{valType:\"any\",values:u.styleValuesMapbox.concat(u.styleValuesNonMapbox),dflt:u.styleValueDflt},center:{lon:{valType:\"number\",dflt:0},lat:{valType:\"number\",dflt:0}},zoom:{valType:\"number\",dflt:1},bearing:{valType:\"number\",dflt:0},pitch:{valType:\"number\",dflt:0},layers:c(\"layer\",{visible:{valType:\"boolean\",dflt:!0},sourcetype:{valType:\"enumerated\",values:[\"geojson\",\"vector\",\"raster\",\"image\"],dflt:\"geojson\"},source:{valType:\"any\"},sourcelayer:{valType:\"string\",dflt:\"\"},sourceattribution:{valType:\"string\"},type:{valType:\"enumerated\",values:[\"circle\",\"line\",\"fill\",\"symbol\",\"raster\"],dflt:\"circle\"},coordinates:{valType:\"any\"},below:{valType:\"string\"},color:{valType:\"color\",dflt:i},opacity:{valType:\"number\",min:0,max:1,dflt:1},minzoom:{valType:\"number\",min:0,max:24,dflt:0},maxzoom:{valType:\"number\",min:0,max:24,dflt:24},circle:{radius:{valType:\"number\",dflt:15}},line:{width:{valType:\"number\",dflt:2},dash:{valType:\"data_array\"}},fill:{outlinecolor:{valType:\"color\",dflt:i}},symbol:{icon:{valType:\"string\",dflt:\"marker\"},iconsize:{valType:\"number\",dflt:10},text:{valType:\"string\",dflt:\"\"},placement:{valType:\"enumerated\",values:[\"point\",\"line\",\"line-center\"],dflt:\"point\"},textfont:f,textposition:n.extendFlat({},s,{arrayOk:!1})}})},\"plot\",\"from-root\")).uirevision={valType:\"any\",editType:\"none\"}},{\"../../components/color\":662,\"../../lib\":799,\"../../plot_api/edit_types\":831,\"../../plot_api/plot_template\":838,\"../../traces/scatter/attributes\":1214,\"../domain\":877,\"../font_attributes\":878,\"./constants\":905}],910:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../subplot_defaults\"),a=t(\"../array_container_defaults\"),o=t(\"./layout_attributes\");function s(t,e,r,n){r(\"accesstoken\",n.accessToken),r(\"style\"),r(\"center.lon\"),r(\"center.lat\"),r(\"zoom\"),r(\"bearing\"),r(\"pitch\"),a(t,e,{name:\"layers\",handleItemDefaults:l}),e._input=t}function l(t,e){function r(r,i){return n.coerce(t,e,o.layers,r,i)}if(r(\"visible\")){var i,a=r(\"sourcetype\"),s=\"raster\"===a||\"image\"===a;r(\"source\"),r(\"sourceattribution\"),\"vector\"===a&&r(\"sourcelayer\"),\"image\"===a&&r(\"coordinates\"),s&&(i=\"raster\");var l=r(\"type\",i);s&&\"raster\"!==l&&(l=e.type=\"raster\",n.log(\"Source types *raster* and *image* must drawn *raster* layer type.\")),r(\"below\"),r(\"color\"),r(\"opacity\"),r(\"minzoom\"),r(\"maxzoom\"),\"circle\"===l&&r(\"circle.radius\"),\"line\"===l&&(r(\"line.width\"),r(\"line.dash\")),\"fill\"===l&&r(\"fill.outlinecolor\"),\"symbol\"===l&&(r(\"symbol.icon\"),r(\"symbol.iconsize\"),r(\"symbol.text\"),n.coerceFont(r,\"symbol.textfont\"),r(\"symbol.textposition\"),r(\"symbol.placement\"))}}e.exports=function(t,e,r){i(t,e,r,{type:\"mapbox\",attributes:o,handleDefaults:s,partition:\"y\",accessToken:e._mapboxAccessToken})}},{\"../../lib\":799,\"../array_container_defaults\":844,\"../subplot_defaults\":921,\"./layout_attributes\":909}],911:[function(t,e,r){\"use strict\";var n=t(\"mapbox-gl/dist/mapbox-gl-unminified\"),i=t(\"../../lib\"),a=t(\"../../lib/geo_location_utils\"),o=t(\"../../registry\"),s=t(\"../cartesian/axes\"),l=t(\"../../components/dragelement\"),c=t(\"../../components/fx\"),u=t(\"../../components/dragelement/helpers\"),f=u.rectMode,h=u.drawMode,p=u.selectMode,d=t(\"../cartesian/select\").prepSelect,m=t(\"../cartesian/select\").clearSelect,g=t(\"../cartesian/select\").clearSelectionsCache,v=t(\"../cartesian/select\").selectOnClick,y=t(\"./constants\"),x=t(\"./layers\");function b(t,e){this.id=e,this.gd=t;var r=t._fullLayout,n=t._context;this.container=r._glcontainer.node(),this.isStatic=n.staticPlot,this.uid=r._uid+\"-\"+this.id,this.div=null,this.xaxis=null,this.yaxis=null,this.createFramework(r),this.map=null,this.accessToken=null,this.styleObj=null,this.traceHash={},this.layerList=[],this.belowLookup={},this.dragging=!1,this.wheeling=!1}var _=b.prototype;_.plot=function(t,e,r){var n,i=this,a=e[i.id];i.map&&a.accesstoken!==i.accessToken&&(i.map.remove(),i.map=null,i.styleObj=null,i.traceHash={},i.layerList=[]),n=i.map?new Promise((function(r,n){i.updateMap(t,e,r,n)})):new Promise((function(r,n){i.createMap(t,e,r,n)})),r.push(n)},_.createMap=function(t,e,r,i){var o=this,s=e[o.id],l=o.styleObj=T(s.style);o.accessToken=s.accesstoken;var c=o.map=new n.Map({container:o.div,style:l.style,center:M(s.center),zoom:s.zoom,bearing:s.bearing,pitch:s.pitch,interactive:!o.isStatic,preserveDrawingBuffer:o.isStatic,doubleClickZoom:!1,boxZoom:!1,attributionControl:!1}).addControl(new n.AttributionControl({compact:!0}));c._canvas.style.left=\"0px\",c._canvas.style.top=\"0px\",o.rejectOnError(i),o.isStatic||o.initFx(t,e);var u=[];u.push(new Promise((function(t){c.once(\"load\",t)}))),u=u.concat(a.fetchTraceGeoData(t)),Promise.all(u).then((function(){o.fillBelowLookup(t,e),o.updateData(t),o.updateLayout(e),o.resolveOnRender(r)})).catch(i)},_.updateMap=function(t,e,r,n){var i=this,o=i.map,s=e[this.id];i.rejectOnError(n);var l=[],c=T(s.style);JSON.stringify(i.styleObj)!==JSON.stringify(c)&&(i.styleObj=c,o.setStyle(c.style),i.traceHash={},l.push(new Promise((function(t){o.once(\"styledata\",t)})))),l=l.concat(a.fetchTraceGeoData(t)),Promise.all(l).then((function(){i.fillBelowLookup(t,e),i.updateData(t),i.updateLayout(e),i.resolveOnRender(r)})).catch(n)},_.fillBelowLookup=function(t,e){var r,n,i=e[this.id].layers,a=this.belowLookup={},o=!1;for(r=0;r<t.length;r++){var s=t[r][0].trace,l=s._module;\"string\"==typeof s.below?n=s.below:l.getBelow&&(n=l.getBelow(s,this)),\"\"===n&&(o=!0),a[\"trace-\"+s.uid]=n||\"\"}for(r=0;r<i.length;r++){var c=i[r];n=\"string\"==typeof c.below?c.below:o?\"traces\":\"\",a[\"layout-\"+r]=n}var u,f,h={};for(u in a)h[n=a[u]]?h[n].push(u):h[n]=[u];for(n in h){var p=h[n];if(p.length>1)for(r=0;r<p.length;r++)0===(u=p[r]).indexOf(\"trace-\")?(f=u.split(\"trace-\")[1],this.traceHash[f]&&(this.traceHash[f].below=null)):0===u.indexOf(\"layout-\")&&(f=u.split(\"layout-\")[1],this.layerList[f]&&(this.layerList[f].below=null))}};var w={choroplethmapbox:0,densitymapbox:1,scattermapbox:2};function T(t){var e={};return i.isPlainObject(t)?(e.id=t.id,e.style=t):\"string\"==typeof t?(e.id=t,-1!==y.styleValuesMapbox.indexOf(t)?e.style=k(t):y.stylesNonMapbox[t]?e.style=y.stylesNonMapbox[t]:e.style=t):(e.id=y.styleValueDflt,e.style=k(y.styleValueDflt)),e.transition={duration:0,delay:0},e}function k(t){return y.styleUrlPrefix+t+\"-\"+y.styleUrlSuffix}function M(t){return[t.lon,t.lat]}_.updateData=function(t){var e,r,n,i,a=this.traceHash,o=t.slice().sort((function(t,e){return w[t[0].trace.type]-w[e[0].trace.type]}));for(n=0;n<o.length;n++){var s=o[n],l=!1;(e=a[(r=s[0].trace).uid])&&(e.type===r.type?(e.update(s),l=!0):e.dispose()),!l&&r._module&&(a[r.uid]=r._module.plot(this,s))}var c=Object.keys(a);t:for(n=0;n<c.length;n++){var u=c[n];for(i=0;i<t.length;i++)if(u===(r=t[i][0].trace).uid)continue t;(e=a[u]).dispose(),delete a[u]}},_.updateLayout=function(t){var e=this.map,r=t[this.id];this.dragging||this.wheeling||(e.setCenter(M(r.center)),e.setZoom(r.zoom),e.setBearing(r.bearing),e.setPitch(r.pitch)),this.updateLayers(t),this.updateFramework(t),this.updateFx(t),this.map.resize(),this.gd._context._scrollZoom.mapbox?e.scrollZoom.enable():e.scrollZoom.disable()},_.resolveOnRender=function(t){var e=this.map;e.on(\"render\",(function r(){e.loaded()&&(e.off(\"render\",r),setTimeout(t,10))}))},_.rejectOnError=function(t){var e=this.map;function r(){t(new Error(y.mapOnErrorMsg))}e.once(\"error\",r),e.once(\"style.error\",r),e.once(\"source.error\",r),e.once(\"tile.error\",r),e.once(\"layer.error\",r)},_.createFramework=function(t){var e=this,r=e.div=document.createElement(\"div\");r.id=e.uid,r.style.position=\"absolute\",e.container.appendChild(r),e.xaxis={_id:\"x\",c2p:function(t){return e.project(t).x}},e.yaxis={_id:\"y\",c2p:function(t){return e.project(t).y}},e.updateFramework(t),e.mockAxis={type:\"linear\",showexponent:\"all\",exponentformat:\"B\"},s.setConvert(e.mockAxis,t)},_.initFx=function(t,e){var r=this,n=r.gd,i=r.map;function a(){c.loneUnhover(e._hoverlayer)}function s(){var t=r.getView();n.emit(\"plotly_relayouting\",r.getViewEditsWithDerived(t))}i.on(\"moveend\",(function(t){if(r.map){var e=n._fullLayout;if(t.originalEvent||r.wheeling){var i=e[r.id];o.call(\"_storeDirectGUIEdit\",n.layout,e._preGUI,r.getViewEdits(i));var a=r.getView();i._input.center=i.center=a.center,i._input.zoom=i.zoom=a.zoom,i._input.bearing=i.bearing=a.bearing,i._input.pitch=i.pitch=a.pitch,n.emit(\"plotly_relayout\",r.getViewEditsWithDerived(a))}t.originalEvent&&\"mouseup\"===t.originalEvent.type?r.dragging=!1:r.wheeling&&(r.wheeling=!1),e._rehover&&e._rehover()}})),i.on(\"wheel\",(function(){r.wheeling=!0})),i.on(\"mousemove\",(function(t){var e=r.div.getBoundingClientRect(),a=[t.originalEvent.offsetX,t.originalEvent.offsetY];t.target.getBoundingClientRect=function(){return e},r.xaxis.p2c=function(){return i.unproject(a).lng},r.yaxis.p2c=function(){return i.unproject(a).lat},n._fullLayout._rehover=function(){n._fullLayout._hoversubplot===r.id&&n._fullLayout[r.id]&&c.hover(n,t,r.id)},c.hover(n,t,r.id),n._fullLayout._hoversubplot=r.id})),i.on(\"dragstart\",(function(){r.dragging=!0,a()})),i.on(\"zoomstart\",a),i.on(\"mouseout\",(function(){n._fullLayout._hoversubplot=null})),i.on(\"drag\",s),i.on(\"zoom\",s),i.on(\"dblclick\",(function(){var t=n._fullLayout[r.id];o.call(\"_storeDirectGUIEdit\",n.layout,n._fullLayout._preGUI,r.getViewEdits(t));var e=r.viewInitial;i.setCenter(M(e.center)),i.setZoom(e.zoom),i.setBearing(e.bearing),i.setPitch(e.pitch);var a=r.getView();t._input.center=t.center=a.center,t._input.zoom=t.zoom=a.zoom,t._input.bearing=t.bearing=a.bearing,t._input.pitch=t.pitch=a.pitch,n.emit(\"plotly_doubleclick\",null),n.emit(\"plotly_relayout\",r.getViewEditsWithDerived(a))})),r.clearSelect=function(){g(r.dragOptions),m(r.dragOptions.gd)},r.onClickInPanFn=function(t){return function(e){var i=n._fullLayout.clickmode;i.indexOf(\"select\")>-1&&v(e.originalEvent,n,[r.xaxis],[r.yaxis],r.id,t),i.indexOf(\"event\")>-1&&c.click(n,e.originalEvent)}}},_.updateFx=function(t){var e=this,r=e.map,n=e.gd;if(!e.isStatic){var a,o=t.dragmode;a=f(o)?function(t,r){(t.range={})[e.id]=[c([r.xmin,r.ymin]),c([r.xmax,r.ymax])]}:function(t,r,n){(t.lassoPoints={})[e.id]=n.filtered.map(c)};var s=e.dragOptions;e.dragOptions=i.extendDeep(s||{},{dragmode:t.dragmode,element:e.div,gd:n,plotinfo:{id:e.id,domain:t[e.id].domain,xaxis:e.xaxis,yaxis:e.yaxis,fillRangeItems:a},xaxes:[e.xaxis],yaxes:[e.yaxis],subplot:e.id}),r.off(\"click\",e.onClickInPanHandler),p(o)||h(o)?(r.dragPan.disable(),r.on(\"zoomstart\",e.clearSelect),e.dragOptions.prepFn=function(t,r,n){d(t,r,n,e.dragOptions,o)},l.init(e.dragOptions)):(r.dragPan.enable(),r.off(\"zoomstart\",e.clearSelect),e.div.onmousedown=null,e.onClickInPanHandler=e.onClickInPanFn(e.dragOptions),r.on(\"click\",e.onClickInPanHandler))}function c(t){var r=e.map.unproject(t);return[r.lng,r.lat]}},_.updateFramework=function(t){var e=t[this.id].domain,r=t._size,n=this.div.style;n.width=r.w*(e.x[1]-e.x[0])+\"px\",n.height=r.h*(e.y[1]-e.y[0])+\"px\",n.left=r.l+e.x[0]*r.w+\"px\",n.top=r.t+(1-e.y[1])*r.h+\"px\",this.xaxis._offset=r.l+e.x[0]*r.w,this.xaxis._length=r.w*(e.x[1]-e.x[0]),this.yaxis._offset=r.t+(1-e.y[1])*r.h,this.yaxis._length=r.h*(e.y[1]-e.y[0])},_.updateLayers=function(t){var e,r=t[this.id].layers,n=this.layerList;if(r.length!==n.length){for(e=0;e<n.length;e++)n[e].dispose();for(n=this.layerList=[],e=0;e<r.length;e++)n.push(x(this,e,r[e]))}else for(e=0;e<r.length;e++)n[e].update(r[e])},_.destroy=function(){this.map&&(this.map.remove(),this.map=null,this.container.removeChild(this.div))},_.toImage=function(){return this.map.stop(),this.map.getCanvas().toDataURL()},_.setOptions=function(t,e,r){for(var n in r)this.map[e](t,n,r[n])},_.getMapLayers=function(){return this.map.getStyle().layers},_.addLayer=function(t,e){var r=this.map;if(\"string\"==typeof e){if(\"\"===e)return void r.addLayer(t,e);for(var n=this.getMapLayers(),a=0;a<n.length;a++)if(e===n[a].id)return void r.addLayer(t,e);i.warn([\"Trying to add layer with *below* value\",e,\"referencing a layer that does not exist\",\"or that does not yet exist.\"].join(\" \"))}r.addLayer(t)},_.project=function(t){return this.map.project(new n.LngLat(t[0],t[1]))},_.getView=function(){var t=this.map,e=t.getCenter(),r={lon:e.lng,lat:e.lat},n=t.getCanvas(),i=n.width,a=n.height;return{center:r,zoom:t.getZoom(),bearing:t.getBearing(),pitch:t.getPitch(),_derived:{coordinates:[t.unproject([0,0]).toArray(),t.unproject([i,0]).toArray(),t.unproject([i,a]).toArray(),t.unproject([0,a]).toArray()]}}},_.getViewEdits=function(t){for(var e=this.id,r=[\"center\",\"zoom\",\"bearing\",\"pitch\"],n={},i=0;i<r.length;i++){var a=r[i];n[e+\".\"+a]=t[a]}return n},_.getViewEditsWithDerived=function(t){var e=this.id,r=this.getViewEdits(t);return r[e+\"._derived\"]=t._derived,r},e.exports=b},{\"../../components/dragelement\":681,\"../../components/dragelement/helpers\":680,\"../../components/fx\":702,\"../../lib\":799,\"../../lib/geo_location_utils\":792,\"../../registry\":927,\"../cartesian/axes\":849,\"../cartesian/select\":869,\"./constants\":905,\"./layers\":908,\"mapbox-gl/dist/mapbox-gl-unminified\":457}],912:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.editType;return{t:{valType:\"number\",dflt:0,editType:e},r:{valType:\"number\",dflt:0,editType:e},b:{valType:\"number\",dflt:0,editType:e},l:{valType:\"number\",dflt:0,editType:e},editType:e}}},{}],913:[function(t,e,r){\"use strict\";var n=t(\"@plotly/d3\"),i=t(\"d3-time-format\").timeFormatLocale,a=t(\"fast-isnumeric\"),o=t(\"../registry\"),s=t(\"../plot_api/plot_schema\"),l=t(\"../plot_api/plot_template\"),c=t(\"../lib\"),u=t(\"../components/color\"),f=t(\"../constants/numerical\").BADNUM,h=t(\"./cartesian/axis_ids\"),p=t(\"./cartesian/handle_outline\").clearSelect,d=t(\"./animation_attributes\"),m=t(\"./frame_attributes\"),g=t(\"../plots/get_data\").getModuleCalcData,v=c.relinkPrivateKeys,y=c._,x=e.exports={};c.extendFlat(x,o),x.attributes=t(\"./attributes\"),x.attributes.type.values=x.allTypes,x.fontAttrs=t(\"./font_attributes\"),x.layoutAttributes=t(\"./layout_attributes\"),x.fontWeight=\"normal\";var b=x.transformsRegistry,_=t(\"./command\");x.executeAPICommand=_.executeAPICommand,x.computeAPICommandBindings=_.computeAPICommandBindings,x.manageCommandObserver=_.manageCommandObserver,x.hasSimpleAPICommandBindings=_.hasSimpleAPICommandBindings,x.redrawText=function(t){return t=c.getGraphDiv(t),new Promise((function(e){setTimeout((function(){t._fullLayout&&(o.getComponentMethod(\"annotations\",\"draw\")(t),o.getComponentMethod(\"legend\",\"draw\")(t),o.getComponentMethod(\"colorbar\",\"draw\")(t),e(x.previousPromises(t)))}),300)}))},x.resize=function(t){var e;t=c.getGraphDiv(t);var r=new Promise((function(r,n){t&&!c.isHidden(t)||n(new Error(\"Resize must be passed a displayed plot div element.\")),t._redrawTimer&&clearTimeout(t._redrawTimer),t._resolveResize&&(e=t._resolveResize),t._resolveResize=r,t._redrawTimer=setTimeout((function(){if(!t.layout||t.layout.width&&t.layout.height||c.isHidden(t))r(t);else{delete t.layout.width,delete t.layout.height;var e=t.changed;t.autoplay=!0,o.call(\"relayout\",t,{autosize:!0}).then((function(){t.changed=e,t._resolveResize===r&&(delete t._resolveResize,r(t))}))}}),100)}));return e&&e(r),r},x.previousPromises=function(t){if((t._promises||[]).length)return Promise.all(t._promises).then((function(){t._promises=[]}))},x.addLinks=function(t){if(t._context.showLink||t._context.showSources){var e=t._fullLayout,r=c.ensureSingle(e._paper,\"text\",\"js-plot-link-container\",(function(t){t.style({\"font-family\":'\"Open Sans\", Arial, sans-serif',\"font-size\":\"12px\",fill:u.defaultLine,\"pointer-events\":\"all\"}).each((function(){var t=n.select(this);t.append(\"tspan\").classed(\"js-link-to-tool\",!0),t.append(\"tspan\").classed(\"js-link-spacer\",!0),t.append(\"tspan\").classed(\"js-sourcelinks\",!0)}))})),i=r.node(),a={y:e._paper.attr(\"height\")-9};document.body.contains(i)&&i.getComputedTextLength()>=e.width-20?(a[\"text-anchor\"]=\"start\",a.x=5):(a[\"text-anchor\"]=\"end\",a.x=e._paper.attr(\"width\")-7),r.attr(a);var o=r.select(\".js-link-to-tool\"),s=r.select(\".js-link-spacer\"),l=r.select(\".js-sourcelinks\");t._context.showSources&&t._context.showSources(t),t._context.showLink&&function(t,e){e.text(\"\");var r=e.append(\"a\").attr({\"xlink:xlink:href\":\"#\",class:\"link--impt link--embedview\",\"font-weight\":\"bold\"}).text(t._context.linkText+\" \"+String.fromCharCode(187));if(t._context.sendData)r.on(\"click\",(function(){x.sendDataToCloud(t)}));else{var n=window.location.pathname.split(\"/\"),i=window.location.search;r.attr({\"xlink:xlink:show\":\"new\",\"xlink:xlink:href\":\"/\"+n[2].split(\".\")[0]+\"/\"+n[1]+i})}}(t,o),s.text(o.text()&&l.text()?\" - \":\"\")}},x.sendDataToCloud=function(t){var e=(window.PLOTLYENV||{}).BASE_URL||t._context.plotlyServerURL;if(e){t.emit(\"plotly_beforeexport\");var r=n.select(t).append(\"div\").attr(\"id\",\"hiddenform\").style(\"display\",\"none\"),i=r.append(\"form\").attr({action:e+\"/external\",method:\"post\",target:\"_blank\"});return i.append(\"input\").attr({type:\"text\",name:\"data\"}).node().value=x.graphJson(t,!1,\"keepdata\"),i.node().submit(),r.remove(),t.emit(\"plotly_afterexport\"),!1}};var w=[\"days\",\"shortDays\",\"months\",\"shortMonths\",\"periods\",\"dateTime\",\"date\",\"time\",\"decimal\",\"thousands\",\"grouping\",\"currency\"],T=[\"year\",\"month\",\"dayMonth\",\"dayMonthYear\"];function k(t,e){var r=t._context.locale;r||(r=\"en-US\");var n=!1,i={};function a(t){for(var r=!0,a=0;a<e.length;a++){var o=e[a];i[o]||(t[o]?i[o]=t[o]:r=!1)}r&&(n=!0)}for(var s=0;s<2;s++){for(var l=t._context.locales,c=0;c<2;c++){var u=(l[r]||{}).format;if(u&&(a(u),n))break;l=o.localeRegistry}var f=r.split(\"-\")[0];if(n||f===r)break;r=f}return n||a(o.localeRegistry.en.format),i}function M(t,e){var r={_fullLayout:e},n=\"x\"===t._id.charAt(0),i=t._mainAxis._anchorAxis,a=\"\",o=\"\",s=\"\";if(i&&(s=i._mainAxis._id,a=n?t._id+s:s+t._id),!a||!e._plots[a]){a=\"\";for(var l=t._counterAxes,c=0;c<l.length;c++){var u=l[c],f=n?t._id+u:u+t._id;o||(o=f);var p=h.getFromId(r,u);if(s&&p.overlaying===s){a=f;break}}}return a||o}function A(t){var e=t.transforms;if(Array.isArray(e)&&e.length)for(var r=0;r<e.length;r++){var n=e[r],i=n._module||b[n.type];if(i&&i.makesData)return!0}return!1}function S(t,e,r,n){for(var i=t.transforms,a=[t],o=0;o<i.length;o++){var s=i[o],l=b[s.type];l&&l.transform&&(a=l.transform(a,{transform:s,fullTrace:t,fullData:e,layout:r,fullLayout:n,transformIndex:o}))}return a}function E(t){return\"string\"==typeof t&&\"px\"===t.substr(t.length-2)&&parseFloat(t)}function L(t){var e=t.margin;if(!t._size){var r=t._size={l:Math.round(e.l),r:Math.round(e.r),t:Math.round(e.t),b:Math.round(e.b),p:Math.round(e.pad)};r.w=Math.round(t.width)-r.l-r.r,r.h=Math.round(t.height)-r.t-r.b}t._pushmargin||(t._pushmargin={}),t._pushmarginIds||(t._pushmarginIds={})}x.supplyDefaults=function(t,e){var r=e&&e.skipUpdateCalc,a=t._fullLayout||{};if(a._skipDefaults)delete a._skipDefaults;else{var s,l=t._fullLayout={},u=t.layout||{},f=t._fullData||[],h=t._fullData=[],d=t.data||[],m=t.calcdata||[],g=t._context||{};t._transitionData||x.createTransitionData(t),l._dfltTitle={plot:y(t,\"Click to enter Plot title\"),x:y(t,\"Click to enter X axis title\"),y:y(t,\"Click to enter Y axis title\"),colorbar:y(t,\"Click to enter Colorscale title\"),annotation:y(t,\"new text\")},l._traceWord=y(t,\"trace\");var b=k(t,w);if(l._mapboxAccessToken=g.mapboxAccessToken,a._initialAutoSizeIsDone){var _=a.width,M=a.height;x.supplyLayoutGlobalDefaults(u,l,b),u.width||(l.width=_),u.height||(l.height=M),x.sanitizeMargins(l)}else{x.supplyLayoutGlobalDefaults(u,l,b);var A=!u.width||!u.height,S=l.autosize,E=g.autosizable;A&&(S||E)?x.plotAutoSize(t,u,l):A&&x.sanitizeMargins(l),!S&&A&&(u.width=l.width,u.height=l.height)}l._d3locale=function(t,e){return t.decimal=e.charAt(0),t.thousands=e.charAt(1),{numberFormat:n.locale(t).numberFormat,timeFormat:i(t).utcFormat}}(b,l.separators),l._extraFormat=k(t,T),l._initialAutoSizeIsDone=!0,l._dataLength=d.length,l._modules=[],l._visibleModules=[],l._basePlotModules=[];var C=l._subplots=function(){var t,e,r=o.collectableSubplotTypes,n={};if(!r){r=[];var i=o.subplotsRegistry;for(var a in i){var s=i[a].attr;if(s&&(r.push(a),Array.isArray(s)))for(e=0;e<s.length;e++)c.pushUnique(r,s[e])}}for(t=0;t<r.length;t++)n[r[t]]=[];return n}(),P=l._splomAxes={x:{},y:{}},I=l._splomSubplots={};l._splomGridDflt={},l._scatterStackOpts={},l._firstScatter={},l._alignmentOpts={},l._colorAxes={},l._requestRangeslider={},l._traceUids=function(t,e){var r,n,i=e.length,a=[];for(r=0;r<t.length;r++){var o=t[r]._fullInput;o!==n&&a.push(o),n=o}var s=a.length,l=new Array(i),u={};function f(t,e){l[e]=t,u[t]=1}function h(t,e){if(t&&\"string\"==typeof t&&!u[t])return f(t,e),!0}for(r=0;r<i;r++){var p=e[r].uid;\"number\"==typeof p&&(p=String(p)),h(p,r)||(r<s&&h(a[r].uid,r)||f(c.randstr(u),r))}return l}(f,d),l._globalTransforms=(t._context||{}).globalTransforms,x.supplyDataDefaults(d,h,u,l);var O=Object.keys(P.x),z=Object.keys(P.y);if(O.length>1&&z.length>1){for(o.getComponentMethod(\"grid\",\"sizeDefaults\")(u,l),s=0;s<O.length;s++)c.pushUnique(C.xaxis,O[s]);for(s=0;s<z.length;s++)c.pushUnique(C.yaxis,z[s]);for(var D in I)c.pushUnique(C.cartesian,D)}if(l._has=x._hasPlotType.bind(l),f.length===h.length)for(s=0;s<h.length;s++)v(h[s],f[s]);x.supplyLayoutModuleDefaults(u,l,h,t._transitionData);var R=l._visibleModules,F=[];for(s=0;s<R.length;s++){var B=R[s].crossTraceDefaults;B&&c.pushUnique(F,B)}for(s=0;s<F.length;s++)F[s](h,l);l._hasOnlyLargeSploms=1===l._basePlotModules.length&&\"splom\"===l._basePlotModules[0].name&&O.length>15&&z.length>15&&0===l.shapes.length&&0===l.images.length,x.linkSubplots(h,l,f,a),x.cleanPlot(h,l,f,a);var N=!(!a._has||!a._has(\"gl2d\")),j=!(!l._has||!l._has(\"gl2d\")),U=!(!a._has||!a._has(\"cartesian\"))||N,V=!(!l._has||!l._has(\"cartesian\"))||j;U&&!V?a._bgLayer.remove():V&&!U&&(l._shouldCreateBgLayer=!0),a._zoomlayer&&!t._dragging&&p({_fullLayout:a}),function(t,e){var r,n=[];e.meta&&(r=e._meta={meta:e.meta,layout:{meta:e.meta}});for(var i=0;i<t.length;i++){var a=t[i];a.meta?n[a.index]=a._meta={meta:a.meta}:e.meta&&(a._meta={meta:e.meta}),e.meta&&(a._meta.layout={meta:e.meta})}n.length&&(r||(r=e._meta={}),r.data=n)}(h,l),v(l,a),o.getComponentMethod(\"colorscale\",\"crossTraceDefaults\")(h,l),l._preGUI||(l._preGUI={}),l._tracePreGUI||(l._tracePreGUI={});var q,H=l._tracePreGUI,G={};for(q in H)G[q]=\"old\";for(s=0;s<h.length;s++)G[q=h[s]._fullInput.uid]||(H[q]={}),G[q]=\"new\";for(q in G)\"old\"===G[q]&&delete H[q];L(l),o.getComponentMethod(\"rangeslider\",\"makeData\")(l),r||m.length!==h.length||x.supplyDefaultsUpdateCalc(m,h)}},x.supplyDefaultsUpdateCalc=function(t,e){for(var r=0;r<e.length;r++){var n=e[r],i=(t[r]||[])[0];if(i&&i.trace){var a=i.trace;if(a._hasCalcTransform){var o,s,l,u=a._arrayAttrs;for(o=0;o<u.length;o++)s=u[o],l=c.nestedProperty(a,s).get().slice(),c.nestedProperty(n,s).set(l)}i.trace=n}}},x.createTransitionData=function(t){t._transitionData||(t._transitionData={}),t._transitionData._frames||(t._transitionData._frames=[]),t._transitionData._frameHash||(t._transitionData._frameHash={}),t._transitionData._counter||(t._transitionData._counter=0),t._transitionData._interruptCallbacks||(t._transitionData._interruptCallbacks=[])},x._hasPlotType=function(t){var e,r=this._basePlotModules||[];for(e=0;e<r.length;e++)if(r[e].name===t)return!0;var n=this._modules||[];for(e=0;e<n.length;e++){var i=n[e].name;if(i===t)return!0;var a=o.modules[i];if(a&&a.categories[t])return!0}return!1},x.cleanPlot=function(t,e,r,n){var i,a,o=n._basePlotModules||[];for(i=0;i<o.length;i++){var s=o[i];s.clean&&s.clean(t,e,r,n)}var l=n._has&&n._has(\"gl\"),c=e._has&&e._has(\"gl\");l&&!c&&void 0!==n._glcontainer&&(n._glcontainer.selectAll(\".gl-canvas\").remove(),n._glcontainer.selectAll(\".no-webgl\").remove(),n._glcanvas=null);var u=!!n._infolayer;t:for(i=0;i<r.length;i++){var f=r[i].uid;for(a=0;a<t.length;a++){if(f===t[a].uid)continue t}u&&n._infolayer.select(\".cb\"+f).remove()}},x.linkSubplots=function(t,e,r,n){var i,a,s=n._plots||{},l=e._plots={},u=e._subplots,f={_fullData:t,_fullLayout:e},p=u.cartesian.concat(u.gl2d||[]);for(i=0;i<p.length;i++){var d,m=p[i],g=s[m],v=h.getFromId(f,m,\"x\"),y=h.getFromId(f,m,\"y\");for(g?d=l[m]=g:(d=l[m]={}).id=m,v._counterAxes.push(y._id),y._counterAxes.push(v._id),v._subplotsWith.push(m),y._subplotsWith.push(m),d.xaxis=v,d.yaxis=y,d._hasClipOnAxisFalse=!1,a=0;a<t.length;a++){var x=t[a];if(x.xaxis===d.xaxis._id&&x.yaxis===d.yaxis._id&&!1===x.cliponaxis){d._hasClipOnAxisFalse=!0;break}}}var b,_=h.list(f,null,!0);for(i=0;i<_.length;i++){var w=null;(b=_[i]).overlaying&&(w=h.getFromId(f,b.overlaying))&&w.overlaying&&(b.overlaying=!1,w=null),b._mainAxis=w||b,w&&(b.domain=w.domain.slice()),b._anchorAxis=\"free\"===b.anchor?null:h.getFromId(f,b.anchor)}for(i=0;i<_.length;i++)if((b=_[i])._counterAxes.sort(h.idSort),b._subplotsWith.sort(c.subplotSort),b._mainSubplot=M(b,e),b._counterAxes.length&&(b.spikemode&&-1!==b.spikemode.indexOf(\"across\")||b.automargin&&b.mirror&&\"free\"!==b.anchor||o.getComponentMethod(\"rangeslider\",\"isVisible\")(b))){var T=1,k=0;for(a=0;a<b._counterAxes.length;a++){var A=h.getFromId(f,b._counterAxes[a]);T=Math.min(T,A.domain[0]),k=Math.max(k,A.domain[1])}T<k&&(b._counterDomainMin=T,b._counterDomainMax=k)}},x.clearExpandedTraceDefaultColors=function(t){var e,r,n;for(r=[],(e=t._module._colorAttrs)||(t._module._colorAttrs=e=[],s.crawl(t._module.attributes,(function(t,n,i,a){r[a]=n,r.length=a+1,\"color\"===t.valType&&void 0===t.dflt&&e.push(r.join(\".\"))}))),n=0;n<e.length;n++){c.nestedProperty(t,\"_input.\"+e[n]).get()||c.nestedProperty(t,e[n]).set(null)}},x.supplyDataDefaults=function(t,e,r,n){var i,a,s,u=n._modules,f=n._visibleModules,h=n._basePlotModules,p=0,d=0;function m(t){e.push(t);var r=t._module;r&&(c.pushUnique(u,r),!0===t.visible&&c.pushUnique(f,r),c.pushUnique(h,t._module.basePlotModule),p++,!1!==t._input.visible&&d++)}n._transformModules=[];var g={},y=[],b=(r.template||{}).data||{},_=l.traceTemplater(b);for(i=0;i<t.length;i++){if(s=t[i],(a=_.newTrace(s)).uid=n._traceUids[i],x.supplyTraceDefaults(s,a,d,n,i),a.index=i,a._input=s,a._expandedIndex=p,a.transforms&&a.transforms.length)for(var w=!1!==s.visible&&!1===a.visible,T=S(a,e,r,n),k=0;k<T.length;k++){var M=T[k],A={_template:a._template,type:a.type,uid:a.uid+k};w&&!1===M.visible&&delete M.visible,x.supplyTraceDefaults(M,A,p,n,i),v(A,M),A.index=i,A._input=s,A._fullInput=a,A._expandedIndex=p,A._expandedInput=M,m(A)}else a._fullInput=a,a._expandedInput=a,m(a);o.traceIs(a,\"carpetAxis\")&&(g[a.carpet]=a),o.traceIs(a,\"carpetDependent\")&&y.push(i)}for(i=0;i<y.length;i++)if((a=e[y[i]]).visible){var E=g[a.carpet];a._carpet=E,E&&E.visible?(a.xaxis=E.xaxis,a.yaxis=E.yaxis):a.visible=!1}},x.supplyAnimationDefaults=function(t){var e;t=t||{};var r={};function n(e,n){return c.coerce(t||{},r,d,e,n)}if(n(\"mode\"),n(\"direction\"),n(\"fromcurrent\"),Array.isArray(t.frame))for(r.frame=[],e=0;e<t.frame.length;e++)r.frame[e]=x.supplyAnimationFrameDefaults(t.frame[e]||{});else r.frame=x.supplyAnimationFrameDefaults(t.frame||{});if(Array.isArray(t.transition))for(r.transition=[],e=0;e<t.transition.length;e++)r.transition[e]=x.supplyAnimationTransitionDefaults(t.transition[e]||{});else r.transition=x.supplyAnimationTransitionDefaults(t.transition||{});return r},x.supplyAnimationFrameDefaults=function(t){var e={};function r(r,n){return c.coerce(t||{},e,d.frame,r,n)}return r(\"duration\"),r(\"redraw\"),e},x.supplyAnimationTransitionDefaults=function(t){var e={};function r(r,n){return c.coerce(t||{},e,d.transition,r,n)}return r(\"duration\"),r(\"easing\"),e},x.supplyFrameDefaults=function(t){var e={};function r(r,n){return c.coerce(t,e,m,r,n)}return r(\"group\"),r(\"name\"),r(\"traces\"),r(\"baseframe\"),r(\"data\"),r(\"layout\"),e},x.supplyTraceDefaults=function(t,e,r,n,i){var a,s=n.colorway||u.defaults,l=s[r%s.length];function f(r,n){return c.coerce(t,e,x.attributes,r,n)}var h=f(\"visible\");f(\"type\"),f(\"name\",n._traceWord+\" \"+i),f(\"uirevision\",n.uirevision);var p=x.getModule(e);if(e._module=p,p){var d=p.basePlotModule,m=d.attr,g=d.attributes;if(m&&g){var v=n._subplots,y=\"\";if(h||\"gl2d\"!==d.name){if(Array.isArray(m))for(a=0;a<m.length;a++){var b=m[a],_=c.coerce(t,e,g,b);v[b]&&c.pushUnique(v[b],_),y+=_}else y=c.coerce(t,e,g,m);v[d.name]&&c.pushUnique(v[d.name],y)}}}if(h){if(f(\"customdata\"),f(\"ids\"),f(\"meta\"),o.traceIs(e,\"showLegend\"))c.coerce(t,e,p.attributes.showlegend?p.attributes:x.attributes,\"showlegend\"),f(\"legendgroup\"),f(\"legendgrouptitle.text\")&&c.coerceFont(f,\"legendgrouptitle.font\",c.extendFlat({},n.font,{size:Math.round(1.1*n.font.size)})),f(\"legendrank\"),e._dfltShowLegend=!0;else e._dfltShowLegend=!1;p&&p.supplyDefaults(t,e,l,n),o.traceIs(e,\"noOpacity\")||f(\"opacity\"),o.traceIs(e,\"notLegendIsolatable\")&&(e.visible=!!e.visible),o.traceIs(e,\"noHover\")||(e.hovertemplate||c.coerceHoverinfo(t,e,n),\"parcats\"!==e.type&&o.getComponentMethod(\"fx\",\"supplyDefaults\")(t,e,l,n)),p&&p.selectPoints&&f(\"selectedpoints\"),x.supplyTransformDefaults(t,e,n)}return e},x.hasMakesDataTransform=A,x.supplyTransformDefaults=function(t,e,r){if(e._length||A(t)){var n=r._globalTransforms||[],i=r._transformModules||[];if(Array.isArray(t.transforms)||0!==n.length)for(var a=t.transforms||[],o=n.concat(a),s=e.transforms=[],l=0;l<o.length;l++){var u,f=o[l],h=f.type,p=b[h],d=!(f._module&&f._module===p),m=p&&\"function\"==typeof p.transform;p||c.warn(\"Unrecognized transform type \"+h+\".\"),p&&p.supplyDefaults&&(d||m)?((u=p.supplyDefaults(f,e,r,t)).type=h,u._module=p,c.pushUnique(i,p)):u=c.extendFlat({},f),s.push(u)}}},x.supplyLayoutGlobalDefaults=function(t,e,r){function n(r,n){return c.coerce(t,e,x.layoutAttributes,r,n)}var i=t.template;c.isPlainObject(i)&&(e.template=i,e._template=i.layout,e._dataTemplate=i.data),n(\"autotypenumbers\");var a=c.coerceFont(n,\"font\");n(\"title.text\",e._dfltTitle.plot),c.coerceFont(n,\"title.font\",{family:a.family,size:Math.round(1.4*a.size),color:a.color}),n(\"title.xref\"),n(\"title.yref\"),n(\"title.x\"),n(\"title.y\"),n(\"title.xanchor\"),n(\"title.yanchor\"),n(\"title.pad.t\"),n(\"title.pad.r\"),n(\"title.pad.b\"),n(\"title.pad.l\"),n(\"uniformtext.mode\")&&n(\"uniformtext.minsize\"),n(\"autosize\",!(t.width&&t.height)),n(\"width\"),n(\"height\"),n(\"margin.l\"),n(\"margin.r\"),n(\"margin.t\"),n(\"margin.b\"),n(\"margin.pad\"),n(\"margin.autoexpand\"),t.width&&t.height&&x.sanitizeMargins(e),o.getComponentMethod(\"grid\",\"sizeDefaults\")(t,e),n(\"paper_bgcolor\"),n(\"separators\",r.decimal+r.thousands),n(\"hidesources\"),n(\"colorway\"),n(\"datarevision\");var s=n(\"uirevision\");n(\"editrevision\",s),n(\"selectionrevision\",s),o.getComponentMethod(\"modebar\",\"supplyLayoutDefaults\")(t,e),o.getComponentMethod(\"shapes\",\"supplyDrawNewShapeDefaults\")(t,e,n),n(\"meta\"),c.isPlainObject(t.transition)&&(n(\"transition.duration\"),n(\"transition.easing\"),n(\"transition.ordering\")),o.getComponentMethod(\"calendars\",\"handleDefaults\")(t,e,\"calendar\"),o.getComponentMethod(\"fx\",\"supplyLayoutGlobalDefaults\")(t,e,n)},x.plotAutoSize=function(t,e,r){var n,i,o=t._context||{},s=o.frameMargins,l=c.isPlotDiv(t);if(l&&t.emit(\"plotly_autosize\"),o.fillFrame)n=window.innerWidth,i=window.innerHeight,document.body.style.overflow=\"hidden\";else{var u=l?window.getComputedStyle(t):{};if(n=E(u.width)||E(u.maxWidth)||r.width,i=E(u.height)||E(u.maxHeight)||r.height,a(s)&&s>0){var f=1-2*s;n=Math.round(f*n),i=Math.round(f*i)}}var h=x.layoutAttributes.width.min,p=x.layoutAttributes.height.min;n<h&&(n=h),i<p&&(i=p);var d=!e.width&&Math.abs(r.width-n)>1,m=!e.height&&Math.abs(r.height-i)>1;(m||d)&&(d&&(r.width=n),m&&(r.height=i)),t._initialAutoSize||(t._initialAutoSize={width:n,height:i}),x.sanitizeMargins(r)},x.supplyLayoutModuleDefaults=function(t,e,r,n){var i,a,s,l=o.componentsRegistry,u=e._basePlotModules,f=o.subplotsRegistry.cartesian;for(i in l)(s=l[i]).includeBasePlot&&s.includeBasePlot(t,e);for(var h in u.length||u.push(f),e._has(\"cartesian\")&&(o.getComponentMethod(\"grid\",\"contentDefaults\")(t,e),f.finalizeSubplots(t,e)),e._subplots)e._subplots[h].sort(c.subplotSort);for(a=0;a<u.length;a++)(s=u[a]).supplyLayoutDefaults&&s.supplyLayoutDefaults(t,e,r);var p=e._modules;for(a=0;a<p.length;a++)(s=p[a]).supplyLayoutDefaults&&s.supplyLayoutDefaults(t,e,r);var d=e._transformModules;for(a=0;a<d.length;a++)(s=d[a]).supplyLayoutDefaults&&s.supplyLayoutDefaults(t,e,r,n);for(i in l)(s=l[i]).supplyLayoutDefaults&&s.supplyLayoutDefaults(t,e,r)},x.purge=function(t){var e=t._fullLayout||{};void 0!==e._glcontainer&&(e._glcontainer.selectAll(\".gl-canvas\").remove(),e._glcontainer.remove(),e._glcanvas=null),e._modeBar&&e._modeBar.destroy(),t._transitionData&&(t._transitionData._interruptCallbacks&&(t._transitionData._interruptCallbacks.length=0),t._transitionData._animationRaf&&window.cancelAnimationFrame(t._transitionData._animationRaf)),c.clearThrottle(),c.clearResponsive(t),delete t.data,delete t.layout,delete t._fullData,delete t._fullLayout,delete t.calcdata,delete t.empty,delete t.fid,delete t.undoqueue,delete t.undonum,delete t.autoplay,delete t.changed,delete t._promises,delete t._redrawTimer,delete t._hmlumcount,delete t._hmpixcount,delete t._transitionData,delete t._transitioning,delete t._initialAutoSize,delete t._transitioningWithDuration,delete t._dragging,delete t._dragged,delete t._dragdata,delete t._hoverdata,delete t._snapshotInProgress,delete t._editing,delete t._mouseDownTime,delete t._legendMouseDownTime,t.removeAllListeners&&t.removeAllListeners()},x.style=function(t){var e,r=t._fullLayout._visibleModules,n=[];for(e=0;e<r.length;e++){var i=r[e];i.style&&c.pushUnique(n,i.style)}for(e=0;e<n.length;e++)n[e](t)},x.sanitizeMargins=function(t){if(t&&t.margin){var e,r=t.width,n=t.height,i=t.margin,a=r-(i.l+i.r),o=n-(i.t+i.b);a<0&&(e=(r-1)/(i.l+i.r),i.l=Math.floor(e*i.l),i.r=Math.floor(e*i.r)),o<0&&(e=(n-1)/(i.t+i.b),i.t=Math.floor(e*i.t),i.b=Math.floor(e*i.b))}},x.clearAutoMarginIds=function(t){t._fullLayout._pushmarginIds={}},x.allowAutoMargin=function(t,e){t._fullLayout._pushmarginIds[e]=1};x.autoMargin=function(t,e,r){var n=t._fullLayout,i=n.width,a=n.height,o=n.margin,s=c.constrain(i-o.l-o.r,2,64),l=c.constrain(a-o.t-o.b,2,64),u=Math.max(0,i-s),f=Math.max(0,a-l),h=n._pushmargin,p=n._pushmarginIds;if(!1!==o.autoexpand){if(r){var d=r.pad;if(void 0===d&&(d=Math.min(12,o.l,o.r,o.t,o.b)),u){var m=(r.l+r.r)/u;m>1&&(r.l/=m,r.r/=m)}if(f){var g=(r.t+r.b)/f;g>1&&(r.t/=g,r.b/=g)}var v=void 0!==r.xl?r.xl:r.x,y=void 0!==r.xr?r.xr:r.x,b=void 0!==r.yt?r.yt:r.y,_=void 0!==r.yb?r.yb:r.y;h[e]={l:{val:v,size:r.l+d},r:{val:y,size:r.r+d},b:{val:_,size:r.b+d},t:{val:b,size:r.t+d}},p[e]=1}else delete h[e],delete p[e];if(!n._replotting)return x.doAutoMargin(t)}},x.doAutoMargin=function(t){var e=t._fullLayout,r=e.width,n=e.height;e._size||(e._size={}),L(e);var i=e._size,s=e.margin,l=c.extendFlat({},i),u=s.l,f=s.r,p=s.t,d=s.b,m=e._pushmargin,g=e._pushmarginIds;if(!1!==e.margin.autoexpand){for(var v in m)g[v]||delete m[v];for(var y in m.base={l:{val:0,size:u},r:{val:1,size:f},t:{val:1,size:p},b:{val:0,size:d}},m){var b=m[y].l||{},_=m[y].b||{},w=b.val,T=b.size,k=_.val,M=_.size;for(var A in m){if(a(T)&&m[A].r){var S=m[A].r.val,E=m[A].r.size;if(S>w){var C=(T*S+(E-r)*w)/(S-w),P=(E*(1-w)+(T-r)*(1-S))/(S-w);C+P>u+f&&(u=C,f=P)}}if(a(M)&&m[A].t){var I=m[A].t.val,O=m[A].t.size;if(I>k){var z=(M*I+(O-n)*k)/(I-k),D=(O*(1-k)+(M-n)*(1-I))/(I-k);z+D>d+p&&(d=z,p=D)}}}}}var R=c.constrain(r-s.l-s.r,2,64),F=c.constrain(n-s.t-s.b,2,64),B=Math.max(0,r-R),N=Math.max(0,n-F);if(B){var j=(u+f)/B;j>1&&(u/=j,f/=j)}if(N){var U=(d+p)/N;U>1&&(d/=U,p/=U)}if(i.l=Math.round(u),i.r=Math.round(f),i.t=Math.round(p),i.b=Math.round(d),i.p=Math.round(s.pad),i.w=Math.round(r)-i.l-i.r,i.h=Math.round(n)-i.t-i.b,!e._replotting&&x.didMarginChange(l,i)){\"_redrawFromAutoMarginCount\"in e?e._redrawFromAutoMarginCount++:e._redrawFromAutoMarginCount=1;var V=3*(1+Object.keys(g).length);if(e._redrawFromAutoMarginCount<V)return o.call(\"_doPlot\",t);e._size=l,c.warn(\"Too many auto-margin redraws.\")}!function(t){var e=h.list(t,\"\",!0);[\"_adjustTickLabelsOverflow\",\"_hideCounterAxisInsideTickLabels\"].forEach((function(t){for(var r=0;r<e.length;r++){var n=e[r][t];n&&n()}}))}(t)};var C=[\"l\",\"r\",\"t\",\"b\",\"p\",\"w\",\"h\"];function P(t,e,r){var n=!1;var i=[x.previousPromises,function(){if(t._transitionData)return t._transitioning=!1,function(t){var e=Promise.resolve();if(!t)return e;for(;t.length;)e=e.then(t.shift());return e}(t._transitionData._interruptCallbacks)},r.prepareFn,x.rehover,function(){return t.emit(\"plotly_transitioning\",[]),new Promise((function(i){t._transitioning=!0,e.duration>0&&(t._transitioningWithDuration=!0),t._transitionData._interruptCallbacks.push((function(){n=!0})),r.redraw&&t._transitionData._interruptCallbacks.push((function(){return o.call(\"redraw\",t)})),t._transitionData._interruptCallbacks.push((function(){t.emit(\"plotly_transitioninterrupted\",[])}));var a=0,s=0;function l(){return a++,function(){s++,n||s!==a||function(e){if(!t._transitionData)return;(function(t){if(t)for(;t.length;)t.shift()})(t._transitionData._interruptCallbacks),Promise.resolve().then((function(){if(r.redraw)return o.call(\"redraw\",t)})).then((function(){t._transitioning=!1,t._transitioningWithDuration=!1,t.emit(\"plotly_transitioned\",[])})).then(e)}(i)}}r.runFn(l),setTimeout(l())}))}],a=c.syncOrAsync(i,t);return a&&a.then||(a=Promise.resolve()),a.then((function(){return t}))}x.didMarginChange=function(t,e){for(var r=0;r<C.length;r++){var n=C[r],i=t[n],o=e[n];if(!a(i)||Math.abs(o-i)>1)return!0}return!1},x.graphJson=function(t,e,r,n,i,a){(i&&e&&!t._fullData||i&&!e&&!t._fullLayout)&&x.supplyDefaults(t);var o=i?t._fullData:t.data,s=i?t._fullLayout:t.layout,l=(t._transitionData||{})._frames;function u(t,e){if(\"function\"==typeof t)return e?\"_function_\":null;if(c.isPlainObject(t)){var n,i={};return Object.keys(t).sort().forEach((function(a){if(-1===[\"_\",\"[\"].indexOf(a.charAt(0)))if(\"function\"!=typeof t[a]){if(\"keepdata\"===r){if(\"src\"===a.substr(a.length-3))return}else if(\"keepstream\"===r){if(\"string\"==typeof(n=t[a+\"src\"])&&n.indexOf(\":\")>0&&!c.isPlainObject(t.stream))return}else if(\"keepall\"!==r&&\"string\"==typeof(n=t[a+\"src\"])&&n.indexOf(\":\")>0)return;i[a]=u(t[a],e)}else e&&(i[a]=\"_function\")})),i}return Array.isArray(t)?t.map((function(t){return u(t,e)})):c.isTypedArray(t)?c.simpleMap(t,c.identity):c.isJSDate(t)?c.ms2DateTimeLocal(+t):t}var f={data:(o||[]).map((function(t){var r=u(t);return e&&delete r.fit,r}))};if(!e&&(f.layout=u(s),i)){var h=s._size;f.layout.computed={margin:{b:h.b,l:h.l,r:h.r,t:h.t}}}return l&&(f.frames=u(l)),a&&(f.config=u(t._context,!0)),\"object\"===n?f:JSON.stringify(f)},x.modifyFrames=function(t,e){var r,n,i,a=t._transitionData._frames,o=t._transitionData._frameHash;for(r=0;r<e.length;r++)switch((n=e[r]).type){case\"replace\":i=n.value;var s=(a[n.index]||{}).name,l=i.name;a[n.index]=o[l]=i,l!==s&&(delete o[s],o[l]=i);break;case\"insert\":o[(i=n.value).name]=i,a.splice(n.index,0,i);break;case\"delete\":delete o[(i=a[n.index]).name],a.splice(n.index,1)}return Promise.resolve()},x.computeFrame=function(t,e){var r,n,i,a,o=t._transitionData._frameHash;if(!e)throw new Error(\"computeFrame must be given a string frame name\");var s=o[e.toString()];if(!s)return!1;for(var l=[s],c=[s.name];s.baseframe&&(s=o[s.baseframe.toString()])&&-1===c.indexOf(s.name);)l.push(s),c.push(s.name);for(var u={};s=l.pop();)if(s.layout&&(u.layout=x.extendLayout(u.layout,s.layout)),s.data){if(u.data||(u.data=[]),!(n=s.traces))for(n=[],r=0;r<s.data.length;r++)n[r]=r;for(u.traces||(u.traces=[]),r=0;r<s.data.length;r++)null!=(i=n[r])&&(-1===(a=u.traces.indexOf(i))&&(a=u.data.length,u.traces[a]=i),u.data[a]=x.extendTrace(u.data[a],s.data[r]))}return u},x.recomputeFrameHash=function(t){for(var e=t._transitionData._frameHash={},r=t._transitionData._frames,n=0;n<r.length;n++){var i=r[n];i&&i.name&&(e[i.name]=i)}},x.extendObjectWithContainers=function(t,e,r){var n,i,a,o,s,l,u,f=c.extendDeepNoArrays({},e||{}),h=c.expandObjectPaths(f),p={};if(r&&r.length)for(a=0;a<r.length;a++)void 0===(i=(n=c.nestedProperty(h,r[a])).get())?c.nestedProperty(p,r[a]).set(null):(n.set(null),c.nestedProperty(p,r[a]).set(i));if(t=c.extendDeepNoArrays(t||{},h),r&&r.length)for(a=0;a<r.length;a++)if(l=c.nestedProperty(p,r[a]).get()){for(u=(s=c.nestedProperty(t,r[a])).get(),Array.isArray(u)||(u=[],s.set(u)),o=0;o<l.length;o++){var d=l[o];u[o]=null===d?null:x.extendObjectWithContainers(u[o],d)}s.set(u)}return t},x.dataArrayContainers=[\"transforms\",\"dimensions\"],x.layoutArrayContainers=o.layoutArrayContainers,x.extendTrace=function(t,e){return x.extendObjectWithContainers(t,e,x.dataArrayContainers)},x.extendLayout=function(t,e){return x.extendObjectWithContainers(t,e,x.layoutArrayContainers)},x.transition=function(t,e,r,n,i,a){var o={redraw:i.redraw},s={},l=[];return o.prepareFn=function(){for(var i=Array.isArray(e)?e.length:0,a=n.slice(0,i),o=0;o<a.length;o++){var u=a[o],f=t._fullData[u]._module;if(f){if(f.animatable){var h=f.basePlotModule.name;s[h]||(s[h]=[]),s[h].push(u)}t.data[a[o]]=x.extendTrace(t.data[a[o]],e[o])}}var p=c.expandObjectPaths(c.extendDeepNoArrays({},r)),d=/^[xy]axis[0-9]*$/;for(var m in p)d.test(m)&&delete p[m].range;x.extendLayout(t.layout,p),delete t.calcdata,x.supplyDefaults(t),x.doCalcdata(t);var g=c.expandObjectPaths(r);if(g){var v=t._fullLayout._plots;for(var y in v){var b=v[y],_=b.xaxis,w=b.yaxis,T=_.range.slice(),k=w.range.slice(),M=null,A=null,S=null,E=null;Array.isArray(g[_._name+\".range\"])?M=g[_._name+\".range\"].slice():Array.isArray((g[_._name]||{}).range)&&(M=g[_._name].range.slice()),Array.isArray(g[w._name+\".range\"])?A=g[w._name+\".range\"].slice():Array.isArray((g[w._name]||{}).range)&&(A=g[w._name].range.slice()),T&&M&&(_.r2l(T[0])!==_.r2l(M[0])||_.r2l(T[1])!==_.r2l(M[1]))&&(S={xr0:T,xr1:M}),k&&A&&(w.r2l(k[0])!==w.r2l(A[0])||w.r2l(k[1])!==w.r2l(A[1]))&&(E={yr0:k,yr1:A}),(S||E)&&l.push(c.extendFlat({plotinfo:b},S,E))}}return Promise.resolve()},o.runFn=function(e){var n,i,o=t._fullLayout._basePlotModules,u=l.length;if(r)for(i=0;i<o.length;i++)o[i].transitionAxes&&o[i].transitionAxes(t,l,a,e);for(var f in u?((n=c.extendFlat({},a)).duration=0,delete s.cartesian):n=a,s){var h=s[f];t._fullData[h[0]]._module.basePlotModule.plot(t,h,n,e)}},P(t,a,o)},x.transitionFromReact=function(t,e,r,n){var i=t._fullLayout,a=i.transition,o={},s=[];return o.prepareFn=function(){var t=i._plots;for(var a in o.redraw=!1,\"some\"===e.anim&&(o.redraw=!0),\"some\"===r.anim&&(o.redraw=!0),t){var l=t[a],u=l.xaxis,f=l.yaxis,h=n[u._name].range.slice(),p=n[f._name].range.slice(),d=u.range.slice(),m=f.range.slice();u.setScale(),f.setScale();var g=null,v=null;u.r2l(h[0])===u.r2l(d[0])&&u.r2l(h[1])===u.r2l(d[1])||(g={xr0:h,xr1:d}),f.r2l(p[0])===f.r2l(m[0])&&f.r2l(p[1])===f.r2l(m[1])||(v={yr0:p,yr1:m}),(g||v)&&s.push(c.extendFlat({plotinfo:l},g,v))}return Promise.resolve()},o.runFn=function(r){for(var n,i,o,l=t._fullData,u=t._fullLayout._basePlotModules,f=[],h=0;h<l.length;h++)f.push(h);function p(){if(t._fullLayout)for(var e=0;e<u.length;e++)u[e].transitionAxes&&u[e].transitionAxes(t,s,n,r)}function d(){if(t._fullLayout)for(var e=0;e<u.length;e++)u[e].plot(t,o,i,r)}s.length&&e.anim?\"traces first\"===a.ordering?(n=c.extendFlat({},a,{duration:0}),o=f,i=a,setTimeout(p,a.duration),d()):(n=a,o=null,i=c.extendFlat({},a,{duration:0}),setTimeout(d,n.duration),p()):s.length?(n=a,p()):e.anim&&(o=f,i=a,d())},P(t,a,o)},x.doCalcdata=function(t,e){var r,n,i,a,l=h.list(t),u=t._fullData,p=t._fullLayout,d=new Array(u.length),m=(t.calcdata||[]).slice();for(t.calcdata=d,p._numBoxes=0,p._numViolins=0,p._violinScaleGroupStats={},t._hmpixcount=0,t._hmlumcount=0,p._piecolormap={},p._sunburstcolormap={},p._treemapcolormap={},p._iciclecolormap={},p._funnelareacolormap={},i=0;i<u.length;i++)Array.isArray(e)&&-1===e.indexOf(i)&&(d[i]=m[i]);for(i=0;i<u.length;i++)(r=u[i])._arrayAttrs=s.findArrayAttributes(r),r._extremes={};var g=p._subplots.polar||[];for(i=0;i<g.length;i++)l.push(p[g[i]].radialaxis,p[g[i]].angularaxis);for(var v in p._colorAxes){var y=p[v];!1!==y.cauto&&(delete y.cmin,delete y.cmax)}var x=!1;function _(e){if(r=u[e],n=r._module,!0===r.visible&&r.transforms){if(n&&n.calc){var i=n.calc(t,r);i[0]&&i[0].t&&i[0].t._scene&&delete i[0].t._scene.dirty}for(a=0;a<r.transforms.length;a++){var o=r.transforms[a];(n=b[o.type])&&n.calcTransform&&(r._hasCalcTransform=!0,x=!0,n.calcTransform(t,r,o))}}}function w(e,i){if(r=u[e],!!(n=r._module).isContainer===i){var o=[];if(!0===r.visible&&0!==r._length){delete r._indexToPoints;var s=r.transforms||[];for(a=s.length-1;a>=0;a--)if(s[a].enabled){r._indexToPoints=s[a]._indexToPoints;break}n&&n.calc&&(o=n.calc(t,r))}Array.isArray(o)&&o[0]||(o=[{x:f,y:f}]),o[0].t||(o[0].t={}),o[0].trace=r,d[e]=o}}for(O(l,u,p),i=0;i<u.length;i++)w(i,!0);for(i=0;i<u.length;i++)_(i);for(x&&O(l,u,p),i=0;i<u.length;i++)w(i,!0);for(i=0;i<u.length;i++)w(i,!1);z(t);var T=function(t,e){var r,n,i,a,s,l=[];function u(t,r,n){var i=r._id.charAt(0);if(\"histogram2dcontour\"===t){var a=r._counterAxes[0],o=h.getFromId(e,a),s=\"x\"===i||\"x\"===a&&\"category\"===o.type,l=\"y\"===i||\"y\"===a&&\"category\"===o.type;return function(t,e){return 0===t||0===e||s&&t===n[e].length-1||l&&e===n.length-1?-1:(\"y\"===i?e:t)-1}}return function(t,e){return\"y\"===i?e:t}}var f={min:function(t){return c.aggNums(Math.min,null,t)},max:function(t){return c.aggNums(Math.max,null,t)},sum:function(t){return c.aggNums((function(t,e){return t+e}),null,t)},total:function(t){return c.aggNums((function(t,e){return t+e}),null,t)},mean:function(t){return c.mean(t)},median:function(t){return c.median(t)}};for(r=0;r<t.length;r++){var p=t[r];if(\"category\"===p.type){var d=p.categoryorder.match(I);if(d){var m=d[1],g=d[2],v=p._id.charAt(0),y=\"x\"===v,x=[];for(n=0;n<p._categories.length;n++)x.push([p._categories[n],[]]);for(n=0;n<p._traceIndices.length;n++){var b=p._traceIndices[n],_=e._fullData[b];if(!0===_.visible){var w=_.type;o.traceIs(_,\"histogram\")&&(delete _._xautoBinFinished,delete _._yautoBinFinished);var T=\"splom\"===w,k=\"scattergl\"===w,M=e.calcdata[b];for(i=0;i<M.length;i++){var A,S,E=M[i];if(T){var L=_._axesDim[p._id];if(!y){var C=_._diag[L][0];C&&(p=e._fullLayout[h.id2name(C)])}var P=E.trace.dimensions[L].values;for(a=0;a<P.length;a++)for(A=p._categoriesMap[P[a]],s=0;s<E.trace.dimensions.length;s++)if(s!==L){var O=E.trace.dimensions[s];x[A][1].push(O.values[a])}}else if(k){for(a=0;a<E.t.x.length;a++)y?(A=E.t.x[a],S=E.t.y[a]):(A=E.t.y[a],S=E.t.x[a]),x[A][1].push(S);E.t&&E.t._scene&&delete E.t._scene.dirty}else if(E.hasOwnProperty(\"z\")){S=E.z;var z=u(_.type,p,S);for(a=0;a<S.length;a++)for(s=0;s<S[a].length;s++)(A=z(s,a))+1&&x[A][1].push(S[a][s])}else for(void 0===(A=E.p)&&(A=E[v]),void 0===(S=E.s)&&(S=E.v),void 0===S&&(S=y?E.y:E.x),Array.isArray(S)||(S=void 0===S?[]:[S]),a=0;a<S.length;a++)x[A][1].push(S[a])}}}p._categoriesValue=x;var D=[];for(n=0;n<x.length;n++)D.push([x[n][0],f[m](x[n][1])]);D.sort((function(t,e){return t[1]-e[1]})),p._categoriesAggregatedValue=D,p._initialCategories=D.map((function(t){return t[0]})),\"descending\"===g&&p._initialCategories.reverse(),l=l.concat(p.sortByInitialCategories())}}}return l}(l,t);if(T.length){for(p._numBoxes=0,p._numViolins=0,i=0;i<T.length;i++)w(T[i],!0);for(i=0;i<T.length;i++)w(T[i],!1);z(t)}o.getComponentMethod(\"fx\",\"calc\")(t),o.getComponentMethod(\"errorbars\",\"calc\")(t)};var I=/(total|sum|min|max|mean|median) (ascending|descending)/;function O(t,e,r){var n={};function i(t){t.clearCalc(),\"multicategory\"===t.type&&t.setupMultiCategory(e),n[t._id]=1}c.simpleMap(t,i);for(var a=r._axisMatchGroups||[],o=0;o<a.length;o++)for(var s in a[o])n[s]||i(r[h.id2name(s)])}function z(t){var e,r,n,i=t._fullLayout,a=i._visibleModules,o={};for(r=0;r<a.length;r++){var s=a[r],l=s.crossTraceCalc;if(l){var u=s.basePlotModule.name;o[u]?c.pushUnique(o[u],l):o[u]=[l]}}for(n in o){var f=o[n],h=i._subplots[n];if(Array.isArray(h))for(e=0;e<h.length;e++){var p=h[e],d=\"cartesian\"===n?i._plots[p]:i[p];for(r=0;r<f.length;r++)f[r](t,d,p)}else for(r=0;r<f.length;r++)f[r](t)}}x.rehover=function(t){t._fullLayout._rehover&&t._fullLayout._rehover()},x.redrag=function(t){t._fullLayout._redrag&&t._fullLayout._redrag()},x.generalUpdatePerTraceModule=function(t,e,r,n){var i,a=e.traceHash,o={};for(i=0;i<r.length;i++){var s=r[i],l=s[0].trace;l.visible&&(o[l.type]=o[l.type]||[],o[l.type].push(s))}for(var u in a)if(!o[u]){var f=a[u][0];f[0].trace.visible=!1,o[u]=[f]}for(var h in o){var p=o[h];p[0][0].trace._module.plot(t,e,c.filterVisible(p),n)}e.traceHash=o},x.plotBasePlot=function(t,e,r,n,i){var a=o.getModule(t),s=g(e.calcdata,a)[0];a.plot(e,s,n,i)},x.cleanBasePlot=function(t,e,r,n,i){var a=i._has&&i._has(t),o=r._has&&r._has(t);a&&!o&&i[\"_\"+t+\"layer\"].selectAll(\"g.trace\").remove()}},{\"../components/color\":662,\"../constants/numerical\":775,\"../lib\":799,\"../plot_api/plot_schema\":837,\"../plot_api/plot_template\":838,\"../plots/get_data\":887,\"../registry\":927,\"./animation_attributes\":843,\"./attributes\":845,\"./cartesian/axis_ids\":853,\"./cartesian/handle_outline\":860,\"./command\":876,\"./font_attributes\":878,\"./frame_attributes\":879,\"./layout_attributes\":904,\"@plotly/d3\":58,\"d3-time-format\":172,\"fast-isnumeric\":245}],914:[function(t,e,r){\"use strict\";e.exports={attr:\"subplot\",name:\"polar\",axisNames:[\"angularaxis\",\"radialaxis\"],axisName2dataArray:{angularaxis:\"theta\",radialaxis:\"r\"},layerNames:[\"draglayer\",\"plotbg\",\"backplot\",\"angular-grid\",\"radial-grid\",\"frontplot\",\"angular-line\",\"radial-line\",\"angular-axis\",\"radial-axis\"],radialDragBoxSize:50,angularDragBoxSize:30,cornerLen:25,cornerHalfWidth:2,MINDRAG:8,MINZOOM:20,OFFEDGE:20}},{}],915:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../lib/polygon\").tester,a=n.findIndexOfMin,o=n.isAngleInsideSector,s=n.angleDelta,l=n.angleDist;function c(t,e,r,n){var i,a,o=n[0],s=n[1],l=f(Math.sin(e)-Math.sin(t)),c=f(Math.cos(e)-Math.cos(t)),u=Math.tan(r),h=f(1/u),p=l/c,d=s-p*o;return h?l&&c?a=u*(i=d/(u-p)):c?(i=s*h,a=s):(i=o,a=o*u):l&&c?(i=0,a=d):c?(i=0,a=s):i=a=NaN,[i,a]}function u(t,e,r,i){return n.isFullCircle([e,r])?function(t,e){var r,n=e.length,i=new Array(n+1);for(r=0;r<n;r++){var a=e[r];i[r]=[t*Math.cos(a),t*Math.sin(a)]}return i[r]=i[0].slice(),i}(t,i):function(t,e,r,i){var s,u,f=i.length,h=[];function p(e){return[t*Math.cos(e),t*Math.sin(e)]}function d(t,e,r){return c(t,e,r,p(t))}function m(t){return n.mod(t,f)}function g(t){return o(t,[e,r])}var v=a(i,(function(t){return g(t)?l(t,e):1/0})),y=d(i[v],i[m(v-1)],e);for(h.push(y),s=v,u=0;u<f;s++,u++){var x=i[m(s)];if(!g(x))break;h.push(p(x))}var b=a(i,(function(t){return g(t)?l(t,r):1/0})),_=d(i[b],i[m(b+1)],r);return h.push(_),h.push([0,0]),h.push(h[0].slice()),h}(t,e,r,i)}function f(t){return Math.abs(t)>1e-10?t:0}function h(t,e,r){e=e||0,r=r||0;for(var n=t.length,i=new Array(n),a=0;a<n;a++){var o=t[a];i[a]=[e+o[0],r-o[1]]}return i}e.exports={isPtInsidePolygon:function(t,e,r,n,a){if(!o(e,n))return!1;var s,l;r[0]<r[1]?(s=r[0],l=r[1]):(s=r[1],l=r[0]);var c=i(u(s,n[0],n[1],a)),f=i(u(l,n[0],n[1],a)),h=[t*Math.cos(e),t*Math.sin(e)];return f.contains(h)&&!c.contains(h)},findPolygonOffset:function(t,e,r,n){for(var i=1/0,a=1/0,o=u(t,e,r,n),s=0;s<o.length;s++){var l=o[s];i=Math.min(i,l[0]),a=Math.min(a,-l[1])}return[i,a]},findEnclosingVertexAngles:function(t,e){var r=a(e,(function(e){var r=s(e,t);return r>0?r:1/0})),i=n.mod(r+1,e.length);return[e[r],e[i]]},findIntersectionXY:c,findXYatLength:function(t,e,r,n){var i=-e*r,a=e*e+1,o=2*(e*i-r),s=i*i+r*r-t*t,l=Math.sqrt(o*o-4*a*s),c=(-o+l)/(2*a),u=(-o-l)/(2*a);return[[c,e*c+i+n],[u,e*u+i+n]]},clampTiny:f,pathPolygon:function(t,e,r,n,i,a){return\"M\"+h(u(t,e,r,n),i,a).join(\"L\")},pathPolygonAnnulus:function(t,e,r,n,i,a,o){var s,l;t<e?(s=t,l=e):(s=e,l=t);var c=h(u(s,r,n,i),a,o);return\"M\"+h(u(l,r,n,i),a,o).reverse().join(\"L\")+\"M\"+c.join(\"L\")}}},{\"../../lib\":799,\"../../lib/polygon\":811}],916:[function(t,e,r){\"use strict\";var n=t(\"../get_data\").getSubplotCalcData,i=t(\"../../lib\").counterRegex,a=t(\"./polar\"),o=t(\"./constants\"),s=o.attr,l=o.name,c=i(l),u={};u[s]={valType:\"subplotid\",dflt:l,editType:\"calc\"},e.exports={attr:s,name:l,idRoot:l,idRegex:c,attrRegex:c,attributes:u,layoutAttributes:t(\"./layout_attributes\"),supplyLayoutDefaults:t(\"./layout_defaults\"),plot:function(t){for(var e=t._fullLayout,r=t.calcdata,i=e._subplots[l],o=0;o<i.length;o++){var s=i[o],c=n(r,l,s),u=e[s]._subplot;u||(u=a(t,s),e[s]._subplot=u),u.plot(c,e,t._promises)}},clean:function(t,e,r,n){for(var i=n._subplots[l]||[],a=n._has&&n._has(\"gl\"),o=e._has&&e._has(\"gl\"),s=a&&!o,c=0;c<i.length;c++){var u=i[c],f=n[u]._subplot;if(!e[u]&&f)for(var h in f.framework.remove(),f.layers[\"radial-axis-title\"].remove(),f.clipPaths)f.clipPaths[h].remove();s&&f._scene&&(f._scene.destroy(),f._scene=null)}},toSVG:t(\"../cartesian\").toSVG}},{\"../../lib\":799,\"../cartesian\":863,\"../get_data\":887,\"./constants\":914,\"./layout_attributes\":917,\"./layout_defaults\":918,\"./polar\":919}],917:[function(t,e,r){\"use strict\";var n=t(\"../../components/color/attributes\"),i=t(\"../cartesian/layout_attributes\"),a=t(\"../domain\").attributes,o=t(\"../../lib\").extendFlat,s=t(\"../../plot_api/edit_types\").overrideAll,l=s({color:i.color,showline:o({},i.showline,{dflt:!0}),linecolor:i.linecolor,linewidth:i.linewidth,showgrid:o({},i.showgrid,{dflt:!0}),gridcolor:i.gridcolor,gridwidth:i.gridwidth},\"plot\",\"from-root\"),c=s({tickmode:i.tickmode,nticks:i.nticks,tick0:i.tick0,dtick:i.dtick,tickvals:i.tickvals,ticktext:i.ticktext,ticks:i.ticks,ticklen:i.ticklen,tickwidth:i.tickwidth,tickcolor:i.tickcolor,showticklabels:i.showticklabels,showtickprefix:i.showtickprefix,tickprefix:i.tickprefix,showticksuffix:i.showticksuffix,ticksuffix:i.ticksuffix,showexponent:i.showexponent,exponentformat:i.exponentformat,minexponent:i.minexponent,separatethousands:i.separatethousands,tickfont:i.tickfont,tickangle:i.tickangle,tickformat:i.tickformat,tickformatstops:i.tickformatstops,layer:i.layer},\"plot\",\"from-root\"),u={visible:o({},i.visible,{dflt:!0}),type:o({},i.type,{values:[\"-\",\"linear\",\"log\",\"date\",\"category\"]}),autotypenumbers:i.autotypenumbers,autorange:o({},i.autorange,{editType:\"plot\"}),rangemode:{valType:\"enumerated\",values:[\"tozero\",\"nonnegative\",\"normal\"],dflt:\"tozero\",editType:\"calc\"},range:o({},i.range,{items:[{valType:\"any\",editType:\"plot\",impliedEdits:{\"^autorange\":!1}},{valType:\"any\",editType:\"plot\",impliedEdits:{\"^autorange\":!1}}],editType:\"plot\"}),categoryorder:i.categoryorder,categoryarray:i.categoryarray,angle:{valType:\"angle\",editType:\"plot\"},side:{valType:\"enumerated\",values:[\"clockwise\",\"counterclockwise\"],dflt:\"clockwise\",editType:\"plot\"},title:{text:o({},i.title.text,{editType:\"plot\",dflt:\"\"}),font:o({},i.title.font,{editType:\"plot\"}),editType:\"plot\"},hoverformat:i.hoverformat,uirevision:{valType:\"any\",editType:\"none\"},editType:\"calc\",_deprecated:{title:i._deprecated.title,titlefont:i._deprecated.titlefont}};o(u,l,c);var f={visible:o({},i.visible,{dflt:!0}),type:{valType:\"enumerated\",values:[\"-\",\"linear\",\"category\"],dflt:\"-\",editType:\"calc\",_noTemplating:!0},autotypenumbers:i.autotypenumbers,categoryorder:i.categoryorder,categoryarray:i.categoryarray,thetaunit:{valType:\"enumerated\",values:[\"radians\",\"degrees\"],dflt:\"degrees\",editType:\"calc\"},period:{valType:\"number\",editType:\"calc\",min:0},direction:{valType:\"enumerated\",values:[\"counterclockwise\",\"clockwise\"],dflt:\"counterclockwise\",editType:\"calc\"},rotation:{valType:\"angle\",editType:\"calc\"},hoverformat:i.hoverformat,uirevision:{valType:\"any\",editType:\"none\"},editType:\"calc\"};o(f,l,c),e.exports={domain:a({name:\"polar\",editType:\"plot\"}),sector:{valType:\"info_array\",items:[{valType:\"number\",editType:\"plot\"},{valType:\"number\",editType:\"plot\"}],dflt:[0,360],editType:\"plot\"},hole:{valType:\"number\",min:0,max:1,dflt:0,editType:\"plot\"},bgcolor:{valType:\"color\",editType:\"plot\",dflt:n.background},radialaxis:u,angularaxis:f,gridshape:{valType:\"enumerated\",values:[\"circular\",\"linear\"],dflt:\"circular\",editType:\"plot\"},uirevision:{valType:\"any\",editType:\"none\"},editType:\"calc\"}},{\"../../components/color/attributes\":661,\"../../lib\":799,\"../../plot_api/edit_types\":831,\"../cartesian/layout_attributes\":864,\"../domain\":877}],918:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/color\"),a=t(\"../../plot_api/plot_template\"),o=t(\"../subplot_defaults\"),s=t(\"../get_data\").getSubplotData,l=t(\"../cartesian/tick_value_defaults\"),c=t(\"../cartesian/tick_mark_defaults\"),u=t(\"../cartesian/tick_label_defaults\"),f=t(\"../cartesian/category_order_defaults\"),h=t(\"../cartesian/line_grid_defaults\"),p=t(\"../cartesian/axis_autotype\"),d=t(\"./layout_attributes\"),m=t(\"./set_convert\"),g=t(\"./constants\"),v=g.axisNames;function y(t,e,r,o){var p=r(\"bgcolor\");o.bgColor=i.combine(p,o.paper_bgcolor);var y=r(\"sector\");r(\"hole\");var b,_=s(o.fullData,g.name,o.id),w=o.layoutOut;function T(t,e){return r(b+\".\"+t,e)}for(var k=0;k<v.length;k++){b=v[k],n.isPlainObject(t[b])||(t[b]={});var M=t[b],A=a.newContainer(e,b);A._id=A._name=b,A._attr=o.id+\".\"+b,A._traceIndices=_.map((function(t){return t._expandedIndex}));var S=g.axisName2dataArray[b],E=x(M,A,T,_,S,o);f(M,A,T,{axData:_,dataAttr:S});var L,C,P=T(\"visible\");switch(m(A,e,w),T(\"uirevision\",e.uirevision),P&&(C=(L=T(\"color\"))===M.color?L:o.font.color),A._m=1,b){case\"radialaxis\":var I=T(\"autorange\",!A.isValidRange(M.range));M.autorange=I,!I||\"linear\"!==E&&\"-\"!==E||T(\"rangemode\"),\"reversed\"===I&&(A._m=-1),T(\"range\"),A.cleanRange(\"range\",{dfltRange:[0,1]}),P&&(T(\"side\"),T(\"angle\",y[0]),T(\"title.text\"),n.coerceFont(T,\"title.font\",{family:o.font.family,size:n.bigFont(o.font.size),color:C}));break;case\"angularaxis\":if(\"date\"===E){n.log(\"Polar plots do not support date angular axes yet.\");for(var O=0;O<_.length;O++)_[O].visible=!1;E=M.type=A.type=\"linear\"}T(\"linear\"===E?\"thetaunit\":\"period\");var z=T(\"direction\");T(\"rotation\",{counterclockwise:0,clockwise:90}[z])}if(P)l(M,A,T,A.type),u(M,A,T,A.type,{tickSuffixDflt:\"degrees\"===A.thetaunit?\"\\xb0\":void 0}),c(M,A,T,{outerTicks:!0}),T(\"showticklabels\")&&(n.coerceFont(T,\"tickfont\",{family:o.font.family,size:o.font.size,color:C}),T(\"tickangle\"),T(\"tickformat\")),h(M,A,T,{dfltColor:L,bgColor:o.bgColor,blend:60,showLine:!0,showGrid:!0,noZeroLine:!0,attributes:d[b]}),T(\"layer\");\"category\"!==E&&T(\"hoverformat\"),A._input=M}\"category\"===e.angularaxis.type&&r(\"gridshape\")}function x(t,e,r,n,i,a){var o=r(\"autotypenumbers\",a.autotypenumbersDflt);if(\"-\"===r(\"type\")){for(var s,l=0;l<n.length;l++)if(n[l].visible){s=n[l];break}s&&s[i]&&(e.type=p(s[i],\"gregorian\",{noMultiCategory:!0,autotypenumbers:o})),\"-\"===e.type?e.type=\"linear\":t.type=e.type}return e.type}e.exports=function(t,e,r){o(t,e,r,{type:g.name,attributes:d,handleDefaults:y,font:e.font,autotypenumbersDflt:e.autotypenumbers,paper_bgcolor:e.paper_bgcolor,fullData:r,layoutOut:e})}},{\"../../components/color\":662,\"../../lib\":799,\"../../plot_api/plot_template\":838,\"../cartesian/axis_autotype\":850,\"../cartesian/category_order_defaults\":854,\"../cartesian/line_grid_defaults\":866,\"../cartesian/tick_label_defaults\":871,\"../cartesian/tick_mark_defaults\":872,\"../cartesian/tick_value_defaults\":873,\"../get_data\":887,\"../subplot_defaults\":921,\"./constants\":914,\"./layout_attributes\":917,\"./set_convert\":920}],919:[function(t,e,r){\"use strict\";var n=t(\"@plotly/d3\"),i=t(\"tinycolor2\"),a=t(\"../../registry\"),o=t(\"../../lib\"),s=o.strRotate,l=o.strTranslate,c=t(\"../../components/color\"),u=t(\"../../components/drawing\"),f=t(\"../plots\"),h=t(\"../../plots/cartesian/axes\"),p=t(\"../cartesian/set_convert\"),d=t(\"./set_convert\"),m=t(\"../cartesian/autorange\").doAutoRange,g=t(\"../cartesian/dragbox\"),v=t(\"../../components/dragelement\"),y=t(\"../../components/fx\"),x=t(\"../../components/titles\"),b=t(\"../cartesian/select\").prepSelect,_=t(\"../cartesian/select\").selectOnClick,w=t(\"../cartesian/select\").clearSelect,T=t(\"../../lib/setcursor\"),k=t(\"../../lib/clear_gl_canvases\"),M=t(\"../../plot_api/subroutines\").redrawReglTraces,A=t(\"../../constants/alignment\").MID_SHIFT,S=t(\"./constants\"),E=t(\"./helpers\"),L=o._,C=o.mod,P=o.deg2rad,I=o.rad2deg;function O(t,e){this.id=e,this.gd=t,this._hasClipOnAxisFalse=null,this.vangles=null,this.radialAxisAngle=null,this.traceHash={},this.layers={},this.clipPaths={},this.clipIds={},this.viewInitial={};var r=t._fullLayout,n=\"clip\"+r._uid+e;this.clipIds.forTraces=n+\"-for-traces\",this.clipPaths.forTraces=r._clips.append(\"clipPath\").attr(\"id\",this.clipIds.forTraces),this.clipPaths.forTraces.append(\"path\"),this.framework=r._polarlayer.append(\"g\").attr(\"class\",e),this.radialTickLayout=null,this.angularTickLayout=null}var z=O.prototype;function D(t){var e=t.ticks+String(t.ticklen)+String(t.showticklabels);return\"side\"in t&&(e+=t.side),e}function R(t,e){return e[o.findIndexOfMin(e,(function(e){return o.angleDist(t,e)}))]}function F(t,e,r){return e?(t.attr(\"display\",null),t.attr(r)):t&&t.attr(\"display\",\"none\"),t}e.exports=function(t,e){return new O(t,e)},z.plot=function(t,e){var r=e[this.id];this._hasClipOnAxisFalse=!1;for(var n=0;n<t.length;n++){if(!1===t[n][0].trace.cliponaxis){this._hasClipOnAxisFalse=!0;break}}this.updateLayers(e,r),this.updateLayout(e,r),f.generalUpdatePerTraceModule(this.gd,this,t,r),this.updateFx(e,r)},z.updateLayers=function(t,e){var r=this.layers,i=e.radialaxis,a=e.angularaxis,o=S.layerNames,s=o.indexOf(\"frontplot\"),l=o.slice(0,s),c=\"below traces\"===a.layer,u=\"below traces\"===i.layer;c&&l.push(\"angular-line\"),u&&l.push(\"radial-line\"),c&&l.push(\"angular-axis\"),u&&l.push(\"radial-axis\"),l.push(\"frontplot\"),c||l.push(\"angular-line\"),u||l.push(\"radial-line\"),c||l.push(\"angular-axis\"),u||l.push(\"radial-axis\");var f=this.framework.selectAll(\".polarsublayer\").data(l,String);f.enter().append(\"g\").attr(\"class\",(function(t){return\"polarsublayer \"+t})).each((function(t){var e=r[t]=n.select(this);switch(t){case\"frontplot\":e.append(\"g\").classed(\"barlayer\",!0),e.append(\"g\").classed(\"scatterlayer\",!0);break;case\"backplot\":e.append(\"g\").classed(\"maplayer\",!0);break;case\"plotbg\":r.bg=e.append(\"path\");break;case\"radial-grid\":case\"angular-grid\":e.style(\"fill\",\"none\");break;case\"radial-line\":e.append(\"line\").style(\"fill\",\"none\");break;case\"angular-line\":e.append(\"path\").style(\"fill\",\"none\")}})),f.order()},z.updateLayout=function(t,e){var r=this.layers,n=t._size,i=e.radialaxis,a=e.angularaxis,o=e.domain.x,s=e.domain.y;this.xOffset=n.l+n.w*o[0],this.yOffset=n.t+n.h*(1-s[1]);var f=this.xLength=n.w*(o[1]-o[0]),h=this.yLength=n.h*(s[1]-s[0]),p=e.sector;this.sectorInRad=p.map(P);var d,m,g,v,y,x=this.sectorBBox=function(t){var e,r,n,i,a=t[0],o=t[1]-a,s=C(a,360),l=s+o,c=Math.cos(P(s)),u=Math.sin(P(s)),f=Math.cos(P(l)),h=Math.sin(P(l));i=s<=90&&l>=90||s>90&&l>=450?1:u<=0&&h<=0?0:Math.max(u,h);e=s<=180&&l>=180||s>180&&l>=540?-1:c>=0&&f>=0?0:Math.min(c,f);r=s<=270&&l>=270||s>270&&l>=630?-1:u>=0&&h>=0?0:Math.min(u,h);n=l>=360?1:c<=0&&f<=0?0:Math.max(c,f);return[e,r,n,i]}(p),b=x[2]-x[0],_=x[3]-x[1],w=h/f,T=Math.abs(_/b);w>T?(d=f,y=(h-(m=f*T))/n.h/2,g=[o[0],o[1]],v=[s[0]+y,s[1]-y]):(m=h,y=(f-(d=h/T))/n.w/2,g=[o[0]+y,o[1]-y],v=[s[0],s[1]]),this.xLength2=d,this.yLength2=m,this.xDomain2=g,this.yDomain2=v;var k=this.xOffset2=n.l+n.w*g[0],M=this.yOffset2=n.t+n.h*(1-v[1]),A=this.radius=d/b,S=this.innerRadius=e.hole*A,E=this.cx=k-A*x[0],L=this.cy=M+A*x[3],I=this.cxx=E-k,O=this.cyy=L-M;this.radialAxis=this.mockAxis(t,e,i,{_id:\"x\",side:{counterclockwise:\"top\",clockwise:\"bottom\"}[i.side],_realSide:i.side,domain:[S/n.w,A/n.w]}),this.angularAxis=this.mockAxis(t,e,a,{side:\"right\",domain:[0,Math.PI],autorange:!1}),this.doAutoRange(t,e),this.updateAngularAxis(t,e),this.updateRadialAxis(t,e),this.updateRadialAxisTitle(t,e),this.xaxis=this.mockCartesianAxis(t,e,{_id:\"x\",domain:g}),this.yaxis=this.mockCartesianAxis(t,e,{_id:\"y\",domain:v});var z=this.pathSubplot();this.clipPaths.forTraces.select(\"path\").attr(\"d\",z).attr(\"transform\",l(I,O)),r.frontplot.attr(\"transform\",l(k,M)).call(u.setClipUrl,this._hasClipOnAxisFalse?null:this.clipIds.forTraces,this.gd),r.bg.attr(\"d\",z).attr(\"transform\",l(E,L)).call(c.fill,e.bgcolor)},z.mockAxis=function(t,e,r,n){var i=o.extendFlat({},r,n);return d(i,e,t),i},z.mockCartesianAxis=function(t,e,r){var n=this,i=r._id,a=o.extendFlat({type:\"linear\"},r);p(a,t);var s={x:[0,2],y:[1,3]};return a.setRange=function(){var t=n.sectorBBox,r=s[i],o=n.radialAxis._rl,l=(o[1]-o[0])/(1-e.hole);a.range=[t[r[0]]*l,t[r[1]]*l]},a.isPtWithinRange=\"x\"===i?function(t){return n.isPtInside(t)}:function(){return!0},a.setRange(),a.setScale(),a},z.doAutoRange=function(t,e){var r=this.gd,n=this.radialAxis,i=e.radialaxis;n.setScale(),m(r,n);var a=n.range;i.range=a.slice(),i._input.range=a.slice(),n._rl=[n.r2l(a[0],null,\"gregorian\"),n.r2l(a[1],null,\"gregorian\")]},z.updateRadialAxis=function(t,e){var r=this,n=r.gd,i=r.layers,a=r.radius,u=r.innerRadius,f=r.cx,p=r.cy,d=e.radialaxis,m=C(e.sector[0],360),g=r.radialAxis,v=u<a;r.fillViewInitialKey(\"radialaxis.angle\",d.angle),r.fillViewInitialKey(\"radialaxis.range\",g.range.slice()),g.setGeometry(),\"auto\"===g.tickangle&&m>90&&m<=270&&(g.tickangle=180);var y=function(t){return l(g.l2p(t.x)+u,0)},x=D(d);if(r.radialTickLayout!==x&&(i[\"radial-axis\"].selectAll(\".xtick\").remove(),r.radialTickLayout=x),v){g.setScale();var b=h.calcTicks(g),_=h.clipEnds(g,b),w=h.getTickSigns(g)[2];h.drawTicks(n,g,{vals:b,layer:i[\"radial-axis\"],path:h.makeTickPath(g,0,w),transFn:y,crisp:!1}),h.drawGrid(n,g,{vals:_,layer:i[\"radial-grid\"],path:function(t){return r.pathArc(g.r2p(t.x)+u)},transFn:o.noop,crisp:!1}),h.drawLabels(n,g,{vals:b,layer:i[\"radial-axis\"],transFn:y,labelFns:h.makeLabelFns(g,0)})}var T=r.radialAxisAngle=r.vangles?I(R(P(d.angle),r.vangles)):d.angle,k=l(f,p),M=k+s(-T);F(i[\"radial-axis\"],v&&(d.showticklabels||d.ticks),{transform:M}),F(i[\"radial-grid\"],v&&d.showgrid,{transform:k}),F(i[\"radial-line\"].select(\"line\"),v&&d.showline,{x1:u,y1:0,x2:a,y2:0,transform:M}).attr(\"stroke-width\",d.linewidth).call(c.stroke,d.linecolor)},z.updateRadialAxisTitle=function(t,e,r){var n=this.gd,i=this.radius,a=this.cx,o=this.cy,s=e.radialaxis,l=this.id+\"title\",c=void 0!==r?r:this.radialAxisAngle,f=P(c),h=Math.cos(f),p=Math.sin(f),d=0;if(s.title){var m=u.bBox(this.layers[\"radial-axis\"].node()).height,g=s.title.font.size;d=\"counterclockwise\"===s.side?-m-.4*g:m+.8*g}this.layers[\"radial-axis-title\"]=x.draw(n,l,{propContainer:s,propName:this.id+\".radialaxis.title\",placeholder:L(n,\"Click to enter radial axis title\"),attributes:{x:a+i/2*h+d*p,y:o-i/2*p+d*h,\"text-anchor\":\"middle\"},transform:{rotate:-c}})},z.updateAngularAxis=function(t,e){var r=this,n=r.gd,i=r.layers,a=r.radius,u=r.innerRadius,f=r.cx,p=r.cy,d=e.angularaxis,m=r.angularAxis;r.fillViewInitialKey(\"angularaxis.rotation\",d.rotation),m.setGeometry(),m.setScale();var g=function(t){return m.t2g(t.x)};\"linear\"===m.type&&\"radians\"===m.thetaunit&&(m.tick0=I(m.tick0),m.dtick=I(m.dtick));var v=function(t){return l(f+a*Math.cos(t),p-a*Math.sin(t))},y=h.makeLabelFns(m,0).labelStandoff,x={xFn:function(t){var e=g(t);return Math.cos(e)*y},yFn:function(t){var e=g(t),r=Math.sin(e)>0?.2:1;return-Math.sin(e)*(y+t.fontSize*r)+Math.abs(Math.cos(e))*(t.fontSize*A)},anchorFn:function(t){var e=g(t),r=Math.cos(e);return Math.abs(r)<.1?\"middle\":r>0?\"start\":\"end\"},heightFn:function(t,e,r){var n=g(t);return-.5*(1+Math.sin(n))*r}},b=D(d);r.angularTickLayout!==b&&(i[\"angular-axis\"].selectAll(\".\"+m._id+\"tick\").remove(),r.angularTickLayout=b);var _,w=h.calcTicks(m);if(\"linear\"===e.gridshape?(_=w.map(g),o.angleDelta(_[0],_[1])<0&&(_=_.slice().reverse())):_=null,r.vangles=_,\"category\"===m.type&&(w=w.filter((function(t){return o.isAngleInsideSector(g(t),r.sectorInRad)}))),m.visible){var T=\"inside\"===m.ticks?-1:1,k=(m.linewidth||1)/2;h.drawTicks(n,m,{vals:w,layer:i[\"angular-axis\"],path:\"M\"+T*k+\",0h\"+T*m.ticklen,transFn:function(t){var e=g(t);return v(e)+s(-I(e))},crisp:!1}),h.drawGrid(n,m,{vals:w,layer:i[\"angular-grid\"],path:function(t){var e=g(t),r=Math.cos(e),n=Math.sin(e);return\"M\"+[f+u*r,p-u*n]+\"L\"+[f+a*r,p-a*n]},transFn:o.noop,crisp:!1}),h.drawLabels(n,m,{vals:w,layer:i[\"angular-axis\"],repositionOnUpdate:!0,transFn:function(t){return v(g(t))},labelFns:x})}F(i[\"angular-line\"].select(\"path\"),d.showline,{d:r.pathSubplot(),transform:l(f,p)}).attr(\"stroke-width\",d.linewidth).call(c.stroke,d.linecolor)},z.updateFx=function(t,e){this.gd._context.staticPlot||(this.updateAngularDrag(t),this.updateRadialDrag(t,e,0),this.updateRadialDrag(t,e,1),this.updateMainDrag(t))},z.updateMainDrag=function(t){var e,r,s=this,c=s.gd,u=s.layers,f=t._zoomlayer,h=S.MINZOOM,p=S.OFFEDGE,d=s.radius,m=s.innerRadius,x=s.cx,T=s.cy,k=s.cxx,M=s.cyy,A=s.sectorInRad,L=s.vangles,C=s.radialAxis,P=E.clampTiny,I=E.findXYatLength,O=E.findEnclosingVertexAngles,z=S.cornerHalfWidth,D=S.cornerLen/2,R=g.makeDragger(u,\"path\",\"maindrag\",\"crosshair\");n.select(R).attr(\"d\",s.pathSubplot()).attr(\"transform\",l(x,T));var F,B,N,j,U,V,q,H,G,Y={element:R,gd:c,subplot:s.id,plotinfo:{id:s.id,xaxis:s.xaxis,yaxis:s.yaxis},xaxes:[s.xaxis],yaxes:[s.yaxis]};function W(t,e){return Math.sqrt(t*t+e*e)}function X(t,e){return W(t-k,e-M)}function Z(t,e){return Math.atan2(M-e,t-k)}function J(t,e){return[t*Math.cos(e),t*Math.sin(-e)]}function K(t,e){if(0===t)return s.pathSector(2*z);var r=D/t,n=e-r,i=e+r,a=Math.max(0,Math.min(t,d)),o=a-z,l=a+z;return\"M\"+J(o,n)+\"A\"+[o,o]+\" 0,0,0 \"+J(o,i)+\"L\"+J(l,i)+\"A\"+[l,l]+\" 0,0,1 \"+J(l,n)+\"Z\"}function Q(t,e,r){if(0===t)return s.pathSector(2*z);var n,i,a=J(t,e),o=J(t,r),l=P((a[0]+o[0])/2),c=P((a[1]+o[1])/2);if(l&&c){var u=c/l,f=-1/u,h=I(z,u,l,c);n=I(D,f,h[0][0],h[0][1]),i=I(D,f,h[1][0],h[1][1])}else{var p,d;c?(p=D,d=z):(p=z,d=D),n=[[l-p,c-d],[l+p,c-d]],i=[[l-p,c+d],[l+p,c+d]]}return\"M\"+n.join(\"L\")+\"L\"+i.reverse().join(\"L\")+\"Z\"}function $(t,e){return e=Math.max(Math.min(e,d),m),t<p?t=0:d-t<p?t=d:e<p?e=0:d-e<p&&(e=d),Math.abs(e-t)>h?(t<e?(N=t,j=e):(N=e,j=t),!0):(N=null,j=null,!1)}function tt(t,e){t=t||U,e=e||\"M0,0Z\",H.attr(\"d\",t),G.attr(\"d\",e),g.transitionZoombox(H,G,V,q),V=!0;var r={};at(r),c.emit(\"plotly_relayouting\",r)}function et(t,n){var i,a,o=F+(t*=e),l=B+(n*=r),c=X(F,B),u=Math.min(X(o,l),d),f=Z(F,B);$(c,u)&&(i=U+s.pathSector(j),N&&(i+=s.pathSector(N)),a=K(N,f)+K(j,f)),tt(i,a)}function rt(t,e,r,n){var i=E.findIntersectionXY(r,n,r,[t-k,M-e]);return W(i[0],i[1])}function nt(t,e){var r,n,i=F+t,a=B+e,o=Z(F,B),l=Z(i,a),c=O(o,L),u=O(l,L);$(rt(F,B,c[0],c[1]),Math.min(rt(i,a,u[0],u[1]),d))&&(r=U+s.pathSector(j),N&&(r+=s.pathSector(N)),n=[Q(N,c[0],c[1]),Q(j,c[0],c[1])].join(\" \")),tt(r,n)}function it(){if(g.removeZoombox(c),null!==N&&null!==j){var t={};at(t),g.showDoubleClickNotifier(c),a.call(\"_guiRelayout\",c,t)}}function at(t){var e=C._rl,r=(e[1]-e[0])/(1-m/d)/d,n=[e[0]+(N-m)*r,e[0]+(j-m)*r];t[s.id+\".radialaxis.range\"]=n}function ot(t,e){var r=c._fullLayout.clickmode;if(g.removeZoombox(c),2===t){var n={};for(var i in s.viewInitial)n[s.id+\".\"+i]=s.viewInitial[i];c.emit(\"plotly_doubleclick\",null),a.call(\"_guiRelayout\",c,n)}r.indexOf(\"select\")>-1&&1===t&&_(e,c,[s.xaxis],[s.yaxis],s.id,Y),r.indexOf(\"event\")>-1&&y.click(c,e,s.id)}Y.prepFn=function(t,n,a){var l=c._fullLayout.dragmode,u=R.getBoundingClientRect();c._fullLayout._calcInverseTransform(c);var h=c._fullLayout._invTransform;e=c._fullLayout._invScaleX,r=c._fullLayout._invScaleY;var p=o.apply3DTransform(h)(n-u.left,a-u.top);if(F=p[0],B=p[1],L){var m=E.findPolygonOffset(d,A[0],A[1],L);F+=k+m[0],B+=M+m[1]}switch(l){case\"zoom\":Y.moveFn=L?nt:et,Y.clickFn=ot,Y.doneFn=it,function(){N=null,j=null,U=s.pathSubplot(),V=!1;var t=c._fullLayout[s.id];q=i(t.bgcolor).getLuminance(),(H=g.makeZoombox(f,q,x,T,U)).attr(\"fill-rule\",\"evenodd\"),G=g.makeCorners(f,x,T),w(c)}();break;case\"select\":case\"lasso\":b(t,n,a,Y,l)}},R.onmousemove=function(t){y.hover(c,t,s.id),c._fullLayout._lasthover=R,c._fullLayout._hoversubplot=s.id},R.onmouseout=function(t){c._dragging||v.unhover(c,t)},v.init(Y)},z.updateRadialDrag=function(t,e,r){var i=this,c=i.gd,u=i.layers,f=i.radius,h=i.innerRadius,p=i.cx,d=i.cy,m=i.radialAxis,y=S.radialDragBoxSize,x=y/2;if(m.visible){var b,_,T,A=P(i.radialAxisAngle),E=m._rl,L=E[0],C=E[1],O=E[r],z=.75*(E[1]-E[0])/(1-e.hole)/f;r?(b=p+(f+x)*Math.cos(A),_=d-(f+x)*Math.sin(A),T=\"radialdrag\"):(b=p+(h-x)*Math.cos(A),_=d-(h-x)*Math.sin(A),T=\"radialdrag-inner\");var D,B,N,j=g.makeRectDragger(u,T,\"crosshair\",-x,-x,y,y),U={element:j,gd:c};F(n.select(j),m.visible&&h<f,{transform:l(b,_)}),U.prepFn=function(){D=null,B=null,N=null,U.moveFn=V,U.doneFn=q,w(c)},U.clampFn=function(t,e){return Math.sqrt(t*t+e*e)<S.MINDRAG&&(t=0,e=0),[t,e]},v.init(U)}function V(t,e){if(D)D(t,e);else{var n=[t,-e],a=[Math.cos(A),Math.sin(A)],s=Math.abs(o.dot(n,a)/Math.sqrt(o.dot(n,n)));isNaN(s)||(D=s<.5?H:G)}var l={};!function(t){null!==B?t[i.id+\".radialaxis.angle\"]=B:null!==N&&(t[i.id+\".radialaxis.range[\"+r+\"]\"]=N)}(l),c.emit(\"plotly_relayouting\",l)}function q(){null!==B?a.call(\"_guiRelayout\",c,i.id+\".radialaxis.angle\",B):null!==N&&a.call(\"_guiRelayout\",c,i.id+\".radialaxis.range[\"+r+\"]\",N)}function H(t,e){if(0!==r){var n=b+t,a=_+e;B=Math.atan2(d-a,n-p),i.vangles&&(B=R(B,i.vangles)),B=I(B);var o=l(p,d)+s(-B);u[\"radial-axis\"].attr(\"transform\",o),u[\"radial-line\"].select(\"line\").attr(\"transform\",o);var c=i.gd._fullLayout,f=c[i.id];i.updateRadialAxisTitle(c,f,B)}}function G(t,e){var n=o.dot([t,-e],[Math.cos(A),Math.sin(A)]);if(N=O-z*n,z>0==(r?N>L:N<C)){var s=c._fullLayout,l=s[i.id];m.range[r]=N,m._rl[r]=N,i.updateRadialAxis(s,l),i.xaxis.setRange(),i.xaxis.setScale(),i.yaxis.setRange(),i.yaxis.setScale();var u=!1;for(var f in i.traceHash){var h=i.traceHash[f],p=o.filterVisible(h);h[0][0].trace._module.plot(c,i,p,l),a.traceIs(f,\"gl\")&&p.length&&(u=!0)}u&&(k(c),M(c))}else N=null}},z.updateAngularDrag=function(t){var e=this,r=e.gd,i=e.layers,c=e.radius,f=e.angularAxis,h=e.cx,p=e.cy,d=e.cxx,m=e.cyy,y=S.angularDragBoxSize,x=g.makeDragger(i,\"path\",\"angulardrag\",\"move\"),b={element:x,gd:r};function _(t,e){return Math.atan2(m+y-e,t-d-y)}n.select(x).attr(\"d\",e.pathAnnulus(c,c+y)).attr(\"transform\",l(h,p)).call(T,\"move\");var A,E,L,C,P,O,z=i.frontplot.select(\".scatterlayer\").selectAll(\".trace\"),D=z.selectAll(\".point\"),R=z.selectAll(\".textpoint\");function F(c,g){var v=e.gd._fullLayout,y=v[e.id],x=_(A+c*t._invScaleX,E+g*t._invScaleY),b=I(x-O);if(C=L+b,i.frontplot.attr(\"transform\",l(e.xOffset2,e.yOffset2)+s([-b,d,m])),e.vangles){P=e.radialAxisAngle+b;var w=l(h,p)+s(-b),T=l(h,p)+s(-P);i.bg.attr(\"transform\",w),i[\"radial-grid\"].attr(\"transform\",w),i[\"radial-axis\"].attr(\"transform\",T),i[\"radial-line\"].select(\"line\").attr(\"transform\",T),e.updateRadialAxisTitle(v,y,P)}else e.clipPaths.forTraces.select(\"path\").attr(\"transform\",l(d,m)+s(b));D.each((function(){var t=n.select(this),e=u.getTranslate(t);t.attr(\"transform\",l(e.x,e.y)+s([b]))})),R.each((function(){var t=n.select(this),e=t.select(\"text\"),r=u.getTranslate(t);t.attr(\"transform\",s([b,e.attr(\"x\"),e.attr(\"y\")])+l(r.x,r.y))})),f.rotation=o.modHalf(C,360),e.updateAngularAxis(v,y),e._hasClipOnAxisFalse&&!o.isFullCircle(e.sectorInRad)&&z.call(u.hideOutsideRangePoints,e);var S=!1;for(var F in e.traceHash)if(a.traceIs(F,\"gl\")){var N=e.traceHash[F],j=o.filterVisible(N);N[0][0].trace._module.plot(r,e,j,y),j.length&&(S=!0)}S&&(k(r),M(r));var U={};B(U),r.emit(\"plotly_relayouting\",U)}function B(t){t[e.id+\".angularaxis.rotation\"]=C,e.vangles&&(t[e.id+\".radialaxis.angle\"]=P)}function N(){R.select(\"text\").attr(\"transform\",null);var t={};B(t),a.call(\"_guiRelayout\",r,t)}b.prepFn=function(n,i,a){var s=t[e.id];L=s.angularaxis.rotation;var l=x.getBoundingClientRect();A=i-l.left,E=a-l.top,r._fullLayout._calcInverseTransform(r);var c=o.apply3DTransform(t._invTransform)(A,E);A=c[0],E=c[1],O=_(A,E),b.moveFn=F,b.doneFn=N,w(r)},e.vangles&&!o.isFullCircle(e.sectorInRad)&&(b.prepFn=o.noop,T(n.select(x),null)),v.init(b)},z.isPtInside=function(t){var e=this.sectorInRad,r=this.vangles,n=this.angularAxis.c2g(t.theta),i=this.radialAxis,a=i.c2l(t.r),s=i._rl;return(r?E.isPtInsidePolygon:o.isPtInsideSector)(a,n,s,e,r)},z.pathArc=function(t){var e=this.sectorInRad,r=this.vangles;return(r?E.pathPolygon:o.pathArc)(t,e[0],e[1],r)},z.pathSector=function(t){var e=this.sectorInRad,r=this.vangles;return(r?E.pathPolygon:o.pathSector)(t,e[0],e[1],r)},z.pathAnnulus=function(t,e){var r=this.sectorInRad,n=this.vangles;return(n?E.pathPolygonAnnulus:o.pathAnnulus)(t,e,r[0],r[1],n)},z.pathSubplot=function(){var t=this.innerRadius,e=this.radius;return t?this.pathAnnulus(t,e):this.pathSector(e)},z.fillViewInitialKey=function(t,e){t in this.viewInitial||(this.viewInitial[t]=e)}},{\"../../components/color\":662,\"../../components/dragelement\":681,\"../../components/drawing\":684,\"../../components/fx\":702,\"../../components/titles\":760,\"../../constants/alignment\":767,\"../../lib\":799,\"../../lib/clear_gl_canvases\":783,\"../../lib/setcursor\":820,\"../../plot_api/subroutines\":839,\"../../plots/cartesian/axes\":849,\"../../registry\":927,\"../cartesian/autorange\":848,\"../cartesian/dragbox\":858,\"../cartesian/select\":869,\"../cartesian/set_convert\":870,\"../plots\":913,\"./constants\":914,\"./helpers\":915,\"./set_convert\":920,\"@plotly/d3\":58,tinycolor2:594}],920:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../cartesian/set_convert\"),a=n.deg2rad,o=n.rad2deg;e.exports=function(t,e,r){switch(i(t,r),t._id){case\"x\":case\"radialaxis\":!function(t,e){var r=e._subplot;t.setGeometry=function(){var e=t._rl[0],n=t._rl[1],i=r.innerRadius,a=(r.radius-i)/(n-e),o=i/a,s=e>n?function(t){return t<=0}:function(t){return t>=0};t.c2g=function(r){var n=t.c2l(r)-e;return(s(n)?n:0)+o},t.g2c=function(r){return t.l2c(r+e-o)},t.g2p=function(t){return t*a},t.c2p=function(e){return t.g2p(t.c2g(e))}}}(t,e);break;case\"angularaxis\":!function(t,e){var r=t.type;if(\"linear\"===r){var i=t.d2c,s=t.c2d;t.d2c=function(t,e){return function(t,e){return\"degrees\"===e?a(t):t}(i(t),e)},t.c2d=function(t,e){return s(function(t,e){return\"degrees\"===e?o(t):t}(t,e))}}t.makeCalcdata=function(e,i){var a,o,s=e[i],l=e._length,c=function(r){return t.d2c(r,e.thetaunit)};if(s){if(n.isTypedArray(s)&&\"linear\"===r){if(l===s.length)return s;if(s.subarray)return s.subarray(0,l)}for(a=new Array(l),o=0;o<l;o++)a[o]=c(s[o])}else{var u=i+\"0\",f=\"d\"+i,h=u in e?c(e[u]):0,p=e[f]?c(e[f]):(t.period||2*Math.PI)/l;for(a=new Array(l),o=0;o<l;o++)a[o]=h+o*p}return a},t.setGeometry=function(){var i,s,l,c,u=e.sector,f=u.map(a),h={clockwise:-1,counterclockwise:1}[t.direction],p=a(t.rotation),d=function(t){return h*t+p},m=function(t){return(t-p)/h};switch(r){case\"linear\":s=i=n.identity,c=a,l=o,t.range=n.isFullCircle(f)?[u[0],u[0]+360]:f.map(m).map(o);break;case\"category\":var g=t._categories.length,v=t.period?Math.max(t.period,g):g;0===v&&(v=1),s=c=function(t){return 2*t*Math.PI/v},i=l=function(t){return t*v/Math.PI/2},t.range=[0,v]}t.c2g=function(t){return d(s(t))},t.g2c=function(t){return i(m(t))},t.t2g=function(t){return d(c(t))},t.g2t=function(t){return l(m(t))}}}(t,e)}}},{\"../../lib\":799,\"../cartesian/set_convert\":870}],921:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"../plot_api/plot_template\"),a=t(\"./domain\").defaults;e.exports=function(t,e,r,o){var s,l,c=o.type,u=o.attributes,f=o.handleDefaults,h=o.partition||\"x\",p=e._subplots[c],d=p.length,m=d&&p[0].replace(/\\d+$/,\"\");function g(t,e){return n.coerce(s,l,u,t,e)}for(var v=0;v<d;v++){var y=p[v];s=t[y]?t[y]:t[y]={},l=i.newContainer(e,y,m),g(\"uirevision\",e.uirevision);var x={};x[h]=[v/d,(v+1)/d],a(l,e,g,x),o.id=y,f(s,l,g,o)}}},{\"../lib\":799,\"../plot_api/plot_template\":838,\"./domain\":877}],922:[function(t,e,r){\"use strict\";var n=t(\"../constants/docs\");n.FORMAT_LINK,n.DATE_FORMAT_LINK;function i(t){var e=t.description?\" \"+t.description:\"\",r=t.keys||[];if(r.length>0){for(var n=[],i=0;i<r.length;i++)n[i]=\"`\"+r[i]+\"`\";e+=\"Finally, the template string has access to \",e=1===r.length?\"variable \"+n[0]:\"variables \"+n.slice(0,-1).join(\", \")+\" and \"+n.slice(-1)+\".\"}return e}r.hovertemplateAttrs=function(t,e){t=t||{};i(e=e||{});var r={valType:\"string\",dflt:\"\",editType:t.editType||\"none\"};return!1!==t.arrayOk&&(r.arrayOk=!0),r},r.texttemplateAttrs=function(t,e){t=t||{};i(e=e||{});var r={valType:\"string\",dflt:\"\",editType:t.editType||\"calc\"};return!1!==t.arrayOk&&(r.arrayOk=!0),r}},{\"../constants/docs\":770}],923:[function(t,e,r){\"use strict\";var n=t(\"./ternary\"),i=t(\"../../plots/get_data\").getSubplotCalcData,a=t(\"../../lib\").counterRegex;r.name=\"ternary\";var o=r.attr=\"subplot\";r.idRoot=\"ternary\",r.idRegex=r.attrRegex=a(\"ternary\"),(r.attributes={})[o]={valType:\"subplotid\",dflt:\"ternary\",editType:\"calc\"},r.layoutAttributes=t(\"./layout_attributes\"),r.supplyLayoutDefaults=t(\"./layout_defaults\"),r.plot=function(t){for(var e=t._fullLayout,r=t.calcdata,a=e._subplots.ternary,o=0;o<a.length;o++){var s=a[o],l=i(r,\"ternary\",s),c=e[s]._subplot;c||(c=new n({id:s,graphDiv:t,container:e._ternarylayer.node()},e),e[s]._subplot=c),c.plot(l,e,t._promises)}},r.clean=function(t,e,r,n){for(var i=n._subplots.ternary||[],a=0;a<i.length;a++){var o=i[a],s=n[o]._subplot;!e[o]&&s&&(s.plotContainer.remove(),s.clipDef.remove(),s.clipDefRelative.remove(),s.layers[\"a-title\"].remove(),s.layers[\"b-title\"].remove(),s.layers[\"c-title\"].remove())}}},{\"../../lib\":799,\"../../plots/get_data\":887,\"./layout_attributes\":924,\"./layout_defaults\":925,\"./ternary\":926}],924:[function(t,e,r){\"use strict\";var n=t(\"../../components/color/attributes\"),i=t(\"../domain\").attributes,a=t(\"../cartesian/layout_attributes\"),o=t(\"../../plot_api/edit_types\").overrideAll,s=t(\"../../lib/extend\").extendFlat,l={title:{text:a.title.text,font:a.title.font},color:a.color,tickmode:a.tickmode,nticks:s({},a.nticks,{dflt:6,min:1}),tick0:a.tick0,dtick:a.dtick,tickvals:a.tickvals,ticktext:a.ticktext,ticks:a.ticks,ticklen:a.ticklen,tickwidth:a.tickwidth,tickcolor:a.tickcolor,showticklabels:a.showticklabels,showtickprefix:a.showtickprefix,tickprefix:a.tickprefix,showticksuffix:a.showticksuffix,ticksuffix:a.ticksuffix,showexponent:a.showexponent,exponentformat:a.exponentformat,minexponent:a.minexponent,separatethousands:a.separatethousands,tickfont:a.tickfont,tickangle:a.tickangle,tickformat:a.tickformat,tickformatstops:a.tickformatstops,hoverformat:a.hoverformat,showline:s({},a.showline,{dflt:!0}),linecolor:a.linecolor,linewidth:a.linewidth,showgrid:s({},a.showgrid,{dflt:!0}),gridcolor:a.gridcolor,gridwidth:a.gridwidth,layer:a.layer,min:{valType:\"number\",dflt:0,min:0},_deprecated:{title:a._deprecated.title,titlefont:a._deprecated.titlefont}},c=e.exports=o({domain:i({name:\"ternary\"}),bgcolor:{valType:\"color\",dflt:n.background},sum:{valType:\"number\",dflt:1,min:0},aaxis:l,baxis:l,caxis:l},\"plot\",\"from-root\");c.uirevision={valType:\"any\",editType:\"none\"},c.aaxis.uirevision=c.baxis.uirevision=c.caxis.uirevision={valType:\"any\",editType:\"none\"}},{\"../../components/color/attributes\":661,\"../../lib/extend\":789,\"../../plot_api/edit_types\":831,\"../cartesian/layout_attributes\":864,\"../domain\":877}],925:[function(t,e,r){\"use strict\";var n=t(\"../../components/color\"),i=t(\"../../plot_api/plot_template\"),a=t(\"../../lib\"),o=t(\"../subplot_defaults\"),s=t(\"../cartesian/tick_label_defaults\"),l=t(\"../cartesian/tick_mark_defaults\"),c=t(\"../cartesian/tick_value_defaults\"),u=t(\"../cartesian/line_grid_defaults\"),f=t(\"./layout_attributes\"),h=[\"aaxis\",\"baxis\",\"caxis\"];function p(t,e,r,a){var o,s,l,c=r(\"bgcolor\"),u=r(\"sum\");a.bgColor=n.combine(c,a.paper_bgcolor);for(var f=0;f<h.length;f++)s=t[o=h[f]]||{},(l=i.newContainer(e,o))._name=o,d(s,l,a,e);var p=e.aaxis,m=e.baxis,g=e.caxis;p.min+m.min+g.min>=u&&(p.min=0,m.min=0,g.min=0,t.aaxis&&delete t.aaxis.min,t.baxis&&delete t.baxis.min,t.caxis&&delete t.caxis.min)}function d(t,e,r,n){var i=f[e._name];function o(r,n){return a.coerce(t,e,i,r,n)}o(\"uirevision\",n.uirevision),e.type=\"linear\";var h=o(\"color\"),p=h!==i.color.dflt?h:r.font.color,d=e._name.charAt(0).toUpperCase(),m=\"Component \"+d,g=o(\"title.text\",m);e._hovertitle=g===m?g:d,a.coerceFont(o,\"title.font\",{family:r.font.family,size:a.bigFont(r.font.size),color:p}),o(\"min\"),c(t,e,o,\"linear\"),s(t,e,o,\"linear\",{}),l(t,e,o,{outerTicks:!0}),o(\"showticklabels\")&&(a.coerceFont(o,\"tickfont\",{family:r.font.family,size:r.font.size,color:p}),o(\"tickangle\"),o(\"tickformat\")),u(t,e,o,{dfltColor:h,bgColor:r.bgColor,blend:60,showLine:!0,showGrid:!0,noZeroLine:!0,attributes:i}),o(\"hoverformat\"),o(\"layer\")}e.exports=function(t,e,r){o(t,e,r,{type:\"ternary\",attributes:f,handleDefaults:p,font:e.font,paper_bgcolor:e.paper_bgcolor})}},{\"../../components/color\":662,\"../../lib\":799,\"../../plot_api/plot_template\":838,\"../cartesian/line_grid_defaults\":866,\"../cartesian/tick_label_defaults\":871,\"../cartesian/tick_mark_defaults\":872,\"../cartesian/tick_value_defaults\":873,\"../subplot_defaults\":921,\"./layout_attributes\":924}],926:[function(t,e,r){\"use strict\";var n=t(\"@plotly/d3\"),i=t(\"tinycolor2\"),a=t(\"../../registry\"),o=t(\"../../lib\"),s=o.strTranslate,l=o._,c=t(\"../../components/color\"),u=t(\"../../components/drawing\"),f=t(\"../cartesian/set_convert\"),h=t(\"../../lib/extend\").extendFlat,p=t(\"../plots\"),d=t(\"../cartesian/axes\"),m=t(\"../../components/dragelement\"),g=t(\"../../components/fx\"),v=t(\"../../components/dragelement/helpers\"),y=v.freeMode,x=v.rectMode,b=t(\"../../components/titles\"),_=t(\"../cartesian/select\").prepSelect,w=t(\"../cartesian/select\").selectOnClick,T=t(\"../cartesian/select\").clearSelect,k=t(\"../cartesian/select\").clearSelectionsCache,M=t(\"../cartesian/constants\");function A(t,e){this.id=t.id,this.graphDiv=t.graphDiv,this.init(e),this.makeFramework(e),this.aTickLayout=null,this.bTickLayout=null,this.cTickLayout=null}e.exports=A;var S=A.prototype;S.init=function(t){this.container=t._ternarylayer,this.defs=t._defs,this.layoutId=t._uid,this.traceHash={},this.layers={}},S.plot=function(t,e){var r=e[this.id],n=e._size;this._hasClipOnAxisFalse=!1;for(var i=0;i<t.length;i++){if(!1===t[i][0].trace.cliponaxis){this._hasClipOnAxisFalse=!0;break}}this.updateLayers(r),this.adjustLayout(r,n),p.generalUpdatePerTraceModule(this.graphDiv,this,t,r),this.layers.plotbg.select(\"path\").call(c.fill,r.bgcolor)},S.makeFramework=function(t){var e=this.graphDiv,r=t[this.id],n=this.clipId=\"clip\"+this.layoutId+this.id,i=this.clipIdRelative=\"clip-relative\"+this.layoutId+this.id;this.clipDef=o.ensureSingleById(t._clips,\"clipPath\",n,(function(t){t.append(\"path\").attr(\"d\",\"M0,0Z\")})),this.clipDefRelative=o.ensureSingleById(t._clips,\"clipPath\",i,(function(t){t.append(\"path\").attr(\"d\",\"M0,0Z\")})),this.plotContainer=o.ensureSingle(this.container,\"g\",this.id),this.updateLayers(r),u.setClipUrl(this.layers.backplot,n,e),u.setClipUrl(this.layers.grids,n,e)},S.updateLayers=function(t){var e=this.layers,r=[\"draglayer\",\"plotbg\",\"backplot\",\"grids\"];\"below traces\"===t.aaxis.layer&&r.push(\"aaxis\",\"aline\"),\"below traces\"===t.baxis.layer&&r.push(\"baxis\",\"bline\"),\"below traces\"===t.caxis.layer&&r.push(\"caxis\",\"cline\"),r.push(\"frontplot\"),\"above traces\"===t.aaxis.layer&&r.push(\"aaxis\",\"aline\"),\"above traces\"===t.baxis.layer&&r.push(\"baxis\",\"bline\"),\"above traces\"===t.caxis.layer&&r.push(\"caxis\",\"cline\");var i=this.plotContainer.selectAll(\"g.toplevel\").data(r,String),a=[\"agrid\",\"bgrid\",\"cgrid\"];i.enter().append(\"g\").attr(\"class\",(function(t){return\"toplevel \"+t})).each((function(t){var r=n.select(this);e[t]=r,\"frontplot\"===t?r.append(\"g\").classed(\"scatterlayer\",!0):\"backplot\"===t?r.append(\"g\").classed(\"maplayer\",!0):\"plotbg\"===t?r.append(\"path\").attr(\"d\",\"M0,0Z\"):\"aline\"===t||\"bline\"===t||\"cline\"===t?r.append(\"path\"):\"grids\"===t&&a.forEach((function(t){e[t]=r.append(\"g\").classed(\"grid \"+t,!0)}))})),i.order()};var E=Math.sqrt(4/3);S.adjustLayout=function(t,e){var r,n,i,a,o,l,p=this,d=t.domain,m=(d.x[0]+d.x[1])/2,g=(d.y[0]+d.y[1])/2,v=d.x[1]-d.x[0],y=d.y[1]-d.y[0],x=v*e.w,b=y*e.h,_=t.sum,w=t.aaxis.min,T=t.baxis.min,k=t.caxis.min;x>E*b?i=(a=b)*E:a=(i=x)/E,o=v*i/x,l=y*a/b,r=e.l+e.w*m-i/2,n=e.t+e.h*(1-g)-a/2,p.x0=r,p.y0=n,p.w=i,p.h=a,p.sum=_,p.xaxis={type:\"linear\",range:[w+2*k-_,_-w-2*T],domain:[m-o/2,m+o/2],_id:\"x\"},f(p.xaxis,p.graphDiv._fullLayout),p.xaxis.setScale(),p.xaxis.isPtWithinRange=function(t){return t.a>=p.aaxis.range[0]&&t.a<=p.aaxis.range[1]&&t.b>=p.baxis.range[1]&&t.b<=p.baxis.range[0]&&t.c>=p.caxis.range[1]&&t.c<=p.caxis.range[0]},p.yaxis={type:\"linear\",range:[w,_-T-k],domain:[g-l/2,g+l/2],_id:\"y\"},f(p.yaxis,p.graphDiv._fullLayout),p.yaxis.setScale(),p.yaxis.isPtWithinRange=function(){return!0};var M=p.yaxis.domain[0],A=p.aaxis=h({},t.aaxis,{range:[w,_-T-k],side:\"left\",tickangle:(+t.aaxis.tickangle||0)-30,domain:[M,M+l*E],anchor:\"free\",position:0,_id:\"y\",_length:i});f(A,p.graphDiv._fullLayout),A.setScale();var S=p.baxis=h({},t.baxis,{range:[_-w-k,T],side:\"bottom\",domain:p.xaxis.domain,anchor:\"free\",position:0,_id:\"x\",_length:i});f(S,p.graphDiv._fullLayout),S.setScale();var L=p.caxis=h({},t.caxis,{range:[_-w-T,k],side:\"right\",tickangle:(+t.caxis.tickangle||0)+30,domain:[M,M+l*E],anchor:\"free\",position:0,_id:\"y\",_length:i});f(L,p.graphDiv._fullLayout),L.setScale();var C=\"M\"+r+\",\"+(n+a)+\"h\"+i+\"l-\"+i/2+\",-\"+a+\"Z\";p.clipDef.select(\"path\").attr(\"d\",C),p.layers.plotbg.select(\"path\").attr(\"d\",C);var P=\"M0,\"+a+\"h\"+i+\"l-\"+i/2+\",-\"+a+\"Z\";p.clipDefRelative.select(\"path\").attr(\"d\",P);var I=s(r,n);p.plotContainer.selectAll(\".scatterlayer,.maplayer\").attr(\"transform\",I),p.clipDefRelative.select(\"path\").attr(\"transform\",null);var O=s(r-S._offset,n+a);p.layers.baxis.attr(\"transform\",O),p.layers.bgrid.attr(\"transform\",O);var z=s(r+i/2,n)+\"rotate(30)\"+s(0,-A._offset);p.layers.aaxis.attr(\"transform\",z),p.layers.agrid.attr(\"transform\",z);var D=s(r+i/2,n)+\"rotate(-30)\"+s(0,-L._offset);p.layers.caxis.attr(\"transform\",D),p.layers.cgrid.attr(\"transform\",D),p.drawAxes(!0),p.layers.aline.select(\"path\").attr(\"d\",A.showline?\"M\"+r+\",\"+(n+a)+\"l\"+i/2+\",-\"+a:\"M0,0\").call(c.stroke,A.linecolor||\"#000\").style(\"stroke-width\",(A.linewidth||0)+\"px\"),p.layers.bline.select(\"path\").attr(\"d\",S.showline?\"M\"+r+\",\"+(n+a)+\"h\"+i:\"M0,0\").call(c.stroke,S.linecolor||\"#000\").style(\"stroke-width\",(S.linewidth||0)+\"px\"),p.layers.cline.select(\"path\").attr(\"d\",L.showline?\"M\"+(r+i/2)+\",\"+n+\"l\"+i/2+\",\"+a:\"M0,0\").call(c.stroke,L.linecolor||\"#000\").style(\"stroke-width\",(L.linewidth||0)+\"px\"),p.graphDiv._context.staticPlot||p.initInteractions(),u.setClipUrl(p.layers.frontplot,p._hasClipOnAxisFalse?null:p.clipId,p.graphDiv)},S.drawAxes=function(t){var e=this.graphDiv,r=this.id.substr(7)+\"title\",n=this.layers,i=this.aaxis,a=this.baxis,o=this.caxis;if(this.drawAx(i),this.drawAx(a),this.drawAx(o),t){var s=Math.max(i.showticklabels?i.tickfont.size/2:0,(o.showticklabels?.75*o.tickfont.size:0)+(\"outside\"===o.ticks?.87*o.ticklen:0)),c=(a.showticklabels?a.tickfont.size:0)+(\"outside\"===a.ticks?a.ticklen:0)+3;n[\"a-title\"]=b.draw(e,\"a\"+r,{propContainer:i,propName:this.id+\".aaxis.title\",placeholder:l(e,\"Click to enter Component A title\"),attributes:{x:this.x0+this.w/2,y:this.y0-i.title.font.size/3-s,\"text-anchor\":\"middle\"}}),n[\"b-title\"]=b.draw(e,\"b\"+r,{propContainer:a,propName:this.id+\".baxis.title\",placeholder:l(e,\"Click to enter Component B title\"),attributes:{x:this.x0-c,y:this.y0+this.h+.83*a.title.font.size+c,\"text-anchor\":\"middle\"}}),n[\"c-title\"]=b.draw(e,\"c\"+r,{propContainer:o,propName:this.id+\".caxis.title\",placeholder:l(e,\"Click to enter Component C title\"),attributes:{x:this.x0+this.w+c,y:this.y0+this.h+.83*o.title.font.size+c,\"text-anchor\":\"middle\"}})}},S.drawAx=function(t){var e,r=this.graphDiv,n=t._name,i=n.charAt(0),a=t._id,s=this.layers[n],l=i+\"tickLayout\",c=(e=t).ticks+String(e.ticklen)+String(e.showticklabels);this[l]!==c&&(s.selectAll(\".\"+a+\"tick\").remove(),this[l]=c),t.setScale();var u=d.calcTicks(t),f=d.clipEnds(t,u),h=d.makeTransTickFn(t),p=d.getTickSigns(t)[2],m=o.deg2rad(30),g=p*(t.linewidth||1)/2,v=p*t.ticklen,y=this.w,x=this.h,b=\"b\"===i?\"M0,\"+g+\"l\"+Math.sin(m)*v+\",\"+Math.cos(m)*v:\"M\"+g+\",0l\"+Math.cos(m)*v+\",\"+-Math.sin(m)*v,_={a:\"M0,0l\"+x+\",-\"+y/2,b:\"M0,0l-\"+y/2+\",-\"+x,c:\"M0,0l-\"+x+\",\"+y/2}[i];d.drawTicks(r,t,{vals:\"inside\"===t.ticks?f:u,layer:s,path:b,transFn:h,crisp:!1}),d.drawGrid(r,t,{vals:f,layer:this.layers[i+\"grid\"],path:_,transFn:h,crisp:!1}),d.drawLabels(r,t,{vals:u,layer:s,transFn:h,labelFns:d.makeLabelFns(t,0,30)})};var L=M.MINZOOM/2+.87,C=\"m-0.87,.5h\"+L+\"v3h-\"+(L+5.2)+\"l\"+(L/2+2.6)+\",-\"+(.87*L+4.5)+\"l2.6,1.5l-\"+L/2+\",\"+.87*L+\"Z\",P=\"m0.87,.5h-\"+L+\"v3h\"+(L+5.2)+\"l-\"+(L/2+2.6)+\",-\"+(.87*L+4.5)+\"l-2.6,1.5l\"+L/2+\",\"+.87*L+\"Z\",I=\"m0,1l\"+L/2+\",\"+.87*L+\"l2.6,-1.5l-\"+(L/2+2.6)+\",-\"+(.87*L+4.5)+\"l-\"+(L/2+2.6)+\",\"+(.87*L+4.5)+\"l2.6,1.5l\"+L/2+\",-\"+.87*L+\"Z\",O=!0;function z(t){n.select(t).selectAll(\".zoombox,.js-zoombox-backdrop,.js-zoombox-menu,.zoombox-corners\").remove()}S.clearSelect=function(){k(this.dragOptions),T(this.dragOptions.gd)},S.initInteractions=function(){var t,e,r,n,f,h,p,d,v,b,T,k,A=this,S=A.layers.plotbg.select(\"path\").node(),L=A.graphDiv,D=L._fullLayout._zoomlayer;function R(t){var e={};return e[A.id+\".aaxis.min\"]=t.a,e[A.id+\".baxis.min\"]=t.b,e[A.id+\".caxis.min\"]=t.c,e}function F(t,e){var r=L._fullLayout.clickmode;z(L),2===t&&(L.emit(\"plotly_doubleclick\",null),a.call(\"_guiRelayout\",L,R({a:0,b:0,c:0}))),r.indexOf(\"select\")>-1&&1===t&&w(e,L,[A.xaxis],[A.yaxis],A.id,A.dragOptions),r.indexOf(\"event\")>-1&&g.click(L,e,A.id)}function B(t,e){return 1-e/A.h}function N(t,e){return 1-(t+(A.h-e)/Math.sqrt(3))/A.w}function j(t,e){return(t-(A.h-e)/Math.sqrt(3))/A.w}function U(i,a){var o=r+i*t,s=n+a*e,l=Math.max(0,Math.min(1,B(0,n),B(0,s))),c=Math.max(0,Math.min(1,N(r,n),N(o,s))),u=Math.max(0,Math.min(1,j(r,n),j(o,s))),m=(l/2+u)*A.w,g=(1-l/2-c)*A.w,y=(m+g)/2,x=g-m,_=(1-l)*A.h,w=_-x/E;x<M.MINZOOM?(p=f,T.attr(\"d\",v),k.attr(\"d\",\"M0,0Z\")):(p={a:f.a+l*h,b:f.b+c*h,c:f.c+u*h},T.attr(\"d\",v+\"M\"+m+\",\"+_+\"H\"+g+\"L\"+y+\",\"+w+\"L\"+m+\",\"+_+\"Z\"),k.attr(\"d\",\"M\"+r+\",\"+n+\"m0.5,0.5h5v-2h-5v-5h-2v5h-5v2h5v5h2ZM\"+m+\",\"+_+C+\"M\"+g+\",\"+_+P+\"M\"+y+\",\"+w+I)),b||(T.transition().style(\"fill\",d>.2?\"rgba(0,0,0,0.4)\":\"rgba(255,255,255,0.3)\").duration(200),k.transition().style(\"opacity\",1).duration(200),b=!0),L.emit(\"plotly_relayouting\",R(p))}function V(){z(L),p!==f&&(a.call(\"_guiRelayout\",L,R(p)),O&&L.data&&L._context.showTips&&(o.notifier(l(L,\"Double-click to zoom back out\"),\"long\"),O=!1))}function q(t,e){var r=t/A.xaxis._m,n=e/A.yaxis._m,i=[(p={a:f.a-n,b:f.b+(r+n)/2,c:f.c-(r-n)/2}).a,p.b,p.c].sort(o.sorterAsc),a=i.indexOf(p.a),l=i.indexOf(p.b),c=i.indexOf(p.c);i[0]<0&&(i[1]+i[0]/2<0?(i[2]+=i[0]+i[1],i[0]=i[1]=0):(i[2]+=i[0]/2,i[1]+=i[0]/2,i[0]=0),p={a:i[a],b:i[l],c:i[c]},e=(f.a-p.a)*A.yaxis._m,t=(f.c-p.c-f.b+p.b)*A.xaxis._m);var h=s(A.x0+t,A.y0+e);A.plotContainer.selectAll(\".scatterlayer,.maplayer\").attr(\"transform\",h);var d=s(-t,-e);A.clipDefRelative.select(\"path\").attr(\"transform\",d),A.aaxis.range=[p.a,A.sum-p.b-p.c],A.baxis.range=[A.sum-p.a-p.c,p.b],A.caxis.range=[A.sum-p.a-p.b,p.c],A.drawAxes(!1),A._hasClipOnAxisFalse&&A.plotContainer.select(\".scatterlayer\").selectAll(\".trace\").call(u.hideOutsideRangePoints,A),L.emit(\"plotly_relayouting\",R(p))}function H(){a.call(\"_guiRelayout\",L,R(p))}this.dragOptions={element:S,gd:L,plotinfo:{id:A.id,domain:L._fullLayout[A.id].domain,xaxis:A.xaxis,yaxis:A.yaxis},subplot:A.id,prepFn:function(a,l,u){A.dragOptions.xaxes=[A.xaxis],A.dragOptions.yaxes=[A.yaxis],t=L._fullLayout._invScaleX,e=L._fullLayout._invScaleY;var m=A.dragOptions.dragmode=L._fullLayout.dragmode;y(m)?A.dragOptions.minDrag=1:A.dragOptions.minDrag=void 0,\"zoom\"===m?(A.dragOptions.moveFn=U,A.dragOptions.clickFn=F,A.dragOptions.doneFn=V,function(t,e,a){var l=S.getBoundingClientRect();r=e-l.left,n=a-l.top,L._fullLayout._calcInverseTransform(L);var u=L._fullLayout._invTransform,m=o.apply3DTransform(u)(r,n);r=m[0],n=m[1],f={a:A.aaxis.range[0],b:A.baxis.range[1],c:A.caxis.range[1]},p=f,h=A.aaxis.range[1]-f.a,d=i(A.graphDiv._fullLayout[A.id].bgcolor).getLuminance(),v=\"M0,\"+A.h+\"L\"+A.w/2+\", 0L\"+A.w+\",\"+A.h+\"Z\",b=!1,T=D.append(\"path\").attr(\"class\",\"zoombox\").attr(\"transform\",s(A.x0,A.y0)).style({fill:d>.2?\"rgba(0,0,0,0)\":\"rgba(255,255,255,0)\",\"stroke-width\":0}).attr(\"d\",v),k=D.append(\"path\").attr(\"class\",\"zoombox-corners\").attr(\"transform\",s(A.x0,A.y0)).style({fill:c.background,stroke:c.defaultLine,\"stroke-width\":1,opacity:0}).attr(\"d\",\"M0,0Z\"),A.clearSelect(L)}(0,l,u)):\"pan\"===m?(A.dragOptions.moveFn=q,A.dragOptions.clickFn=F,A.dragOptions.doneFn=H,f={a:A.aaxis.range[0],b:A.baxis.range[1],c:A.caxis.range[1]},p=f,A.clearSelect(L)):(x(m)||y(m))&&_(a,l,u,A.dragOptions,m)}},S.onmousemove=function(t){g.hover(L,t,A.id),L._fullLayout._lasthover=S,L._fullLayout._hoversubplot=A.id},S.onmouseout=function(t){L._dragging||m.unhover(L,t)},m.init(this.dragOptions)}},{\"../../components/color\":662,\"../../components/dragelement\":681,\"../../components/dragelement/helpers\":680,\"../../components/drawing\":684,\"../../components/fx\":702,\"../../components/titles\":760,\"../../lib\":799,\"../../lib/extend\":789,\"../../registry\":927,\"../cartesian/axes\":849,\"../cartesian/constants\":856,\"../cartesian/select\":869,\"../cartesian/set_convert\":870,\"../plots\":913,\"@plotly/d3\":58,tinycolor2:594}],927:[function(t,e,r){\"use strict\";var n=t(\"./lib/loggers\"),i=t(\"./lib/noop\"),a=t(\"./lib/push_unique\"),o=t(\"./lib/is_plain_object\"),s=t(\"./lib/dom\").addStyleRule,l=t(\"./lib/extend\"),c=t(\"./plots/attributes\"),u=t(\"./plots/layout_attributes\"),f=l.extendFlat,h=l.extendDeepAll;function p(t){var e=t.name,i=t.categories,a=t.meta;if(r.modules[e])n.log(\"Type \"+e+\" already registered\");else{r.subplotsRegistry[t.basePlotModule.name]||function(t){var e=t.name;if(r.subplotsRegistry[e])return void n.log(\"Plot type \"+e+\" already registered.\");for(var i in v(t),r.subplotsRegistry[e]=t,r.componentsRegistry)b(i,t.name)}(t.basePlotModule);for(var o={},l=0;l<i.length;l++)o[i[l]]=!0,r.allCategories[i[l]]=!0;for(var c in r.modules[e]={_module:t,categories:o},a&&Object.keys(a).length&&(r.modules[e].meta=a),r.allTypes.push(e),r.componentsRegistry)y(c,e);t.layoutAttributes&&f(r.traceLayoutAttributes,t.layoutAttributes);var u=t.basePlotModule,h=u.name;if(\"mapbox\"===h){var p=u.constants.styleRules;for(var d in p)s(\".js-plotly-plot .plotly .mapboxgl-\"+d,p[d])}\"geo\"!==h&&\"mapbox\"!==h||void 0===typeof window||void 0!==window.PlotlyGeoAssets||(window.PlotlyGeoAssets={topojson:{}})}}function d(t){if(\"string\"!=typeof t.name)throw new Error(\"Component module *name* must be a string.\");var e=t.name;for(var n in r.componentsRegistry[e]=t,t.layoutAttributes&&(t.layoutAttributes._isLinkedToArray&&a(r.layoutArrayContainers,e),v(t)),r.modules)y(e,n);for(var i in r.subplotsRegistry)b(e,i);for(var o in r.transformsRegistry)x(e,o);t.schema&&t.schema.layout&&h(u,t.schema.layout)}function m(t){if(\"string\"!=typeof t.name)throw new Error(\"Transform module *name* must be a string.\");var e=\"Transform module \"+t.name,i=\"function\"==typeof t.transform,a=\"function\"==typeof t.calcTransform;if(!i&&!a)throw new Error(e+\" is missing a *transform* or *calcTransform* method.\");for(var s in i&&a&&n.log([e+\" has both a *transform* and *calcTransform* methods.\",\"Please note that all *transform* methods are executed\",\"before all *calcTransform* methods.\"].join(\" \")),o(t.attributes)||n.log(e+\" registered without an *attributes* object.\"),\"function\"!=typeof t.supplyDefaults&&n.log(e+\" registered without a *supplyDefaults* method.\"),r.transformsRegistry[t.name]=t,r.componentsRegistry)x(s,t.name)}function g(t){var e=t.name,n=e.split(\"-\")[0],i=t.dictionary,a=t.format,o=i&&Object.keys(i).length,s=a&&Object.keys(a).length,l=r.localeRegistry,c=l[e];if(c||(l[e]=c={}),n!==e){var u=l[n];u||(l[n]=u={}),o&&u.dictionary===c.dictionary&&(u.dictionary=i),s&&u.format===c.format&&(u.format=a)}o&&(c.dictionary=i),s&&(c.format=a)}function v(t){if(t.layoutAttributes){var e=t.layoutAttributes._arrayAttrRegexps;if(e)for(var n=0;n<e.length;n++)a(r.layoutArrayRegexes,e[n])}}function y(t,e){var n=r.componentsRegistry[t].schema;if(n&&n.traces){var i=n.traces[e];i&&h(r.modules[e]._module.attributes,i)}}function x(t,e){var n=r.componentsRegistry[t].schema;if(n&&n.transforms){var i=n.transforms[e];i&&h(r.transformsRegistry[e].attributes,i)}}function b(t,e){var n=r.componentsRegistry[t].schema;if(n&&n.subplots){var i=r.subplotsRegistry[e],a=i.layoutAttributes,o=\"subplot\"===i.attr?i.name:i.attr;Array.isArray(o)&&(o=o[0]);var s=n.subplots[o];a&&s&&h(a,s)}}function _(t){return\"object\"==typeof t&&(t=t.type),t}r.modules={},r.allCategories={},r.allTypes=[],r.subplotsRegistry={},r.transformsRegistry={},r.componentsRegistry={},r.layoutArrayContainers=[],r.layoutArrayRegexes=[],r.traceLayoutAttributes={},r.localeRegistry={},r.apiMethodRegistry={},r.collectableSubplotTypes=null,r.register=function(t){if(r.collectableSubplotTypes=null,!t)throw new Error(\"No argument passed to Plotly.register.\");t&&!Array.isArray(t)&&(t=[t]);for(var e=0;e<t.length;e++){var n=t[e];if(!n)throw new Error(\"Invalid module was attempted to be registered!\");switch(n.moduleType){case\"trace\":p(n);break;case\"transform\":m(n);break;case\"component\":d(n);break;case\"locale\":g(n);break;case\"apiMethod\":var i=n.name;r.apiMethodRegistry[i]=n.fn;break;default:throw new Error(\"Invalid module was attempted to be registered!\")}}},r.getModule=function(t){var e=r.modules[_(t)];return!!e&&e._module},r.traceIs=function(t,e){if(\"various\"===(t=_(t)))return!1;var i=r.modules[t];return i||(t&&n.log(\"Unrecognized trace type \"+t+\".\"),i=r.modules[c.type.dflt]),!!i.categories[e]},r.getTransformIndices=function(t,e){for(var r=[],n=t.transforms||[],i=0;i<n.length;i++)n[i].type===e&&r.push(i);return r},r.hasTransform=function(t,e){for(var r=t.transforms||[],n=0;n<r.length;n++)if(r[n].type===e)return!0;return!1},r.getComponentMethod=function(t,e){var n=r.componentsRegistry[t];return n&&n[e]||i},r.call=function(){var t=arguments[0],e=[].slice.call(arguments,1);return r.apiMethodRegistry[t].apply(null,e)}},{\"./lib/dom\":787,\"./lib/extend\":789,\"./lib/is_plain_object\":800,\"./lib/loggers\":803,\"./lib/noop\":808,\"./lib/push_unique\":814,\"./plots/attributes\":845,\"./plots/layout_attributes\":904}],928:[function(t,e,r){\"use strict\";var n=t(\"../registry\"),i=t(\"../lib\"),a=i.extendFlat,o=i.extendDeep;function s(t){var e;switch(t){case\"themes__thumb\":e={autosize:!0,width:150,height:150,title:{text:\"\"},showlegend:!1,margin:{l:5,r:5,t:5,b:5,pad:0},annotations:[]};break;case\"thumbnail\":e={title:{text:\"\"},hidesources:!0,showlegend:!1,borderwidth:0,bordercolor:\"\",margin:{l:1,r:1,t:1,b:1,pad:0},annotations:[]};break;default:e={}}return e}e.exports=function(t,e){var r,i,l=t.data,c=t.layout,u=o([],l),f=o({},c,s(e.tileClass)),h=t._context||{};if(e.width&&(f.width=e.width),e.height&&(f.height=e.height),\"thumbnail\"===e.tileClass||\"themes__thumb\"===e.tileClass){f.annotations=[];var p=Object.keys(f);for(r=0;r<p.length;r++)i=p[r],[\"xaxis\",\"yaxis\",\"zaxis\"].indexOf(i.slice(0,5))>-1&&(f[p[r]].title={text:\"\"});for(r=0;r<u.length;r++){var d=u[r];d.showscale=!1,d.marker&&(d.marker.showscale=!1),n.traceIs(d,\"pie-like\")&&(d.textposition=\"none\")}}if(Array.isArray(e.annotations))for(r=0;r<e.annotations.length;r++)f.annotations.push(e.annotations[r]);var m=Object.keys(f).filter((function(t){return t.match(/^scene\\d*$/)}));if(m.length){var g={};for(\"thumbnail\"===e.tileClass&&(g={title:{text:\"\"},showaxeslabels:!1,showticklabels:!1,linetickenable:!1}),r=0;r<m.length;r++){var v=f[m[r]];v.xaxis||(v.xaxis={}),v.yaxis||(v.yaxis={}),v.zaxis||(v.zaxis={}),a(v.xaxis,g),a(v.yaxis,g),a(v.zaxis,g),v._scene=null}}var y=document.createElement(\"div\");e.tileClass&&(y.className=e.tileClass);var x={gd:y,td:y,layout:f,data:u,config:{staticPlot:void 0===e.staticPlot||e.staticPlot,plotGlPixelRatio:void 0===e.plotGlPixelRatio?2:e.plotGlPixelRatio,displaylogo:e.displaylogo||!1,showLink:e.showLink||!1,showTips:e.showTips||!1,mapboxAccessToken:h.mapboxAccessToken}};return\"transparent\"!==e.setBackground&&(x.config.setBackground=e.setBackground||\"opaque\"),x.gd.defaultLayout=s(e.tileClass),x}},{\"../lib\":799,\"../registry\":927}],929:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"../plot_api/to_image\"),a=t(\"./filesaver\"),o=t(\"./helpers\");e.exports=function(t,e){var r;return n.isPlainObject(t)||(r=n.getGraphDiv(t)),(e=e||{}).format=e.format||\"png\",e.width=e.width||null,e.height=e.height||null,e.imageDataOnly=!0,new Promise((function(s,l){r&&r._snapshotInProgress&&l(new Error(\"Snapshotting already in progress.\")),n.isIE()&&\"svg\"!==e.format&&l(new Error(o.MSG_IE_BAD_FORMAT)),r&&(r._snapshotInProgress=!0);var c=i(t,e),u=e.filename||t.fn||\"newplot\";u+=\".\"+e.format.replace(\"-\",\".\"),c.then((function(t){return r&&(r._snapshotInProgress=!1),a(t,u,e.format)})).then((function(t){s(t)})).catch((function(t){r&&(r._snapshotInProgress=!1),l(t)}))}))}},{\"../lib\":799,\"../plot_api/to_image\":841,\"./filesaver\":930,\"./helpers\":931}],930:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"./helpers\");e.exports=function(t,e,r){var a=document.createElement(\"a\"),o=\"download\"in a;return new Promise((function(s,l){var c,u;if(n.isSafari()){var f=\"svg\"===r?\",\":\";base64,\";return i.octetStream(f+encodeURIComponent(t)),s(e)}return n.isIE()?(c=i.createBlob(t,\"svg\"),window.navigator.msSaveBlob(c,e),c=null,s(e)):o?(c=i.createBlob(t,r),u=i.createObjectURL(c),a.href=u,a.download=e,document.body.appendChild(a),a.click(),document.body.removeChild(a),i.revokeObjectURL(u),c=null,s(e)):void l(new Error(\"download error\"))}))}},{\"../lib\":799,\"./helpers\":931}],931:[function(t,e,r){\"use strict\";var n=t(\"../registry\");r.getDelay=function(t){return t._has&&(t._has(\"gl3d\")||t._has(\"gl2d\")||t._has(\"mapbox\"))?500:0},r.getRedrawFunc=function(t){return function(){n.getComponentMethod(\"colorbar\",\"draw\")(t)}},r.encodeSVG=function(t){return\"data:image/svg+xml,\"+encodeURIComponent(t)},r.encodeJSON=function(t){return\"data:application/json,\"+encodeURIComponent(t)};var i=window.URL||window.webkitURL;r.createObjectURL=function(t){return i.createObjectURL(t)},r.revokeObjectURL=function(t){return i.revokeObjectURL(t)},r.createBlob=function(t,e){if(\"svg\"===e)return new window.Blob([t],{type:\"image/svg+xml;charset=utf-8\"});if(\"full-json\"===e)return new window.Blob([t],{type:\"application/json;charset=utf-8\"});var r=function(t){for(var e=t.length,r=new ArrayBuffer(e),n=new Uint8Array(r),i=0;i<e;i++)n[i]=t.charCodeAt(i);return r}(window.atob(t));return new window.Blob([r],{type:\"image/\"+e})},r.octetStream=function(t){document.location.href=\"data:application/octet-stream\"+t},r.IMAGE_URL_PREFIX=/^data:image\\/\\w+;base64,/,r.MSG_IE_BAD_FORMAT=\"Sorry IE does not support downloading from canvas. Try {format:'svg'} instead.\"},{\"../registry\":927}],932:[function(t,e,r){\"use strict\";var n=t(\"./helpers\"),i={getDelay:n.getDelay,getRedrawFunc:n.getRedrawFunc,clone:t(\"./cloneplot\"),toSVG:t(\"./tosvg\"),svgToImg:t(\"./svgtoimg\"),toImage:t(\"./toimage\"),downloadImage:t(\"./download\")};e.exports=i},{\"./cloneplot\":928,\"./download\":929,\"./helpers\":931,\"./svgtoimg\":933,\"./toimage\":934,\"./tosvg\":935}],933:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"events\").EventEmitter,a=t(\"./helpers\");e.exports=function(t){var e=t.emitter||new i,r=new Promise((function(i,o){var s=window.Image,l=t.svg,c=t.format||\"png\";if(n.isIE()&&\"svg\"!==c){var u=new Error(a.MSG_IE_BAD_FORMAT);return o(u),t.promise?r:e.emit(\"error\",u)}var f,h,p=t.canvas,d=t.scale||1,m=t.width||300,g=t.height||150,v=d*m,y=d*g,x=p.getContext(\"2d\"),b=new s;\"svg\"===c||n.isSafari()?h=a.encodeSVG(l):(f=a.createBlob(l,\"svg\"),h=a.createObjectURL(f)),p.width=v,p.height=y,b.onload=function(){var r;switch(f=null,a.revokeObjectURL(h),\"svg\"!==c&&x.drawImage(b,0,0,v,y),c){case\"jpeg\":r=p.toDataURL(\"image/jpeg\");break;case\"png\":r=p.toDataURL(\"image/png\");break;case\"webp\":r=p.toDataURL(\"image/webp\");break;case\"svg\":r=h;break;default:var n=\"Image format is not jpeg, png, svg or webp.\";if(o(new Error(n)),!t.promise)return e.emit(\"error\",n)}i(r),t.promise||e.emit(\"success\",r)},b.onerror=function(r){if(f=null,a.revokeObjectURL(h),o(r),!t.promise)return e.emit(\"error\",r)},b.src=h}));return t.promise?r:e}},{\"../lib\":799,\"./helpers\":931,events:116}],934:[function(t,e,r){\"use strict\";var n=t(\"events\").EventEmitter,i=t(\"../registry\"),a=t(\"../lib\"),o=t(\"./helpers\"),s=t(\"./cloneplot\"),l=t(\"./tosvg\"),c=t(\"./svgtoimg\");e.exports=function(t,e){var r=new n,u=s(t,{format:\"png\"}),f=u.gd;f.style.position=\"absolute\",f.style.left=\"-5000px\",document.body.appendChild(f);var h=o.getRedrawFunc(f);return i.call(\"_doPlot\",f,u.data,u.layout,u.config).then(h).then((function(){var t=o.getDelay(f._fullLayout);setTimeout((function(){var t=l(f),n=document.createElement(\"canvas\");n.id=a.randstr(),(r=c({format:e.format,width:f._fullLayout.width,height:f._fullLayout.height,canvas:n,emitter:r,svg:t})).clean=function(){f&&document.body.removeChild(f)}}),t)})).catch((function(t){r.emit(\"error\",t)})),r}},{\"../lib\":799,\"../registry\":927,\"./cloneplot\":928,\"./helpers\":931,\"./svgtoimg\":933,\"./tosvg\":935,events:116}],935:[function(t,e,r){\"use strict\";var n=t(\"@plotly/d3\"),i=t(\"../lib\"),a=t(\"../components/drawing\"),o=t(\"../components/color\"),s=t(\"../constants/xmlns_namespaces\"),l=/\"/g,c=new RegExp('(\"TOBESTRIPPED)|(TOBESTRIPPED\")',\"g\");e.exports=function(t,e,r){var u,f,h=t._fullLayout,p=h._paper,d=h._toppaper,m=h.width,g=h.height;p.insert(\"rect\",\":first-child\").call(a.setRect,0,0,m,g).call(o.fill,h.paper_bgcolor);var v=h._basePlotModules||[];for(u=0;u<v.length;u++){var y=v[u];y.toSVG&&y.toSVG(t)}if(d){var x=d.node().childNodes,b=Array.prototype.slice.call(x);for(u=0;u<b.length;u++){var _=b[u];_.childNodes.length&&p.node().appendChild(_)}}h._draggers&&h._draggers.remove(),p.node().style.background=\"\",p.selectAll(\"text\").attr({\"data-unformatted\":null,\"data-math\":null}).each((function(){var t=n.select(this);if(\"hidden\"!==this.style.visibility&&\"none\"!==this.style.display){t.style({visibility:null,display:null});var e=this.style.fontFamily;e&&-1!==e.indexOf('\"')&&t.style(\"font-family\",e.replace(l,\"TOBESTRIPPED\"))}else t.remove()}));var w=[];if(h._gradientUrlQueryParts)for(f in h._gradientUrlQueryParts)w.push(f);if(h._patternUrlQueryParts)for(f in h._patternUrlQueryParts)w.push(f);w.length&&p.selectAll(w.join(\",\")).each((function(){var t=n.select(this),e=this.style.fill;e&&-1!==e.indexOf(\"url(\")&&t.style(\"fill\",e.replace(l,\"TOBESTRIPPED\"));var r=this.style.stroke;r&&-1!==r.indexOf(\"url(\")&&t.style(\"stroke\",r.replace(l,\"TOBESTRIPPED\"))})),\"pdf\"!==e&&\"eps\"!==e||p.selectAll(\"#MathJax_SVG_glyphs path\").attr(\"stroke-width\",0),p.node().setAttributeNS(s.xmlns,\"xmlns\",s.svg),p.node().setAttributeNS(s.xmlns,\"xmlns:xlink\",s.xlink),\"svg\"===e&&r&&(p.attr(\"width\",r*m),p.attr(\"height\",r*g),p.attr(\"viewBox\",\"0 0 \"+m+\" \"+g));var T=(new window.XMLSerializer).serializeToString(p.node());return T=function(t){var e=n.select(\"body\").append(\"div\").style({display:\"none\"}).html(\"\"),r=t.replace(/(&[^;]*;)/gi,(function(t){return\"&lt;\"===t?\"&#60;\":\"&rt;\"===t?\"&#62;\":-1!==t.indexOf(\"<\")||-1!==t.indexOf(\">\")?\"\":e.html(t).text()}));return e.remove(),r}(T),T=(T=T.replace(/&(?!\\w+;|\\#[0-9]+;| \\#x[0-9A-F]+;)/g,\"&amp;\")).replace(c,\"'\"),i.isIE()&&(T=(T=(T=T.replace(/\"/gi,\"'\")).replace(/(\\('#)([^']*)('\\))/gi,'(\"#$2\")')).replace(/(\\\\')/gi,'\"')),T}},{\"../components/color\":662,\"../components/drawing\":684,\"../constants/xmlns_namespaces\":776,\"../lib\":799,\"@plotly/d3\":58}],936:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e){for(var r=0;r<t.length;r++)t[r].i=r;n.mergeArray(e.text,t,\"tx\"),n.mergeArray(e.hovertext,t,\"htx\");var i=e.marker;if(i){n.mergeArray(i.opacity,t,\"mo\",!0),n.mergeArray(i.color,t,\"mc\");var a=i.line;a&&(n.mergeArray(a.color,t,\"mlc\"),n.mergeArrayCastPositive(a.width,t,\"mlw\"))}}},{\"../../lib\":799}],937:[function(t,e,r){\"use strict\";var n=t(\"../scatter/attributes\"),i=t(\"../../plots/cartesian/axis_format_attributes\").axisHoverFormat,a=t(\"../../plots/template_attributes\").hovertemplateAttrs,o=t(\"../../plots/template_attributes\").texttemplateAttrs,s=t(\"../../components/colorscale/attributes\"),l=t(\"../../plots/font_attributes\"),c=t(\"./constants\"),u=t(\"../../components/drawing/attributes\").pattern,f=t(\"../../lib/extend\").extendFlat,h=l({editType:\"calc\",arrayOk:!0,colorEditType:\"style\"}),p=f({},n.marker.line.width,{dflt:0}),d=f({width:p,editType:\"calc\"},s(\"marker.line\")),m=f({line:d,editType:\"calc\"},s(\"marker\"),{opacity:{valType:\"number\",arrayOk:!0,dflt:1,min:0,max:1,editType:\"style\"},pattern:u});e.exports={x:n.x,x0:n.x0,dx:n.dx,y:n.y,y0:n.y0,dy:n.dy,xperiod:n.xperiod,yperiod:n.yperiod,xperiod0:n.xperiod0,yperiod0:n.yperiod0,xperiodalignment:n.xperiodalignment,yperiodalignment:n.yperiodalignment,xhoverformat:i(\"x\"),yhoverformat:i(\"y\"),text:n.text,texttemplate:o({editType:\"plot\"},{keys:c.eventDataKeys}),hovertext:n.hovertext,hovertemplate:a({},{keys:c.eventDataKeys}),textposition:{valType:\"enumerated\",values:[\"inside\",\"outside\",\"auto\",\"none\"],dflt:\"auto\",arrayOk:!0,editType:\"calc\"},insidetextanchor:{valType:\"enumerated\",values:[\"end\",\"middle\",\"start\"],dflt:\"end\",editType:\"plot\"},textangle:{valType:\"angle\",dflt:\"auto\",editType:\"plot\"},textfont:f({},h,{}),insidetextfont:f({},h,{}),outsidetextfont:f({},h,{}),constraintext:{valType:\"enumerated\",values:[\"inside\",\"outside\",\"both\",\"none\"],dflt:\"both\",editType:\"calc\"},cliponaxis:f({},n.cliponaxis,{}),orientation:{valType:\"enumerated\",values:[\"v\",\"h\"],editType:\"calc+clearAxisTypes\"},base:{valType:\"any\",dflt:null,arrayOk:!0,editType:\"calc\"},offset:{valType:\"number\",dflt:null,arrayOk:!0,editType:\"calc\"},width:{valType:\"number\",dflt:null,min:0,arrayOk:!0,editType:\"calc\"},marker:m,offsetgroup:{valType:\"string\",dflt:\"\",editType:\"calc\"},alignmentgroup:{valType:\"string\",dflt:\"\",editType:\"calc\"},selected:{marker:{opacity:n.selected.marker.opacity,color:n.selected.marker.color,editType:\"style\"},textfont:n.selected.textfont,editType:\"style\"},unselected:{marker:{opacity:n.unselected.marker.opacity,color:n.unselected.marker.color,editType:\"style\"},textfont:n.unselected.textfont,editType:\"style\"},_deprecated:{bardir:{valType:\"enumerated\",editType:\"calc\",values:[\"v\",\"h\"]}}}},{\"../../components/colorscale/attributes\":669,\"../../components/drawing/attributes\":683,\"../../lib/extend\":789,\"../../plots/cartesian/axis_format_attributes\":852,\"../../plots/font_attributes\":878,\"../../plots/template_attributes\":922,\"../scatter/attributes\":1214,\"./constants\":939}],938:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"../../plots/cartesian/align_period\"),a=t(\"../../components/colorscale/helpers\").hasColorscale,o=t(\"../../components/colorscale/calc\"),s=t(\"./arrays_to_calcdata\"),l=t(\"../scatter/calc_selection\");e.exports=function(t,e){var r,c,u,f,h=n.getFromId(t,e.xaxis||\"x\"),p=n.getFromId(t,e.yaxis||\"y\"),d={msUTC:!(!e.base&&0!==e.base)};\"h\"===e.orientation?(r=h.makeCalcdata(e,\"x\",d),u=p.makeCalcdata(e,\"y\"),c=i(e,p,\"y\",u),f=!!e.yperiodalignment):(r=p.makeCalcdata(e,\"y\",d),u=h.makeCalcdata(e,\"x\"),c=i(e,h,\"x\",u),f=!!e.xperiodalignment);for(var m=Math.min(c.length,r.length),g=new Array(m),v=0;v<m;v++)g[v]={p:c[v],s:r[v]},f&&(g[v].orig_p=u[v]),e.ids&&(g[v].id=String(e.ids[v]));return a(e,\"marker\")&&o(t,e,{vals:e.marker.color,containerStr:\"marker\",cLetter:\"c\"}),a(e,\"marker.line\")&&o(t,e,{vals:e.marker.line.color,containerStr:\"marker.line\",cLetter:\"c\"}),s(g,e),l(g,e),g}},{\"../../components/colorscale/calc\":670,\"../../components/colorscale/helpers\":673,\"../../plots/cartesian/align_period\":846,\"../../plots/cartesian/axes\":849,\"../scatter/calc_selection\":1216,\"./arrays_to_calcdata\":936}],939:[function(t,e,r){\"use strict\";e.exports={TEXTPAD:3,eventDataKeys:[\"value\",\"label\"]}},{}],940:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\").isArrayOrTypedArray,a=t(\"../../constants/numerical\").BADNUM,o=t(\"../../registry\"),s=t(\"../../plots/cartesian/axes\"),l=t(\"../../plots/cartesian/constraints\").getAxisGroup,c=t(\"./sieve.js\");function u(t,e,r,o,u){if(o.length){var b,_,w,T;switch(function(t,e){var r,a;for(r=0;r<e.length;r++){var o,s=e[r],l=s[0].trace,c=\"funnel\"===l.type?l._base:l.base,u=\"h\"===l.orientation?l.xcalendar:l.ycalendar,f=\"category\"===t.type||\"multicategory\"===t.type?function(){return null}:t.d2c;if(i(c)){for(a=0;a<Math.min(c.length,s.length);a++)o=f(c[a],0,u),n(o)?(s[a].b=+o,s[a].hasB=1):s[a].b=0;for(;a<s.length;a++)s[a].b=0}else{o=f(c,0,u);var h=n(o);for(o=h?o:0,a=0;a<s.length;a++)s[a].b=o,h&&(s[a].hasB=1)}}}(r,o),u.mode){case\"overlay\":f(e,r,o,u);break;case\"group\":for(b=[],_=[],w=0;w<o.length;w++)void 0===(T=o[w])[0].trace.offset?_.push(T):b.push(T);_.length&&function(t,e,r,n,i){var o=new c(n,{posAxis:e,sepNegVal:!1,overlapNoMerge:!i.norm});(function(t,e,r,n){for(var i=t._fullLayout,a=r.positions,o=r.distinctPositions,s=r.minDiff,c=r.traces,u=c.length,f=a.length!==o.length,h=s*(1-n.gap),g=l(i,e._id)+c[0][0].trace.orientation,v=i._alignmentOpts[g]||{},y=0;y<u;y++){var x,b,_=c[y],w=_[0].trace,T=v[w.alignmentgroup]||{},k=Object.keys(T.offsetGroups||{}).length,M=(x=k?h/k:f?h/u:h)*(1-(n.groupgap||0));b=k?((2*w._offsetIndex+1-k)*x-M)/2:f?((2*y+1-u)*x-M)/2:-M/2;var A=_[0].t;A.barwidth=M,A.poffset=b,A.bargroupwidth=h,A.bardelta=s}r.binWidth=c[0][0].t.barwidth/100,p(r),d(e,r),m(e,r,f)})(t,e,o,i),function(t,e){for(var r=t.traces,n=0;n<r.length;n++){var i=r[n];if(void 0===i[0].trace.base)for(var o=new c([i],{posAxis:e,sepNegVal:!0,overlapNoMerge:!0}),s=0;s<i.length;s++){var l=i[s];if(l.p!==a){var u=o.put(l.p,l.b+l.s);u&&(l.b=u)}}}}(o,e),i.norm?(v(o),y(r,o,i)):g(r,o)}(t,e,r,_,u),b.length&&f(e,r,b,u);break;case\"stack\":case\"relative\":for(b=[],_=[],w=0;w<o.length;w++)void 0===(T=o[w])[0].trace.base?_.push(T):b.push(T);_.length&&function(t,e,r,n,i){var o=new c(n,{posAxis:e,sepNegVal:\"relative\"===i.mode,overlapNoMerge:!(i.norm||\"stack\"===i.mode||\"relative\"===i.mode)});h(e,o,i),function(t,e,r){var n,i,o,l,c,u,f=x(t),h=e.traces;for(l=0;l<h.length;l++)if(n=h[l],\"funnel\"===(i=n[0].trace).type)for(c=0;c<n.length;c++)(u=n[c]).s!==a&&e.put(u.p,-.5*u.s);for(l=0;l<h.length;l++){n=h[l],i=n[0].trace,o=\"funnel\"===i.type;var p=[];for(c=0;c<n.length;c++)if((u=n[c]).s!==a){var d;d=o?u.s:u.s+u.b;var m=e.put(u.p,d),g=m+d;u.b=m,u[f]=g,r.norm||(p.push(g),u.hasB&&p.push(m))}r.norm||(i._extremes[t._id]=s.findExtremes(t,p,{tozero:!0,padded:!0}))}}(r,o,i);for(var l=0;l<n.length;l++)for(var u=n[l],f=0;f<u.length;f++){var p=u[f];if(p.s!==a)p.b+p.s===o.get(p.p,p.s)&&(p._outmost=!0)}i.norm&&y(r,o,i)}(0,e,r,_,u),b.length&&f(e,r,b,u)}!function(t,e){var r,i,a,o=x(e),s={},l=1/0,c=-1/0;for(r=0;r<t.length;r++)for(a=t[r],i=0;i<a.length;i++){var u=a[i].p;n(u)&&(l=Math.min(l,u),c=Math.max(c,u))}var f=1e4/(c-l),h=s.round=function(t){return String(Math.round(f*(t-l)))};for(r=0;r<t.length;r++){(a=t[r])[0].t.extents=s;var p=a[0].t.poffset,d=Array.isArray(p);for(i=0;i<a.length;i++){var m=a[i],g=m[o]-m.w/2;if(n(g)){var v=m[o]+m.w/2,y=h(m.p);s[y]?s[y]=[Math.min(g,s[y][0]),Math.max(v,s[y][1])]:s[y]=[g,v]}m.p0=m.p+(d?p[i]:p),m.p1=m.p0+m.w,m.s0=m.b,m.s1=m.s0+m.s}}}(o,e)}}function f(t,e,r,n){for(var i=0;i<r.length;i++){var a=r[i],o=new c([a],{posAxis:t,sepNegVal:!1,overlapNoMerge:!n.norm});h(t,o,n),n.norm?(v(o),y(e,o,n)):g(e,o)}}function h(t,e,r){for(var n=e.minDiff,i=e.traces,a=n*(1-r.gap),o=a*(1-(r.groupgap||0)),s=-o/2,l=0;l<i.length;l++){var c=i[l][0].t;c.barwidth=o,c.poffset=s,c.bargroupwidth=a,c.bardelta=n}e.binWidth=i[0][0].t.barwidth/100,p(e),d(t,e),m(t,e)}function p(t){var e,r,a=t.traces;for(e=0;e<a.length;e++){var o,s=a[e],l=s[0],c=l.trace,u=l.t,f=c._offset||c.offset,h=u.poffset;if(i(f)){for(o=Array.prototype.slice.call(f,0,s.length),r=0;r<o.length;r++)n(o[r])||(o[r]=h);for(r=o.length;r<s.length;r++)o.push(h);u.poffset=o}else void 0!==f&&(u.poffset=f);var p=c._width||c.width,d=u.barwidth;if(i(p)){var m=Array.prototype.slice.call(p,0,s.length);for(r=0;r<m.length;r++)n(m[r])||(m[r]=d);for(r=m.length;r<s.length;r++)m.push(d);if(u.barwidth=m,void 0===f){for(o=[],r=0;r<s.length;r++)o.push(h+(d-m[r])/2);u.poffset=o}}else void 0!==p&&(u.barwidth=p,void 0===f&&(u.poffset=h+(d-p)/2))}}function d(t,e){for(var r=e.traces,n=x(t),i=0;i<r.length;i++)for(var a=r[i],o=a[0].t,s=o.poffset,l=Array.isArray(s),c=o.barwidth,u=Array.isArray(c),f=0;f<a.length;f++){var h=a[f],p=h.w=u?c[f]:c;h[n]=h.p+(l?s[f]:s)+p/2}}function m(t,e,r){var n=e.traces,i=e.minDiff/2;s.minDtick(t,e.minDiff,e.distinctPositions[0],r);for(var a=0;a<n.length;a++){var o,l,c,u,f=n[a],h=f[0],p=h.trace,d=[];for(u=0;u<f.length;u++)l=(o=f[u]).p-i,c=o.p+i,d.push(l,c);if(p.width||p.offset){var m=h.t,g=m.poffset,v=m.barwidth,y=Array.isArray(g),x=Array.isArray(v);for(u=0;u<f.length;u++){o=f[u];var b=y?g[u]:g,_=x?v[u]:v;c=(l=o.p+b)+_,d.push(l,c)}}p._extremes[t._id]=s.findExtremes(t,d,{padded:!1})}}function g(t,e){for(var r=e.traces,n=x(t),i=0;i<r.length;i++){for(var a=r[i],o=a[0].trace,l=[],c=!1,u=0;u<a.length;u++){var f=a[u],h=f.b,p=h+f.s;f[n]=p,l.push(p),f.hasB&&l.push(h),f.hasB&&f.b||(c=!0)}o._extremes[t._id]=s.findExtremes(t,l,{tozero:c,padded:!0})}}function v(t){for(var e=t.traces,r=0;r<e.length;r++)for(var n=e[r],i=0;i<n.length;i++){var o=n[i];o.s!==a&&t.put(o.p,o.b+o.s)}}function y(t,e,r){var i=e.traces,o=x(t),l=\"fraction\"===r.norm?1:100,c=l/1e9,u=t.l2c(t.c2l(0)),f=\"stack\"===r.mode?l:u;function h(e){return n(t.c2l(e))&&(e<u-c||e>f+c||!n(u))}for(var p=0;p<i.length;p++){for(var d=i[p],m=d[0].trace,g=[],v=!1,y=!1,b=0;b<d.length;b++){var _=d[b];if(_.s!==a){var w=Math.abs(l/e.get(_.p,_.s));_.b*=w,_.s*=w;var T=_.b,k=T+_.s;_[o]=k,g.push(k),y=y||h(k),_.hasB&&(g.push(T),y=y||h(T)),_.hasB&&_.b||(v=!0)}}m._extremes[t._id]=s.findExtremes(t,g,{tozero:v,padded:y})}}function x(t){return t._id.charAt(0)}e.exports={crossTraceCalc:function(t,e){for(var r=e.xaxis,n=e.yaxis,i=t._fullLayout,a=t._fullData,s=t.calcdata,l=[],c=[],f=0;f<a.length;f++){var h=a[f];if(!0===h.visible&&o.traceIs(h,\"bar\")&&h.xaxis===r._id&&h.yaxis===n._id&&(\"h\"===h.orientation?l.push(s[f]):c.push(s[f]),h._computePh))for(var p=t.calcdata[f],d=0;d<p.length;d++)\"function\"==typeof p[d].ph0&&(p[d].ph0=p[d].ph0()),\"function\"==typeof p[d].ph1&&(p[d].ph1=p[d].ph1())}var m={xCat:\"category\"===r.type||\"multicategory\"===r.type,yCat:\"category\"===n.type||\"multicategory\"===n.type,mode:i.barmode,norm:i.barnorm,gap:i.bargap,groupgap:i.bargroupgap};u(t,r,n,c,m),u(t,n,r,l,m)},setGroupPositions:u}},{\"../../constants/numerical\":775,\"../../lib\":799,\"../../plots/cartesian/axes\":849,\"../../plots/cartesian/constraints\":857,\"../../registry\":927,\"./sieve.js\":950,\"fast-isnumeric\":245}],941:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/color\"),a=t(\"../../registry\"),o=t(\"../scatter/xy_defaults\"),s=t(\"../scatter/period_defaults\"),l=t(\"./style_defaults\"),c=t(\"../../plots/cartesian/constraints\").getAxisGroup,u=t(\"./attributes\"),f=n.coerceFont;function h(t,e,r,n){var i=e.orientation,a=e[{v:\"x\",h:\"y\"}[i]+\"axis\"],o=c(r,a)+i,s=r._alignmentOpts||{},l=n(\"alignmentgroup\"),u=s[o];u||(u=s[o]={});var f=u[l];f?f.traces.push(e):f=u[l]={traces:[e],alignmentIndex:Object.keys(u).length,offsetGroups:{}};var h=n(\"offsetgroup\"),p=f.offsetGroups,d=p[h];h&&(d||(d=p[h]={offsetIndex:Object.keys(p).length}),e._offsetIndex=d.offsetIndex)}function p(t,e,r,i,a,o){var s=!(!1===(o=o||{}).moduleHasSelected),l=!(!1===o.moduleHasUnselected),c=!(!1===o.moduleHasConstrain),u=!(!1===o.moduleHasCliponaxis),h=!(!1===o.moduleHasTextangle),p=!(!1===o.moduleHasInsideanchor),d=!!o.hasPathbar,m=Array.isArray(a)||\"auto\"===a,g=m||\"inside\"===a,v=m||\"outside\"===a;if(g||v){var y=f(i,\"textfont\",r.font),x=n.extendFlat({},y),b=!(t.textfont&&t.textfont.color);if(b&&delete x.color,f(i,\"insidetextfont\",x),d){var _=n.extendFlat({},y);b&&delete _.color,f(i,\"pathbar.textfont\",_)}v&&f(i,\"outsidetextfont\",y),s&&i(\"selected.textfont.color\"),l&&i(\"unselected.textfont.color\"),c&&i(\"constraintext\"),u&&i(\"cliponaxis\"),h&&i(\"textangle\"),i(\"texttemplate\")}g&&p&&i(\"insidetextanchor\")}e.exports={supplyDefaults:function(t,e,r,c){function f(r,i){return n.coerce(t,e,u,r,i)}if(o(t,e,c,f)){s(t,e,c,f),f(\"xhoverformat\"),f(\"yhoverformat\"),f(\"orientation\",e.x&&!e.y?\"h\":\"v\"),f(\"base\"),f(\"offset\"),f(\"width\"),f(\"text\"),f(\"hovertext\"),f(\"hovertemplate\");var h=f(\"textposition\");p(t,e,c,f,h,{moduleHasSelected:!0,moduleHasUnselected:!0,moduleHasConstrain:!0,moduleHasCliponaxis:!0,moduleHasTextangle:!0,moduleHasInsideanchor:!0}),l(t,e,f,r,c);var d=(e.marker.line||{}).color,m=a.getComponentMethod(\"errorbars\",\"supplyDefaults\");m(t,e,d||i.defaultLine,{axis:\"y\"}),m(t,e,d||i.defaultLine,{axis:\"x\",inherit:\"y\"}),n.coerceSelectionMarkerOpacity(e,f)}else e.visible=!1},crossTraceDefaults:function(t,e){var r;function i(t){return n.coerce(r._input,r,u,t)}if(\"group\"===e.barmode)for(var a=0;a<t.length;a++)\"bar\"===(r=t[a]).type&&(r._input,h(0,r,e,i))},handleGroupingDefaults:h,handleText:p}},{\"../../components/color\":662,\"../../lib\":799,\"../../plots/cartesian/constraints\":857,\"../../registry\":927,\"../scatter/period_defaults\":1234,\"../scatter/xy_defaults\":1241,\"./attributes\":937,\"./style_defaults\":952}],942:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){return t.x=\"xVal\"in e?e.xVal:e.x,t.y=\"yVal\"in e?e.yVal:e.y,e.xa&&(t.xaxis=e.xa),e.ya&&(t.yaxis=e.ya),\"h\"===r.orientation?(t.label=t.y,t.value=t.x):(t.label=t.x,t.value=t.y),t}},{}],943:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"tinycolor2\"),a=t(\"../../lib\").isArrayOrTypedArray;r.coerceString=function(t,e,r){if(\"string\"==typeof e){if(e||!t.noBlank)return e}else if((\"number\"==typeof e||!0===e)&&!t.strict)return String(e);return void 0!==r?r:t.dflt},r.coerceNumber=function(t,e,r){if(n(e)){e=+e;var i=t.min,a=t.max;if(!(void 0!==i&&e<i||void 0!==a&&e>a))return e}return void 0!==r?r:t.dflt},r.coerceColor=function(t,e,r){return i(e).isValid()?e:void 0!==r?r:t.dflt},r.coerceEnumerated=function(t,e,r){return t.coerceNumber&&(e=+e),-1!==t.values.indexOf(e)?e:void 0!==r?r:t.dflt},r.getValue=function(t,e){var r;return Array.isArray(t)?e<t.length&&(r=t[e]):r=t,r},r.getLineWidth=function(t,e){return 0<e.mlw?e.mlw:a(t.marker.line.width)?0:t.marker.line.width}},{\"../../lib\":799,\"fast-isnumeric\":245,tinycolor2:594}],944:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx\"),i=t(\"../../registry\"),a=t(\"../../components/color\"),o=t(\"../../lib\").fillText,s=t(\"./helpers\").getLineWidth,l=t(\"../../plots/cartesian/axes\").hoverLabelText,c=t(\"../../constants/numerical\").BADNUM;function u(t,e,r,i,a){var s,u,f,h,p,d,m,g=t.cd,v=g[0].trace,y=g[0].t,x=\"closest\"===i,b=\"waterfall\"===v.type,_=t.maxHoverDistance,w=t.maxSpikeDistance;\"h\"===v.orientation?(s=r,u=e,f=\"y\",h=\"x\",p=I,d=C):(s=e,u=r,f=\"x\",h=\"y\",d=I,p=C);var T=v[f+\"period\"];function k(t){return A(t,-1)}function M(t){return A(t,1)}function A(t,e){return T?t.p+e*Math.abs(t.p-t.orig_p):t[f]+e*t.w/2}var S=x||T?k:function(t){return Math.min(k(t),t.p-y.bardelta/2)},E=x||T?M:function(t){return Math.max(M(t),t.p+y.bardelta/2)};function L(t,e,r){return a.finiteRange&&(r=0),n.inbox(t-s,e-s,r+Math.min(1,Math.abs(e-t)/m)-1)}function C(t){return L(S(t),E(t),_)}function P(t){var e=t[h];if(b){var r=Math.abs(t.rawS)||0;u>0?e+=r:u<0&&(e-=r)}return e}function I(t){var e=u,r=t.b,i=P(t);return n.inbox(r-e,i-e,_+(i-e)/(i-r)-1)}var O=t[f+\"a\"],z=t[h+\"a\"];m=Math.abs(O.r2c(O.range[1])-O.r2c(O.range[0]));var D=n.getDistanceFunction(i,p,d,(function(t){return(p(t)+d(t))/2}));if(n.getClosest(g,D,t),!1!==t.index&&g[t.index].p!==c){x||(S=function(t){return Math.min(k(t),t.p-y.bargroupwidth/2)},E=function(t){return Math.max(M(t),t.p+y.bargroupwidth/2)});var R=g[t.index],F=v.base?R.b+R.s:R.s;t[h+\"0\"]=t[h+\"1\"]=z.c2p(R[h],!0),t[h+\"LabelVal\"]=F;var B=y.extents[y.extents.round(R.p)];t[f+\"0\"]=O.c2p(x?S(R):B[0],!0),t[f+\"1\"]=O.c2p(x?E(R):B[1],!0);var N=void 0!==R.orig_p;return t[f+\"LabelVal\"]=N?R.orig_p:R.p,t.labelLabel=l(O,t[f+\"LabelVal\"],v[f+\"hoverformat\"]),t.valueLabel=l(z,t[h+\"LabelVal\"],v[h+\"hoverformat\"]),t.baseLabel=l(z,R.b,v[h+\"hoverformat\"]),t.spikeDistance=(function(t){var e=u,r=t.b,i=P(t);return n.inbox(r-e,i-e,w+(i-e)/(i-r)-1)}(R)+function(t){return L(k(t),M(t),w)}(R))/2,t[f+\"Spike\"]=O.c2p(R.p,!0),o(R,v,t),t.hovertemplate=v.hovertemplate,t}}function f(t,e){var r=e.mcc||t.marker.color,n=e.mlcc||t.marker.line.color,i=s(t,e);return a.opacity(r)?r:a.opacity(n)&&i?n:void 0}e.exports={hoverPoints:function(t,e,r,n,a){var o=u(t,e,r,n,a);if(o){var s=o.cd,l=s[0].trace,c=s[o.index];return o.color=f(l,c),i.getComponentMethod(\"errorbars\",\"hoverInfo\")(c,l,o),[o]}},hoverOnBars:u,getTraceColor:f}},{\"../../components/color\":662,\"../../components/fx\":702,\"../../constants/numerical\":775,\"../../lib\":799,\"../../plots/cartesian/axes\":849,\"../../registry\":927,\"./helpers\":943}],945:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),layoutAttributes:t(\"./layout_attributes\"),supplyDefaults:t(\"./defaults\").supplyDefaults,crossTraceDefaults:t(\"./defaults\").crossTraceDefaults,supplyLayoutDefaults:t(\"./layout_defaults\"),calc:t(\"./calc\"),crossTraceCalc:t(\"./cross_trace_calc\").crossTraceCalc,colorbar:t(\"../scatter/marker_colorbar\"),arraysToCalcdata:t(\"./arrays_to_calcdata\"),plot:t(\"./plot\").plot,style:t(\"./style\").style,styleOnSelect:t(\"./style\").styleOnSelect,hoverPoints:t(\"./hover\").hoverPoints,eventData:t(\"./event_data\"),selectPoints:t(\"./select\"),moduleType:\"trace\",name:\"bar\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"bar-like\",\"cartesian\",\"svg\",\"bar\",\"oriented\",\"errorBarsOK\",\"showLegend\",\"zoomScale\"],animatable:!0,meta:{}}},{\"../../plots/cartesian\":863,\"../scatter/marker_colorbar\":1232,\"./arrays_to_calcdata\":936,\"./attributes\":937,\"./calc\":938,\"./cross_trace_calc\":940,\"./defaults\":941,\"./event_data\":942,\"./hover\":944,\"./layout_attributes\":946,\"./layout_defaults\":947,\"./plot\":948,\"./select\":949,\"./style\":951}],946:[function(t,e,r){\"use strict\";e.exports={barmode:{valType:\"enumerated\",values:[\"stack\",\"group\",\"overlay\",\"relative\"],dflt:\"group\",editType:\"calc\"},barnorm:{valType:\"enumerated\",values:[\"\",\"fraction\",\"percent\"],dflt:\"\",editType:\"calc\"},bargap:{valType:\"number\",min:0,max:1,editType:\"calc\"},bargroupgap:{valType:\"number\",min:0,max:1,dflt:0,editType:\"calc\"}}},{}],947:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../../lib\"),o=t(\"./layout_attributes\");e.exports=function(t,e,r){function s(r,n){return a.coerce(t,e,o,r,n)}for(var l=!1,c=!1,u=!1,f={},h=s(\"barmode\"),p=0;p<r.length;p++){var d=r[p];if(n.traceIs(d,\"bar\")&&d.visible){if(l=!0,\"group\"===h){var m=d.xaxis+d.yaxis;f[m]&&(u=!0),f[m]=!0}if(d.visible&&\"histogram\"===d.type)\"category\"!==i.getFromId({_fullLayout:e},d[\"v\"===d.orientation?\"xaxis\":\"yaxis\"]).type&&(c=!0)}}l?(\"overlay\"!==h&&s(\"barnorm\"),s(\"bargap\",c&&!u?0:.2),s(\"bargroupgap\")):delete e.barmode}},{\"../../lib\":799,\"../../plots/cartesian/axes\":849,\"../../registry\":927,\"./layout_attributes\":946}],948:[function(t,e,r){\"use strict\";var n=t(\"@plotly/d3\"),i=t(\"fast-isnumeric\"),a=t(\"../../lib\"),o=t(\"../../lib/svg_text_utils\"),s=t(\"../../components/color\"),l=t(\"../../components/drawing\"),c=t(\"../../registry\"),u=t(\"../../plots/cartesian/axes\").tickText,f=t(\"./uniform_text\"),h=f.recordMinTextSize,p=f.clearMinTextSize,d=t(\"./style\"),m=t(\"./helpers\"),g=t(\"./constants\"),v=t(\"./attributes\"),y=v.text,x=v.textposition,b=t(\"../../components/fx/helpers\").appendArrayPointValue,_=g.TEXTPAD;function w(t){return t.id}function T(t){if(t.ids)return w}function k(t,e){return t<e?1:-1}function M(t,e,r,n){var i;return!e.uniformtext.mode&&A(r)?(n&&(i=n()),t.transition().duration(r.duration).ease(r.easing).each(\"end\",(function(){i&&i()})).each(\"interrupt\",(function(){i&&i()}))):t}function A(t){return t&&t.duration>0}function S(t){return\"auto\"===t?0:t}function E(t,e){var r=Math.PI/180*e,n=Math.abs(Math.sin(r)),i=Math.abs(Math.cos(r));return{x:t.width*i+t.height*n,y:t.width*n+t.height*i}}function L(t,e,r,n,i,a){var o=!!a.isHorizontal,s=!!a.constrained,l=a.angle||0,c=a.anchor||\"end\",u=\"end\"===c,f=\"start\"===c,h=((a.leftToRight||0)+1)/2,p=1-h,d=i.width,m=i.height,g=Math.abs(e-t),v=Math.abs(n-r),y=g>2*_&&v>2*_?_:0;g-=2*y,v-=2*y;var x=S(l);\"auto\"!==l||d<=g&&m<=v||!(d>g||m>v)||(d>v||m>g)&&d<m==g<v||(x+=90);var b=E(i,x),w=1;s&&(w=Math.min(1,g/b.x,v/b.y));var T=i.left*p+i.right*h,M=(i.top+i.bottom)/2,A=(t+_)*p+(e-_)*h,L=(r+n)/2,C=0,P=0;if(f||u){var I=(o?b.x:b.y)/2,O=o?k(t,e):k(r,n);o?f?(A=t+O*y,C=-O*I):(A=e-O*y,C=O*I):f?(L=r+O*y,P=-O*I):(L=n-O*y,P=O*I)}return{textX:T,textY:M,targetX:A,targetY:L,anchorX:C,anchorY:P,scale:w,rotate:x}}e.exports={plot:function(t,e,r,f,g,v){var w=e.xaxis,C=e.yaxis,P=t._fullLayout;g||(g={mode:P.barmode,norm:P.barmode,gap:P.bargap,groupgap:P.bargroupgap},p(\"bar\",P));var I=a.makeTraceGroups(f,r,\"trace bars\").each((function(r){var c=n.select(this),f=r[0].trace,p=\"waterfall\"===f.type,I=\"funnel\"===f.type,O=\"bar\"===f.type||I,z=0;p&&f.connector.visible&&\"between\"===f.connector.mode&&(z=f.connector.line.width/2);var D=\"h\"===f.orientation,R=A(g),F=a.ensureSingle(c,\"g\",\"points\"),B=T(f),N=F.selectAll(\"g.point\").data(a.identity,B);N.enter().append(\"g\").classed(\"point\",!0),N.exit().remove(),N.each((function(c,p){var T,A,I=n.select(this),F=function(t,e,r,n){var i=[],a=[],o=n?e:r,s=n?r:e;return i[0]=o.c2p(t.s0,!0),a[0]=s.c2p(t.p0,!0),i[1]=o.c2p(t.s1,!0),a[1]=s.c2p(t.p1,!0),n?[i,a]:[a,i]}(c,w,C,D),B=F[0][0],N=F[0][1],j=F[1][0],U=F[1][1],V=0==(D?N-B:U-j);if(V&&O&&m.getLineWidth(f,c)&&(V=!1),V||(V=!(i(B)&&i(N)&&i(j)&&i(U))),c.isBlank=V,V&&(D?N=B:U=j),z&&!V&&(D?(B-=k(B,N)*z,N+=k(B,N)*z):(j-=k(j,U)*z,U+=k(j,U)*z)),\"waterfall\"===f.type){if(!V){var q=f[c.dir].marker;T=q.line.width,A=q.color}}else T=m.getLineWidth(f,c),A=c.mc||f.marker.color;function H(t){var e=n.round(T/2%1,2);return 0===g.gap&&0===g.groupgap?n.round(Math.round(t)-e,2):t}if(!t._context.staticPlot){var G=s.opacity(A)<1||T>.01?H:function(t,e,r){return r&&t===e?t:Math.abs(t-e)>=2?H(t):t>e?Math.ceil(t):Math.floor(t)};B=G(B,N,D),N=G(N,B,D),j=G(j,U,!D),U=G(U,j,!D)}var Y=M(a.ensureSingle(I,\"path\"),P,g,v);if(Y.style(\"vector-effect\",\"non-scaling-stroke\").attr(\"d\",isNaN((N-B)*(U-j))||V&&t._context.staticPlot?\"M0,0Z\":\"M\"+B+\",\"+j+\"V\"+U+\"H\"+N+\"V\"+j+\"Z\").call(l.setClipUrl,e.layerClipId,t),!P.uniformtext.mode&&R){var W=l.makePointStyleFns(f);l.singlePointStyle(c,Y,f,W,t)}!function(t,e,r,n,i,s,c,f,p,g,v){var w,T=e.xaxis,A=e.yaxis,C=t._fullLayout;function P(e,r,n){return a.ensureSingle(e,\"text\").text(r).attr({class:\"bartext bartext-\"+w,\"text-anchor\":\"middle\",\"data-notex\":1}).call(l.font,n).call(o.convertToTspans,t)}var I=n[0].trace,O=\"h\"===I.orientation,z=function(t,e,r,n,i){var o,s=e[0].trace;o=s.texttemplate?function(t,e,r,n,i){var o=e[0].trace,s=a.castOption(o,r,\"texttemplate\");if(!s)return\"\";var l,c,f,h,p=\"waterfall\"===o.type,d=\"funnel\"===o.type;\"h\"===o.orientation?(l=\"y\",c=i,f=\"x\",h=n):(l=\"x\",c=n,f=\"y\",h=i);function m(t){return u(h,h.c2l(t),!0).text}var g=e[r],v={};v.label=g.p,v.labelLabel=v[l+\"Label\"]=(y=g.p,u(c,c.c2l(y),!0).text);var y;var x=a.castOption(o,g.i,\"text\");(0===x||x)&&(v.text=x);v.value=g.s,v.valueLabel=v[f+\"Label\"]=m(g.s);var _={};b(_,o,g.i),p&&(v.delta=+g.rawS||g.s,v.deltaLabel=m(v.delta),v.final=g.v,v.finalLabel=m(v.final),v.initial=v.final-v.delta,v.initialLabel=m(v.initial));d&&(v.value=g.s,v.valueLabel=m(v.value),v.percentInitial=g.begR,v.percentInitialLabel=a.formatPercent(g.begR),v.percentPrevious=g.difR,v.percentPreviousLabel=a.formatPercent(g.difR),v.percentTotal=g.sumR,v.percenTotalLabel=a.formatPercent(g.sumR));var w=a.castOption(o,g.i,\"customdata\");w&&(v.customdata=w);return a.texttemplateString(s,v,t._d3locale,_,v,o._meta||{})}(t,e,r,n,i):s.textinfo?function(t,e,r,n){var i=t[0].trace,o=\"h\"===i.orientation,s=\"waterfall\"===i.type,l=\"funnel\"===i.type;function c(t){return u(o?r:n,+t,!0).text}var f,h=i.textinfo,p=t[e],d=h.split(\"+\"),m=[],g=function(t){return-1!==d.indexOf(t)};g(\"label\")&&m.push((v=t[e].p,u(o?n:r,v,!0).text));var v;g(\"text\")&&(0===(f=a.castOption(i,p.i,\"text\"))||f)&&m.push(f);if(s){var y=+p.rawS||p.s,x=p.v,b=x-y;g(\"initial\")&&m.push(c(b)),g(\"delta\")&&m.push(c(y)),g(\"final\")&&m.push(c(x))}if(l){g(\"value\")&&m.push(c(p.s));var _=0;g(\"percent initial\")&&_++,g(\"percent previous\")&&_++,g(\"percent total\")&&_++;var w=_>1;g(\"percent initial\")&&(f=a.formatPercent(p.begR),w&&(f+=\" of initial\"),m.push(f)),g(\"percent previous\")&&(f=a.formatPercent(p.difR),w&&(f+=\" of previous\"),m.push(f)),g(\"percent total\")&&(f=a.formatPercent(p.sumR),w&&(f+=\" of total\"),m.push(f))}return m.join(\"<br>\")}(e,r,n,i):m.getValue(s.text,r);return m.coerceString(y,o)}(C,n,i,T,A);w=function(t,e){var r=m.getValue(t.textposition,e);return m.coerceEnumerated(x,r)}(I,i);var D=\"stack\"===g.mode||\"relative\"===g.mode,R=n[i],F=!D||R._outmost;if(!z||\"none\"===w||(R.isBlank||s===c||f===p)&&(\"auto\"===w||\"inside\"===w))return void r.select(\"text\").remove();var B=C.font,N=d.getBarColor(n[i],I),j=d.getInsideTextFont(I,i,B,N),U=d.getOutsideTextFont(I,i,B),V=r.datum();O?\"log\"===T.type&&V.s0<=0&&(s=T.range[0]<T.range[1]?0:T._length):\"log\"===A.type&&V.s0<=0&&(f=A.range[0]<A.range[1]?A._length:0);var q,H,G,Y,W,X=Math.abs(c-s)-2*_,Z=Math.abs(p-f)-2*_;\"outside\"===w&&(F||R.hasB||(w=\"inside\"));if(\"auto\"===w)if(F){w=\"inside\",W=a.ensureUniformFontSize(t,j),q=P(r,z,W),H=l.bBox(q.node()),G=H.width,Y=H.height;var J=G<=X&&Y<=Z,K=G<=Z&&Y<=X,Q=O?X>=G*(Z/Y):Z>=Y*(X/G);G>0&&Y>0&&(J||K||Q)?w=\"inside\":(w=\"outside\",q.remove(),q=null)}else w=\"inside\";if(!q){W=a.ensureUniformFontSize(t,\"outside\"===w?U:j);var $=(q=P(r,z,W)).attr(\"transform\");if(q.attr(\"transform\",\"\"),H=l.bBox(q.node()),G=H.width,Y=H.height,q.attr(\"transform\",$),G<=0||Y<=0)return void q.remove()}var tt,et,rt=I.textangle;\"outside\"===w?(et=\"both\"===I.constraintext||\"outside\"===I.constraintext,tt=function(t,e,r,n,i,a){var o,s=!!a.isHorizontal,l=!!a.constrained,c=a.angle||0,u=i.width,f=i.height,h=Math.abs(e-t),p=Math.abs(n-r);o=s?p>2*_?_:0:h>2*_?_:0;var d=1;l&&(d=s?Math.min(1,p/f):Math.min(1,h/u));var m=S(c),g=E(i,m),v=(s?g.x:g.y)/2,y=(i.left+i.right)/2,x=(i.top+i.bottom)/2,b=(t+e)/2,w=(r+n)/2,T=0,M=0,A=s?k(e,t):k(r,n);s?(b=e-A*o,T=A*v):(w=n+A*o,M=-A*v);return{textX:y,textY:x,targetX:b,targetY:w,anchorX:T,anchorY:M,scale:d,rotate:m}}(s,c,f,p,H,{isHorizontal:O,constrained:et,angle:rt})):(et=\"both\"===I.constraintext||\"inside\"===I.constraintext,tt=L(s,c,f,p,H,{isHorizontal:O,constrained:et,angle:rt,anchor:I.insidetextanchor}));tt.fontSize=W.size,h(I.type,tt,C),R.transform=tt,M(q,C,g,v).attr(\"transform\",a.getTextTransform(tt))}(t,e,I,r,p,B,N,j,U,g,v),e.layerClipId&&l.hideOutsideRangePoint(c,I.select(\"text\"),w,C,f.xcalendar,f.ycalendar)}));var j=!1===f.cliponaxis;l.setClipUrl(c,j?null:e.layerClipId,t)}));c.getComponentMethod(\"errorbars\",\"plot\")(t,I,e,g)},toMoveInsideBar:L}},{\"../../components/color\":662,\"../../components/drawing\":684,\"../../components/fx/helpers\":698,\"../../lib\":799,\"../../lib/svg_text_utils\":824,\"../../plots/cartesian/axes\":849,\"../../registry\":927,\"./attributes\":937,\"./constants\":939,\"./helpers\":943,\"./style\":951,\"./uniform_text\":953,\"@plotly/d3\":58,\"fast-isnumeric\":245}],949:[function(t,e,r){\"use strict\";function n(t,e,r,n,i){var a=e.c2p(n?t.s0:t.p0,!0),o=e.c2p(n?t.s1:t.p1,!0),s=r.c2p(n?t.p0:t.s0,!0),l=r.c2p(n?t.p1:t.s1,!0);return i?[(a+o)/2,(s+l)/2]:n?[o,(s+l)/2]:[(a+o)/2,l]}e.exports=function(t,e){var r,i=t.cd,a=t.xaxis,o=t.yaxis,s=i[0].trace,l=\"funnel\"===s.type,c=\"h\"===s.orientation,u=[];if(!1===e)for(r=0;r<i.length;r++)i[r].selected=0;else for(r=0;r<i.length;r++){var f=i[r],h=\"ct\"in f?f.ct:n(f,a,o,c,l);e.contains(h,!1,r,t)?(u.push({pointNumber:r,x:a.c2d(f.x),y:o.c2d(f.y)}),f.selected=1):f.selected=0}return u}},{}],950:[function(t,e,r){\"use strict\";e.exports=a;var n=t(\"../../lib\").distinctVals,i=t(\"../../constants/numerical\").BADNUM;function a(t,e){this.traces=t,this.sepNegVal=e.sepNegVal,this.overlapNoMerge=e.overlapNoMerge;for(var r=1/0,a=[],o=0;o<t.length;o++){for(var s=t[o],l=0;l<s.length;l++){var c=s[l];c.p!==i&&a.push(c.p)}s[0]&&s[0].width1&&(r=Math.min(s[0].width1,r))}this.positions=a;var u=n(a);this.distinctPositions=u.vals,1===u.vals.length&&r!==1/0?this.minDiff=r:this.minDiff=Math.min(u.minDiff,r);var f=(e.posAxis||{}).type;\"category\"!==f&&\"multicategory\"!==f||(this.minDiff=1),this.binWidth=this.minDiff,this.bins={}}a.prototype.put=function(t,e){var r=this.getLabel(t,e),n=this.bins[r]||0;return this.bins[r]=n+e,n},a.prototype.get=function(t,e){var r=this.getLabel(t,e);return this.bins[r]||0},a.prototype.getLabel=function(t,e){return(e<0&&this.sepNegVal?\"v\":\"^\")+(this.overlapNoMerge?t:Math.round(t/this.binWidth))}},{\"../../constants/numerical\":775,\"../../lib\":799}],951:[function(t,e,r){\"use strict\";var n=t(\"@plotly/d3\"),i=t(\"../../components/color\"),a=t(\"../../components/drawing\"),o=t(\"../../lib\"),s=t(\"../../registry\"),l=t(\"./uniform_text\").resizeText,c=t(\"./attributes\"),u=c.textfont,f=c.insidetextfont,h=c.outsidetextfont,p=t(\"./helpers\");function d(t,e,r){a.pointStyle(t.selectAll(\"path\"),e,r),m(t,e,r)}function m(t,e,r){t.selectAll(\"text\").each((function(t){var i=n.select(this),s=o.ensureUniformFontSize(r,g(i,t,e,r));a.font(i,s)}))}function g(t,e,r,n){var i=n._fullLayout.font,a=r.textfont;if(t.classed(\"bartext-inside\")){var o=_(e,r);a=y(r,e.i,i,o)}else t.classed(\"bartext-outside\")&&(a=x(r,e.i,i));return a}function v(t,e,r){return b(u,t.textfont,e,r)}function y(t,e,r,n){var a=v(t,e,r);return(void 0===t._input.textfont||void 0===t._input.textfont.color||Array.isArray(t.textfont.color)&&void 0===t.textfont.color[e])&&(a={color:i.contrast(n),family:a.family,size:a.size}),b(f,t.insidetextfont,e,a)}function x(t,e,r){var n=v(t,e,r);return b(h,t.outsidetextfont,e,n)}function b(t,e,r,n){e=e||{};var i=p.getValue(e.family,r),a=p.getValue(e.size,r),o=p.getValue(e.color,r);return{family:p.coerceString(t.family,i,n.family),size:p.coerceNumber(t.size,a,n.size),color:p.coerceColor(t.color,o,n.color)}}function _(t,e){return\"waterfall\"===e.type?e[t.dir].marker.color:t.mcc||t.mc||e.marker.color}e.exports={style:function(t){var e=n.select(t).selectAll(\"g.barlayer\").selectAll(\"g.trace\");l(t,e,\"bar\");var r=e.size(),i=t._fullLayout;e.style(\"opacity\",(function(t){return t[0].trace.opacity})).each((function(t){(\"stack\"===i.barmode&&r>1||0===i.bargap&&0===i.bargroupgap&&!t[0].trace.marker.line.width)&&n.select(this).attr(\"shape-rendering\",\"crispEdges\")})),e.selectAll(\"g.points\").each((function(e){d(n.select(this),e[0].trace,t)})),s.getComponentMethod(\"errorbars\",\"style\")(e)},styleTextPoints:m,styleOnSelect:function(t,e,r){var i=e[0].trace;i.selectedpoints?function(t,e,r){a.selectedPointStyle(t.selectAll(\"path\"),e),function(t,e,r){t.each((function(t){var i,s=n.select(this);if(t.selected){i=o.ensureUniformFontSize(r,g(s,t,e,r));var l=e.selected.textfont&&e.selected.textfont.color;l&&(i.color=l),a.font(s,i)}else a.selectedTextStyle(s,e)}))}(t.selectAll(\"text\"),e,r)}(r,i,t):(d(r,i,t),s.getComponentMethod(\"errorbars\",\"style\")(r))},getInsideTextFont:y,getOutsideTextFont:x,getBarColor:_,resizeText:l}},{\"../../components/color\":662,\"../../components/drawing\":684,\"../../lib\":799,\"../../registry\":927,\"./attributes\":937,\"./helpers\":943,\"./uniform_text\":953,\"@plotly/d3\":58}],952:[function(t,e,r){\"use strict\";var n=t(\"../../components/color\"),i=t(\"../../components/colorscale/helpers\").hasColorscale,a=t(\"../../components/colorscale/defaults\"),o=t(\"../../lib\").coercePattern;e.exports=function(t,e,r,s,l){var c=r(\"marker.color\",s),u=i(t,\"marker\");u&&a(t,e,l,r,{prefix:\"marker.\",cLetter:\"c\"}),r(\"marker.line.color\",n.defaultLine),i(t,\"marker.line\")&&a(t,e,l,r,{prefix:\"marker.line.\",cLetter:\"c\"}),r(\"marker.line.width\"),r(\"marker.opacity\"),o(r,\"marker.pattern\",c,u),r(\"selected.marker.color\"),r(\"unselected.marker.color\")}},{\"../../components/color\":662,\"../../components/colorscale/defaults\":672,\"../../components/colorscale/helpers\":673,\"../../lib\":799}],953:[function(t,e,r){\"use strict\";var n=t(\"@plotly/d3\"),i=t(\"../../lib\");function a(t){return\"_\"+t+\"Text_minsize\"}e.exports={recordMinTextSize:function(t,e,r){if(r.uniformtext.mode){var n=a(t),i=r.uniformtext.minsize,o=e.scale*e.fontSize;e.hide=o<i,r[n]=r[n]||1/0,e.hide||(r[n]=Math.min(r[n],Math.max(o,i)))}},clearMinTextSize:function(t,e){e[a(t)]=void 0},resizeText:function(t,e,r){var a=t._fullLayout,o=a[\"_\"+r+\"Text_minsize\"];if(o){var s,l=\"hide\"===a.uniformtext.mode;switch(r){case\"funnelarea\":case\"pie\":case\"sunburst\":s=\"g.slice\";break;case\"treemap\":case\"icicle\":s=\"g.slice, g.pathbar\";break;default:s=\"g.points > g.point\"}e.selectAll(s).each((function(t){var e=t.transform;e&&(e.scale=l&&e.hide?0:o/e.fontSize,n.select(this).select(\"text\").attr(\"transform\",i.getTextTransform(e)))}))}}}},{\"../../lib\":799,\"@plotly/d3\":58}],954:[function(t,e,r){\"use strict\";var n=t(\"../../plots/template_attributes\").hovertemplateAttrs,i=t(\"../../lib/extend\").extendFlat,a=t(\"../scatterpolar/attributes\"),o=t(\"../bar/attributes\");e.exports={r:a.r,theta:a.theta,r0:a.r0,dr:a.dr,theta0:a.theta0,dtheta:a.dtheta,thetaunit:a.thetaunit,base:i({},o.base,{}),offset:i({},o.offset,{}),width:i({},o.width,{}),text:i({},o.text,{}),hovertext:i({},o.hovertext,{}),marker:o.marker,hoverinfo:a.hoverinfo,hovertemplate:n(),selected:o.selected,unselected:o.unselected}},{\"../../lib/extend\":789,\"../../plots/template_attributes\":922,\"../bar/attributes\":937,\"../scatterpolar/attributes\":1288}],955:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/helpers\").hasColorscale,i=t(\"../../components/colorscale/calc\"),a=t(\"../bar/arrays_to_calcdata\"),o=t(\"../bar/cross_trace_calc\").setGroupPositions,s=t(\"../scatter/calc_selection\"),l=t(\"../../registry\").traceIs,c=t(\"../../lib\").extendFlat;e.exports={calc:function(t,e){for(var r=t._fullLayout,o=e.subplot,l=r[o].radialaxis,c=r[o].angularaxis,u=l.makeCalcdata(e,\"r\"),f=c.makeCalcdata(e,\"theta\"),h=e._length,p=new Array(h),d=u,m=f,g=0;g<h;g++)p[g]={p:m[g],s:d[g]};function v(t){var r=e[t];void 0!==r&&(e[\"_\"+t]=Array.isArray(r)?c.makeCalcdata(e,t):c.d2c(r,e.thetaunit))}return\"linear\"===c.type&&(v(\"width\"),v(\"offset\")),n(e,\"marker\")&&i(t,e,{vals:e.marker.color,containerStr:\"marker\",cLetter:\"c\"}),n(e,\"marker.line\")&&i(t,e,{vals:e.marker.line.color,containerStr:\"marker.line\",cLetter:\"c\"}),a(p,e),s(p,e),p},crossTraceCalc:function(t,e,r){for(var n=t.calcdata,i=[],a=0;a<n.length;a++){var s=n[a],u=s[0].trace;!0===u.visible&&l(u,\"bar\")&&u.subplot===r&&i.push(s)}var f=c({},e.radialaxis,{_id:\"x\"}),h=e.angularaxis;o(t,h,f,i,{mode:e.barmode,norm:e.barnorm,gap:e.bargap,groupgap:e.bargroupgap})}}},{\"../../components/colorscale/calc\":670,\"../../components/colorscale/helpers\":673,\"../../lib\":799,\"../../registry\":927,\"../bar/arrays_to_calcdata\":936,\"../bar/cross_trace_calc\":940,\"../scatter/calc_selection\":1216}],956:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatterpolar/defaults\").handleRThetaDefaults,a=t(\"../bar/style_defaults\"),o=t(\"./attributes\");e.exports=function(t,e,r,s){function l(r,i){return n.coerce(t,e,o,r,i)}i(t,e,s,l)?(l(\"thetaunit\"),l(\"base\"),l(\"offset\"),l(\"width\"),l(\"text\"),l(\"hovertext\"),l(\"hovertemplate\"),a(t,e,l,r,s),n.coerceSelectionMarkerOpacity(e,l)):e.visible=!1}},{\"../../lib\":799,\"../bar/style_defaults\":952,\"../scatterpolar/defaults\":1290,\"./attributes\":954}],957:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx\"),i=t(\"../../lib\"),a=t(\"../bar/hover\").getTraceColor,o=i.fillText,s=t(\"../scatterpolar/hover\").makeHoverPointText,l=t(\"../../plots/polar/helpers\").isPtInsidePolygon;e.exports=function(t,e,r){var c=t.cd,u=c[0].trace,f=t.subplot,h=f.radialAxis,p=f.angularAxis,d=f.vangles,m=d?l:i.isPtInsideSector,g=t.maxHoverDistance,v=p._period||2*Math.PI,y=Math.abs(h.g2p(Math.sqrt(e*e+r*r))),x=Math.atan2(r,e);h.range[0]>h.range[1]&&(x+=Math.PI);if(n.getClosest(c,(function(t){return m(y,x,[t.rp0,t.rp1],[t.thetag0,t.thetag1],d)?g+Math.min(1,Math.abs(t.thetag1-t.thetag0)/v)-1+(t.rp1-y)/(t.rp1-t.rp0)-1:1/0}),t),!1!==t.index){var b=c[t.index];t.x0=t.x1=b.ct[0],t.y0=t.y1=b.ct[1];var _=i.extendFlat({},b,{r:b.s,theta:b.p});return o(b,u,t),s(_,u,f,t),t.hovertemplate=u.hovertemplate,t.color=a(u,b),t.xLabelVal=t.yLabelVal=void 0,b.s<0&&(t.idealAlign=\"left\"),[t]}}},{\"../../components/fx\":702,\"../../lib\":799,\"../../plots/polar/helpers\":915,\"../bar/hover\":944,\"../scatterpolar/hover\":1292}],958:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"barpolar\",basePlotModule:t(\"../../plots/polar\"),categories:[\"polar\",\"bar\",\"showLegend\"],attributes:t(\"./attributes\"),layoutAttributes:t(\"./layout_attributes\"),supplyDefaults:t(\"./defaults\"),supplyLayoutDefaults:t(\"./layout_defaults\"),calc:t(\"./calc\").calc,crossTraceCalc:t(\"./calc\").crossTraceCalc,plot:t(\"./plot\"),colorbar:t(\"../scatter/marker_colorbar\"),formatLabels:t(\"../scatterpolar/format_labels\"),style:t(\"../bar/style\").style,styleOnSelect:t(\"../bar/style\").styleOnSelect,hoverPoints:t(\"./hover\"),selectPoints:t(\"../bar/select\"),meta:{}}},{\"../../plots/polar\":916,\"../bar/select\":949,\"../bar/style\":951,\"../scatter/marker_colorbar\":1232,\"../scatterpolar/format_labels\":1291,\"./attributes\":954,\"./calc\":955,\"./defaults\":956,\"./hover\":957,\"./layout_attributes\":959,\"./layout_defaults\":960,\"./plot\":961}],959:[function(t,e,r){\"use strict\";e.exports={barmode:{valType:\"enumerated\",values:[\"stack\",\"overlay\"],dflt:\"stack\",editType:\"calc\"},bargap:{valType:\"number\",dflt:.1,min:0,max:1,editType:\"calc\"}}},{}],960:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\");e.exports=function(t,e,r){var a,o={};function s(r,o){return n.coerce(t[a]||{},e[a],i,r,o)}for(var l=0;l<r.length;l++){var c=r[l];\"barpolar\"===c.type&&!0===c.visible&&(o[a=c.subplot]||(s(\"barmode\"),s(\"bargap\"),o[a]=1))}}},{\"../../lib\":799,\"./layout_attributes\":959}],961:[function(t,e,r){\"use strict\";var n=t(\"@plotly/d3\"),i=t(\"fast-isnumeric\"),a=t(\"../../lib\"),o=t(\"../../components/drawing\"),s=t(\"../../plots/polar/helpers\");e.exports=function(t,e,r){var l=e.xaxis,c=e.yaxis,u=e.radialAxis,f=e.angularAxis,h=function(t){var e=t.cxx,r=t.cyy;if(t.vangles)return function(n,i,o,l){var c,u;a.angleDelta(o,l)>0?(c=o,u=l):(c=l,u=o);var f=[s.findEnclosingVertexAngles(c,t.vangles)[0],(c+u)/2,s.findEnclosingVertexAngles(u,t.vangles)[1]];return s.pathPolygonAnnulus(n,i,c,u,f,e,r)};return function(t,n,i,o){return a.pathAnnulus(t,n,i,o,e,r)}}(e),p=e.layers.frontplot.select(\"g.barlayer\");a.makeTraceGroups(p,r,\"trace bars\").each((function(){var r=n.select(this),s=a.ensureSingle(r,\"g\",\"points\").selectAll(\"g.point\").data(a.identity);s.enter().append(\"g\").style(\"vector-effect\",\"non-scaling-stroke\").style(\"stroke-miterlimit\",2).classed(\"point\",!0),s.exit().remove(),s.each((function(t){var e,r=n.select(this),o=t.rp0=u.c2p(t.s0),s=t.rp1=u.c2p(t.s1),p=t.thetag0=f.c2g(t.p0),d=t.thetag1=f.c2g(t.p1);if(i(o)&&i(s)&&i(p)&&i(d)&&o!==s&&p!==d){var m=u.c2g(t.s1),g=(p+d)/2;t.ct=[l.c2p(m*Math.cos(g)),c.c2p(m*Math.sin(g))],e=h(o,s,p,d)}else e=\"M0,0Z\";a.ensureSingle(r,\"path\").attr(\"d\",e)})),o.setClipUrl(r,e._hasClipOnAxisFalse?e.clipIds.forTraces:null,t)}))}},{\"../../components/drawing\":684,\"../../lib\":799,\"../../plots/polar/helpers\":915,\"@plotly/d3\":58,\"fast-isnumeric\":245}],962:[function(t,e,r){\"use strict\";var n=t(\"../scatter/attributes\"),i=t(\"../bar/attributes\"),a=t(\"../../components/color/attributes\"),o=t(\"../../plots/cartesian/axis_format_attributes\").axisHoverFormat,s=t(\"../../plots/template_attributes\").hovertemplateAttrs,l=t(\"../../lib/extend\").extendFlat,c=n.marker,u=c.line;e.exports={y:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},x:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},x0:{valType:\"any\",editType:\"calc+clearAxisTypes\"},y0:{valType:\"any\",editType:\"calc+clearAxisTypes\"},dx:{valType:\"number\",editType:\"calc\"},dy:{valType:\"number\",editType:\"calc\"},xperiod:n.xperiod,yperiod:n.yperiod,xperiod0:n.xperiod0,yperiod0:n.yperiod0,xperiodalignment:n.xperiodalignment,yperiodalignment:n.yperiodalignment,xhoverformat:o(\"x\"),yhoverformat:o(\"y\"),name:{valType:\"string\",editType:\"calc+clearAxisTypes\"},q1:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},median:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},q3:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},lowerfence:{valType:\"data_array\",editType:\"calc\"},upperfence:{valType:\"data_array\",editType:\"calc\"},notched:{valType:\"boolean\",editType:\"calc\"},notchwidth:{valType:\"number\",min:0,max:.5,dflt:.25,editType:\"calc\"},notchspan:{valType:\"data_array\",editType:\"calc\"},boxpoints:{valType:\"enumerated\",values:[\"all\",\"outliers\",\"suspectedoutliers\",!1],editType:\"calc\"},jitter:{valType:\"number\",min:0,max:1,editType:\"calc\"},pointpos:{valType:\"number\",min:-2,max:2,editType:\"calc\"},boxmean:{valType:\"enumerated\",values:[!0,\"sd\",!1],editType:\"calc\"},mean:{valType:\"data_array\",editType:\"calc\"},sd:{valType:\"data_array\",editType:\"calc\"},orientation:{valType:\"enumerated\",values:[\"v\",\"h\"],editType:\"calc+clearAxisTypes\"},quartilemethod:{valType:\"enumerated\",values:[\"linear\",\"exclusive\",\"inclusive\"],dflt:\"linear\",editType:\"calc\"},width:{valType:\"number\",min:0,dflt:0,editType:\"calc\"},marker:{outliercolor:{valType:\"color\",dflt:\"rgba(0, 0, 0, 0)\",editType:\"style\"},symbol:l({},c.symbol,{arrayOk:!1,editType:\"plot\"}),opacity:l({},c.opacity,{arrayOk:!1,dflt:1,editType:\"style\"}),size:l({},c.size,{arrayOk:!1,editType:\"calc\"}),color:l({},c.color,{arrayOk:!1,editType:\"style\"}),line:{color:l({},u.color,{arrayOk:!1,dflt:a.defaultLine,editType:\"style\"}),width:l({},u.width,{arrayOk:!1,dflt:0,editType:\"style\"}),outliercolor:{valType:\"color\",editType:\"style\"},outlierwidth:{valType:\"number\",min:0,dflt:1,editType:\"style\"},editType:\"style\"},editType:\"plot\"},line:{color:{valType:\"color\",editType:\"style\"},width:{valType:\"number\",min:0,dflt:2,editType:\"style\"},editType:\"plot\"},fillcolor:n.fillcolor,whiskerwidth:{valType:\"number\",min:0,max:1,dflt:.5,editType:\"calc\"},offsetgroup:i.offsetgroup,alignmentgroup:i.alignmentgroup,selected:{marker:n.selected.marker,editType:\"style\"},unselected:{marker:n.unselected.marker,editType:\"style\"},text:l({},n.text,{}),hovertext:l({},n.hovertext,{}),hovertemplate:s({}),hoveron:{valType:\"flaglist\",flags:[\"boxes\",\"points\"],dflt:\"boxes+points\",editType:\"style\"}}},{\"../../components/color/attributes\":661,\"../../lib/extend\":789,\"../../plots/cartesian/axis_format_attributes\":852,\"../../plots/template_attributes\":922,\"../bar/attributes\":937,\"../scatter/attributes\":1214}],963:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../../plots/cartesian/align_period\"),o=t(\"../../lib\"),s=t(\"../../constants/numerical\").BADNUM,l=o._;e.exports=function(t,e){var r,c,y,x,b,_,w,T=t._fullLayout,k=i.getFromId(t,e.xaxis||\"x\"),M=i.getFromId(t,e.yaxis||\"y\"),A=[],S=\"violin\"===e.type?\"_numViolins\":\"_numBoxes\";\"h\"===e.orientation?(y=k,x=\"x\",b=M,_=\"y\",w=!!e.yperiodalignment):(y=M,x=\"y\",b=k,_=\"x\",w=!!e.xperiodalignment);var E,L,C,P,I,O,z=function(t,e,r,i){var s,l=e+\"0\"in t,c=\"d\"+e in t;if(e in t||l&&c){var u=r.makeCalcdata(t,e);return[a(t,r,e,u),u]}s=l?t[e+\"0\"]:\"name\"in t&&(\"category\"===r.type||n(t.name)&&-1!==[\"linear\",\"log\"].indexOf(r.type)||o.isDateTime(t.name)&&\"date\"===r.type)?t.name:i;for(var f=\"multicategory\"===r.type?r.r2c_just_indices(s):r.d2c(s,0,t[e+\"calendar\"]),h=t._length,p=new Array(h),d=0;d<h;d++)p[d]=f;return[p]}(e,_,b,T[S]),D=z[0],R=z[1],F=o.distinctVals(D,b),B=F.vals,N=F.minDiff/2,j=\"all\"===(e.boxpoints||e.points)?o.identity:function(t){return t.v<E.lf||t.v>E.uf};if(e._hasPreCompStats){var U=e[x],V=function(t){return y.d2c((e[t]||[])[r])},q=1/0,H=-1/0;for(r=0;r<e._length;r++){var G=D[r];if(n(G)){if((E={}).pos=E[_]=G,w&&R&&(E.orig_p=R[r]),E.q1=V(\"q1\"),E.med=V(\"median\"),E.q3=V(\"q3\"),L=[],U&&o.isArrayOrTypedArray(U[r]))for(c=0;c<U[r].length;c++)(O=y.d2c(U[r][c]))!==s&&(u(I={v:O,i:[r,c]},e,[r,c]),L.push(I));if(E.pts=L.sort(f),P=(C=E[x]=L.map(h)).length,E.med!==s&&E.q1!==s&&E.q3!==s&&E.med>=E.q1&&E.q3>=E.med){var Y=V(\"lowerfence\");E.lf=Y!==s&&Y<=E.q1?Y:p(E,C,P);var W=V(\"upperfence\");E.uf=W!==s&&W>=E.q3?W:d(E,C,P);var X=V(\"mean\");E.mean=X!==s?X:P?o.mean(C,P):(E.q1+E.q3)/2;var Z=V(\"sd\");E.sd=X!==s&&Z>=0?Z:P?o.stdev(C,P,E.mean):E.q3-E.q1,E.lo=m(E),E.uo=g(E);var J=V(\"notchspan\");J=J!==s&&J>0?J:v(E,P),E.ln=E.med-J,E.un=E.med+J;var K=E.lf,Q=E.uf;e.boxpoints&&C.length&&(K=Math.min(K,C[0]),Q=Math.max(Q,C[P-1])),e.notched&&(K=Math.min(K,E.ln),Q=Math.max(Q,E.un)),E.min=K,E.max=Q}else{var $;o.warn([\"Invalid input - make sure that q1 <= median <= q3\",\"q1 = \"+E.q1,\"median = \"+E.med,\"q3 = \"+E.q3].join(\"\\n\")),$=E.med!==s?E.med:E.q1!==s?E.q3!==s?(E.q1+E.q3)/2:E.q1:E.q3!==s?E.q3:0,E.med=$,E.q1=E.q3=$,E.lf=E.uf=$,E.mean=E.sd=$,E.ln=E.un=$,E.min=E.max=$}q=Math.min(q,E.min),H=Math.max(H,E.max),E.pts2=L.filter(j),A.push(E)}}e._extremes[y._id]=i.findExtremes(y,[q,H],{padded:!0})}else{var tt=y.makeCalcdata(e,x),et=function(t,e){for(var r=t.length,n=new Array(r+1),i=0;i<r;i++)n[i]=t[i]-e;return n[r]=t[r-1]+e,n}(B,N),rt=B.length,nt=function(t){for(var e=new Array(t),r=0;r<t;r++)e[r]=[];return e}(rt);for(r=0;r<e._length;r++)if(O=tt[r],n(O)){var it=o.findBin(D[r],et);it>=0&&it<rt&&(u(I={v:O,i:r},e,r),nt[it].push(I))}var at=1/0,ot=-1/0,st=e.quartilemethod,lt=\"exclusive\"===st,ct=\"inclusive\"===st;for(r=0;r<rt;r++)if(nt[r].length>0){var ut,ft;if((E={}).pos=E[_]=B[r],L=E.pts=nt[r].sort(f),P=(C=E[x]=L.map(h)).length,E.min=C[0],E.max=C[P-1],E.mean=o.mean(C,P),E.sd=o.stdev(C,P,E.mean),E.med=o.interp(C,.5),P%2&&(lt||ct))lt?(ut=C.slice(0,P/2),ft=C.slice(P/2+1)):ct&&(ut=C.slice(0,P/2+1),ft=C.slice(P/2)),E.q1=o.interp(ut,.5),E.q3=o.interp(ft,.5);else E.q1=o.interp(C,.25),E.q3=o.interp(C,.75);E.lf=p(E,C,P),E.uf=d(E,C,P),E.lo=m(E),E.uo=g(E);var ht=v(E,P);E.ln=E.med-ht,E.un=E.med+ht,at=Math.min(at,E.ln),ot=Math.max(ot,E.un),E.pts2=L.filter(j),A.push(E)}e._extremes[y._id]=i.findExtremes(y,e.notched?tt.concat([at,ot]):tt,{padded:!0})}return function(t,e){if(o.isArrayOrTypedArray(e.selectedpoints))for(var r=0;r<t.length;r++){for(var n=t[r].pts||[],i={},a=0;a<n.length;a++)i[n[a].i]=a;o.tagSelected(n,e,i)}}(A,e),A.length>0?(A[0].t={num:T[S],dPos:N,posLetter:_,valLetter:x,labels:{med:l(t,\"median:\"),min:l(t,\"min:\"),q1:l(t,\"q1:\"),q3:l(t,\"q3:\"),max:l(t,\"max:\"),mean:\"sd\"===e.boxmean?l(t,\"mean \\xb1 \\u03c3:\"):l(t,\"mean:\"),lf:l(t,\"lower fence:\"),uf:l(t,\"upper fence:\")}},T[S]++,A):[{t:{empty:!0}}]};var c={text:\"tx\",hovertext:\"htx\"};function u(t,e,r){for(var n in c)o.isArrayOrTypedArray(e[n])&&(Array.isArray(r)?o.isArrayOrTypedArray(e[n][r[0]])&&(t[c[n]]=e[n][r[0]][r[1]]):t[c[n]]=e[n][r])}function f(t,e){return t.v-e.v}function h(t){return t.v}function p(t,e,r){return 0===r?t.q1:Math.min(t.q1,e[Math.min(o.findBin(2.5*t.q1-1.5*t.q3,e,!0)+1,r-1)])}function d(t,e,r){return 0===r?t.q3:Math.max(t.q3,e[Math.max(o.findBin(2.5*t.q3-1.5*t.q1,e),0)])}function m(t){return 4*t.q1-3*t.q3}function g(t){return 4*t.q3-3*t.q1}function v(t,e){return 0===e?0:1.57*(t.q3-t.q1)/Math.sqrt(e)}},{\"../../constants/numerical\":775,\"../../lib\":799,\"../../plots/cartesian/align_period\":846,\"../../plots/cartesian/axes\":849,\"fast-isnumeric\":245}],964:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"../../lib\"),a=t(\"../../plots/cartesian/constraints\").getAxisGroup,o=[\"v\",\"h\"];function s(t,e,r,o){var s,l,c,u=e.calcdata,f=e._fullLayout,h=o._id,p=h.charAt(0),d=[],m=0;for(s=0;s<r.length;s++)for(c=u[r[s]],l=0;l<c.length;l++)d.push(o.c2l(c[l].pos,!0)),m+=(c[l].pts2||[]).length;if(d.length){var g=i.distinctVals(d);\"category\"!==o.type&&\"multicategory\"!==o.type||(g.minDiff=1);var v=g.minDiff/2;n.minDtick(o,g.minDiff,g.vals[0],!0);var y=f[\"violin\"===t?\"_numViolins\":\"_numBoxes\"],x=\"group\"===f[t+\"mode\"]&&y>1,b=1-f[t+\"gap\"],_=1-f[t+\"groupgap\"];for(s=0;s<r.length;s++){var w,T,k,M,A,S,E=(c=u[r[s]])[0].trace,L=c[0].t,C=E.width,P=E.side;if(C)w=T=M=C/2,k=0;else if(w=v,x){var I=a(f,o._id)+E.orientation,O=(f._alignmentOpts[I]||{})[E.alignmentgroup]||{},z=Object.keys(O.offsetGroups||{}).length,D=z||y;T=w*b*_/D,k=2*w*(((z?E._offsetIndex:L.num)+.5)/D-.5)*b,M=w*b/D}else T=w*b*_,k=0,M=w;L.dPos=w,L.bPos=k,L.bdPos=T,L.wHover=M;var R,F,B,N,j,U,V=k+T,q=Boolean(C);if(\"positive\"===P?(A=w*(C?1:.5),R=V,S=R=k):\"negative\"===P?(A=R=k,S=w*(C?1:.5),F=V):(A=S=w,R=F=V),(E.boxpoints||E.points)&&m>0){var H=E.pointpos,G=E.jitter,Y=E.marker.size/2,W=0;H+G>=0&&((W=V*(H+G))>A?(q=!0,j=Y,B=W):W>R&&(j=Y,B=A)),W<=A&&(B=A);var X=0;H-G<=0&&((X=-V*(H-G))>S?(q=!0,U=Y,N=X):X>F&&(U=Y,N=S)),X<=S&&(N=S)}else B=A,N=S;var Z=new Array(c.length);for(l=0;l<c.length;l++)Z[l]=c[l].pos;E._extremes[h]=n.findExtremes(o,Z,{padded:q,vpadminus:N,vpadplus:B,vpadLinearized:!0,ppadminus:{x:U,y:j}[p],ppadplus:{x:j,y:U}[p]})}}}e.exports={crossTraceCalc:function(t,e){for(var r=t.calcdata,n=e.xaxis,i=e.yaxis,a=0;a<o.length;a++){for(var l=o[a],c=\"h\"===l?i:n,u=[],f=0;f<r.length;f++){var h=r[f],p=h[0].t,d=h[0].trace;!0!==d.visible||\"box\"!==d.type&&\"candlestick\"!==d.type||p.empty||(d.orientation||\"v\")!==l||d.xaxis!==n._id||d.yaxis!==i._id||u.push(f)}s(\"box\",t,u,c)}},setPositionOffset:s}},{\"../../lib\":799,\"../../plots/cartesian/axes\":849,\"../../plots/cartesian/constraints\":857}],965:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../registry\"),a=t(\"../../components/color\"),o=t(\"../scatter/period_defaults\"),s=t(\"../bar/defaults\").handleGroupingDefaults,l=t(\"../../plots/cartesian/axis_autotype\"),c=t(\"./attributes\");function u(t,e,r,a){function o(t){var e=0;return t&&t.length&&(e+=1,n.isArrayOrTypedArray(t[0])&&t[0].length&&(e+=1)),e}function s(e){return n.validate(t[e],c[e])}var u,f=r(\"y\"),h=r(\"x\");if(\"box\"===e.type){var p=r(\"q1\"),d=r(\"median\"),m=r(\"q3\");e._hasPreCompStats=p&&p.length&&d&&d.length&&m&&m.length,u=Math.min(n.minRowLength(p),n.minRowLength(d),n.minRowLength(m))}var g,v,y=o(f),x=o(h),b=y&&n.minRowLength(f),_=x&&n.minRowLength(h),w=a.calendar,T={autotypenumbers:a.autotypenumbers};if(e._hasPreCompStats)switch(String(x)+String(y)){case\"00\":var k=s(\"x0\")||s(\"dx\");g=(s(\"y0\")||s(\"dy\"))&&!k?\"h\":\"v\",v=u;break;case\"10\":g=\"v\",v=Math.min(u,_);break;case\"20\":g=\"h\",v=Math.min(u,h.length);break;case\"01\":g=\"h\",v=Math.min(u,b);break;case\"02\":g=\"v\",v=Math.min(u,f.length);break;case\"12\":g=\"v\",v=Math.min(u,_,f.length);break;case\"21\":g=\"h\",v=Math.min(u,h.length,b);break;case\"11\":v=0;break;case\"22\":var M,A=!1;for(M=0;M<h.length;M++)if(\"category\"===l(h[M],w,T)){A=!0;break}if(A)g=\"v\",v=Math.min(u,_,f.length);else{for(M=0;M<f.length;M++)if(\"category\"===l(f[M],w,T)){A=!0;break}A?(g=\"h\",v=Math.min(u,h.length,b)):(g=\"v\",v=Math.min(u,_,f.length))}}else y>0?(g=\"v\",v=x>0?Math.min(_,b):Math.min(b)):x>0?(g=\"h\",v=Math.min(_)):v=0;if(v){e._length=v;var S=r(\"orientation\",g);e._hasPreCompStats?\"v\"===S&&0===x?(r(\"x0\",0),r(\"dx\",1)):\"h\"===S&&0===y&&(r(\"y0\",0),r(\"dy\",1)):\"v\"===S&&0===x?r(\"x0\"):\"h\"===S&&0===y&&r(\"y0\"),i.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\",\"y\"],a)}else e.visible=!1}function f(t,e,r,i){var a=i.prefix,o=n.coerce2(t,e,c,\"marker.outliercolor\"),s=r(\"marker.line.outliercolor\"),l=\"outliers\";e._hasPreCompStats?l=\"all\":(o||s)&&(l=\"suspectedoutliers\");var u=r(a+\"points\",l);u?(r(\"jitter\",\"all\"===u?.3:0),r(\"pointpos\",\"all\"===u?-1.5:0),r(\"marker.symbol\"),r(\"marker.opacity\"),r(\"marker.size\"),r(\"marker.color\",e.line.color),r(\"marker.line.color\"),r(\"marker.line.width\"),\"suspectedoutliers\"===u&&(r(\"marker.line.outliercolor\",e.marker.color),r(\"marker.line.outlierwidth\")),r(\"selected.marker.color\"),r(\"unselected.marker.color\"),r(\"selected.marker.size\"),r(\"unselected.marker.size\"),r(\"text\"),r(\"hovertext\")):delete e.marker;var f=r(\"hoveron\");\"all\"!==f&&-1===f.indexOf(\"points\")||r(\"hovertemplate\"),n.coerceSelectionMarkerOpacity(e,r)}e.exports={supplyDefaults:function(t,e,r,i){function s(r,i){return n.coerce(t,e,c,r,i)}if(u(t,e,s,i),!1!==e.visible){o(t,e,i,s),s(\"xhoverformat\"),s(\"yhoverformat\");var l=e._hasPreCompStats;l&&(s(\"lowerfence\"),s(\"upperfence\")),s(\"line.color\",(t.marker||{}).color||r),s(\"line.width\"),s(\"fillcolor\",a.addOpacity(e.line.color,.5));var h=!1;if(l){var p=s(\"mean\"),d=s(\"sd\");p&&p.length&&(h=!0,d&&d.length&&(h=\"sd\"))}s(\"boxmean\",h),s(\"whiskerwidth\"),s(\"width\"),s(\"quartilemethod\");var m=!1;if(l){var g=s(\"notchspan\");g&&g.length&&(m=!0)}else n.validate(t.notchwidth,c.notchwidth)&&(m=!0);s(\"notched\",m)&&s(\"notchwidth\"),f(t,e,s,{prefix:\"box\"})}},crossTraceDefaults:function(t,e){var r,i;function a(t){return n.coerce(i._input,i,c,t)}for(var o=0;o<t.length;o++){var l=(i=t[o]).type;\"box\"!==l&&\"violin\"!==l||(r=i._input,\"group\"===e[l+\"mode\"]&&s(r,i,e,a))}},handleSampleDefaults:u,handlePointsDefaults:f}},{\"../../components/color\":662,\"../../lib\":799,\"../../plots/cartesian/axis_autotype\":850,\"../../registry\":927,\"../bar/defaults\":941,\"../scatter/period_defaults\":1234,\"./attributes\":962}],966:[function(t,e,r){\"use strict\";e.exports=function(t,e){return e.hoverOnBox&&(t.hoverOnBox=e.hoverOnBox),\"xVal\"in e&&(t.x=e.xVal),\"yVal\"in e&&(t.y=e.yVal),e.xa&&(t.xaxis=e.xa),e.ya&&(t.yaxis=e.ya),t}},{}],967:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"../../lib\"),a=t(\"../../components/fx\"),o=t(\"../../components/color\"),s=i.fillText;function l(t,e,r,s){var l,c,u,f,h,p,d,m,g,v,y,x,b,_,w=t.cd,T=t.xa,k=t.ya,M=w[0].trace,A=w[0].t,S=\"violin\"===M.type,E=[],L=A.bdPos,C=A.wHover,P=function(t){return u.c2l(t.pos)+A.bPos-u.c2l(p)};S&&\"both\"!==M.side?(\"positive\"===M.side&&(g=function(t){var e=P(t);return a.inbox(e,e+C,v)},x=L,b=0),\"negative\"===M.side&&(g=function(t){var e=P(t);return a.inbox(e-C,e,v)},x=0,b=L)):(g=function(t){var e=P(t);return a.inbox(e-C,e+C,v)},x=b=L),_=S?function(t){return a.inbox(t.span[0]-h,t.span[1]-h,v)}:function(t){return a.inbox(t.min-h,t.max-h,v)},\"h\"===M.orientation?(h=e,p=r,d=_,m=g,l=\"y\",u=k,c=\"x\",f=T):(h=r,p=e,d=g,m=_,l=\"x\",u=T,c=\"y\",f=k);var I=Math.min(1,L/Math.abs(u.r2c(u.range[1])-u.r2c(u.range[0])));function O(t){return(d(t)+m(t))/2}v=t.maxHoverDistance-I,y=t.maxSpikeDistance-I;var z=a.getDistanceFunction(s,d,m,O);if(a.getClosest(w,z,t),!1===t.index)return[];var D=w[t.index],R=M.line.color,F=(M.marker||{}).color;o.opacity(R)&&M.line.width?t.color=R:o.opacity(F)&&M.boxpoints?t.color=F:t.color=M.fillcolor,t[l+\"0\"]=u.c2p(D.pos+A.bPos-b,!0),t[l+\"1\"]=u.c2p(D.pos+A.bPos+x,!0),t[l+\"LabelVal\"]=void 0!==D.orig_p?D.orig_p:D.pos;var B=l+\"Spike\";t.spikeDistance=O(D)*y/v,t[B]=u.c2p(D.pos,!0);var N={},j=[\"med\",\"q1\",\"q3\",\"min\",\"max\"];(M.boxmean||(M.meanline||{}).visible)&&j.push(\"mean\"),(M.boxpoints||M.points)&&j.push(\"lf\",\"uf\");for(var U=0;U<j.length;U++){var V=j[U];if(V in D&&!(D[V]in N)){N[D[V]]=!0;var q=D[V],H=f.c2p(q,!0),G=i.extendFlat({},t);G.attr=V,G[c+\"0\"]=G[c+\"1\"]=H,G[c+\"LabelVal\"]=q,G[c+\"Label\"]=(A.labels?A.labels[V]+\" \":\"\")+n.hoverLabelText(f,q,M[c+\"hoverformat\"]),G.hoverOnBox=!0,\"mean\"===V&&\"sd\"in D&&\"sd\"===M.boxmean&&(G[c+\"err\"]=D.sd),t.name=\"\",t.spikeDistance=void 0,t[B]=void 0,G.hovertemplate=!1,E.push(G)}}return E}function c(t,e,r){for(var n,o,l,c=t.cd,u=t.xa,f=t.ya,h=c[0].trace,p=u.c2p(e),d=f.c2p(r),m=a.quadrature((function(t){var e=Math.max(3,t.mrc||0);return Math.max(Math.abs(u.c2p(t.x)-p)-e,1-3/e)}),(function(t){var e=Math.max(3,t.mrc||0);return Math.max(Math.abs(f.c2p(t.y)-d)-e,1-3/e)})),g=!1,v=0;v<c.length;v++){o=c[v];for(var y=0;y<(o.pts||[]).length;y++){var x=m(l=o.pts[y]);x<=t.distance&&(t.distance=x,g=[v,y])}}if(!g)return!1;l=(o=c[g[0]]).pts[g[1]];var b=u.c2p(l.x,!0),_=f.c2p(l.y,!0),w=l.mrc||1;n=i.extendFlat({},t,{index:l.i,color:(h.marker||{}).color,name:h.name,x0:b-w,x1:b+w,y0:_-w,y1:_+w,spikeDistance:t.distance,hovertemplate:h.hovertemplate});var T,k=o.orig_p,M=void 0!==k?k:o.pos;return\"h\"===h.orientation?(T=f,n.xLabelVal=l.x,n.yLabelVal=M):(T=u,n.xLabelVal=M,n.yLabelVal=l.y),n[T._id.charAt(0)+\"Spike\"]=T.c2p(o.pos,!0),s(l,h,n),n}e.exports={hoverPoints:function(t,e,r,n){var i,a=t.cd[0].trace.hoveron,o=[];return-1!==a.indexOf(\"boxes\")&&(o=o.concat(l(t,e,r,n))),-1!==a.indexOf(\"points\")&&(i=c(t,e,r)),\"closest\"===n?i?[i]:o:i?(o.push(i),o):o},hoverOnBoxes:l,hoverOnPoints:c}},{\"../../components/color\":662,\"../../components/fx\":702,\"../../lib\":799,\"../../plots/cartesian/axes\":849}],968:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),layoutAttributes:t(\"./layout_attributes\"),supplyDefaults:t(\"./defaults\").supplyDefaults,crossTraceDefaults:t(\"./defaults\").crossTraceDefaults,supplyLayoutDefaults:t(\"./layout_defaults\").supplyLayoutDefaults,calc:t(\"./calc\"),crossTraceCalc:t(\"./cross_trace_calc\").crossTraceCalc,plot:t(\"./plot\").plot,style:t(\"./style\").style,styleOnSelect:t(\"./style\").styleOnSelect,hoverPoints:t(\"./hover\").hoverPoints,eventData:t(\"./event_data\"),selectPoints:t(\"./select\"),moduleType:\"trace\",name:\"box\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"symbols\",\"oriented\",\"box-violin\",\"showLegend\",\"boxLayout\",\"zoomScale\"],meta:{}}},{\"../../plots/cartesian\":863,\"./attributes\":962,\"./calc\":963,\"./cross_trace_calc\":964,\"./defaults\":965,\"./event_data\":966,\"./hover\":967,\"./layout_attributes\":969,\"./layout_defaults\":970,\"./plot\":971,\"./select\":972,\"./style\":973}],969:[function(t,e,r){\"use strict\";e.exports={boxmode:{valType:\"enumerated\",values:[\"group\",\"overlay\"],dflt:\"overlay\",editType:\"calc\"},boxgap:{valType:\"number\",min:0,max:1,dflt:.3,editType:\"calc\"},boxgroupgap:{valType:\"number\",min:0,max:1,dflt:.3,editType:\"calc\"}}},{}],970:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"./layout_attributes\");function o(t,e,r,i,a){for(var o=a+\"Layout\",s=!1,l=0;l<r.length;l++){var c=r[l];if(n.traceIs(c,o)){s=!0;break}}s&&(i(a+\"mode\"),i(a+\"gap\"),i(a+\"groupgap\"))}e.exports={supplyLayoutDefaults:function(t,e,r){o(0,0,r,(function(r,n){return i.coerce(t,e,a,r,n)}),\"box\")},_supply:o}},{\"../../lib\":799,\"../../registry\":927,\"./layout_attributes\":969}],971:[function(t,e,r){\"use strict\";var n=t(\"@plotly/d3\"),i=t(\"../../lib\"),a=t(\"../../components/drawing\");function o(t,e,r,a){var o,s,l=\"h\"===r.orientation,c=e.val,u=e.pos,f=!!u.rangebreaks,h=a.bPos,p=a.wdPos||0,d=a.bPosPxOffset||0,m=r.whiskerwidth||0,g=r.notched||!1,v=g?1-2*r.notchwidth:1;Array.isArray(a.bdPos)?(o=a.bdPos[0],s=a.bdPos[1]):(o=a.bdPos,s=a.bdPos);var y=t.selectAll(\"path.box\").data(\"violin\"!==r.type||r.box.visible?i.identity:[]);y.enter().append(\"path\").style(\"vector-effect\",\"non-scaling-stroke\").attr(\"class\",\"box\"),y.exit().remove(),y.each((function(t){if(t.empty)return\"M0,0Z\";var e=u.c2l(t.pos+h,!0),a=u.l2p(e-o)+d,y=u.l2p(e+s)+d,x=f?(a+y)/2:u.l2p(e)+d,b=r.whiskerwidth,_=f?a*b+(1-b)*x:u.l2p(e-p)+d,w=f?y*b+(1-b)*x:u.l2p(e+p)+d,T=u.l2p(e-o*v)+d,k=u.l2p(e+s*v)+d,M=c.c2p(t.q1,!0),A=c.c2p(t.q3,!0),S=i.constrain(c.c2p(t.med,!0),Math.min(M,A)+1,Math.max(M,A)-1),E=void 0===t.lf||!1===r.boxpoints,L=c.c2p(E?t.min:t.lf,!0),C=c.c2p(E?t.max:t.uf,!0),P=c.c2p(t.ln,!0),I=c.c2p(t.un,!0);l?n.select(this).attr(\"d\",\"M\"+S+\",\"+T+\"V\"+k+\"M\"+M+\",\"+a+\"V\"+y+(g?\"H\"+P+\"L\"+S+\",\"+k+\"L\"+I+\",\"+y:\"\")+\"H\"+A+\"V\"+a+(g?\"H\"+I+\"L\"+S+\",\"+T+\"L\"+P+\",\"+a:\"\")+\"ZM\"+M+\",\"+x+\"H\"+L+\"M\"+A+\",\"+x+\"H\"+C+(0===m?\"\":\"M\"+L+\",\"+_+\"V\"+w+\"M\"+C+\",\"+_+\"V\"+w)):n.select(this).attr(\"d\",\"M\"+T+\",\"+S+\"H\"+k+\"M\"+a+\",\"+M+\"H\"+y+(g?\"V\"+P+\"L\"+k+\",\"+S+\"L\"+y+\",\"+I:\"\")+\"V\"+A+\"H\"+a+(g?\"V\"+I+\"L\"+T+\",\"+S+\"L\"+a+\",\"+P:\"\")+\"ZM\"+x+\",\"+M+\"V\"+L+\"M\"+x+\",\"+A+\"V\"+C+(0===m?\"\":\"M\"+_+\",\"+L+\"H\"+w+\"M\"+_+\",\"+C+\"H\"+w))}))}function s(t,e,r,n){var o=e.x,s=e.y,l=n.bdPos,c=n.bPos,u=r.boxpoints||r.points;i.seedPseudoRandom();var f=t.selectAll(\"g.points\").data(u?function(t){return t.forEach((function(t){t.t=n,t.trace=r})),t}:[]);f.enter().append(\"g\").attr(\"class\",\"points\"),f.exit().remove();var h=f.selectAll(\"path\").data((function(t){var e,n,a=t.pts2,o=Math.max((t.max-t.min)/10,t.q3-t.q1),s=1e-9*o,f=.01*o,h=[],p=0;if(r.jitter){if(0===o)for(p=1,h=new Array(a.length),e=0;e<a.length;e++)h[e]=1;else for(e=0;e<a.length;e++){var d=Math.max(0,e-5),m=a[d].v,g=Math.min(a.length-1,e+5),v=a[g].v;\"all\"!==u&&(a[e].v<t.lf?v=Math.min(v,t.lf):m=Math.max(m,t.uf));var y=Math.sqrt(f*(g-d)/(v-m+s))||0;y=i.constrain(Math.abs(y),0,1),h.push(y),p=Math.max(y,p)}n=2*r.jitter/(p||1)}for(e=0;e<a.length;e++){var x=a[e],b=x.v,_=r.jitter?n*h[e]*(i.pseudoRandom()-.5):0,w=t.pos+c+l*(r.pointpos+_);\"h\"===r.orientation?(x.y=w,x.x=b):(x.x=w,x.y=b),\"suspectedoutliers\"===u&&b<t.uo&&b>t.lo&&(x.so=!0)}return a}));h.enter().append(\"path\").classed(\"point\",!0),h.exit().remove(),h.call(a.translatePoints,o,s)}function l(t,e,r,a){var o,s,l=e.val,c=e.pos,u=!!c.rangebreaks,f=a.bPos,h=a.bPosPxOffset||0,p=r.boxmean||(r.meanline||{}).visible;Array.isArray(a.bdPos)?(o=a.bdPos[0],s=a.bdPos[1]):(o=a.bdPos,s=a.bdPos);var d=t.selectAll(\"path.mean\").data(\"box\"===r.type&&r.boxmean||\"violin\"===r.type&&r.box.visible&&r.meanline.visible?i.identity:[]);d.enter().append(\"path\").attr(\"class\",\"mean\").style({fill:\"none\",\"vector-effect\":\"non-scaling-stroke\"}),d.exit().remove(),d.each((function(t){var e=c.c2l(t.pos+f,!0),i=c.l2p(e-o)+h,a=c.l2p(e+s)+h,d=u?(i+a)/2:c.l2p(e)+h,m=l.c2p(t.mean,!0),g=l.c2p(t.mean-t.sd,!0),v=l.c2p(t.mean+t.sd,!0);\"h\"===r.orientation?n.select(this).attr(\"d\",\"M\"+m+\",\"+i+\"V\"+a+(\"sd\"===p?\"m0,0L\"+g+\",\"+d+\"L\"+m+\",\"+i+\"L\"+v+\",\"+d+\"Z\":\"\")):n.select(this).attr(\"d\",\"M\"+i+\",\"+m+\"H\"+a+(\"sd\"===p?\"m0,0L\"+d+\",\"+g+\"L\"+i+\",\"+m+\"L\"+d+\",\"+v+\"Z\":\"\"))}))}e.exports={plot:function(t,e,r,a){var c=e.xaxis,u=e.yaxis;i.makeTraceGroups(a,r,\"trace boxes\").each((function(t){var e,r,i=n.select(this),a=t[0],f=a.t,h=a.trace;(f.wdPos=f.bdPos*h.whiskerwidth,!0!==h.visible||f.empty)?i.remove():(\"h\"===h.orientation?(e=u,r=c):(e=c,r=u),o(i,{pos:e,val:r},h,f),s(i,{x:c,y:u},h,f),l(i,{pos:e,val:r},h,f))}))},plotBoxAndWhiskers:o,plotPoints:s,plotBoxMean:l}},{\"../../components/drawing\":684,\"../../lib\":799,\"@plotly/d3\":58}],972:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r,n,i=t.cd,a=t.xaxis,o=t.yaxis,s=[];if(!1===e)for(r=0;r<i.length;r++)for(n=0;n<(i[r].pts||[]).length;n++)i[r].pts[n].selected=0;else for(r=0;r<i.length;r++)for(n=0;n<(i[r].pts||[]).length;n++){var l=i[r].pts[n],c=a.c2p(l.x),u=o.c2p(l.y);e.contains([c,u],null,l.i,t)?(s.push({pointNumber:l.i,x:a.c2d(l.x),y:o.c2d(l.y)}),l.selected=1):l.selected=0}return s}},{}],973:[function(t,e,r){\"use strict\";var n=t(\"@plotly/d3\"),i=t(\"../../components/color\"),a=t(\"../../components/drawing\");e.exports={style:function(t,e,r){var o=r||n.select(t).selectAll(\"g.trace.boxes\");o.style(\"opacity\",(function(t){return t[0].trace.opacity})),o.each((function(e){var r=n.select(this),o=e[0].trace,s=o.line.width;function l(t,e,r,n){t.style(\"stroke-width\",e+\"px\").call(i.stroke,r).call(i.fill,n)}var c=r.selectAll(\"path.box\");if(\"candlestick\"===o.type)c.each((function(t){if(!t.empty){var e=n.select(this),r=o[t.dir];l(e,r.line.width,r.line.color,r.fillcolor),e.style(\"opacity\",o.selectedpoints&&!t.selected?.3:1)}}));else{l(c,s,o.line.color,o.fillcolor),r.selectAll(\"path.mean\").style({\"stroke-width\":s,\"stroke-dasharray\":2*s+\"px,\"+s+\"px\"}).call(i.stroke,o.line.color);var u=r.selectAll(\"path.point\");a.pointStyle(u,o,t)}}))},styleOnSelect:function(t,e,r){var n=e[0].trace,i=r.selectAll(\"path.point\");n.selectedpoints?a.selectedPointStyle(i,n):a.pointStyle(i,n,t)}}},{\"../../components/color\":662,\"../../components/drawing\":684,\"@plotly/d3\":58}],974:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").extendFlat,i=t(\"../../plots/cartesian/axis_format_attributes\").axisHoverFormat,a=t(\"../ohlc/attributes\"),o=t(\"../box/attributes\");function s(t){return{line:{color:n({},o.line.color,{dflt:t}),width:o.line.width,editType:\"style\"},fillcolor:o.fillcolor,editType:\"style\"}}e.exports={xperiod:a.xperiod,xperiod0:a.xperiod0,xperiodalignment:a.xperiodalignment,xhoverformat:i(\"x\"),yhoverformat:i(\"y\"),x:a.x,open:a.open,high:a.high,low:a.low,close:a.close,line:{width:n({},o.line.width,{}),editType:\"style\"},increasing:s(a.increasing.line.color.dflt),decreasing:s(a.decreasing.line.color.dflt),text:a.text,hovertext:a.hovertext,whiskerwidth:n({},o.whiskerwidth,{dflt:0}),hoverlabel:a.hoverlabel}},{\"../../lib\":799,\"../../plots/cartesian/axis_format_attributes\":852,\"../box/attributes\":962,\"../ohlc/attributes\":1160}],975:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../../plots/cartesian/align_period\"),o=t(\"../ohlc/calc\").calcCommon;function s(t,e,r,n){return{min:r,q1:Math.min(t,n),med:n,q3:Math.max(t,n),max:e}}e.exports=function(t,e){var r=t._fullLayout,l=i.getFromId(t,e.xaxis),c=i.getFromId(t,e.yaxis),u=l.makeCalcdata(e,\"x\"),f=a(e,l,\"x\",u),h=o(t,e,u,f,c,s);return h.length?(n.extendFlat(h[0].t,{num:r._numBoxes,dPos:n.distinctVals(f).minDiff/2,posLetter:\"x\",valLetter:\"y\"}),r._numBoxes++,h):[{t:{empty:!0}}]}},{\"../../lib\":799,\"../../plots/cartesian/align_period\":846,\"../../plots/cartesian/axes\":849,\"../ohlc/calc\":1161}],976:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/color\"),a=t(\"../ohlc/ohlc_defaults\"),o=t(\"../scatter/period_defaults\"),s=t(\"./attributes\");function l(t,e,r,n){var a=r(n+\".line.color\");r(n+\".line.width\",e.line.width),r(n+\".fillcolor\",i.addOpacity(a,.5))}e.exports=function(t,e,r,i){function c(r,i){return n.coerce(t,e,s,r,i)}a(t,e,c,i)?(o(t,e,i,c,{x:!0}),c(\"xhoverformat\"),c(\"yhoverformat\"),c(\"line.width\"),l(t,e,c,\"increasing\"),l(t,e,c,\"decreasing\"),c(\"text\"),c(\"hovertext\"),c(\"whiskerwidth\"),i._requestRangeslider[e.xaxis]=!0):e.visible=!1}},{\"../../components/color\":662,\"../../lib\":799,\"../ohlc/ohlc_defaults\":1165,\"../scatter/period_defaults\":1234,\"./attributes\":974}],977:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"candlestick\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"showLegend\",\"candlestick\",\"boxLayout\"],meta:{},attributes:t(\"./attributes\"),layoutAttributes:t(\"../box/layout_attributes\"),supplyLayoutDefaults:t(\"../box/layout_defaults\").supplyLayoutDefaults,crossTraceCalc:t(\"../box/cross_trace_calc\").crossTraceCalc,supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\"),plot:t(\"../box/plot\").plot,layerName:\"boxlayer\",style:t(\"../box/style\").style,hoverPoints:t(\"../ohlc/hover\").hoverPoints,selectPoints:t(\"../ohlc/select\")}},{\"../../plots/cartesian\":863,\"../box/cross_trace_calc\":964,\"../box/layout_attributes\":969,\"../box/layout_defaults\":970,\"../box/plot\":971,\"../box/style\":973,\"../ohlc/hover\":1163,\"../ohlc/select\":1167,\"./attributes\":974,\"./calc\":975,\"./defaults\":976}],978:[function(t,e,r){\"use strict\";var n=t(\"./axis_defaults\"),i=t(\"../../plot_api/plot_template\");e.exports=function(t,e,r,a,o){a(\"a\")||(a(\"da\"),a(\"a0\")),a(\"b\")||(a(\"db\"),a(\"b0\")),function(t,e,r,a){[\"aaxis\",\"baxis\"].forEach((function(o){var s=o.charAt(0),l=t[o]||{},c=i.newContainer(e,o),u={tickfont:\"x\",id:s+\"axis\",letter:s,font:e.font,name:o,data:t[s],calendar:e.calendar,dfltColor:a,bgColor:r.paper_bgcolor,autotypenumbersDflt:r.autotypenumbers,fullLayout:r};n(l,c,u),c._categories=c._categories||[],t[o]||\"-\"===l.type||(t[o]={type:l.type})}))}(t,e,r,o)}},{\"../../plot_api/plot_template\":838,\"./axis_defaults\":983}],979:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").isArrayOrTypedArray;e.exports=function(t){return function t(e,r){if(!n(e)||r>=10)return null;for(var i=1/0,a=-1/0,o=e.length,s=0;s<o;s++){var l=e[s];if(n(l)){var c=t(l,r+1);c&&(i=Math.min(c[0],i),a=Math.max(c[1],a))}else i=Math.min(l,i),a=Math.max(l,a)}return[i,a]}(t,0)}},{\"../../lib\":799}],980:[function(t,e,r){\"use strict\";var n=t(\"../../plots/font_attributes\"),i=t(\"./axis_attributes\"),a=t(\"../../components/color/attributes\"),o=n({editType:\"calc\"});o.family.dflt='\"Open Sans\", verdana, arial, sans-serif',o.size.dflt=12,o.color.dflt=a.defaultLine,e.exports={carpet:{valType:\"string\",editType:\"calc\"},x:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},y:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},a:{valType:\"data_array\",editType:\"calc\"},a0:{valType:\"number\",dflt:0,editType:\"calc\"},da:{valType:\"number\",dflt:1,editType:\"calc\"},b:{valType:\"data_array\",editType:\"calc\"},b0:{valType:\"number\",dflt:0,editType:\"calc\"},db:{valType:\"number\",dflt:1,editType:\"calc\"},cheaterslope:{valType:\"number\",dflt:1,editType:\"calc\"},aaxis:i,baxis:i,font:o,color:{valType:\"color\",dflt:a.defaultLine,editType:\"plot\"},transforms:void 0}},{\"../../components/color/attributes\":661,\"../../plots/font_attributes\":878,\"./axis_attributes\":982}],981:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").isArrayOrTypedArray;e.exports=function(t,e,r,i){var a,o,s,l,c,u,f,h,p,d,m,g,v,y=n(r)?\"a\":\"b\",x=(\"a\"===y?t.aaxis:t.baxis).smoothing,b=\"a\"===y?t.a2i:t.b2j,_=\"a\"===y?r:i,w=\"a\"===y?i:r,T=\"a\"===y?e.a.length:e.b.length,k=\"a\"===y?e.b.length:e.a.length,M=Math.floor(\"a\"===y?t.b2j(w):t.a2i(w)),A=\"a\"===y?function(e){return t.evalxy([],e,M)}:function(e){return t.evalxy([],M,e)};x&&(s=Math.max(0,Math.min(k-2,M)),l=M-s,o=\"a\"===y?function(e,r){return t.dxydi([],e,s,r,l)}:function(e,r){return t.dxydj([],s,e,l,r)});var S=b(_[0]),E=b(_[1]),L=S<E?1:-1,C=1e-8*(E-S),P=L>0?Math.floor:Math.ceil,I=L>0?Math.ceil:Math.floor,O=L>0?Math.min:Math.max,z=L>0?Math.max:Math.min,D=P(S+C),R=I(E-C),F=[[f=A(S)]];for(a=D;a*L<R*L;a+=L)c=[],m=z(S,a),v=(g=O(E,a+L))-m,u=Math.max(0,Math.min(T-2,Math.floor(.5*(m+g)))),h=A(g),x&&(p=o(u,m-u),d=o(u,g-u),c.push([f[0]+p[0]/3*v,f[1]+p[1]/3*v]),c.push([h[0]-d[0]/3*v,h[1]-d[1]/3*v])),c.push(h),F.push(c),f=h;return F}},{\"../../lib\":799}],982:[function(t,e,r){\"use strict\";var n=t(\"../../plots/font_attributes\"),i=t(\"../../components/color/attributes\"),a=t(\"../../plots/cartesian/layout_attributes\"),o=t(\"../../plots/cartesian/axis_format_attributes\").descriptionWithDates,s=t(\"../../plot_api/edit_types\").overrideAll;e.exports={color:{valType:\"color\",editType:\"calc\"},smoothing:{valType:\"number\",dflt:1,min:0,max:1.3,editType:\"calc\"},title:{text:{valType:\"string\",dflt:\"\",editType:\"calc\"},font:n({editType:\"calc\"}),offset:{valType:\"number\",dflt:10,editType:\"calc\"},editType:\"calc\"},type:{valType:\"enumerated\",values:[\"-\",\"linear\",\"date\",\"category\"],dflt:\"-\",editType:\"calc\"},autotypenumbers:a.autotypenumbers,autorange:{valType:\"enumerated\",values:[!0,!1,\"reversed\"],dflt:!0,editType:\"calc\"},rangemode:{valType:\"enumerated\",values:[\"normal\",\"tozero\",\"nonnegative\"],dflt:\"normal\",editType:\"calc\"},range:{valType:\"info_array\",editType:\"calc\",items:[{valType:\"any\",editType:\"calc\"},{valType:\"any\",editType:\"calc\"}]},fixedrange:{valType:\"boolean\",dflt:!1,editType:\"calc\"},cheatertype:{valType:\"enumerated\",values:[\"index\",\"value\"],dflt:\"value\",editType:\"calc\"},tickmode:{valType:\"enumerated\",values:[\"linear\",\"array\"],dflt:\"array\",editType:\"calc\"},nticks:{valType:\"integer\",min:0,dflt:0,editType:\"calc\"},tickvals:{valType:\"data_array\",editType:\"calc\"},ticktext:{valType:\"data_array\",editType:\"calc\"},showticklabels:{valType:\"enumerated\",values:[\"start\",\"end\",\"both\",\"none\"],dflt:\"start\",editType:\"calc\"},tickfont:n({editType:\"calc\"}),tickangle:{valType:\"angle\",dflt:\"auto\",editType:\"calc\"},tickprefix:{valType:\"string\",dflt:\"\",editType:\"calc\"},showtickprefix:{valType:\"enumerated\",values:[\"all\",\"first\",\"last\",\"none\"],dflt:\"all\",editType:\"calc\"},ticksuffix:{valType:\"string\",dflt:\"\",editType:\"calc\"},showticksuffix:{valType:\"enumerated\",values:[\"all\",\"first\",\"last\",\"none\"],dflt:\"all\",editType:\"calc\"},showexponent:{valType:\"enumerated\",values:[\"all\",\"first\",\"last\",\"none\"],dflt:\"all\",editType:\"calc\"},exponentformat:{valType:\"enumerated\",values:[\"none\",\"e\",\"E\",\"power\",\"SI\",\"B\"],dflt:\"B\",editType:\"calc\"},minexponent:{valType:\"number\",dflt:3,min:0,editType:\"calc\"},separatethousands:{valType:\"boolean\",dflt:!1,editType:\"calc\"},tickformat:{valType:\"string\",dflt:\"\",editType:\"calc\",description:o(\"tick label\")},tickformatstops:s(a.tickformatstops,\"calc\",\"from-root\"),categoryorder:{valType:\"enumerated\",values:[\"trace\",\"category ascending\",\"category descending\",\"array\"],dflt:\"trace\",editType:\"calc\"},categoryarray:{valType:\"data_array\",editType:\"calc\"},labelpadding:{valType:\"integer\",dflt:10,editType:\"calc\"},labelprefix:{valType:\"string\",editType:\"calc\"},labelsuffix:{valType:\"string\",dflt:\"\",editType:\"calc\"},showline:{valType:\"boolean\",dflt:!1,editType:\"calc\"},linecolor:{valType:\"color\",dflt:i.defaultLine,editType:\"calc\"},linewidth:{valType:\"number\",min:0,dflt:1,editType:\"calc\"},gridcolor:{valType:\"color\",editType:\"calc\"},gridwidth:{valType:\"number\",min:0,dflt:1,editType:\"calc\"},showgrid:{valType:\"boolean\",dflt:!0,editType:\"calc\"},minorgridcount:{valType:\"integer\",min:0,dflt:0,editType:\"calc\"},minorgridwidth:{valType:\"number\",min:0,dflt:1,editType:\"calc\"},minorgridcolor:{valType:\"color\",dflt:i.lightLine,editType:\"calc\"},startline:{valType:\"boolean\",editType:\"calc\"},startlinecolor:{valType:\"color\",editType:\"calc\"},startlinewidth:{valType:\"number\",dflt:1,editType:\"calc\"},endline:{valType:\"boolean\",editType:\"calc\"},endlinewidth:{valType:\"number\",dflt:1,editType:\"calc\"},endlinecolor:{valType:\"color\",editType:\"calc\"},tick0:{valType:\"number\",min:0,dflt:0,editType:\"calc\"},dtick:{valType:\"number\",min:0,dflt:1,editType:\"calc\"},arraytick0:{valType:\"integer\",min:0,dflt:0,editType:\"calc\"},arraydtick:{valType:\"integer\",min:1,dflt:1,editType:\"calc\"},_deprecated:{title:{valType:\"string\",editType:\"calc\"},titlefont:n({editType:\"calc\"}),titleoffset:{valType:\"number\",dflt:10,editType:\"calc\"}},editType:\"calc\"}},{\"../../components/color/attributes\":661,\"../../plot_api/edit_types\":831,\"../../plots/cartesian/axis_format_attributes\":852,\"../../plots/cartesian/layout_attributes\":864,\"../../plots/font_attributes\":878}],983:[function(t,e,r){\"use strict\";var n=t(\"./attributes\"),i=t(\"../../components/color\").addOpacity,a=t(\"../../registry\"),o=t(\"../../lib\"),s=t(\"../../plots/cartesian/tick_value_defaults\"),l=t(\"../../plots/cartesian/tick_label_defaults\"),c=t(\"../../plots/cartesian/category_order_defaults\"),u=t(\"../../plots/cartesian/set_convert\"),f=t(\"../../plots/cartesian/axis_autotype\");e.exports=function(t,e,r){var h=r.letter,p=r.font||{},d=n[h+\"axis\"];function m(r,n){return o.coerce(t,e,d,r,n)}function g(r,n){return o.coerce2(t,e,d,r,n)}r.name&&(e._name=r.name,e._id=r.name),m(\"autotypenumbers\",r.autotypenumbersDflt);var v=m(\"type\");(\"-\"===v&&(r.data&&function(t,e){if(\"-\"!==t.type)return;var r=t._id.charAt(0),n=t[r+\"calendar\"];t.type=f(e,n,{autotypenumbers:t.autotypenumbers})}(e,r.data),\"-\"===e.type?e.type=\"linear\":v=t.type=e.type),m(\"smoothing\"),m(\"cheatertype\"),m(\"showticklabels\"),m(\"labelprefix\",h+\" = \"),m(\"labelsuffix\"),m(\"showtickprefix\"),m(\"showticksuffix\"),m(\"separatethousands\"),m(\"tickformat\"),m(\"exponentformat\"),m(\"minexponent\"),m(\"showexponent\"),m(\"categoryorder\"),m(\"tickmode\"),m(\"tickvals\"),m(\"ticktext\"),m(\"tick0\"),m(\"dtick\"),\"array\"===e.tickmode&&(m(\"arraytick0\"),m(\"arraydtick\")),m(\"labelpadding\"),e._hovertitle=h,\"date\"===v)&&a.getComponentMethod(\"calendars\",\"handleDefaults\")(t,e,\"calendar\",r.calendar);u(e,r.fullLayout),e.c2p=o.identity;var y=m(\"color\",r.dfltColor),x=y===t.color?y:p.color;m(\"title.text\")&&(o.coerceFont(m,\"title.font\",{family:p.family,size:o.bigFont(p.size),color:x}),m(\"title.offset\")),m(\"tickangle\"),m(\"autorange\",!e.isValidRange(t.range))&&m(\"rangemode\"),m(\"range\"),e.cleanRange(),m(\"fixedrange\"),s(t,e,m,v),l(t,e,m,v,r),c(t,e,m,{data:r.data,dataAttr:h});var b=g(\"gridcolor\",i(y,.3)),_=g(\"gridwidth\"),w=m(\"showgrid\");w||(delete e.gridcolor,delete e.gridwidth);var T=g(\"startlinecolor\",y),k=g(\"startlinewidth\",_);m(\"startline\",e.showgrid||!!T||!!k)||(delete e.startlinecolor,delete e.startlinewidth);var M=g(\"endlinecolor\",y),A=g(\"endlinewidth\",_);return m(\"endline\",e.showgrid||!!M||!!A)||(delete e.endlinecolor,delete e.endlinewidth),w?(m(\"minorgridcount\"),m(\"minorgridwidth\",_),m(\"minorgridcolor\",i(b,.06)),e.minorgridcount||(delete e.minorgridwidth,delete e.minorgridcolor)):(delete e.gridcolor,delete e.gridWidth),\"none\"===e.showticklabels&&(delete e.tickfont,delete e.tickangle,delete e.showexponent,delete e.exponentformat,delete e.minexponent,delete e.tickformat,delete e.showticksuffix,delete e.showtickprefix),e.showticksuffix||delete e.ticksuffix,e.showtickprefix||delete e.tickprefix,m(\"tickmode\"),e}},{\"../../components/color\":662,\"../../lib\":799,\"../../plots/cartesian/axis_autotype\":850,\"../../plots/cartesian/category_order_defaults\":854,\"../../plots/cartesian/set_convert\":870,\"../../plots/cartesian/tick_label_defaults\":871,\"../../plots/cartesian/tick_value_defaults\":873,\"../../registry\":927,\"./attributes\":980}],984:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"../../lib\").isArray1D,a=t(\"./cheater_basis\"),o=t(\"./array_minmax\"),s=t(\"./calc_gridlines\"),l=t(\"./calc_labels\"),c=t(\"./calc_clippath\"),u=t(\"../heatmap/clean_2d_array\"),f=t(\"./smooth_fill_2d_array\"),h=t(\"../heatmap/convert_column_xyz\"),p=t(\"./set_convert\");e.exports=function(t,e){var r=n.getFromId(t,e.xaxis),d=n.getFromId(t,e.yaxis),m=e.aaxis,g=e.baxis,v=e.x,y=e.y,x=[];v&&i(v)&&x.push(\"x\"),y&&i(y)&&x.push(\"y\"),x.length&&h(e,m,g,\"a\",\"b\",x);var b=e._a=e._a||e.a,_=e._b=e._b||e.b;v=e._x||e.x,y=e._y||e.y;var w={};if(e._cheater){var T=\"index\"===m.cheatertype?b.length:b,k=\"index\"===g.cheatertype?_.length:_;v=a(T,k,e.cheaterslope)}e._x=v=u(v),e._y=y=u(y),f(v,b,_),f(y,b,_),p(e),e.setScale();var M=o(v),A=o(y),S=.5*(M[1]-M[0]),E=.5*(M[1]+M[0]),L=.5*(A[1]-A[0]),C=.5*(A[1]+A[0]);return M=[E-1.3*S,E+1.3*S],A=[C-1.3*L,C+1.3*L],e._extremes[r._id]=n.findExtremes(r,M,{padded:!0}),e._extremes[d._id]=n.findExtremes(d,A,{padded:!0}),s(e,\"a\",\"b\"),s(e,\"b\",\"a\"),l(e,m),l(e,g),w.clipsegments=c(e._xctrl,e._yctrl,m,g),w.x=v,w.y=y,w.a=b,w.b=_,[w]}},{\"../../lib\":799,\"../../plots/cartesian/axes\":849,\"../heatmap/clean_2d_array\":1083,\"../heatmap/convert_column_xyz\":1085,\"./array_minmax\":979,\"./calc_clippath\":985,\"./calc_gridlines\":986,\"./calc_labels\":987,\"./cheater_basis\":989,\"./set_convert\":1002,\"./smooth_fill_2d_array\":1003}],985:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n){var i,a,o,s=[],l=!!r.smoothing,c=!!n.smoothing,u=t[0].length-1,f=t.length-1;for(i=0,a=[],o=[];i<=u;i++)a[i]=t[0][i],o[i]=e[0][i];for(s.push({x:a,y:o,bicubic:l}),i=0,a=[],o=[];i<=f;i++)a[i]=t[i][u],o[i]=e[i][u];for(s.push({x:a,y:o,bicubic:c}),i=u,a=[],o=[];i>=0;i--)a[u-i]=t[f][i],o[u-i]=e[f][i];for(s.push({x:a,y:o,bicubic:l}),i=f,a=[],o=[];i>=0;i--)a[f-i]=t[i][0],o[f-i]=e[i][0];return s.push({x:a,y:o,bicubic:c}),s}},{}],986:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"../../lib/extend\").extendFlat;e.exports=function(t,e,r){var a,o,s,l,c,u,f,h,p,d,m,g,v,y,x=t[\"_\"+e],b=t[e+\"axis\"],_=b._gridlines=[],w=b._minorgridlines=[],T=b._boundarylines=[],k=t[\"_\"+r],M=t[r+\"axis\"];\"array\"===b.tickmode&&(b.tickvals=x.slice());var A=t._xctrl,S=t._yctrl,E=A[0].length,L=A.length,C=t._a.length,P=t._b.length;n.prepTicks(b),\"array\"===b.tickmode&&delete b.tickvals;var I=b.smoothing?3:1;function O(n){var i,a,o,s,l,c,u,f,p,d,m,g,v=[],y=[],x={};if(\"b\"===e)for(a=t.b2j(n),o=Math.floor(Math.max(0,Math.min(P-2,a))),s=a-o,x.length=P,x.crossLength=C,x.xy=function(e){return t.evalxy([],e,a)},x.dxy=function(e,r){return t.dxydi([],e,o,r,s)},i=0;i<C;i++)c=Math.min(C-2,i),u=i-c,f=t.evalxy([],i,a),M.smoothing&&i>0&&(p=t.dxydi([],i-1,o,0,s),v.push(l[0]+p[0]/3),y.push(l[1]+p[1]/3),d=t.dxydi([],i-1,o,1,s),v.push(f[0]-d[0]/3),y.push(f[1]-d[1]/3)),v.push(f[0]),y.push(f[1]),l=f;else for(i=t.a2i(n),c=Math.floor(Math.max(0,Math.min(C-2,i))),u=i-c,x.length=C,x.crossLength=P,x.xy=function(e){return t.evalxy([],i,e)},x.dxy=function(e,r){return t.dxydj([],c,e,u,r)},a=0;a<P;a++)o=Math.min(P-2,a),s=a-o,f=t.evalxy([],i,a),M.smoothing&&a>0&&(m=t.dxydj([],c,a-1,u,0),v.push(l[0]+m[0]/3),y.push(l[1]+m[1]/3),g=t.dxydj([],c,a-1,u,1),v.push(f[0]-g[0]/3),y.push(f[1]-g[1]/3)),v.push(f[0]),y.push(f[1]),l=f;return x.axisLetter=e,x.axis=b,x.crossAxis=M,x.value=n,x.constvar=r,x.index=h,x.x=v,x.y=y,x.smoothing=M.smoothing,x}function z(n){var i,a,o,s,l,c=[],u=[],f={};if(f.length=x.length,f.crossLength=k.length,\"b\"===e)for(o=Math.max(0,Math.min(P-2,n)),l=Math.min(1,Math.max(0,n-o)),f.xy=function(e){return t.evalxy([],e,n)},f.dxy=function(e,r){return t.dxydi([],e,o,r,l)},i=0;i<E;i++)c[i]=A[n*I][i],u[i]=S[n*I][i];else for(a=Math.max(0,Math.min(C-2,n)),s=Math.min(1,Math.max(0,n-a)),f.xy=function(e){return t.evalxy([],n,e)},f.dxy=function(e,r){return t.dxydj([],a,e,s,r)},i=0;i<L;i++)c[i]=A[i][n*I],u[i]=S[i][n*I];return f.axisLetter=e,f.axis=b,f.crossAxis=M,f.value=x[n],f.constvar=r,f.index=n,f.x=c,f.y=u,f.smoothing=M.smoothing,f}if(\"array\"===b.tickmode){for(l=5e-15,u=(c=[Math.floor((x.length-1-b.arraytick0)/b.arraydtick*(1+l)),Math.ceil(-b.arraytick0/b.arraydtick/(1+l))].sort((function(t,e){return t-e})))[0]-1,f=c[1]+1,h=u;h<f;h++)(o=b.arraytick0+b.arraydtick*h)<0||o>x.length-1||_.push(i(z(o),{color:b.gridcolor,width:b.gridwidth}));for(h=u;h<f;h++)if(s=b.arraytick0+b.arraydtick*h,m=Math.min(s+b.arraydtick,x.length-1),!(s<0||s>x.length-1||m<0||m>x.length-1))for(g=x[s],v=x[m],a=0;a<b.minorgridcount;a++)(y=m-s)<=0||(d=g+(v-g)*(a+1)/(b.minorgridcount+1)*(b.arraydtick/y))<x[0]||d>x[x.length-1]||w.push(i(O(d),{color:b.minorgridcolor,width:b.minorgridwidth}));b.startline&&T.push(i(z(0),{color:b.startlinecolor,width:b.startlinewidth})),b.endline&&T.push(i(z(x.length-1),{color:b.endlinecolor,width:b.endlinewidth}))}else{for(l=5e-15,u=(c=[Math.floor((x[x.length-1]-b.tick0)/b.dtick*(1+l)),Math.ceil((x[0]-b.tick0)/b.dtick/(1+l))].sort((function(t,e){return t-e})))[0],f=c[1],h=u;h<=f;h++)p=b.tick0+b.dtick*h,_.push(i(O(p),{color:b.gridcolor,width:b.gridwidth}));for(h=u-1;h<f+1;h++)for(p=b.tick0+b.dtick*h,a=0;a<b.minorgridcount;a++)(d=p+b.dtick*(a+1)/(b.minorgridcount+1))<x[0]||d>x[x.length-1]||w.push(i(O(d),{color:b.minorgridcolor,width:b.minorgridwidth}));b.startline&&T.push(i(O(x[0]),{color:b.startlinecolor,width:b.startlinewidth})),b.endline&&T.push(i(O(x[x.length-1]),{color:b.endlinecolor,width:b.endlinewidth}))}}},{\"../../lib/extend\":789,\"../../plots/cartesian/axes\":849}],987:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"../../lib/extend\").extendFlat;e.exports=function(t,e){var r,a,o,s=e._labels=[],l=e._gridlines;for(r=0;r<l.length;r++)o=l[r],-1!==[\"start\",\"both\"].indexOf(e.showticklabels)&&(a=n.tickText(e,o.value),i(a,{prefix:void 0,suffix:void 0,endAnchor:!0,xy:o.xy(0),dxy:o.dxy(0,0),axis:o.axis,length:o.crossAxis.length,font:o.axis.tickfont,isFirst:0===r,isLast:r===l.length-1}),s.push(a)),-1!==[\"end\",\"both\"].indexOf(e.showticklabels)&&(a=n.tickText(e,o.value),i(a,{endAnchor:!1,xy:o.xy(o.crossLength-1),dxy:o.dxy(o.crossLength-2,1),axis:o.axis,length:o.crossAxis.length,font:o.axis.tickfont,isFirst:0===r,isLast:r===l.length-1}),s.push(a))}},{\"../../lib/extend\":789,\"../../plots/cartesian/axes\":849}],988:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n){var i=t[0]-e[0],a=t[1]-e[1],o=r[0]-e[0],s=r[1]-e[1],l=Math.pow(i*i+a*a,.25),c=Math.pow(o*o+s*s,.25),u=(c*c*i-l*l*o)*n,f=(c*c*a-l*l*s)*n,h=c*(l+c)*3,p=l*(l+c)*3;return[[e[0]+(h&&u/h),e[1]+(h&&f/h)],[e[0]-(p&&u/p),e[1]-(p&&f/p)]]}},{}],989:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").isArrayOrTypedArray;e.exports=function(t,e,r){var i,a,o,s,l,c,u=[],f=n(t)?t.length:t,h=n(e)?e.length:e,p=n(t)?t:null,d=n(e)?e:null;p&&(o=(p.length-1)/(p[p.length-1]-p[0])/(f-1)),d&&(s=(d.length-1)/(d[d.length-1]-d[0])/(h-1));var m=1/0,g=-1/0;for(a=0;a<h;a++)for(u[a]=[],l=d?(d[a]-d[0])*s:a/(h-1),i=0;i<f;i++)c=(p?(p[i]-p[0])*o:i/(f-1))-l*r,m=Math.min(c,m),g=Math.max(c,g),u[a][i]=c;var v=1/(g-m),y=-m*v;for(a=0;a<h;a++)for(i=0;i<f;i++)u[a][i]=v*u[a][i]+y;return u}},{\"../../lib\":799}],990:[function(t,e,r){\"use strict\";var n=t(\"./catmull_rom\"),i=t(\"../../lib\").ensureArray;function a(t,e,r){var n=-.5*r[0]+1.5*e[0],i=-.5*r[1]+1.5*e[1];return[(2*n+t[0])/3,(2*i+t[1])/3]}e.exports=function(t,e,r,o,s,l){var c,u,f,h,p,d,m,g,v,y,x=r[0].length,b=r.length,_=s?3*x-2:x,w=l?3*b-2:b;for(t=i(t,w),e=i(e,w),f=0;f<w;f++)t[f]=i(t[f],_),e[f]=i(e[f],_);for(u=0,h=0;u<b;u++,h+=l?3:1)for(p=t[h],d=e[h],m=r[u],g=o[u],c=0,f=0;c<x;c++,f+=s?3:1)p[f]=m[c],d[f]=g[c];if(s)for(u=0,h=0;u<b;u++,h+=l?3:1){for(c=1,f=3;c<x-1;c++,f+=3)v=n([r[u][c-1],o[u][c-1]],[r[u][c],o[u][c]],[r[u][c+1],o[u][c+1]],s),t[h][f-1]=v[0][0],e[h][f-1]=v[0][1],t[h][f+1]=v[1][0],e[h][f+1]=v[1][1];y=a([t[h][0],e[h][0]],[t[h][2],e[h][2]],[t[h][3],e[h][3]]),t[h][1]=y[0],e[h][1]=y[1],y=a([t[h][_-1],e[h][_-1]],[t[h][_-3],e[h][_-3]],[t[h][_-4],e[h][_-4]]),t[h][_-2]=y[0],e[h][_-2]=y[1]}if(l)for(f=0;f<_;f++){for(h=3;h<w-3;h+=3)v=n([t[h-3][f],e[h-3][f]],[t[h][f],e[h][f]],[t[h+3][f],e[h+3][f]],l),t[h-1][f]=v[0][0],e[h-1][f]=v[0][1],t[h+1][f]=v[1][0],e[h+1][f]=v[1][1];y=a([t[0][f],e[0][f]],[t[2][f],e[2][f]],[t[3][f],e[3][f]]),t[1][f]=y[0],e[1][f]=y[1],y=a([t[w-1][f],e[w-1][f]],[t[w-3][f],e[w-3][f]],[t[w-4][f],e[w-4][f]]),t[w-2][f]=y[0],e[w-2][f]=y[1]}if(s&&l)for(h=1;h<w;h+=(h+1)%3==0?2:1){for(f=3;f<_-3;f+=3)v=n([t[h][f-3],e[h][f-3]],[t[h][f],e[h][f]],[t[h][f+3],e[h][f+3]],s),t[h][f-1]=.5*(t[h][f-1]+v[0][0]),e[h][f-1]=.5*(e[h][f-1]+v[0][1]),t[h][f+1]=.5*(t[h][f+1]+v[1][0]),e[h][f+1]=.5*(e[h][f+1]+v[1][1]);y=a([t[h][0],e[h][0]],[t[h][2],e[h][2]],[t[h][3],e[h][3]]),t[h][1]=.5*(t[h][1]+y[0]),e[h][1]=.5*(e[h][1]+y[1]),y=a([t[h][_-1],e[h][_-1]],[t[h][_-3],e[h][_-3]],[t[h][_-4],e[h][_-4]]),t[h][_-2]=.5*(t[h][_-2]+y[0]),e[h][_-2]=.5*(e[h][_-2]+y[1])}return[t,e]}},{\"../../lib\":799,\"./catmull_rom\":988}],991:[function(t,e,r){\"use strict\";e.exports={RELATIVE_CULL_TOLERANCE:1e-6}},{}],992:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){return e&&r?function(e,r,n,i,a){var o,s,l,c,u,f;e||(e=[]),r*=3,n*=3;var h=i*i,p=1-i,d=p*p,m=p*i*2,g=-3*d,v=3*(d-m),y=3*(m-h),x=3*h,b=a*a,_=b*a,w=1-a,T=w*w,k=T*w;for(f=0;f<t.length;f++)o=g*(u=t[f])[n][r]+v*u[n][r+1]+y*u[n][r+2]+x*u[n][r+3],s=g*u[n+1][r]+v*u[n+1][r+1]+y*u[n+1][r+2]+x*u[n+1][r+3],l=g*u[n+2][r]+v*u[n+2][r+1]+y*u[n+2][r+2]+x*u[n+2][r+3],c=g*u[n+3][r]+v*u[n+3][r+1]+y*u[n+3][r+2]+x*u[n+3][r+3],e[f]=k*o+3*(T*a*s+w*b*l)+_*c;return e}:e?function(e,r,n,i,a){var o,s,l,c;e||(e=[]),r*=3;var u=i*i,f=1-i,h=f*f,p=f*i*2,d=-3*h,m=3*(h-p),g=3*(p-u),v=3*u,y=1-a;for(l=0;l<t.length;l++)o=d*(c=t[l])[n][r]+m*c[n][r+1]+g*c[n][r+2]+v*c[n][r+3],s=d*c[n+1][r]+m*c[n+1][r+1]+g*c[n+1][r+2]+v*c[n+1][r+3],e[l]=y*o+a*s;return e}:r?function(e,r,n,i,a){var o,s,l,c,u,f;e||(e=[]),n*=3;var h=a*a,p=h*a,d=1-a,m=d*d,g=m*d;for(u=0;u<t.length;u++)o=(f=t[u])[n][r+1]-f[n][r],s=f[n+1][r+1]-f[n+1][r],l=f[n+2][r+1]-f[n+2][r],c=f[n+3][r+1]-f[n+3][r],e[u]=g*o+3*(m*a*s+d*h*l)+p*c;return e}:function(e,r,n,i,a){var o,s,l,c;e||(e=[]);var u=1-a;for(l=0;l<t.length;l++)o=(c=t[l])[n][r+1]-c[n][r],s=c[n+1][r+1]-c[n+1][r],e[l]=u*o+a*s;return e}}},{}],993:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){return e&&r?function(e,r,n,i,a){var o,s,l,c,u,f;e||(e=[]),r*=3,n*=3;var h=i*i,p=h*i,d=1-i,m=d*d,g=m*d,v=a*a,y=1-a,x=y*y,b=y*a*2,_=-3*x,w=3*(x-b),T=3*(b-v),k=3*v;for(f=0;f<t.length;f++)o=_*(u=t[f])[n][r]+w*u[n+1][r]+T*u[n+2][r]+k*u[n+3][r],s=_*u[n][r+1]+w*u[n+1][r+1]+T*u[n+2][r+1]+k*u[n+3][r+1],l=_*u[n][r+2]+w*u[n+1][r+2]+T*u[n+2][r+2]+k*u[n+3][r+2],c=_*u[n][r+3]+w*u[n+1][r+3]+T*u[n+2][r+3]+k*u[n+3][r+3],e[f]=g*o+3*(m*i*s+d*h*l)+p*c;return e}:e?function(e,r,n,i,a){var o,s,l,c,u,f;e||(e=[]),r*=3;var h=a*a,p=h*a,d=1-a,m=d*d,g=m*d;for(u=0;u<t.length;u++)o=(f=t[u])[n+1][r]-f[n][r],s=f[n+1][r+1]-f[n][r+1],l=f[n+1][r+2]-f[n][r+2],c=f[n+1][r+3]-f[n][r+3],e[u]=g*o+3*(m*a*s+d*h*l)+p*c;return e}:r?function(e,r,n,i,a){var o,s,l,c;e||(e=[]),n*=3;var u=1-i,f=a*a,h=1-a,p=h*h,d=h*a*2,m=-3*p,g=3*(p-d),v=3*(d-f),y=3*f;for(l=0;l<t.length;l++)o=m*(c=t[l])[n][r]+g*c[n+1][r]+v*c[n+2][r]+y*c[n+3][r],s=m*c[n][r+1]+g*c[n+1][r+1]+v*c[n+2][r+1]+y*c[n+3][r+1],e[l]=u*o+i*s;return e}:function(e,r,n,i,a){var o,s,l,c;e||(e=[]);var u=1-i;for(l=0;l<t.length;l++)o=(c=t[l])[n+1][r]-c[n][r],s=c[n+1][r+1]-c[n][r+1],e[l]=u*o+i*s;return e}}},{}],994:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,i){var a=e-2,o=r-2;return n&&i?function(e,r,n){var i,s,l,c,u,f;e||(e=[]);var h=Math.max(0,Math.min(Math.floor(r),a)),p=Math.max(0,Math.min(Math.floor(n),o)),d=Math.max(0,Math.min(1,r-h)),m=Math.max(0,Math.min(1,n-p));h*=3,p*=3;var g=d*d,v=g*d,y=1-d,x=y*y,b=x*y,_=m*m,w=_*m,T=1-m,k=T*T,M=k*T;for(f=0;f<t.length;f++)i=b*(u=t[f])[p][h]+3*(x*d*u[p][h+1]+y*g*u[p][h+2])+v*u[p][h+3],s=b*u[p+1][h]+3*(x*d*u[p+1][h+1]+y*g*u[p+1][h+2])+v*u[p+1][h+3],l=b*u[p+2][h]+3*(x*d*u[p+2][h+1]+y*g*u[p+2][h+2])+v*u[p+2][h+3],c=b*u[p+3][h]+3*(x*d*u[p+3][h+1]+y*g*u[p+3][h+2])+v*u[p+3][h+3],e[f]=M*i+3*(k*m*s+T*_*l)+w*c;return e}:n?function(e,r,n){e||(e=[]);var i,s,l,c,u,f,h=Math.max(0,Math.min(Math.floor(r),a)),p=Math.max(0,Math.min(Math.floor(n),o)),d=Math.max(0,Math.min(1,r-h)),m=Math.max(0,Math.min(1,n-p));h*=3;var g=d*d,v=g*d,y=1-d,x=y*y,b=x*y,_=1-m;for(u=0;u<t.length;u++)i=_*(f=t[u])[p][h]+m*f[p+1][h],s=_*f[p][h+1]+m*f[p+1][h+1],l=_*f[p][h+2]+m*f[p+1][h+1],c=_*f[p][h+3]+m*f[p+1][h+1],e[u]=b*i+3*(x*d*s+y*g*l)+v*c;return e}:i?function(e,r,n){e||(e=[]);var i,s,l,c,u,f,h=Math.max(0,Math.min(Math.floor(r),a)),p=Math.max(0,Math.min(Math.floor(n),o)),d=Math.max(0,Math.min(1,r-h)),m=Math.max(0,Math.min(1,n-p));p*=3;var g=m*m,v=g*m,y=1-m,x=y*y,b=x*y,_=1-d;for(u=0;u<t.length;u++)i=_*(f=t[u])[p][h]+d*f[p][h+1],s=_*f[p+1][h]+d*f[p+1][h+1],l=_*f[p+2][h]+d*f[p+2][h+1],c=_*f[p+3][h]+d*f[p+3][h+1],e[u]=b*i+3*(x*m*s+y*g*l)+v*c;return e}:function(e,r,n){e||(e=[]);var i,s,l,c,u=Math.max(0,Math.min(Math.floor(r),a)),f=Math.max(0,Math.min(Math.floor(n),o)),h=Math.max(0,Math.min(1,r-u)),p=Math.max(0,Math.min(1,n-f)),d=1-p,m=1-h;for(l=0;l<t.length;l++)i=m*(c=t[l])[f][u]+h*c[f][u+1],s=m*c[f+1][u]+h*c[f+1][u+1],e[l]=d*i+p*s;return e}}},{}],995:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./xy_defaults\"),a=t(\"./ab_defaults\"),o=t(\"./attributes\"),s=t(\"../../components/color/attributes\");e.exports=function(t,e,r,l){function c(r,i){return n.coerce(t,e,o,r,i)}e._clipPathId=\"clip\"+e.uid+\"carpet\";var u=c(\"color\",s.defaultLine);(n.coerceFont(c,\"font\"),c(\"carpet\"),a(t,e,l,c,u),e.a&&e.b)?(e.a.length<3&&(e.aaxis.smoothing=0),e.b.length<3&&(e.baxis.smoothing=0),i(t,e,c)||(e.visible=!1),e._cheater&&c(\"cheaterslope\")):e.visible=!1}},{\"../../components/color/attributes\":661,\"../../lib\":799,\"./ab_defaults\":978,\"./attributes\":980,\"./xy_defaults\":1004}],996:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),plot:t(\"./plot\"),calc:t(\"./calc\"),animatable:!0,isContainer:!0,moduleType:\"trace\",name:\"carpet\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"carpet\",\"carpetAxis\",\"notLegendIsolatable\",\"noMultiCategory\",\"noHover\",\"noSortingByValue\"],meta:{}}},{\"../../plots/cartesian\":863,\"./attributes\":980,\"./calc\":984,\"./defaults\":995,\"./plot\":1001}],997:[function(t,e,r){\"use strict\";e.exports=function(t,e){for(var r,n=t._fullData.length,i=0;i<n;i++){var a=t._fullData[i];if(a.index!==e.index&&(\"carpet\"===a.type&&(r||(r=a),a.carpet===e.carpet)))return a}return r}},{}],998:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){if(0===t.length)return\"\";var n,i=[],a=r?3:1;for(n=0;n<t.length;n+=a)i.push(t[n]+\",\"+e[n]),r&&n<t.length-a&&(i.push(\"C\"),i.push([t[n+1]+\",\"+e[n+1],t[n+2]+\",\"+e[n+2]+\" \"].join(\" \")));return i.join(r?\"\":\"L\")}},{}],999:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").isArrayOrTypedArray;e.exports=function(t,e,r){var i;for(n(t)?t.length>e.length&&(t=t.slice(0,e.length)):t=[],i=0;i<e.length;i++)t[i]=r(e[i]);return t}},{\"../../lib\":799}],1e3:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,i,a){var o=i[0]*t.dpdx(e),s=i[1]*t.dpdy(r),l=1,c=1;if(a){var u=Math.sqrt(i[0]*i[0]+i[1]*i[1]),f=Math.sqrt(a[0]*a[0]+a[1]*a[1]),h=(i[0]*a[0]+i[1]*a[1])/u/f;c=Math.max(0,h)}var p=180*Math.atan2(s,o)/Math.PI;return p<-90?(p+=180,l=-l):p>90&&(p-=180,l=-l),{angle:p,flip:l,p:t.c2p(n,e,r),offsetMultplier:c}}},{}],1001:[function(t,e,r){\"use strict\";var n=t(\"@plotly/d3\"),i=t(\"../../components/drawing\"),a=t(\"./map_1d_array\"),o=t(\"./makepath\"),s=t(\"./orient_text\"),l=t(\"../../lib/svg_text_utils\"),c=t(\"../../lib\"),u=c.strRotate,f=c.strTranslate,h=t(\"../../constants/alignment\");function p(t,e,r,i,s,l){var c=\"const-\"+s+\"-lines\",u=r.selectAll(\".\"+c).data(l);u.enter().append(\"path\").classed(c,!0).style(\"vector-effect\",\"non-scaling-stroke\"),u.each((function(r){var i=r,s=i.x,l=i.y,c=a([],s,t.c2p),u=a([],l,e.c2p),f=\"M\"+o(c,u,i.smoothing);n.select(this).attr(\"d\",f).style(\"stroke-width\",i.width).style(\"stroke\",i.color).style(\"fill\",\"none\")})),u.exit().remove()}function d(t,e,r,a,o,c,h,p){var d=c.selectAll(\"text.\"+p).data(h);d.enter().append(\"text\").classed(p,!0);var m=0,g={};return d.each((function(o,c){var h;if(\"auto\"===o.axis.tickangle)h=s(a,e,r,o.xy,o.dxy);else{var p=(o.axis.tickangle+180)*Math.PI/180;h=s(a,e,r,o.xy,[Math.cos(p),Math.sin(p)])}c||(g={angle:h.angle,flip:h.flip});var d=(o.endAnchor?-1:1)*h.flip,v=n.select(this).attr({\"text-anchor\":d>0?\"start\":\"end\",\"data-notex\":1}).call(i.font,o.font).text(o.text).call(l.convertToTspans,t),y=i.bBox(this);v.attr(\"transform\",f(h.p[0],h.p[1])+u(h.angle)+f(o.axis.labelpadding*d,.3*y.height)),m=Math.max(m,y.width+o.axis.labelpadding)})),d.exit().remove(),g.maxExtent=m,g}e.exports=function(t,e,r,i){var l=e.xaxis,u=e.yaxis,f=t._fullLayout._clips;c.makeTraceGroups(i,r,\"trace\").each((function(e){var r=n.select(this),i=e[0],h=i.trace,m=h.aaxis,g=h.baxis,y=c.ensureSingle(r,\"g\",\"minorlayer\"),x=c.ensureSingle(r,\"g\",\"majorlayer\"),b=c.ensureSingle(r,\"g\",\"boundarylayer\"),_=c.ensureSingle(r,\"g\",\"labellayer\");r.style(\"opacity\",h.opacity),p(l,u,x,m,\"a\",m._gridlines),p(l,u,x,g,\"b\",g._gridlines),p(l,u,y,m,\"a\",m._minorgridlines),p(l,u,y,g,\"b\",g._minorgridlines),p(l,u,b,m,\"a-boundary\",m._boundarylines),p(l,u,b,g,\"b-boundary\",g._boundarylines);var w=d(t,l,u,h,i,_,m._labels,\"a-label\"),T=d(t,l,u,h,i,_,g._labels,\"b-label\");!function(t,e,r,n,i,a,o,l){var u,f,h,p,d=c.aggNums(Math.min,null,r.a),m=c.aggNums(Math.max,null,r.a),g=c.aggNums(Math.min,null,r.b),y=c.aggNums(Math.max,null,r.b);u=.5*(d+m),f=g,h=r.ab2xy(u,f,!0),p=r.dxyda_rough(u,f),void 0===o.angle&&c.extendFlat(o,s(r,i,a,h,r.dxydb_rough(u,f)));v(t,e,r,n,h,p,r.aaxis,i,a,o,\"a-title\"),u=d,f=.5*(g+y),h=r.ab2xy(u,f,!0),p=r.dxydb_rough(u,f),void 0===l.angle&&c.extendFlat(l,s(r,i,a,h,r.dxyda_rough(u,f)));v(t,e,r,n,h,p,r.baxis,i,a,l,\"b-title\")}(t,_,h,i,l,u,w,T),function(t,e,r,n,i){var s,l,u,f,h=r.select(\"#\"+t._clipPathId);h.size()||(h=r.append(\"clipPath\").classed(\"carpetclip\",!0));var p=c.ensureSingle(h,\"path\",\"carpetboundary\"),d=e.clipsegments,m=[];for(f=0;f<d.length;f++)s=d[f],l=a([],s.x,n.c2p),u=a([],s.y,i.c2p),m.push(o(l,u,s.bicubic));var g=\"M\"+m.join(\"L\")+\"Z\";h.attr(\"id\",t._clipPathId),p.attr(\"d\",g)}(h,i,f,l,u)}))};var m=h.LINE_SPACING,g=(1-h.MID_SHIFT)/m+1;function v(t,e,r,a,o,c,h,p,d,v,y){var x=[];h.title.text&&x.push(h.title.text);var b=e.selectAll(\"text.\"+y).data(x),_=v.maxExtent;b.enter().append(\"text\").classed(y,!0),b.each((function(){var e=s(r,p,d,o,c);-1===[\"start\",\"both\"].indexOf(h.showticklabels)&&(_=0);var a=h.title.font.size;_+=a+h.title.offset;var y=(v.angle+(v.flip<0?180:0)-e.angle+450)%360,x=y>90&&y<270,b=n.select(this);b.text(h.title.text).call(l.convertToTspans,t),x&&(_=(-l.lineCount(b)+g)*m*a-_),b.attr(\"transform\",f(e.p[0],e.p[1])+u(e.angle)+f(0,_)).attr(\"text-anchor\",\"middle\").call(i.font,h.title.font)})),b.exit().remove()}},{\"../../components/drawing\":684,\"../../constants/alignment\":767,\"../../lib\":799,\"../../lib/svg_text_utils\":824,\"./makepath\":998,\"./map_1d_array\":999,\"./orient_text\":1e3,\"@plotly/d3\":58}],1002:[function(t,e,r){\"use strict\";var n=t(\"./constants\"),i=t(\"../../lib/search\").findBin,a=t(\"./compute_control_points\"),o=t(\"./create_spline_evaluator\"),s=t(\"./create_i_derivative_evaluator\"),l=t(\"./create_j_derivative_evaluator\");e.exports=function(t){var e=t._a,r=t._b,c=e.length,u=r.length,f=t.aaxis,h=t.baxis,p=e[0],d=e[c-1],m=r[0],g=r[u-1],v=e[e.length-1]-e[0],y=r[r.length-1]-r[0],x=v*n.RELATIVE_CULL_TOLERANCE,b=y*n.RELATIVE_CULL_TOLERANCE;p-=x,d+=x,m-=b,g+=b,t.isVisible=function(t,e){return t>p&&t<d&&e>m&&e<g},t.isOccluded=function(t,e){return t<p||t>d||e<m||e>g},t.setScale=function(){var e=t._x,r=t._y,n=a(t._xctrl,t._yctrl,e,r,f.smoothing,h.smoothing);t._xctrl=n[0],t._yctrl=n[1],t.evalxy=o([t._xctrl,t._yctrl],c,u,f.smoothing,h.smoothing),t.dxydi=s([t._xctrl,t._yctrl],f.smoothing,h.smoothing),t.dxydj=l([t._xctrl,t._yctrl],f.smoothing,h.smoothing)},t.i2a=function(t){var r=Math.max(0,Math.floor(t[0]),c-2),n=t[0]-r;return(1-n)*e[r]+n*e[r+1]},t.j2b=function(t){var e=Math.max(0,Math.floor(t[1]),c-2),n=t[1]-e;return(1-n)*r[e]+n*r[e+1]},t.ij2ab=function(e){return[t.i2a(e[0]),t.j2b(e[1])]},t.a2i=function(t){var r=Math.max(0,Math.min(i(t,e),c-2)),n=e[r],a=e[r+1];return Math.max(0,Math.min(c-1,r+(t-n)/(a-n)))},t.b2j=function(t){var e=Math.max(0,Math.min(i(t,r),u-2)),n=r[e],a=r[e+1];return Math.max(0,Math.min(u-1,e+(t-n)/(a-n)))},t.ab2ij=function(e){return[t.a2i(e[0]),t.b2j(e[1])]},t.i2c=function(e,r){return t.evalxy([],e,r)},t.ab2xy=function(n,i,a){if(!a&&(n<e[0]||n>e[c-1]|i<r[0]||i>r[u-1]))return[!1,!1];var o=t.a2i(n),s=t.b2j(i),l=t.evalxy([],o,s);if(a){var f,h,p,d,m=0,g=0,v=[];n<e[0]?(f=0,h=0,m=(n-e[0])/(e[1]-e[0])):n>e[c-1]?(f=c-2,h=1,m=(n-e[c-1])/(e[c-1]-e[c-2])):h=o-(f=Math.max(0,Math.min(c-2,Math.floor(o)))),i<r[0]?(p=0,d=0,g=(i-r[0])/(r[1]-r[0])):i>r[u-1]?(p=u-2,d=1,g=(i-r[u-1])/(r[u-1]-r[u-2])):d=s-(p=Math.max(0,Math.min(u-2,Math.floor(s)))),m&&(t.dxydi(v,f,p,h,d),l[0]+=v[0]*m,l[1]+=v[1]*m),g&&(t.dxydj(v,f,p,h,d),l[0]+=v[0]*g,l[1]+=v[1]*g)}return l},t.c2p=function(t,e,r){return[e.c2p(t[0]),r.c2p(t[1])]},t.p2x=function(t,e,r){return[e.p2c(t[0]),r.p2c(t[1])]},t.dadi=function(t){var r=Math.max(0,Math.min(e.length-2,t));return e[r+1]-e[r]},t.dbdj=function(t){var e=Math.max(0,Math.min(r.length-2,t));return r[e+1]-r[e]},t.dxyda=function(e,r,n,i){var a=t.dxydi(null,e,r,n,i),o=t.dadi(e,n);return[a[0]/o,a[1]/o]},t.dxydb=function(e,r,n,i){var a=t.dxydj(null,e,r,n,i),o=t.dbdj(r,i);return[a[0]/o,a[1]/o]},t.dxyda_rough=function(e,r,n){var i=v*(n||.1),a=t.ab2xy(e+i,r,!0),o=t.ab2xy(e-i,r,!0);return[.5*(a[0]-o[0])/i,.5*(a[1]-o[1])/i]},t.dxydb_rough=function(e,r,n){var i=y*(n||.1),a=t.ab2xy(e,r+i,!0),o=t.ab2xy(e,r-i,!0);return[.5*(a[0]-o[0])/i,.5*(a[1]-o[1])/i]},t.dpdx=function(t){return t._m},t.dpdy=function(t){return t._m}}},{\"../../lib/search\":819,\"./compute_control_points\":990,\"./constants\":991,\"./create_i_derivative_evaluator\":992,\"./create_j_derivative_evaluator\":993,\"./create_spline_evaluator\":994}],1003:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e,r){var i,a,o,s=[],l=[],c=t[0].length,u=t.length;function f(e,r){var n,i=0,a=0;return e>0&&void 0!==(n=t[r][e-1])&&(a++,i+=n),e<c-1&&void 0!==(n=t[r][e+1])&&(a++,i+=n),r>0&&void 0!==(n=t[r-1][e])&&(a++,i+=n),r<u-1&&void 0!==(n=t[r+1][e])&&(a++,i+=n),i/Math.max(1,a)}var h,p,d,m,g,v,y,x,b,_,w,T=0;for(i=0;i<c;i++)for(a=0;a<u;a++)void 0===t[a][i]&&(s.push(i),l.push(a),t[a][i]=f(i,a)),T=Math.max(T,Math.abs(t[a][i]));if(!s.length)return t;var k=0,M=0,A=s.length;do{for(k=0,o=0;o<A;o++){i=s[o],a=l[o];var S,E,L,C,P,I,O=0,z=0;0===i?(L=e[P=Math.min(c-1,2)],C=e[1],S=t[a][P],z+=(E=t[a][1])+(E-S)*(e[0]-C)/(C-L),O++):i===c-1&&(L=e[P=Math.max(0,c-3)],C=e[c-2],S=t[a][P],z+=(E=t[a][c-2])+(E-S)*(e[c-1]-C)/(C-L),O++),(0===i||i===c-1)&&a>0&&a<u-1&&(h=r[a+1]-r[a],z+=((p=r[a]-r[a-1])*t[a+1][i]+h*t[a-1][i])/(p+h),O++),0===a?(L=r[I=Math.min(u-1,2)],C=r[1],S=t[I][i],z+=(E=t[1][i])+(E-S)*(r[0]-C)/(C-L),O++):a===u-1&&(L=r[I=Math.max(0,u-3)],C=r[u-2],S=t[I][i],z+=(E=t[u-2][i])+(E-S)*(r[u-1]-C)/(C-L),O++),(0===a||a===u-1)&&i>0&&i<c-1&&(h=e[i+1]-e[i],z+=((p=e[i]-e[i-1])*t[a][i+1]+h*t[a][i-1])/(p+h),O++),O?z/=O:(d=e[i+1]-e[i],m=e[i]-e[i-1],x=(g=r[a+1]-r[a])*(v=r[a]-r[a-1])*(g+v),z=((y=d*m*(d+m))*(v*t[a+1][i]+g*t[a-1][i])+x*(m*t[a][i+1]+d*t[a][i-1]))/(x*(m+d)+y*(v+g))),k+=(_=(b=z-t[a][i])/T)*_,w=O?0:.85,t[a][i]+=b*(1+w)}k=Math.sqrt(k)}while(M++<100&&k>1e-5);return n.log(\"Smoother converged to\",k,\"after\",M,\"iterations\"),t}},{\"../../lib\":799}],1004:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").isArray1D;e.exports=function(t,e,r){var i=r(\"x\"),a=i&&i.length,o=r(\"y\"),s=o&&o.length;if(!a&&!s)return!1;if(e._cheater=!i,a&&!n(i)||s&&!n(o))e._length=null;else{var l=a?i.length:1/0;s&&(l=Math.min(l,o.length)),e.a&&e.a.length&&(l=Math.min(l,e.a.length)),e.b&&e.b.length&&(l=Math.min(l,e.b.length)),e._length=l}return!0}},{\"../../lib\":799}],1005:[function(t,e,r){\"use strict\";var n=t(\"../../plots/template_attributes\").hovertemplateAttrs,i=t(\"../scattergeo/attributes\"),a=t(\"../../components/colorscale/attributes\"),o=t(\"../../plots/attributes\"),s=t(\"../../components/color/attributes\").defaultLine,l=t(\"../../lib/extend\").extendFlat,c=i.marker.line;e.exports=l({locations:{valType:\"data_array\",editType:\"calc\"},locationmode:i.locationmode,z:{valType:\"data_array\",editType:\"calc\"},geojson:l({},i.geojson,{}),featureidkey:i.featureidkey,text:l({},i.text,{}),hovertext:l({},i.hovertext,{}),marker:{line:{color:l({},c.color,{dflt:s}),width:l({},c.width,{dflt:1}),editType:\"calc\"},opacity:{valType:\"number\",arrayOk:!0,min:0,max:1,dflt:1,editType:\"style\"},editType:\"calc\"},selected:{marker:{opacity:i.selected.marker.opacity,editType:\"plot\"},editType:\"plot\"},unselected:{marker:{opacity:i.unselected.marker.opacity,editType:\"plot\"},editType:\"plot\"},hoverinfo:l({},o.hoverinfo,{editType:\"calc\",flags:[\"location\",\"z\",\"text\",\"name\"]}),hovertemplate:n(),showlegend:l({},o.showlegend,{dflt:!1})},a(\"\",{cLetter:\"z\",editTypeOverride:\"calc\"}))},{\"../../components/color/attributes\":661,\"../../components/colorscale/attributes\":669,\"../../lib/extend\":789,\"../../plots/attributes\":845,\"../../plots/template_attributes\":922,\"../scattergeo/attributes\":1256}],1006:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../constants/numerical\").BADNUM,a=t(\"../../components/colorscale/calc\"),o=t(\"../scatter/arrays_to_calcdata\"),s=t(\"../scatter/calc_selection\");function l(t){return t&&\"string\"==typeof t}e.exports=function(t,e){var r,c=e._length,u=new Array(c);r=e.geojson?function(t){return l(t)||n(t)}:l;for(var f=0;f<c;f++){var h=u[f]={},p=e.locations[f],d=e.z[f];r(p)&&n(d)?(h.loc=p,h.z=d):(h.loc=null,h.z=i),h.index=f}return o(u,e),a(t,e,{vals:e.z,containerStr:\"\",cLetter:\"z\"}),s(u,e),u}},{\"../../components/colorscale/calc\":670,\"../../constants/numerical\":775,\"../scatter/arrays_to_calcdata\":1213,\"../scatter/calc_selection\":1216,\"fast-isnumeric\":245}],1007:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/colorscale/defaults\"),a=t(\"./attributes\");e.exports=function(t,e,r,o){function s(r,i){return n.coerce(t,e,a,r,i)}var l=s(\"locations\"),c=s(\"z\");if(l&&l.length&&n.isArrayOrTypedArray(c)&&c.length){e._length=Math.min(l.length,c.length);var u,f=s(\"geojson\");(\"string\"==typeof f&&\"\"!==f||n.isPlainObject(f))&&(u=\"geojson-id\"),\"geojson-id\"===s(\"locationmode\",u)&&s(\"featureidkey\"),s(\"text\"),s(\"hovertext\"),s(\"hovertemplate\"),s(\"marker.line.width\")&&s(\"marker.line.color\"),s(\"marker.opacity\"),i(t,e,o,s,{prefix:\"\",cLetter:\"z\"}),n.coerceSelectionMarkerOpacity(e,s)}else e.visible=!1}},{\"../../components/colorscale/defaults\":672,\"../../lib\":799,\"./attributes\":1005}],1008:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,i){t.location=e.location,t.z=e.z;var a=n[i];return a.fIn&&a.fIn.properties&&(t.properties=a.fIn.properties),t.ct=a.ct,t}},{}],1009:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"./attributes\"),a=t(\"../../lib\").fillText;e.exports=function(t,e,r){var o,s,l,c,u=t.cd,f=u[0].trace,h=t.subplot,p=[e,r],d=[e+360,r];for(s=0;s<u.length;s++)if(c=!1,(o=u[s])._polygons){for(l=0;l<o._polygons.length;l++)o._polygons[l].contains(p)&&(c=!c),o._polygons[l].contains(d)&&(c=!c);if(c)break}if(c&&o)return t.x0=t.x1=t.xa.c2p(o.ct),t.y0=t.y1=t.ya.c2p(o.ct),t.index=o.index,t.location=o.loc,t.z=o.z,t.zLabel=n.tickText(h.mockAxis,h.mockAxis.c2l(o.z),\"hover\").text,t.hovertemplate=o.hovertemplate,function(t,e,r){if(e.hovertemplate)return;var n=r.hi||e.hoverinfo,o=String(r.loc),s=\"all\"===n?i.hoverinfo.flags:n.split(\"+\"),l=-1!==s.indexOf(\"name\"),c=-1!==s.indexOf(\"location\"),u=-1!==s.indexOf(\"z\"),f=-1!==s.indexOf(\"text\"),h=[];!l&&c?t.nameOverride=o:(l&&(t.nameOverride=e.name),c&&h.push(o));u&&h.push(t.zLabel);f&&a(r,e,h);t.extraText=h.join(\"<br>\")}(t,f,o),[t]}},{\"../../lib\":799,\"../../plots/cartesian/axes\":849,\"./attributes\":1005}],1010:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../heatmap/colorbar\"),calc:t(\"./calc\"),calcGeoJSON:t(\"./plot\").calcGeoJSON,plot:t(\"./plot\").plot,style:t(\"./style\").style,styleOnSelect:t(\"./style\").styleOnSelect,hoverPoints:t(\"./hover\"),eventData:t(\"./event_data\"),selectPoints:t(\"./select\"),moduleType:\"trace\",name:\"choropleth\",basePlotModule:t(\"../../plots/geo\"),categories:[\"geo\",\"noOpacity\",\"showLegend\"],meta:{}}},{\"../../plots/geo\":882,\"../heatmap/colorbar\":1084,\"./attributes\":1005,\"./calc\":1006,\"./defaults\":1007,\"./event_data\":1008,\"./hover\":1009,\"./plot\":1011,\"./select\":1012,\"./style\":1013}],1011:[function(t,e,r){\"use strict\";var n=t(\"@plotly/d3\"),i=t(\"../../lib\"),a=t(\"../../lib/geo_location_utils\"),o=t(\"../../lib/topojson_utils\").getTopojsonFeatures,s=t(\"../../plots/cartesian/autorange\").findExtremes,l=t(\"./style\").style;e.exports={calcGeoJSON:function(t,e){for(var r=t[0].trace,n=e[r.geo],i=n._subplot,l=r.locationmode,c=r._length,u=\"geojson-id\"===l?a.extractTraceFeature(t):o(r,i.topojson),f=[],h=[],p=0;p<c;p++){var d=t[p],m=\"geojson-id\"===l?d.fOut:a.locationToFeature(l,d.loc,u);if(m){d.geojson=m,d.ct=m.properties.ct,d._polygons=a.feature2polygons(m);var g=a.computeBbox(m);f.push(g[0],g[2]),h.push(g[1],g[3])}else d.geojson=null}if(\"geojson\"===n.fitbounds&&\"geojson-id\"===l){var v=a.computeBbox(a.getTraceGeojson(r));f=[v[0],v[2]],h=[v[1],v[3]]}var y={padded:!0};r._extremes.lon=s(n.lonaxis._ax,f,y),r._extremes.lat=s(n.lataxis._ax,h,y)},plot:function(t,e,r){var a=e.layers.backplot.select(\".choroplethlayer\");i.makeTraceGroups(a,r,\"trace choropleth\").each((function(e){var r=n.select(this).selectAll(\"path.choroplethlocation\").data(i.identity);r.enter().append(\"path\").classed(\"choroplethlocation\",!0),r.exit().remove(),l(t,e)}))}}},{\"../../lib\":799,\"../../lib/geo_location_utils\":792,\"../../lib/topojson_utils\":827,\"../../plots/cartesian/autorange\":848,\"./style\":1013,\"@plotly/d3\":58}],1012:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r,n,i,a,o,s=t.cd,l=t.xaxis,c=t.yaxis,u=[];if(!1===e)for(r=0;r<s.length;r++)s[r].selected=0;else for(r=0;r<s.length;r++)(i=(n=s[r]).ct)&&(a=l.c2p(i),o=c.c2p(i),e.contains([a,o],null,r,t)?(u.push({pointNumber:r,lon:i[0],lat:i[1]}),n.selected=1):n.selected=0);return u}},{}],1013:[function(t,e,r){\"use strict\";var n=t(\"@plotly/d3\"),i=t(\"../../components/color\"),a=t(\"../../components/drawing\"),o=t(\"../../components/colorscale\");function s(t,e){var r=e[0].trace,s=e[0].node3.selectAll(\".choroplethlocation\"),l=r.marker||{},c=l.line||{},u=o.makeColorScaleFuncFromTrace(r);s.each((function(t){n.select(this).attr(\"fill\",u(t.z)).call(i.stroke,t.mlc||c.color).call(a.dashLine,\"\",t.mlw||c.width||0).style(\"opacity\",l.opacity)})),a.selectedPointStyle(s,r,t)}e.exports={style:function(t,e){e&&s(t,e)},styleOnSelect:function(t,e){var r=e[0].node3,n=e[0].trace;n.selectedpoints?a.selectedPointStyle(r.selectAll(\".choroplethlocation\"),n,t):s(t,e)}}},{\"../../components/color\":662,\"../../components/colorscale\":674,\"../../components/drawing\":684,\"@plotly/d3\":58}],1014:[function(t,e,r){\"use strict\";var n=t(\"../choropleth/attributes\"),i=t(\"../../components/colorscale/attributes\"),a=t(\"../../plots/template_attributes\").hovertemplateAttrs,o=t(\"../../plots/attributes\"),s=t(\"../../lib/extend\").extendFlat;e.exports=s({locations:{valType:\"data_array\",editType:\"calc\"},z:{valType:\"data_array\",editType:\"calc\"},geojson:{valType:\"any\",editType:\"calc\"},featureidkey:s({},n.featureidkey,{}),below:{valType:\"string\",editType:\"plot\"},text:n.text,hovertext:n.hovertext,marker:{line:{color:s({},n.marker.line.color,{editType:\"plot\"}),width:s({},n.marker.line.width,{editType:\"plot\"}),editType:\"calc\"},opacity:s({},n.marker.opacity,{editType:\"plot\"}),editType:\"calc\"},selected:{marker:{opacity:s({},n.selected.marker.opacity,{editType:\"plot\"}),editType:\"plot\"},editType:\"plot\"},unselected:{marker:{opacity:s({},n.unselected.marker.opacity,{editType:\"plot\"}),editType:\"plot\"},editType:\"plot\"},hoverinfo:n.hoverinfo,hovertemplate:a({},{keys:[\"properties\"]}),showlegend:s({},o.showlegend,{dflt:!1})},i(\"\",{cLetter:\"z\",editTypeOverride:\"calc\"}))},{\"../../components/colorscale/attributes\":669,\"../../lib/extend\":789,\"../../plots/attributes\":845,\"../../plots/template_attributes\":922,\"../choropleth/attributes\":1005}],1015:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../../components/colorscale\"),o=t(\"../../components/drawing\"),s=t(\"../../lib/geojson_utils\").makeBlank,l=t(\"../../lib/geo_location_utils\");function c(t){var e,r=t[0].trace,n=r._opts;if(r.selectedpoints){for(var a=o.makeSelectedPointStyleFns(r),s=0;s<t.length;s++){var l=t[s];l.fOut&&(l.fOut.properties.mo2=a.selectedOpacityFn(l))}e={type:\"identity\",property:\"mo2\"}}else e=i.isArrayOrTypedArray(r.marker.opacity)?{type:\"identity\",property:\"mo\"}:r.marker.opacity;return i.extendFlat(n.fill.paint,{\"fill-opacity\":e}),i.extendFlat(n.line.paint,{\"line-opacity\":e}),n}e.exports={convert:function(t){var e=t[0].trace,r=!0===e.visible&&0!==e._length,o={layout:{visibility:\"none\"},paint:{}},u={layout:{visibility:\"none\"},paint:{}},f=e._opts={fill:o,line:u,geojson:s()};if(!r)return f;var h=l.extractTraceFeature(t);if(!h)return f;var p,d,m,g=a.makeColorScaleFuncFromTrace(e),v=e.marker,y=v.line||{};i.isArrayOrTypedArray(v.opacity)&&(p=function(t){var e=t.mo;return n(e)?+i.constrain(e,0,1):0}),i.isArrayOrTypedArray(y.color)&&(d=function(t){return t.mlc}),i.isArrayOrTypedArray(y.width)&&(m=function(t){return t.mlw});for(var x=0;x<t.length;x++){var b=t[x],_=b.fOut;if(_){var w=_.properties;w.fc=g(b.z),p&&(w.mo=p(b)),d&&(w.mlc=d(b)),m&&(w.mlw=m(b)),b.ct=w.ct,b._polygons=l.feature2polygons(_)}}var T=p?{type:\"identity\",property:\"mo\"}:v.opacity;return i.extendFlat(o.paint,{\"fill-color\":{type:\"identity\",property:\"fc\"},\"fill-opacity\":T}),i.extendFlat(u.paint,{\"line-color\":d?{type:\"identity\",property:\"mlc\"}:y.color,\"line-width\":m?{type:\"identity\",property:\"mlw\"}:y.width,\"line-opacity\":T}),o.layout.visibility=\"visible\",u.layout.visibility=\"visible\",f.geojson={type:\"FeatureCollection\",features:h},c(t),f},convertOnSelect:c}},{\"../../components/colorscale\":674,\"../../components/drawing\":684,\"../../lib\":799,\"../../lib/geo_location_utils\":792,\"../../lib/geojson_utils\":793,\"fast-isnumeric\":245}],1016:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/colorscale/defaults\"),a=t(\"./attributes\");e.exports=function(t,e,r,o){function s(r,i){return n.coerce(t,e,a,r,i)}var l=s(\"locations\"),c=s(\"z\"),u=s(\"geojson\");n.isArrayOrTypedArray(l)&&l.length&&n.isArrayOrTypedArray(c)&&c.length&&(\"string\"==typeof u&&\"\"!==u||n.isPlainObject(u))?(s(\"featureidkey\"),e._length=Math.min(l.length,c.length),s(\"below\"),s(\"text\"),s(\"hovertext\"),s(\"hovertemplate\"),s(\"marker.line.width\")&&s(\"marker.line.color\"),s(\"marker.opacity\"),i(t,e,o,s,{prefix:\"\",cLetter:\"z\"}),n.coerceSelectionMarkerOpacity(e,s)):e.visible=!1}},{\"../../components/colorscale/defaults\":672,\"../../lib\":799,\"./attributes\":1014}],1017:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../heatmap/colorbar\"),calc:t(\"../choropleth/calc\"),plot:t(\"./plot\"),hoverPoints:t(\"../choropleth/hover\"),eventData:t(\"../choropleth/event_data\"),selectPoints:t(\"../choropleth/select\"),styleOnSelect:function(t,e){e&&e[0].trace._glTrace.updateOnSelect(e)},getBelow:function(t,e){for(var r=e.getMapLayers(),n=r.length-2;n>=0;n--){var i=r[n].id;if(\"string\"==typeof i&&0===i.indexOf(\"water\"))for(var a=n+1;a<r.length;a++)if(\"string\"==typeof(i=r[a].id)&&-1===i.indexOf(\"plotly-\"))return i}},moduleType:\"trace\",name:\"choroplethmapbox\",basePlotModule:t(\"../../plots/mapbox\"),categories:[\"mapbox\",\"gl\",\"noOpacity\",\"showLegend\"],meta:{hr_name:\"choropleth_mapbox\"}}},{\"../../plots/mapbox\":907,\"../choropleth/calc\":1006,\"../choropleth/event_data\":1008,\"../choropleth/hover\":1009,\"../choropleth/select\":1012,\"../heatmap/colorbar\":1084,\"./attributes\":1014,\"./defaults\":1016,\"./plot\":1018}],1018:[function(t,e,r){\"use strict\";var n=t(\"./convert\").convert,i=t(\"./convert\").convertOnSelect,a=t(\"../../plots/mapbox/constants\").traceLayerPrefix;function o(t,e){this.type=\"choroplethmapbox\",this.subplot=t,this.uid=e,this.sourceId=\"source-\"+e,this.layerList=[[\"fill\",a+e+\"-fill\"],[\"line\",a+e+\"-line\"]],this.below=null}var s=o.prototype;s.update=function(t){this._update(n(t))},s.updateOnSelect=function(t){this._update(i(t))},s._update=function(t){var e=this.subplot,r=this.layerList,n=e.belowLookup[\"trace-\"+this.uid];e.map.getSource(this.sourceId).setData(t.geojson),n!==this.below&&(this._removeLayers(),this._addLayers(t,n),this.below=n);for(var i=0;i<r.length;i++){var a=r[i],o=a[0],s=a[1],l=t[o];e.setOptions(s,\"setLayoutProperty\",l.layout),\"visible\"===l.layout.visibility&&e.setOptions(s,\"setPaintProperty\",l.paint)}},s._addLayers=function(t,e){for(var r=this.subplot,n=this.layerList,i=this.sourceId,a=0;a<n.length;a++){var o=n[a],s=o[0],l=t[s];r.addLayer({type:s,id:o[1],source:i,layout:l.layout,paint:l.paint},e)}},s._removeLayers=function(){for(var t=this.subplot.map,e=this.layerList,r=e.length-1;r>=0;r--)t.removeLayer(e[r][1])},s.dispose=function(){var t=this.subplot.map;this._removeLayers(),t.removeSource(this.sourceId)},e.exports=function(t,e){var r=e[0].trace,i=new o(t,r.uid),a=i.sourceId,s=n(e),l=i.below=t.belowLookup[\"trace-\"+r.uid];return t.map.addSource(a,{type:\"geojson\",data:s.geojson}),i._addLayers(s,l),e[0].trace._glTrace=i,i}},{\"../../plots/mapbox/constants\":905,\"./convert\":1015}],1019:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/attributes\"),i=t(\"../../plots/cartesian/axis_format_attributes\").axisHoverFormat,a=t(\"../../plots/template_attributes\").hovertemplateAttrs,o=t(\"../mesh3d/attributes\"),s=t(\"../../plots/attributes\"),l=t(\"../../lib/extend\").extendFlat,c={x:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},y:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},z:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},u:{valType:\"data_array\",editType:\"calc\"},v:{valType:\"data_array\",editType:\"calc\"},w:{valType:\"data_array\",editType:\"calc\"},sizemode:{valType:\"enumerated\",values:[\"scaled\",\"absolute\"],editType:\"calc\",dflt:\"scaled\"},sizeref:{valType:\"number\",editType:\"calc\",min:0},anchor:{valType:\"enumerated\",editType:\"calc\",values:[\"tip\",\"tail\",\"cm\",\"center\"],dflt:\"cm\"},text:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"calc\"},hovertext:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"calc\"},hovertemplate:a({editType:\"calc\"},{keys:[\"norm\"]}),uhoverformat:i(\"u\",1),vhoverformat:i(\"v\",1),whoverformat:i(\"w\",1),xhoverformat:i(\"x\"),yhoverformat:i(\"y\"),zhoverformat:i(\"z\"),showlegend:l({},s.showlegend,{dflt:!1})};l(c,n(\"\",{colorAttr:\"u/v/w norm\",showScaleDflt:!0,editTypeOverride:\"calc\"}));[\"opacity\",\"lightposition\",\"lighting\"].forEach((function(t){c[t]=o[t]})),c.hoverinfo=l({},s.hoverinfo,{editType:\"calc\",flags:[\"x\",\"y\",\"z\",\"u\",\"v\",\"w\",\"norm\",\"text\",\"name\"],dflt:\"x+y+z+norm+text+name\"}),c.transforms=void 0,e.exports=c},{\"../../components/colorscale/attributes\":669,\"../../lib/extend\":789,\"../../plots/attributes\":845,\"../../plots/cartesian/axis_format_attributes\":852,\"../../plots/template_attributes\":922,\"../mesh3d/attributes\":1155}],1020:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/calc\");e.exports=function(t,e){for(var r=e.u,i=e.v,a=e.w,o=Math.min(e.x.length,e.y.length,e.z.length,r.length,i.length,a.length),s=-1/0,l=1/0,c=0;c<o;c++){var u=r[c],f=i[c],h=a[c],p=Math.sqrt(u*u+f*f+h*h);s=Math.max(s,p),l=Math.min(l,p)}e._len=o,e._normMax=s,n(t,e,{vals:[l,s],containerStr:\"\",cLetter:\"c\"})}},{\"../../components/colorscale/calc\":670}],1021:[function(t,e,r){\"use strict\";var n=t(\"gl-cone3d\"),i=t(\"gl-cone3d\").createConeMesh,a=t(\"../../lib\").simpleMap,o=t(\"../../lib/gl_format_color\").parseColorScale,s=t(\"../../components/colorscale\").extractOpts,l=t(\"../../plots/gl3d/zip3\");function c(t,e){this.scene=t,this.uid=e,this.mesh=null,this.data=null}var u=c.prototype;u.handlePick=function(t){if(t.object===this.mesh){var e=t.index=t.data.index,r=this.data.x[e],n=this.data.y[e],i=this.data.z[e],a=this.data.u[e],o=this.data.v[e],s=this.data.w[e];t.traceCoordinate=[r,n,i,a,o,s,Math.sqrt(a*a+o*o+s*s)];var l=this.data.hovertext||this.data.text;return Array.isArray(l)&&void 0!==l[e]?t.textLabel=l[e]:l&&(t.textLabel=l),!0}};var f={xaxis:0,yaxis:1,zaxis:2},h={tip:1,tail:0,cm:.25,center:.5},p={tip:1,tail:1,cm:.75,center:.5};function d(t,e){var r=t.fullSceneLayout,i=t.dataScale,c={};function u(t,e){var n=r[e],o=i[f[e]];return a(t,(function(t){return n.d2l(t)*o}))}c.vectors=l(u(e.u,\"xaxis\"),u(e.v,\"yaxis\"),u(e.w,\"zaxis\"),e._len),c.positions=l(u(e.x,\"xaxis\"),u(e.y,\"yaxis\"),u(e.z,\"zaxis\"),e._len);var d=s(e);c.colormap=o(e),c.vertexIntensityBounds=[d.min/e._normMax,d.max/e._normMax],c.coneOffset=h[e.anchor],\"scaled\"===e.sizemode?c.coneSize=e.sizeref||.5:c.coneSize=e.sizeref&&e._normMax?e.sizeref/e._normMax:.5;var m=n(c),g=e.lightposition;return m.lightPosition=[g.x,g.y,g.z],m.ambient=e.lighting.ambient,m.diffuse=e.lighting.diffuse,m.specular=e.lighting.specular,m.roughness=e.lighting.roughness,m.fresnel=e.lighting.fresnel,m.opacity=e.opacity,e._pad=p[e.anchor]*m.vectorScale*m.coneScale*e._normMax,m}u.update=function(t){this.data=t;var e=d(this.scene,t);this.mesh.update(e)},u.dispose=function(){this.scene.glplot.remove(this.mesh),this.mesh.dispose()},e.exports=function(t,e){var r=t.glplot.gl,n=d(t,e),a=i(r,n),o=new c(t,e.uid);return o.mesh=a,o.data=e,a._trace=o,t.glplot.add(a),o}},{\"../../components/colorscale\":674,\"../../lib\":799,\"../../lib/gl_format_color\":795,\"../../plots/gl3d/zip3\":903,\"gl-cone3d\":264}],1022:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/colorscale/defaults\"),a=t(\"./attributes\");e.exports=function(t,e,r,o){function s(r,i){return n.coerce(t,e,a,r,i)}var l=s(\"u\"),c=s(\"v\"),u=s(\"w\"),f=s(\"x\"),h=s(\"y\"),p=s(\"z\");l&&l.length&&c&&c.length&&u&&u.length&&f&&f.length&&h&&h.length&&p&&p.length?(s(\"sizeref\"),s(\"sizemode\"),s(\"anchor\"),s(\"lighting.ambient\"),s(\"lighting.diffuse\"),s(\"lighting.specular\"),s(\"lighting.roughness\"),s(\"lighting.fresnel\"),s(\"lightposition.x\"),s(\"lightposition.y\"),s(\"lightposition.z\"),i(t,e,o,s,{prefix:\"\",cLetter:\"c\"}),s(\"text\"),s(\"hovertext\"),s(\"hovertemplate\"),s(\"uhoverformat\"),s(\"vhoverformat\"),s(\"whoverformat\"),s(\"xhoverformat\"),s(\"yhoverformat\"),s(\"zhoverformat\"),e._length=null):e.visible=!1}},{\"../../components/colorscale/defaults\":672,\"../../lib\":799,\"./attributes\":1019}],1023:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"cone\",basePlotModule:t(\"../../plots/gl3d\"),categories:[\"gl3d\",\"showLegend\"],attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:{min:\"cmin\",max:\"cmax\"},calc:t(\"./calc\"),plot:t(\"./convert\"),eventData:function(t,e){return t.norm=e.traceCoordinate[6],t},meta:{}}},{\"../../plots/gl3d\":892,\"./attributes\":1019,\"./calc\":1020,\"./convert\":1021,\"./defaults\":1022}],1024:[function(t,e,r){\"use strict\";var n=t(\"../heatmap/attributes\"),i=t(\"../scatter/attributes\"),a=t(\"../../plots/cartesian/axis_format_attributes\"),o=a.axisHoverFormat,s=a.descriptionOnlyNumbers,l=t(\"../../components/colorscale/attributes\"),c=t(\"../../components/drawing/attributes\").dash,u=t(\"../../plots/font_attributes\"),f=t(\"../../lib/extend\").extendFlat,h=t(\"../../constants/filter_ops\"),p=h.COMPARISON_OPS2,d=h.INTERVAL_OPS,m=i.line;e.exports=f({z:n.z,x:n.x,x0:n.x0,dx:n.dx,y:n.y,y0:n.y0,dy:n.dy,xperiod:n.xperiod,yperiod:n.yperiod,xperiod0:i.xperiod0,yperiod0:i.yperiod0,xperiodalignment:n.xperiodalignment,yperiodalignment:n.yperiodalignment,text:n.text,hovertext:n.hovertext,transpose:n.transpose,xtype:n.xtype,ytype:n.ytype,xhoverformat:o(\"x\"),yhoverformat:o(\"y\"),zhoverformat:o(\"z\",1),hovertemplate:n.hovertemplate,hoverongaps:n.hoverongaps,connectgaps:f({},n.connectgaps,{}),fillcolor:{valType:\"color\",editType:\"calc\"},autocontour:{valType:\"boolean\",dflt:!0,editType:\"calc\",impliedEdits:{\"contours.start\":void 0,\"contours.end\":void 0,\"contours.size\":void 0}},ncontours:{valType:\"integer\",dflt:15,min:1,editType:\"calc\"},contours:{type:{valType:\"enumerated\",values:[\"levels\",\"constraint\"],dflt:\"levels\",editType:\"calc\"},start:{valType:\"number\",dflt:null,editType:\"plot\",impliedEdits:{\"^autocontour\":!1}},end:{valType:\"number\",dflt:null,editType:\"plot\",impliedEdits:{\"^autocontour\":!1}},size:{valType:\"number\",dflt:null,min:0,editType:\"plot\",impliedEdits:{\"^autocontour\":!1}},coloring:{valType:\"enumerated\",values:[\"fill\",\"heatmap\",\"lines\",\"none\"],dflt:\"fill\",editType:\"calc\"},showlines:{valType:\"boolean\",dflt:!0,editType:\"plot\"},showlabels:{valType:\"boolean\",dflt:!1,editType:\"plot\"},labelfont:u({editType:\"plot\",colorEditType:\"style\"}),labelformat:{valType:\"string\",dflt:\"\",editType:\"plot\",description:s(\"contour label\")},operation:{valType:\"enumerated\",values:[].concat(p).concat(d),dflt:\"=\",editType:\"calc\"},value:{valType:\"any\",dflt:0,editType:\"calc\"},editType:\"calc\",impliedEdits:{autocontour:!1}},line:{color:f({},m.color,{editType:\"style+colorbars\"}),width:{valType:\"number\",min:0,editType:\"style+colorbars\"},dash:c,smoothing:f({},m.smoothing,{}),editType:\"plot\"}},l(\"\",{cLetter:\"z\",autoColorDflt:!1,editTypeOverride:\"calc\"}))},{\"../../components/colorscale/attributes\":669,\"../../components/drawing/attributes\":683,\"../../constants/filter_ops\":771,\"../../lib/extend\":789,\"../../plots/cartesian/axis_format_attributes\":852,\"../../plots/font_attributes\":878,\"../heatmap/attributes\":1081,\"../scatter/attributes\":1214}],1025:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale\"),i=t(\"../heatmap/calc\"),a=t(\"./set_contours\"),o=t(\"./end_plus\");e.exports=function(t,e){var r=i(t,e),s=r[0].z;a(e,s);var l,c=e.contours,u=n.extractOpts(e);if(\"heatmap\"===c.coloring&&u.auto&&!1===e.autocontour){var f=c.start,h=o(c),p=c.size||1,d=Math.floor((h-f)/p)+1;isFinite(p)||(p=1,d=1);var m=f-p/2;l=[m,m+d*p]}else l=s;return n.calc(t,e,{vals:l,cLetter:\"z\"}),r}},{\"../../components/colorscale\":674,\"../heatmap/calc\":1082,\"./end_plus\":1035,\"./set_contours\":1043}],1026:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r,n=t[0],i=n.z;switch(e.type){case\"levels\":var a=Math.min(i[0][0],i[0][1]);for(r=0;r<t.length;r++){var o=t[r];o.prefixBoundary=!o.edgepaths.length&&(a>o.level||o.starts.length&&a===o.level)}break;case\"constraint\":if(n.prefixBoundary=!1,n.edgepaths.length)return;var s=n.x.length,l=n.y.length,c=-1/0,u=1/0;for(r=0;r<l;r++)u=Math.min(u,i[r][0]),u=Math.min(u,i[r][s-1]),c=Math.max(c,i[r][0]),c=Math.max(c,i[r][s-1]);for(r=1;r<s-1;r++)u=Math.min(u,i[0][r]),u=Math.min(u,i[l-1][r]),c=Math.max(c,i[0][r]),c=Math.max(c,i[l-1][r]);var f,h,p=e.value;switch(e._operation){case\">\":p>c&&(n.prefixBoundary=!0);break;case\"<\":(p<u||n.starts.length&&p===u)&&(n.prefixBoundary=!0);break;case\"[]\":f=Math.min(p[0],p[1]),((h=Math.max(p[0],p[1]))<u||f>c||n.starts.length&&h===u)&&(n.prefixBoundary=!0);break;case\"][\":f=Math.min(p[0],p[1]),h=Math.max(p[0],p[1]),f<u&&h>c&&(n.prefixBoundary=!0)}}}},{}],1027:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale\"),i=t(\"./make_color_map\"),a=t(\"./end_plus\");e.exports={min:\"zmin\",max:\"zmax\",calc:function(t,e,r){var o=e.contours,s=e.line,l=o.size||1,c=o.coloring,u=i(e,{isColorbar:!0});if(\"heatmap\"===c){var f=n.extractOpts(e);r._fillgradient=f.reversescale?n.flipScale(f.colorscale):f.colorscale,r._zrange=[f.min,f.max]}else\"fill\"===c&&(r._fillcolor=u);r._line={color:\"lines\"===c?u:s.color,width:!1!==o.showlines?s.width:0,dash:s.dash},r._levels={start:o.start,end:a(o),size:l}}}},{\"../../components/colorscale\":674,\"./end_plus\":1035,\"./make_color_map\":1040}],1028:[function(t,e,r){\"use strict\";e.exports={BOTTOMSTART:[1,9,13,104,713],TOPSTART:[4,6,7,104,713],LEFTSTART:[8,12,14,208,1114],RIGHTSTART:[2,3,11,208,1114],NEWDELTA:[null,[-1,0],[0,-1],[-1,0],[1,0],null,[0,-1],[-1,0],[0,1],[0,1],null,[0,1],[1,0],[1,0],[0,-1]],CHOOSESADDLE:{104:[4,1],208:[2,8],713:[7,13],1114:[11,14]},SADDLEREMAINDER:{1:4,2:8,4:1,7:13,8:2,11:14,13:7,14:11},LABELDISTANCE:2,LABELINCREASE:10,LABELMIN:3,LABELMAX:10,LABELOPTIMIZER:{EDGECOST:1,ANGLECOST:1,NEIGHBORCOST:5,SAMELEVELFACTOR:10,SAMELEVELDISTANCE:5,MAXCOST:100,INITIALSEARCHPOINTS:10,ITERATIONS:5}}},{}],1029:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"./label_defaults\"),a=t(\"../../components/color\"),o=a.addOpacity,s=a.opacity,l=t(\"../../constants/filter_ops\"),c=l.CONSTRAINT_REDUCTION,u=l.COMPARISON_OPS2;e.exports=function(t,e,r,a,l,f){var h,p,d,m=e.contours,g=r(\"contours.operation\");(m._operation=c[g],function(t,e){var r;-1===u.indexOf(e.operation)?(t(\"contours.value\",[0,1]),Array.isArray(e.value)?e.value.length>2?e.value=e.value.slice(2):0===e.length?e.value=[0,1]:e.length<2?(r=parseFloat(e.value[0]),e.value=[r,r+1]):e.value=[parseFloat(e.value[0]),parseFloat(e.value[1])]:n(e.value)&&(r=parseFloat(e.value),e.value=[r,r+1])):(t(\"contours.value\",0),n(e.value)||(Array.isArray(e.value)?e.value=parseFloat(e.value[0]):e.value=0))}(r,m),\"=\"===g?h=m.showlines=!0:(h=r(\"contours.showlines\"),d=r(\"fillcolor\",o((t.line||{}).color||l,.5))),h)&&(p=r(\"line.color\",d&&s(d)?o(e.fillcolor,1):l),r(\"line.width\",2),r(\"line.dash\"));r(\"line.smoothing\"),i(r,a,p,f)}},{\"../../components/color\":662,\"../../constants/filter_ops\":771,\"./label_defaults\":1039,\"fast-isnumeric\":245}],1030:[function(t,e,r){\"use strict\";var n=t(\"../../constants/filter_ops\"),i=t(\"fast-isnumeric\");function a(t,e){var r,a=Array.isArray(e);function o(t){return i(t)?+t:null}return-1!==n.COMPARISON_OPS2.indexOf(t)?r=o(a?e[0]:e):-1!==n.INTERVAL_OPS.indexOf(t)?r=a?[o(e[0]),o(e[1])]:[o(e),o(e)]:-1!==n.SET_OPS.indexOf(t)&&(r=a?e.map(o):[o(e)]),r}function o(t){return function(e){e=a(t,e);var r=Math.min(e[0],e[1]),n=Math.max(e[0],e[1]);return{start:r,end:n,size:n-r}}}function s(t){return function(e){return{start:e=a(t,e),end:1/0,size:1/0}}}e.exports={\"[]\":o(\"[]\"),\"][\":o(\"][\"),\">\":s(\">\"),\"<\":s(\"<\"),\"=\":s(\"=\")}},{\"../../constants/filter_ops\":771,\"fast-isnumeric\":245}],1031:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n){var i=n(\"contours.start\"),a=n(\"contours.end\"),o=!1===i||!1===a,s=r(\"contours.size\");!(o?e.autocontour=!0:r(\"autocontour\",!1))&&s||r(\"ncontours\")}},{}],1032:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");function i(t){return n.extendFlat({},t,{edgepaths:n.extendDeep([],t.edgepaths),paths:n.extendDeep([],t.paths),starts:n.extendDeep([],t.starts)})}e.exports=function(t,e){var r,a,o,s=function(t){return t.reverse()},l=function(t){return t};switch(e){case\"=\":case\"<\":return t;case\">\":for(1!==t.length&&n.warn(\"Contour data invalid for the specified inequality operation.\"),a=t[0],r=0;r<a.edgepaths.length;r++)a.edgepaths[r]=s(a.edgepaths[r]);for(r=0;r<a.paths.length;r++)a.paths[r]=s(a.paths[r]);for(r=0;r<a.starts.length;r++)a.starts[r]=s(a.starts[r]);return t;case\"][\":var c=s;s=l,l=c;case\"[]\":for(2!==t.length&&n.warn(\"Contour data invalid for the specified inequality range operation.\"),a=i(t[0]),o=i(t[1]),r=0;r<a.edgepaths.length;r++)a.edgepaths[r]=s(a.edgepaths[r]);for(r=0;r<a.paths.length;r++)a.paths[r]=s(a.paths[r]);for(r=0;r<a.starts.length;r++)a.starts[r]=s(a.starts[r]);for(;o.edgepaths.length;)a.edgepaths.push(l(o.edgepaths.shift()));for(;o.paths.length;)a.paths.push(l(o.paths.shift()));for(;o.starts.length;)a.starts.push(l(o.starts.shift()));return[a]}}},{\"../../lib\":799}],1033:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../heatmap/xyz_defaults\"),a=t(\"../scatter/period_defaults\"),o=t(\"./constraint_defaults\"),s=t(\"./contours_defaults\"),l=t(\"./style_defaults\"),c=t(\"./attributes\");e.exports=function(t,e,r,u){function f(r,i){return n.coerce(t,e,c,r,i)}if(i(t,e,f,u)){a(t,e,u,f),f(\"xhoverformat\"),f(\"yhoverformat\"),f(\"text\"),f(\"hovertext\"),f(\"hovertemplate\"),f(\"hoverongaps\");var h=\"constraint\"===f(\"contours.type\");f(\"connectgaps\",n.isArray1D(e.z)),h?o(t,e,f,u,r):(s(t,e,f,(function(r){return n.coerce2(t,e,c,r)})),l(t,e,f,u))}else e.visible=!1}},{\"../../lib\":799,\"../heatmap/xyz_defaults\":1095,\"../scatter/period_defaults\":1234,\"./attributes\":1024,\"./constraint_defaults\":1029,\"./contours_defaults\":1031,\"./style_defaults\":1045}],1034:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./constraint_mapping\"),a=t(\"./end_plus\");e.exports=function(t,e,r){for(var o=\"constraint\"===t.type?i[t._operation](t.value):t,s=o.size,l=[],c=a(o),u=r.trace._carpetTrace,f=u?{xaxis:u.aaxis,yaxis:u.baxis,x:r.a,y:r.b}:{xaxis:e.xaxis,yaxis:e.yaxis,x:r.x,y:r.y},h=o.start;h<c;h+=s)if(l.push(n.extendFlat({level:h,crossings:{},starts:[],edgepaths:[],paths:[],z:r.z,smoothing:r.trace.line.smoothing},f)),l.length>1e3){n.warn(\"Too many contours, clipping at 1000\",t);break}return l}},{\"../../lib\":799,\"./constraint_mapping\":1030,\"./end_plus\":1035}],1035:[function(t,e,r){\"use strict\";e.exports=function(t){return t.end+t.size/1e6}},{}],1036:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./constants\");function a(t,e,r,n){return Math.abs(t[0]-e[0])<r&&Math.abs(t[1]-e[1])<n}function o(t,e,r,o,l){var c,u=e.join(\",\"),f=t.crossings[u],h=function(t,e,r){var n=0,a=0;t>20&&e?208===t||1114===t?n=0===r[0]?1:-1:a=0===r[1]?1:-1:-1!==i.BOTTOMSTART.indexOf(t)?a=1:-1!==i.LEFTSTART.indexOf(t)?n=1:-1!==i.TOPSTART.indexOf(t)?a=-1:n=-1;return[n,a]}(f,r,e),p=[s(t,e,[-h[0],-h[1]])],d=t.z.length,m=t.z[0].length,g=e.slice(),v=h.slice();for(c=0;c<1e4;c++){if(f>20?(f=i.CHOOSESADDLE[f][(h[0]||h[1])<0?0:1],t.crossings[u]=i.SADDLEREMAINDER[f]):delete t.crossings[u],!(h=i.NEWDELTA[f])){n.log(\"Found bad marching index:\",f,e,t.level);break}p.push(s(t,e,h)),e[0]+=h[0],e[1]+=h[1],u=e.join(\",\"),a(p[p.length-1],p[p.length-2],o,l)&&p.pop();var y=h[0]&&(e[0]<0||e[0]>m-2)||h[1]&&(e[1]<0||e[1]>d-2);if(e[0]===g[0]&&e[1]===g[1]&&h[0]===v[0]&&h[1]===v[1]||r&&y)break;f=t.crossings[u]}1e4===c&&n.log(\"Infinite loop in contour?\");var x,b,_,w,T,k,M,A,S,E,L,C,P,I,O,z=a(p[0],p[p.length-1],o,l),D=0,R=.2*t.smoothing,F=[],B=0;for(c=1;c<p.length;c++)C=p[c],P=p[c-1],I=void 0,O=void 0,I=C[2]-P[2],O=C[3]-P[3],D+=M=Math.sqrt(I*I+O*O),F.push(M);var N=D/F.length*R;function j(t){return p[t%p.length]}for(c=p.length-2;c>=B;c--)if((x=F[c])<N){for(_=0,b=c-1;b>=B&&x+F[b]<N;b--)x+=F[b];if(z&&c===p.length-2)for(_=0;_<b&&x+F[_]<N;_++)x+=F[_];T=c-b+_+1,k=Math.floor((c+b+_+2)/2),w=z||c!==p.length-2?z||-1!==b?T%2?j(k):[(j(k)[0]+j(k+1)[0])/2,(j(k)[1]+j(k+1)[1])/2]:p[0]:p[p.length-1],p.splice(b+1,c-b+1,w),c=b+1,_&&(B=_),z&&(c===p.length-2?p[_]=p[p.length-1]:0===c&&(p[p.length-1]=p[0]))}for(p.splice(0,B),c=0;c<p.length;c++)p[c].length=2;if(!(p.length<2))if(z)p.pop(),t.paths.push(p);else{r||n.log(\"Unclosed interior contour?\",t.level,g.join(\",\"),p.join(\"L\"));var U=!1;for(A=0;A<t.edgepaths.length;A++)if(E=t.edgepaths[A],!U&&a(E[0],p[p.length-1],o,l)){p.pop(),U=!0;var V=!1;for(S=0;S<t.edgepaths.length;S++)if(a((L=t.edgepaths[S])[L.length-1],p[0],o,l)){V=!0,p.shift(),t.edgepaths.splice(A,1),S===A?t.paths.push(p.concat(L)):(S>A&&S--,t.edgepaths[S]=L.concat(p,E));break}V||(t.edgepaths[A]=p.concat(E))}for(A=0;A<t.edgepaths.length&&!U;A++)a((E=t.edgepaths[A])[E.length-1],p[0],o,l)&&(p.shift(),t.edgepaths[A]=E.concat(p),U=!0);U||t.edgepaths.push(p)}}function s(t,e,r){var n=e[0]+Math.max(r[0],0),i=e[1]+Math.max(r[1],0),a=t.z[i][n],o=t.xaxis,s=t.yaxis;if(r[1]){var l=(t.level-a)/(t.z[i][n+1]-a);return[o.c2p((1-l)*t.x[n]+l*t.x[n+1],!0),s.c2p(t.y[i],!0),n+l,i]}var c=(t.level-a)/(t.z[i+1][n]-a);return[o.c2p(t.x[n],!0),s.c2p((1-c)*t.y[i]+c*t.y[i+1],!0),n,i+c]}e.exports=function(t,e,r){var i,a,s,l;for(e=e||.01,r=r||.01,a=0;a<t.length;a++){for(s=t[a],l=0;l<s.starts.length;l++)o(s,s.starts[l],\"edge\",e,r);for(i=0;Object.keys(s.crossings).length&&i<1e4;)i++,o(s,Object.keys(s.crossings)[0].split(\",\").map(Number),void 0,e,r);1e4===i&&n.log(\"Infinite loop in contour?\")}}},{\"../../lib\":799,\"./constants\":1028}],1037:[function(t,e,r){\"use strict\";var n=t(\"../../components/color\"),i=t(\"../heatmap/hover\");e.exports=function(t,e,r,a,o){o||(o={}),o.isContour=!0;var s=i(t,e,r,a,o);return s&&s.forEach((function(t){var e=t.trace;\"constraint\"===e.contours.type&&(e.fillcolor&&n.opacity(e.fillcolor)?t.color=n.addOpacity(e.fillcolor,1):e.contours.showlines&&n.opacity(e.line.color)&&(t.color=n.addOpacity(e.line.color,1)))})),s}},{\"../../components/color\":662,\"../heatmap/hover\":1088}],1038:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\"),plot:t(\"./plot\").plot,style:t(\"./style\"),colorbar:t(\"./colorbar\"),hoverPoints:t(\"./hover\"),moduleType:\"trace\",name:\"contour\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"2dMap\",\"contour\",\"showLegend\"],meta:{}}},{\"../../plots/cartesian\":863,\"./attributes\":1024,\"./calc\":1025,\"./colorbar\":1027,\"./defaults\":1033,\"./hover\":1037,\"./plot\":1042,\"./style\":1044}],1039:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e,r,i){if(i||(i={}),t(\"contours.showlabels\")){var a=e.font;n.coerceFont(t,\"contours.labelfont\",{family:a.family,size:a.size,color:r}),t(\"contours.labelformat\")}!1!==i.hasHover&&t(\"zhoverformat\")}},{\"../../lib\":799}],1040:[function(t,e,r){\"use strict\";var n=t(\"@plotly/d3\"),i=t(\"../../components/colorscale\"),a=t(\"./end_plus\");e.exports=function(t){var e=t.contours,r=e.start,o=a(e),s=e.size||1,l=Math.floor((o-r)/s)+1,c=\"lines\"===e.coloring?0:1,u=i.extractOpts(t);isFinite(s)||(s=1,l=1);var f,h,p=u.reversescale?i.flipScale(u.colorscale):u.colorscale,d=p.length,m=new Array(d),g=new Array(d);if(\"heatmap\"===e.coloring){var v=u.min,y=u.max;for(h=0;h<d;h++)f=p[h],m[h]=f[0]*(y-v)+v,g[h]=f[1];var x=n.extent([v,y,e.start,e.start+s*(l-1)]),b=x[v<y?0:1],_=x[v<y?1:0];b!==v&&(m.splice(0,0,b),g.splice(0,0,g[0])),_!==y&&(m.push(_),g.push(g[g.length-1]))}else for(h=0;h<d;h++)f=p[h],m[h]=(f[0]*(l+c-1)-c/2)*s+r,g[h]=f[1];return i.makeColorScaleFunc({domain:m,range:g},{noNumericCheck:!0})}},{\"../../components/colorscale\":674,\"./end_plus\":1035,\"@plotly/d3\":58}],1041:[function(t,e,r){\"use strict\";var n=t(\"./constants\");function i(t,e){var r=(e[0][0]>t?0:1)+(e[0][1]>t?0:2)+(e[1][1]>t?0:4)+(e[1][0]>t?0:8);return 5===r||10===r?t>(e[0][0]+e[0][1]+e[1][0]+e[1][1])/4?5===r?713:1114:5===r?104:208:15===r?0:r}e.exports=function(t){var e,r,a,o,s,l,c,u,f,h=t[0].z,p=h.length,d=h[0].length,m=2===p||2===d;for(r=0;r<p-1;r++)for(o=[],0===r&&(o=o.concat(n.BOTTOMSTART)),r===p-2&&(o=o.concat(n.TOPSTART)),e=0;e<d-1;e++)for(a=o.slice(),0===e&&(a=a.concat(n.LEFTSTART)),e===d-2&&(a=a.concat(n.RIGHTSTART)),s=e+\",\"+r,l=[[h[r][e],h[r][e+1]],[h[r+1][e],h[r+1][e+1]]],f=0;f<t.length;f++)(c=i((u=t[f]).level,l))&&(u.crossings[s]=c,-1!==a.indexOf(c)&&(u.starts.push([e,r]),m&&-1!==a.indexOf(c,a.indexOf(c)+1)&&u.starts.push([e,r])))}},{\"./constants\":1028}],1042:[function(t,e,r){\"use strict\";var n=t(\"@plotly/d3\"),i=t(\"../../lib\"),a=t(\"../../components/drawing\"),o=t(\"../../components/colorscale\"),s=t(\"../../lib/svg_text_utils\"),l=t(\"../../plots/cartesian/axes\"),c=t(\"../../plots/cartesian/set_convert\"),u=t(\"../heatmap/plot\"),f=t(\"./make_crossings\"),h=t(\"./find_all_paths\"),p=t(\"./empty_pathinfo\"),d=t(\"./convert_to_constraints\"),m=t(\"./close_boundaries\"),g=t(\"./constants\"),v=g.LABELOPTIMIZER;function y(t,e){var r,n,o,s,l,c,u,f=\"\",h=0,p=t.edgepaths.map((function(t,e){return e})),d=!0;function m(t){return Math.abs(t[1]-e[2][1])<.01}function g(t){return Math.abs(t[0]-e[0][0])<.01}function v(t){return Math.abs(t[0]-e[2][0])<.01}for(;p.length;){for(c=a.smoothopen(t.edgepaths[h],t.smoothing),f+=d?c:c.replace(/^M/,\"L\"),p.splice(p.indexOf(h),1),r=t.edgepaths[h][t.edgepaths[h].length-1],s=-1,o=0;o<4;o++){if(!r){i.log(\"Missing end?\",h,t);break}for(u=r,Math.abs(u[1]-e[0][1])<.01&&!v(r)?n=e[1]:g(r)?n=e[0]:m(r)?n=e[3]:v(r)&&(n=e[2]),l=0;l<t.edgepaths.length;l++){var y=t.edgepaths[l][0];Math.abs(r[0]-n[0])<.01?Math.abs(r[0]-y[0])<.01&&(y[1]-r[1])*(n[1]-y[1])>=0&&(n=y,s=l):Math.abs(r[1]-n[1])<.01?Math.abs(r[1]-y[1])<.01&&(y[0]-r[0])*(n[0]-y[0])>=0&&(n=y,s=l):i.log(\"endpt to newendpt is not vert. or horz.\",r,n,y)}if(r=n,s>=0)break;f+=\"L\"+n}if(s===t.edgepaths.length){i.log(\"unclosed perimeter path\");break}h=s,(d=-1===p.indexOf(h))&&(h=p[0],f+=\"Z\")}for(h=0;h<t.paths.length;h++)f+=a.smoothclosed(t.paths[h],t.smoothing);return f}function x(t,e,r,n){var a=e.width/2,o=e.height/2,s=t.x,l=t.y,c=t.theta,u=Math.cos(c)*a,f=Math.sin(c)*a,h=(s>n.center?n.right-s:s-n.left)/(u+Math.abs(Math.sin(c)*o)),p=(l>n.middle?n.bottom-l:l-n.top)/(Math.abs(f)+Math.cos(c)*o);if(h<1||p<1)return 1/0;var d=v.EDGECOST*(1/(h-1)+1/(p-1));d+=v.ANGLECOST*c*c;for(var m=s-u,g=l-f,y=s+u,x=l+f,b=0;b<r.length;b++){var _=r[b],w=Math.cos(_.theta)*_.width/2,T=Math.sin(_.theta)*_.width/2,k=2*i.segmentDistance(m,g,y,x,_.x-w,_.y-T,_.x+w,_.y+T)/(e.height+_.height),M=_.level===e.level,A=M?v.SAMELEVELDISTANCE:1;if(k<=A)return 1/0;d+=v.NEIGHBORCOST*(M?v.SAMELEVELFACTOR:1)/(k-A)}return d}function b(t){var e,r,n=t.trace._emptypoints,i=[],a=t.z.length,o=t.z[0].length,s=[];for(e=0;e<o;e++)s.push(1);for(e=0;e<a;e++)i.push(s.slice());for(e=0;e<n.length;e++)i[(r=n[e])[0]][r[1]]=0;return t.zmask=i,i}r.plot=function(t,e,o,s){var l=e.xaxis,c=e.yaxis;i.makeTraceGroups(s,o,\"contour\").each((function(o){var s=n.select(this),v=o[0],x=v.trace,_=v.x,w=v.y,T=x.contours,k=p(T,e,v),M=i.ensureSingle(s,\"g\",\"heatmapcoloring\"),A=[];\"heatmap\"===T.coloring&&(A=[o]),u(t,e,A,M),f(k),h(k);var S=l.c2p(_[0],!0),E=l.c2p(_[_.length-1],!0),L=c.c2p(w[0],!0),C=c.c2p(w[w.length-1],!0),P=[[S,C],[E,C],[E,L],[S,L]],I=k;\"constraint\"===T.type&&(I=d(k,T._operation)),function(t,e,r){var n=i.ensureSingle(t,\"g\",\"contourbg\").selectAll(\"path\").data(\"fill\"===r.coloring?[0]:[]);n.enter().append(\"path\"),n.exit().remove(),n.attr(\"d\",\"M\"+e.join(\"L\")+\"Z\").style(\"stroke\",\"none\")}(s,P,T),function(t,e,r,a){var o=\"fill\"===a.coloring||\"constraint\"===a.type&&\"=\"!==a._operation,s=\"M\"+r.join(\"L\")+\"Z\";o&&m(e,a);var l=i.ensureSingle(t,\"g\",\"contourfill\").selectAll(\"path\").data(o?e:[]);l.enter().append(\"path\"),l.exit().remove(),l.each((function(t){var e=(t.prefixBoundary?s:\"\")+y(t,r);e?n.select(this).attr(\"d\",e).style(\"stroke\",\"none\"):n.select(this).remove()}))}(s,I,P,T),function(t,e,o,s,l){var c=i.ensureSingle(t,\"g\",\"contourlines\"),u=!1!==l.showlines,f=l.showlabels,h=u&&f,p=r.createLines(c,u||f,e),d=r.createLineClip(c,h,o,s.trace.uid),m=t.selectAll(\"g.contourlabels\").data(f?[0]:[]);if(m.exit().remove(),m.enter().append(\"g\").classed(\"contourlabels\",!0),f){var v=[],y=[];i.clearLocationCache();var x=r.labelFormatter(o,s),b=a.tester.append(\"text\").attr(\"data-notex\",1).call(a.font,l.labelfont),_=e[0].xaxis,w=e[0].yaxis,T=_._length,k=w._length,M=_.range,A=w.range,S=i.aggNums(Math.min,null,s.x),E=i.aggNums(Math.max,null,s.x),L=i.aggNums(Math.min,null,s.y),C=i.aggNums(Math.max,null,s.y),P=Math.max(_.c2p(S,!0),0),I=Math.min(_.c2p(E,!0),T),O=Math.max(w.c2p(C,!0),0),z=Math.min(w.c2p(L,!0),k),D={};M[0]<M[1]?(D.left=P,D.right=I):(D.left=I,D.right=P),A[0]<A[1]?(D.top=O,D.bottom=z):(D.top=z,D.bottom=O),D.middle=(D.top+D.bottom)/2,D.center=(D.left+D.right)/2,v.push([[D.left,D.top],[D.right,D.top],[D.right,D.bottom],[D.left,D.bottom]]);var R=Math.sqrt(T*T+k*k),F=g.LABELDISTANCE*R/Math.max(1,e.length/g.LABELINCREASE);p.each((function(t){var e=r.calcTextOpts(t.level,x,b,o);n.select(this).selectAll(\"path\").each((function(){var t=i.getVisibleSegment(this,D,e.height/2);if(t&&!(t.len<(e.width+e.height)*g.LABELMIN))for(var n=Math.min(Math.ceil(t.len/F),g.LABELMAX),a=0;a<n;a++){var o=r.findBestTextLocation(this,t,e,y,D);if(!o)break;r.addLabelData(o,e,y,v)}}))})),b.remove(),r.drawLabels(m,y,o,d,h?v:null)}f&&!u&&p.remove()}(s,k,t,v,T),function(t,e,r,n,o){var s=n.trace,l=r._fullLayout._clips,c=\"clip\"+s.uid,u=l.selectAll(\"#\"+c).data(s.connectgaps?[]:[0]);if(u.enter().append(\"clipPath\").classed(\"contourclip\",!0).attr(\"id\",c),u.exit().remove(),!1===s.connectgaps){var p={level:.9,crossings:{},starts:[],edgepaths:[],paths:[],xaxis:e.xaxis,yaxis:e.yaxis,x:n.x,y:n.y,z:b(n),smoothing:0};f([p]),h([p]),m([p],{type:\"levels\"}),i.ensureSingle(u,\"path\",\"\").attr(\"d\",(p.prefixBoundary?\"M\"+o.join(\"L\")+\"Z\":\"\")+y(p,o))}else c=null;a.setClipUrl(t,c,r)}(s,e,t,v,P)}))},r.createLines=function(t,e,r){var n=r[0].smoothing,i=t.selectAll(\"g.contourlevel\").data(e?r:[]);if(i.exit().remove(),i.enter().append(\"g\").classed(\"contourlevel\",!0),e){var o=i.selectAll(\"path.openline\").data((function(t){return t.pedgepaths||t.edgepaths}));o.exit().remove(),o.enter().append(\"path\").classed(\"openline\",!0),o.attr(\"d\",(function(t){return a.smoothopen(t,n)})).style(\"stroke-miterlimit\",1).style(\"vector-effect\",\"non-scaling-stroke\");var s=i.selectAll(\"path.closedline\").data((function(t){return t.ppaths||t.paths}));s.exit().remove(),s.enter().append(\"path\").classed(\"closedline\",!0),s.attr(\"d\",(function(t){return a.smoothclosed(t,n)})).style(\"stroke-miterlimit\",1).style(\"vector-effect\",\"non-scaling-stroke\")}return i},r.createLineClip=function(t,e,r,n){var i=e?\"clipline\"+n:null,o=r._fullLayout._clips.selectAll(\"#\"+i).data(e?[0]:[]);return o.exit().remove(),o.enter().append(\"clipPath\").classed(\"contourlineclip\",!0).attr(\"id\",i),a.setClipUrl(t,i,r),o},r.labelFormatter=function(t,e){var r=t._fullLayout,n=e.trace,i=n.contours,a={type:\"linear\",_id:\"ycontour\",showexponent:\"all\",exponentformat:\"B\"};if(i.labelformat)a.tickformat=i.labelformat,c(a,r);else{var s=o.extractOpts(n);if(s&&s.colorbar&&s.colorbar._axis)a=s.colorbar._axis;else{if(\"constraint\"===i.type){var u=i.value;Array.isArray(u)?a.range=[u[0],u[u.length-1]]:a.range=[u,u]}else a.range=[i.start,i.end],a.nticks=(i.end-i.start)/i.size;a.range[0]===a.range[1]&&(a.range[1]+=a.range[0]||1),a.nticks||(a.nticks=1e3),c(a,r),l.prepTicks(a),a._tmin=null,a._tmax=null}}return function(t){return l.tickText(a,t).text}},r.calcTextOpts=function(t,e,r,n){var i=e(t);r.text(i).call(s.convertToTspans,n);var o=r.node(),l=a.bBox(o,!0);return{text:i,width:l.width,height:l.height,fontSize:+o.style[\"font-size\"].replace(\"px\",\"\"),level:t,dy:(l.top+l.bottom)/2}},r.findBestTextLocation=function(t,e,r,n,a){var o,s,l,c,u,f=r.width;e.isClosed?(s=e.len/v.INITIALSEARCHPOINTS,o=e.min+s/2,l=e.max):(s=(e.len-f)/(v.INITIALSEARCHPOINTS+1),o=e.min+s+f/2,l=e.max-(s+f)/2);for(var h=1/0,p=0;p<v.ITERATIONS;p++){for(var d=o;d<l;d+=s){var m=i.getTextLocation(t,e.total,d,f),g=x(m,r,n,a);g<h&&(h=g,u=m,c=d)}if(h>2*v.MAXCOST)break;p&&(s/=2),l=(o=c-s/2)+1.5*s}if(h<=v.MAXCOST)return u},r.addLabelData=function(t,e,r,n){var i=e.fontSize,a=e.width+i/3,o=Math.max(0,e.height-i/3),s=t.x,l=t.y,c=t.theta,u=Math.sin(c),f=Math.cos(c),h=function(t,e){return[s+t*f-e*u,l+t*u+e*f]},p=[h(-a/2,-o/2),h(-a/2,o/2),h(a/2,o/2),h(a/2,-o/2)];r.push({text:e.text,x:s,y:l,dy:e.dy,theta:c,level:e.level,width:a,height:o}),n.push(p)},r.drawLabels=function(t,e,r,a,o){var l=t.selectAll(\"text\").data(e,(function(t){return t.text+\",\"+t.x+\",\"+t.y+\",\"+t.theta}));if(l.exit().remove(),l.enter().append(\"text\").attr({\"data-notex\":1,\"text-anchor\":\"middle\"}).each((function(t){var e=t.x+Math.sin(t.theta)*t.dy,i=t.y-Math.cos(t.theta)*t.dy;n.select(this).text(t.text).attr({x:e,y:i,transform:\"rotate(\"+180*t.theta/Math.PI+\" \"+e+\" \"+i+\")\"}).call(s.convertToTspans,r)})),o){for(var c=\"\",u=0;u<o.length;u++)c+=\"M\"+o[u].join(\"L\")+\"Z\";i.ensureSingle(a,\"path\",\"\").attr(\"d\",c)}}},{\"../../components/colorscale\":674,\"../../components/drawing\":684,\"../../lib\":799,\"../../lib/svg_text_utils\":824,\"../../plots/cartesian/axes\":849,\"../../plots/cartesian/set_convert\":870,\"../heatmap/plot\":1092,\"./close_boundaries\":1026,\"./constants\":1028,\"./convert_to_constraints\":1032,\"./empty_pathinfo\":1034,\"./find_all_paths\":1036,\"./make_crossings\":1041,\"@plotly/d3\":58}],1043:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"../../lib\");function a(t,e,r){var i={type:\"linear\",range:[t,e]};return n.autoTicks(i,(e-t)/(r||15)),i}e.exports=function(t,e){var r=t.contours;if(t.autocontour){var o=t.zmin,s=t.zmax;(t.zauto||void 0===o)&&(o=i.aggNums(Math.min,null,e)),(t.zauto||void 0===s)&&(s=i.aggNums(Math.max,null,e));var l=a(o,s,t.ncontours);r.size=l.dtick,r.start=n.tickFirst(l),l.range.reverse(),r.end=n.tickFirst(l),r.start===o&&(r.start+=r.size),r.end===s&&(r.end-=r.size),r.start>r.end&&(r.start=r.end=(r.start+r.end)/2),t._input.contours||(t._input.contours={}),i.extendFlat(t._input.contours,{start:r.start,end:r.end,size:r.size}),t._input.autocontour=!0}else if(\"constraint\"!==r.type){var c,u=r.start,f=r.end,h=t._input.contours;if(u>f&&(r.start=h.start=f,f=r.end=h.end=u,u=r.start),!(r.size>0))c=u===f?1:a(u,f,t.ncontours).dtick,h.size=r.size=c}}},{\"../../lib\":799,\"../../plots/cartesian/axes\":849}],1044:[function(t,e,r){\"use strict\";var n=t(\"@plotly/d3\"),i=t(\"../../components/drawing\"),a=t(\"../heatmap/style\"),o=t(\"./make_color_map\");e.exports=function(t){var e=n.select(t).selectAll(\"g.contour\");e.style(\"opacity\",(function(t){return t[0].trace.opacity})),e.each((function(t){var e=n.select(this),r=t[0].trace,a=r.contours,s=r.line,l=a.size||1,c=a.start,u=\"constraint\"===a.type,f=!u&&\"lines\"===a.coloring,h=!u&&\"fill\"===a.coloring,p=f||h?o(r):null;e.selectAll(\"g.contourlevel\").each((function(t){n.select(this).selectAll(\"path\").call(i.lineGroupStyle,s.width,f?p(t.level):s.color,s.dash)}));var d=a.labelfont;if(e.selectAll(\"g.contourlabels text\").each((function(t){i.font(n.select(this),{family:d.family,size:d.size,color:d.color||(f?p(t.level):s.color)})})),u)e.selectAll(\"g.contourfill path\").style(\"fill\",r.fillcolor);else if(h){var m;e.selectAll(\"g.contourfill path\").style(\"fill\",(function(t){return void 0===m&&(m=t.level),p(t.level+.5*l)})),void 0===m&&(m=c),e.selectAll(\"g.contourbg path\").style(\"fill\",p(m-.5*l))}})),a(t)}},{\"../../components/drawing\":684,\"../heatmap/style\":1093,\"./make_color_map\":1040,\"@plotly/d3\":58}],1045:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/defaults\"),i=t(\"./label_defaults\");e.exports=function(t,e,r,a,o){var s,l=r(\"contours.coloring\"),c=\"\";\"fill\"===l&&(s=r(\"contours.showlines\")),!1!==s&&(\"lines\"!==l&&(c=r(\"line.color\",\"#000\")),r(\"line.width\",.5),r(\"line.dash\")),\"none\"!==l&&(!0!==t.showlegend&&(e.showlegend=!1),e._dfltShowLegend=!1,n(t,e,a,r,{prefix:\"\",cLetter:\"z\"})),r(\"line.smoothing\"),i(r,a,c,o)}},{\"../../components/colorscale/defaults\":672,\"./label_defaults\":1039}],1046:[function(t,e,r){\"use strict\";var n=t(\"../heatmap/attributes\"),i=t(\"../contour/attributes\"),a=t(\"../../components/colorscale/attributes\"),o=t(\"../../lib/extend\").extendFlat,s=i.contours;e.exports=o({carpet:{valType:\"string\",editType:\"calc\"},z:n.z,a:n.x,a0:n.x0,da:n.dx,b:n.y,b0:n.y0,db:n.dy,text:n.text,hovertext:n.hovertext,transpose:n.transpose,atype:n.xtype,btype:n.ytype,fillcolor:i.fillcolor,autocontour:i.autocontour,ncontours:i.ncontours,contours:{type:s.type,start:s.start,end:s.end,size:s.size,coloring:{valType:\"enumerated\",values:[\"fill\",\"lines\",\"none\"],dflt:\"fill\",editType:\"calc\"},showlines:s.showlines,showlabels:s.showlabels,labelfont:s.labelfont,labelformat:s.labelformat,operation:s.operation,value:s.value,editType:\"calc\",impliedEdits:{autocontour:!1}},line:{color:i.line.color,width:i.line.width,dash:i.line.dash,smoothing:i.line.smoothing,editType:\"plot\"},transforms:void 0},a(\"\",{cLetter:\"z\",autoColorDflt:!1}))},{\"../../components/colorscale/attributes\":669,\"../../lib/extend\":789,\"../contour/attributes\":1024,\"../heatmap/attributes\":1081}],1047:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/calc\"),i=t(\"../../lib\"),a=t(\"../heatmap/convert_column_xyz\"),o=t(\"../heatmap/clean_2d_array\"),s=t(\"../heatmap/interp2d\"),l=t(\"../heatmap/find_empties\"),c=t(\"../heatmap/make_bound_array\"),u=t(\"./defaults\"),f=t(\"../carpet/lookup_carpetid\"),h=t(\"../contour/set_contours\");e.exports=function(t,e){var r=e._carpetTrace=f(t,e);if(r&&r.visible&&\"legendonly\"!==r.visible){if(!e.a||!e.b){var p=t.data[r.index],d=t.data[e.index];d.a||(d.a=p.a),d.b||(d.b=p.b),u(d,e,e._defaultColor,t._fullLayout)}var m=function(t,e){var r,u,f,h,p,d,m,g=e._carpetTrace,v=g.aaxis,y=g.baxis;v._minDtick=0,y._minDtick=0,i.isArray1D(e.z)&&a(e,v,y,\"a\",\"b\",[\"z\"]);r=e._a=e._a||e.a,h=e._b=e._b||e.b,r=r?v.makeCalcdata(e,\"_a\"):[],h=h?y.makeCalcdata(e,\"_b\"):[],u=e.a0||0,f=e.da||1,p=e.b0||0,d=e.db||1,m=e._z=o(e._z||e.z,e.transpose),e._emptypoints=l(m),s(m,e._emptypoints);var x=i.maxRowLength(m),b=\"scaled\"===e.xtype?\"\":r,_=c(e,b,u,f,x,v),w=\"scaled\"===e.ytype?\"\":h,T=c(e,w,p,d,m.length,y),k={a:_,b:T,z:m};\"levels\"===e.contours.type&&\"none\"!==e.contours.coloring&&n(t,e,{vals:m,containerStr:\"\",cLetter:\"z\"});return[k]}(t,e);return h(e,e._z),m}}},{\"../../components/colorscale/calc\":670,\"../../lib\":799,\"../carpet/lookup_carpetid\":997,\"../contour/set_contours\":1043,\"../heatmap/clean_2d_array\":1083,\"../heatmap/convert_column_xyz\":1085,\"../heatmap/find_empties\":1087,\"../heatmap/interp2d\":1090,\"../heatmap/make_bound_array\":1091,\"./defaults\":1048}],1048:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../heatmap/xyz_defaults\"),a=t(\"./attributes\"),o=t(\"../contour/constraint_defaults\"),s=t(\"../contour/contours_defaults\"),l=t(\"../contour/style_defaults\");e.exports=function(t,e,r,c){function u(r,i){return n.coerce(t,e,a,r,i)}if(u(\"carpet\"),t.a&&t.b){if(!i(t,e,u,c,\"a\",\"b\"))return void(e.visible=!1);u(\"text\"),\"constraint\"===u(\"contours.type\")?o(t,e,u,c,r,{hasHover:!1}):(s(t,e,u,(function(r){return n.coerce2(t,e,a,r)})),l(t,e,u,c,{hasHover:!1}))}else e._defaultColor=r,e._length=null}},{\"../../lib\":799,\"../contour/constraint_defaults\":1029,\"../contour/contours_defaults\":1031,\"../contour/style_defaults\":1045,\"../heatmap/xyz_defaults\":1095,\"./attributes\":1046}],1049:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../contour/colorbar\"),calc:t(\"./calc\"),plot:t(\"./plot\"),style:t(\"../contour/style\"),moduleType:\"trace\",name:\"contourcarpet\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"carpet\",\"contour\",\"symbols\",\"showLegend\",\"hasLines\",\"carpetDependent\",\"noHover\",\"noSortingByValue\"],meta:{}}},{\"../../plots/cartesian\":863,\"../contour/colorbar\":1027,\"../contour/style\":1044,\"./attributes\":1046,\"./calc\":1047,\"./defaults\":1048,\"./plot\":1050}],1050:[function(t,e,r){\"use strict\";var n=t(\"@plotly/d3\"),i=t(\"../carpet/map_1d_array\"),a=t(\"../carpet/makepath\"),o=t(\"../../components/drawing\"),s=t(\"../../lib\"),l=t(\"../contour/make_crossings\"),c=t(\"../contour/find_all_paths\"),u=t(\"../contour/plot\"),f=t(\"../contour/constants\"),h=t(\"../contour/convert_to_constraints\"),p=t(\"../contour/empty_pathinfo\"),d=t(\"../contour/close_boundaries\"),m=t(\"../carpet/lookup_carpetid\"),g=t(\"../carpet/axis_aligned_line\");function v(t,e,r){var n=t.getPointAtLength(e),i=t.getPointAtLength(r),a=i.x-n.x,o=i.y-n.y,s=Math.sqrt(a*a+o*o);return[a/s,o/s]}function y(t){var e=Math.sqrt(t[0]*t[0]+t[1]*t[1]);return[t[0]/e,t[1]/e]}function x(t,e){var r=Math.abs(t[0]*e[0]+t[1]*e[1]);return Math.sqrt(1-r*r)/r}e.exports=function(t,e,r,b){var _=e.xaxis,w=e.yaxis;s.makeTraceGroups(b,r,\"contour\").each((function(r){var b=n.select(this),T=r[0],k=T.trace,M=k._carpetTrace=m(t,k),A=t.calcdata[M.index][0];if(M.visible&&\"legendonly\"!==M.visible){var S=T.a,E=T.b,L=k.contours,C=p(L,e,T),P=\"constraint\"===L.type,I=L._operation,O=P?\"=\"===I?\"lines\":\"fill\":L.coloring,z=[[S[0],E[E.length-1]],[S[S.length-1],E[E.length-1]],[S[S.length-1],E[0]],[S[0],E[0]]];l(C);var D=1e-8*(S[S.length-1]-S[0]),R=1e-8*(E[E.length-1]-E[0]);c(C,D,R);var F,B,N,j,U=C;\"constraint\"===L.type&&(U=h(C,I)),function(t,e){var r,n,i,a,o,s,l,c,u;for(r=0;r<t.length;r++){for(a=t[r],o=a.pedgepaths=[],s=a.ppaths=[],n=0;n<a.edgepaths.length;n++){for(u=a.edgepaths[n],l=[],i=0;i<u.length;i++)l[i]=e(u[i]);o.push(l)}for(n=0;n<a.paths.length;n++){for(u=a.paths[n],c=[],i=0;i<u.length;i++)c[i]=e(u[i]);s.push(c)}}}(C,H);var V=[];for(j=A.clipsegments.length-1;j>=0;j--)F=A.clipsegments[j],B=i([],F.x,_.c2p),N=i([],F.y,w.c2p),B.reverse(),N.reverse(),V.push(a(B,N,F.bicubic));var q=\"M\"+V.join(\"L\")+\"Z\";!function(t,e,r,n,o,l){var c,u,f,h,p=s.ensureSingle(t,\"g\",\"contourbg\").selectAll(\"path\").data(\"fill\"!==l||o?[]:[0]);p.enter().append(\"path\"),p.exit().remove();var d=[];for(h=0;h<e.length;h++)c=e[h],u=i([],c.x,r.c2p),f=i([],c.y,n.c2p),d.push(a(u,f,c.bicubic));p.attr(\"d\",\"M\"+d.join(\"L\")+\"Z\").style(\"stroke\",\"none\")}(b,A.clipsegments,_,w,P,O),function(t,e,r,i,a,l,c,u,f,h,p){var m=\"fill\"===h;m&&d(a,t.contours);var v=s.ensureSingle(e,\"g\",\"contourfill\").selectAll(\"path\").data(m?a:[]);v.enter().append(\"path\"),v.exit().remove(),v.each((function(t){var e=(t.prefixBoundary?p:\"\")+function(t,e,r,n,i,a,l,c){var u,f,h,p,d,m,v,y=\"\",x=e.edgepaths.map((function(t,e){return e})),b=!0,_=1e-4*Math.abs(r[0][0]-r[2][0]),w=1e-4*Math.abs(r[0][1]-r[2][1]);function T(t){return Math.abs(t[1]-r[0][1])<w}function k(t){return Math.abs(t[1]-r[2][1])<w}function M(t){return Math.abs(t[0]-r[0][0])<_}function A(t){return Math.abs(t[0]-r[2][0])<_}function S(t,e){var r,n,o,s,u=\"\";for(T(t)&&!A(t)||k(t)&&!M(t)?(s=i.aaxis,o=g(i,a,[t[0],e[0]],.5*(t[1]+e[1]))):(s=i.baxis,o=g(i,a,.5*(t[0]+e[0]),[t[1],e[1]])),r=1;r<o.length;r++)for(u+=s.smoothing?\"C\":\"L\",n=0;n<o[r].length;n++){var f=o[r][n];u+=[l.c2p(f[0]),c.c2p(f[1])]+\" \"}return u}u=0,f=null;for(;x.length;){var E=e.edgepaths[u][0];for(f&&(y+=S(f,E)),v=o.smoothopen(e.edgepaths[u].map(n),e.smoothing),y+=b?v:v.replace(/^M/,\"L\"),x.splice(x.indexOf(u),1),f=e.edgepaths[u][e.edgepaths[u].length-1],d=-1,p=0;p<4;p++){if(!f){s.log(\"Missing end?\",u,e);break}for(T(f)&&!A(f)?h=r[1]:M(f)?h=r[0]:k(f)?h=r[3]:A(f)&&(h=r[2]),m=0;m<e.edgepaths.length;m++){var L=e.edgepaths[m][0];Math.abs(f[0]-h[0])<_?Math.abs(f[0]-L[0])<_&&(L[1]-f[1])*(h[1]-L[1])>=0&&(h=L,d=m):Math.abs(f[1]-h[1])<w?Math.abs(f[1]-L[1])<w&&(L[0]-f[0])*(h[0]-L[0])>=0&&(h=L,d=m):s.log(\"endpt to newendpt is not vert. or horz.\",f,h,L)}if(d>=0)break;y+=S(f,h),f=h}if(d===e.edgepaths.length){s.log(\"unclosed perimeter path\");break}u=d,(b=-1===x.indexOf(u))&&(u=x[0],y+=S(f,h)+\"Z\",f=null)}for(u=0;u<e.paths.length;u++)y+=o.smoothclosed(e.paths[u].map(n),e.smoothing);return y}(0,t,l,c,u,f,r,i);e?n.select(this).attr(\"d\",e).style(\"stroke\",\"none\"):n.select(this).remove()}))}(k,b,_,w,U,z,H,M,A,O,q),function(t,e,r,i,a,l,c){var h=s.ensureSingle(t,\"g\",\"contourlines\"),p=!1!==a.showlines,d=a.showlabels,m=p&&d,g=u.createLines(h,p||d,e),b=u.createLineClip(h,m,r,i.trace.uid),_=t.selectAll(\"g.contourlabels\").data(d?[0]:[]);if(_.exit().remove(),_.enter().append(\"g\").classed(\"contourlabels\",!0),d){var w=l.xaxis,T=l.yaxis,k=w._length,M=T._length,A=[[[0,0],[k,0],[k,M],[0,M]]],S=[];s.clearLocationCache();var E=u.labelFormatter(r,i),L=o.tester.append(\"text\").attr(\"data-notex\",1).call(o.font,a.labelfont),C={left:0,right:k,center:k/2,top:0,bottom:M,middle:M/2},P=Math.sqrt(k*k+M*M),I=f.LABELDISTANCE*P/Math.max(1,e.length/f.LABELINCREASE);g.each((function(t){var e=u.calcTextOpts(t.level,E,L,r);n.select(this).selectAll(\"path\").each((function(r){var n=s.getVisibleSegment(this,C,e.height/2);if(n&&(function(t,e,r,n,i,a){for(var o,s=0;s<r.pedgepaths.length;s++)e===r.pedgepaths[s]&&(o=r.edgepaths[s]);if(!o)return;var l=i.a[0],c=i.a[i.a.length-1],u=i.b[0],f=i.b[i.b.length-1];function h(t,e){var r,n=0;return(Math.abs(t[0]-l)<.1||Math.abs(t[0]-c)<.1)&&(r=y(i.dxydb_rough(t[0],t[1],.1)),n=Math.max(n,a*x(e,r)/2)),(Math.abs(t[1]-u)<.1||Math.abs(t[1]-f)<.1)&&(r=y(i.dxyda_rough(t[0],t[1],.1)),n=Math.max(n,a*x(e,r)/2)),n}var p=v(t,0,1),d=v(t,n.total,n.total-1),m=h(o[0],p),g=n.total-h(o[o.length-1],d);n.min<m&&(n.min=m);n.max>g&&(n.max=g);n.len=n.max-n.min}(this,r,t,n,c,e.height),!(n.len<(e.width+e.height)*f.LABELMIN)))for(var i=Math.min(Math.ceil(n.len/I),f.LABELMAX),a=0;a<i;a++){var o=u.findBestTextLocation(this,n,e,S,C);if(!o)break;u.addLabelData(o,e,S,A)}}))})),L.remove(),u.drawLabels(_,S,r,b,m?A:null)}d&&!p&&g.remove()}(b,C,t,T,L,e,M),o.setClipUrl(b,M._clipPathId,t)}function H(t){var e=M.ab2xy(t[0],t[1],!0);return[_.c2p(e[0]),w.c2p(e[1])]}}))}},{\"../../components/drawing\":684,\"../../lib\":799,\"../carpet/axis_aligned_line\":981,\"../carpet/lookup_carpetid\":997,\"../carpet/makepath\":998,\"../carpet/map_1d_array\":999,\"../contour/close_boundaries\":1026,\"../contour/constants\":1028,\"../contour/convert_to_constraints\":1032,\"../contour/empty_pathinfo\":1034,\"../contour/find_all_paths\":1036,\"../contour/make_crossings\":1041,\"../contour/plot\":1042,\"@plotly/d3\":58}],1051:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/attributes\"),i=t(\"../../plots/template_attributes\").hovertemplateAttrs,a=t(\"../../plots/attributes\"),o=t(\"../scattermapbox/attributes\"),s=t(\"../../lib/extend\").extendFlat;e.exports=s({lon:o.lon,lat:o.lat,z:{valType:\"data_array\",editType:\"calc\"},radius:{valType:\"number\",editType:\"plot\",arrayOk:!0,min:1,dflt:30},below:{valType:\"string\",editType:\"plot\"},text:o.text,hovertext:o.hovertext,hoverinfo:s({},a.hoverinfo,{flags:[\"lon\",\"lat\",\"z\",\"text\",\"name\"]}),hovertemplate:i(),showlegend:s({},a.showlegend,{dflt:!1})},n(\"\",{cLetter:\"z\",editTypeOverride:\"calc\"}))},{\"../../components/colorscale/attributes\":669,\"../../lib/extend\":789,\"../../plots/attributes\":845,\"../../plots/template_attributes\":922,\"../scattermapbox/attributes\":1279}],1052:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\").isArrayOrTypedArray,a=t(\"../../constants/numerical\").BADNUM,o=t(\"../../components/colorscale/calc\"),s=t(\"../../lib\")._;e.exports=function(t,e){for(var r=e._length,l=new Array(r),c=e.z,u=i(c)&&c.length,f=0;f<r;f++){var h=l[f]={},p=e.lon[f],d=e.lat[f];if(h.lonlat=n(p)&&n(d)?[+p,+d]:[a,a],u){var m=c[f];h.z=n(m)?m:a}}return o(t,e,{vals:u?c:[0,1],containerStr:\"\",cLetter:\"z\"}),r&&(l[0].t={labels:{lat:s(t,\"lat:\")+\" \",lon:s(t,\"lon:\")+\" \"}}),l}},{\"../../components/colorscale/calc\":670,\"../../constants/numerical\":775,\"../../lib\":799,\"fast-isnumeric\":245}],1053:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../../components/color\"),o=t(\"../../components/colorscale\"),s=t(\"../../constants/numerical\").BADNUM,l=t(\"../../lib/geojson_utils\").makeBlank;e.exports=function(t){var e=t[0].trace,r=!0===e.visible&&0!==e._length,c=e._opts={heatmap:{layout:{visibility:\"none\"},paint:{}},geojson:l()};if(!r)return c;var u,f=[],h=e.z,p=e.radius,d=i.isArrayOrTypedArray(h)&&h.length,m=i.isArrayOrTypedArray(p);for(u=0;u<t.length;u++){var g=t[u],v=g.lonlat;if(v[0]!==s){var y={};if(d){var x=g.z;y.z=x!==s?x:0}m&&(y.r=n(p[u])&&p[u]>0?+p[u]:0),f.push({type:\"Feature\",geometry:{type:\"Point\",coordinates:v},properties:y})}}var b=o.extractOpts(e),_=b.reversescale?o.flipScale(b.colorscale):b.colorscale,w=_[0][1],T=[\"interpolate\",[\"linear\"],[\"heatmap-density\"],0,a.opacity(w)<1?w:a.addOpacity(w,0)];for(u=1;u<_.length;u++)T.push(_[u][0],_[u][1]);var k=[\"interpolate\",[\"linear\"],[\"get\",\"z\"],b.min,0,b.max,1];return i.extendFlat(c.heatmap.paint,{\"heatmap-weight\":d?k:1/(b.max-b.min),\"heatmap-color\":T,\"heatmap-radius\":m?{type:\"identity\",property:\"r\"}:e.radius,\"heatmap-opacity\":e.opacity}),c.geojson={type:\"FeatureCollection\",features:f},c.heatmap.layout.visibility=\"visible\",c}},{\"../../components/color\":662,\"../../components/colorscale\":674,\"../../constants/numerical\":775,\"../../lib\":799,\"../../lib/geojson_utils\":793,\"fast-isnumeric\":245}],1054:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/colorscale/defaults\"),a=t(\"./attributes\");e.exports=function(t,e,r,o){function s(r,i){return n.coerce(t,e,a,r,i)}var l=s(\"lon\")||[],c=s(\"lat\")||[],u=Math.min(l.length,c.length);u?(e._length=u,s(\"z\"),s(\"radius\"),s(\"below\"),s(\"text\"),s(\"hovertext\"),s(\"hovertemplate\"),i(t,e,o,s,{prefix:\"\",cLetter:\"z\"})):e.visible=!1}},{\"../../components/colorscale/defaults\":672,\"../../lib\":799,\"./attributes\":1051}],1055:[function(t,e,r){\"use strict\";e.exports=function(t,e){return t.lon=e.lon,t.lat=e.lat,t.z=e.z,t}},{}],1056:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"../scattermapbox/hover\").hoverPoints,a=t(\"../scattermapbox/hover\").getExtraText;e.exports=function(t,e,r){var o=i(t,e,r);if(o){var s=o[0],l=s.cd,c=l[0].trace,u=l[s.index];if(delete s.color,\"z\"in u){var f=s.subplot.mockAxis;s.z=u.z,s.zLabel=n.tickText(f,f.c2l(u.z),\"hover\").text}return s.extraText=a(c,u,l[0].t.labels),[s]}}},{\"../../plots/cartesian/axes\":849,\"../scattermapbox/hover\":1284}],1057:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../heatmap/colorbar\"),formatLabels:t(\"../scattermapbox/format_labels\"),calc:t(\"./calc\"),plot:t(\"./plot\"),hoverPoints:t(\"./hover\"),eventData:t(\"./event_data\"),getBelow:function(t,e){for(var r=e.getMapLayers(),n=0;n<r.length;n++){var i=r[n],a=i.id;if(\"symbol\"===i.type&&\"string\"==typeof a&&-1===a.indexOf(\"plotly-\"))return a}},moduleType:\"trace\",name:\"densitymapbox\",basePlotModule:t(\"../../plots/mapbox\"),categories:[\"mapbox\",\"gl\",\"showLegend\"],meta:{hr_name:\"density_mapbox\"}}},{\"../../plots/mapbox\":907,\"../heatmap/colorbar\":1084,\"../scattermapbox/format_labels\":1283,\"./attributes\":1051,\"./calc\":1052,\"./defaults\":1054,\"./event_data\":1055,\"./hover\":1056,\"./plot\":1058}],1058:[function(t,e,r){\"use strict\";var n=t(\"./convert\"),i=t(\"../../plots/mapbox/constants\").traceLayerPrefix;function a(t,e){this.type=\"densitymapbox\",this.subplot=t,this.uid=e,this.sourceId=\"source-\"+e,this.layerList=[[\"heatmap\",i+e+\"-heatmap\"]],this.below=null}var o=a.prototype;o.update=function(t){var e=this.subplot,r=this.layerList,i=n(t),a=e.belowLookup[\"trace-\"+this.uid];e.map.getSource(this.sourceId).setData(i.geojson),a!==this.below&&(this._removeLayers(),this._addLayers(i,a),this.below=a);for(var o=0;o<r.length;o++){var s=r[o],l=s[0],c=s[1],u=i[l];e.setOptions(c,\"setLayoutProperty\",u.layout),\"visible\"===u.layout.visibility&&e.setOptions(c,\"setPaintProperty\",u.paint)}},o._addLayers=function(t,e){for(var r=this.subplot,n=this.layerList,i=this.sourceId,a=0;a<n.length;a++){var o=n[a],s=o[0],l=t[s];r.addLayer({type:s,id:o[1],source:i,layout:l.layout,paint:l.paint},e)}},o._removeLayers=function(){for(var t=this.subplot.map,e=this.layerList,r=e.length-1;r>=0;r--)t.removeLayer(e[r][1])},o.dispose=function(){var t=this.subplot.map;this._removeLayers(),t.removeSource(this.sourceId)},e.exports=function(t,e){var r=e[0].trace,i=new a(t,r.uid),o=i.sourceId,s=n(e),l=i.below=t.belowLookup[\"trace-\"+r.uid];return t.map.addSource(o,{type:\"geojson\",data:s.geojson}),i._addLayers(s,l),i}},{\"../../plots/mapbox/constants\":905,\"./convert\":1053}],1059:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e){for(var r=0;r<t.length;r++)t[r].i=r;n.mergeArray(e.text,t,\"tx\"),n.mergeArray(e.hovertext,t,\"htx\");var i=e.marker;if(i){n.mergeArray(i.opacity,t,\"mo\"),n.mergeArray(i.color,t,\"mc\");var a=i.line;a&&(n.mergeArray(a.color,t,\"mlc\"),n.mergeArrayCastPositive(a.width,t,\"mlw\"))}}},{\"../../lib\":799}],1060:[function(t,e,r){\"use strict\";var n,i=t(\"../bar/attributes\"),a=t(\"../scatter/attributes\").line,o=t(\"../../plots/attributes\"),s=t(\"../../plots/cartesian/axis_format_attributes\").axisHoverFormat,l=t(\"../../plots/template_attributes\").hovertemplateAttrs,c=t(\"../../plots/template_attributes\").texttemplateAttrs,u=t(\"./constants\"),f=t(\"../../lib/extend\").extendFlat,h=t(\"../../components/color\");e.exports={x:i.x,x0:i.x0,dx:i.dx,y:i.y,y0:i.y0,dy:i.dy,xperiod:i.xperiod,yperiod:i.yperiod,xperiod0:i.xperiod0,yperiod0:i.yperiod0,xperiodalignment:i.xperiodalignment,yperiodalignment:i.yperiodalignment,xhoverformat:s(\"x\"),yhoverformat:s(\"y\"),hovertext:i.hovertext,hovertemplate:l({},{keys:u.eventDataKeys}),hoverinfo:f({},o.hoverinfo,{flags:[\"name\",\"x\",\"y\",\"text\",\"percent initial\",\"percent previous\",\"percent total\"]}),textinfo:{valType:\"flaglist\",flags:[\"label\",\"text\",\"percent initial\",\"percent previous\",\"percent total\",\"value\"],extras:[\"none\"],editType:\"plot\",arrayOk:!1},texttemplate:c({editType:\"plot\"},{keys:u.eventDataKeys.concat([\"label\",\"value\"])}),text:i.text,textposition:i.textposition,insidetextanchor:f({},i.insidetextanchor,{dflt:\"middle\"}),textangle:f({},i.textangle,{dflt:0}),textfont:i.textfont,insidetextfont:i.insidetextfont,outsidetextfont:i.outsidetextfont,constraintext:i.constraintext,cliponaxis:i.cliponaxis,orientation:f({},i.orientation,{}),offset:f({},i.offset,{arrayOk:!1}),width:f({},i.width,{arrayOk:!1}),marker:(n=f({},i.marker),delete n.pattern,n),connector:{fillcolor:{valType:\"color\",editType:\"style\"},line:{color:f({},a.color,{dflt:h.defaultLine}),width:f({},a.width,{dflt:0,editType:\"plot\"}),dash:a.dash,editType:\"style\"},visible:{valType:\"boolean\",dflt:!0,editType:\"plot\"},editType:\"plot\"},offsetgroup:i.offsetgroup,alignmentgroup:i.alignmentgroup}},{\"../../components/color\":662,\"../../lib/extend\":789,\"../../plots/attributes\":845,\"../../plots/cartesian/axis_format_attributes\":852,\"../../plots/template_attributes\":922,\"../bar/attributes\":937,\"../scatter/attributes\":1214,\"./constants\":1062}],1061:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"../../plots/cartesian/align_period\"),a=t(\"./arrays_to_calcdata\"),o=t(\"../scatter/calc_selection\"),s=t(\"../../constants/numerical\").BADNUM;function l(t){return t===s?0:t}e.exports=function(t,e){var r,c,u,f,h,p,d=n.getFromId(t,e.xaxis||\"x\"),m=n.getFromId(t,e.yaxis||\"y\");\"h\"===e.orientation?(r=d.makeCalcdata(e,\"x\"),u=m.makeCalcdata(e,\"y\"),c=i(e,m,\"y\",u),p=!!e.yperiodalignment):(r=m.makeCalcdata(e,\"y\"),u=d.makeCalcdata(e,\"x\"),c=i(e,d,\"x\",u),p=!!e.xperiodalignment);var g,v=Math.min(c.length,r.length),y=new Array(v);for(e._base=[],f=0;f<v;f++){r[f]<0&&(r[f]=s);var x=!1;r[f]!==s&&f+1<v&&r[f+1]!==s&&(x=!0),h=y[f]={p:c[f],s:r[f],cNext:x},e._base[f]=-.5*h.s,p&&(y[f].orig_p=u[f]),e.ids&&(h.id=String(e.ids[f])),0===f&&(y[0].vTotal=0),y[0].vTotal+=l(h.s),h.begR=l(h.s)/l(y[0].s)}for(f=0;f<v;f++)(h=y[f]).s!==s&&(h.sumR=h.s/y[0].vTotal,h.difR=void 0!==g?h.s/g:1,g=h.s);return a(y,e),o(y,e),y}},{\"../../constants/numerical\":775,\"../../plots/cartesian/align_period\":846,\"../../plots/cartesian/axes\":849,\"../scatter/calc_selection\":1216,\"./arrays_to_calcdata\":1059}],1062:[function(t,e,r){\"use strict\";e.exports={eventDataKeys:[\"percentInitial\",\"percentPrevious\",\"percentTotal\"]}},{}],1063:[function(t,e,r){\"use strict\";var n=t(\"../bar/cross_trace_calc\").setGroupPositions;e.exports=function(t,e){var r,i,a=t._fullLayout,o=t._fullData,s=t.calcdata,l=e.xaxis,c=e.yaxis,u=[],f=[],h=[];for(i=0;i<o.length;i++){var p=o[i],d=\"h\"===p.orientation;!0===p.visible&&p.xaxis===l._id&&p.yaxis===c._id&&\"funnel\"===p.type&&(r=s[i],d?h.push(r):f.push(r),u.push(r))}var m={mode:a.funnelmode,norm:a.funnelnorm,gap:a.funnelgap,groupgap:a.funnelgroupgap};for(n(t,l,c,f,m),n(t,c,l,h,m),i=0;i<u.length;i++){r=u[i];for(var g=0;g<r.length;g++)g+1<r.length&&(r[g].nextP0=r[g+1].p0,r[g].nextS0=r[g+1].s0,r[g].nextP1=r[g+1].p1,r[g].nextS1=r[g+1].s1)}}},{\"../bar/cross_trace_calc\":940}],1064:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../bar/defaults\").handleGroupingDefaults,a=t(\"../bar/defaults\").handleText,o=t(\"../scatter/xy_defaults\"),s=t(\"../scatter/period_defaults\"),l=t(\"./attributes\"),c=t(\"../../components/color\");e.exports={supplyDefaults:function(t,e,r,i){function u(r,i){return n.coerce(t,e,l,r,i)}if(o(t,e,i,u)){s(t,e,i,u),u(\"xhoverformat\"),u(\"yhoverformat\"),u(\"orientation\",e.y&&!e.x?\"v\":\"h\"),u(\"offset\"),u(\"width\");var f=u(\"text\");u(\"hovertext\"),u(\"hovertemplate\");var h=u(\"textposition\");a(t,e,i,u,h,{moduleHasSelected:!1,moduleHasUnselected:!1,moduleHasConstrain:!0,moduleHasCliponaxis:!0,moduleHasTextangle:!0,moduleHasInsideanchor:!0}),\"none\"===e.textposition||e.texttemplate||u(\"textinfo\",Array.isArray(f)?\"text+value\":\"value\");var p=u(\"marker.color\",r);if(u(\"marker.line.color\",c.defaultLine),u(\"marker.line.width\"),u(\"connector.visible\"))u(\"connector.fillcolor\",function(t){var e=n.isArrayOrTypedArray(t)?\"#000\":t;return c.addOpacity(e,.5*c.opacity(e))}(p)),u(\"connector.line.width\")&&(u(\"connector.line.color\"),u(\"connector.line.dash\"))}else e.visible=!1},crossTraceDefaults:function(t,e){var r,a;function o(t){return n.coerce(a._input,a,l,t)}if(\"group\"===e.funnelmode)for(var s=0;s<t.length;s++)r=(a=t[s])._input,i(r,a,e,o)}}},{\"../../components/color\":662,\"../../lib\":799,\"../bar/defaults\":941,\"../scatter/period_defaults\":1234,\"../scatter/xy_defaults\":1241,\"./attributes\":1060}],1065:[function(t,e,r){\"use strict\";e.exports=function(t,e){return t.x=\"xVal\"in e?e.xVal:e.x,t.y=\"yVal\"in e?e.yVal:e.y,\"percentInitial\"in e&&(t.percentInitial=e.percentInitial),\"percentPrevious\"in e&&(t.percentPrevious=e.percentPrevious),\"percentTotal\"in e&&(t.percentTotal=e.percentTotal),e.xa&&(t.xaxis=e.xa),e.ya&&(t.yaxis=e.ya),t}},{}],1066:[function(t,e,r){\"use strict\";var n=t(\"../../components/color\").opacity,i=t(\"../bar/hover\").hoverOnBars,a=t(\"../../lib\").formatPercent;e.exports=function(t,e,r,o,s){var l=i(t,e,r,o,s);if(l){var c=l.cd,u=c[0].trace,f=\"h\"===u.orientation,h=c[l.index];l[(f?\"x\":\"y\")+\"LabelVal\"]=h.s,l.percentInitial=h.begR,l.percentInitialLabel=a(h.begR,1),l.percentPrevious=h.difR,l.percentPreviousLabel=a(h.difR,1),l.percentTotal=h.sumR,l.percentTotalLabel=a(h.sumR,1);var p=h.hi||u.hoverinfo,d=[];if(p&&\"none\"!==p&&\"skip\"!==p){var m=\"all\"===p,g=p.split(\"+\"),v=function(t){return m||-1!==g.indexOf(t)};v(\"percent initial\")&&d.push(l.percentInitialLabel+\" of initial\"),v(\"percent previous\")&&d.push(l.percentPreviousLabel+\" of previous\"),v(\"percent total\")&&d.push(l.percentTotalLabel+\" of total\")}return l.extraText=d.join(\"<br>\"),l.color=function(t,e){var r=t.marker,i=e.mc||r.color,a=e.mlc||r.line.color,o=e.mlw||r.line.width;if(n(i))return i;if(n(a)&&o)return a}(u,h),[l]}}},{\"../../components/color\":662,\"../../lib\":799,\"../bar/hover\":944}],1067:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),layoutAttributes:t(\"./layout_attributes\"),supplyDefaults:t(\"./defaults\").supplyDefaults,crossTraceDefaults:t(\"./defaults\").crossTraceDefaults,supplyLayoutDefaults:t(\"./layout_defaults\"),calc:t(\"./calc\"),crossTraceCalc:t(\"./cross_trace_calc\"),plot:t(\"./plot\"),style:t(\"./style\").style,hoverPoints:t(\"./hover\"),eventData:t(\"./event_data\"),selectPoints:t(\"../bar/select\"),moduleType:\"trace\",name:\"funnel\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"bar-like\",\"cartesian\",\"svg\",\"oriented\",\"showLegend\",\"zoomScale\"],meta:{}}},{\"../../plots/cartesian\":863,\"../bar/select\":949,\"./attributes\":1060,\"./calc\":1061,\"./cross_trace_calc\":1063,\"./defaults\":1064,\"./event_data\":1065,\"./hover\":1066,\"./layout_attributes\":1068,\"./layout_defaults\":1069,\"./plot\":1070,\"./style\":1071}],1068:[function(t,e,r){\"use strict\";e.exports={funnelmode:{valType:\"enumerated\",values:[\"stack\",\"group\",\"overlay\"],dflt:\"stack\",editType:\"calc\"},funnelgap:{valType:\"number\",min:0,max:1,editType:\"calc\"},funnelgroupgap:{valType:\"number\",min:0,max:1,dflt:0,editType:\"calc\"}}},{}],1069:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\");e.exports=function(t,e,r){var a=!1;function o(r,a){return n.coerce(t,e,i,r,a)}for(var s=0;s<r.length;s++){var l=r[s];if(l.visible&&\"funnel\"===l.type){a=!0;break}}a&&(o(\"funnelmode\"),o(\"funnelgap\",.2),o(\"funnelgroupgap\"))}},{\"../../lib\":799,\"./layout_attributes\":1068}],1070:[function(t,e,r){\"use strict\";var n=t(\"@plotly/d3\"),i=t(\"../../lib\"),a=t(\"../../components/drawing\"),o=t(\"../../constants/numerical\").BADNUM,s=t(\"../bar/plot\"),l=t(\"../bar/uniform_text\").clearMinTextSize;function c(t,e,r,n){var i=[],a=[],o=n?e:r,s=n?r:e;return i[0]=o.c2p(t.s0,!0),a[0]=s.c2p(t.p0,!0),i[1]=o.c2p(t.s1,!0),a[1]=s.c2p(t.p1,!0),i[2]=o.c2p(t.nextS0,!0),a[2]=s.c2p(t.nextP0,!0),i[3]=o.c2p(t.nextS1,!0),a[3]=s.c2p(t.nextP1,!0),n?[i,a]:[a,i]}e.exports=function(t,e,r,u){var f=t._fullLayout;l(\"funnel\",f),function(t,e,r,s){var l=e.xaxis,u=e.yaxis;i.makeTraceGroups(s,r,\"trace bars\").each((function(r){var s=n.select(this),f=r[0].trace,h=i.ensureSingle(s,\"g\",\"regions\");if(f.connector&&f.connector.visible){var p=\"h\"===f.orientation,d=h.selectAll(\"g.region\").data(i.identity);d.enter().append(\"g\").classed(\"region\",!0),d.exit().remove();var m=d.size();d.each((function(r,s){if(s===m-1||r.cNext){var f=c(r,l,u,p),h=f[0],d=f[1],g=\"\";h[0]!==o&&d[0]!==o&&h[1]!==o&&d[1]!==o&&h[2]!==o&&d[2]!==o&&h[3]!==o&&d[3]!==o&&(g+=p?\"M\"+h[0]+\",\"+d[1]+\"L\"+h[2]+\",\"+d[2]+\"H\"+h[3]+\"L\"+h[1]+\",\"+d[1]+\"Z\":\"M\"+h[1]+\",\"+d[1]+\"L\"+h[2]+\",\"+d[3]+\"V\"+d[2]+\"L\"+h[1]+\",\"+d[0]+\"Z\"),\"\"===g&&(g=\"M0,0Z\"),i.ensureSingle(n.select(this),\"path\").attr(\"d\",g).call(a.setClipUrl,e.layerClipId,t)}}))}else h.remove()}))}(t,e,r,u),function(t,e,r,o){var s=e.xaxis,l=e.yaxis;i.makeTraceGroups(o,r,\"trace bars\").each((function(r){var o=n.select(this),u=r[0].trace,f=i.ensureSingle(o,\"g\",\"lines\");if(u.connector&&u.connector.visible&&u.connector.line.width){var h=\"h\"===u.orientation,p=f.selectAll(\"g.line\").data(i.identity);p.enter().append(\"g\").classed(\"line\",!0),p.exit().remove();var d=p.size();p.each((function(r,o){if(o===d-1||r.cNext){var u=c(r,s,l,h),f=u[0],p=u[1],m=\"\";void 0!==f[3]&&void 0!==p[3]&&(h?(m+=\"M\"+f[0]+\",\"+p[1]+\"L\"+f[2]+\",\"+p[2],m+=\"M\"+f[1]+\",\"+p[1]+\"L\"+f[3]+\",\"+p[2]):(m+=\"M\"+f[1]+\",\"+p[1]+\"L\"+f[2]+\",\"+p[3],m+=\"M\"+f[1]+\",\"+p[0]+\"L\"+f[2]+\",\"+p[2])),\"\"===m&&(m=\"M0,0Z\"),i.ensureSingle(n.select(this),\"path\").attr(\"d\",m).call(a.setClipUrl,e.layerClipId,t)}}))}else f.remove()}))}(t,e,r,u),s.plot(t,e,r,u,{mode:f.funnelmode,norm:f.funnelmode,gap:f.funnelgap,groupgap:f.funnelgroupgap})}},{\"../../components/drawing\":684,\"../../constants/numerical\":775,\"../../lib\":799,\"../bar/plot\":948,\"../bar/uniform_text\":953,\"@plotly/d3\":58}],1071:[function(t,e,r){\"use strict\";var n=t(\"@plotly/d3\"),i=t(\"../../components/drawing\"),a=t(\"../../components/color\"),o=t(\"../../constants/interactions\").DESELECTDIM,s=t(\"../bar/style\"),l=t(\"../bar/uniform_text\").resizeText,c=s.styleTextPoints;e.exports={style:function(t,e,r){var s=r||n.select(t).selectAll(\"g.funnellayer\").selectAll(\"g.trace\");l(t,s,\"funnel\"),s.style(\"opacity\",(function(t){return t[0].trace.opacity})),s.each((function(e){var r=n.select(this),s=e[0].trace;r.selectAll(\".point > path\").each((function(t){if(!t.isBlank){var e=s.marker;n.select(this).call(a.fill,t.mc||e.color).call(a.stroke,t.mlc||e.line.color).call(i.dashLine,e.line.dash,t.mlw||e.line.width).style(\"opacity\",s.selectedpoints&&!t.selected?o:1)}})),c(r,s,t),r.selectAll(\".regions\").each((function(){n.select(this).selectAll(\"path\").style(\"stroke-width\",0).call(a.fill,s.connector.fillcolor)})),r.selectAll(\".lines\").each((function(){var t=s.connector.line;i.lineGroupStyle(n.select(this).selectAll(\"path\"),t.width,t.color,t.dash)}))}))}}},{\"../../components/color\":662,\"../../components/drawing\":684,\"../../constants/interactions\":774,\"../bar/style\":951,\"../bar/uniform_text\":953,\"@plotly/d3\":58}],1072:[function(t,e,r){\"use strict\";var n=t(\"../pie/attributes\"),i=t(\"../../plots/attributes\"),a=t(\"../../plots/domain\").attributes,o=t(\"../../plots/template_attributes\").hovertemplateAttrs,s=t(\"../../plots/template_attributes\").texttemplateAttrs,l=t(\"../../lib/extend\").extendFlat;e.exports={labels:n.labels,label0:n.label0,dlabel:n.dlabel,values:n.values,marker:{colors:n.marker.colors,line:{color:l({},n.marker.line.color,{dflt:null}),width:l({},n.marker.line.width,{dflt:1}),editType:\"calc\"},editType:\"calc\"},text:n.text,hovertext:n.hovertext,scalegroup:l({},n.scalegroup,{}),textinfo:l({},n.textinfo,{flags:[\"label\",\"text\",\"value\",\"percent\"]}),texttemplate:s({editType:\"plot\"},{keys:[\"label\",\"color\",\"value\",\"text\",\"percent\"]}),hoverinfo:l({},i.hoverinfo,{flags:[\"label\",\"text\",\"value\",\"percent\",\"name\"]}),hovertemplate:o({},{keys:[\"label\",\"color\",\"value\",\"text\",\"percent\"]}),textposition:l({},n.textposition,{values:[\"inside\",\"none\"],dflt:\"inside\"}),textfont:n.textfont,insidetextfont:n.insidetextfont,title:{text:n.title.text,font:n.title.font,position:l({},n.title.position,{values:[\"top left\",\"top center\",\"top right\"],dflt:\"top center\"}),editType:\"plot\"},domain:a({name:\"funnelarea\",trace:!0,editType:\"calc\"}),aspectratio:{valType:\"number\",min:0,dflt:1,editType:\"plot\"},baseratio:{valType:\"number\",min:0,max:1,dflt:.333,editType:\"plot\"}}},{\"../../lib/extend\":789,\"../../plots/attributes\":845,\"../../plots/domain\":877,\"../../plots/template_attributes\":922,\"../pie/attributes\":1188}],1073:[function(t,e,r){\"use strict\";var n=t(\"../../plots/plots\");r.name=\"funnelarea\",r.plot=function(t,e,i,a){n.plotBasePlot(r.name,t,e,i,a)},r.clean=function(t,e,i,a){n.cleanBasePlot(r.name,t,e,i,a)}},{\"../../plots/plots\":913}],1074:[function(t,e,r){\"use strict\";var n=t(\"../pie/calc\");e.exports={calc:function(t,e){return n.calc(t,e)},crossTraceCalc:function(t){n.crossTraceCalc(t,{type:\"funnelarea\"})}}},{\"../pie/calc\":1190}],1075:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\"),a=t(\"../../plots/domain\").defaults,o=t(\"../bar/defaults\").handleText,s=t(\"../pie/defaults\").handleLabelsAndValues;e.exports=function(t,e,r,l){function c(r,a){return n.coerce(t,e,i,r,a)}var u=c(\"labels\"),f=c(\"values\"),h=s(u,f),p=h.len;if(e._hasLabels=h.hasLabels,e._hasValues=h.hasValues,!e._hasLabels&&e._hasValues&&(c(\"label0\"),c(\"dlabel\")),p){e._length=p,c(\"marker.line.width\")&&c(\"marker.line.color\",l.paper_bgcolor),c(\"marker.colors\"),c(\"scalegroup\");var d,m=c(\"text\"),g=c(\"texttemplate\");if(g||(d=c(\"textinfo\",Array.isArray(m)?\"text+percent\":\"percent\")),c(\"hovertext\"),c(\"hovertemplate\"),g||d&&\"none\"!==d){var v=c(\"textposition\");o(t,e,l,c,v,{moduleHasSelected:!1,moduleHasUnselected:!1,moduleHasConstrain:!1,moduleHasCliponaxis:!1,moduleHasTextangle:!1,moduleHasInsideanchor:!1})}a(e,l,c),c(\"title.text\")&&(c(\"title.position\"),n.coerceFont(c,\"title.font\",l.font)),c(\"aspectratio\"),c(\"baseratio\")}else e.visible=!1}},{\"../../lib\":799,\"../../plots/domain\":877,\"../bar/defaults\":941,\"../pie/defaults\":1191,\"./attributes\":1072}],1076:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"funnelarea\",basePlotModule:t(\"./base_plot\"),categories:[\"pie-like\",\"funnelarea\",\"showLegend\"],attributes:t(\"./attributes\"),layoutAttributes:t(\"./layout_attributes\"),supplyDefaults:t(\"./defaults\"),supplyLayoutDefaults:t(\"./layout_defaults\"),calc:t(\"./calc\").calc,crossTraceCalc:t(\"./calc\").crossTraceCalc,plot:t(\"./plot\"),style:t(\"./style\"),styleOne:t(\"../pie/style_one\"),meta:{}}},{\"../pie/style_one\":1199,\"./attributes\":1072,\"./base_plot\":1073,\"./calc\":1074,\"./defaults\":1075,\"./layout_attributes\":1077,\"./layout_defaults\":1078,\"./plot\":1079,\"./style\":1080}],1077:[function(t,e,r){\"use strict\";var n=t(\"../pie/layout_attributes\").hiddenlabels;e.exports={hiddenlabels:n,funnelareacolorway:{valType:\"colorlist\",editType:\"calc\"},extendfunnelareacolors:{valType:\"boolean\",dflt:!0,editType:\"calc\"}}},{\"../pie/layout_attributes\":1195}],1078:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\");e.exports=function(t,e){function r(r,a){return n.coerce(t,e,i,r,a)}r(\"hiddenlabels\"),r(\"funnelareacolorway\",e.colorway),r(\"extendfunnelareacolors\")}},{\"../../lib\":799,\"./layout_attributes\":1077}],1079:[function(t,e,r){\"use strict\";var n=t(\"@plotly/d3\"),i=t(\"../../components/drawing\"),a=t(\"../../lib\"),o=a.strScale,s=a.strTranslate,l=t(\"../../lib/svg_text_utils\"),c=t(\"../bar/plot\").toMoveInsideBar,u=t(\"../bar/uniform_text\"),f=u.recordMinTextSize,h=u.clearMinTextSize,p=t(\"../pie/helpers\"),d=t(\"../pie/plot\"),m=d.attachFxHandlers,g=d.determineInsideTextFont,v=d.layoutAreas,y=d.prerenderTitles,x=d.positionTitleOutside,b=d.formatSliceLabel;function _(t,e){return\"l\"+(e[0]-t[0])+\",\"+(e[1]-t[1])}e.exports=function(t,e){var r=t._fullLayout;h(\"funnelarea\",r),y(e,t),v(e,r._size),a.makeTraceGroups(r._funnelarealayer,e,\"trace\").each((function(e){var u=n.select(this),h=e[0],d=h.trace;!function(t){if(!t.length)return;var e=t[0],r=e.trace,n=r.aspectratio,i=r.baseratio;i>.999&&(i=.999);var a,o=Math.pow(i,2),s=e.vTotal,l=s,c=s*o/(1-o)/s;function u(){var t,e={x:t=Math.sqrt(c),y:-t};return[e.x,e.y]}var f,h,p=[];for(p.push(u()),f=t.length-1;f>-1;f--)if(!(h=t[f]).hidden){var d=h.v/l;c+=d,p.push(u())}var m=1/0,g=-1/0;for(f=0;f<p.length;f++)a=p[f],m=Math.min(m,a[1]),g=Math.max(g,a[1]);for(f=0;f<p.length;f++)p[f][1]-=(g+m)/2;var v=p[p.length-1][0],y=e.r,x=(g-m)/2,b=y/v,_=y/x*n;for(e.r=_*x,f=0;f<p.length;f++)p[f][0]*=b,p[f][1]*=_;var w=[-(a=p[0])[0],a[1]],T=[a[0],a[1]],k=0;for(f=t.length-1;f>-1;f--)if(!(h=t[f]).hidden){var M=p[k+=1][0],A=p[k][1];h.TL=[-M,A],h.TR=[M,A],h.BL=w,h.BR=T,h.pxmid=(S=h.TR,E=h.BR,[.5*(S[0]+E[0]),.5*(S[1]+E[1])]),w=h.TL,T=h.TR}var S,E}(e),u.each((function(){var u=n.select(this).selectAll(\"g.slice\").data(e);u.enter().append(\"g\").classed(\"slice\",!0),u.exit().remove(),u.each((function(o,s){if(o.hidden)n.select(this).selectAll(\"path,g\").remove();else{o.pointNumber=o.i,o.curveNumber=d.index;var u=h.cx,v=h.cy,y=n.select(this),x=y.selectAll(\"path.surface\").data([o]);x.enter().append(\"path\").classed(\"surface\",!0).style({\"pointer-events\":\"all\"}),y.call(m,t,e);var w=\"M\"+(u+o.TR[0])+\",\"+(v+o.TR[1])+_(o.TR,o.BR)+_(o.BR,o.BL)+_(o.BL,o.TL)+\"Z\";x.attr(\"d\",w),b(t,o,h);var T=p.castOption(d.textposition,o.pts),k=y.selectAll(\"g.slicetext\").data(o.text&&\"none\"!==T?[0]:[]);k.enter().append(\"g\").classed(\"slicetext\",!0),k.exit().remove(),k.each((function(){var h=a.ensureSingle(n.select(this),\"text\",\"\",(function(t){t.attr(\"data-notex\",1)})),p=a.ensureUniformFontSize(t,g(d,o,r.font));h.text(o.text).attr({class:\"slicetext\",transform:\"\",\"text-anchor\":\"middle\"}).call(i.font,p).call(l.convertToTspans,t);var m,y,x,b=i.bBox(h.node()),_=Math.min(o.BL[1],o.BR[1])+v,w=Math.max(o.TL[1],o.TR[1])+v;y=Math.max(o.TL[0],o.BL[0])+u,x=Math.min(o.TR[0],o.BR[0])+u,(m=c(y,x,_,w,b,{isHorizontal:!0,constrained:!0,angle:0,anchor:\"middle\"})).fontSize=p.size,f(d.type,m,r),e[s].transform=m,h.attr(\"transform\",a.getTextTransform(m))}))}}));var v=n.select(this).selectAll(\"g.titletext\").data(d.title.text?[0]:[]);v.enter().append(\"g\").classed(\"titletext\",!0),v.exit().remove(),v.each((function(){var e=a.ensureSingle(n.select(this),\"text\",\"\",(function(t){t.attr(\"data-notex\",1)})),c=d.title.text;d._meta&&(c=a.templateString(c,d._meta)),e.text(c).attr({class:\"titletext\",transform:\"\",\"text-anchor\":\"middle\"}).call(i.font,d.title.font).call(l.convertToTspans,t);var u=x(h,r._size);e.attr(\"transform\",s(u.x,u.y)+o(Math.min(1,u.scale))+s(u.tx,u.ty))}))}))}))}},{\"../../components/drawing\":684,\"../../lib\":799,\"../../lib/svg_text_utils\":824,\"../bar/plot\":948,\"../bar/uniform_text\":953,\"../pie/helpers\":1193,\"../pie/plot\":1197,\"@plotly/d3\":58}],1080:[function(t,e,r){\"use strict\";var n=t(\"@plotly/d3\"),i=t(\"../pie/style_one\"),a=t(\"../bar/uniform_text\").resizeText;e.exports=function(t){var e=t._fullLayout._funnelarealayer.selectAll(\".trace\");a(t,e,\"funnelarea\"),e.each((function(t){var e=t[0].trace,r=n.select(this);r.style({opacity:e.opacity}),r.selectAll(\"path.surface\").each((function(t){n.select(this).call(i,t,e)}))}))}},{\"../bar/uniform_text\":953,\"../pie/style_one\":1199,\"@plotly/d3\":58}],1081:[function(t,e,r){\"use strict\";var n=t(\"../scatter/attributes\"),i=t(\"../../plots/attributes\"),a=t(\"../../plots/cartesian/axis_format_attributes\").axisHoverFormat,o=t(\"../../plots/template_attributes\").hovertemplateAttrs,s=t(\"../../components/colorscale/attributes\"),l=t(\"../../lib/extend\").extendFlat;e.exports=l({z:{valType:\"data_array\",editType:\"calc\"},x:l({},n.x,{impliedEdits:{xtype:\"array\"}}),x0:l({},n.x0,{impliedEdits:{xtype:\"scaled\"}}),dx:l({},n.dx,{impliedEdits:{xtype:\"scaled\"}}),y:l({},n.y,{impliedEdits:{ytype:\"array\"}}),y0:l({},n.y0,{impliedEdits:{ytype:\"scaled\"}}),dy:l({},n.dy,{impliedEdits:{ytype:\"scaled\"}}),xperiod:l({},n.xperiod,{impliedEdits:{xtype:\"scaled\"}}),yperiod:l({},n.yperiod,{impliedEdits:{ytype:\"scaled\"}}),xperiod0:l({},n.xperiod0,{impliedEdits:{xtype:\"scaled\"}}),yperiod0:l({},n.yperiod0,{impliedEdits:{ytype:\"scaled\"}}),xperiodalignment:l({},n.xperiodalignment,{impliedEdits:{xtype:\"scaled\"}}),yperiodalignment:l({},n.yperiodalignment,{impliedEdits:{ytype:\"scaled\"}}),text:{valType:\"data_array\",editType:\"calc\"},hovertext:{valType:\"data_array\",editType:\"calc\"},transpose:{valType:\"boolean\",dflt:!1,editType:\"calc\"},xtype:{valType:\"enumerated\",values:[\"array\",\"scaled\"],editType:\"calc+clearAxisTypes\"},ytype:{valType:\"enumerated\",values:[\"array\",\"scaled\"],editType:\"calc+clearAxisTypes\"},zsmooth:{valType:\"enumerated\",values:[\"fast\",\"best\",!1],dflt:!1,editType:\"calc\"},hoverongaps:{valType:\"boolean\",dflt:!0,editType:\"none\"},connectgaps:{valType:\"boolean\",editType:\"calc\"},xgap:{valType:\"number\",dflt:0,min:0,editType:\"plot\"},ygap:{valType:\"number\",dflt:0,min:0,editType:\"plot\"},xhoverformat:a(\"x\"),yhoverformat:a(\"y\"),zhoverformat:a(\"z\",1),hovertemplate:o(),showlegend:l({},i.showlegend,{dflt:!1})},{transforms:void 0},s(\"\",{cLetter:\"z\",autoColorDflt:!1}))},{\"../../components/colorscale/attributes\":669,\"../../lib/extend\":789,\"../../plots/attributes\":845,\"../../plots/cartesian/axis_format_attributes\":852,\"../../plots/template_attributes\":922,\"../scatter/attributes\":1214}],1082:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"../../plots/cartesian/axes\"),o=t(\"../../plots/cartesian/align_period\"),s=t(\"../histogram2d/calc\"),l=t(\"../../components/colorscale/calc\"),c=t(\"./convert_column_xyz\"),u=t(\"./clean_2d_array\"),f=t(\"./interp2d\"),h=t(\"./find_empties\"),p=t(\"./make_bound_array\"),d=t(\"../../constants/numerical\").BADNUM;function m(t){for(var e=[],r=t.length,n=0;n<r;n++){var i=t[n];i!==d&&e.push(i)}return e}e.exports=function(t,e){var r,g,v,y,x,b,_,w,T,k,M,A=a.getFromId(t,e.xaxis||\"x\"),S=a.getFromId(t,e.yaxis||\"y\"),E=n.traceIs(e,\"contour\"),L=n.traceIs(e,\"histogram\"),C=n.traceIs(e,\"gl2d\"),P=E?\"best\":e.zsmooth;if(A._minDtick=0,S._minDtick=0,L)y=(M=s(t,e)).orig_x,r=M.x,g=M.x0,v=M.dx,w=M.orig_y,x=M.y,b=M.y0,_=M.dy,T=M.z;else{var I=e.z;i.isArray1D(I)?(c(e,A,S,\"x\",\"y\",[\"z\"]),r=e._x,x=e._y,I=e._z):(y=e.x?A.makeCalcdata(e,\"x\"):[],w=e.y?S.makeCalcdata(e,\"y\"):[],r=o(e,A,\"x\",y),x=o(e,S,\"y\",w),e._x=r,e._y=x),g=e.x0,v=e.dx,b=e.y0,_=e.dy,T=u(I,e,A,S)}function O(t){P=e._input.zsmooth=e.zsmooth=!1,i.warn('cannot use zsmooth: \"fast\": '+t)}if((A.rangebreaks||S.rangebreaks)&&(T=function(t,e,r){for(var n=[],i=-1,a=0;a<r.length;a++)if(e[a]!==d){i++,n[i]=[];for(var o=0;o<r[a].length;o++)t[o]!==d&&n[i].push(r[a][o])}return n}(r,x,T),L||(r=m(r),x=m(x),e._x=r,e._y=x)),L||!E&&!e.connectgaps||(e._emptypoints=h(T),f(T,e._emptypoints)),\"fast\"===P)if(\"log\"===A.type||\"log\"===S.type)O(\"log axis found\");else if(!L){if(r.length){var z=(r[r.length-1]-r[0])/(r.length-1),D=Math.abs(z/100);for(k=0;k<r.length-1;k++)if(Math.abs(r[k+1]-r[k]-z)>D){O(\"x scale is not linear\");break}}if(x.length&&\"fast\"===P){var R=(x[x.length-1]-x[0])/(x.length-1),F=Math.abs(R/100);for(k=0;k<x.length-1;k++)if(Math.abs(x[k+1]-x[k]-R)>F){O(\"y scale is not linear\");break}}}var B=i.maxRowLength(T),N=\"scaled\"===e.xtype?\"\":r,j=p(e,N,g,v,B,A),U=\"scaled\"===e.ytype?\"\":x,V=p(e,U,b,_,T.length,S);C||(e._extremes[A._id]=a.findExtremes(A,j),e._extremes[S._id]=a.findExtremes(S,V));var q={x:j,y:V,z:T,text:e._text||e.text,hovertext:e._hovertext||e.hovertext};if(e.xperiodalignment&&y&&(q.orig_x=y),e.yperiodalignment&&w&&(q.orig_y=w),N&&N.length===j.length-1&&(q.xCenter=N),U&&U.length===V.length-1&&(q.yCenter=U),L&&(q.xRanges=M.xRanges,q.yRanges=M.yRanges,q.pts=M.pts),E||l(t,e,{vals:T,cLetter:\"z\"}),E&&e.contours&&\"heatmap\"===e.contours.coloring){var H={type:\"contour\"===e.type?\"heatmap\":\"histogram2d\",xcalendar:e.xcalendar,ycalendar:e.ycalendar};q.xfill=p(H,N,g,v,B,A),q.yfill=p(H,U,b,_,T.length,S)}return[q]}},{\"../../components/colorscale/calc\":670,\"../../constants/numerical\":775,\"../../lib\":799,\"../../plots/cartesian/align_period\":846,\"../../plots/cartesian/axes\":849,\"../../registry\":927,\"../histogram2d/calc\":1114,\"./clean_2d_array\":1083,\"./convert_column_xyz\":1085,\"./find_empties\":1087,\"./interp2d\":1090,\"./make_bound_array\":1091}],1083:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../../constants/numerical\").BADNUM;e.exports=function(t,e,r,o){var s,l,c,u,f,h;function p(t){if(n(t))return+t}if(e&&e.transpose){for(s=0,f=0;f<t.length;f++)s=Math.max(s,t[f].length);if(0===s)return!1;c=function(t){return t.length},u=function(t,e,r){return(t[r]||[])[e]}}else s=t.length,c=function(t,e){return t[e].length},u=function(t,e,r){return(t[e]||[])[r]};var d=function(t,e,r){return e===a||r===a?a:u(t,e,r)};function m(t){if(e&&\"carpet\"!==e.type&&\"contourcarpet\"!==e.type&&t&&\"category\"===t.type&&e[\"_\"+t._id.charAt(0)].length){var r=t._id.charAt(0),n={},o=e[\"_\"+r+\"CategoryMap\"]||e[r];for(f=0;f<o.length;f++)n[o[f]]=f;return function(e){var r=n[t._categories[e]];return r+1?r:a}}return i.identity}var g=m(r),v=m(o);o&&\"category\"===o.type&&(s=o._categories.length);var y=new Array(s);for(f=0;f<s;f++)for(l=r&&\"category\"===r.type?r._categories.length:c(t,f),y[f]=new Array(l),h=0;h<l;h++)y[f][h]=p(d(t,v(f),g(h)));return y}},{\"../../constants/numerical\":775,\"../../lib\":799,\"fast-isnumeric\":245}],1084:[function(t,e,r){\"use strict\";e.exports={min:\"zmin\",max:\"zmax\"}},{}],1085:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../constants/numerical\").BADNUM,a=t(\"../../plots/cartesian/align_period\");e.exports=function(t,e,r,o,s,l){var c=t._length,u=e.makeCalcdata(t,o),f=r.makeCalcdata(t,s);u=a(t,e,o,u),f=a(t,r,s,f);var h,p,d,m,g=t.text,v=void 0!==g&&n.isArray1D(g),y=t.hovertext,x=void 0!==y&&n.isArray1D(y),b=n.distinctVals(u),_=b.vals,w=n.distinctVals(f),T=w.vals,k=[],M=T.length,A=_.length;for(h=0;h<l.length;h++)k[h]=n.init2dArray(M,A);v&&(d=n.init2dArray(M,A)),x&&(m=n.init2dArray(M,A));var S=n.init2dArray(M,A);for(h=0;h<c;h++)if(u[h]!==i&&f[h]!==i){var E=n.findBin(u[h]+b.minDiff/2,_),L=n.findBin(f[h]+w.minDiff/2,T);for(p=0;p<l.length;p++){var C=t[l[p]];k[p][L][E]=C[h],S[L][E]=h}v&&(d[L][E]=g[h]),x&&(m[L][E]=y[h])}for(t[\"_\"+o]=_,t[\"_\"+s]=T,p=0;p<l.length;p++)t[\"_\"+l[p]]=k[p];v&&(t._text=d),x&&(t._hovertext=m),e&&\"category\"===e.type&&(t[\"_\"+o+\"CategoryMap\"]=_.map((function(t){return e._categories[t]}))),r&&\"category\"===r.type&&(t[\"_\"+s+\"CategoryMap\"]=T.map((function(t){return r._categories[t]}))),t._after2before=S}},{\"../../constants/numerical\":775,\"../../lib\":799,\"../../plots/cartesian/align_period\":846}],1086:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./xyz_defaults\"),a=t(\"../scatter/period_defaults\"),o=t(\"./style_defaults\"),s=t(\"../../components/colorscale/defaults\"),l=t(\"./attributes\");e.exports=function(t,e,r,c){function u(r,i){return n.coerce(t,e,l,r,i)}i(t,e,u,c)?(a(t,e,c,u),u(\"xhoverformat\"),u(\"yhoverformat\"),u(\"text\"),u(\"hovertext\"),u(\"hovertemplate\"),o(t,e,u,c),u(\"hoverongaps\"),u(\"connectgaps\",n.isArray1D(e.z)&&!1!==e.zsmooth),s(t,e,c,u,{prefix:\"\",cLetter:\"z\"})):e.visible=!1}},{\"../../components/colorscale/defaults\":672,\"../../lib\":799,\"../scatter/period_defaults\":1234,\"./attributes\":1081,\"./style_defaults\":1094,\"./xyz_defaults\":1095}],1087:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").maxRowLength;e.exports=function(t){var e,r,i,a,o,s,l,c,u=[],f={},h=[],p=t[0],d=[],m=[0,0,0],g=n(t);for(r=0;r<t.length;r++)for(e=d,d=p,p=t[r+1]||[],i=0;i<g;i++)void 0===d[i]&&((s=(void 0!==d[i-1]?1:0)+(void 0!==d[i+1]?1:0)+(void 0!==e[i]?1:0)+(void 0!==p[i]?1:0))?(0===r&&s++,0===i&&s++,r===t.length-1&&s++,i===d.length-1&&s++,s<4&&(f[[r,i]]=[r,i,s]),u.push([r,i,s])):h.push([r,i]));for(;h.length;){for(l={},c=!1,o=h.length-1;o>=0;o--)(s=((f[[(r=(a=h[o])[0])-1,i=a[1]]]||m)[2]+(f[[r+1,i]]||m)[2]+(f[[r,i-1]]||m)[2]+(f[[r,i+1]]||m)[2])/20)&&(l[a]=[r,i,s],h.splice(o,1),c=!0);if(!c)throw\"findEmpties iterated with no new neighbors\";for(a in l)f[a]=l[a],u.push(l[a])}return u.sort((function(t,e){return e[2]-t[2]}))}},{\"../../lib\":799}],1088:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx\"),i=t(\"../../lib\"),a=t(\"../../plots/cartesian/axes\"),o=t(\"../../components/colorscale\").extractOpts;e.exports=function(t,e,r,s,l){l||(l={});var c,u,f,h,p=l.isContour,d=t.cd[0],m=d.trace,g=t.xa,v=t.ya,y=d.x,x=d.y,b=d.z,_=d.xCenter,w=d.yCenter,T=d.zmask,k=m.zhoverformat,M=y,A=x;if(!1!==t.index){try{f=Math.round(t.index[1]),h=Math.round(t.index[0])}catch(e){return void i.error(\"Error hovering on heatmap, pointNumber must be [row,col], found:\",t.index)}if(f<0||f>=b[0].length||h<0||h>b.length)return}else{if(n.inbox(e-y[0],e-y[y.length-1],0)>0||n.inbox(r-x[0],r-x[x.length-1],0)>0)return;if(p){var S;for(M=[2*y[0]-y[1]],S=1;S<y.length;S++)M.push((y[S]+y[S-1])/2);for(M.push([2*y[y.length-1]-y[y.length-2]]),A=[2*x[0]-x[1]],S=1;S<x.length;S++)A.push((x[S]+x[S-1])/2);A.push([2*x[x.length-1]-x[x.length-2]])}f=Math.max(0,Math.min(M.length-2,i.findBin(e,M))),h=Math.max(0,Math.min(A.length-2,i.findBin(r,A)))}var E,L,C=g.c2p(y[f]),P=g.c2p(y[f+1]),I=v.c2p(x[h]),O=v.c2p(x[h+1]);p?(E=d.orig_x||y,L=d.orig_y||x,P=C,c=E[f],O=I,u=L[h]):(E=d.orig_x||_||y,L=d.orig_y||w||x,c=_?E[f]:(E[f]+E[f+1])/2,u=w?L[h]:(L[h]+L[h+1])/2,g&&\"category\"===g.type&&(c=y[f]),v&&\"category\"===v.type&&(u=x[h]),m.zsmooth&&(C=P=g.c2p(c),I=O=v.c2p(u)));var z=b[h][f];if(T&&!T[h][f]&&(z=void 0),void 0!==z||m.hoverongaps){var D;Array.isArray(d.hovertext)&&Array.isArray(d.hovertext[h])?D=d.hovertext[h][f]:Array.isArray(d.text)&&Array.isArray(d.text[h])&&(D=d.text[h][f]);var R=o(m),F={type:\"linear\",range:[R.min,R.max],hoverformat:k,_separators:g._separators,_numFormat:g._numFormat},B=a.tickText(F,z,\"hover\").text;return[i.extendFlat(t,{index:m._after2before?m._after2before[h][f]:[h,f],distance:t.maxHoverDistance,spikeDistance:t.maxSpikeDistance,x0:C,x1:P,y0:I,y1:O,xLabelVal:c,yLabelVal:u,zLabelVal:z,zLabel:B,text:D})]}}},{\"../../components/colorscale\":674,\"../../components/fx\":702,\"../../lib\":799,\"../../plots/cartesian/axes\":849}],1089:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\"),plot:t(\"./plot\"),colorbar:t(\"./colorbar\"),style:t(\"./style\"),hoverPoints:t(\"./hover\"),moduleType:\"trace\",name:\"heatmap\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"2dMap\",\"showLegend\"],meta:{}}},{\"../../plots/cartesian\":863,\"./attributes\":1081,\"./calc\":1082,\"./colorbar\":1084,\"./defaults\":1086,\"./hover\":1088,\"./plot\":1092,\"./style\":1093}],1090:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=[[-1,0],[1,0],[0,-1],[0,1]];function a(t){return.5-.25*Math.min(1,.5*t)}function o(t,e,r){var n,a,o,s,l,c,u,f,h,p,d,m,g,v=0;for(s=0;s<e.length;s++){for(a=(n=e[s])[0],o=n[1],d=t[a][o],p=0,h=0,l=0;l<4;l++)(u=t[a+(c=i[l])[0]])&&void 0!==(f=u[o+c[1]])&&(0===p?m=g=f:(m=Math.min(m,f),g=Math.max(g,f)),h++,p+=f);if(0===h)throw\"iterateInterp2d order is wrong: no defined neighbors\";t[a][o]=p/h,void 0===d?h<4&&(v=1):(t[a][o]=(1+r)*t[a][o]-r*d,g>m&&(v=Math.max(v,Math.abs(t[a][o]-d)/(g-m))))}return v}e.exports=function(t,e){var r,i=1;for(o(t,e),r=0;r<e.length&&!(e[r][2]<4);r++);for(e=e.slice(r),r=0;r<100&&i>.01;r++)i=o(t,e,a(i));return i>.01&&n.log(\"interp2d didn't converge quickly\",i),t}},{\"../../lib\":799}],1091:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\").isArrayOrTypedArray;e.exports=function(t,e,r,a,o,s){var l,c,u,f=[],h=n.traceIs(t,\"contour\"),p=n.traceIs(t,\"histogram\"),d=n.traceIs(t,\"gl2d\");if(i(e)&&e.length>1&&!p&&\"category\"!==s.type){var m=e.length;if(!(m<=o))return h?e.slice(0,o):e.slice(0,o+1);if(h||d)f=e.slice(0,o);else if(1===o)f=[e[0]-.5,e[0]+.5];else{for(f=[1.5*e[0]-.5*e[1]],u=1;u<m;u++)f.push(.5*(e[u-1]+e[u]));f.push(1.5*e[m-1]-.5*e[m-2])}if(m<o){var g=f[f.length-1],v=g-f[f.length-2];for(u=m;u<o;u++)g+=v,f.push(g)}}else{var y=t[s._id.charAt(0)+\"calendar\"];if(p)l=s.r2c(r,0,y);else if(i(e)&&1===e.length)l=e[0];else if(void 0===r)l=0;else{l=(\"log\"===s.type?s.d2c:s.r2c)(r,0,y)}for(c=a||1,u=h||d?0:-.5;u<o;u++)f.push(l+c*u)}return f}},{\"../../lib\":799,\"../../registry\":927}],1092:[function(t,e,r){\"use strict\";var n=t(\"@plotly/d3\"),i=t(\"tinycolor2\"),a=t(\"../../registry\"),o=t(\"../../lib\"),s=t(\"../../components/colorscale\").makeColorScaleFuncFromTrace,l=t(\"../../constants/xmlns_namespaces\");function c(t,e){var r=e.length-2,n=o.constrain(o.findBin(t,e),0,r),i=e[n],a=e[n+1],s=o.constrain(n+(t-i)/(a-i)-.5,0,r),l=Math.round(s),c=Math.abs(s-l);return s&&s!==r&&c?{bin0:l,frac:c,bin1:Math.round(l+c/(s-l))}:{bin0:l,bin1:l,frac:0}}function u(t,e){var r=e.length-1,n=o.constrain(o.findBin(t,e),0,r),i=e[n],a=(t-i)/(e[n+1]-i)||0;return a<=0?{bin0:n,bin1:n,frac:0}:a<.5?{bin0:n,bin1:n+1,frac:a}:{bin0:n+1,bin1:n,frac:1-a}}function f(t,e,r){t[e]=r[0],t[e+1]=r[1],t[e+2]=r[2],t[e+3]=Math.round(255*r[3])}e.exports=function(t,e,r,h){var p=e.xaxis,d=e.yaxis;o.makeTraceGroups(h,r,\"hm\").each((function(e){var r,h,m,g,v,y,x=n.select(this),b=e[0],_=b.trace,w=b.z,T=b.x,k=b.y,M=b.xCenter,A=b.yCenter,S=a.traceIs(_,\"contour\"),E=S?\"best\":_.zsmooth,L=w.length,C=o.maxRowLength(w),P=!1,I=!1;for(y=0;void 0===r&&y<T.length-1;)r=p.c2p(T[y]),y++;for(y=T.length-1;void 0===h&&y>0;)h=p.c2p(T[y]),y--;for(h<r&&(m=h,h=r,r=m,P=!0),y=0;void 0===g&&y<k.length-1;)g=d.c2p(k[y]),y++;for(y=k.length-1;void 0===v&&y>0;)v=d.c2p(k[y]),y--;if(v<g&&(m=g,g=v,v=m,I=!0),S&&(M=T,A=k,T=b.xfill,k=b.yfill),\"fast\"!==E){var O=\"best\"===E?0:.5;r=Math.max(-O*p._length,r),h=Math.min((1+O)*p._length,h),g=Math.max(-O*d._length,g),v=Math.min((1+O)*d._length,v)}var z=Math.round(h-r),D=Math.round(v-g);if(z<=0||D<=0){x.selectAll(\"image\").data([]).exit().remove()}else{var R,F;\"fast\"===E?(R=C,F=L):(R=z,F=D);var B=document.createElement(\"canvas\");B.width=R,B.height=F;var N,j,U=B.getContext(\"2d\"),V=s(_,{noNumericCheck:!0,returnArray:!0});\"fast\"===E?(N=P?function(t){return C-1-t}:o.identity,j=I?function(t){return L-1-t}:o.identity):(N=function(t){return o.constrain(Math.round(p.c2p(T[t])-r),0,z)},j=function(t){return o.constrain(Math.round(d.c2p(k[t])-g),0,D)});var q,H,G,Y,W,X=j(0),Z=[X,X],J=P?0:1,K=I?0:1,Q=0,$=0,tt=0,et=0;if(E){var rt,nt=0;try{rt=new Uint8Array(z*D*4)}catch(t){rt=new Array(z*D*4)}if(\"best\"===E){var it,at,ot,st=M||T,lt=A||k,ct=new Array(st.length),ut=new Array(lt.length),ft=new Array(z),ht=M?u:c,pt=A?u:c;for(y=0;y<st.length;y++)ct[y]=Math.round(p.c2p(st[y])-r);for(y=0;y<lt.length;y++)ut[y]=Math.round(d.c2p(lt[y])-g);for(y=0;y<z;y++)ft[y]=ht(y,ct);for(H=0;H<D;H++)for(at=w[(it=pt(H,ut)).bin0],ot=w[it.bin1],y=0;y<z;y++,nt+=4)f(rt,nt,W=kt(at,ot,ft[y],it))}else for(H=0;H<L;H++)for(Y=w[H],Z=j(H),y=0;y<z;y++)W=Tt(Y[y],1),f(rt,nt=4*(Z*z+N(y)),W);var dt=U.createImageData(z,D);try{dt.data.set(rt)}catch(t){var mt=dt.data,gt=mt.length;for(H=0;H<gt;H++)mt[H]=rt[H]}U.putImageData(dt,0,0)}else{var vt=_.xgap,yt=_.ygap,xt=Math.floor(vt/2),bt=Math.floor(yt/2);for(H=0;H<L;H++)if(Y=w[H],Z.reverse(),Z[K]=j(H+1),Z[0]!==Z[1]&&void 0!==Z[0]&&void 0!==Z[1])for(q=[G=N(0),G],y=0;y<C;y++)q.reverse(),q[J]=N(y+1),q[0]!==q[1]&&void 0!==q[0]&&void 0!==q[1]&&(W=Tt(Y[y],(q[1]-q[0])*(Z[1]-Z[0])),U.fillStyle=\"rgba(\"+W.join(\",\")+\")\",U.fillRect(q[0]+xt,Z[0]+bt,q[1]-q[0]-vt,Z[1]-Z[0]-yt))}$=Math.round($/Q),tt=Math.round(tt/Q),et=Math.round(et/Q);var _t=i(\"rgb(\"+$+\",\"+tt+\",\"+et+\")\");t._hmpixcount=(t._hmpixcount||0)+Q,t._hmlumcount=(t._hmlumcount||0)+Q*_t.getLuminance();var wt=x.selectAll(\"image\").data(e);wt.enter().append(\"svg:image\").attr({xmlns:l.svg,preserveAspectRatio:\"none\"}),wt.attr({height:D,width:z,x:r,y:g,\"xlink:href\":B.toDataURL(\"image/png\")})}function Tt(t,e){if(void 0!==t){var r=V(t);return r[0]=Math.round(r[0]),r[1]=Math.round(r[1]),r[2]=Math.round(r[2]),Q+=e,$+=r[0]*e,tt+=r[1]*e,et+=r[2]*e,r}return[0,0,0,0]}function kt(t,e,r,n){var i=t[r.bin0];if(void 0===i)return Tt(void 0,1);var a,o=t[r.bin1],s=e[r.bin0],l=e[r.bin1],c=o-i||0,u=s-i||0;return a=void 0===o?void 0===l?0:void 0===s?2*(l-i):2*(2*l-s-i)/3:void 0===l?void 0===s?0:2*(2*i-o-s)/3:void 0===s?2*(2*l-o-i)/3:l+i-o-s,Tt(i+r.frac*c+n.frac*(u+r.frac*a))}}))}},{\"../../components/colorscale\":674,\"../../constants/xmlns_namespaces\":776,\"../../lib\":799,\"../../registry\":927,\"@plotly/d3\":58,tinycolor2:594}],1093:[function(t,e,r){\"use strict\";var n=t(\"@plotly/d3\");e.exports=function(t){n.select(t).selectAll(\".hm image\").style(\"opacity\",(function(t){return t.trace.opacity}))}},{\"@plotly/d3\":58}],1094:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){!1===r(\"zsmooth\")&&(r(\"xgap\"),r(\"ygap\")),r(\"zhoverformat\")}},{}],1095:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../../registry\");function o(t,e){var r=e(t);return\"scaled\"===(r?e(t+\"type\",\"array\"):\"scaled\")&&(e(t+\"0\"),e(\"d\"+t)),r}e.exports=function(t,e,r,s,l,c){var u,f,h=r(\"z\");if(l=l||\"x\",c=c||\"y\",void 0===h||!h.length)return 0;if(i.isArray1D(t.z)){u=r(l),f=r(c);var p=i.minRowLength(u),d=i.minRowLength(f);if(0===p||0===d)return 0;e._length=Math.min(p,d,h.length)}else{if(u=o(l,r),f=o(c,r),!function(t){for(var e,r=!0,a=!1,o=!1,s=0;s<t.length;s++){if(e=t[s],!i.isArrayOrTypedArray(e)){r=!1;break}e.length>0&&(a=!0);for(var l=0;l<e.length;l++)if(n(e[l])){o=!0;break}}return r&&a&&o}(h))return 0;r(\"transpose\"),e._length=null}return\"heatmapgl\"===t.type||a.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[l,c],s),!0}},{\"../../lib\":799,\"../../registry\":927,\"fast-isnumeric\":245}],1096:[function(t,e,r){\"use strict\";for(var n=t(\"../heatmap/attributes\"),i=t(\"../../components/colorscale/attributes\"),a=t(\"../../lib/extend\").extendFlat,o=t(\"../../plot_api/edit_types\").overrideAll,s=[\"z\",\"x\",\"x0\",\"dx\",\"y\",\"y0\",\"dy\",\"text\",\"transpose\",\"xtype\",\"ytype\"],l={},c=0;c<s.length;c++){var u=s[c];l[u]=n[u]}l.zsmooth={valType:\"enumerated\",values:[\"fast\",!1],dflt:\"fast\",editType:\"calc\"},a(l,i(\"\",{cLetter:\"z\",autoColorDflt:!1})),e.exports=o(l,\"calc\",\"nested\")},{\"../../components/colorscale/attributes\":669,\"../../lib/extend\":789,\"../../plot_api/edit_types\":831,\"../heatmap/attributes\":1081}],1097:[function(t,e,r){\"use strict\";var n=t(\"gl-heatmap2d\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../../lib/str2rgbarray\");function o(t,e){this.scene=t,this.uid=e,this.type=\"heatmapgl\",this.name=\"\",this.hoverinfo=\"all\",this.xData=[],this.yData=[],this.zData=[],this.textLabels=[],this.idToIndex=[],this.bounds=[0,0,0,0],this.options={zsmooth:\"fast\",z:[],x:[],y:[],shape:[0,0],colorLevels:[0],colorValues:[0,0,0,1]},this.heatmap=n(t.glplot,this.options),this.heatmap._trace=this}var s=o.prototype;s.handlePick=function(t){var e=this.options,r=e.shape,n=t.pointId,i=n%r[0],a=Math.floor(n/r[0]),o=n;return{trace:this,dataCoord:t.dataCoord,traceCoord:[e.x[i],e.y[a],e.z[o]],textLabel:this.textLabels[n],name:this.name,pointIndex:[a,i],hoverinfo:this.hoverinfo}},s.update=function(t,e){var r=e[0];this.index=t.index,this.name=t.name,this.hoverinfo=t.hoverinfo;var n=r.z;this.options.z=[].concat.apply([],n);var o=n[0].length,s=n.length;this.options.shape=[o,s],this.options.x=r.x,this.options.y=r.y,this.options.zsmooth=t.zsmooth;var l=function(t){for(var e=t.colorscale,r=t.zmin,n=t.zmax,i=e.length,o=new Array(i),s=new Array(4*i),l=0;l<i;l++){var c=e[l],u=a(c[1]);o[l]=r+c[0]*(n-r);for(var f=0;f<4;f++)s[4*l+f]=u[f]}return{colorLevels:o,colorValues:s}}(t);this.options.colorLevels=l.colorLevels,this.options.colorValues=l.colorValues,this.textLabels=[].concat.apply([],t.text),this.heatmap.update(this.options);var c,u,f=this.scene.xaxis,h=this.scene.yaxis;!1===t.zsmooth&&(c={ppad:r.x[1]-r.x[0]},u={ppad:r.y[1]-r.y[0]}),t._extremes[f._id]=i.findExtremes(f,r.x,c),t._extremes[h._id]=i.findExtremes(h,r.y,u)},s.dispose=function(){this.heatmap.dispose()},e.exports=function(t,e,r){var n=new o(t,e.uid);return n.update(e,r),n}},{\"../../lib/str2rgbarray\":823,\"../../plots/cartesian/axes\":849,\"gl-heatmap2d\":274}],1098:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../heatmap/xyz_defaults\"),a=t(\"../../components/colorscale/defaults\"),o=t(\"./attributes\");e.exports=function(t,e,r,s){function l(r,i){return n.coerce(t,e,o,r,i)}i(t,e,l,s)?(l(\"text\"),l(\"zsmooth\"),a(t,e,s,l,{prefix:\"\",cLetter:\"z\"})):e.visible=!1}},{\"../../components/colorscale/defaults\":672,\"../../lib\":799,\"../heatmap/xyz_defaults\":1095,\"./attributes\":1096}],1099:[function(t,e,r){\"use strict\";[\"*heatmapgl* trace is deprecated!\",\"Please consider switching to the *heatmap* or *image* trace types.\",\"Alternatively you could contribute/sponsor rewriting this trace type\",\"based on cartesian features and using regl framework.\"].join(\" \");e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../heatmap/colorbar\"),calc:t(\"../heatmap/calc\"),plot:t(\"./convert\"),moduleType:\"trace\",name:\"heatmapgl\",basePlotModule:t(\"../../plots/gl2d\"),categories:[\"gl\",\"gl2d\",\"2dMap\"],meta:{}}},{\"../../plots/gl2d\":890,\"../heatmap/calc\":1082,\"../heatmap/colorbar\":1084,\"./attributes\":1096,\"./convert\":1097,\"./defaults\":1098}],1100:[function(t,e,r){\"use strict\";var n=t(\"../bar/attributes\"),i=t(\"../../plots/cartesian/axis_format_attributes\").axisHoverFormat,a=t(\"../../plots/template_attributes\").hovertemplateAttrs,o=t(\"./bin_attributes\"),s=t(\"./constants\"),l=t(\"../../lib/extend\").extendFlat;e.exports={x:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},y:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},xhoverformat:i(\"x\"),yhoverformat:i(\"y\"),text:l({},n.text,{}),hovertext:l({},n.hovertext,{}),orientation:n.orientation,histfunc:{valType:\"enumerated\",values:[\"count\",\"sum\",\"avg\",\"min\",\"max\"],dflt:\"count\",editType:\"calc\"},histnorm:{valType:\"enumerated\",values:[\"\",\"percent\",\"probability\",\"density\",\"probability density\"],dflt:\"\",editType:\"calc\"},cumulative:{enabled:{valType:\"boolean\",dflt:!1,editType:\"calc\"},direction:{valType:\"enumerated\",values:[\"increasing\",\"decreasing\"],dflt:\"increasing\",editType:\"calc\"},currentbin:{valType:\"enumerated\",values:[\"include\",\"exclude\",\"half\"],dflt:\"include\",editType:\"calc\"},editType:\"calc\"},nbinsx:{valType:\"integer\",min:0,dflt:0,editType:\"calc\"},xbins:o(\"x\",!0),nbinsy:{valType:\"integer\",min:0,dflt:0,editType:\"calc\"},ybins:o(\"y\",!0),autobinx:{valType:\"boolean\",dflt:null,editType:\"calc\"},autobiny:{valType:\"boolean\",dflt:null,editType:\"calc\"},bingroup:{valType:\"string\",dflt:\"\",editType:\"calc\"},hovertemplate:a({},{keys:s.eventDataKeys}),marker:n.marker,offsetgroup:n.offsetgroup,alignmentgroup:n.alignmentgroup,selected:n.selected,unselected:n.unselected,_deprecated:{bardir:n._deprecated.bardir}}},{\"../../lib/extend\":789,\"../../plots/cartesian/axis_format_attributes\":852,\"../../plots/template_attributes\":922,\"../bar/attributes\":937,\"./bin_attributes\":1102,\"./constants\":1106}],1101:[function(t,e,r){\"use strict\";e.exports=function(t,e){for(var r=t.length,n=0,i=0;i<r;i++)e[i]?(t[i]/=e[i],n+=t[i]):t[i]=null;return n}},{}],1102:[function(t,e,r){\"use strict\";e.exports=function(t,e){return{start:{valType:\"any\",editType:\"calc\"},end:{valType:\"any\",editType:\"calc\"},size:{valType:\"any\",editType:\"calc\"},editType:\"calc\"}}},{}],1103:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\");e.exports={count:function(t,e,r){return r[t]++,1},sum:function(t,e,r,i){var a=i[e];return n(a)?(a=Number(a),r[t]+=a,a):0},avg:function(t,e,r,i,a){var o=i[e];return n(o)&&(o=Number(o),r[t]+=o,a[t]++),0},min:function(t,e,r,i){var a=i[e];if(n(a)){if(a=Number(a),!n(r[t]))return r[t]=a,a;if(r[t]>a){var o=a-r[t];return r[t]=a,o}}return 0},max:function(t,e,r,i){var a=i[e];if(n(a)){if(a=Number(a),!n(r[t]))return r[t]=a,a;if(r[t]<a){var o=a-r[t];return r[t]=a,o}}return 0}}},{\"fast-isnumeric\":245}],1104:[function(t,e,r){\"use strict\";var n=t(\"../../constants/numerical\"),i=n.ONEAVGYEAR,a=n.ONEAVGMONTH,o=n.ONEDAY,s=n.ONEHOUR,l=n.ONEMIN,c=n.ONESEC,u=t(\"../../plots/cartesian/axes\").tickIncrement;function f(t,e,r,n){if(t*e<=0)return 1/0;for(var i=Math.abs(e-t),a=\"date\"===r.type,o=h(i,a),s=0;s<10;s++){var l=h(80*o,a);if(o===l)break;if(!p(l,t,e,a,r,n))break;o=l}return o}function h(t,e){return e&&t>c?t>o?t>1.1*i?i:t>1.1*a?a:o:t>s?s:t>l?l:c:Math.pow(10,Math.floor(Math.log(t)/Math.LN10))}function p(t,e,r,n,a,s){if(n&&t>o){var l=d(e,a,s),c=d(r,a,s),u=t===i?0:1;return l[u]!==c[u]}return Math.floor(r/t)-Math.floor(e/t)>.1}function d(t,e,r){var n=e.c2d(t,i,r).split(\"-\");return\"\"===n[0]&&(n.unshift(),n[0]=\"-\"+n[0]),n}e.exports=function(t,e,r,n,a){var s,l,c=-1.1*e,h=-.1*e,p=t-h,d=r[0],m=r[1],g=Math.min(f(d+h,d+p,n,a),f(m+h,m+p,n,a)),v=Math.min(f(d+c,d+h,n,a),f(m+c,m+h,n,a));if(g>v&&v<Math.abs(m-d)/4e3?(s=g,l=!1):(s=Math.min(g,v),l=!0),\"date\"===n.type&&s>o){var y=s===i?1:6,x=s===i?\"M12\":\"M1\";return function(e,r){var o=n.c2d(e,i,a),s=o.indexOf(\"-\",y);s>0&&(o=o.substr(0,s));var c=n.d2c(o,0,a);if(c<e){var f=u(c,x,!1,a);(c+f)/2<e+t&&(c=f)}return r&&l?u(c,x,!0,a):c}}return function(e,r){var n=s*Math.round(e/s);return n+s/10<e&&n+.9*s<e+t&&(n+=s),r&&l&&(n-=s),n}}},{\"../../constants/numerical\":775,\"../../plots/cartesian/axes\":849}],1105:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../../registry\"),o=t(\"../../plots/cartesian/axes\"),s=t(\"../bar/arrays_to_calcdata\"),l=t(\"./bin_functions\"),c=t(\"./norm_functions\"),u=t(\"./average\"),f=t(\"./bin_label_vals\");function h(t,e,r,s,l){var c,u,f,p,d,m,g,v=s+\"bins\",y=t._fullLayout,x=e[\"_\"+s+\"bingroup\"],b=y._histogramBinOpts[x],_=\"overlay\"===y.barmode,w=function(t){return r.r2c(t,0,p)},T=function(t){return r.c2r(t,0,p)},k=\"date\"===r.type?function(t){return t||0===t?i.cleanDate(t,null,p):null}:function(t){return n(t)?Number(t):null};function M(t,e,r){e[t+\"Found\"]?(e[t]=k(e[t]),null===e[t]&&(e[t]=r[t])):(m[t]=e[t]=r[t],i.nestedProperty(u[0],v+\".\"+t).set(r[t]))}if(e[\"_\"+s+\"autoBinFinished\"])delete e[\"_\"+s+\"autoBinFinished\"];else{u=b.traces;var A=[],S=!0,E=!1,L=!1;for(c=0;c<u.length;c++)if((f=u[c]).visible){var C=b.dirs[c];d=f[\"_\"+C+\"pos0\"]=r.makeCalcdata(f,C),A=i.concat(A,d),delete f[\"_\"+s+\"autoBinFinished\"],!0===e.visible&&(S?S=!1:(delete f._autoBin,f[\"_\"+s+\"autoBinFinished\"]=1),a.traceIs(f,\"2dMap\")&&(E=!0),\"histogram2dcontour\"===f.type&&(L=!0))}p=u[0][s+\"calendar\"];var P=o.autoBin(A,r,b.nbins,E,p,b.sizeFound&&b.size),I=u[0]._autoBin={};if(m=I[b.dirs[0]]={},L&&(b.size||(P.start=T(o.tickIncrement(w(P.start),P.size,!0,p))),void 0===b.end&&(P.end=T(o.tickIncrement(w(P.end),P.size,!1,p)))),_&&!a.traceIs(e,\"2dMap\")&&0===P._dataSpan&&\"category\"!==r.type&&\"multicategory\"!==r.type){if(l)return[P,d,!0];P=function(t,e,r,n,a){var o,s,l,c=t._fullLayout,u=function(t,e){for(var r=e.xaxis,n=e.yaxis,i=e.orientation,a=[],o=t._fullData,s=0;s<o.length;s++){var l=o[s];\"histogram\"===l.type&&!0===l.visible&&l.orientation===i&&l.xaxis===r&&l.yaxis===n&&a.push(l)}return a}(t,e),f=!1,p=1/0,d=[e];for(o=0;o<u.length;o++)if((s=u[o])===e)f=!0;else if(f){var m=h(t,s,r,n,!0),g=m[0],v=m[2];s[\"_\"+n+\"autoBinFinished\"]=1,s[\"_\"+n+\"pos0\"]=m[1],v?d.push(s):p=Math.min(p,g.size)}else l=c._histogramBinOpts[s[\"_\"+n+\"bingroup\"]],p=Math.min(p,l.size||s[a].size);var y=new Array(d.length);for(o=0;o<d.length;o++)for(var x=d[o][\"_\"+n+\"pos0\"],b=0;b<x.length;b++)if(void 0!==x[b]){y[o]=x[b];break}isFinite(p)||(p=i.distinctVals(y).minDiff);for(o=0;o<d.length;o++){var _=(s=d[o])[n+\"calendar\"],w={start:r.c2r(y[o]-p/2,0,_),end:r.c2r(y[o]+p/2,0,_),size:p};s._input[a]=s[a]=w,(l=c._histogramBinOpts[s[\"_\"+n+\"bingroup\"]])&&i.extendFlat(l,w)}return e[a]}(t,e,r,s,v)}(g=f.cumulative||{}).enabled&&\"include\"!==g.currentbin&&(\"decreasing\"===g.direction?P.start=T(o.tickIncrement(w(P.start),P.size,!0,p)):P.end=T(o.tickIncrement(w(P.end),P.size,!1,p))),b.size=P.size,b.sizeFound||(m.size=P.size,i.nestedProperty(u[0],v+\".size\").set(P.size)),M(\"start\",b,P),M(\"end\",b,P)}d=e[\"_\"+s+\"pos0\"],delete e[\"_\"+s+\"pos0\"];var O=e._input[v]||{},z=i.extendFlat({},b),D=b.start,R=r.r2l(O.start),F=void 0!==R;if((b.startFound||F)&&R!==r.r2l(D)){var B=F?R:i.aggNums(Math.min,null,d),N={type:\"category\"===r.type||\"multicategory\"===r.type?\"linear\":r.type,r2l:r.r2l,dtick:b.size,tick0:D,calendar:p,range:[B,o.tickIncrement(B,b.size,!1,p)].map(r.l2r)},j=o.tickFirst(N);j>r.r2l(B)&&(j=o.tickIncrement(j,b.size,!0,p)),z.start=r.l2r(j),F||i.nestedProperty(e,v+\".start\").set(z.start)}var U=b.end,V=r.r2l(O.end),q=void 0!==V;if((b.endFound||q)&&V!==r.r2l(U)){var H=q?V:i.aggNums(Math.max,null,d);z.end=r.l2r(H),q||i.nestedProperty(e,v+\".start\").set(z.end)}var G=\"autobin\"+s;return!1===e._input[G]&&(e._input[v]=i.extendFlat({},e[v]||{}),delete e._input[G],delete e[G]),[z,d]}e.exports={calc:function(t,e){var r,a,p,d,m=[],g=[],v=o.getFromId(t,\"h\"===e.orientation?e.yaxis:e.xaxis),y=\"h\"===e.orientation?\"y\":\"x\",x={x:\"y\",y:\"x\"}[y],b=e[y+\"calendar\"],_=e.cumulative,w=h(t,e,v,y),T=w[0],k=w[1],M=\"string\"==typeof T.size,A=[],S=M?A:T,E=[],L=[],C=[],P=0,I=e.histnorm,O=e.histfunc,z=-1!==I.indexOf(\"density\");_.enabled&&z&&(I=I.replace(/ ?density$/,\"\"),z=!1);var D,R=\"max\"===O||\"min\"===O?null:0,F=l.count,B=c[I],N=!1,j=function(t){return v.r2c(t,0,b)};for(i.isArrayOrTypedArray(e[x])&&\"count\"!==O&&(D=e[x],N=\"avg\"===O,F=l[O]),r=j(T.start),p=j(T.end)+(r-o.tickIncrement(r,T.size,!1,b))/1e6;r<p&&m.length<1e6&&(a=o.tickIncrement(r,T.size,!1,b),m.push((r+a)/2),g.push(R),C.push([]),A.push(r),z&&E.push(1/(a-r)),N&&L.push(0),!(a<=r));)r=a;A.push(r),M||\"date\"!==v.type||(S={start:j(S.start),end:j(S.end),size:S.size}),t._fullLayout._roundFnOpts||(t._fullLayout._roundFnOpts={});var U=e[\"_\"+y+\"bingroup\"],V={leftGap:1/0,rightGap:1/0};U&&(t._fullLayout._roundFnOpts[U]||(t._fullLayout._roundFnOpts[U]=V),V=t._fullLayout._roundFnOpts[U]);var q,H=g.length,G=!0,Y=V.leftGap,W=V.rightGap,X={};for(r=0;r<k.length;r++){var Z=k[r];(d=i.findBin(Z,S))>=0&&d<H&&(P+=F(d,r,g,D,L),G&&C[d].length&&Z!==k[C[d][0]]&&(G=!1),C[d].push(r),X[r]=d,Y=Math.min(Y,Z-A[d]),W=Math.min(W,A[d+1]-Z))}V.leftGap=Y,V.rightGap=W,G||(q=function(e,r){return function(){var n=t._fullLayout._roundFnOpts[U];return f(n.leftGap,n.rightGap,A,v,b)(e,r)}}),N&&(P=u(g,L)),B&&B(g,P,E),_.enabled&&function(t,e,r){var n,i,a;function o(e){a=t[e],t[e]/=2}function s(e){i=t[e],t[e]=a+i/2,a+=i}if(\"half\"===r)if(\"increasing\"===e)for(o(0),n=1;n<t.length;n++)s(n);else for(o(t.length-1),n=t.length-2;n>=0;n--)s(n);else if(\"increasing\"===e){for(n=1;n<t.length;n++)t[n]+=t[n-1];\"exclude\"===r&&(t.unshift(0),t.pop())}else{for(n=t.length-2;n>=0;n--)t[n]+=t[n+1];\"exclude\"===r&&(t.push(0),t.shift())}}(g,_.direction,_.currentbin);var J=Math.min(m.length,g.length),K=[],Q=0,$=J-1;for(r=0;r<J;r++)if(g[r]){Q=r;break}for(r=J-1;r>=Q;r--)if(g[r]){$=r;break}for(r=Q;r<=$;r++)if(n(m[r])&&n(g[r])){var tt={p:m[r],s:g[r],b:0};_.enabled||(tt.pts=C[r],G?tt.ph0=tt.ph1=C[r].length?k[C[r][0]]:m[r]:(e._computePh=!0,tt.ph0=q(A[r]),tt.ph1=q(A[r+1],!0))),K.push(tt)}return 1===K.length&&(K[0].width1=o.tickIncrement(K[0].p,T.size,!1,b)-K[0].p),s(K,e),i.isArrayOrTypedArray(e.selectedpoints)&&i.tagSelected(K,e,X),K},calcAllAutoBins:h}},{\"../../lib\":799,\"../../plots/cartesian/axes\":849,\"../../registry\":927,\"../bar/arrays_to_calcdata\":936,\"./average\":1101,\"./bin_functions\":1103,\"./bin_label_vals\":1104,\"./norm_functions\":1112,\"fast-isnumeric\":245}],1106:[function(t,e,r){\"use strict\";e.exports={eventDataKeys:[\"binNumber\"]}},{}],1107:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axis_ids\"),a=t(\"../../registry\").traceIs,o=t(\"../bar/defaults\").handleGroupingDefaults,s=n.nestedProperty,l=t(\"../../plots/cartesian/constraints\").getAxisGroup,c=[{aStr:{x:\"xbins.start\",y:\"ybins.start\"},name:\"start\"},{aStr:{x:\"xbins.end\",y:\"ybins.end\"},name:\"end\"},{aStr:{x:\"xbins.size\",y:\"ybins.size\"},name:\"size\"},{aStr:{x:\"nbinsx\",y:\"nbinsy\"},name:\"nbins\"}],u=[\"x\",\"y\"];e.exports=function(t,e){var r,f,h,p,d,m,g,v=e._histogramBinOpts={},y=[],x={},b=[];function _(t,e){return n.coerce(r._input,r,r._module.attributes,t,e)}function w(t){return\"v\"===t.orientation?\"x\":\"y\"}function T(t,r,a){var o=t.uid+\"__\"+a;r||(r=o);var s=function(t,r){return i.getFromTrace({_fullLayout:e},t,r).type}(t,a),l=t[a+\"calendar\"]||\"\",c=v[r],u=!0;c&&(s===c.axType&&l===c.calendar?(u=!1,c.traces.push(t),c.dirs.push(a)):(r=o,s!==c.axType&&n.warn([\"Attempted to group the bins of trace\",t.index,\"set on a\",\"type:\"+s,\"axis\",\"with bins on\",\"type:\"+c.axType,\"axis.\"].join(\" \")),l!==c.calendar&&n.warn([\"Attempted to group the bins of trace\",t.index,\"set with a\",l,\"calendar\",\"with bins\",c.calendar?\"on a \"+c.calendar+\" calendar\":\"w/o a set calendar\"].join(\" \")))),u&&(v[r]={traces:[t],dirs:[a],axType:s,calendar:t[a+\"calendar\"]||\"\"}),t[\"_\"+a+\"bingroup\"]=r}for(d=0;d<t.length;d++)r=t[d],a(r,\"histogram\")&&(y.push(r),delete r._xautoBinFinished,delete r._yautoBinFinished,a(r,\"2dMap\")||o(r._input,r,e,_));var k=e._alignmentOpts||{};for(d=0;d<y.length;d++){if(r=y[d],h=\"\",!a(r,\"2dMap\")){if(p=w(r),\"group\"===e.barmode&&r.alignmentgroup){var M=r[p+\"axis\"],A=l(e,M)+r.orientation;(k[A]||{})[r.alignmentgroup]&&(h=A)}h||\"overlay\"===e.barmode||(h=l(e,r.xaxis)+l(e,r.yaxis)+w(r))}h?(x[h]||(x[h]=[]),x[h].push(r)):b.push(r)}for(h in x)if(1!==(f=x[h]).length){var S=!1;for(f.length&&(r=f[0],S=_(\"bingroup\")),h=S||h,d=0;d<f.length;d++){var E=(r=f[d])._input.bingroup;E&&E!==h&&n.warn([\"Trace\",r.index,\"must match\",\"within bingroup\",h+\".\",\"Ignoring its bingroup:\",E,\"setting.\"].join(\" \")),r.bingroup=h,T(r,h,w(r))}}else b.push(f[0]);for(d=0;d<b.length;d++){r=b[d];var L=_(\"bingroup\");if(a(r,\"2dMap\"))for(g=0;g<2;g++){var C=_((p=u[g])+\"bingroup\",L?L+\"__\"+p:null);T(r,C,p)}else T(r,L,w(r))}for(h in v){var P=v[h];for(f=P.traces,m=0;m<c.length;m++){var I,O,z=c[m],D=z.name;if(\"nbins\"!==D||!P.sizeFound){for(d=0;d<f.length;d++){if(r=f[d],p=P.dirs[d],I=z.aStr[p],void 0!==s(r._input,I).get()){P[D]=_(I),P[D+\"Found\"]=!0;break}(O=(r._autoBin||{})[p]||{})[D]&&s(r,I).set(O[D])}if(\"start\"===D||\"end\"===D)for(;d<f.length;d++)(r=f[d])[\"_\"+p+\"bingroup\"]&&_(I,(O=(r._autoBin||{})[p]||{})[D]);\"nbins\"!==D||P.sizeFound||P.nbinsFound||(r=f[0],P[D]=_(I))}}}}},{\"../../lib\":799,\"../../plots/cartesian/axis_ids\":853,\"../../plots/cartesian/constraints\":857,\"../../registry\":927,\"../bar/defaults\":941}],1108:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"../../components/color\"),o=t(\"../bar/style_defaults\"),s=t(\"./attributes\");e.exports=function(t,e,r,l){function c(r,n){return i.coerce(t,e,s,r,n)}var u=c(\"x\"),f=c(\"y\");c(\"cumulative.enabled\")&&(c(\"cumulative.direction\"),c(\"cumulative.currentbin\")),c(\"text\"),c(\"hovertext\"),c(\"hovertemplate\"),c(\"xhoverformat\"),c(\"yhoverformat\");var h=c(\"orientation\",f&&!u?\"h\":\"v\"),p=\"v\"===h?\"x\":\"y\",d=\"v\"===h?\"y\":\"x\",m=u&&f?Math.min(i.minRowLength(u)&&i.minRowLength(f)):i.minRowLength(e[p]||[]);if(m){e._length=m,n.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\",\"y\"],l),e[d]&&c(\"histfunc\"),c(\"histnorm\"),c(\"autobin\"+p),o(t,e,c,r,l),i.coerceSelectionMarkerOpacity(e,c);var g=(e.marker.line||{}).color,v=n.getComponentMethod(\"errorbars\",\"supplyDefaults\");v(t,e,g||a.defaultLine,{axis:\"y\"}),v(t,e,g||a.defaultLine,{axis:\"x\",inherit:\"y\"})}else e.visible=!1}},{\"../../components/color\":662,\"../../lib\":799,\"../../registry\":927,\"../bar/style_defaults\":952,\"./attributes\":1100}],1109:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,i){if(t.x=\"xVal\"in e?e.xVal:e.x,t.y=\"yVal\"in e?e.yVal:e.y,\"zLabelVal\"in e&&(t.z=e.zLabelVal),e.xa&&(t.xaxis=e.xa),e.ya&&(t.yaxis=e.ya),!(r.cumulative||{}).enabled){var a,o=Array.isArray(i)?n[0].pts[i[0]][i[1]]:n[i].pts;if(t.pointNumbers=o,t.binNumber=t.pointNumber,delete t.pointNumber,delete t.pointIndex,r._indexToPoints){a=[];for(var s=0;s<o.length;s++)a=a.concat(r._indexToPoints[o[s]])}else a=o;t.pointIndices=a}return t}},{}],1110:[function(t,e,r){\"use strict\";var n=t(\"../bar/hover\").hoverPoints,i=t(\"../../plots/cartesian/axes\").hoverLabelText;e.exports=function(t,e,r,a,o){var s=n(t,e,r,a,o);if(s){var l=(t=s[0]).cd[t.index],c=t.cd[0].trace;if(!c.cumulative.enabled){var u=\"h\"===c.orientation?\"y\":\"x\";t[u+\"Label\"]=i(t[u+\"a\"],[l.ph0,l.ph1],c[u+\"hoverformat\"])}return s}}},{\"../../plots/cartesian/axes\":849,\"../bar/hover\":944}],1111:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),layoutAttributes:t(\"../bar/layout_attributes\"),supplyDefaults:t(\"./defaults\"),crossTraceDefaults:t(\"./cross_trace_defaults\"),supplyLayoutDefaults:t(\"../bar/layout_defaults\"),calc:t(\"./calc\").calc,crossTraceCalc:t(\"../bar/cross_trace_calc\").crossTraceCalc,plot:t(\"../bar/plot\").plot,layerName:\"barlayer\",style:t(\"../bar/style\").style,styleOnSelect:t(\"../bar/style\").styleOnSelect,colorbar:t(\"../scatter/marker_colorbar\"),hoverPoints:t(\"./hover\"),selectPoints:t(\"../bar/select\"),eventData:t(\"./event_data\"),moduleType:\"trace\",name:\"histogram\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"bar-like\",\"cartesian\",\"svg\",\"bar\",\"histogram\",\"oriented\",\"errorBarsOK\",\"showLegend\"],meta:{}}},{\"../../plots/cartesian\":863,\"../bar/cross_trace_calc\":940,\"../bar/layout_attributes\":946,\"../bar/layout_defaults\":947,\"../bar/plot\":948,\"../bar/select\":949,\"../bar/style\":951,\"../scatter/marker_colorbar\":1232,\"./attributes\":1100,\"./calc\":1105,\"./cross_trace_defaults\":1107,\"./defaults\":1108,\"./event_data\":1109,\"./hover\":1110}],1112:[function(t,e,r){\"use strict\";e.exports={percent:function(t,e){for(var r=t.length,n=100/e,i=0;i<r;i++)t[i]*=n},probability:function(t,e){for(var r=t.length,n=0;n<r;n++)t[n]/=e},density:function(t,e,r,n){var i=t.length;n=n||1;for(var a=0;a<i;a++)t[a]*=r[a]*n},\"probability density\":function(t,e,r,n){var i=t.length;n&&(e/=n);for(var a=0;a<i;a++)t[a]*=r[a]/e}}},{}],1113:[function(t,e,r){\"use strict\";var n=t(\"../histogram/attributes\"),i=t(\"../histogram/bin_attributes\"),a=t(\"../heatmap/attributes\"),o=t(\"../../plots/attributes\"),s=t(\"../../plots/cartesian/axis_format_attributes\").axisHoverFormat,l=t(\"../../plots/template_attributes\").hovertemplateAttrs,c=t(\"../../components/colorscale/attributes\"),u=t(\"../../lib/extend\").extendFlat;e.exports=u({x:n.x,y:n.y,z:{valType:\"data_array\",editType:\"calc\"},marker:{color:{valType:\"data_array\",editType:\"calc\"},editType:\"calc\"},histnorm:n.histnorm,histfunc:n.histfunc,nbinsx:n.nbinsx,xbins:i(\"x\"),nbinsy:n.nbinsy,ybins:i(\"y\"),autobinx:n.autobinx,autobiny:n.autobiny,bingroup:u({},n.bingroup,{}),xbingroup:u({},n.bingroup,{}),ybingroup:u({},n.bingroup,{}),xgap:a.xgap,ygap:a.ygap,zsmooth:a.zsmooth,xhoverformat:s(\"x\"),yhoverformat:s(\"y\"),zhoverformat:s(\"z\",1),hovertemplate:l({},{keys:\"z\"}),showlegend:u({},o.showlegend,{dflt:!1})},c(\"\",{cLetter:\"z\",autoColorDflt:!1}))},{\"../../components/colorscale/attributes\":669,\"../../lib/extend\":789,\"../../plots/attributes\":845,\"../../plots/cartesian/axis_format_attributes\":852,\"../../plots/template_attributes\":922,\"../heatmap/attributes\":1081,\"../histogram/attributes\":1100,\"../histogram/bin_attributes\":1102}],1114:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../histogram/bin_functions\"),o=t(\"../histogram/norm_functions\"),s=t(\"../histogram/average\"),l=t(\"../histogram/bin_label_vals\"),c=t(\"../histogram/calc\").calcAllAutoBins;function u(t,e,r,n){var i,a=new Array(t);if(n)for(i=0;i<t;i++)a[i]=1/(e[i+1]-e[i]);else{var o=1/r;for(i=0;i<t;i++)a[i]=o}return a}function f(t,e){return{start:t(e.start),end:t(e.end),size:e.size}}function h(t,e,r,n,i,a){var o,s=t.length-1,c=new Array(s),u=l(r,n,t,i,a);for(o=0;o<s;o++){var f=(e||[])[o];c[o]=void 0===f?[u(t[o]),u(t[o+1],!0)]:[f,f]}return c}e.exports=function(t,e){var r,l,p,d,m=i.getFromId(t,e.xaxis),g=i.getFromId(t,e.yaxis),v=e.xcalendar,y=e.ycalendar,x=function(t){return m.r2c(t,0,v)},b=function(t){return g.r2c(t,0,y)},_=c(t,e,m,\"x\"),w=_[0],T=_[1],k=c(t,e,g,\"y\"),M=k[0],A=k[1],S=e._length;T.length>S&&T.splice(S,T.length-S),A.length>S&&A.splice(S,A.length-S);var E=[],L=[],C=[],P=\"string\"==typeof w.size,I=\"string\"==typeof M.size,O=[],z=[],D=P?O:w,R=I?z:M,F=0,B=[],N=[],j=e.histnorm,U=e.histfunc,V=-1!==j.indexOf(\"density\"),q=\"max\"===U||\"min\"===U?null:0,H=a.count,G=o[j],Y=!1,W=[],X=[],Z=\"z\"in e?e.z:\"marker\"in e&&Array.isArray(e.marker.color)?e.marker.color:\"\";Z&&\"count\"!==U&&(Y=\"avg\"===U,H=a[U]);var J=w.size,K=x(w.start),Q=x(w.end)+(K-i.tickIncrement(K,J,!1,v))/1e6;for(r=K;r<Q;r=i.tickIncrement(r,J,!1,v))L.push(q),O.push(r),Y&&C.push(0);O.push(r);var $,tt=L.length,et=(r-K)/tt,rt=($=K+et/2,m.c2r($,0,v)),nt=M.size,it=b(M.start),at=b(M.end)+(it-i.tickIncrement(it,nt,!1,y))/1e6;for(r=it;r<at;r=i.tickIncrement(r,nt,!1,y)){E.push(L.slice()),z.push(r);var ot=new Array(tt);for(l=0;l<tt;l++)ot[l]=[];N.push(ot),Y&&B.push(C.slice())}z.push(r);var st=E.length,lt=(r-it)/st,ct=function(t){return g.c2r(t,0,y)}(it+lt/2);V&&(W=u(L.length,D,et,P),X=u(E.length,R,lt,I)),P||\"date\"!==m.type||(D=f(x,D)),I||\"date\"!==g.type||(R=f(b,R));var ut=!0,ft=!0,ht=new Array(tt),pt=new Array(st),dt=1/0,mt=1/0,gt=1/0,vt=1/0;for(r=0;r<S;r++){var yt=T[r],xt=A[r];p=n.findBin(yt,D),d=n.findBin(xt,R),p>=0&&p<tt&&d>=0&&d<st&&(F+=H(p,r,E[d],Z,B[d]),N[d][p].push(r),ut&&(void 0===ht[p]?ht[p]=yt:ht[p]!==yt&&(ut=!1)),ft&&(void 0===pt[d]?pt[d]=xt:pt[d]!==xt&&(ft=!1)),dt=Math.min(dt,yt-O[p]),mt=Math.min(mt,O[p+1]-yt),gt=Math.min(gt,xt-z[d]),vt=Math.min(vt,z[d+1]-xt))}if(Y)for(d=0;d<st;d++)F+=s(E[d],B[d]);if(G)for(d=0;d<st;d++)G(E[d],F,W,X[d]);return{x:T,xRanges:h(O,ut&&ht,dt,mt,m,v),x0:rt,dx:et,y:A,yRanges:h(z,ft&&pt,gt,vt,g,y),y0:ct,dy:lt,z:E,pts:N}}},{\"../../lib\":799,\"../../plots/cartesian/axes\":849,\"../histogram/average\":1101,\"../histogram/bin_functions\":1103,\"../histogram/bin_label_vals\":1104,\"../histogram/calc\":1105,\"../histogram/norm_functions\":1112}],1115:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./sample_defaults\"),a=t(\"../heatmap/style_defaults\"),o=t(\"../../components/colorscale/defaults\"),s=t(\"./attributes\");e.exports=function(t,e,r,l){function c(r,i){return n.coerce(t,e,s,r,i)}i(t,e,c,l),!1!==e.visible&&(a(t,e,c,l),o(t,e,l,c,{prefix:\"\",cLetter:\"z\"}),c(\"hovertemplate\"),c(\"xhoverformat\"),c(\"yhoverformat\"))}},{\"../../components/colorscale/defaults\":672,\"../../lib\":799,\"../heatmap/style_defaults\":1094,\"./attributes\":1113,\"./sample_defaults\":1118}],1116:[function(t,e,r){\"use strict\";var n=t(\"../heatmap/hover\"),i=t(\"../../plots/cartesian/axes\").hoverLabelText;e.exports=function(t,e,r,a,o){var s=n(t,e,r,a,o);if(s){var l=(t=s[0]).index,c=l[0],u=l[1],f=t.cd[0],h=f.trace,p=f.xRanges[u],d=f.yRanges[c];return t.xLabel=i(t.xa,[p[0],p[1]],h.xhoverformat),t.yLabel=i(t.ya,[d[0],d[1]],h.yhoverformat),s}}},{\"../../plots/cartesian/axes\":849,\"../heatmap/hover\":1088}],1117:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),crossTraceDefaults:t(\"../histogram/cross_trace_defaults\"),calc:t(\"../heatmap/calc\"),plot:t(\"../heatmap/plot\"),layerName:\"heatmaplayer\",colorbar:t(\"../heatmap/colorbar\"),style:t(\"../heatmap/style\"),hoverPoints:t(\"./hover\"),eventData:t(\"../histogram/event_data\"),moduleType:\"trace\",name:\"histogram2d\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"2dMap\",\"histogram\",\"showLegend\"],meta:{}}},{\"../../plots/cartesian\":863,\"../heatmap/calc\":1082,\"../heatmap/colorbar\":1084,\"../heatmap/plot\":1092,\"../heatmap/style\":1093,\"../histogram/cross_trace_defaults\":1107,\"../histogram/event_data\":1109,\"./attributes\":1113,\"./defaults\":1115,\"./hover\":1116}],1118:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\");e.exports=function(t,e,r,a){var o=r(\"x\"),s=r(\"y\"),l=i.minRowLength(o),c=i.minRowLength(s);l&&c?(e._length=Math.min(l,c),n.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\",\"y\"],a),(r(\"z\")||r(\"marker.color\"))&&r(\"histfunc\"),r(\"histnorm\"),r(\"autobinx\"),r(\"autobiny\")):e.visible=!1}},{\"../../lib\":799,\"../../registry\":927}],1119:[function(t,e,r){\"use strict\";var n=t(\"../histogram2d/attributes\"),i=t(\"../contour/attributes\"),a=t(\"../../components/colorscale/attributes\"),o=t(\"../../plots/cartesian/axis_format_attributes\").axisHoverFormat,s=t(\"../../lib/extend\").extendFlat;e.exports=s({x:n.x,y:n.y,z:n.z,marker:n.marker,histnorm:n.histnorm,histfunc:n.histfunc,nbinsx:n.nbinsx,xbins:n.xbins,nbinsy:n.nbinsy,ybins:n.ybins,autobinx:n.autobinx,autobiny:n.autobiny,bingroup:n.bingroup,xbingroup:n.xbingroup,ybingroup:n.ybingroup,autocontour:i.autocontour,ncontours:i.ncontours,contours:i.contours,line:{color:i.line.color,width:s({},i.line.width,{dflt:.5}),dash:i.line.dash,smoothing:i.line.smoothing,editType:\"plot\"},xhoverformat:o(\"x\"),yhoverformat:o(\"y\"),zhoverformat:o(\"z\",1),hovertemplate:n.hovertemplate},a(\"\",{cLetter:\"z\",editTypeOverride:\"calc\"}))},{\"../../components/colorscale/attributes\":669,\"../../lib/extend\":789,\"../../plots/cartesian/axis_format_attributes\":852,\"../contour/attributes\":1024,\"../histogram2d/attributes\":1113}],1120:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../histogram2d/sample_defaults\"),a=t(\"../contour/contours_defaults\"),o=t(\"../contour/style_defaults\"),s=t(\"./attributes\");e.exports=function(t,e,r,l){function c(r,i){return n.coerce(t,e,s,r,i)}i(t,e,c,l),!1!==e.visible&&(a(t,e,c,(function(r){return n.coerce2(t,e,s,r)})),o(t,e,c,l),c(\"hovertemplate\"),c(\"xhoverformat\"),c(\"yhoverformat\"))}},{\"../../lib\":799,\"../contour/contours_defaults\":1031,\"../contour/style_defaults\":1045,\"../histogram2d/sample_defaults\":1118,\"./attributes\":1119}],1121:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),crossTraceDefaults:t(\"../histogram/cross_trace_defaults\"),calc:t(\"../contour/calc\"),plot:t(\"../contour/plot\").plot,layerName:\"contourlayer\",style:t(\"../contour/style\"),colorbar:t(\"../contour/colorbar\"),hoverPoints:t(\"../contour/hover\"),moduleType:\"trace\",name:\"histogram2dcontour\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"2dMap\",\"contour\",\"histogram\",\"showLegend\"],meta:{}}},{\"../../plots/cartesian\":863,\"../contour/calc\":1025,\"../contour/colorbar\":1027,\"../contour/hover\":1037,\"../contour/plot\":1042,\"../contour/style\":1044,\"../histogram/cross_trace_defaults\":1107,\"./attributes\":1119,\"./defaults\":1120}],1122:[function(t,e,r){\"use strict\";var n=t(\"../../plots/template_attributes\").hovertemplateAttrs,i=t(\"../../plots/template_attributes\").texttemplateAttrs,a=t(\"../../components/colorscale/attributes\"),o=t(\"../../plots/domain\").attributes,s=t(\"../pie/attributes\"),l=t(\"../sunburst/attributes\"),c=t(\"../treemap/attributes\"),u=t(\"../treemap/constants\"),f=t(\"../../lib/extend\").extendFlat;e.exports={labels:l.labels,parents:l.parents,values:l.values,branchvalues:l.branchvalues,count:l.count,level:l.level,maxdepth:l.maxdepth,tiling:{orientation:{valType:\"enumerated\",values:[\"v\",\"h\"],dflt:\"h\",editType:\"plot\"},flip:c.tiling.flip,pad:{valType:\"number\",min:0,dflt:0,editType:\"plot\"},editType:\"calc\"},marker:f({colors:l.marker.colors,line:l.marker.line,editType:\"calc\"},a(\"marker\",{colorAttr:\"colors\",anim:!1})),leaf:l.leaf,pathbar:c.pathbar,text:s.text,textinfo:l.textinfo,texttemplate:i({editType:\"plot\"},{keys:u.eventDataKeys.concat([\"label\",\"value\"])}),hovertext:s.hovertext,hoverinfo:l.hoverinfo,hovertemplate:n({},{keys:u.eventDataKeys}),textfont:s.textfont,insidetextfont:s.insidetextfont,outsidetextfont:c.outsidetextfont,textposition:c.textposition,sort:s.sort,root:l.root,domain:o({name:\"icicle\",trace:!0,editType:\"calc\"})}},{\"../../components/colorscale/attributes\":669,\"../../lib/extend\":789,\"../../plots/domain\":877,\"../../plots/template_attributes\":922,\"../pie/attributes\":1188,\"../sunburst/attributes\":1326,\"../treemap/attributes\":1352,\"../treemap/constants\":1355}],1123:[function(t,e,r){\"use strict\";var n=t(\"../../plots/plots\");r.name=\"icicle\",r.plot=function(t,e,i,a){n.plotBasePlot(r.name,t,e,i,a)},r.clean=function(t,e,i,a){n.cleanBasePlot(r.name,t,e,i,a)}},{\"../../plots/plots\":913}],1124:[function(t,e,r){\"use strict\";var n=t(\"../sunburst/calc\");r.calc=function(t,e){return n.calc(t,e)},r.crossTraceCalc=function(t){return n._runCrossTraceCalc(\"icicle\",t)}},{\"../sunburst/calc\":1328}],1125:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\"),a=t(\"../../components/color\"),o=t(\"../../plots/domain\").defaults,s=t(\"../bar/defaults\").handleText,l=t(\"../bar/constants\").TEXTPAD,c=t(\"../../components/colorscale\"),u=c.hasColorscale,f=c.handleDefaults;e.exports=function(t,e,r,c){function h(r,a){return n.coerce(t,e,i,r,a)}var p=h(\"labels\"),d=h(\"parents\");if(p&&p.length&&d&&d.length){var m=h(\"values\");m&&m.length?h(\"branchvalues\"):h(\"count\"),h(\"level\"),h(\"maxdepth\"),h(\"tiling.orientation\"),h(\"tiling.flip\"),h(\"tiling.pad\");var g=h(\"text\");h(\"texttemplate\"),e.texttemplate||h(\"textinfo\",Array.isArray(g)?\"text+label\":\"label\"),h(\"hovertext\"),h(\"hovertemplate\");var v=h(\"pathbar.visible\");s(t,e,c,h,\"auto\",{hasPathbar:v,moduleHasSelected:!1,moduleHasUnselected:!1,moduleHasConstrain:!1,moduleHasCliponaxis:!1,moduleHasTextangle:!1,moduleHasInsideanchor:!1}),h(\"textposition\"),h(\"marker.line.width\")&&h(\"marker.line.color\",c.paper_bgcolor),h(\"marker.colors\");var y=e._hasColorscale=u(t,\"marker\",\"colors\")||(t.marker||{}).coloraxis;y&&f(t,e,c,h,{prefix:\"marker.\",cLetter:\"c\"}),h(\"leaf.opacity\",y?1:.7),e._hovered={marker:{line:{width:2,color:a.contrast(c.paper_bgcolor)}}},v&&(h(\"pathbar.thickness\",e.pathbar.textfont.size+2*l),h(\"pathbar.side\"),h(\"pathbar.edgeshape\")),h(\"sort\"),h(\"root.color\"),o(e,c,h),e._length=null}else e.visible=!1}},{\"../../components/color\":662,\"../../components/colorscale\":674,\"../../lib\":799,\"../../plots/domain\":877,\"../bar/constants\":939,\"../bar/defaults\":941,\"./attributes\":1122}],1126:[function(t,e,r){\"use strict\";var n=t(\"@plotly/d3\"),i=t(\"../../lib\"),a=t(\"../../components/drawing\"),o=t(\"../../lib/svg_text_utils\"),s=t(\"./partition\"),l=t(\"./style\").styleOne,c=t(\"../treemap/constants\"),u=t(\"../sunburst/helpers\"),f=t(\"../sunburst/fx\"),h=t(\"../sunburst/plot\").formatSliceLabel;e.exports=function(t,e,r,p,d){var m=d.width,g=d.height,v=d.viewX,y=d.viewY,x=d.pathSlice,b=d.toMoveInsideSlice,_=d.strTransform,w=d.hasTransition,T=d.handleSlicesExit,k=d.makeUpdateSliceInterpolator,M=d.makeUpdateTextInterpolator,A=d.prevEntry,S=t._fullLayout,E=e[0].trace,L=-1!==E.textposition.indexOf(\"left\"),C=-1!==E.textposition.indexOf(\"right\"),P=-1!==E.textposition.indexOf(\"bottom\"),I=s(r,[m,g],{flipX:E.tiling.flip.indexOf(\"x\")>-1,flipY:E.tiling.flip.indexOf(\"y\")>-1,orientation:E.tiling.orientation,pad:{inner:E.tiling.pad},maxDepth:E._maxDepth}).descendants(),O=1/0,z=-1/0;I.forEach((function(t){var e=t.depth;e>=E._maxDepth?(t.x0=t.x1=(t.x0+t.x1)/2,t.y0=t.y1=(t.y0+t.y1)/2):(O=Math.min(O,e),z=Math.max(z,e))})),p=p.data(I,u.getPtId),E._maxVisibleLayers=isFinite(z)?z-O+1:0,p.enter().append(\"g\").classed(\"slice\",!0),T(p,!1,{},[m,g],x),p.order();var D=null;if(w&&A){var R=u.getPtId(A);p.each((function(t){null===D&&u.getPtId(t)===R&&(D={x0:t.x0,x1:t.x1,y0:t.y0,y1:t.y1})}))}var F=function(){return D||{x0:0,x1:m,y0:0,y1:g}},B=p;return w&&(B=B.transition().each(\"end\",(function(){var e=n.select(this);u.setSliceCursor(e,t,{hideOnRoot:!0,hideOnLeaves:!1,isTransitioning:!1})}))),B.each((function(s){s._hoverX=v(s.x1-E.tiling.pad),s._hoverY=y(P?s.y1-E.tiling.pad/2:s.y0+E.tiling.pad/2);var p=n.select(this),d=i.ensureSingle(p,\"path\",\"surface\",(function(t){t.style(\"pointer-events\",\"all\")}));w?d.transition().attrTween(\"d\",(function(t){var e=k(t,!1,F(),[m,g],{orientation:E.tiling.orientation,flipX:E.tiling.flip.indexOf(\"x\")>-1,flipY:E.tiling.flip.indexOf(\"y\")>-1});return function(t){return x(e(t))}})):d.attr(\"d\",x),p.call(f,r,t,e,{styleOne:l,eventDataKeys:c.eventDataKeys,transitionTime:c.CLICK_TRANSITION_TIME,transitionEasing:c.CLICK_TRANSITION_EASING}).call(u.setSliceCursor,t,{isTransitioning:t._transitioning}),d.call(l,s,E,{hovered:!1}),s.x0===s.x1||s.y0===s.y1?s._text=\"\":s._text=h(s,r,E,e,S)||\"\";var T=i.ensureSingle(p,\"g\",\"slicetext\"),A=i.ensureSingle(T,\"text\",\"\",(function(t){t.attr(\"data-notex\",1)})),I=i.ensureUniformFontSize(t,u.determineTextFont(E,s,S.font));A.text(s._text||\" \").classed(\"slicetext\",!0).attr(\"text-anchor\",C?\"end\":L?\"start\":\"middle\").call(a.font,I).call(o.convertToTspans,t),s.textBB=a.bBox(A.node()),s.transform=b(s,{fontSize:I.size}),s.transform.fontSize=I.size,w?A.transition().attrTween(\"transform\",(function(t){var e=M(t,!1,F(),[m,g]);return function(t){return _(e(t))}})):A.attr(\"transform\",_(s))})),D}},{\"../../components/drawing\":684,\"../../lib\":799,\"../../lib/svg_text_utils\":824,\"../sunburst/fx\":1331,\"../sunburst/helpers\":1332,\"../sunburst/plot\":1336,\"../treemap/constants\":1355,\"./partition\":1130,\"./style\":1132,\"@plotly/d3\":58}],1127:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"icicle\",basePlotModule:t(\"./base_plot\"),categories:[],animatable:!0,attributes:t(\"./attributes\"),layoutAttributes:t(\"./layout_attributes\"),supplyDefaults:t(\"./defaults\"),supplyLayoutDefaults:t(\"./layout_defaults\"),calc:t(\"./calc\").calc,crossTraceCalc:t(\"./calc\").crossTraceCalc,plot:t(\"./plot\"),style:t(\"./style\").style,colorbar:t(\"../scatter/marker_colorbar\"),meta:{}}},{\"../scatter/marker_colorbar\":1232,\"./attributes\":1122,\"./base_plot\":1123,\"./calc\":1124,\"./defaults\":1125,\"./layout_attributes\":1128,\"./layout_defaults\":1129,\"./plot\":1131,\"./style\":1132}],1128:[function(t,e,r){\"use strict\";e.exports={iciclecolorway:{valType:\"colorlist\",editType:\"calc\"},extendiciclecolors:{valType:\"boolean\",dflt:!0,editType:\"calc\"}}},{}],1129:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\");e.exports=function(t,e){function r(r,a){return n.coerce(t,e,i,r,a)}r(\"iciclecolorway\",e.colorway),r(\"extendiciclecolors\")}},{\"../../lib\":799,\"./layout_attributes\":1128}],1130:[function(t,e,r){\"use strict\";var n=t(\"d3-hierarchy\"),i=t(\"../treemap/flip_tree\");e.exports=function(t,e,r){var a=r.flipX,o=r.flipY,s=\"h\"===r.orientation,l=r.maxDepth,c=e[0],u=e[1];l&&(c=(t.height+1)*e[0]/Math.min(t.height+1,l),u=(t.height+1)*e[1]/Math.min(t.height+1,l));var f=n.partition().padding(r.pad.inner).size(s?[e[1],c]:[e[0],u])(t);return(s||a||o)&&i(f,e,{swapXY:s,flipX:a,flipY:o}),f}},{\"../treemap/flip_tree\":1360,\"d3-hierarchy\":167}],1131:[function(t,e,r){\"use strict\";var n=t(\"../treemap/draw\"),i=t(\"./draw_descendants\");e.exports=function(t,e,r,a){return n(t,e,r,a,{type:\"icicle\",drawDescendants:i})}},{\"../treemap/draw\":1357,\"./draw_descendants\":1126}],1132:[function(t,e,r){\"use strict\";var n=t(\"@plotly/d3\"),i=t(\"../../components/color\"),a=t(\"../../lib\"),o=t(\"../bar/uniform_text\").resizeText;function s(t,e,r){var n=e.data.data,o=!e.children,s=n.i,l=a.castOption(r,s,\"marker.line.color\")||i.defaultLine,c=a.castOption(r,s,\"marker.line.width\")||0;t.style(\"stroke-width\",c).call(i.fill,n.color).call(i.stroke,l).style(\"opacity\",o?r.leaf.opacity:null)}e.exports={style:function(t){var e=t._fullLayout._iciclelayer.selectAll(\".trace\");o(t,e,\"icicle\"),e.each((function(t){var e=n.select(this),r=t[0].trace;e.style(\"opacity\",r.opacity),e.selectAll(\"path.surface\").each((function(t){n.select(this).call(s,t,r)}))}))},styleOne:s}},{\"../../components/color\":662,\"../../lib\":799,\"../bar/uniform_text\":953,\"@plotly/d3\":58}],1133:[function(t,e,r){\"use strict\";for(var n=t(\"../../plots/attributes\"),i=t(\"../../plots/template_attributes\").hovertemplateAttrs,a=t(\"../../lib/extend\").extendFlat,o=t(\"./constants\").colormodel,s=[\"rgb\",\"rgba\",\"rgba256\",\"hsl\",\"hsla\"],l=[],c=[],u=0;u<s.length;u++){var f=o[s[u]];l.push(\"For the `\"+s[u]+\"` colormodel, it is [\"+(f.zminDflt||f.min).join(\", \")+\"].\"),c.push(\"For the `\"+s[u]+\"` colormodel, it is [\"+(f.zmaxDflt||f.max).join(\", \")+\"].\")}e.exports=a({source:{valType:\"string\",editType:\"calc\"},z:{valType:\"data_array\",editType:\"calc\"},colormodel:{valType:\"enumerated\",values:s,editType:\"calc\"},zsmooth:{valType:\"enumerated\",values:[\"fast\",!1],dflt:!1,editType:\"plot\"},zmin:{valType:\"info_array\",items:[{valType:\"number\",editType:\"calc\"},{valType:\"number\",editType:\"calc\"},{valType:\"number\",editType:\"calc\"},{valType:\"number\",editType:\"calc\"}],editType:\"calc\"},zmax:{valType:\"info_array\",items:[{valType:\"number\",editType:\"calc\"},{valType:\"number\",editType:\"calc\"},{valType:\"number\",editType:\"calc\"},{valType:\"number\",editType:\"calc\"}],editType:\"calc\"},x0:{valType:\"any\",dflt:0,editType:\"calc+clearAxisTypes\"},y0:{valType:\"any\",dflt:0,editType:\"calc+clearAxisTypes\"},dx:{valType:\"number\",dflt:1,editType:\"calc\"},dy:{valType:\"number\",dflt:1,editType:\"calc\"},text:{valType:\"data_array\",editType:\"plot\"},hovertext:{valType:\"data_array\",editType:\"plot\"},hoverinfo:a({},n.hoverinfo,{flags:[\"x\",\"y\",\"z\",\"color\",\"name\",\"text\"],dflt:\"x+y+z+text+name\"}),hovertemplate:i({},{keys:[\"z\",\"color\",\"colormodel\"]}),transforms:void 0})},{\"../../lib/extend\":789,\"../../plots/attributes\":845,\"../../plots/template_attributes\":922,\"./constants\":1135}],1134:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./constants\"),a=t(\"fast-isnumeric\"),o=t(\"../../plots/cartesian/axes\"),s=t(\"../../lib\").maxRowLength,l=t(\"./helpers\").getImageSize;function c(t,e,r,i){return function(a){return n.constrain((a-t)*e,r,i)}}function u(t,e){return function(r){return n.constrain(r,t,e)}}e.exports=function(t,e){var r,n;if(e._hasZ)r=e.z.length,n=s(e.z);else if(e._hasSource){var f=l(e.source);r=f.height,n=f.width}var h,p=o.getFromId(t,e.xaxis||\"x\"),d=o.getFromId(t,e.yaxis||\"y\"),m=p.d2c(e.x0)-e.dx/2,g=d.d2c(e.y0)-e.dy/2,v=[m,m+n*e.dx],y=[g,g+r*e.dy];if(p&&\"log\"===p.type)for(h=0;h<n;h++)v.push(m+h*e.dx);if(d&&\"log\"===d.type)for(h=0;h<r;h++)y.push(g+h*e.dy);return e._extremes[p._id]=o.findExtremes(p,v),e._extremes[d._id]=o.findExtremes(d,y),e._scaler=function(t){var e=i.colormodel[t.colormodel],r=(e.colormodel||t.colormodel).length;t._sArray=[];for(var n=0;n<r;n++)e.min[n]!==t.zmin[n]||e.max[n]!==t.zmax[n]?t._sArray.push(c(t.zmin[n],(e.max[n]-e.min[n])/(t.zmax[n]-t.zmin[n]),e.min[n],e.max[n])):t._sArray.push(u(e.min[n],e.max[n]));return function(e){for(var n=e.slice(0,r),i=0;i<r;i++){var o=n[i];if(!a(o))return!1;n[i]=t._sArray[i](o)}return n}}(e),[{x0:m,y0:g,z:e.z,w:n,h:r}]}},{\"../../lib\":799,\"../../plots/cartesian/axes\":849,\"./constants\":1135,\"./helpers\":1138,\"fast-isnumeric\":245}],1135:[function(t,e,r){\"use strict\";e.exports={colormodel:{rgb:{min:[0,0,0],max:[255,255,255],fmt:function(t){return t.slice(0,3)},suffix:[\"\",\"\",\"\"]},rgba:{min:[0,0,0,0],max:[255,255,255,1],fmt:function(t){return t.slice(0,4)},suffix:[\"\",\"\",\"\",\"\"]},rgba256:{colormodel:\"rgba\",zminDflt:[0,0,0,0],zmaxDflt:[255,255,255,255],min:[0,0,0,0],max:[255,255,255,1],fmt:function(t){return t.slice(0,4)},suffix:[\"\",\"\",\"\",\"\"]},hsl:{min:[0,0,0],max:[360,100,100],fmt:function(t){var e=t.slice(0,3);return e[1]=e[1]+\"%\",e[2]=e[2]+\"%\",e},suffix:[\"\\xb0\",\"%\",\"%\"]},hsla:{min:[0,0,0,0],max:[360,100,100,1],fmt:function(t){var e=t.slice(0,4);return e[1]=e[1]+\"%\",e[2]=e[2]+\"%\",e},suffix:[\"\\xb0\",\"%\",\"%\",\"\"]}},pixelatedStyle:[\"image-rendering: optimizeSpeed\",\"image-rendering: -moz-crisp-edges\",\"image-rendering: -o-crisp-edges\",\"image-rendering: -webkit-optimize-contrast\",\"image-rendering: optimize-contrast\",\"image-rendering: crisp-edges\",\"image-rendering: pixelated\",\"\"].join(\"; \")}},{}],1136:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\"),a=t(\"./constants\"),o=t(\"../../snapshot/helpers\").IMAGE_URL_PREFIX;e.exports=function(t,e){function r(r,a){return n.coerce(t,e,i,r,a)}r(\"source\"),e.source&&!e.source.match(o)&&delete e.source,e._hasSource=!!e.source;var s,l=r(\"z\");(e._hasZ=!(void 0===l||!l.length||!l[0]||!l[0].length),e._hasZ||e._hasSource)?(r(\"x0\"),r(\"y0\"),r(\"dx\"),r(\"dy\"),e._hasZ?(r(\"colormodel\",\"rgb\"),r(\"zmin\",(s=a.colormodel[e.colormodel]).zminDflt||s.min),r(\"zmax\",s.zmaxDflt||s.max)):e._hasSource&&(e.colormodel=\"rgba256\",s=a.colormodel[e.colormodel],e.zmin=s.zminDflt,e.zmax=s.zmaxDflt),r(\"zsmooth\"),r(\"text\"),r(\"hovertext\"),r(\"hovertemplate\"),e._length=null):e.visible=!1}},{\"../../lib\":799,\"../../snapshot/helpers\":931,\"./attributes\":1133,\"./constants\":1135}],1137:[function(t,e,r){\"use strict\";e.exports=function(t,e){return\"xVal\"in e&&(t.x=e.xVal),\"yVal\"in e&&(t.y=e.yVal),e.xa&&(t.xaxis=e.xa),e.ya&&(t.yaxis=e.ya),t.color=e.color,t.colormodel=e.trace.colormodel,t.z||(t.z=e.color),t}},{}],1138:[function(t,e,r){\"use strict\";var n=t(\"probe-image-size/sync\"),i=t(\"../../snapshot/helpers\").IMAGE_URL_PREFIX,a=t(\"buffer/\").Buffer;r.getImageSize=function(t){var e=t.replace(i,\"\"),r=new a(e,\"base64\");return n(r)}},{\"../../snapshot/helpers\":931,\"buffer/\":117,\"probe-image-size/sync\":523}],1139:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx\"),i=t(\"../../lib\"),a=t(\"./constants\");e.exports=function(t,e,r){var o=t.cd[0],s=o.trace,l=t.xa,c=t.ya;if(!(n.inbox(e-o.x0,e-(o.x0+o.w*s.dx),0)>0||n.inbox(r-o.y0,r-(o.y0+o.h*s.dy),0)>0)){var u,f=Math.floor((e-o.x0)/s.dx),h=Math.floor(Math.abs(r-o.y0)/s.dy);if(s._hasZ?u=o.z[h][f]:s._hasSource&&(u=s._canvas.el.getContext(\"2d\").getImageData(f,h,1,1).data),u){var p,d=o.hi||s.hoverinfo;if(d){var m=d.split(\"+\");-1!==m.indexOf(\"all\")&&(m=[\"color\"]),-1!==m.indexOf(\"color\")&&(p=!0)}var g,v=a.colormodel[s.colormodel],y=v.colormodel||s.colormodel,x=y.length,b=s._scaler(u),_=v.suffix,w=[];(s.hovertemplate||p)&&(w.push(\"[\"+[b[0]+_[0],b[1]+_[1],b[2]+_[2]].join(\", \")),4===x&&w.push(\", \"+b[3]+_[3]),w.push(\"]\"),w=w.join(\"\"),t.extraText=y.toUpperCase()+\": \"+w),Array.isArray(s.hovertext)&&Array.isArray(s.hovertext[h])?g=s.hovertext[h][f]:Array.isArray(s.text)&&Array.isArray(s.text[h])&&(g=s.text[h][f]);var T=c.c2p(o.y0+(h+.5)*s.dy),k=o.x0+(f+.5)*s.dx,M=o.y0+(h+.5)*s.dy,A=\"[\"+u.slice(0,s.colormodel.length).join(\", \")+\"]\";return[i.extendFlat(t,{index:[h,f],x0:l.c2p(o.x0+f*s.dx),x1:l.c2p(o.x0+(f+1)*s.dx),y0:T,y1:T,color:b,xVal:k,xLabelVal:k,yVal:M,yLabelVal:M,zLabelVal:A,text:g,hovertemplateLabels:{zLabel:A,colorLabel:w,\"color[0]Label\":b[0]+_[0],\"color[1]Label\":b[1]+_[1],\"color[2]Label\":b[2]+_[2],\"color[3]Label\":b[3]+_[3]}})]}}}},{\"../../components/fx\":702,\"../../lib\":799,\"./constants\":1135}],1140:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\"),plot:t(\"./plot\"),style:t(\"./style\"),hoverPoints:t(\"./hover\"),eventData:t(\"./event_data\"),moduleType:\"trace\",name:\"image\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"2dMap\",\"noSortingByValue\"],animatable:!1,meta:{}}},{\"../../plots/cartesian\":863,\"./attributes\":1133,\"./calc\":1134,\"./defaults\":1136,\"./event_data\":1137,\"./hover\":1139,\"./plot\":1141,\"./style\":1142}],1141:[function(t,e,r){\"use strict\";var n=t(\"@plotly/d3\"),i=t(\"../../lib\"),a=i.strTranslate,o=t(\"../../constants/xmlns_namespaces\"),s=t(\"./constants\"),l=i.isIOS()||i.isSafari()||i.isIE();e.exports=function(t,e,r,c){var u=e.xaxis,f=e.yaxis,h=!(l||t._context._exportedPlot);i.makeTraceGroups(c,r,\"im\").each((function(e){var r=n.select(this),l=e[0],c=l.trace,p=(\"fast\"===c.zsmooth||!1===c.zsmooth&&h)&&!c._hasZ&&c._hasSource&&\"linear\"===u.type&&\"linear\"===f.type;c._realImage=p;var d,m,g,v,y,x,b=l.z,_=l.x0,w=l.y0,T=l.w,k=l.h,M=c.dx,A=c.dy;for(x=0;void 0===d&&x<T;)d=u.c2p(_+x*M),x++;for(x=T;void 0===m&&x>0;)m=u.c2p(_+x*M),x--;for(x=0;void 0===v&&x<k;)v=f.c2p(w+x*A),x++;for(x=k;void 0===y&&x>0;)y=f.c2p(w+x*A),x--;if(m<d&&(g=m,m=d,d=g),y<v&&(g=v,v=y,y=g),!p){d=Math.max(-.5*u._length,d),m=Math.min(1.5*u._length,m),v=Math.max(-.5*f._length,v),y=Math.min(1.5*f._length,y)}var S=Math.round(m-d),E=Math.round(y-v);if(S<=0||E<=0){r.selectAll(\"image\").data([]).exit().remove()}else{var L=r.selectAll(\"image\").data([e]);L.enter().append(\"svg:image\").attr({xmlns:o.svg,preserveAspectRatio:\"none\"}),L.exit().remove();var C=!1===c.zsmooth?s.pixelatedStyle:\"\";if(p){var P=i.simpleMap(u.range,u.r2l),I=i.simpleMap(f.range,f.r2l),O=P[1]<P[0],z=I[1]>I[0];if(O||z){var D=d+S/2,R=v+E/2;C+=\"transform:\"+a(D+\"px\",R+\"px\")+\"scale(\"+(O?-1:1)+\",\"+(z?-1:1)+\")\"+a(-D+\"px\",-R+\"px\")+\";\"}}L.attr(\"style\",C);var F=new Promise((function(t){if(c._hasZ)t();else if(c._hasSource)if(c._canvas&&c._canvas.el.width===T&&c._canvas.el.height===k&&c._canvas.source===c.source)t();else{var e=document.createElement(\"canvas\");e.width=T,e.height=k;var r=e.getContext(\"2d\");c._image=c._image||new Image;var n=c._image;n.onload=function(){r.drawImage(n,0,0),c._canvas={el:e,source:c.source},t()},n.setAttribute(\"src\",c.source)}})).then((function(){var t;if(c._hasZ)t=B((function(t,e){return b[e][t]})).toDataURL(\"image/png\");else if(c._hasSource)if(p)t=c.source;else{var e=c._canvas.el.getContext(\"2d\").getImageData(0,0,T,k).data;t=B((function(t,r){var n=4*(r*T+t);return[e[n],e[n+1],e[n+2],e[n+3]]})).toDataURL(\"image/png\")}L.attr({\"xlink:href\":t,height:E,width:S,x:d,y:v})}));t._promises.push(F)}function B(t){var e=document.createElement(\"canvas\");e.width=S,e.height=E;var r,n=e.getContext(\"2d\"),a=function(t){return i.constrain(Math.round(u.c2p(_+t*M)-d),0,S)},o=function(t){return i.constrain(Math.round(f.c2p(w+t*A)-v),0,E)},h=s.colormodel[c.colormodel],p=h.colormodel||c.colormodel,m=h.fmt;for(x=0;x<l.w;x++){var g=a(x),y=a(x+1);if(y!==g&&!isNaN(y)&&!isNaN(g))for(var b=0;b<l.h;b++){var T=o(b),k=o(b+1);k===T||isNaN(k)||isNaN(T)||!t(x,b)||(r=c._scaler(t(x,b)),n.fillStyle=r?p+\"(\"+m(r).join(\",\")+\")\":\"rgba(0,0,0,0)\",n.fillRect(g,T,y-g,k-T))}}return e}}))}},{\"../../constants/xmlns_namespaces\":776,\"../../lib\":799,\"./constants\":1135,\"@plotly/d3\":58}],1142:[function(t,e,r){\"use strict\";var n=t(\"@plotly/d3\");e.exports=function(t){n.select(t).selectAll(\".im image\").style(\"opacity\",(function(t){return t[0].trace.opacity}))}},{\"@plotly/d3\":58}],1143:[function(t,e,r){\"use strict\";var n=t(\"../../lib/extend\").extendFlat,i=t(\"../../lib/extend\").extendDeep,a=t(\"../../plot_api/edit_types\").overrideAll,o=t(\"../../plots/font_attributes\"),s=t(\"../../components/color/attributes\"),l=t(\"../../plots/domain\").attributes,c=t(\"../../plots/cartesian/layout_attributes\"),u=t(\"../../plot_api/plot_template\").templatedArray,f=t(\"../../constants/delta.js\"),h=t(\"../../plots/cartesian/axis_format_attributes\").descriptionOnlyNumbers,p=o({editType:\"plot\",colorEditType:\"plot\"}),d={color:{valType:\"color\",editType:\"plot\"},line:{color:{valType:\"color\",dflt:s.defaultLine,editType:\"plot\"},width:{valType:\"number\",min:0,dflt:0,editType:\"plot\"},editType:\"calc\"},thickness:{valType:\"number\",min:0,max:1,dflt:1,editType:\"plot\"},editType:\"calc\"},m={valType:\"info_array\",items:[{valType:\"number\",editType:\"plot\"},{valType:\"number\",editType:\"plot\"}],editType:\"plot\"},g=u(\"step\",i({},d,{range:m}));e.exports={mode:{valType:\"flaglist\",editType:\"calc\",flags:[\"number\",\"delta\",\"gauge\"],dflt:\"number\"},value:{valType:\"number\",editType:\"calc\",anim:!0},align:{valType:\"enumerated\",values:[\"left\",\"center\",\"right\"],editType:\"plot\"},domain:l({name:\"indicator\",trace:!0,editType:\"calc\"}),title:{text:{valType:\"string\",editType:\"plot\"},align:{valType:\"enumerated\",values:[\"left\",\"center\",\"right\"],editType:\"plot\"},font:n({},p,{}),editType:\"plot\"},number:{valueformat:{valType:\"string\",dflt:\"\",editType:\"plot\",description:h(\"value\")},font:n({},p,{}),prefix:{valType:\"string\",dflt:\"\",editType:\"plot\"},suffix:{valType:\"string\",dflt:\"\",editType:\"plot\"},editType:\"plot\"},delta:{reference:{valType:\"number\",editType:\"calc\"},position:{valType:\"enumerated\",values:[\"top\",\"bottom\",\"left\",\"right\"],dflt:\"bottom\",editType:\"plot\"},relative:{valType:\"boolean\",editType:\"plot\",dflt:!1},valueformat:{valType:\"string\",editType:\"plot\",description:h(\"value\")},increasing:{symbol:{valType:\"string\",dflt:f.INCREASING.SYMBOL,editType:\"plot\"},color:{valType:\"color\",dflt:f.INCREASING.COLOR,editType:\"plot\"},editType:\"plot\"},decreasing:{symbol:{valType:\"string\",dflt:f.DECREASING.SYMBOL,editType:\"plot\"},color:{valType:\"color\",dflt:f.DECREASING.COLOR,editType:\"plot\"},editType:\"plot\"},font:n({},p,{}),editType:\"calc\"},gauge:{shape:{valType:\"enumerated\",editType:\"plot\",dflt:\"angular\",values:[\"angular\",\"bullet\"]},bar:i({},d,{color:{dflt:\"green\"}}),bgcolor:{valType:\"color\",editType:\"plot\"},bordercolor:{valType:\"color\",dflt:s.defaultLine,editType:\"plot\"},borderwidth:{valType:\"number\",min:0,dflt:1,editType:\"plot\"},axis:a({range:m,visible:n({},c.visible,{dflt:!0}),tickmode:c.tickmode,nticks:c.nticks,tick0:c.tick0,dtick:c.dtick,tickvals:c.tickvals,ticktext:c.ticktext,ticks:n({},c.ticks,{dflt:\"outside\"}),ticklen:c.ticklen,tickwidth:c.tickwidth,tickcolor:c.tickcolor,showticklabels:c.showticklabels,tickfont:o({}),tickangle:c.tickangle,tickformat:c.tickformat,tickformatstops:c.tickformatstops,tickprefix:c.tickprefix,showtickprefix:c.showtickprefix,ticksuffix:c.ticksuffix,showticksuffix:c.showticksuffix,separatethousands:c.separatethousands,exponentformat:c.exponentformat,minexponent:c.minexponent,showexponent:c.showexponent,editType:\"plot\"},\"plot\"),steps:g,threshold:{line:{color:n({},d.line.color,{}),width:n({},d.line.width,{dflt:1}),editType:\"plot\"},thickness:n({},d.thickness,{dflt:.85}),value:{valType:\"number\",editType:\"calc\",dflt:!1},editType:\"plot\"},editType:\"plot\"}}},{\"../../components/color/attributes\":661,\"../../constants/delta.js\":769,\"../../lib/extend\":789,\"../../plot_api/edit_types\":831,\"../../plot_api/plot_template\":838,\"../../plots/cartesian/axis_format_attributes\":852,\"../../plots/cartesian/layout_attributes\":864,\"../../plots/domain\":877,\"../../plots/font_attributes\":878}],1144:[function(t,e,r){\"use strict\";var n=t(\"../../plots/plots\");r.name=\"indicator\",r.plot=function(t,e,i,a){n.plotBasePlot(r.name,t,e,i,a)},r.clean=function(t,e,i,a){n.cleanBasePlot(r.name,t,e,i,a)}},{\"../../plots/plots\":913}],1145:[function(t,e,r){\"use strict\";e.exports={calc:function(t,e){var r=[],n=e.value;\"number\"!=typeof e._lastValue&&(e._lastValue=e.value);var i=e._lastValue,a=i;return e._hasDelta&&\"number\"==typeof e.delta.reference&&(a=e.delta.reference),r[0]={y:n,lastY:i,delta:n-a,relativeDelta:(n-a)/a},r}}},{}],1146:[function(t,e,r){\"use strict\";e.exports={defaultNumberFontSize:80,bulletNumberDomainSize:.25,bulletPadding:.025,innerRadius:.75,valueThickness:.5,titlePadding:5,horizontalPadding:10}},{}],1147:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\"),a=t(\"../../plots/domain\").defaults,o=t(\"../../plot_api/plot_template\"),s=t(\"../../plots/array_container_defaults\"),l=t(\"./constants.js\"),c=t(\"../../plots/cartesian/tick_value_defaults\"),u=t(\"../../plots/cartesian/tick_mark_defaults\"),f=t(\"../../plots/cartesian/tick_label_defaults\");function h(t,e){function r(r,a){return n.coerce(t,e,i.gauge.steps,r,a)}r(\"color\"),r(\"line.color\"),r(\"line.width\"),r(\"range\"),r(\"thickness\")}e.exports={supplyDefaults:function(t,e,r,p){function d(r,a){return n.coerce(t,e,i,r,a)}a(e,p,d),d(\"mode\"),e._hasNumber=-1!==e.mode.indexOf(\"number\"),e._hasDelta=-1!==e.mode.indexOf(\"delta\"),e._hasGauge=-1!==e.mode.indexOf(\"gauge\");var m=d(\"value\");e._range=[0,\"number\"==typeof m?1.5*m:1];var g,v,y,x,b,_,w=new Array(2);function T(t,e){return n.coerce(y,x,i.gauge,t,e)}function k(t,e){return n.coerce(b,_,i.gauge.axis,t,e)}if(e._hasNumber&&(d(\"number.valueformat\"),d(\"number.font.color\",p.font.color),d(\"number.font.family\",p.font.family),d(\"number.font.size\"),void 0===e.number.font.size&&(e.number.font.size=l.defaultNumberFontSize,w[0]=!0),d(\"number.prefix\"),d(\"number.suffix\"),g=e.number.font.size),e._hasDelta&&(d(\"delta.font.color\",p.font.color),d(\"delta.font.family\",p.font.family),d(\"delta.font.size\"),void 0===e.delta.font.size&&(e.delta.font.size=(e._hasNumber?.5:1)*(g||l.defaultNumberFontSize),w[1]=!0),d(\"delta.reference\",e.value),d(\"delta.relative\"),d(\"delta.valueformat\",e.delta.relative?\"2%\":\"\"),d(\"delta.increasing.symbol\"),d(\"delta.increasing.color\"),d(\"delta.decreasing.symbol\"),d(\"delta.decreasing.color\"),d(\"delta.position\"),v=e.delta.font.size),e._scaleNumbers=(!e._hasNumber||w[0])&&(!e._hasDelta||w[1])||!1,d(\"title.font.color\",p.font.color),d(\"title.font.family\",p.font.family),d(\"title.font.size\",.25*(g||v||l.defaultNumberFontSize)),d(\"title.text\"),e._hasGauge){(y=t.gauge)||(y={}),x=o.newContainer(e,\"gauge\"),T(\"shape\"),(e._isBullet=\"bullet\"===e.gauge.shape)||d(\"title.align\",\"center\"),(e._isAngular=\"angular\"===e.gauge.shape)||d(\"align\",\"center\"),T(\"bgcolor\",p.paper_bgcolor),T(\"borderwidth\"),T(\"bordercolor\"),T(\"bar.color\"),T(\"bar.line.color\"),T(\"bar.line.width\"),T(\"bar.thickness\",l.valueThickness*(\"bullet\"===e.gauge.shape?.5:1)),s(y,x,{name:\"steps\",handleItemDefaults:h}),T(\"threshold.value\"),T(\"threshold.thickness\"),T(\"threshold.line.width\"),T(\"threshold.line.color\"),b={},y&&(b=y.axis||{}),_=o.newContainer(x,\"axis\"),k(\"visible\"),e._range=k(\"range\",e._range);var M={outerTicks:!0};c(b,_,k,\"linear\"),f(b,_,k,\"linear\",M),u(b,_,k,M)}else d(\"title.align\",\"center\"),d(\"align\",\"center\"),e._isAngular=e._isBullet=!1;e._length=null}}},{\"../../lib\":799,\"../../plot_api/plot_template\":838,\"../../plots/array_container_defaults\":844,\"../../plots/cartesian/tick_label_defaults\":871,\"../../plots/cartesian/tick_mark_defaults\":872,\"../../plots/cartesian/tick_value_defaults\":873,\"../../plots/domain\":877,\"./attributes\":1143,\"./constants.js\":1146}],1148:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"indicator\",basePlotModule:t(\"./base_plot\"),categories:[\"svg\",\"noOpacity\",\"noHover\"],animatable:!0,attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\").supplyDefaults,calc:t(\"./calc\").calc,plot:t(\"./plot\"),meta:{}}},{\"./attributes\":1143,\"./base_plot\":1144,\"./calc\":1145,\"./defaults\":1147,\"./plot\":1149}],1149:[function(t,e,r){\"use strict\";var n=t(\"@plotly/d3\"),i=t(\"../../lib\"),a=i.strScale,o=i.strTranslate,s=i.rad2deg,l=t(\"../../constants/alignment\").MID_SHIFT,c=t(\"../../components/drawing\"),u=t(\"./constants\"),f=t(\"../../lib/svg_text_utils\"),h=t(\"../../plots/cartesian/axes\"),p=t(\"../../plots/cartesian/axis_defaults\"),d=t(\"../../plots/cartesian/position_defaults\"),m=t(\"../../plots/cartesian/layout_attributes\"),g=t(\"../../components/color\"),v={left:\"start\",center:\"middle\",right:\"end\"},y={left:0,center:.5,right:1},x=/[yzafpn\\xb5mkMGTPEZY]/;function b(t){return t&&t.duration>0}function _(t){t.each((function(t){g.stroke(n.select(this),t.line.color)})).each((function(t){g.fill(n.select(this),t.color)})).style(\"stroke-width\",(function(t){return t.line.width}))}function w(t,e,r){var n=t._fullLayout,a=i.extendFlat({type:\"linear\",ticks:\"outside\",range:r,showline:!0},e),o={type:\"linear\",_id:\"x\"+e._id},s={letter:\"x\",font:n.font,noHover:!0,noTickson:!0};function l(t,e){return i.coerce(a,o,m,t,e)}return p(a,o,l,s,n),d(a,o,l,s),o}function T(t,e,r){return[Math.min(e/t.width,r/t.height),t,e+\"x\"+r]}function k(t,e,r,i){var a=document.createElementNS(\"http://www.w3.org/2000/svg\",\"text\"),o=n.select(a);return o.text(t).attr(\"x\",0).attr(\"y\",0).attr(\"text-anchor\",r).attr(\"data-unformatted\",t).call(f.convertToTspans,i).call(c.font,e),c.bBox(o.node())}function M(t,e,r,n,a,o){var s=\"_cache\"+e;t[s]&&t[s].key===a||(t[s]={key:a,value:r});var l=i.aggNums(o,null,[t[s].value,n],2);return t[s].value=l,l}e.exports=function(t,e,r,p){var d,m=t._fullLayout;b(r)&&p&&(d=p()),i.makeTraceGroups(m._indicatorlayer,e,\"trace\").each((function(e){var p,A,S,E,L,C=e[0].trace,P=n.select(this),I=C._hasGauge,O=C._isAngular,z=C._isBullet,D=C.domain,R={w:m._size.w*(D.x[1]-D.x[0]),h:m._size.h*(D.y[1]-D.y[0]),l:m._size.l+m._size.w*D.x[0],r:m._size.r+m._size.w*(1-D.x[1]),t:m._size.t+m._size.h*(1-D.y[1]),b:m._size.b+m._size.h*D.y[0]},F=R.l+R.w/2,B=R.t+R.h/2,N=Math.min(R.w/2,R.h),j=u.innerRadius*N,U=C.align||\"center\";if(A=B,I){if(O&&(p=F,A=B+N/2,S=function(t){return function(t,e){var r=Math.sqrt(t.width/2*(t.width/2)+t.height*t.height);return[e/r,t,e]}(t,.9*j)}),z){var V=u.bulletPadding,q=1-u.bulletNumberDomainSize+V;p=R.l+(q+(1-q)*y[U])*R.w,S=function(t){return T(t,(u.bulletNumberDomainSize-V)*R.w,R.h)}}}else p=R.l+y[U]*R.w,S=function(t){return T(t,R.w,R.h)};!function(t,e,r,s){var l,u,p,d=r[0].trace,m=s.numbersX,_=s.numbersY,T=d.align||\"center\",A=v[T],S=s.transitionOpts,E=s.onComplete,L=i.ensureSingle(e,\"g\",\"numbers\"),C=[];d._hasNumber&&C.push(\"number\");d._hasDelta&&(C.push(\"delta\"),\"left\"===d.delta.position&&C.reverse());var P=L.selectAll(\"text\").data(C);function I(e,r,n,i){if(!e.match(\"s\")||n>=0==i>=0||r(n).slice(-1).match(x)||r(i).slice(-1).match(x))return r;var a=e.slice().replace(\"s\",\"f\").replace(/\\d+/,(function(t){return parseInt(t)-1})),o=w(t,{tickformat:a});return function(t){return Math.abs(t)<1?h.tickText(o,t).text:r(t)}}P.enter().append(\"text\"),P.attr(\"text-anchor\",(function(){return A})).attr(\"class\",(function(t){return t})).attr(\"x\",null).attr(\"y\",null).attr(\"dx\",null).attr(\"dy\",null),P.exit().remove();var O,z=d.mode+d.align;d._hasDelta&&(O=function(){var e=w(t,{tickformat:d.delta.valueformat},d._range);e.setScale(),h.prepTicks(e);var i=function(t){return h.tickText(e,t).text},a=function(t){return d.delta.relative?t.relativeDelta:t.delta},o=function(t,e){return 0===t||\"number\"!=typeof t||isNaN(t)?\"-\":(t>0?d.delta.increasing.symbol:d.delta.decreasing.symbol)+e(t)},s=function(t){return t.delta>=0?d.delta.increasing.color:d.delta.decreasing.color};void 0===d._deltaLastValue&&(d._deltaLastValue=a(r[0]));var l=L.select(\"text.delta\");function p(){l.text(o(a(r[0]),i)).call(g.fill,s(r[0])).call(f.convertToTspans,t)}return l.call(c.font,d.delta.font).call(g.fill,s({delta:d._deltaLastValue})),b(S)?l.transition().duration(S.duration).ease(S.easing).tween(\"text\",(function(){var t=n.select(this),e=a(r[0]),l=d._deltaLastValue,c=I(d.delta.valueformat,i,l,e),u=n.interpolateNumber(l,e);return d._deltaLastValue=e,function(e){t.text(o(u(e),c)),t.call(g.fill,s({delta:u(e)}))}})).each(\"end\",(function(){p(),E&&E()})).each(\"interrupt\",(function(){p(),E&&E()})):p(),u=k(o(a(r[0]),i),d.delta.font,A,t),l}(),z+=d.delta.position+d.delta.font.size+d.delta.font.family+d.delta.valueformat,z+=d.delta.increasing.symbol+d.delta.decreasing.symbol,p=u);d._hasNumber&&(!function(){var e=w(t,{tickformat:d.number.valueformat},d._range);e.setScale(),h.prepTicks(e);var i=function(t){return h.tickText(e,t).text},a=d.number.suffix,o=d.number.prefix,s=L.select(\"text.number\");function u(){var e=\"number\"==typeof r[0].y?o+i(r[0].y)+a:\"-\";s.text(e).call(c.font,d.number.font).call(f.convertToTspans,t)}b(S)?s.transition().duration(S.duration).ease(S.easing).each(\"end\",(function(){u(),E&&E()})).each(\"interrupt\",(function(){u(),E&&E()})).attrTween(\"text\",(function(){var t=n.select(this),e=n.interpolateNumber(r[0].lastY,r[0].y);d._lastValue=r[0].y;var s=I(d.number.valueformat,i,r[0].lastY,r[0].y);return function(r){t.text(o+s(e(r))+a)}})):u(),l=k(o+i(r[0].y)+a,d.number.font,A,t)}(),z+=d.number.font.size+d.number.font.family+d.number.valueformat+d.number.suffix+d.number.prefix,p=l);if(d._hasDelta&&d._hasNumber){var D,R,F=[(l.left+l.right)/2,(l.top+l.bottom)/2],B=[(u.left+u.right)/2,(u.top+u.bottom)/2],N=.75*d.delta.font.size;\"left\"===d.delta.position&&(D=M(d,\"deltaPos\",0,-1*(l.width*y[d.align]+u.width*(1-y[d.align])+N),z,Math.min),R=F[1]-B[1],p={width:l.width+u.width+N,height:Math.max(l.height,u.height),left:u.left+D,right:l.right,top:Math.min(l.top,u.top+R),bottom:Math.max(l.bottom,u.bottom+R)}),\"right\"===d.delta.position&&(D=M(d,\"deltaPos\",0,l.width*(1-y[d.align])+u.width*y[d.align]+N,z,Math.max),R=F[1]-B[1],p={width:l.width+u.width+N,height:Math.max(l.height,u.height),left:l.left,right:u.right+D,top:Math.min(l.top,u.top+R),bottom:Math.max(l.bottom,u.bottom+R)}),\"bottom\"===d.delta.position&&(D=null,R=u.height,p={width:Math.max(l.width,u.width),height:l.height+u.height,left:Math.min(l.left,u.left),right:Math.max(l.right,u.right),top:l.bottom-l.height,bottom:l.bottom+u.height}),\"top\"===d.delta.position&&(D=null,R=l.top,p={width:Math.max(l.width,u.width),height:l.height+u.height,left:Math.min(l.left,u.left),right:Math.max(l.right,u.right),top:l.bottom-l.height-u.height,bottom:l.bottom}),O.attr({dx:D,dy:R})}(d._hasNumber||d._hasDelta)&&L.attr(\"transform\",(function(){var t=s.numbersScaler(p);z+=t[2];var e,r=M(d,\"numbersScale\",1,t[0],z,Math.min);d._scaleNumbers||(r=1),e=d._isAngular?_-r*p.bottom:_-r*(p.top+p.bottom)/2,d._numbersTop=r*p.top+e;var n=p[T];\"center\"===T&&(n=(p.left+p.right)/2);var i=m-r*n;return i=M(d,\"numbersTranslate\",0,i,z,Math.max),o(i,e)+a(r)}))}(t,P,e,{numbersX:p,numbersY:A,numbersScaler:S,transitionOpts:r,onComplete:d}),I&&(E={range:C.gauge.axis.range,color:C.gauge.bgcolor,line:{color:C.gauge.bordercolor,width:0},thickness:1},L={range:C.gauge.axis.range,color:\"rgba(0, 0, 0, 0)\",line:{color:C.gauge.bordercolor,width:C.gauge.borderwidth},thickness:1});var H=P.selectAll(\"g.angular\").data(O?e:[]);H.exit().remove();var G=P.selectAll(\"g.angularaxis\").data(O?e:[]);G.exit().remove(),O&&function(t,e,r,i){var a,c,u,f,p=r[0].trace,d=i.size,m=i.radius,g=i.innerRadius,v=i.gaugeBg,y=i.gaugeOutline,x=[d.l+d.w/2,d.t+d.h/2+m/2],T=i.gauge,k=i.layer,M=i.transitionOpts,A=i.onComplete,S=Math.PI/2;function E(t){var e=p.gauge.axis.range[0],r=(t-e)/(p.gauge.axis.range[1]-e)*Math.PI-S;return r<-S?-S:r>S?S:r}function L(t){return n.svg.arc().innerRadius((g+m)/2-t/2*(m-g)).outerRadius((g+m)/2+t/2*(m-g)).startAngle(-S)}function C(t){t.attr(\"d\",(function(t){return L(t.thickness).startAngle(E(t.range[0])).endAngle(E(t.range[1]))()}))}T.enter().append(\"g\").classed(\"angular\",!0),T.attr(\"transform\",o(x[0],x[1])),k.enter().append(\"g\").classed(\"angularaxis\",!0).classed(\"crisp\",!0),k.selectAll(\"g.xangularaxistick,path,text\").remove(),(a=w(t,p.gauge.axis)).type=\"linear\",a.range=p.gauge.axis.range,a._id=\"xangularaxis\",a.ticklabeloverflow=\"allow\",a.setScale();var P=function(t){return(a.range[0]-t.x)/(a.range[1]-a.range[0])*Math.PI+Math.PI},I={},O=h.makeLabelFns(a,0).labelStandoff;I.xFn=function(t){var e=P(t);return Math.cos(e)*O},I.yFn=function(t){var e=P(t),r=Math.sin(e)>0?.2:1;return-Math.sin(e)*(O+t.fontSize*r)+Math.abs(Math.cos(e))*(t.fontSize*l)},I.anchorFn=function(t){var e=P(t),r=Math.cos(e);return Math.abs(r)<.1?\"middle\":r>0?\"start\":\"end\"},I.heightFn=function(t,e,r){var n=P(t);return-.5*(1+Math.sin(n))*r};var z=function(t){return o(x[0]+m*Math.cos(t),x[1]-m*Math.sin(t))};u=function(t){return z(P(t))};if(c=h.calcTicks(a),f=h.getTickSigns(a)[2],a.visible){f=\"inside\"===a.ticks?-1:1;var D=(a.linewidth||1)/2;h.drawTicks(t,a,{vals:c,layer:k,path:\"M\"+f*D+\",0h\"+f*a.ticklen,transFn:function(t){var e=P(t);return z(e)+\"rotate(\"+-s(e)+\")\"}}),h.drawLabels(t,a,{vals:c,layer:k,transFn:u,labelFns:I})}var R=[v].concat(p.gauge.steps),F=T.selectAll(\"g.bg-arc\").data(R);F.enter().append(\"g\").classed(\"bg-arc\",!0).append(\"path\"),F.select(\"path\").call(C).call(_),F.exit().remove();var B=L(p.gauge.bar.thickness),N=T.selectAll(\"g.value-arc\").data([p.gauge.bar]);N.enter().append(\"g\").classed(\"value-arc\",!0).append(\"path\");var j=N.select(\"path\");b(M)?(j.transition().duration(M.duration).ease(M.easing).each(\"end\",(function(){A&&A()})).each(\"interrupt\",(function(){A&&A()})).attrTween(\"d\",(U=B,V=E(r[0].lastY),q=E(r[0].y),function(){var t=n.interpolate(V,q);return function(e){return U.endAngle(t(e))()}})),p._lastValue=r[0].y):j.attr(\"d\",\"number\"==typeof r[0].y?B.endAngle(E(r[0].y)):\"M0,0Z\");var U,V,q;j.call(_),N.exit().remove(),R=[];var H=p.gauge.threshold.value;(H||0===H)&&R.push({range:[H,H],color:p.gauge.threshold.color,line:{color:p.gauge.threshold.line.color,width:p.gauge.threshold.line.width},thickness:p.gauge.threshold.thickness});var G=T.selectAll(\"g.threshold-arc\").data(R);G.enter().append(\"g\").classed(\"threshold-arc\",!0).append(\"path\"),G.select(\"path\").call(C).call(_),G.exit().remove();var Y=T.selectAll(\"g.gauge-outline\").data([y]);Y.enter().append(\"g\").classed(\"gauge-outline\",!0).append(\"path\"),Y.select(\"path\").call(C).call(_),Y.exit().remove()}(t,0,e,{radius:N,innerRadius:j,gauge:H,layer:G,size:R,gaugeBg:E,gaugeOutline:L,transitionOpts:r,onComplete:d});var Y=P.selectAll(\"g.bullet\").data(z?e:[]);Y.exit().remove();var W=P.selectAll(\"g.bulletaxis\").data(z?e:[]);W.exit().remove(),z&&function(t,e,r,n){var i,a,s,l,c,f=r[0].trace,p=n.gauge,d=n.layer,m=n.gaugeBg,v=n.gaugeOutline,y=n.size,x=f.domain,T=n.transitionOpts,k=n.onComplete;p.enter().append(\"g\").classed(\"bullet\",!0),p.attr(\"transform\",o(y.l,y.t)),d.enter().append(\"g\").classed(\"bulletaxis\",!0).classed(\"crisp\",!0),d.selectAll(\"g.xbulletaxistick,path,text\").remove();var M=y.h,A=f.gauge.bar.thickness*M,S=x.x[0],E=x.x[0]+(x.x[1]-x.x[0])*(f._hasNumber||f._hasDelta?1-u.bulletNumberDomainSize:1);(i=w(t,f.gauge.axis))._id=\"xbulletaxis\",i.domain=[S,E],i.setScale(),a=h.calcTicks(i),s=h.makeTransTickFn(i),l=h.getTickSigns(i)[2],c=y.t+y.h,i.visible&&(h.drawTicks(t,i,{vals:\"inside\"===i.ticks?h.clipEnds(i,a):a,layer:d,path:h.makeTickPath(i,c,l),transFn:s}),h.drawLabels(t,i,{vals:a,layer:d,transFn:s,labelFns:h.makeLabelFns(i,c)}));function L(t){t.attr(\"width\",(function(t){return Math.max(0,i.c2p(t.range[1])-i.c2p(t.range[0]))})).attr(\"x\",(function(t){return i.c2p(t.range[0])})).attr(\"y\",(function(t){return.5*(1-t.thickness)*M})).attr(\"height\",(function(t){return t.thickness*M}))}var C=[m].concat(f.gauge.steps),P=p.selectAll(\"g.bg-bullet\").data(C);P.enter().append(\"g\").classed(\"bg-bullet\",!0).append(\"rect\"),P.select(\"rect\").call(L).call(_),P.exit().remove();var I=p.selectAll(\"g.value-bullet\").data([f.gauge.bar]);I.enter().append(\"g\").classed(\"value-bullet\",!0).append(\"rect\"),I.select(\"rect\").attr(\"height\",A).attr(\"y\",(M-A)/2).call(_),b(T)?I.select(\"rect\").transition().duration(T.duration).ease(T.easing).each(\"end\",(function(){k&&k()})).each(\"interrupt\",(function(){k&&k()})).attr(\"width\",Math.max(0,i.c2p(Math.min(f.gauge.axis.range[1],r[0].y)))):I.select(\"rect\").attr(\"width\",\"number\"==typeof r[0].y?Math.max(0,i.c2p(Math.min(f.gauge.axis.range[1],r[0].y))):0);I.exit().remove();var O=r.filter((function(){return f.gauge.threshold.value||0===f.gauge.threshold.value})),z=p.selectAll(\"g.threshold-bullet\").data(O);z.enter().append(\"g\").classed(\"threshold-bullet\",!0).append(\"line\"),z.select(\"line\").attr(\"x1\",i.c2p(f.gauge.threshold.value)).attr(\"x2\",i.c2p(f.gauge.threshold.value)).attr(\"y1\",(1-f.gauge.threshold.thickness)/2*M).attr(\"y2\",(1-(1-f.gauge.threshold.thickness)/2)*M).call(g.stroke,f.gauge.threshold.line.color).style(\"stroke-width\",f.gauge.threshold.line.width),z.exit().remove();var D=p.selectAll(\"g.gauge-outline\").data([v]);D.enter().append(\"g\").classed(\"gauge-outline\",!0).append(\"rect\"),D.select(\"rect\").call(L).call(_),D.exit().remove()}(t,0,e,{gauge:Y,layer:W,size:R,gaugeBg:E,gaugeOutline:L,transitionOpts:r,onComplete:d});var X=P.selectAll(\"text.title\").data(e);X.exit().remove(),X.enter().append(\"text\").classed(\"title\",!0),X.attr(\"text-anchor\",(function(){return z?v.right:v[C.title.align]})).text(C.title.text).call(c.font,C.title.font).call(f.convertToTspans,t),X.attr(\"transform\",(function(){var t,e=R.l+R.w*y[C.title.align],r=u.titlePadding,n=c.bBox(X.node());if(I){if(O)if(C.gauge.axis.visible)t=c.bBox(G.node()).top-r-n.bottom;else t=R.t+R.h/2-N/2-n.bottom-r;z&&(t=A-(n.top+n.bottom)/2,e=R.l-u.bulletPadding*R.w)}else t=C._numbersTop-r-n.bottom;return o(e,t)}))}))}},{\"../../components/color\":662,\"../../components/drawing\":684,\"../../constants/alignment\":767,\"../../lib\":799,\"../../lib/svg_text_utils\":824,\"../../plots/cartesian/axes\":849,\"../../plots/cartesian/axis_defaults\":851,\"../../plots/cartesian/layout_attributes\":864,\"../../plots/cartesian/position_defaults\":867,\"./constants\":1146,\"@plotly/d3\":58}],1150:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/attributes\"),i=t(\"../../plots/cartesian/axis_format_attributes\").axisHoverFormat,a=t(\"../../plots/template_attributes\").hovertemplateAttrs,o=t(\"../mesh3d/attributes\"),s=t(\"../../plots/attributes\"),l=t(\"../../lib/extend\").extendFlat,c=t(\"../../plot_api/edit_types\").overrideAll;var u=e.exports=c(l({x:{valType:\"data_array\"},y:{valType:\"data_array\"},z:{valType:\"data_array\"},value:{valType:\"data_array\"},isomin:{valType:\"number\"},isomax:{valType:\"number\"},surface:{show:{valType:\"boolean\",dflt:!0},count:{valType:\"integer\",dflt:2,min:1},fill:{valType:\"number\",min:0,max:1,dflt:1},pattern:{valType:\"flaglist\",flags:[\"A\",\"B\",\"C\",\"D\",\"E\"],extras:[\"all\",\"odd\",\"even\"],dflt:\"all\"}},spaceframe:{show:{valType:\"boolean\",dflt:!1},fill:{valType:\"number\",min:0,max:1,dflt:.15}},slices:{x:{show:{valType:\"boolean\",dflt:!1},locations:{valType:\"data_array\",dflt:[]},fill:{valType:\"number\",min:0,max:1,dflt:1}},y:{show:{valType:\"boolean\",dflt:!1},locations:{valType:\"data_array\",dflt:[]},fill:{valType:\"number\",min:0,max:1,dflt:1}},z:{show:{valType:\"boolean\",dflt:!1},locations:{valType:\"data_array\",dflt:[]},fill:{valType:\"number\",min:0,max:1,dflt:1}}},caps:{x:{show:{valType:\"boolean\",dflt:!0},fill:{valType:\"number\",min:0,max:1,dflt:1}},y:{show:{valType:\"boolean\",dflt:!0},fill:{valType:\"number\",min:0,max:1,dflt:1}},z:{show:{valType:\"boolean\",dflt:!0},fill:{valType:\"number\",min:0,max:1,dflt:1}}},text:{valType:\"string\",dflt:\"\",arrayOk:!0},hovertext:{valType:\"string\",dflt:\"\",arrayOk:!0},hovertemplate:a(),xhoverformat:i(\"x\"),yhoverformat:i(\"y\"),zhoverformat:i(\"z\"),valuehoverformat:i(\"value\",1),showlegend:l({},s.showlegend,{dflt:!1})},n(\"\",{colorAttr:\"`value`\",showScaleDflt:!0,editTypeOverride:\"calc\"}),{opacity:o.opacity,lightposition:o.lightposition,lighting:o.lighting,flatshading:o.flatshading,contour:o.contour,hoverinfo:l({},s.hoverinfo)}),\"calc\",\"nested\");u.flatshading.dflt=!0,u.lighting.facenormalsepsilon.dflt=0,u.x.editType=u.y.editType=u.z.editType=u.value.editType=\"calc+clearAxisTypes\",u.transforms=void 0},{\"../../components/colorscale/attributes\":669,\"../../lib/extend\":789,\"../../plot_api/edit_types\":831,\"../../plots/attributes\":845,\"../../plots/cartesian/axis_format_attributes\":852,\"../../plots/template_attributes\":922,\"../mesh3d/attributes\":1155}],1151:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/calc\"),i=t(\"../streamtube/calc\").processGrid,a=t(\"../streamtube/calc\").filter;e.exports=function(t,e){e._len=Math.min(e.x.length,e.y.length,e.z.length,e.value.length),e._x=a(e.x,e._len),e._y=a(e.y,e._len),e._z=a(e.z,e._len),e._value=a(e.value,e._len);var r=i(e);e._gridFill=r.fill,e._Xs=r.Xs,e._Ys=r.Ys,e._Zs=r.Zs,e._len=r.len;for(var o=1/0,s=-1/0,l=0;l<e._len;l++){var c=e._value[l];o=Math.min(o,c),s=Math.max(s,c)}e._minValues=o,e._maxValues=s,e._vMin=void 0===e.isomin||null===e.isomin?o:e.isomin,e._vMax=void 0===e.isomax||null===e.isomin?s:e.isomax,n(t,e,{vals:[e._vMin,e._vMax],containerStr:\"\",cLetter:\"c\"})}},{\"../../components/colorscale/calc\":670,\"../streamtube/calc\":1322}],1152:[function(t,e,r){\"use strict\";var n=t(\"gl-mesh3d\"),i=t(\"../../lib/gl_format_color\").parseColorScale,a=t(\"../../lib/str2rgbarray\"),o=t(\"../../components/colorscale\").extractOpts,s=t(\"../../plots/gl3d/zip3\"),l=function(t,e){for(var r=e.length-1;r>0;r--){var n=Math.min(e[r],e[r-1]),i=Math.max(e[r],e[r-1]);if(i>n&&n<t&&t<=i)return{id:r,distRatio:(i-t)/(i-n)}}return{id:0,distRatio:0}};function c(t,e,r){this.scene=t,this.uid=r,this.mesh=e,this.name=\"\",this.data=null,this.showContour=!1}var u=c.prototype;u.handlePick=function(t){if(t.object===this.mesh){var e=t.data.index,r=this.data._meshX[e],n=this.data._meshY[e],i=this.data._meshZ[e],a=this.data._Ys.length,o=this.data._Zs.length,s=l(r,this.data._Xs).id,c=l(n,this.data._Ys).id,u=l(i,this.data._Zs).id,f=t.index=u+o*c+o*a*s;t.traceCoordinate=[this.data._meshX[f],this.data._meshY[f],this.data._meshZ[f],this.data._value[f]];var h=this.data.hovertext||this.data.text;return Array.isArray(h)&&void 0!==h[f]?t.textLabel=h[f]:h&&(t.textLabel=h),!0}},u.update=function(t){var e=this.scene,r=e.fullSceneLayout;function n(t,e,r,n){return e.map((function(e){return t.d2l(e,0,n)*r}))}this.data=h(t);var l={positions:s(n(r.xaxis,t._meshX,e.dataScale[0],t.xcalendar),n(r.yaxis,t._meshY,e.dataScale[1],t.ycalendar),n(r.zaxis,t._meshZ,e.dataScale[2],t.zcalendar)),cells:s(t._meshI,t._meshJ,t._meshK),lightPosition:[t.lightposition.x,t.lightposition.y,t.lightposition.z],ambient:t.lighting.ambient,diffuse:t.lighting.diffuse,specular:t.lighting.specular,roughness:t.lighting.roughness,fresnel:t.lighting.fresnel,vertexNormalsEpsilon:t.lighting.vertexnormalsepsilon,faceNormalsEpsilon:t.lighting.facenormalsepsilon,opacity:t.opacity,contourEnable:t.contour.show,contourColor:a(t.contour.color).slice(0,3),contourWidth:t.contour.width,useFacetNormals:t.flatshading},c=o(t);l.vertexIntensity=t._meshIntensity,l.vertexIntensityBounds=[c.min,c.max],l.colormap=i(t),this.mesh.update(l)},u.dispose=function(){this.scene.glplot.remove(this.mesh),this.mesh.dispose()};var f=[\"xyz\",\"xzy\",\"yxz\",\"yzx\",\"zxy\",\"zyx\"];function h(t){t._meshI=[],t._meshJ=[],t._meshK=[];var e,r,n,i,a,o,s,c=t.surface.show,u=t.spaceframe.show,h=t.surface.fill,p=t.spaceframe.fill,d=!1,m=!1,g=0,v=t._Xs,y=t._Ys,x=t._Zs,b=v.length,_=y.length,w=x.length,T=f.indexOf(t._gridFill.replace(/-/g,\"\").replace(/\\+/g,\"\")),k=function(t,e,r){switch(T){case 5:return r+w*e+w*_*t;case 4:return r+w*t+w*b*e;case 3:return e+_*r+_*w*t;case 2:return e+_*t+_*b*r;case 1:return t+b*r+b*w*e;default:return t+b*e+b*_*r}},M=t._minValues,A=t._maxValues,S=t._vMin,E=t._vMax;function L(t,e,s){for(var l=o.length,c=r;c<l;c++)if(t===n[c]&&e===i[c]&&s===a[c])return c;return-1}function C(){r=e}function P(){n=[],i=[],a=[],o=[],e=0,C()}function I(t,r,s,l){return n.push(t),i.push(r),a.push(s),o.push(l),++e-1}function O(t,e,r){for(var n=[],i=0;i<t.length;i++)n[i]=t[i]*(1-r)+r*e[i];return n}function z(t){s=t}function D(t,e){return\"all\"===t||null===t||t.indexOf(e)>-1}function R(t,e){return null===t?e:t}function F(e,r,n){C();var i,a,o,l=[r],c=[n];if(s>=1)l=[r],c=[n];else if(s>0){var u=function(t,e){var r=t[0],n=t[1],i=t[2],a=function(t,e,r){for(var n=[],i=0;i<t.length;i++)n[i]=(t[i]+e[i]+r[i])/3;return n}(r,n,i),o=Math.sqrt(1-s),l=O(a,r,o),c=O(a,n,o),u=O(a,i,o),f=e[0],h=e[1],p=e[2];return{xyzv:[[r,n,c],[c,l,r],[n,i,u],[u,c,n],[i,r,l],[l,u,i]],abc:[[f,h,-1],[-1,-1,f],[h,p,-1],[-1,-1,h],[p,f,-1],[-1,-1,p]]}}(r,n);l=u.xyzv,c=u.abc}for(var f=0;f<l.length;f++){r=l[f],n=c[f];for(var h=[],p=0;p<3;p++){var d=r[p][0],m=r[p][1],v=r[p][2],y=r[p][3],x=n[p]>-1?n[p]:L(d,m,v);h[p]=x>-1?x:I(d,m,v,R(e,y))}i=h[0],a=h[1],o=h[2],t._meshI.push(i),t._meshJ.push(a),t._meshK.push(o),++g}}function B(t,e,r,n){var i=t[3];i<r&&(i=r),i>n&&(i=n);for(var a=(t[3]-i)/(t[3]-e[3]+1e-9),o=[],s=0;s<4;s++)o[s]=(1-a)*t[s]+a*e[s];return o}function N(t,e,r){return t>=e&&t<=r}function j(t){var e=.001*(E-S);return t>=S-e&&t<=E+e}function U(e){for(var r=[],n=0;n<4;n++){var i=e[n];r.push([t._x[i],t._y[i],t._z[i],t._value[i]])}return r}function V(t,e,r,n,i,a){a||(a=1),r=[-1,-1,-1];var o=!1,s=[N(e[0][3],n,i),N(e[1][3],n,i),N(e[2][3],n,i)];if(!s[0]&&!s[1]&&!s[2])return!1;var l=function(t,e,r){return j(e[0][3])&&j(e[1][3])&&j(e[2][3])?(F(t,e,r),!0):a<3&&V(t,e,r,S,E,++a)};if(s[0]&&s[1]&&s[2])return l(t,e,r)||o;var c=!1;return[[0,1,2],[2,0,1],[1,2,0]].forEach((function(a){if(s[a[0]]&&s[a[1]]&&!s[a[2]]){var u=e[a[0]],f=e[a[1]],h=e[a[2]],p=B(h,u,n,i),d=B(h,f,n,i);o=l(t,[d,p,u],[-1,-1,r[a[0]]])||o,o=l(t,[u,f,d],[r[a[0]],r[a[1]],-1])||o,c=!0}})),c||[[0,1,2],[1,2,0],[2,0,1]].forEach((function(a){if(s[a[0]]&&!s[a[1]]&&!s[a[2]]){var u=e[a[0]],f=e[a[1]],h=e[a[2]],p=B(f,u,n,i),d=B(h,u,n,i);o=l(t,[d,p,u],[-1,-1,r[a[0]]])||o,c=!0}})),o}function q(t,e,r,n){var i=!1,a=U(e),o=[N(a[0][3],r,n),N(a[1][3],r,n),N(a[2][3],r,n),N(a[3][3],r,n)];if(!(o[0]||o[1]||o[2]||o[3]))return i;if(o[0]&&o[1]&&o[2]&&o[3])return m&&(i=function(t,e,r){var n=function(n,i,a){F(t,[e[n],e[i],e[a]],[r[n],r[i],r[a]])};n(0,1,2),n(3,0,1),n(2,3,0),n(1,2,3)}(t,a,e)||i),i;var s=!1;return[[0,1,2,3],[3,0,1,2],[2,3,0,1],[1,2,3,0]].forEach((function(l){if(o[l[0]]&&o[l[1]]&&o[l[2]]&&!o[l[3]]){var c=a[l[0]],u=a[l[1]],f=a[l[2]],h=a[l[3]];if(m)i=F(t,[c,u,f],[e[l[0]],e[l[1]],e[l[2]]])||i;else{var p=B(h,c,r,n),d=B(h,u,r,n),g=B(h,f,r,n);i=F(null,[p,d,g],[-1,-1,-1])||i}s=!0}})),s?i:([[0,1,2,3],[1,2,3,0],[2,3,0,1],[3,0,1,2],[0,2,3,1],[1,3,2,0]].forEach((function(l){if(o[l[0]]&&o[l[1]]&&!o[l[2]]&&!o[l[3]]){var c=a[l[0]],u=a[l[1]],f=a[l[2]],h=a[l[3]],p=B(f,c,r,n),d=B(f,u,r,n),g=B(h,u,r,n),v=B(h,c,r,n);m?(i=F(t,[c,v,p],[e[l[0]],-1,-1])||i,i=F(t,[u,d,g],[e[l[1]],-1,-1])||i):i=function(t,e,r){var n=function(n,i,a){F(t,[e[n],e[i],e[a]],[r[n],r[i],r[a]])};n(0,1,2),n(2,3,0)}(null,[p,d,g,v],[-1,-1,-1,-1])||i,s=!0}})),s||[[0,1,2,3],[1,2,3,0],[2,3,0,1],[3,0,1,2]].forEach((function(l){if(o[l[0]]&&!o[l[1]]&&!o[l[2]]&&!o[l[3]]){var c=a[l[0]],u=a[l[1]],f=a[l[2]],h=a[l[3]],p=B(u,c,r,n),d=B(f,c,r,n),g=B(h,c,r,n);m?(i=F(t,[c,p,d],[e[l[0]],-1,-1])||i,i=F(t,[c,d,g],[e[l[0]],-1,-1])||i,i=F(t,[c,g,p],[e[l[0]],-1,-1])||i):i=F(null,[p,d,g],[-1,-1,-1])||i,s=!0}})),i)}function H(t,e,r,n,i,a,o,s,l,c,u){var f=!1;return d&&(D(t,\"A\")&&(f=q(null,[e,r,n,a],c,u)||f),D(t,\"B\")&&(f=q(null,[r,n,i,l],c,u)||f),D(t,\"C\")&&(f=q(null,[r,a,o,l],c,u)||f),D(t,\"D\")&&(f=q(null,[n,a,s,l],c,u)||f),D(t,\"E\")&&(f=q(null,[r,n,a,l],c,u)||f)),m&&(f=q(t,[r,n,a,l],c,u)||f),f}function G(t,e,r,n,i,a,o,s){return[!0===s[0]||V(t,U([e,r,n]),[e,r,n],a,o),!0===s[1]||V(t,U([n,i,e]),[n,i,e],a,o)]}function Y(t,e,r,n,i,a,o,s,l){return s?G(t,e,r,i,n,a,o,l):G(t,r,i,n,e,a,o,l)}function W(t,e,r,n,i,a,o){var s,l,c,u,f=!1,h=function(){f=V(t,[s,l,c],[-1,-1,-1],i,a)||f,f=V(t,[c,u,s],[-1,-1,-1],i,a)||f},p=o[0],d=o[1],m=o[2];return p&&(s=O(U([k(e,r-0,n-0)])[0],U([k(e-1,r-0,n-0)])[0],p),l=O(U([k(e,r-0,n-1)])[0],U([k(e-1,r-0,n-1)])[0],p),c=O(U([k(e,r-1,n-1)])[0],U([k(e-1,r-1,n-1)])[0],p),u=O(U([k(e,r-1,n-0)])[0],U([k(e-1,r-1,n-0)])[0],p),h()),d&&(s=O(U([k(e-0,r,n-0)])[0],U([k(e-0,r-1,n-0)])[0],d),l=O(U([k(e-0,r,n-1)])[0],U([k(e-0,r-1,n-1)])[0],d),c=O(U([k(e-1,r,n-1)])[0],U([k(e-1,r-1,n-1)])[0],d),u=O(U([k(e-1,r,n-0)])[0],U([k(e-1,r-1,n-0)])[0],d),h()),m&&(s=O(U([k(e-0,r-0,n)])[0],U([k(e-0,r-0,n-1)])[0],m),l=O(U([k(e-0,r-1,n)])[0],U([k(e-0,r-1,n-1)])[0],m),c=O(U([k(e-1,r-1,n)])[0],U([k(e-1,r-1,n-1)])[0],m),u=O(U([k(e-1,r-0,n)])[0],U([k(e-1,r-0,n-1)])[0],m),h()),f}function X(t,e,r,n,i,a,o,s,l,c,u,f){var h=t;return f?(d&&\"even\"===t&&(h=null),H(h,e,r,n,i,a,o,s,l,c,u)):(d&&\"odd\"===t&&(h=null),H(h,l,s,o,a,i,n,r,e,c,u))}function Z(t,e,r,n,i){for(var a=[],o=0,s=0;s<e.length;s++)for(var l=e[s],c=1;c<w;c++)for(var u=1;u<_;u++)a.push(Y(t,k(l,u-1,c-1),k(l,u-1,c),k(l,u,c-1),k(l,u,c),r,n,(l+u+c)%2,i&&i[o]?i[o]:[])),o++;return a}function J(t,e,r,n,i){for(var a=[],o=0,s=0;s<e.length;s++)for(var l=e[s],c=1;c<b;c++)for(var u=1;u<w;u++)a.push(Y(t,k(c-1,l,u-1),k(c,l,u-1),k(c-1,l,u),k(c,l,u),r,n,(c+l+u)%2,i&&i[o]?i[o]:[])),o++;return a}function K(t,e,r,n,i){for(var a=[],o=0,s=0;s<e.length;s++)for(var l=e[s],c=1;c<_;c++)for(var u=1;u<b;u++)a.push(Y(t,k(u-1,c-1,l),k(u-1,c,l),k(u,c-1,l),k(u,c,l),r,n,(u+c+l)%2,i&&i[o]?i[o]:[])),o++;return a}function Q(t,e,r){for(var n=1;n<w;n++)for(var i=1;i<_;i++)for(var a=1;a<b;a++)X(t,k(a-1,i-1,n-1),k(a-1,i-1,n),k(a-1,i,n-1),k(a-1,i,n),k(a,i-1,n-1),k(a,i-1,n),k(a,i,n-1),k(a,i,n),e,r,(a+i+n)%2)}function $(t,e,r){d=!0,Q(t,e,r),d=!1}function tt(t,e,r,n,i,a){for(var o=[],s=0,l=0;l<e.length;l++)for(var c=e[l],u=1;u<w;u++)for(var f=1;f<_;f++)o.push(W(t,c,f,u,r,n,i[l],a&&a[s]&&a[s])),s++;return o}function et(t,e,r,n,i,a){for(var o=[],s=0,l=0;l<e.length;l++)for(var c=e[l],u=1;u<b;u++)for(var f=1;f<w;f++)o.push(W(t,u,c,f,r,n,i[l],a&&a[s]&&a[s])),s++;return o}function rt(t,e,r,n,i,a){for(var o=[],s=0,l=0;l<e.length;l++)for(var c=e[l],u=1;u<_;u++)for(var f=1;f<b;f++)o.push(W(t,f,u,c,r,n,i[l],a&&a[s]&&a[s])),s++;return o}function nt(t,e){for(var r=[],n=t;n<e;n++)r.push(n);return r}return function(){if(P(),function(){for(var e=0;e<b;e++)for(var r=0;r<_;r++)for(var n=0;n<w;n++){var i=k(e,r,n);I(t._x[i],t._y[i],t._z[i],t._value[i])}}(),u&&p&&(z(p),m=!0,Q(null,S,E),m=!1),c&&h){z(h);for(var e=t.surface.pattern,r=t.surface.count,s=0;s<r;s++){var f=1===r?.5:s/(r-1),d=(1-f)*S+f*E,T=Math.abs(d-M)>Math.abs(d-A)?[M,d]:[d,A];$(e,T[0],T[1])}}var L=[[Math.min(S,A),Math.max(S,A)],[Math.min(M,E),Math.max(M,E)]];[\"x\",\"y\",\"z\"].forEach((function(e){for(var r=[],n=0;n<L.length;n++){var i=0,a=L[n][0],o=L[n][1],s=t.slices[e];if(s.show&&s.fill){z(s.fill);var c=[],u=[],f=[];if(s.locations.length)for(var h=0;h<s.locations.length;h++){var p=l(s.locations[h],\"x\"===e?v:\"y\"===e?y:x);0===p.distRatio?c.push(p.id):p.id>0&&(u.push(p.id),\"x\"===e?f.push([p.distRatio,0,0]):\"y\"===e?f.push([0,p.distRatio,0]):f.push([0,0,p.distRatio]))}else c=nt(1,\"x\"===e?b-1:\"y\"===e?_-1:w-1);u.length>0&&(r[i]=\"x\"===e?tt(null,u,a,o,f,r[i]):\"y\"===e?et(null,u,a,o,f,r[i]):rt(null,u,a,o,f,r[i]),i++),c.length>0&&(r[i]=\"x\"===e?Z(null,c,a,o,r[i]):\"y\"===e?J(null,c,a,o,r[i]):K(null,c,a,o,r[i]),i++)}var d=t.caps[e];d.show&&d.fill&&(z(d.fill),r[i]=\"x\"===e?Z(null,[0,b-1],a,o,r[i]):\"y\"===e?J(null,[0,_-1],a,o,r[i]):K(null,[0,w-1],a,o,r[i]),i++)}})),0===g&&P(),t._meshX=n,t._meshY=i,t._meshZ=a,t._meshIntensity=o,t._Xs=v,t._Ys=y,t._Zs=x}(),t}e.exports={findNearestOnAxis:l,generateIsoMeshes:h,createIsosurfaceTrace:function(t,e){var r=t.glplot.gl,i=n({gl:r}),a=new c(t,i,e.uid);return i._trace=a,a.update(e),t.glplot.add(i),a}}},{\"../../components/colorscale\":674,\"../../lib/gl_format_color\":795,\"../../lib/str2rgbarray\":823,\"../../plots/gl3d/zip3\":903,\"gl-mesh3d\":311}],1153:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../registry\"),a=t(\"./attributes\"),o=t(\"../../components/colorscale/defaults\");function s(t,e,r,n,a){var s=a(\"isomin\"),l=a(\"isomax\");null!=l&&null!=s&&s>l&&(e.isomin=null,e.isomax=null);var c=a(\"x\"),u=a(\"y\"),f=a(\"z\"),h=a(\"value\");c&&c.length&&u&&u.length&&f&&f.length&&h&&h.length?(i.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\",\"y\",\"z\"],n),a(\"valuehoverformat\"),[\"x\",\"y\",\"z\"].forEach((function(t){a(t+\"hoverformat\");var e=\"caps.\"+t;a(e+\".show\")&&a(e+\".fill\");var r=\"slices.\"+t;a(r+\".show\")&&(a(r+\".fill\"),a(r+\".locations\"))})),a(\"spaceframe.show\")&&a(\"spaceframe.fill\"),a(\"surface.show\")&&(a(\"surface.count\"),a(\"surface.fill\"),a(\"surface.pattern\")),a(\"contour.show\")&&(a(\"contour.color\"),a(\"contour.width\")),[\"text\",\"hovertext\",\"hovertemplate\",\"lighting.ambient\",\"lighting.diffuse\",\"lighting.specular\",\"lighting.roughness\",\"lighting.fresnel\",\"lighting.vertexnormalsepsilon\",\"lighting.facenormalsepsilon\",\"lightposition.x\",\"lightposition.y\",\"lightposition.z\",\"flatshading\",\"opacity\"].forEach((function(t){a(t)})),o(t,e,n,a,{prefix:\"\",cLetter:\"c\"}),e._length=null):e.visible=!1}e.exports={supplyDefaults:function(t,e,r,i){s(t,e,r,i,(function(r,i){return n.coerce(t,e,a,r,i)}))},supplyIsoDefaults:s}},{\"../../components/colorscale/defaults\":672,\"../../lib\":799,\"../../registry\":927,\"./attributes\":1150}],1154:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\").supplyDefaults,calc:t(\"./calc\"),colorbar:{min:\"cmin\",max:\"cmax\"},plot:t(\"./convert\").createIsosurfaceTrace,moduleType:\"trace\",name:\"isosurface\",basePlotModule:t(\"../../plots/gl3d\"),categories:[\"gl3d\",\"showLegend\"],meta:{}}},{\"../../plots/gl3d\":892,\"./attributes\":1150,\"./calc\":1151,\"./convert\":1152,\"./defaults\":1153}],1155:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/attributes\"),i=t(\"../../plots/cartesian/axis_format_attributes\").axisHoverFormat,a=t(\"../../plots/template_attributes\").hovertemplateAttrs,o=t(\"../surface/attributes\"),s=t(\"../../plots/attributes\"),l=t(\"../../lib/extend\").extendFlat;e.exports=l({x:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},y:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},z:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},i:{valType:\"data_array\",editType:\"calc\"},j:{valType:\"data_array\",editType:\"calc\"},k:{valType:\"data_array\",editType:\"calc\"},text:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"calc\"},hovertext:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"calc\"},hovertemplate:a({editType:\"calc\"}),xhoverformat:i(\"x\"),yhoverformat:i(\"y\"),zhoverformat:i(\"z\"),delaunayaxis:{valType:\"enumerated\",values:[\"x\",\"y\",\"z\"],dflt:\"z\",editType:\"calc\"},alphahull:{valType:\"number\",dflt:-1,editType:\"calc\"},intensity:{valType:\"data_array\",editType:\"calc\"},intensitymode:{valType:\"enumerated\",values:[\"vertex\",\"cell\"],dflt:\"vertex\",editType:\"calc\"},color:{valType:\"color\",editType:\"calc\"},vertexcolor:{valType:\"data_array\",editType:\"calc\"},facecolor:{valType:\"data_array\",editType:\"calc\"},transforms:void 0},n(\"\",{colorAttr:\"`intensity`\",showScaleDflt:!0,editTypeOverride:\"calc\"}),{opacity:o.opacity,flatshading:{valType:\"boolean\",dflt:!1,editType:\"calc\"},contour:{show:l({},o.contours.x.show,{}),color:o.contours.x.color,width:o.contours.x.width,editType:\"calc\"},lightposition:{x:l({},o.lightposition.x,{dflt:1e5}),y:l({},o.lightposition.y,{dflt:1e5}),z:l({},o.lightposition.z,{dflt:0}),editType:\"calc\"},lighting:l({vertexnormalsepsilon:{valType:\"number\",min:0,max:1,dflt:1e-12,editType:\"calc\"},facenormalsepsilon:{valType:\"number\",min:0,max:1,dflt:1e-6,editType:\"calc\"},editType:\"calc\"},o.lighting),hoverinfo:l({},s.hoverinfo,{editType:\"calc\"}),showlegend:l({},s.showlegend,{dflt:!1})})},{\"../../components/colorscale/attributes\":669,\"../../lib/extend\":789,\"../../plots/attributes\":845,\"../../plots/cartesian/axis_format_attributes\":852,\"../../plots/template_attributes\":922,\"../surface/attributes\":1338}],1156:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/calc\");e.exports=function(t,e){e.intensity&&n(t,e,{vals:e.intensity,containerStr:\"\",cLetter:\"c\"})}},{\"../../components/colorscale/calc\":670}],1157:[function(t,e,r){\"use strict\";var n=t(\"gl-mesh3d\"),i=t(\"delaunay-triangulate\"),a=t(\"alpha-shape\"),o=t(\"convex-hull\"),s=t(\"../../lib/gl_format_color\").parseColorScale,l=t(\"../../lib/str2rgbarray\"),c=t(\"../../components/colorscale\").extractOpts,u=t(\"../../plots/gl3d/zip3\");function f(t,e,r){this.scene=t,this.uid=r,this.mesh=e,this.name=\"\",this.color=\"#fff\",this.data=null,this.showContour=!1}var h=f.prototype;function p(t){for(var e=[],r=t.length,n=0;n<r;n++)e[n]=l(t[n]);return e}function d(t,e,r,n){for(var i=[],a=e.length,o=0;o<a;o++)i[o]=t.d2l(e[o],0,n)*r;return i}function m(t){for(var e=[],r=t.length,n=0;n<r;n++)e[n]=Math.round(t[n]);return e}function g(t,e){for(var r=t.length,n=0;n<r;n++)if(t[n]<=-.5||t[n]>=e-.5)return!1;return!0}h.handlePick=function(t){if(t.object===this.mesh){var e=t.index=t.data.index;t.data._cellCenter?t.traceCoordinate=t.data.dataCoordinate:t.traceCoordinate=[this.data.x[e],this.data.y[e],this.data.z[e]];var r=this.data.hovertext||this.data.text;return Array.isArray(r)&&void 0!==r[e]?t.textLabel=r[e]:r&&(t.textLabel=r),!0}},h.update=function(t){var e=this.scene,r=e.fullSceneLayout;this.data=t;var n,f=t.x.length,h=u(d(r.xaxis,t.x,e.dataScale[0],t.xcalendar),d(r.yaxis,t.y,e.dataScale[1],t.ycalendar),d(r.zaxis,t.z,e.dataScale[2],t.zcalendar));if(t.i&&t.j&&t.k){if(t.i.length!==t.j.length||t.j.length!==t.k.length||!g(t.i,f)||!g(t.j,f)||!g(t.k,f))return;n=u(m(t.i),m(t.j),m(t.k))}else n=0===t.alphahull?o(h):t.alphahull>0?a(t.alphahull,h):function(t,e){for(var r=[\"x\",\"y\",\"z\"].indexOf(t),n=[],a=e.length,o=0;o<a;o++)n[o]=[e[o][(r+1)%3],e[o][(r+2)%3]];return i(n)}(t.delaunayaxis,h);var v={positions:h,cells:n,lightPosition:[t.lightposition.x,t.lightposition.y,t.lightposition.z],ambient:t.lighting.ambient,diffuse:t.lighting.diffuse,specular:t.lighting.specular,roughness:t.lighting.roughness,fresnel:t.lighting.fresnel,vertexNormalsEpsilon:t.lighting.vertexnormalsepsilon,faceNormalsEpsilon:t.lighting.facenormalsepsilon,opacity:t.opacity,contourEnable:t.contour.show,contourColor:l(t.contour.color).slice(0,3),contourWidth:t.contour.width,useFacetNormals:t.flatshading};if(t.intensity){var y=c(t);this.color=\"#fff\";var x=t.intensitymode;v[x+\"Intensity\"]=t.intensity,v[x+\"IntensityBounds\"]=[y.min,y.max],v.colormap=s(t)}else t.vertexcolor?(this.color=t.vertexcolor[0],v.vertexColors=p(t.vertexcolor)):t.facecolor?(this.color=t.facecolor[0],v.cellColors=p(t.facecolor)):(this.color=t.color,v.meshColor=l(t.color));this.mesh.update(v)},h.dispose=function(){this.scene.glplot.remove(this.mesh),this.mesh.dispose()},e.exports=function(t,e){var r=t.glplot.gl,i=n({gl:r}),a=new f(t,i,e.uid);return i._trace=a,a.update(e),t.glplot.add(i),a}},{\"../../components/colorscale\":674,\"../../lib/gl_format_color\":795,\"../../lib/str2rgbarray\":823,\"../../plots/gl3d/zip3\":903,\"alpha-shape\":75,\"convex-hull\":141,\"delaunay-triangulate\":176,\"gl-mesh3d\":311}],1158:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"../../components/colorscale/defaults\"),o=t(\"./attributes\");e.exports=function(t,e,r,s){function l(r,n){return i.coerce(t,e,o,r,n)}function c(t){var e=t.map((function(t){var e=l(t);return e&&i.isArrayOrTypedArray(e)?e:null}));return e.every((function(t){return t&&t.length===e[0].length}))&&e}c([\"x\",\"y\",\"z\"])?(c([\"i\",\"j\",\"k\"]),(!e.i||e.j&&e.k)&&(!e.j||e.k&&e.i)&&(!e.k||e.i&&e.j)?(n.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\",\"y\",\"z\"],s),[\"lighting.ambient\",\"lighting.diffuse\",\"lighting.specular\",\"lighting.roughness\",\"lighting.fresnel\",\"lighting.vertexnormalsepsilon\",\"lighting.facenormalsepsilon\",\"lightposition.x\",\"lightposition.y\",\"lightposition.z\",\"flatshading\",\"alphahull\",\"delaunayaxis\",\"opacity\"].forEach((function(t){l(t)})),l(\"contour.show\")&&(l(\"contour.color\"),l(\"contour.width\")),\"intensity\"in t?(l(\"intensity\"),l(\"intensitymode\"),a(t,e,s,l,{prefix:\"\",cLetter:\"c\"})):(e.showscale=!1,\"facecolor\"in t?l(\"facecolor\"):\"vertexcolor\"in t?l(\"vertexcolor\"):l(\"color\",r)),l(\"text\"),l(\"hovertext\"),l(\"hovertemplate\"),l(\"xhoverformat\"),l(\"yhoverformat\"),l(\"zhoverformat\"),e._length=null):e.visible=!1):e.visible=!1}},{\"../../components/colorscale/defaults\":672,\"../../lib\":799,\"../../registry\":927,\"./attributes\":1155}],1159:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\"),colorbar:{min:\"cmin\",max:\"cmax\"},plot:t(\"./convert\"),moduleType:\"trace\",name:\"mesh3d\",basePlotModule:t(\"../../plots/gl3d\"),categories:[\"gl3d\",\"showLegend\"],meta:{}}},{\"../../plots/gl3d\":892,\"./attributes\":1155,\"./calc\":1156,\"./convert\":1157,\"./defaults\":1158}],1160:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").extendFlat,i=t(\"../scatter/attributes\"),a=t(\"../../plots/cartesian/axis_format_attributes\").axisHoverFormat,o=t(\"../../components/drawing/attributes\").dash,s=t(\"../../components/fx/attributes\"),l=t(\"../../constants/delta.js\"),c=l.INCREASING.COLOR,u=l.DECREASING.COLOR,f=i.line;function h(t){return{line:{color:n({},f.color,{dflt:t}),width:f.width,dash:o,editType:\"style\"},editType:\"style\"}}e.exports={xperiod:i.xperiod,xperiod0:i.xperiod0,xperiodalignment:i.xperiodalignment,xhoverformat:a(\"x\"),yhoverformat:a(\"y\"),x:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},open:{valType:\"data_array\",editType:\"calc\"},high:{valType:\"data_array\",editType:\"calc\"},low:{valType:\"data_array\",editType:\"calc\"},close:{valType:\"data_array\",editType:\"calc\"},line:{width:n({},f.width,{}),dash:n({},o,{}),editType:\"style\"},increasing:h(c),decreasing:h(u),text:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"calc\"},hovertext:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"calc\"},tickwidth:{valType:\"number\",min:0,max:.5,dflt:.3,editType:\"calc\"},hoverlabel:n({},s.hoverlabel,{split:{valType:\"boolean\",dflt:!1,editType:\"style\"}})}},{\"../../components/drawing/attributes\":683,\"../../components/fx/attributes\":693,\"../../constants/delta.js\":769,\"../../lib\":799,\"../../plots/cartesian/axis_format_attributes\":852,\"../scatter/attributes\":1214}],1161:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=n._,a=t(\"../../plots/cartesian/axes\"),o=t(\"../../plots/cartesian/align_period\"),s=t(\"../../constants/numerical\").BADNUM;function l(t,e,r,n){return{o:t,h:e,l:r,c:n}}function c(t,e,r,o,l,c){for(var u=l.makeCalcdata(e,\"open\"),f=l.makeCalcdata(e,\"high\"),h=l.makeCalcdata(e,\"low\"),p=l.makeCalcdata(e,\"close\"),d=Array.isArray(e.text),m=Array.isArray(e.hovertext),g=!0,v=null,y=!!e.xperiodalignment,x=[],b=0;b<o.length;b++){var _=o[b],w=u[b],T=f[b],k=h[b],M=p[b];if(_!==s&&w!==s&&T!==s&&k!==s&&M!==s){M===w?null!==v&&M!==v&&(g=M>v):g=M>w,v=M;var A=c(w,T,k,M);A.pos=_,A.yc=(w+M)/2,A.i=b,A.dir=g?\"increasing\":\"decreasing\",A.x=A.pos,A.y=[k,T],y&&(A.orig_p=r[b]),d&&(A.tx=e.text[b]),m&&(A.htx=e.hovertext[b]),x.push(A)}else x.push({pos:_,empty:!0})}return e._extremes[l._id]=a.findExtremes(l,n.concat(h,f),{padded:!0}),x.length&&(x[0].t={labels:{open:i(t,\"open:\")+\" \",high:i(t,\"high:\")+\" \",low:i(t,\"low:\")+\" \",close:i(t,\"close:\")+\" \"}}),x}e.exports={calc:function(t,e){var r=a.getFromId(t,e.xaxis),i=a.getFromId(t,e.yaxis),s=function(t,e,r){var i=r._minDiff;if(!i){var a,s=t._fullData,l=[];for(i=1/0,a=0;a<s.length;a++){var c=s[a];if(\"ohlc\"===c.type&&!0===c.visible&&c.xaxis===e._id){l.push(c);var u=e.makeCalcdata(c,\"x\");c._origX=u;var f=o(r,e,\"x\",u);c._xcalc=f;var h=n.distinctVals(f).minDiff;h&&isFinite(h)&&(i=Math.min(i,h))}}for(i===1/0&&(i=1),a=0;a<l.length;a++)l[a]._minDiff=i}return i*r.tickwidth}(t,r,e),u=e._minDiff;e._minDiff=null;var f=e._origX;e._origX=null;var h=e._xcalc;e._xcalc=null;var p=c(t,e,f,h,i,l);return e._extremes[r._id]=a.findExtremes(r,h,{vpad:u/2}),p.length?(n.extendFlat(p[0].t,{wHover:u/2,tickLen:s}),p):[{t:{empty:!0}}]},calcCommon:c}},{\"../../constants/numerical\":775,\"../../lib\":799,\"../../plots/cartesian/align_period\":846,\"../../plots/cartesian/axes\":849}],1162:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./ohlc_defaults\"),a=t(\"../scatter/period_defaults\"),o=t(\"./attributes\");function s(t,e,r,n){r(n+\".line.color\"),r(n+\".line.width\",e.line.width),r(n+\".line.dash\",e.line.dash)}e.exports=function(t,e,r,l){function c(r,i){return n.coerce(t,e,o,r,i)}i(t,e,c,l)?(a(t,e,l,c,{x:!0}),c(\"xhoverformat\"),c(\"yhoverformat\"),c(\"line.width\"),c(\"line.dash\"),s(t,e,c,\"increasing\"),s(t,e,c,\"decreasing\"),c(\"text\"),c(\"hovertext\"),c(\"tickwidth\"),l._requestRangeslider[e.xaxis]=!0):e.visible=!1}},{\"../../lib\":799,\"../scatter/period_defaults\":1234,\"./attributes\":1160,\"./ohlc_defaults\":1165}],1163:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"../../lib\"),a=t(\"../../components/fx\"),o=t(\"../../components/color\"),s=t(\"../../lib\").fillText,l=t(\"../../constants/delta.js\"),c={increasing:l.INCREASING.SYMBOL,decreasing:l.DECREASING.SYMBOL};function u(t,e,r,n){var i,s,l=t.cd,c=t.xa,u=l[0].trace,f=l[0].t,h=u.type,p=\"ohlc\"===h?\"l\":\"min\",d=\"ohlc\"===h?\"h\":\"max\",m=f.bPos||0,g=f.bdPos||f.tickLen,v=f.wHover,y=Math.min(1,g/Math.abs(c.r2c(c.range[1])-c.r2c(c.range[0])));function x(t){var r=function(t){return t.pos+m-e}(t);return a.inbox(r-v,r+v,i)}function b(t){var e=t[p],n=t[d];return e===n||a.inbox(e-r,n-r,i)}function _(t){return(x(t)+b(t))/2}i=t.maxHoverDistance-y,s=t.maxSpikeDistance-y;var w=a.getDistanceFunction(n,x,b,_);if(a.getClosest(l,w,t),!1===t.index)return null;var T=l[t.index];if(T.empty)return null;var k=u[T.dir],M=k.line.color;return o.opacity(M)&&k.line.width?t.color=M:t.color=k.fillcolor,t.x0=c.c2p(T.pos+m-g,!0),t.x1=c.c2p(T.pos+m+g,!0),t.xLabelVal=void 0!==T.orig_p?T.orig_p:T.pos,t.spikeDistance=_(T)*s/i,t.xSpike=c.c2p(T.pos,!0),t}function f(t,e,r,a){var o=t.cd,s=t.ya,l=o[0].trace,c=o[0].t,f=[],h=u(t,e,r,a);if(!h)return[];var p=o[h.index].hi||l.hoverinfo,d=p.split(\"+\");if(!(\"all\"===p||-1!==d.indexOf(\"y\")))return[];for(var m=[\"high\",\"open\",\"close\",\"low\"],g={},v=0;v<m.length;v++){var y,x=m[v],b=l[x][h.index],_=s.c2p(b,!0);b in g?(y=g[b]).yLabel+=\"<br>\"+c.labels[x]+n.hoverLabelText(s,b,l.yhoverformat):((y=i.extendFlat({},h)).y0=y.y1=_,y.yLabelVal=b,y.yLabel=c.labels[x]+n.hoverLabelText(s,b,l.yhoverformat),y.name=\"\",f.push(y),g[b]=y)}return f}function h(t,e,r,i){var a=t.cd,o=t.ya,l=a[0].trace,f=a[0].t,h=u(t,e,r,i);if(!h)return[];var p=a[h.index],d=h.index=p.i,m=p.dir;function g(t){return f.labels[t]+n.hoverLabelText(o,l[t][d],l.yhoverformat)}var v=p.hi||l.hoverinfo,y=v.split(\"+\"),x=\"all\"===v,b=x||-1!==y.indexOf(\"y\"),_=x||-1!==y.indexOf(\"text\"),w=b?[g(\"open\"),g(\"high\"),g(\"low\"),g(\"close\")+\"  \"+c[m]]:[];return _&&s(p,l,w),h.extraText=w.join(\"<br>\"),h.y0=h.y1=o.c2p(p.yc,!0),[h]}e.exports={hoverPoints:function(t,e,r,n){return t.cd[0].trace.hoverlabel.split?f(t,e,r,n):h(t,e,r,n)},hoverSplit:f,hoverOnPoints:h}},{\"../../components/color\":662,\"../../components/fx\":702,\"../../constants/delta.js\":769,\"../../lib\":799,\"../../plots/cartesian/axes\":849}],1164:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"ohlc\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"showLegend\"],meta:{},attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\").calc,plot:t(\"./plot\"),style:t(\"./style\"),hoverPoints:t(\"./hover\").hoverPoints,selectPoints:t(\"./select\")}},{\"../../plots/cartesian\":863,\"./attributes\":1160,\"./calc\":1161,\"./defaults\":1162,\"./hover\":1163,\"./plot\":1166,\"./select\":1167,\"./style\":1168}],1165:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\");e.exports=function(t,e,r,a){var o=r(\"x\"),s=r(\"open\"),l=r(\"high\"),c=r(\"low\"),u=r(\"close\");if(r(\"hoverlabel.split\"),n.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\"],a),s&&l&&c&&u){var f=Math.min(s.length,l.length,c.length,u.length);return o&&(f=Math.min(f,i.minRowLength(o))),e._length=f,f}}},{\"../../lib\":799,\"../../registry\":927}],1166:[function(t,e,r){\"use strict\";var n=t(\"@plotly/d3\"),i=t(\"../../lib\");e.exports=function(t,e,r,a){var o=e.yaxis,s=e.xaxis,l=!!s.rangebreaks;i.makeTraceGroups(a,r,\"trace ohlc\").each((function(t){var e=n.select(this),r=t[0],a=r.t;if(!0!==r.trace.visible||a.empty)e.remove();else{var c=a.tickLen,u=e.selectAll(\"path\").data(i.identity);u.enter().append(\"path\"),u.exit().remove(),u.attr(\"d\",(function(t){if(t.empty)return\"M0,0Z\";var e=s.c2p(t.pos-c,!0),r=s.c2p(t.pos+c,!0),n=l?(e+r)/2:s.c2p(t.pos,!0);return\"M\"+e+\",\"+o.c2p(t.o,!0)+\"H\"+n+\"M\"+n+\",\"+o.c2p(t.h,!0)+\"V\"+o.c2p(t.l,!0)+\"M\"+r+\",\"+o.c2p(t.c,!0)+\"H\"+n}))}}))}},{\"../../lib\":799,\"@plotly/d3\":58}],1167:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r,n=t.cd,i=t.xaxis,a=t.yaxis,o=[],s=n[0].t.bPos||0;if(!1===e)for(r=0;r<n.length;r++)n[r].selected=0;else for(r=0;r<n.length;r++){var l=n[r];e.contains([i.c2p(l.pos+s),a.c2p(l.yc)],null,l.i,t)?(o.push({pointNumber:l.i,x:i.c2d(l.pos),y:a.c2d(l.yc)}),l.selected=1):l.selected=0}return o}},{}],1168:[function(t,e,r){\"use strict\";var n=t(\"@plotly/d3\"),i=t(\"../../components/drawing\"),a=t(\"../../components/color\");e.exports=function(t,e,r){var o=r||n.select(t).selectAll(\"g.ohlclayer\").selectAll(\"g.trace\");o.style(\"opacity\",(function(t){return t[0].trace.opacity})),o.each((function(t){var e=t[0].trace;n.select(this).selectAll(\"path\").each((function(t){if(!t.empty){var r=e[t.dir].line;n.select(this).style(\"fill\",\"none\").call(a.stroke,r.color).call(i.dashLine,r.dash,r.width).style(\"opacity\",e.selectedpoints&&!t.selected?.3:1)}}))}))}},{\"../../components/color\":662,\"../../components/drawing\":684,\"@plotly/d3\":58}],1169:[function(t,e,r){\"use strict\";var n=t(\"../../lib/extend\").extendFlat,i=t(\"../../plots/attributes\"),a=t(\"../../plots/font_attributes\"),o=t(\"../../components/colorscale/attributes\"),s=t(\"../../plots/template_attributes\").hovertemplateAttrs,l=t(\"../../plots/domain\").attributes,c=n({editType:\"calc\"},o(\"line\",{editTypeOverride:\"calc\"}),{shape:{valType:\"enumerated\",values:[\"linear\",\"hspline\"],dflt:\"linear\",editType:\"plot\"},hovertemplate:s({editType:\"plot\",arrayOk:!1},{keys:[\"count\",\"probability\"]})});e.exports={domain:l({name:\"parcats\",trace:!0,editType:\"calc\"}),hoverinfo:n({},i.hoverinfo,{flags:[\"count\",\"probability\"],editType:\"plot\",arrayOk:!1}),hoveron:{valType:\"enumerated\",values:[\"category\",\"color\",\"dimension\"],dflt:\"category\",editType:\"plot\"},hovertemplate:s({editType:\"plot\",arrayOk:!1},{keys:[\"count\",\"probability\",\"category\",\"categorycount\",\"colorcount\",\"bandcolorcount\"]}),arrangement:{valType:\"enumerated\",values:[\"perpendicular\",\"freeform\",\"fixed\"],dflt:\"perpendicular\",editType:\"plot\"},bundlecolors:{valType:\"boolean\",dflt:!0,editType:\"plot\"},sortpaths:{valType:\"enumerated\",values:[\"forward\",\"backward\"],dflt:\"forward\",editType:\"plot\"},labelfont:a({editType:\"calc\"}),tickfont:a({editType:\"calc\"}),dimensions:{_isLinkedToArray:\"dimension\",label:{valType:\"string\",editType:\"calc\"},categoryorder:{valType:\"enumerated\",values:[\"trace\",\"category ascending\",\"category descending\",\"array\"],dflt:\"trace\",editType:\"calc\"},categoryarray:{valType:\"data_array\",editType:\"calc\"},ticktext:{valType:\"data_array\",editType:\"calc\"},values:{valType:\"data_array\",dflt:[],editType:\"calc\"},displayindex:{valType:\"integer\",editType:\"calc\"},editType:\"calc\",visible:{valType:\"boolean\",dflt:!0,editType:\"calc\"}},line:c,counts:{valType:\"number\",min:0,dflt:1,arrayOk:!0,editType:\"calc\"},customdata:void 0,hoverlabel:void 0,ids:void 0,legendgroup:void 0,legendrank:void 0,opacity:void 0,selectedpoints:void 0,showlegend:void 0}},{\"../../components/colorscale/attributes\":669,\"../../lib/extend\":789,\"../../plots/attributes\":845,\"../../plots/domain\":877,\"../../plots/font_attributes\":878,\"../../plots/template_attributes\":922}],1170:[function(t,e,r){\"use strict\";var n=t(\"../../plots/get_data\").getModuleCalcData,i=t(\"./plot\");r.name=\"parcats\",r.plot=function(t,e,r,a){var o=n(t.calcdata,\"parcats\");if(o.length){var s=o[0];i(t,s,r,a)}},r.clean=function(t,e,r,n){var i=n._has&&n._has(\"parcats\"),a=e._has&&e._has(\"parcats\");i&&!a&&n._paperdiv.selectAll(\".parcats\").remove()}},{\"../../plots/get_data\":887,\"./plot\":1175}],1171:[function(t,e,r){\"use strict\";var n=t(\"../../lib/gup\").wrap,i=t(\"../../components/colorscale/helpers\").hasColorscale,a=t(\"../../components/colorscale/calc\"),o=t(\"../../lib/filter_unique.js\"),s=t(\"../../components/drawing\"),l=t(\"../../lib\"),c=t(\"fast-isnumeric\");function u(t,e,r){t.valueInds.push(e),t.count+=r}function f(t,e,r){return{categoryInds:t,color:e,rawColor:r,valueInds:[],count:0}}function h(t,e,r){t.valueInds.push(e),t.count+=r}e.exports=function(t,e){var r=l.filterVisible(e.dimensions);if(0===r.length)return[];var p,d,m,g=r.map((function(t){var e;if(\"trace\"===t.categoryorder)e=null;else if(\"array\"===t.categoryorder)e=t.categoryarray;else{e=o(t.values);for(var r=!0,n=0;n<e.length;n++)if(!c(e[n])){r=!1;break}e.sort(r?l.sorterAsc:void 0),\"category descending\"===t.categoryorder&&(e=e.reverse())}return function(t,e){e=null==e?[]:e.map((function(t){return t}));var r={},n={},i=[];e.forEach((function(t,e){r[t]=0,n[t]=e}));for(var a=0;a<t.length;a++){var o,s=t[a];void 0===r[s]?(r[s]=1,o=e.push(s)-1,n[s]=o):(r[s]++,o=n[s]),i.push(o)}var l=e.map((function(t){return r[t]}));return{uniqueValues:e,uniqueCounts:l,inds:i}}(t.values,e)}));p=l.isArrayOrTypedArray(e.counts)?e.counts:[e.counts],function(t){var e;if(function(t){for(var e=new Array(t.length),r=0;r<t.length;r++){if(t[r]<0||t[r]>=t.length)return!1;if(void 0!==e[t[r]])return!1;e[t[r]]=!0}return!0}(t.map((function(t){return t.displayindex}))))for(e=0;e<t.length;e++)t[e]._displayindex=t[e].displayindex;else for(e=0;e<t.length;e++)t[e]._displayindex=e}(r),r.forEach((function(t,e){!function(t,e){t._categoryarray=e.uniqueValues,null===t.ticktext||void 0===t.ticktext?t._ticktext=[]:t._ticktext=t.ticktext.slice();for(var r=t._ticktext.length;r<e.uniqueValues.length;r++)t._ticktext.push(e.uniqueValues[r])}(t,g[e])}));var v,y=e.line;y?(i(e,\"line\")&&a(t,e,{vals:e.line.color,containerStr:\"line\",cLetter:\"c\"}),v=s.tryColorscale(y)):v=l.identity;var x,b,_,w,T,k=r[0].values.length,M={},A=g.map((function(t){return t.inds}));for(m=0,x=0;x<k;x++){var S=[];for(b=0;b<A.length;b++)S.push(A[b][x]);d=p[x%p.length],m+=d;var E=(_=x,w=void 0,T=void 0,l.isArrayOrTypedArray(y.color)?T=w=y.color[_%y.color.length]:w=y.color,{color:v(w),rawColor:T}),L=S+\"-\"+E.rawColor;void 0===M[L]&&(M[L]=f(S,E.color,E.rawColor)),h(M[L],x,d)}var C,P=r.map((function(t,e){return function(t,e,r,n,i){return{dimensionInd:t,containerInd:e,displayInd:r,dimensionLabel:n,count:i,categories:[],dragX:null}}(e,t._index,t._displayindex,t.label,m)}));for(x=0;x<k;x++)for(d=p[x%p.length],b=0;b<P.length;b++){var I=P[b].containerInd,O=g[b].inds[x],z=P[b].categories;if(void 0===z[O]){var D=e.dimensions[I]._categoryarray[O],R=e.dimensions[I]._ticktext[O];z[O]={dimensionInd:b,categoryInd:C=O,categoryValue:D,displayInd:C,categoryLabel:R,valueInds:[],count:0,dragY:null}}u(z[O],x,d)}return n(function(t,e,r){var n=t.map((function(t){return t.categories.length})).reduce((function(t,e){return Math.max(t,e)}));return{dimensions:t,paths:e,trace:void 0,maxCats:n,count:r}}(P,M,m))}},{\"../../components/colorscale/calc\":670,\"../../components/colorscale/helpers\":673,\"../../components/drawing\":684,\"../../lib\":799,\"../../lib/filter_unique.js\":790,\"../../lib/gup\":796,\"fast-isnumeric\":245}],1172:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/colorscale/helpers\").hasColorscale,a=t(\"../../components/colorscale/defaults\"),o=t(\"../../plots/domain\").defaults,s=t(\"../../plots/array_container_defaults\"),l=t(\"./attributes\"),c=t(\"../parcoords/merge_length\");function u(t,e){function r(r,i){return n.coerce(t,e,l.dimensions,r,i)}var i=r(\"values\"),a=r(\"visible\");if(i&&i.length||(a=e.visible=!1),a){r(\"label\"),r(\"displayindex\",e._index);var o,s=t.categoryarray,c=Array.isArray(s)&&s.length>0;c&&(o=\"array\");var u=r(\"categoryorder\",o);\"array\"===u?(r(\"categoryarray\"),r(\"ticktext\")):(delete t.categoryarray,delete t.ticktext),c||\"array\"!==u||(e.categoryorder=\"trace\")}}e.exports=function(t,e,r,f){function h(r,i){return n.coerce(t,e,l,r,i)}var p=s(t,e,{name:\"dimensions\",handleItemDefaults:u}),d=function(t,e,r,o,s){s(\"line.shape\"),s(\"line.hovertemplate\");var l=s(\"line.color\",o.colorway[0]);if(i(t,\"line\")&&n.isArrayOrTypedArray(l)){if(l.length)return s(\"line.colorscale\"),a(t,e,o,s,{prefix:\"line.\",cLetter:\"c\"}),l.length;e.line.color=r}return 1/0}(t,e,r,f,h);o(e,f,h),Array.isArray(p)&&p.length||(e.visible=!1),c(e,p,\"values\",d),h(\"hoveron\"),h(\"hovertemplate\"),h(\"arrangement\"),h(\"bundlecolors\"),h(\"sortpaths\"),h(\"counts\");var m={family:f.font.family,size:Math.round(f.font.size),color:f.font.color};n.coerceFont(h,\"labelfont\",m);var g={family:f.font.family,size:Math.round(f.font.size/1.2),color:f.font.color};n.coerceFont(h,\"tickfont\",g)}},{\"../../components/colorscale/defaults\":672,\"../../components/colorscale/helpers\":673,\"../../lib\":799,\"../../plots/array_container_defaults\":844,\"../../plots/domain\":877,\"../parcoords/merge_length\":1185,\"./attributes\":1169}],1173:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\"),plot:t(\"./plot\"),colorbar:{container:\"line\",min:\"cmin\",max:\"cmax\"},moduleType:\"trace\",name:\"parcats\",basePlotModule:t(\"./base_plot\"),categories:[\"noOpacity\"],meta:{}}},{\"./attributes\":1169,\"./base_plot\":1170,\"./calc\":1171,\"./defaults\":1172,\"./plot\":1175}],1174:[function(t,e,r){\"use strict\";var n=t(\"@plotly/d3\"),i=t(\"../../plot_api/plot_api\"),a=t(\"../../components/fx\"),o=t(\"../../lib\"),s=o.strTranslate,l=t(\"../../components/drawing\"),c=t(\"tinycolor2\"),u=t(\"../../lib/svg_text_utils\");function f(t,e,r,i){var a=t.map(R.bind(0,e,r)),c=i.selectAll(\"g.parcatslayer\").data([null]);c.enter().append(\"g\").attr(\"class\",\"parcatslayer\").style(\"pointer-events\",\"all\");var f=c.selectAll(\"g.trace.parcats\").data(a,h),v=f.enter().append(\"g\").attr(\"class\",\"trace parcats\");f.attr(\"transform\",(function(t){return s(t.x,t.y)})),v.append(\"g\").attr(\"class\",\"paths\");var y=f.select(\"g.paths\").selectAll(\"path.path\").data((function(t){return t.paths}),h);y.attr(\"fill\",(function(t){return t.model.color}));var _=y.enter().append(\"path\").attr(\"class\",\"path\").attr(\"stroke-opacity\",0).attr(\"fill\",(function(t){return t.model.color})).attr(\"fill-opacity\",0);b(_),y.attr(\"d\",(function(t){return t.svgD})),_.empty()||y.sort(d),y.exit().remove(),y.on(\"mouseover\",m).on(\"mouseout\",g).on(\"click\",x),v.append(\"g\").attr(\"class\",\"dimensions\");var k=f.select(\"g.dimensions\").selectAll(\"g.dimension\").data((function(t){return t.dimensions}),h);k.enter().append(\"g\").attr(\"class\",\"dimension\"),k.attr(\"transform\",(function(t){return s(t.x,0)})),k.exit().remove();var M=k.selectAll(\"g.category\").data((function(t){return t.categories}),h),A=M.enter().append(\"g\").attr(\"class\",\"category\");M.attr(\"transform\",(function(t){return s(0,t.y)})),A.append(\"rect\").attr(\"class\",\"catrect\").attr(\"pointer-events\",\"none\"),M.select(\"rect.catrect\").attr(\"fill\",\"none\").attr(\"width\",(function(t){return t.width})).attr(\"height\",(function(t){return t.height})),w(A);var S=M.selectAll(\"rect.bandrect\").data((function(t){return t.bands}),h);S.each((function(){o.raiseToTop(this)})),S.attr(\"fill\",(function(t){return t.color}));var O=S.enter().append(\"rect\").attr(\"class\",\"bandrect\").attr(\"stroke-opacity\",0).attr(\"fill\",(function(t){return t.color})).attr(\"fill-opacity\",0);S.attr(\"fill\",(function(t){return t.color})).attr(\"width\",(function(t){return t.width})).attr(\"height\",(function(t){return t.height})).attr(\"y\",(function(t){return t.y})).attr(\"cursor\",(function(t){return\"fixed\"===t.parcatsViewModel.arrangement?\"default\":\"perpendicular\"===t.parcatsViewModel.arrangement?\"ns-resize\":\"move\"})),T(O),S.exit().remove(),A.append(\"text\").attr(\"class\",\"catlabel\").attr(\"pointer-events\",\"none\");var z=e._fullLayout.paper_bgcolor;M.select(\"text.catlabel\").attr(\"text-anchor\",(function(t){return p(t)?\"start\":\"end\"})).attr(\"alignment-baseline\",\"middle\").style(\"text-shadow\",u.makeTextShadow(z)).style(\"fill\",\"rgb(0, 0, 0)\").attr(\"x\",(function(t){return p(t)?t.width+5:-5})).attr(\"y\",(function(t){return t.height/2})).text((function(t){return t.model.categoryLabel})).each((function(t){l.font(n.select(this),t.parcatsViewModel.categorylabelfont),u.convertToTspans(n.select(this),e)})),A.append(\"text\").attr(\"class\",\"dimlabel\"),M.select(\"text.dimlabel\").attr(\"text-anchor\",\"middle\").attr(\"alignment-baseline\",\"baseline\").attr(\"cursor\",(function(t){return\"fixed\"===t.parcatsViewModel.arrangement?\"default\":\"ew-resize\"})).attr(\"x\",(function(t){return t.width/2})).attr(\"y\",-5).text((function(t,e){return 0===e?t.parcatsViewModel.model.dimensions[t.model.dimensionInd].dimensionLabel:null})).each((function(t){l.font(n.select(this),t.parcatsViewModel.labelfont)})),M.selectAll(\"rect.bandrect\").on(\"mouseover\",E).on(\"mouseout\",L),M.exit().remove(),k.call(n.behavior.drag().origin((function(t){return{x:t.x,y:0}})).on(\"dragstart\",C).on(\"drag\",P).on(\"dragend\",I)),f.each((function(t){t.traceSelection=n.select(this),t.pathSelection=n.select(this).selectAll(\"g.paths\").selectAll(\"path.path\"),t.dimensionSelection=n.select(this).selectAll(\"g.dimensions\").selectAll(\"g.dimension\")})),f.exit().remove()}function h(t){return t.key}function p(t){var e=t.parcatsViewModel.dimensions.length,r=t.parcatsViewModel.dimensions[e-1].model.dimensionInd;return t.model.dimensionInd===r}function d(t,e){return t.model.rawColor>e.model.rawColor?1:t.model.rawColor<e.model.rawColor?-1:0}function m(t){if(!t.parcatsViewModel.dragDimension&&-1===t.parcatsViewModel.hoverinfoItems.indexOf(\"skip\")){o.raiseToTop(this),_(n.select(this));var e=v(t),r=y(t);if(t.parcatsViewModel.graphDiv.emit(\"plotly_hover\",{points:e,event:n.event,constraints:r}),-1===t.parcatsViewModel.hoverinfoItems.indexOf(\"none\")){var i,s,l,u=n.mouse(this)[0],f=t.parcatsViewModel.graphDiv,h=t.parcatsViewModel.trace,p=f._fullLayout,d=p._paperdiv.node().getBoundingClientRect(),m=t.parcatsViewModel.graphDiv.getBoundingClientRect();for(l=0;l<t.leftXs.length-1;l++)if(t.leftXs[l]+t.dimWidths[l]-2<=u&&u<=t.leftXs[l+1]+2){var g=t.parcatsViewModel.dimensions[l],x=t.parcatsViewModel.dimensions[l+1];i=(g.x+g.width+x.x)/2,s=(t.topYs[l]+t.topYs[l+1]+t.height)/2;break}var b=t.parcatsViewModel.x+i,w=t.parcatsViewModel.y+s,T=c.mostReadable(t.model.color,[\"black\",\"white\"]),k=t.model.count,M=k/t.parcatsViewModel.model.count,A={countLabel:k,probabilityLabel:M.toFixed(3)},S=[];-1!==t.parcatsViewModel.hoverinfoItems.indexOf(\"count\")&&S.push([\"Count:\",A.countLabel].join(\" \")),-1!==t.parcatsViewModel.hoverinfoItems.indexOf(\"probability\")&&S.push([\"P:\",A.probabilityLabel].join(\" \"));var E=S.join(\"<br>\"),L=n.mouse(f)[0];a.loneHover({trace:h,x:b-d.left+m.left,y:w-d.top+m.top,text:E,color:t.model.color,borderColor:\"black\",fontFamily:'Monaco, \"Courier New\", monospace',fontSize:10,fontColor:T,idealAlign:L<b?\"right\":\"left\",hovertemplate:(h.line||{}).hovertemplate,hovertemplateLabels:A,eventData:[{data:h._input,fullData:h,count:k,probability:M}]},{container:p._hoverlayer.node(),outerContainer:p._paper.node(),gd:f})}}}function g(t){if(!t.parcatsViewModel.dragDimension&&(b(n.select(this)),a.loneUnhover(t.parcatsViewModel.graphDiv._fullLayout._hoverlayer.node()),t.parcatsViewModel.pathSelection.sort(d),-1===t.parcatsViewModel.hoverinfoItems.indexOf(\"skip\"))){var e=v(t),r=y(t);t.parcatsViewModel.graphDiv.emit(\"plotly_unhover\",{points:e,event:n.event,constraints:r})}}function v(t){for(var e=[],r=O(t.parcatsViewModel),n=0;n<t.model.valueInds.length;n++){var i=t.model.valueInds[n];e.push({curveNumber:r,pointNumber:i})}return e}function y(t){for(var e={},r=t.parcatsViewModel.model.dimensions,n=0;n<r.length;n++){var i=r[n],a=i.categories[t.model.categoryInds[n]];e[i.containerInd]=a.categoryValue}return void 0!==t.model.rawColor&&(e.color=t.model.rawColor),e}function x(t){if(-1===t.parcatsViewModel.hoverinfoItems.indexOf(\"skip\")){var e=v(t),r=y(t);t.parcatsViewModel.graphDiv.emit(\"plotly_click\",{points:e,event:n.event,constraints:r})}}function b(t){t.attr(\"fill\",(function(t){return t.model.color})).attr(\"fill-opacity\",.6).attr(\"stroke\",\"lightgray\").attr(\"stroke-width\",.2).attr(\"stroke-opacity\",1)}function _(t){t.attr(\"fill-opacity\",.8).attr(\"stroke\",(function(t){return c.mostReadable(t.model.color,[\"black\",\"white\"])})).attr(\"stroke-width\",.3)}function w(t){t.select(\"rect.catrect\").attr(\"stroke\",\"black\").attr(\"stroke-width\",1).attr(\"stroke-opacity\",1)}function T(t){t.attr(\"stroke\",\"black\").attr(\"stroke-width\",.2).attr(\"stroke-opacity\",1).attr(\"fill-opacity\",1)}function k(t){var e=t.parcatsViewModel.pathSelection,r=t.categoryViewModel.model.dimensionInd,n=t.categoryViewModel.model.categoryInd;return e.filter((function(e){return e.model.categoryInds[r]===n&&e.model.color===t.color}))}function M(t,e,r){var i=n.select(t).datum(),a=i.categoryViewModel.model,o=i.parcatsViewModel.graphDiv,s=n.select(t.parentNode).selectAll(\"rect.bandrect\"),l=[];s.each((function(t){k(t).each((function(t){Array.prototype.push.apply(l,v(t))}))}));var c={};c[a.dimensionInd]=a.categoryValue,o.emit(e,{points:l,event:r,constraints:c})}function A(t,e,r){var i=n.select(t).datum(),a=i.categoryViewModel.model,o=i.parcatsViewModel.graphDiv,s=k(i),l=[];s.each((function(t){Array.prototype.push.apply(l,v(t))}));var c={};c[a.dimensionInd]=a.categoryValue,void 0!==i.rawColor&&(c.color=i.rawColor),o.emit(e,{points:l,event:r,constraints:c})}function S(t,e,r){t._fullLayout._calcInverseTransform(t);var i,a,o=t._fullLayout._invScaleX,s=t._fullLayout._invScaleY,l=n.select(r.parentNode).select(\"rect.catrect\"),c=l.node().getBoundingClientRect(),u=l.datum(),f=u.parcatsViewModel,h=f.model.dimensions[u.model.dimensionInd],p=f.trace,d=c.top+c.height/2;f.dimensions.length>1&&h.displayInd===f.dimensions.length-1?(i=c.left,a=\"left\"):(i=c.left+c.width,a=\"right\");var m=u.model.count,g=u.model.categoryLabel,v=m/u.parcatsViewModel.model.count,y={countLabel:m,categoryLabel:g,probabilityLabel:v.toFixed(3)},x=[];-1!==u.parcatsViewModel.hoverinfoItems.indexOf(\"count\")&&x.push([\"Count:\",y.countLabel].join(\" \")),-1!==u.parcatsViewModel.hoverinfoItems.indexOf(\"probability\")&&x.push([\"P(\"+y.categoryLabel+\"):\",y.probabilityLabel].join(\" \"));var b=x.join(\"<br>\");return{trace:p,x:o*(i-e.left),y:s*(d-e.top),text:b,color:\"lightgray\",borderColor:\"black\",fontFamily:'Monaco, \"Courier New\", monospace',fontSize:12,fontColor:\"black\",idealAlign:a,hovertemplate:p.hovertemplate,hovertemplateLabels:y,eventData:[{data:p._input,fullData:p,count:m,category:g,probability:v}]}}function E(t){if(!t.parcatsViewModel.dragDimension&&-1===t.parcatsViewModel.hoverinfoItems.indexOf(\"skip\")){if(n.mouse(this)[1]<-1)return;var e,r=t.parcatsViewModel.graphDiv,i=r._fullLayout,s=i._paperdiv.node().getBoundingClientRect(),l=t.parcatsViewModel.hoveron;if(\"color\"===l?(!function(t){var e=n.select(t).datum(),r=k(e);_(r),r.each((function(){o.raiseToTop(this)})),n.select(t.parentNode).selectAll(\"rect.bandrect\").filter((function(t){return t.color===e.color})).each((function(){o.raiseToTop(this),n.select(this).attr(\"stroke\",\"black\").attr(\"stroke-width\",1.5)}))}(this),A(this,\"plotly_hover\",n.event)):(!function(t){n.select(t.parentNode).selectAll(\"rect.bandrect\").each((function(t){var e=k(t);_(e),e.each((function(){o.raiseToTop(this)}))})),n.select(t.parentNode).select(\"rect.catrect\").attr(\"stroke\",\"black\").attr(\"stroke-width\",2.5)}(this),M(this,\"plotly_hover\",n.event)),-1===t.parcatsViewModel.hoverinfoItems.indexOf(\"none\"))\"category\"===l?e=S(r,s,this):\"color\"===l?e=function(t,e,r){t._fullLayout._calcInverseTransform(t);var i,a,o=t._fullLayout._invScaleX,s=t._fullLayout._invScaleY,l=r.getBoundingClientRect(),u=n.select(r).datum(),f=u.categoryViewModel,h=f.parcatsViewModel,p=h.model.dimensions[f.model.dimensionInd],d=h.trace,m=l.y+l.height/2;h.dimensions.length>1&&p.displayInd===h.dimensions.length-1?(i=l.left,a=\"left\"):(i=l.left+l.width,a=\"right\");var g=f.model.categoryLabel,v=u.parcatsViewModel.model.count,y=0;u.categoryViewModel.bands.forEach((function(t){t.color===u.color&&(y+=t.count)}));var x=f.model.count,b=0;h.pathSelection.each((function(t){t.model.color===u.color&&(b+=t.model.count)}));var _=y/v,w=y/b,T=y/x,k={countLabel:v,categoryLabel:g,probabilityLabel:_.toFixed(3)},M=[];-1!==f.parcatsViewModel.hoverinfoItems.indexOf(\"count\")&&M.push([\"Count:\",k.countLabel].join(\" \")),-1!==f.parcatsViewModel.hoverinfoItems.indexOf(\"probability\")&&(M.push(\"P(color \\u2229 \"+g+\"): \"+k.probabilityLabel),M.push(\"P(\"+g+\" | color): \"+w.toFixed(3)),M.push(\"P(color | \"+g+\"): \"+T.toFixed(3)));var A=M.join(\"<br>\"),S=c.mostReadable(u.color,[\"black\",\"white\"]);return{trace:d,x:o*(i-e.left),y:s*(m-e.top),text:A,color:u.color,borderColor:\"black\",fontFamily:'Monaco, \"Courier New\", monospace',fontColor:S,fontSize:10,idealAlign:a,hovertemplate:d.hovertemplate,hovertemplateLabels:k,eventData:[{data:d._input,fullData:d,category:g,count:v,probability:_,categorycount:x,colorcount:b,bandcolorcount:y}]}}(r,s,this):\"dimension\"===l&&(e=function(t,e,r){var i=[];return n.select(r.parentNode.parentNode).selectAll(\"g.category\").select(\"rect.catrect\").each((function(){i.push(S(t,e,this))})),i}(r,s,this)),e&&a.loneHover(e,{container:i._hoverlayer.node(),outerContainer:i._paper.node(),gd:r})}}function L(t){var e=t.parcatsViewModel;if(!e.dragDimension&&(b(e.pathSelection),w(e.dimensionSelection.selectAll(\"g.category\")),T(e.dimensionSelection.selectAll(\"g.category\").selectAll(\"rect.bandrect\")),a.loneUnhover(e.graphDiv._fullLayout._hoverlayer.node()),e.pathSelection.sort(d),-1===e.hoverinfoItems.indexOf(\"skip\"))){\"color\"===t.parcatsViewModel.hoveron?A(this,\"plotly_unhover\",n.event):M(this,\"plotly_unhover\",n.event)}}function C(t){\"fixed\"!==t.parcatsViewModel.arrangement&&(t.dragDimensionDisplayInd=t.model.displayInd,t.initialDragDimensionDisplayInds=t.parcatsViewModel.model.dimensions.map((function(t){return t.displayInd})),t.dragHasMoved=!1,t.dragCategoryDisplayInd=null,n.select(this).selectAll(\"g.category\").select(\"rect.catrect\").each((function(e){var r=n.mouse(this)[0],i=n.mouse(this)[1];-2<=r&&r<=e.width+2&&-2<=i&&i<=e.height+2&&(t.dragCategoryDisplayInd=e.model.displayInd,t.initialDragCategoryDisplayInds=t.model.categories.map((function(t){return t.displayInd})),e.model.dragY=e.y,o.raiseToTop(this.parentNode),n.select(this.parentNode).selectAll(\"rect.bandrect\").each((function(e){e.y<i&&i<=e.y+e.height&&(t.potentialClickBand=this)})))})),t.parcatsViewModel.dragDimension=t,a.loneUnhover(t.parcatsViewModel.graphDiv._fullLayout._hoverlayer.node()))}function P(t){if(\"fixed\"!==t.parcatsViewModel.arrangement&&(t.dragHasMoved=!0,null!==t.dragDimensionDisplayInd)){var e=t.dragDimensionDisplayInd,r=e-1,i=e+1,a=t.parcatsViewModel.dimensions[e];if(null!==t.dragCategoryDisplayInd){var o=a.categories[t.dragCategoryDisplayInd];o.model.dragY+=n.event.dy;var s=o.model.dragY,l=o.model.displayInd,c=a.categories,u=c[l-1],f=c[l+1];void 0!==u&&s<u.y+u.height/2&&(o.model.displayInd=u.model.displayInd,u.model.displayInd=l),void 0!==f&&s+o.height>f.y+f.height/2&&(o.model.displayInd=f.model.displayInd,f.model.displayInd=l),t.dragCategoryDisplayInd=o.model.displayInd}if(null===t.dragCategoryDisplayInd||\"freeform\"===t.parcatsViewModel.arrangement){a.model.dragX=n.event.x;var h=t.parcatsViewModel.dimensions[r],p=t.parcatsViewModel.dimensions[i];void 0!==h&&a.model.dragX<h.x+h.width&&(a.model.displayInd=h.model.displayInd,h.model.displayInd=e),void 0!==p&&a.model.dragX+a.width>p.x&&(a.model.displayInd=p.model.displayInd,p.model.displayInd=t.dragDimensionDisplayInd),t.dragDimensionDisplayInd=a.model.displayInd}N(t.parcatsViewModel),B(t.parcatsViewModel),D(t.parcatsViewModel),z(t.parcatsViewModel)}}function I(t){if(\"fixed\"!==t.parcatsViewModel.arrangement&&null!==t.dragDimensionDisplayInd){n.select(this).selectAll(\"text\").attr(\"font-weight\",\"normal\");var e={},r=O(t.parcatsViewModel),a=t.parcatsViewModel.model.dimensions.map((function(t){return t.displayInd})),o=t.initialDragDimensionDisplayInds.some((function(t,e){return t!==a[e]}));o&&a.forEach((function(r,n){var i=t.parcatsViewModel.model.dimensions[n].containerInd;e[\"dimensions[\"+i+\"].displayindex\"]=r}));var s=!1;if(null!==t.dragCategoryDisplayInd){var l=t.model.categories.map((function(t){return t.displayInd}));if(s=t.initialDragCategoryDisplayInds.some((function(t,e){return t!==l[e]}))){var c=t.model.categories.slice().sort((function(t,e){return t.displayInd-e.displayInd})),u=c.map((function(t){return t.categoryValue})),f=c.map((function(t){return t.categoryLabel}));e[\"dimensions[\"+t.model.containerInd+\"].categoryarray\"]=[u],e[\"dimensions[\"+t.model.containerInd+\"].ticktext\"]=[f],e[\"dimensions[\"+t.model.containerInd+\"].categoryorder\"]=\"array\"}}if(-1===t.parcatsViewModel.hoverinfoItems.indexOf(\"skip\")&&!t.dragHasMoved&&t.potentialClickBand&&(\"color\"===t.parcatsViewModel.hoveron?A(t.potentialClickBand,\"plotly_click\",n.event.sourceEvent):M(t.potentialClickBand,\"plotly_click\",n.event.sourceEvent)),t.model.dragX=null,null!==t.dragCategoryDisplayInd)t.parcatsViewModel.dimensions[t.dragDimensionDisplayInd].categories[t.dragCategoryDisplayInd].model.dragY=null,t.dragCategoryDisplayInd=null;t.dragDimensionDisplayInd=null,t.parcatsViewModel.dragDimension=null,t.dragHasMoved=null,t.potentialClickBand=null,N(t.parcatsViewModel),B(t.parcatsViewModel),n.transition().duration(300).ease(\"cubic-in-out\").each((function(){D(t.parcatsViewModel,!0),z(t.parcatsViewModel,!0)})).each(\"end\",(function(){(o||s)&&i.restyle(t.parcatsViewModel.graphDiv,e,[r])}))}}function O(t){for(var e,r=t.graphDiv._fullData,n=0;n<r.length;n++)if(t.key===r[n].uid){e=n;break}return e}function z(t,e){var r;void 0===e&&(e=!1),t.pathSelection.data((function(t){return t.paths}),h),(r=t.pathSelection,e?r.transition():r).attr(\"d\",(function(t){return t.svgD}))}function D(t,e){function r(t){return e?t.transition():t}void 0===e&&(e=!1),t.dimensionSelection.data((function(t){return t.dimensions}),h);var i=t.dimensionSelection.selectAll(\"g.category\").data((function(t){return t.categories}),h);r(t.dimensionSelection).attr(\"transform\",(function(t){return s(t.x,0)})),r(i).attr(\"transform\",(function(t){return s(0,t.y)})),i.select(\".dimlabel\").text((function(t,e){return 0===e?t.parcatsViewModel.model.dimensions[t.model.dimensionInd].dimensionLabel:null})),i.select(\".catlabel\").attr(\"text-anchor\",(function(t){return p(t)?\"start\":\"end\"})).attr(\"x\",(function(t){return p(t)?t.width+5:-5})).each((function(t){var e,r;p(t)?(e=t.width+5,r=\"start\"):(e=-5,r=\"end\"),n.select(this).selectAll(\"tspan\").attr(\"x\",e).attr(\"text-anchor\",r)}));var a=i.selectAll(\"rect.bandrect\").data((function(t){return t.bands}),h),l=a.enter().append(\"rect\").attr(\"class\",\"bandrect\").attr(\"cursor\",\"move\").attr(\"stroke-opacity\",0).attr(\"fill\",(function(t){return t.color})).attr(\"fill-opacity\",0);a.attr(\"fill\",(function(t){return t.color})).attr(\"width\",(function(t){return t.width})).attr(\"height\",(function(t){return t.height})).attr(\"y\",(function(t){return t.y})),T(l),a.each((function(){o.raiseToTop(this)})),a.exit().remove()}function R(t,e,r){var n,i=r[0],a=e.margin||{l:80,r:80,t:100,b:80},o=i.trace,s=o.domain,l=e.width,c=e.height,u=Math.floor(l*(s.x[1]-s.x[0])),f=Math.floor(c*(s.y[1]-s.y[0])),h=s.x[0]*l+a.l,p=e.height-s.y[1]*e.height+a.t,d=o.line.shape;n=\"all\"===o.hoverinfo?[\"count\",\"probability\"]:(o.hoverinfo||\"\").split(\"+\");var m={trace:o,key:o.uid,model:i,x:h,y:p,width:u,height:f,hoveron:o.hoveron,hoverinfoItems:n,arrangement:o.arrangement,bundlecolors:o.bundlecolors,sortpaths:o.sortpaths,labelfont:o.labelfont,categorylabelfont:o.tickfont,pathShape:d,dragDimension:null,margin:a,paths:[],dimensions:[],graphDiv:t,traceSelection:null,pathSelection:null,dimensionSelection:null};return i.dimensions&&(N(m),B(m)),m}function F(t,e,r,i,a){var o,s,l=[],c=[];for(s=0;s<r.length-1;s++)o=n.interpolateNumber(r[s]+t[s],t[s+1]),l.push(o(a)),c.push(o(1-a));var u=\"M \"+t[0]+\",\"+e[0];for(u+=\"l\"+r[0]+\",0 \",s=1;s<r.length;s++)u+=\"C\"+l[s-1]+\",\"+e[s-1]+\" \"+c[s-1]+\",\"+e[s]+\" \"+t[s]+\",\"+e[s],u+=\"l\"+r[s]+\",0 \";for(u+=\"l0,\"+i+\" \",u+=\"l -\"+r[r.length-1]+\",0 \",s=r.length-2;s>=0;s--)u+=\"C\"+c[s]+\",\"+(e[s+1]+i)+\" \"+l[s]+\",\"+(e[s]+i)+\" \"+(t[s]+r[s])+\",\"+(e[s]+i),u+=\"l-\"+r[s]+\",0 \";return u+=\"Z\"}function B(t){var e=t.dimensions,r=t.model,n=e.map((function(t){return t.categories.map((function(t){return t.y}))})),i=t.model.dimensions.map((function(t){return t.categories.map((function(t){return t.displayInd}))})),a=t.model.dimensions.map((function(t){return t.displayInd})),o=t.dimensions.map((function(t){return t.model.dimensionInd})),s=e.map((function(t){return t.x})),l=e.map((function(t){return t.width})),c=[];for(var u in r.paths)r.paths.hasOwnProperty(u)&&c.push(r.paths[u]);function f(t){var e=t.categoryInds.map((function(t,e){return i[e][t]}));return o.map((function(t){return e[t]}))}c.sort((function(e,r){var n=f(e),i=f(r);return\"backward\"===t.sortpaths&&(n.reverse(),i.reverse()),n.push(e.valueInds[0]),i.push(r.valueInds[0]),t.bundlecolors&&(n.unshift(e.rawColor),i.unshift(r.rawColor)),n<i?-1:n>i?1:0}));for(var h=new Array(c.length),p=e[0].model.count,d=e[0].categories.map((function(t){return t.height})).reduce((function(t,e){return t+e})),m=0;m<c.length;m++){var g,v=c[m];g=p>0?d*(v.count/p):0;for(var y,x=new Array(n.length),b=0;b<v.categoryInds.length;b++){var _=v.categoryInds[b],w=i[b][_],T=a[b];x[T]=n[T][w],n[T][w]+=g;var k=t.dimensions[T].categories[w],M=k.bands.length,A=k.bands[M-1];if(void 0===A||v.rawColor!==A.rawColor){var S=void 0===A?0:A.y+A.height;k.bands.push({key:S,color:v.color,rawColor:v.rawColor,height:g,width:k.width,count:v.count,y:S,categoryViewModel:k,parcatsViewModel:t})}else{var E=k.bands[M-1];E.height+=g,E.count+=v.count}}y=\"hspline\"===t.pathShape?F(s,x,l,g,.5):F(s,x,l,g,0),h[m]={key:v.valueInds[0],model:v,height:g,leftXs:s,topYs:x,dimWidths:l,svgD:y,parcatsViewModel:t}}t.paths=h}function N(t){var e=t.model.dimensions.map((function(t){return{displayInd:t.displayInd,dimensionInd:t.dimensionInd}}));e.sort((function(t,e){return t.displayInd-e.displayInd}));var r=[];for(var n in e){var i=e[n].dimensionInd,a=t.model.dimensions[i];r.push(j(t,a))}t.dimensions=r}function j(t,e){var r,n=t.model.dimensions.length,i=e.displayInd;r=40+(n>1?(t.width-80-16)/(n-1):0)*i;var a,o,s,l,c,u=[],f=t.model.maxCats,h=e.categories.length,p=e.count,d=t.height-8*(f-1),m=8*(f-h)/2,g=e.categories.map((function(t){return{displayInd:t.displayInd,categoryInd:t.categoryInd}}));for(g.sort((function(t,e){return t.displayInd-e.displayInd})),c=0;c<h;c++)l=g[c].categoryInd,o=e.categories[l],a=p>0?o.count/p*d:0,s={key:o.valueInds[0],model:o,width:16,height:a,y:null!==o.dragY?o.dragY:m,bands:[],parcatsViewModel:t},m=m+a+8,u.push(s);return{key:e.dimensionInd,x:null!==e.dragX?e.dragX:r,y:0,width:16,model:e,categories:u,parcatsViewModel:t,dragCategoryDisplayInd:null,dragDimensionDisplayInd:null,initialDragDimensionDisplayInds:null,initialDragCategoryDisplayInds:null,dragHasMoved:null,potentialClickBand:null}}e.exports=function(t,e,r,n){f(r,t,n,e)}},{\"../../components/drawing\":684,\"../../components/fx\":702,\"../../lib\":799,\"../../lib/svg_text_utils\":824,\"../../plot_api/plot_api\":835,\"@plotly/d3\":58,tinycolor2:594}],1175:[function(t,e,r){\"use strict\";var n=t(\"./parcats\");e.exports=function(t,e,r,i){var a=t._fullLayout,o=a._paper,s=a._size;n(t,o,e,{width:s.w,height:s.h,margin:{t:s.t,r:s.r,b:s.b,l:s.l}},r,i)}},{\"./parcats\":1174}],1176:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/attributes\"),i=t(\"../../plots/cartesian/layout_attributes\"),a=t(\"../../plots/font_attributes\"),o=t(\"../../plots/domain\").attributes,s=t(\"../../lib/extend\").extendFlat,l=t(\"../../plot_api/plot_template\").templatedArray;e.exports={domain:o({name:\"parcoords\",trace:!0,editType:\"plot\"}),labelangle:{valType:\"angle\",dflt:0,editType:\"plot\"},labelside:{valType:\"enumerated\",values:[\"top\",\"bottom\"],dflt:\"top\",editType:\"plot\"},labelfont:a({editType:\"plot\"}),tickfont:a({editType:\"plot\"}),rangefont:a({editType:\"plot\"}),dimensions:l(\"dimension\",{label:{valType:\"string\",editType:\"plot\"},tickvals:s({},i.tickvals,{editType:\"plot\"}),ticktext:s({},i.ticktext,{editType:\"plot\"}),tickformat:s({},i.tickformat,{editType:\"plot\"}),visible:{valType:\"boolean\",dflt:!0,editType:\"plot\"},range:{valType:\"info_array\",items:[{valType:\"number\",editType:\"plot\"},{valType:\"number\",editType:\"plot\"}],editType:\"plot\"},constraintrange:{valType:\"info_array\",freeLength:!0,dimensions:\"1-2\",items:[{valType:\"number\",editType:\"plot\"},{valType:\"number\",editType:\"plot\"}],editType:\"plot\"},multiselect:{valType:\"boolean\",dflt:!0,editType:\"plot\"},values:{valType:\"data_array\",editType:\"calc\"},editType:\"calc\"}),line:s({editType:\"calc\"},n(\"line\",{colorscaleDflt:\"Viridis\",autoColorDflt:!1,editTypeOverride:\"calc\"}))}},{\"../../components/colorscale/attributes\":669,\"../../lib/extend\":789,\"../../plot_api/plot_template\":838,\"../../plots/cartesian/layout_attributes\":864,\"../../plots/domain\":877,\"../../plots/font_attributes\":878}],1177:[function(t,e,r){\"use strict\";var n=t(\"./constants\"),i=t(\"@plotly/d3\"),a=t(\"../../lib/gup\").keyFun,o=t(\"../../lib/gup\").repeat,s=t(\"../../lib\").sorterAsc,l=t(\"../../lib\").strTranslate,c=n.bar.snapRatio;function u(t,e){return t*(1-c)+e*c}var f=n.bar.snapClose;function h(t,e){return t*(1-f)+e*f}function p(t,e,r,n){if(function(t,e){for(var r=0;r<e.length;r++)if(t>=e[r][0]&&t<=e[r][1])return!0;return!1}(r,n))return r;var i=t?-1:1,a=0,o=e.length-1;if(i<0){var s=a;a=o,o=s}for(var l=e[a],c=l,f=a;i*f<i*o;f+=i){var p=f+i,d=e[p];if(i*r<i*h(l,d))return u(l,c);if(i*r<i*d||p===o)return u(d,l);c=l,l=d}}function d(t){t.attr(\"x\",-n.bar.captureWidth/2).attr(\"width\",n.bar.captureWidth)}function m(t){t.attr(\"visibility\",\"visible\").style(\"visibility\",\"visible\").attr(\"fill\",\"yellow\").attr(\"opacity\",0)}function g(t){if(!t.brush.filterSpecified)return\"0,\"+t.height;for(var e,r,n,i=v(t.brush.filter.getConsolidated(),t.height),a=[0],o=i.length?i[0][0]:null,s=0;s<i.length;s++)r=(e=i[s])[1]-e[0],a.push(o),a.push(r),(n=s+1)<i.length&&(o=i[n][0]-e[1]);return a.push(t.height),a}function v(t,e){return t.map((function(t){return t.map((function(t){return Math.max(0,t*e)})).sort(s)}))}function y(){i.select(document.body).style(\"cursor\",null)}function x(t){t.attr(\"stroke-dasharray\",g)}function b(t,e){var r=i.select(t).selectAll(\".highlight, .highlight-shadow\");x(e?r.transition().duration(n.bar.snapDuration).each(\"end\",e):r)}function _(t,e){var r,i=t.brush,a=NaN,o={};if(i.filterSpecified){var s=t.height,l=i.filter.getConsolidated(),c=v(l,s),u=NaN,f=NaN,h=NaN;for(r=0;r<=c.length;r++){var p=c[r];if(p&&p[0]<=e&&e<=p[1]){u=r;break}if(f=r?r-1:NaN,p&&p[0]>e){h=r;break}}if(a=u,isNaN(a)&&(a=isNaN(f)||isNaN(h)?isNaN(f)?h:f:e-c[f][1]<c[h][0]-e?f:h),!isNaN(a)){var d=c[a],m=function(t,e){var r=n.bar.handleHeight;if(!(e>t[1]+r||e<t[0]-r))return e>=.9*t[1]+.1*t[0]?\"n\":e<=.9*t[0]+.1*t[1]?\"s\":\"ns\"}(d,e);m&&(o.interval=l[a],o.intervalPix=d,o.region=m)}}if(t.ordinal&&!o.region){var g=t.unitTickvals,y=t.unitToPaddedPx.invert(e);for(r=0;r<g.length;r++){var x=[.25*g[Math.max(r-1,0)]+.75*g[r],.25*g[Math.min(r+1,g.length-1)]+.75*g[r]];if(y>=x[0]&&y<=x[1]){o.clickableOrdinalRange=x;break}}}return o}function w(t,e){i.event.sourceEvent.stopPropagation();var r=e.height-i.mouse(t)[1]-2*n.verticalPadding,a=e.brush.svgBrush;a.wasDragged=!0,a._dragging=!0,a.grabbingBar?a.newExtent=[r-a.grabPoint,r+a.barLength-a.grabPoint].map(e.unitToPaddedPx.invert):a.newExtent=[a.startExtent,e.unitToPaddedPx.invert(r)].sort(s),e.brush.filterSpecified=!0,a.extent=a.stayingIntervals.concat([a.newExtent]),a.brushCallback(e),b(t.parentNode)}function T(t,e){var r=_(e,e.height-i.mouse(t)[1]-2*n.verticalPadding),a=\"crosshair\";r.clickableOrdinalRange?a=\"pointer\":r.region&&(a=r.region+\"-resize\"),i.select(document.body).style(\"cursor\",a)}function k(t){t.on(\"mousemove\",(function(t){i.event.preventDefault(),t.parent.inBrushDrag||T(this,t)})).on(\"mouseleave\",(function(t){t.parent.inBrushDrag||y()})).call(i.behavior.drag().on(\"dragstart\",(function(t){!function(t,e){i.event.sourceEvent.stopPropagation();var r=e.height-i.mouse(t)[1]-2*n.verticalPadding,a=e.unitToPaddedPx.invert(r),o=e.brush,s=_(e,r),l=s.interval,c=o.svgBrush;if(c.wasDragged=!1,c.grabbingBar=\"ns\"===s.region,c.grabbingBar){var u=l.map(e.unitToPaddedPx);c.grabPoint=r-u[0]-n.verticalPadding,c.barLength=u[1]-u[0]}c.clickableOrdinalRange=s.clickableOrdinalRange,c.stayingIntervals=e.multiselect&&o.filterSpecified?o.filter.getConsolidated():[],l&&(c.stayingIntervals=c.stayingIntervals.filter((function(t){return t[0]!==l[0]&&t[1]!==l[1]}))),c.startExtent=s.region?l[\"s\"===s.region?1:0]:a,e.parent.inBrushDrag=!0,c.brushStartCallback()}(this,t)})).on(\"drag\",(function(t){w(this,t)})).on(\"dragend\",(function(t){!function(t,e){var r=e.brush,n=r.filter,a=r.svgBrush;a._dragging||(T(t,e),w(t,e),e.brush.svgBrush.wasDragged=!1),a._dragging=!1,i.event.sourceEvent.stopPropagation();var o=a.grabbingBar;if(a.grabbingBar=!1,a.grabLocation=void 0,e.parent.inBrushDrag=!1,y(),!a.wasDragged)return a.wasDragged=void 0,a.clickableOrdinalRange?r.filterSpecified&&e.multiselect?a.extent.push(a.clickableOrdinalRange):(a.extent=[a.clickableOrdinalRange],r.filterSpecified=!0):o?(a.extent=a.stayingIntervals,0===a.extent.length&&A(r)):A(r),a.brushCallback(e),b(t.parentNode),void a.brushEndCallback(r.filterSpecified?n.getConsolidated():[]);var s=function(){n.set(n.getConsolidated())};if(e.ordinal){var l=e.unitTickvals;l[l.length-1]<l[0]&&l.reverse(),a.newExtent=[p(0,l,a.newExtent[0],a.stayingIntervals),p(1,l,a.newExtent[1],a.stayingIntervals)];var c=a.newExtent[1]>a.newExtent[0];a.extent=a.stayingIntervals.concat(c?[a.newExtent]:[]),a.extent.length||A(r),a.brushCallback(e),c?b(t.parentNode,s):(s(),b(t.parentNode))}else s();a.brushEndCallback(r.filterSpecified?n.getConsolidated():[])}(this,t)})))}function M(t,e){return t[0]-e[0]}function A(t){t.filterSpecified=!1,t.svgBrush.extent=[[-1/0,1/0]]}function S(t){for(var e,r=t.slice(),n=[],i=r.shift();i;){for(e=i.slice();(i=r.shift())&&i[0]<=e[1];)e[1]=Math.max(e[1],i[1]);n.push(e)}return 1===n.length&&n[0][0]>n[0][1]&&(n=[]),n}e.exports={makeBrush:function(t,e,r,n,i,a){var o,l=function(){var t,e,r=[];return{set:function(n){1===(r=n.map((function(t){return t.slice().sort(s)})).sort(M)).length&&r[0][0]===-1/0&&r[0][1]===1/0&&(r=[[0,-1]]),t=S(r),e=r.reduce((function(t,e){return[Math.min(t[0],e[0]),Math.max(t[1],e[1])]}),[1/0,-1/0])},get:function(){return r.slice()},getConsolidated:function(){return t},getBounds:function(){return e}}}();return l.set(r),{filter:l,filterSpecified:e,svgBrush:{extent:[],brushStartCallback:n,brushCallback:(o=i,function(t){var e=t.brush,r=function(t){return t.svgBrush.extent.map((function(t){return t.slice()}))}(e).slice();e.filter.set(r),o()}),brushEndCallback:a}}},ensureAxisBrush:function(t,e){var r=t.selectAll(\".\"+n.cn.axisBrush).data(o,a);r.enter().append(\"g\").classed(n.cn.axisBrush,!0),function(t,e){var r=t.selectAll(\".background\").data(o);r.enter().append(\"rect\").classed(\"background\",!0).call(d).call(m).style(\"pointer-events\",\"auto\").attr(\"transform\",l(0,n.verticalPadding)),r.call(k).attr(\"height\",(function(t){return t.height-n.verticalPadding}));var i=t.selectAll(\".highlight-shadow\").data(o);i.enter().append(\"line\").classed(\"highlight-shadow\",!0).attr(\"x\",-n.bar.width/2).attr(\"stroke-width\",n.bar.width+n.bar.strokeWidth).attr(\"stroke\",e).attr(\"opacity\",n.bar.strokeOpacity).attr(\"stroke-linecap\",\"butt\"),i.attr(\"y1\",(function(t){return t.height})).call(x);var a=t.selectAll(\".highlight\").data(o);a.enter().append(\"line\").classed(\"highlight\",!0).attr(\"x\",-n.bar.width/2).attr(\"stroke-width\",n.bar.width-n.bar.strokeWidth).attr(\"stroke\",n.bar.fillColor).attr(\"opacity\",n.bar.fillOpacity).attr(\"stroke-linecap\",\"butt\"),a.attr(\"y1\",(function(t){return t.height})).call(x)}(r,e)},cleanRanges:function(t,e){if(Array.isArray(t[0])?(t=t.map((function(t){return t.sort(s)})),t=e.multiselect?S(t.sort(M)):[t[0]]):t=[t.sort(s)],e.tickvals){var r=e.tickvals.slice().sort(s);if(!(t=t.map((function(t){var e=[p(0,r,t[0],[]),p(1,r,t[1],[])];if(e[1]>e[0])return e})).filter((function(t){return t}))).length)return}return t.length>1?t:t[0]}}},{\"../../lib\":799,\"../../lib/gup\":796,\"./constants\":1180,\"@plotly/d3\":58}],1178:[function(t,e,r){\"use strict\";var n=t(\"@plotly/d3\"),i=t(\"../../plots/get_data\").getModuleCalcData,a=t(\"./plot\"),o=t(\"../../constants/xmlns_namespaces\");r.name=\"parcoords\",r.plot=function(t){var e=i(t.calcdata,\"parcoords\")[0];e.length&&a(t,e)},r.clean=function(t,e,r,n){var i=n._has&&n._has(\"parcoords\"),a=e._has&&e._has(\"parcoords\");i&&!a&&(n._paperdiv.selectAll(\".parcoords\").remove(),n._glimages.selectAll(\"*\").remove())},r.toSVG=function(t){var e=t._fullLayout._glimages,r=n.select(t).selectAll(\".svg-container\");r.filter((function(t,e){return e===r.size()-1})).selectAll(\".gl-canvas-context, .gl-canvas-focus\").each((function(){var t=this.toDataURL(\"image/png\");e.append(\"svg:image\").attr({xmlns:o.svg,\"xlink:href\":t,preserveAspectRatio:\"none\",x:0,y:0,width:this.width,height:this.height})})),window.setTimeout((function(){n.selectAll(\"#filterBarPattern\").attr(\"id\",\"filterBarPattern\")}),60)}},{\"../../constants/xmlns_namespaces\":776,\"../../plots/get_data\":887,\"./plot\":1187,\"@plotly/d3\":58}],1179:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").isArrayOrTypedArray,i=t(\"../../components/colorscale\"),a=t(\"../../lib/gup\").wrap;e.exports=function(t,e){var r,o;return i.hasColorscale(e,\"line\")&&n(e.line.color)?(r=e.line.color,o=i.extractOpts(e.line).colorscale,i.calc(t,e,{vals:r,containerStr:\"line\",cLetter:\"c\"})):(r=function(t){for(var e=new Array(t),r=0;r<t;r++)e[r]=.5;return e}(e._length),o=[[0,e.line.color],[1,e.line.color]]),a({lineColor:r,cscale:o})}},{\"../../components/colorscale\":674,\"../../lib\":799,\"../../lib/gup\":796}],1180:[function(t,e,r){\"use strict\";e.exports={maxDimensionCount:60,overdrag:45,verticalPadding:2,tickDistance:50,canvasPixelRatio:1,blockLineCount:5e3,layers:[\"contextLineLayer\",\"focusLineLayer\",\"pickLineLayer\"],axisTitleOffset:28,axisExtentOffset:10,deselectedLineColor:\"#777\",bar:{width:4,captureWidth:10,fillColor:\"magenta\",fillOpacity:1,snapDuration:150,snapRatio:.25,snapClose:.01,strokeOpacity:1,strokeWidth:1,handleHeight:8,handleOpacity:1,handleOverlap:0},cn:{axisExtentText:\"axis-extent-text\",parcoordsLineLayers:\"parcoords-line-layers\",parcoordsLineLayer:\"parcoords-lines\",parcoords:\"parcoords\",parcoordsControlView:\"parcoords-control-view\",yAxis:\"y-axis\",axisOverlays:\"axis-overlays\",axis:\"axis\",axisHeading:\"axis-heading\",axisTitle:\"axis-title\",axisExtent:\"axis-extent\",axisExtentTop:\"axis-extent-top\",axisExtentTopText:\"axis-extent-top-text\",axisExtentBottom:\"axis-extent-bottom\",axisExtentBottomText:\"axis-extent-bottom-text\",axisBrush:\"axis-brush\"},id:{filterBarPattern:\"filter-bar-pattern\"}}},{}],1181:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/colorscale/helpers\").hasColorscale,a=t(\"../../components/colorscale/defaults\"),o=t(\"../../plots/domain\").defaults,s=t(\"../../plots/array_container_defaults\"),l=t(\"../../plots/cartesian/axes\"),c=t(\"./attributes\"),u=t(\"./axisbrush\"),f=t(\"./constants\").maxDimensionCount,h=t(\"./merge_length\");function p(t,e,r,i){function a(r,i){return n.coerce(t,e,c.dimensions,r,i)}var o=a(\"values\"),s=a(\"visible\");if(o&&o.length||(s=e.visible=!1),s){a(\"label\"),a(\"tickvals\"),a(\"ticktext\"),a(\"tickformat\");var f=a(\"range\");e._ax={_id:\"y\",type:\"linear\",showexponent:\"all\",exponentformat:\"B\",range:f},l.setConvert(e._ax,i.layout),a(\"multiselect\");var h=a(\"constraintrange\");h&&(e.constraintrange=u.cleanRanges(h,e))}}e.exports=function(t,e,r,l){function u(r,i){return n.coerce(t,e,c,r,i)}var d=t.dimensions;Array.isArray(d)&&d.length>f&&(n.log(\"parcoords traces support up to \"+f+\" dimensions at the moment\"),d.splice(f));var m=s(t,e,{name:\"dimensions\",layout:l,handleItemDefaults:p}),g=function(t,e,r,o,s){var l=s(\"line.color\",r);if(i(t,\"line\")&&n.isArrayOrTypedArray(l)){if(l.length)return s(\"line.colorscale\"),a(t,e,o,s,{prefix:\"line.\",cLetter:\"c\"}),l.length;e.line.color=r}return 1/0}(t,e,r,l,u);o(e,l,u),Array.isArray(m)&&m.length||(e.visible=!1),h(e,m,\"values\",g);var v={family:l.font.family,size:Math.round(l.font.size/1.2),color:l.font.color};n.coerceFont(u,\"labelfont\",v),n.coerceFont(u,\"tickfont\",v),n.coerceFont(u,\"rangefont\",v),u(\"labelangle\"),u(\"labelside\")}},{\"../../components/colorscale/defaults\":672,\"../../components/colorscale/helpers\":673,\"../../lib\":799,\"../../plots/array_container_defaults\":844,\"../../plots/cartesian/axes\":849,\"../../plots/domain\":877,\"./attributes\":1176,\"./axisbrush\":1177,\"./constants\":1180,\"./merge_length\":1185}],1182:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").isTypedArray;r.convertTypedArray=function(t){return n(t)?Array.prototype.slice.call(t):t},r.isOrdinal=function(t){return!!t.tickvals},r.isVisible=function(t){return t.visible||!(\"visible\"in t)}},{\"../../lib\":799}],1183:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\"),plot:t(\"./plot\"),colorbar:{container:\"line\",min:\"cmin\",max:\"cmax\"},moduleType:\"trace\",name:\"parcoords\",basePlotModule:t(\"./base_plot\"),categories:[\"gl\",\"regl\",\"noOpacity\",\"noHover\"],meta:{}}},{\"./attributes\":1176,\"./base_plot\":1178,\"./calc\":1179,\"./defaults\":1181,\"./plot\":1187}],1184:[function(t,e,r){\"use strict\";var n=t(\"glslify\"),i=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nvarying vec4 fragColor;\\n\\nattribute vec4 p01_04, p05_08, p09_12, p13_16,\\n               p17_20, p21_24, p25_28, p29_32,\\n               p33_36, p37_40, p41_44, p45_48,\\n               p49_52, p53_56, p57_60, colors;\\n\\nuniform mat4 dim0A, dim1A, dim0B, dim1B, dim0C, dim1C, dim0D, dim1D,\\n             loA, hiA, loB, hiB, loC, hiC, loD, hiD;\\n\\nuniform vec2 resolution, viewBoxPos, viewBoxSize;\\nuniform sampler2D mask, palette;\\nuniform float maskHeight;\\nuniform float drwLayer; // 0: context, 1: focus, 2: pick\\nuniform vec4 contextColor;\\n\\nbool isPick    = (drwLayer > 1.5);\\nbool isContext = (drwLayer < 0.5);\\n\\nconst vec4 ZEROS = vec4(0.0, 0.0, 0.0, 0.0);\\nconst vec4 UNITS = vec4(1.0, 1.0, 1.0, 1.0);\\n\\nfloat val(mat4 p, mat4 v) {\\n    return dot(matrixCompMult(p, v) * UNITS, UNITS);\\n}\\n\\nfloat axisY(float ratio, mat4 A, mat4 B, mat4 C, mat4 D) {\\n    float y1 = val(A, dim0A) + val(B, dim0B) + val(C, dim0C) + val(D, dim0D);\\n    float y2 = val(A, dim1A) + val(B, dim1B) + val(C, dim1C) + val(D, dim1D);\\n    return y1 * (1.0 - ratio) + y2 * ratio;\\n}\\n\\nint iMod(int a, int b) {\\n    return a - b * (a / b);\\n}\\n\\nbool fOutside(float p, float lo, float hi) {\\n    return (lo < hi) && (lo > p || p > hi);\\n}\\n\\nbool vOutside(vec4 p, vec4 lo, vec4 hi) {\\n    return (\\n        fOutside(p[0], lo[0], hi[0]) ||\\n        fOutside(p[1], lo[1], hi[1]) ||\\n        fOutside(p[2], lo[2], hi[2]) ||\\n        fOutside(p[3], lo[3], hi[3])\\n    );\\n}\\n\\nbool mOutside(mat4 p, mat4 lo, mat4 hi) {\\n    return (\\n        vOutside(p[0], lo[0], hi[0]) ||\\n        vOutside(p[1], lo[1], hi[1]) ||\\n        vOutside(p[2], lo[2], hi[2]) ||\\n        vOutside(p[3], lo[3], hi[3])\\n    );\\n}\\n\\nbool outsideBoundingBox(mat4 A, mat4 B, mat4 C, mat4 D) {\\n    return mOutside(A, loA, hiA) ||\\n           mOutside(B, loB, hiB) ||\\n           mOutside(C, loC, hiC) ||\\n           mOutside(D, loD, hiD);\\n}\\n\\nbool outsideRasterMask(mat4 A, mat4 B, mat4 C, mat4 D) {\\n    mat4 pnts[4];\\n    pnts[0] = A;\\n    pnts[1] = B;\\n    pnts[2] = C;\\n    pnts[3] = D;\\n\\n    for(int i = 0; i < 4; ++i) {\\n        for(int j = 0; j < 4; ++j) {\\n            for(int k = 0; k < 4; ++k) {\\n                if(0 == iMod(\\n                    int(255.0 * texture2D(mask,\\n                        vec2(\\n                            (float(i * 2 + j / 2) + 0.5) / 8.0,\\n                            (pnts[i][j][k] * (maskHeight - 1.0) + 1.0) / maskHeight\\n                        ))[3]\\n                    ) / int(pow(2.0, float(iMod(j * 4 + k, 8)))),\\n                    2\\n                )) return true;\\n            }\\n        }\\n    }\\n    return false;\\n}\\n\\nvec4 position(bool isContext, float v, mat4 A, mat4 B, mat4 C, mat4 D) {\\n    float x = 0.5 * sign(v) + 0.5;\\n    float y = axisY(x, A, B, C, D);\\n    float z = 1.0 - abs(v);\\n\\n    z += isContext ? 0.0 : 2.0 * float(\\n        outsideBoundingBox(A, B, C, D) ||\\n        outsideRasterMask(A, B, C, D)\\n    );\\n\\n    return vec4(\\n        2.0 * (vec2(x, y) * viewBoxSize + viewBoxPos) / resolution - 1.0,\\n        z,\\n        1.0\\n    );\\n}\\n\\nvoid main() {\\n    mat4 A = mat4(p01_04, p05_08, p09_12, p13_16);\\n    mat4 B = mat4(p17_20, p21_24, p25_28, p29_32);\\n    mat4 C = mat4(p33_36, p37_40, p41_44, p45_48);\\n    mat4 D = mat4(p49_52, p53_56, p57_60, ZEROS);\\n\\n    float v = colors[3];\\n\\n    gl_Position = position(isContext, v, A, B, C, D);\\n\\n    fragColor =\\n        isContext ? vec4(contextColor) :\\n        isPick ? vec4(colors.rgb, 1.0) : texture2D(palette, vec2(abs(v), 0.5));\\n}\\n\"]),a=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nvarying vec4 fragColor;\\n\\nvoid main() {\\n    gl_FragColor = fragColor;\\n}\\n\"]),o=t(\"./constants\").maxDimensionCount,s=t(\"../../lib\"),l=new Uint8Array(4),c=new Uint8Array(4),u={shape:[256,1],format:\"rgba\",type:\"uint8\",mag:\"nearest\",min:\"nearest\"};function f(t,e,r,n,i){var a=t._gl;a.enable(a.SCISSOR_TEST),a.scissor(e,r,n,i),t.clear({color:[0,0,0,0],depth:1})}function h(t,e,r,n,i,a){var o=a.key;r.drawCompleted||(!function(t){t.read({x:0,y:0,width:1,height:1,data:l})}(t),r.drawCompleted=!0),function s(l){var c=Math.min(n,i-l*n);0===l&&(window.cancelAnimationFrame(r.currentRafs[o]),delete r.currentRafs[o],f(t,a.scissorX,a.scissorY,a.scissorWidth,a.viewBoxSize[1])),r.clearOnly||(a.count=2*c,a.offset=2*l*n,e(a),l*n+c<i&&(r.currentRafs[o]=window.requestAnimationFrame((function(){s(l+1)}))),r.drawCompleted=!1)}(0)}function p(t,e){for(var r=new Array(256),n=0;n<256;n++)r[n]=t(n/255).concat(e);return r}function d(t,e){return(t>>>8*e)%256/255}function m(t,e,r){for(var n=new Array(8*e),i=0,a=0;a<e;a++)for(var o=0;o<2;o++)for(var s=0;s<4;s++){var l=4*t+s,c=r[64*a+l];63===l&&0===o&&(c*=-1),n[i++]=c}return n}function g(t){var e=\"0\"+t;return e.substr(e.length-2)}function v(t){return t<o?\"p\"+g(t+1)+\"_\"+g(t+4):\"colors\"}function y(t,e,r,n,i,a,o,l,c,u,f,h,p){for(var d=[[],[]],m=0;m<64;m++)d[0][m]=m===i?1:0,d[1][m]=m===a?1:0;var g=t.lines.canvasOverdrag,v=t.domain,y=t.canvasWidth,x=t.canvasHeight,b=t.deselectedLines.color;return s.extendFlat({key:f,resolution:[y,x],viewBoxPos:[o+g,l],viewBoxSize:[c,u],i0:i,i1:a,dim0A:d[0].slice(0,16),dim0B:d[0].slice(16,32),dim0C:d[0].slice(32,48),dim0D:d[0].slice(48,64),dim1A:d[1].slice(0,16),dim1B:d[1].slice(16,32),dim1C:d[1].slice(32,48),dim1D:d[1].slice(48,64),drwLayer:h,contextColor:[b[0]/255,b[1]/255,b[2]/255,b[3]<1?b[3]:Math.max(1/255,Math.pow(1/t.lines.color.length,1/3))],scissorX:(n===e?0:o+g)+(t.pad.l-g)+t.layoutWidth*v.x[0],scissorWidth:(n===r?y-o+g:c+.5)+(n===e?o+g:0),scissorY:l+t.pad.b+t.layoutHeight*v.y[0],scissorHeight:u,viewportX:t.pad.l-g+t.layoutWidth*v.x[0],viewportY:t.pad.b+t.layoutHeight*v.y[0],viewportWidth:y,viewportHeight:x},p)}function x(t){var e=Math.max(0,Math.floor(2047*t[0]),0),r=Math.min(2047,Math.ceil(2047*t[1]),2047);return[Math.min(e,r),Math.max(e,r)]}e.exports=function(t,e){var r,n,l,g,b,_=e.context,w=e.pick,T=e.regl,k={currentRafs:{},drawCompleted:!0,clearOnly:!1},M=function(t){for(var e={},r=0;r<=o;r+=4)e[v(r)]=t.buffer({usage:\"dynamic\",type:\"float\",data:new Uint8Array(0)});return e}(T),A=T.texture(u),S=[];L(e);var E=T({profile:!1,blend:{enable:_,func:{srcRGB:\"src alpha\",dstRGB:\"one minus src alpha\",srcAlpha:1,dstAlpha:1},equation:{rgb:\"add\",alpha:\"add\"},color:[0,0,0,0]},depth:{enable:!_,mask:!0,func:\"less\",range:[0,1]},cull:{enable:!0,face:\"back\"},scissor:{enable:!0,box:{x:T.prop(\"scissorX\"),y:T.prop(\"scissorY\"),width:T.prop(\"scissorWidth\"),height:T.prop(\"scissorHeight\")}},viewport:{x:T.prop(\"viewportX\"),y:T.prop(\"viewportY\"),width:T.prop(\"viewportWidth\"),height:T.prop(\"viewportHeight\")},dither:!1,vert:i,frag:a,primitive:\"lines\",lineWidth:1,attributes:M,uniforms:{resolution:T.prop(\"resolution\"),viewBoxPos:T.prop(\"viewBoxPos\"),viewBoxSize:T.prop(\"viewBoxSize\"),dim0A:T.prop(\"dim0A\"),dim1A:T.prop(\"dim1A\"),dim0B:T.prop(\"dim0B\"),dim1B:T.prop(\"dim1B\"),dim0C:T.prop(\"dim0C\"),dim1C:T.prop(\"dim1C\"),dim0D:T.prop(\"dim0D\"),dim1D:T.prop(\"dim1D\"),loA:T.prop(\"loA\"),hiA:T.prop(\"hiA\"),loB:T.prop(\"loB\"),hiB:T.prop(\"hiB\"),loC:T.prop(\"loC\"),hiC:T.prop(\"hiC\"),loD:T.prop(\"loD\"),hiD:T.prop(\"hiD\"),palette:A,contextColor:T.prop(\"contextColor\"),mask:T.prop(\"maskTexture\"),drwLayer:T.prop(\"drwLayer\"),maskHeight:T.prop(\"maskHeight\")},offset:T.prop(\"offset\"),count:T.prop(\"count\")});function L(t){r=t.model,n=t.viewModel,l=n.dimensions.slice(),g=l[0]?l[0].values.length:0;var e=r.lines,i=w?e.color.map((function(t,r){return r/e.color.length})):e.color,a=function(t,e,r){for(var n,i=new Array(t*(o+4)),a=0,s=0;s<t;s++){for(var l=0;l<o;l++)i[a++]=l<e.length?e[l].paddedUnitValues[s]:.5;i[a++]=d(s,2),i[a++]=d(s,1),i[a++]=d(s,0),i[a++]=(n=r[s],Math.max(1e-6,Math.min(.999999,n)))}return i}(g,l,i);!function(t,e,r){for(var n=0;n<=o;n+=4)t[v(n)](m(n/4,e,r))}(M,g,a),_||w||(A=T.texture(s.extendFlat({data:p(r.unitToColor,255)},u)))}return{render:function(t,e,n){var i,a,o,s=t.length,c=1/0,u=-1/0;for(i=0;i<s;i++)t[i].dim0.canvasX<c&&(c=t[i].dim0.canvasX,a=i),t[i].dim1.canvasX>u&&(u=t[i].dim1.canvasX,o=i);0===s&&f(T,0,0,r.canvasWidth,r.canvasHeight);var p=function(t){var e,r,n,i=[[],[]];for(n=0;n<64;n++){var a=!t&&n<l.length?l[n].brush.filter.getBounds():[-1/0,1/0];i[0][n]=a[0],i[1][n]=a[1]}var o=new Array(16384);for(e=0;e<16384;e++)o[e]=255;if(!t)for(e=0;e<l.length;e++){var s=e%8,c=(e-s)/8,u=Math.pow(2,s),f=l[e].brush.filter.get();if(!(f.length<2)){var h=x(f[0])[1];for(r=1;r<f.length;r++){var p=x(f[r]);for(n=h+1;n<p[0];n++)o[8*n+c]&=~u;h=Math.max(h,p[1])}}}var d={shape:[8,2048],format:\"alpha\",type:\"uint8\",mag:\"nearest\",min:\"nearest\",data:o};return b?b(d):b=T.texture(d),{maskTexture:b,maskHeight:2048,loA:i[0].slice(0,16),loB:i[0].slice(16,32),loC:i[0].slice(32,48),loD:i[0].slice(48,64),hiA:i[1].slice(0,16),hiB:i[1].slice(16,32),hiC:i[1].slice(32,48),hiD:i[1].slice(48,64)}}(_);for(i=0;i<s;i++){var d=t[i],m=d.dim0.crossfilterDimensionIndex,v=d.dim1.crossfilterDimensionIndex,M=d.canvasX,A=d.canvasY,L=M+d.panelSizeX;if(e||!S[m]||S[m][0]!==M||S[m][1]!==L){S[m]=[M,L];var C=y(r,a,o,i,m,v,M,A,d.panelSizeX,d.panelSizeY,d.dim0.crossfilterDimensionIndex,_?0:w?2:1,p);k.clearOnly=n;var P=e?r.lines.blockLineCount:g;h(T,E,k,P,g,C)}}},readPixel:function(t,e){return T.read({x:t,y:e,width:1,height:1,data:c}),c},readPixels:function(t,e,r,n){var i=new Uint8Array(4*r*n);return T.read({x:t,y:e,width:r,height:n,data:i}),i},destroy:function(){for(var e in t.style[\"pointer-events\"]=\"none\",A.destroy(),b&&b.destroy(),M)M[e].destroy()},update:L}}},{\"../../lib\":799,\"./constants\":1180,glslify:438}],1185:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n){var i,a;for(n||(n=1/0),i=0;i<e.length;i++)(a=e[i]).visible&&(n=Math.min(n,a[r].length));for(n===1/0&&(n=0),t._length=n,i=0;i<e.length;i++)(a=e[i]).visible&&(a._length=n);return n}},{}],1186:[function(t,e,r){\"use strict\";var n=t(\"@plotly/d3\"),i=t(\"color-rgba\"),a=t(\"../../plots/cartesian/axes\"),o=t(\"../../lib\"),s=o.strRotate,l=o.strTranslate,c=t(\"../../lib/svg_text_utils\"),u=t(\"../../components/drawing\"),f=t(\"../../components/colorscale\"),h=t(\"../../lib/gup\"),p=h.keyFun,d=h.repeat,m=h.unwrap,g=t(\"./helpers\"),v=t(\"./constants\"),y=t(\"./axisbrush\"),x=t(\"./lines\");function b(t,e,r){return o.aggNums(t,null,e,r)}function _(t,e){return T(b(Math.min,t,e),b(Math.max,t,e))}function w(t){var e=t.range;return e?T(e[0],e[1]):_(t.values,t._length)}function T(t,e){return!isNaN(t)&&isFinite(t)||(t=0),!isNaN(e)&&isFinite(e)||(e=0),t===e&&(0===t?(t-=1,e+=1):(t*=.9,e*=1.1)),[t,e]}function k(t,e,r,i,a){var o,s,l=w(r);return i?n.scale.ordinal().domain(i.map((o=n.format(r.tickformat),s=a,s?function(t,e){var r=s[e];return null==r?o(t):r}:o))).range(i.map((function(r){var n=(r-l[0])/(l[1]-l[0]);return t-e+n*(2*e-t)}))):n.scale.linear().domain(l).range([t-e,e])}function M(t){if(t.tickvals){var e=w(t);return n.scale.ordinal().domain(t.tickvals).range(t.tickvals.map((function(t){return(t-e[0])/(e[1]-e[0])})))}}function A(t){var e=t.map((function(t){return t[0]})),r=t.map((function(t){var e=i(t[1]);return n.rgb(\"rgb(\"+e[0]+\",\"+e[1]+\",\"+e[2]+\")\")})),a=\"rgb\".split(\"\").map((function(t){return n.scale.linear().clamp(!0).domain(e).range(r.map((i=t,function(t){return t[i]})));var i}));return function(t){return a.map((function(e){return e(t)}))}}function S(t){return t.dimensions.some((function(t){return t.brush.filterSpecified}))}function E(t,e,r){var a=m(e),s=a.trace,l=g.convertTypedArray(a.lineColor),c=s.line,u={color:i(v.deselectedLineColor)},h=f.extractOpts(c),p=h.reversescale?f.flipScale(a.cscale):a.cscale,d=s.domain,y=s.dimensions,x=t.width,b=s.labelangle,_=s.labelside,T=s.labelfont,k=s.tickfont,M=s.rangefont,S=o.extendDeepNoArrays({},c,{color:l.map(n.scale.linear().domain(w({values:l,range:[h.min,h.max],_length:s._length}))),blockLineCount:v.blockLineCount,canvasOverdrag:v.overdrag*v.canvasPixelRatio}),E=Math.floor(x*(d.x[1]-d.x[0])),L=Math.floor(t.height*(d.y[1]-d.y[0])),C=t.margin||{l:80,r:80,t:100,b:80},P=E,I=L;return{key:r,colCount:y.filter(g.isVisible).length,dimensions:y,tickDistance:v.tickDistance,unitToColor:A(p),lines:S,deselectedLines:u,labelAngle:b,labelSide:_,labelFont:T,tickFont:k,rangeFont:M,layoutWidth:x,layoutHeight:t.height,domain:d,translateX:d.x[0]*x,translateY:t.height-d.y[1]*t.height,pad:C,canvasWidth:P*v.canvasPixelRatio+2*S.canvasOverdrag,canvasHeight:I*v.canvasPixelRatio,width:P,height:I,canvasPixelRatio:v.canvasPixelRatio}}function L(t,e,r){var i=r.width,a=r.height,s=r.dimensions,l=r.canvasPixelRatio,c=function(t){return i*t/Math.max(1,r.colCount-1)},u=v.verticalPadding/a,f=function(t,e){return n.scale.linear().range([e,t-e])}(a,v.verticalPadding),h={key:r.key,xScale:c,model:r,inBrushDrag:!1},p={};return h.dimensions=s.filter(g.isVisible).map((function(i,s){var d=function(t,e){return n.scale.linear().domain(w(t)).range([e,1-e])}(i,u),m=p[i.label];p[i.label]=(m||0)+1;var x=i.label+(m?\"__\"+m:\"\"),b=i.constraintrange,_=b&&b.length;_&&!Array.isArray(b[0])&&(b=[b]);var T=_?b.map((function(t){return t.map(d)})):[[-1/0,1/0]],A=i.values;A.length>i._length&&(A=A.slice(0,i._length));var E,L=i.tickvals;function C(t,e){return{val:t,text:E[e]}}function P(t,e){return t.val-e.val}if(Array.isArray(L)&&L.length){E=i.ticktext,Array.isArray(E)&&E.length?E.length>L.length?E=E.slice(0,L.length):L.length>E.length&&(L=L.slice(0,E.length)):E=L.map(n.format(i.tickformat));for(var I=1;I<L.length;I++)if(L[I]<L[I-1]){for(var O=L.map(C).sort(P),z=0;z<L.length;z++)L[z]=O[z].val,E[z]=O[z].text;break}}else L=void 0;return A=g.convertTypedArray(A),{key:x,label:i.label,tickFormat:i.tickformat,tickvals:L,ticktext:E,ordinal:g.isOrdinal(i),multiselect:i.multiselect,xIndex:s,crossfilterDimensionIndex:s,visibleIndex:i._index,height:a,values:A,paddedUnitValues:A.map(d),unitTickvals:L&&L.map(d),xScale:c,x:c(s),canvasX:c(s)*l,unitToPaddedPx:f,domainScale:k(a,v.verticalPadding,i,L,E),ordinalScale:M(i),parent:h,model:r,brush:y.makeBrush(t,_,T,(function(){t.linePickActive(!1)}),(function(){var e=h;e.focusLayer&&e.focusLayer.render(e.panels,!0);var r=S(e);!t.contextShown()&&r?(e.contextLayer&&e.contextLayer.render(e.panels,!0),t.contextShown(!0)):t.contextShown()&&!r&&(e.contextLayer&&e.contextLayer.render(e.panels,!0,!0),t.contextShown(!1))}),(function(r){if(h.focusLayer.render(h.panels,!0),h.pickLayer&&h.pickLayer.render(h.panels,!0),t.linePickActive(!0),e&&e.filterChanged){var n=d.invert,a=r.map((function(t){return t.map(n).sort(o.sorterAsc)})).sort((function(t,e){return t[0]-e[0]}));e.filterChanged(h.key,i._index,a)}}))}})),h}function C(t){t.classed(v.cn.axisExtentText,!0).attr(\"text-anchor\",\"middle\").style(\"cursor\",\"default\")}function P(t,e){var r=\"top\"===e?1:-1,n=t*Math.PI/180;return{dir:r,dx:Math.sin(n),dy:Math.cos(n),degrees:t}}function I(t,e){for(var r=e.panels||(e.panels=[]),n=t.data(),i=0;i<n.length-1;i++){var a=r[i]||(r[i]={}),o=n[i],s=n[i+1];a.dim0=o,a.dim1=s,a.canvasX=o.canvasX,a.panelSizeX=s.canvasX-o.canvasX,a.panelSizeY=e.model.canvasHeight,a.y=0,a.canvasY=0}}function O(t,e){return a.tickText(t._ax,e,!1).text}function z(t,e){if(t.ordinal)return\"\";var r=t.domainScale.domain(),n=r[e?r.length-1:0];return O(t.model.dimensions[t.visibleIndex],n)}e.exports=function(t,e,r,i){var f=t._fullLayout,h=f._toppaper,b=f._glcontainer,w=t._fullLayout.paper_bgcolor;!function(t){for(var e=0;e<t.length;e++)for(var r=0;r<t[e].length;r++)for(var n=t[e][r].trace,i=n.dimensions,o=0;o<i.length;o++){var s=i[o].values,l=i[o]._ax;l&&(l.range?l.range=T(l.range[0],l.range[1]):l.range=_(s,n._length),l.dtick||(l.dtick=.01*(Math.abs(l.range[1]-l.range[0])||1)),l.tickformat=i[o].tickformat,a.calcTicks(l),l.cleanRange())}}(e);var k,M,A=(k=!0,M=!1,{linePickActive:function(t){return arguments.length?k=!!t:k},contextShown:function(t){return arguments.length?M=!!t:M}}),D=e.filter((function(t){return m(t).trace.visible})).map(E.bind(0,r)).map(L.bind(0,A,i));b.each((function(t,e){return o.extendFlat(t,D[e])}));var R=b.selectAll(\".gl-canvas\").each((function(t){t.viewModel=D[0],t.viewModel.paperColor=w,t.model=t.viewModel?t.viewModel.model:null})),F=null;R.filter((function(t){return t.pick})).style(\"pointer-events\",\"auto\").on(\"mousemove\",(function(t){if(A.linePickActive()&&t.lineLayer&&i&&i.hover){var e=n.event,r=this.width,a=this.height,o=n.mouse(this),s=o[0],l=o[1];if(s<0||l<0||s>=r||l>=a)return;var c=t.lineLayer.readPixel(s,a-1-l),u=0!==c[3],f=u?c[2]+256*(c[1]+256*c[0]):null,h={x:s,y:l,clientX:e.clientX,clientY:e.clientY,dataIndex:t.model.key,curveNumber:f};f!==F&&(u?i.hover(h):i.unhover&&i.unhover(h),F=f)}})),R.style(\"opacity\",(function(t){return t.pick?0:1})),h.style(\"background\",\"rgba(255, 255, 255, 0)\");var B=h.selectAll(\".\"+v.cn.parcoords).data(D,p);B.exit().remove(),B.enter().append(\"g\").classed(v.cn.parcoords,!0).style(\"shape-rendering\",\"crispEdges\").style(\"pointer-events\",\"none\"),B.attr(\"transform\",(function(t){return l(t.model.translateX,t.model.translateY)}));var N=B.selectAll(\".\"+v.cn.parcoordsControlView).data(d,p);N.enter().append(\"g\").classed(v.cn.parcoordsControlView,!0),N.attr(\"transform\",(function(t){return l(t.model.pad.l,t.model.pad.t)}));var j=N.selectAll(\".\"+v.cn.yAxis).data((function(t){return t.dimensions}),p);j.enter().append(\"g\").classed(v.cn.yAxis,!0),N.each((function(t){I(j,t)})),R.each((function(t){if(t.viewModel){!t.lineLayer||i?t.lineLayer=x(this,t):t.lineLayer.update(t),(t.key||0===t.key)&&(t.viewModel[t.key]=t.lineLayer);var e=!t.context||i;t.lineLayer.render(t.viewModel.panels,e)}})),j.attr(\"transform\",(function(t){return l(t.xScale(t.xIndex),0)})),j.call(n.behavior.drag().origin((function(t){return t})).on(\"drag\",(function(t){var e=t.parent;A.linePickActive(!1),t.x=Math.max(-v.overdrag,Math.min(t.model.width+v.overdrag,n.event.x)),t.canvasX=t.x*t.model.canvasPixelRatio,j.sort((function(t,e){return t.x-e.x})).each((function(e,r){e.xIndex=r,e.x=t===e?e.x:e.xScale(e.xIndex),e.canvasX=e.x*e.model.canvasPixelRatio})),I(j,e),j.filter((function(e){return 0!==Math.abs(t.xIndex-e.xIndex)})).attr(\"transform\",(function(t){return l(t.xScale(t.xIndex),0)})),n.select(this).attr(\"transform\",l(t.x,0)),j.each((function(r,n,i){i===t.parent.key&&(e.dimensions[n]=r)})),e.contextLayer&&e.contextLayer.render(e.panels,!1,!S(e)),e.focusLayer.render&&e.focusLayer.render(e.panels)})).on(\"dragend\",(function(t){var e=t.parent;t.x=t.xScale(t.xIndex),t.canvasX=t.x*t.model.canvasPixelRatio,I(j,e),n.select(this).attr(\"transform\",(function(t){return l(t.x,0)})),e.contextLayer&&e.contextLayer.render(e.panels,!1,!S(e)),e.focusLayer&&e.focusLayer.render(e.panels),e.pickLayer&&e.pickLayer.render(e.panels,!0),A.linePickActive(!0),i&&i.axesMoved&&i.axesMoved(e.key,e.dimensions.map((function(t){return t.crossfilterDimensionIndex})))}))),j.exit().remove();var U=j.selectAll(\".\"+v.cn.axisOverlays).data(d,p);U.enter().append(\"g\").classed(v.cn.axisOverlays,!0),U.selectAll(\".\"+v.cn.axis).remove();var V=U.selectAll(\".\"+v.cn.axis).data(d,p);V.enter().append(\"g\").classed(v.cn.axis,!0),V.each((function(t){var e=t.model.height/t.model.tickDistance,r=t.domainScale,i=r.domain();n.select(this).call(n.svg.axis().orient(\"left\").tickSize(4).outerTickSize(2).ticks(e,t.tickFormat).tickValues(t.ordinal?i:null).tickFormat((function(e){return g.isOrdinal(t)?e:O(t.model.dimensions[t.visibleIndex],e)})).scale(r)),u.font(V.selectAll(\"text\"),t.model.tickFont)})),V.selectAll(\".domain, .tick>line\").attr(\"fill\",\"none\").attr(\"stroke\",\"black\").attr(\"stroke-opacity\",.25).attr(\"stroke-width\",\"1px\"),V.selectAll(\"text\").style(\"text-shadow\",c.makeTextShadow(w)).style(\"cursor\",\"default\");var q=U.selectAll(\".\"+v.cn.axisHeading).data(d,p);q.enter().append(\"g\").classed(v.cn.axisHeading,!0);var H=q.selectAll(\".\"+v.cn.axisTitle).data(d,p);H.enter().append(\"text\").classed(v.cn.axisTitle,!0).attr(\"text-anchor\",\"middle\").style(\"cursor\",\"ew-resize\").style(\"pointer-events\",\"auto\"),H.text((function(t){return t.label})).each((function(e){var r=n.select(this);u.font(r,e.model.labelFont),c.convertToTspans(r,t)})).attr(\"transform\",(function(t){var e=P(t.model.labelAngle,t.model.labelSide),r=v.axisTitleOffset;return(e.dir>0?\"\":l(0,2*r+t.model.height))+s(e.degrees)+l(-r*e.dx,-r*e.dy)})).attr(\"text-anchor\",(function(t){var e=P(t.model.labelAngle,t.model.labelSide);return 2*Math.abs(e.dx)>Math.abs(e.dy)?e.dir*e.dx<0?\"start\":\"end\":\"middle\"}));var G=U.selectAll(\".\"+v.cn.axisExtent).data(d,p);G.enter().append(\"g\").classed(v.cn.axisExtent,!0);var Y=G.selectAll(\".\"+v.cn.axisExtentTop).data(d,p);Y.enter().append(\"g\").classed(v.cn.axisExtentTop,!0),Y.attr(\"transform\",l(0,-v.axisExtentOffset));var W=Y.selectAll(\".\"+v.cn.axisExtentTopText).data(d,p);W.enter().append(\"text\").classed(v.cn.axisExtentTopText,!0).call(C),W.text((function(t){return z(t,!0)})).each((function(t){u.font(n.select(this),t.model.rangeFont)}));var X=G.selectAll(\".\"+v.cn.axisExtentBottom).data(d,p);X.enter().append(\"g\").classed(v.cn.axisExtentBottom,!0),X.attr(\"transform\",(function(t){return l(0,t.model.height+v.axisExtentOffset)}));var Z=X.selectAll(\".\"+v.cn.axisExtentBottomText).data(d,p);Z.enter().append(\"text\").classed(v.cn.axisExtentBottomText,!0).attr(\"dy\",\"0.75em\").call(C),Z.text((function(t){return z(t,!1)})).each((function(t){u.font(n.select(this),t.model.rangeFont)})),y.ensureAxisBrush(U,w)}},{\"../../components/colorscale\":674,\"../../components/drawing\":684,\"../../lib\":799,\"../../lib/gup\":796,\"../../lib/svg_text_utils\":824,\"../../plots/cartesian/axes\":849,\"./axisbrush\":1177,\"./constants\":1180,\"./helpers\":1182,\"./lines\":1184,\"@plotly/d3\":58,\"color-rgba\":133}],1187:[function(t,e,r){\"use strict\";var n=t(\"./parcoords\"),i=t(\"../../lib/prepare_regl\"),a=t(\"./helpers\").isVisible;function o(t,e,r){var n=e.indexOf(r),i=t.indexOf(n);return-1===i&&(i+=e.length),i}e.exports=function(t,e){var r=t._fullLayout;if(i(t)){var s={},l={},c={},u={},f=r._size;e.forEach((function(e,r){var n=e[0].trace;c[r]=n.index;var i=u[r]=n._fullInput.index;s[r]=t.data[i].dimensions,l[r]=t.data[i].dimensions.slice()}));n(t,e,{width:f.w,height:f.h,margin:{t:f.t,r:f.r,b:f.b,l:f.l}},{filterChanged:function(e,n,i){var a=l[e][n],o=i.map((function(t){return t.slice()})),s=\"dimensions[\"+n+\"].constraintrange\",f=r._tracePreGUI[t._fullData[c[e]]._fullInput.uid];if(void 0===f[s]){var h=a.constraintrange;f[s]=h||null}var p=t._fullData[c[e]].dimensions[n];o.length?(1===o.length&&(o=o[0]),a.constraintrange=o,p.constraintrange=o.slice(),o=[o]):(delete a.constraintrange,delete p.constraintrange,o=null);var d={};d[s]=o,t.emit(\"plotly_restyle\",[d,[u[e]]])},hover:function(e){t.emit(\"plotly_hover\",e)},unhover:function(e){t.emit(\"plotly_unhover\",e)},axesMoved:function(e,r){var n=function(t,e){return function(r,n){return o(t,e,r)-o(t,e,n)}}(r,l[e].filter(a));s[e].sort(n),l[e].filter((function(t){return!a(t)})).sort((function(t){return l[e].indexOf(t)})).forEach((function(t){s[e].splice(s[e].indexOf(t),1),s[e].splice(l[e].indexOf(t),0,t)})),t.emit(\"plotly_restyle\",[{dimensions:[s[e]]},[u[e]]])}})}}},{\"../../lib/prepare_regl\":812,\"./helpers\":1182,\"./parcoords\":1186}],1188:[function(t,e,r){\"use strict\";var n=t(\"../../plots/attributes\"),i=t(\"../../plots/domain\").attributes,a=t(\"../../plots/font_attributes\"),o=t(\"../../components/color/attributes\"),s=t(\"../../plots/template_attributes\").hovertemplateAttrs,l=t(\"../../plots/template_attributes\").texttemplateAttrs,c=t(\"../../lib/extend\").extendFlat,u=a({editType:\"plot\",arrayOk:!0,colorEditType:\"plot\"});e.exports={labels:{valType:\"data_array\",editType:\"calc\"},label0:{valType:\"number\",dflt:0,editType:\"calc\"},dlabel:{valType:\"number\",dflt:1,editType:\"calc\"},values:{valType:\"data_array\",editType:\"calc\"},marker:{colors:{valType:\"data_array\",editType:\"calc\"},line:{color:{valType:\"color\",dflt:o.defaultLine,arrayOk:!0,editType:\"style\"},width:{valType:\"number\",min:0,dflt:0,arrayOk:!0,editType:\"style\"},editType:\"calc\"},editType:\"calc\"},text:{valType:\"data_array\",editType:\"plot\"},hovertext:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"style\"},scalegroup:{valType:\"string\",dflt:\"\",editType:\"calc\"},textinfo:{valType:\"flaglist\",flags:[\"label\",\"text\",\"value\",\"percent\"],extras:[\"none\"],editType:\"calc\"},hoverinfo:c({},n.hoverinfo,{flags:[\"label\",\"text\",\"value\",\"percent\",\"name\"]}),hovertemplate:s({},{keys:[\"label\",\"color\",\"value\",\"percent\",\"text\"]}),texttemplate:l({editType:\"plot\"},{keys:[\"label\",\"color\",\"value\",\"percent\",\"text\"]}),textposition:{valType:\"enumerated\",values:[\"inside\",\"outside\",\"auto\",\"none\"],dflt:\"auto\",arrayOk:!0,editType:\"plot\"},textfont:c({},u,{}),insidetextorientation:{valType:\"enumerated\",values:[\"horizontal\",\"radial\",\"tangential\",\"auto\"],dflt:\"auto\",editType:\"plot\"},insidetextfont:c({},u,{}),outsidetextfont:c({},u,{}),automargin:{valType:\"boolean\",dflt:!1,editType:\"plot\"},title:{text:{valType:\"string\",dflt:\"\",editType:\"plot\"},font:c({},u,{}),position:{valType:\"enumerated\",values:[\"top left\",\"top center\",\"top right\",\"middle center\",\"bottom left\",\"bottom center\",\"bottom right\"],editType:\"plot\"},editType:\"plot\"},domain:i({name:\"pie\",trace:!0,editType:\"calc\"}),hole:{valType:\"number\",min:0,max:1,dflt:0,editType:\"calc\"},sort:{valType:\"boolean\",dflt:!0,editType:\"calc\"},direction:{valType:\"enumerated\",values:[\"clockwise\",\"counterclockwise\"],dflt:\"counterclockwise\",editType:\"calc\"},rotation:{valType:\"number\",min:-360,max:360,dflt:0,editType:\"calc\"},pull:{valType:\"number\",min:0,max:1,dflt:0,arrayOk:!0,editType:\"calc\"},_deprecated:{title:{valType:\"string\",dflt:\"\",editType:\"calc\"},titlefont:c({},u,{}),titleposition:{valType:\"enumerated\",values:[\"top left\",\"top center\",\"top right\",\"middle center\",\"bottom left\",\"bottom center\",\"bottom right\"],editType:\"calc\"}}}},{\"../../components/color/attributes\":661,\"../../lib/extend\":789,\"../../plots/attributes\":845,\"../../plots/domain\":877,\"../../plots/font_attributes\":878,\"../../plots/template_attributes\":922}],1189:[function(t,e,r){\"use strict\";var n=t(\"../../plots/plots\");r.name=\"pie\",r.plot=function(t,e,i,a){n.plotBasePlot(r.name,t,e,i,a)},r.clean=function(t,e,i,a){n.cleanBasePlot(r.name,t,e,i,a)}},{\"../../plots/plots\":913}],1190:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"tinycolor2\"),a=t(\"../../components/color\"),o={};function s(t){return function(e,r){return!!e&&(!!(e=i(e)).isValid()&&(e=a.addOpacity(e,e.getAlpha()),t[r]||(t[r]=e),e))}}function l(t,e){var r,n=JSON.stringify(t),a=e[n];if(!a){for(a=t.slice(),r=0;r<t.length;r++)a.push(i(t[r]).lighten(20).toHexString());for(r=0;r<t.length;r++)a.push(i(t[r]).darken(20).toHexString());e[n]=a}return a}e.exports={calc:function(t,e){var r,i,a=[],o=t._fullLayout,l=o.hiddenlabels||[],c=e.labels,u=e.marker.colors||[],f=e.values,h=e._length,p=e._hasValues&&h;if(e.dlabel)for(c=new Array(h),r=0;r<h;r++)c[r]=String(e.label0+r*e.dlabel);var d={},m=s(o[\"_\"+e.type+\"colormap\"]),g=0,v=!1;for(r=0;r<h;r++){var y,x,b;if(p){if(y=f[r],!n(y))continue;if((y=+y)<0)continue}else y=1;void 0!==(x=c[r])&&\"\"!==x||(x=r);var _=d[x=String(x)];void 0===_?(d[x]=a.length,(b=-1!==l.indexOf(x))||(g+=y),a.push({v:y,label:x,color:m(u[r],x),i:r,pts:[r],hidden:b})):(v=!0,(i=a[_]).v+=y,i.pts.push(r),i.hidden||(g+=y),!1===i.color&&u[r]&&(i.color=m(u[r],x)))}return(\"funnelarea\"===e.type?v:e.sort)&&a.sort((function(t,e){return e.v-t.v})),a[0]&&(a[0].vTotal=g),a},crossTraceCalc:function(t,e){var r=(e||{}).type;r||(r=\"pie\");var n=t._fullLayout,i=t.calcdata,a=n[r+\"colorway\"],s=n[\"_\"+r+\"colormap\"];n[\"extend\"+r+\"colors\"]&&(a=l(a,o));for(var c=0,u=0;u<i.length;u++){var f=i[u];if(f[0].trace.type===r)for(var h=0;h<f.length;h++){var p=f[h];!1===p.color&&(s[p.label]?p.color=s[p.label]:(s[p.label]=p.color=a[c%a.length],c++))}}},makePullColorFn:s,generateExtendedColors:l}},{\"../../components/color\":662,\"fast-isnumeric\":245,tinycolor2:594}],1191:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"./attributes\"),o=t(\"../../plots/domain\").defaults,s=t(\"../bar/defaults\").handleText;function l(t,e){var r=Array.isArray(t),a=i.isArrayOrTypedArray(e),o=Math.min(r?t.length:1/0,a?e.length:1/0);if(isFinite(o)||(o=0),o&&a){for(var s,l=0;l<o;l++){var c=e[l];if(n(c)&&c>0){s=!0;break}}s||(o=0)}return{hasLabels:r,hasValues:a,len:o}}e.exports={handleLabelsAndValues:l,supplyDefaults:function(t,e,r,n){function c(r,n){return i.coerce(t,e,a,r,n)}var u=l(c(\"labels\"),c(\"values\")),f=u.len;if(e._hasLabels=u.hasLabels,e._hasValues=u.hasValues,!e._hasLabels&&e._hasValues&&(c(\"label0\"),c(\"dlabel\")),f){e._length=f,c(\"marker.line.width\")&&c(\"marker.line.color\"),c(\"marker.colors\"),c(\"scalegroup\");var h,p=c(\"text\"),d=c(\"texttemplate\");if(d||(h=c(\"textinfo\",Array.isArray(p)?\"text+percent\":\"percent\")),c(\"hovertext\"),c(\"hovertemplate\"),d||h&&\"none\"!==h){var m=c(\"textposition\");s(t,e,n,c,m,{moduleHasSelected:!1,moduleHasUnselected:!1,moduleHasConstrain:!1,moduleHasCliponaxis:!1,moduleHasTextangle:!1,moduleHasInsideanchor:!1}),(Array.isArray(m)||\"auto\"===m||\"outside\"===m)&&c(\"automargin\"),(\"inside\"===m||\"auto\"===m||Array.isArray(m))&&c(\"insidetextorientation\")}o(e,n,c);var g=c(\"hole\");if(c(\"title.text\")){var v=c(\"title.position\",g?\"middle center\":\"top center\");g||\"middle center\"!==v||(e.title.position=\"top center\"),i.coerceFont(c,\"title.font\",n.font)}c(\"sort\"),c(\"direction\"),c(\"rotation\"),c(\"pull\")}else e.visible=!1}}},{\"../../lib\":799,\"../../plots/domain\":877,\"../bar/defaults\":941,\"./attributes\":1188,\"fast-isnumeric\":245}],1192:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx/helpers\").appendArrayMultiPointValues;e.exports=function(t,e){var r={curveNumber:e.index,pointNumbers:t.pts,data:e._input,fullData:e,label:t.label,color:t.color,value:t.v,percent:t.percent,text:t.text,v:t.v};return 1===t.pts.length&&(r.pointNumber=r.i=t.pts[0]),n(r,e,t.pts),\"funnelarea\"===e.type&&(delete r.v,delete r.i),r}},{\"../../components/fx/helpers\":698}],1193:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");function i(t){return-1!==t.indexOf(\"e\")?t.replace(/[.]?0+e/,\"e\"):-1!==t.indexOf(\".\")?t.replace(/[.]?0+$/,\"\"):t}r.formatPiePercent=function(t,e){var r=i((100*t).toPrecision(3));return n.numSeparate(r,e)+\"%\"},r.formatPieValue=function(t,e){var r=i(t.toPrecision(10));return n.numSeparate(r,e)},r.getFirstFilled=function(t,e){if(Array.isArray(t))for(var r=0;r<e.length;r++){var n=t[e[r]];if(n||0===n||\"\"===n)return n}},r.castOption=function(t,e){return Array.isArray(t)?r.getFirstFilled(t,e):t||void 0},r.getRotationAngle=function(t){return(\"auto\"===t?0:t)*Math.PI/180}},{\"../../lib\":799}],1194:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\").supplyDefaults,supplyLayoutDefaults:t(\"./layout_defaults\"),layoutAttributes:t(\"./layout_attributes\"),calc:t(\"./calc\").calc,crossTraceCalc:t(\"./calc\").crossTraceCalc,plot:t(\"./plot\").plot,style:t(\"./style\"),styleOne:t(\"./style_one\"),moduleType:\"trace\",name:\"pie\",basePlotModule:t(\"./base_plot\"),categories:[\"pie-like\",\"pie\",\"showLegend\"],meta:{}}},{\"./attributes\":1188,\"./base_plot\":1189,\"./calc\":1190,\"./defaults\":1191,\"./layout_attributes\":1195,\"./layout_defaults\":1196,\"./plot\":1197,\"./style\":1198,\"./style_one\":1199}],1195:[function(t,e,r){\"use strict\";e.exports={hiddenlabels:{valType:\"data_array\",editType:\"calc\"},piecolorway:{valType:\"colorlist\",editType:\"calc\"},extendpiecolors:{valType:\"boolean\",dflt:!0,editType:\"calc\"}}},{}],1196:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\");e.exports=function(t,e){function r(r,a){return n.coerce(t,e,i,r,a)}r(\"hiddenlabels\"),r(\"piecolorway\",e.colorway),r(\"extendpiecolors\")}},{\"../../lib\":799,\"./layout_attributes\":1195}],1197:[function(t,e,r){\"use strict\";var n=t(\"@plotly/d3\"),i=t(\"../../plots/plots\"),a=t(\"../../components/fx\"),o=t(\"../../components/color\"),s=t(\"../../components/drawing\"),l=t(\"../../lib\"),c=l.strScale,u=l.strTranslate,f=t(\"../../lib/svg_text_utils\"),h=t(\"../bar/uniform_text\"),p=h.recordMinTextSize,d=h.clearMinTextSize,m=t(\"../bar/constants\").TEXTPAD,g=t(\"./helpers\"),v=t(\"./event_data\"),y=t(\"../../lib\").isValidTextValue;function x(t,e,r){var i=r[0],o=i.trace,s=i.cx,c=i.cy;\"_hasHoverLabel\"in o||(o._hasHoverLabel=!1),\"_hasHoverEvent\"in o||(o._hasHoverEvent=!1),t.on(\"mouseover\",(function(t){var r=e._fullLayout,u=e._fullData[o.index];if(!e._dragging&&!1!==r.hovermode){var f=u.hoverinfo;if(Array.isArray(f)&&(f=a.castHoverinfo({hoverinfo:[g.castOption(f,t.pts)],_module:o._module},r,0)),\"all\"===f&&(f=\"label+text+value+percent+name\"),u.hovertemplate||\"none\"!==f&&\"skip\"!==f&&f){var h=t.rInscribed||0,p=s+t.pxmid[0]*(1-h),d=c+t.pxmid[1]*(1-h),m=r.separators,y=[];if(f&&-1!==f.indexOf(\"label\")&&y.push(t.label),t.text=g.castOption(u.hovertext||u.text,t.pts),f&&-1!==f.indexOf(\"text\")){var x=t.text;l.isValidTextValue(x)&&y.push(x)}t.value=t.v,t.valueLabel=g.formatPieValue(t.v,m),f&&-1!==f.indexOf(\"value\")&&y.push(t.valueLabel),t.percent=t.v/i.vTotal,t.percentLabel=g.formatPiePercent(t.percent,m),f&&-1!==f.indexOf(\"percent\")&&y.push(t.percentLabel);var b=u.hoverlabel,_=b.font;a.loneHover({trace:o,x0:p-h*i.r,x1:p+h*i.r,y:d,text:y.join(\"<br>\"),name:u.hovertemplate||-1!==f.indexOf(\"name\")?u.name:void 0,idealAlign:t.pxmid[0]<0?\"left\":\"right\",color:g.castOption(b.bgcolor,t.pts)||t.color,borderColor:g.castOption(b.bordercolor,t.pts),fontFamily:g.castOption(_.family,t.pts),fontSize:g.castOption(_.size,t.pts),fontColor:g.castOption(_.color,t.pts),nameLength:g.castOption(b.namelength,t.pts),textAlign:g.castOption(b.align,t.pts),hovertemplate:g.castOption(u.hovertemplate,t.pts),hovertemplateLabels:t,eventData:[v(t,u)]},{container:r._hoverlayer.node(),outerContainer:r._paper.node(),gd:e}),o._hasHoverLabel=!0}o._hasHoverEvent=!0,e.emit(\"plotly_hover\",{points:[v(t,u)],event:n.event})}})),t.on(\"mouseout\",(function(t){var r=e._fullLayout,i=e._fullData[o.index],s=n.select(this).datum();o._hasHoverEvent&&(t.originalEvent=n.event,e.emit(\"plotly_unhover\",{points:[v(s,i)],event:n.event}),o._hasHoverEvent=!1),o._hasHoverLabel&&(a.loneUnhover(r._hoverlayer.node()),o._hasHoverLabel=!1)})),t.on(\"click\",(function(t){var r=e._fullLayout,i=e._fullData[o.index];e._dragging||!1===r.hovermode||(e._hoverdata=[v(t,i)],a.click(e,n.event))}))}function b(t,e,r){var n=g.castOption(t.insidetextfont.color,e.pts);!n&&t._input.textfont&&(n=g.castOption(t._input.textfont.color,e.pts));var i=g.castOption(t.insidetextfont.family,e.pts)||g.castOption(t.textfont.family,e.pts)||r.family,a=g.castOption(t.insidetextfont.size,e.pts)||g.castOption(t.textfont.size,e.pts)||r.size;return{color:n||o.contrast(e.color),family:i,size:a}}function _(t,e){for(var r,n,i=0;i<t.length;i++)if((n=(r=t[i][0]).trace).title.text){var a=n.title.text;n._meta&&(a=l.templateString(a,n._meta));var o=s.tester.append(\"text\").attr(\"data-notex\",1).text(a).call(s.font,n.title.font).call(f.convertToTspans,e),c=s.bBox(o.node(),!0);r.titleBox={width:c.width,height:c.height},o.remove()}}function w(t,e,r){var n=r.r||e.rpx1,i=e.rInscribed;if(e.startangle===e.stopangle)return{rCenter:1-i,scale:0,rotate:0,textPosAngle:0};var a,o=e.ring,s=1===o&&Math.abs(e.startangle-e.stopangle)===2*Math.PI,l=e.halfangle,c=e.midangle,u=r.trace.insidetextorientation,f=\"horizontal\"===u,h=\"tangential\"===u,p=\"radial\"===u,d=\"auto\"===u,m=[];if(!d){var g,v=function(r,i){if(function(t,e){var r=t.startangle,n=t.stopangle;return r>e&&e>n||r<e&&e<n}(e,r)){var s=Math.abs(r-e.startangle),l=Math.abs(r-e.stopangle),c=s<l?s:l;(a=\"tan\"===i?k(t,n,o,c,0):T(t,n,o,c,Math.PI/2)).textPosAngle=r,m.push(a)}};if(f||h){for(g=4;g>=-4;g-=2)v(Math.PI*g,\"tan\");for(g=4;g>=-4;g-=2)v(Math.PI*(g+1),\"tan\")}if(f||p){for(g=4;g>=-4;g-=2)v(Math.PI*(g+1.5),\"rad\");for(g=4;g>=-4;g-=2)v(Math.PI*(g+.5),\"rad\")}}if(s||d||f){var y=Math.sqrt(t.width*t.width+t.height*t.height);if((a={scale:i*n*2/y,rCenter:1-i,rotate:0}).textPosAngle=(e.startangle+e.stopangle)/2,a.scale>=1)return a;m.push(a)}(d||p)&&((a=T(t,n,o,l,c)).textPosAngle=(e.startangle+e.stopangle)/2,m.push(a)),(d||h)&&((a=k(t,n,o,l,c)).textPosAngle=(e.startangle+e.stopangle)/2,m.push(a));for(var x=0,b=0,_=0;_<m.length;_++){var w=m[_].scale;if(b<w&&(b=w,x=_),!d&&b>=1)break}return m[x]}function T(t,e,r,n,i){e=Math.max(0,e-2*m);var a=t.width/t.height,o=S(a,n,e,r);return{scale:2*o/t.height,rCenter:M(a,o/e),rotate:A(i)}}function k(t,e,r,n,i){e=Math.max(0,e-2*m);var a=t.height/t.width,o=S(a,n,e,r);return{scale:2*o/t.width,rCenter:M(a,o/e),rotate:A(i+Math.PI/2)}}function M(t,e){return Math.cos(e)-t*e}function A(t){return(180/Math.PI*t+720)%180-90}function S(t,e,r,n){var i=t+1/(2*Math.tan(e));return r*Math.min(1/(Math.sqrt(i*i+.5)+i),n/(Math.sqrt(t*t+n/2)+t))}function E(t,e){return t.v!==e.vTotal||e.trace.hole?Math.min(1/(1+1/Math.sin(t.halfangle)),t.ring/2):1}function L(t,e){var r=e.pxmid[0],n=e.pxmid[1],i=t.width/2,a=t.height/2;return r<0&&(i*=-1),n<0&&(a*=-1),{scale:1,rCenter:1,rotate:0,x:i+Math.abs(a)*(i>0?1:-1)/2,y:a/(1+r*r/(n*n)),outside:!0}}function C(t,e){var r,n,i,a=t.trace,o={x:t.cx,y:t.cy},s={tx:0,ty:0};s.ty+=a.title.font.size,i=I(a),-1!==a.title.position.indexOf(\"top\")?(o.y-=(1+i)*t.r,s.ty-=t.titleBox.height):-1!==a.title.position.indexOf(\"bottom\")&&(o.y+=(1+i)*t.r);var l,c,u=(l=t.r,c=t.trace.aspectratio,l/(void 0===c?1:c)),f=e.w*(a.domain.x[1]-a.domain.x[0])/2;return-1!==a.title.position.indexOf(\"left\")?(f+=u,o.x-=(1+i)*u,s.tx+=t.titleBox.width/2):-1!==a.title.position.indexOf(\"center\")?f*=2:-1!==a.title.position.indexOf(\"right\")&&(f+=u,o.x+=(1+i)*u,s.tx-=t.titleBox.width/2),r=f/t.titleBox.width,n=P(t,e)/t.titleBox.height,{x:o.x,y:o.y,scale:Math.min(r,n),tx:s.tx,ty:s.ty}}function P(t,e){var r=t.trace,n=e.h*(r.domain.y[1]-r.domain.y[0]);return Math.min(t.titleBox.height,n/2)}function I(t){var e,r=t.pull;if(!r)return 0;if(Array.isArray(r))for(r=0,e=0;e<t.pull.length;e++)t.pull[e]>r&&(r=t.pull[e]);return r}function O(t,e){for(var r=[],n=0;n<t.length;n++){var i=t[n][0],a=i.trace,o=a.domain,s=e.w*(o.x[1]-o.x[0]),l=e.h*(o.y[1]-o.y[0]);a.title.text&&\"middle center\"!==a.title.position&&(l-=P(i,e));var c=s/2,u=l/2;\"funnelarea\"!==a.type||a.scalegroup||(u/=a.aspectratio),i.r=Math.min(c,u)/(1+I(a)),i.cx=e.l+e.w*(a.domain.x[1]+a.domain.x[0])/2,i.cy=e.t+e.h*(1-a.domain.y[0])-l/2,a.title.text&&-1!==a.title.position.indexOf(\"bottom\")&&(i.cy-=P(i,e)),a.scalegroup&&-1===r.indexOf(a.scalegroup)&&r.push(a.scalegroup)}!function(t,e){for(var r,n,i,a=0;a<e.length;a++){var o=1/0,s=e[a];for(n=0;n<t.length;n++)if(r=t[n][0],(i=r.trace).scalegroup===s){var l;if(\"pie\"===i.type)l=r.r*r.r;else if(\"funnelarea\"===i.type){var c,u;i.aspectratio>1?(c=r.r,u=c/i.aspectratio):(u=r.r,c=u*i.aspectratio),c*=(1+i.baseratio)/2,l=c*u}o=Math.min(o,l/r.vTotal)}for(n=0;n<t.length;n++)if(r=t[n][0],(i=r.trace).scalegroup===s){var f=o*r.vTotal;\"funnelarea\"===i.type&&(f/=(1+i.baseratio)/2,f/=i.aspectratio),r.r=Math.sqrt(f)}}}(t,r)}function z(t,e){return[t*Math.sin(e),-t*Math.cos(e)]}function D(t,e,r){var n=t._fullLayout,i=r.trace,a=i.texttemplate,o=i.textinfo;if(!a&&o&&\"none\"!==o){var s,c=o.split(\"+\"),u=function(t){return-1!==c.indexOf(t)},f=u(\"label\"),h=u(\"text\"),p=u(\"value\"),d=u(\"percent\"),m=n.separators;if(s=f?[e.label]:[],h){var v=g.getFirstFilled(i.text,e.pts);y(v)&&s.push(v)}p&&s.push(g.formatPieValue(e.v,m)),d&&s.push(g.formatPiePercent(e.v/r.vTotal,m)),e.text=s.join(\"<br>\")}if(a){var x=l.castOption(i,e.i,\"texttemplate\");if(x){var b=function(t){return{label:t.label,value:t.v,valueLabel:g.formatPieValue(t.v,n.separators),percent:t.v/r.vTotal,percentLabel:g.formatPiePercent(t.v/r.vTotal,n.separators),color:t.color,text:t.text,customdata:l.castOption(i,t.i,\"customdata\")}}(e),_=g.getFirstFilled(i.text,e.pts);(y(_)||\"\"===_)&&(b.text=_),e.text=l.texttemplateString(x,b,t._fullLayout._d3locale,b,i._meta||{})}else e.text=\"\"}}function R(t,e){var r=t.rotate*Math.PI/180,n=Math.cos(r),i=Math.sin(r),a=(e.left+e.right)/2,o=(e.top+e.bottom)/2;t.textX=a*n-o*i,t.textY=a*i+o*n,t.noCenter=!0}e.exports={plot:function(t,e){var r=t._fullLayout,a=r._size;d(\"pie\",r),_(e,t),O(e,a);var h=l.makeTraceGroups(r._pielayer,e,\"trace\").each((function(e){var h=n.select(this),d=e[0],m=d.trace;!function(t){var e,r,n,i=t[0],a=i.r,o=i.trace,s=g.getRotationAngle(o.rotation),l=2*Math.PI/i.vTotal,c=\"px0\",u=\"px1\";if(\"counterclockwise\"===o.direction){for(e=0;e<t.length&&t[e].hidden;e++);if(e===t.length)return;s+=l*t[e].v,l*=-1,c=\"px1\",u=\"px0\"}for(n=z(a,s),e=0;e<t.length;e++)(r=t[e]).hidden||(r[c]=n,r.startangle=s,s+=l*r.v/2,r.pxmid=z(a,s),r.midangle=s,s+=l*r.v/2,n=z(a,s),r.stopangle=s,r[u]=n,r.largeArc=r.v>i.vTotal/2?1:0,r.halfangle=Math.PI*Math.min(r.v/i.vTotal,.5),r.ring=1-o.hole,r.rInscribed=E(r,i))}(e),h.attr(\"stroke-linejoin\",\"round\"),h.each((function(){var v=n.select(this).selectAll(\"g.slice\").data(e);v.enter().append(\"g\").classed(\"slice\",!0),v.exit().remove();var y=[[[],[]],[[],[]]],_=!1;v.each((function(i,a){if(i.hidden)n.select(this).selectAll(\"path,g\").remove();else{i.pointNumber=i.i,i.curveNumber=m.index,y[i.pxmid[1]<0?0:1][i.pxmid[0]<0?0:1].push(i);var o=d.cx,c=d.cy,u=n.select(this),h=u.selectAll(\"path.surface\").data([i]);if(h.enter().append(\"path\").classed(\"surface\",!0).style({\"pointer-events\":\"all\"}),u.call(x,t,e),m.pull){var v=+g.castOption(m.pull,i.pts)||0;v>0&&(o+=v*i.pxmid[0],c+=v*i.pxmid[1])}i.cxFinal=o,i.cyFinal=c;var T=m.hole;if(i.v===d.vTotal){var k=\"M\"+(o+i.px0[0])+\",\"+(c+i.px0[1])+C(i.px0,i.pxmid,!0,1)+C(i.pxmid,i.px0,!0,1)+\"Z\";T?h.attr(\"d\",\"M\"+(o+T*i.px0[0])+\",\"+(c+T*i.px0[1])+C(i.px0,i.pxmid,!1,T)+C(i.pxmid,i.px0,!1,T)+\"Z\"+k):h.attr(\"d\",k)}else{var M=C(i.px0,i.px1,!0,1);if(T){var A=1-T;h.attr(\"d\",\"M\"+(o+T*i.px1[0])+\",\"+(c+T*i.px1[1])+C(i.px1,i.px0,!1,T)+\"l\"+A*i.px0[0]+\",\"+A*i.px0[1]+M+\"Z\")}else h.attr(\"d\",\"M\"+o+\",\"+c+\"l\"+i.px0[0]+\",\"+i.px0[1]+M+\"Z\")}D(t,i,d);var S=g.castOption(m.textposition,i.pts),E=u.selectAll(\"g.slicetext\").data(i.text&&\"none\"!==S?[0]:[]);E.enter().append(\"g\").classed(\"slicetext\",!0),E.exit().remove(),E.each((function(){var u=l.ensureSingle(n.select(this),\"text\",\"\",(function(t){t.attr(\"data-notex\",1)})),h=l.ensureUniformFontSize(t,\"outside\"===S?function(t,e,r){var n=g.castOption(t.outsidetextfont.color,e.pts)||g.castOption(t.textfont.color,e.pts)||r.color,i=g.castOption(t.outsidetextfont.family,e.pts)||g.castOption(t.textfont.family,e.pts)||r.family,a=g.castOption(t.outsidetextfont.size,e.pts)||g.castOption(t.textfont.size,e.pts)||r.size;return{color:n,family:i,size:a}}(m,i,r.font):b(m,i,r.font));u.text(i.text).attr({class:\"slicetext\",transform:\"\",\"text-anchor\":\"middle\"}).call(s.font,h).call(f.convertToTspans,t);var v,y=s.bBox(u.node());if(\"outside\"===S)v=L(y,i);else if(v=w(y,i,d),\"auto\"===S&&v.scale<1){var x=l.ensureUniformFontSize(t,m.outsidetextfont);u.call(s.font,x),v=L(y=s.bBox(u.node()),i)}var T=v.textPosAngle,k=void 0===T?i.pxmid:z(d.r,T);if(v.targetX=o+k[0]*v.rCenter+(v.x||0),v.targetY=c+k[1]*v.rCenter+(v.y||0),R(v,y),v.outside){var M=v.targetY;i.yLabelMin=M-y.height/2,i.yLabelMid=M,i.yLabelMax=M+y.height/2,i.labelExtraX=0,i.labelExtraY=0,_=!0}v.fontSize=h.size,p(m.type,v,r),e[a].transform=v,u.attr(\"transform\",l.getTextTransform(v))}))}function C(t,e,r,n){var a=n*(e[0]-t[0]),o=n*(e[1]-t[1]);return\"a\"+n*d.r+\",\"+n*d.r+\" 0 \"+i.largeArc+(r?\" 1 \":\" 0 \")+a+\",\"+o}}));var T=n.select(this).selectAll(\"g.titletext\").data(m.title.text?[0]:[]);if(T.enter().append(\"g\").classed(\"titletext\",!0),T.exit().remove(),T.each((function(){var e,r=l.ensureSingle(n.select(this),\"text\",\"\",(function(t){t.attr(\"data-notex\",1)})),i=m.title.text;m._meta&&(i=l.templateString(i,m._meta)),r.text(i).attr({class:\"titletext\",transform:\"\",\"text-anchor\":\"middle\"}).call(s.font,m.title.font).call(f.convertToTspans,t),e=\"middle center\"===m.title.position?function(t){var e=Math.sqrt(t.titleBox.width*t.titleBox.width+t.titleBox.height*t.titleBox.height);return{x:t.cx,y:t.cy,scale:t.trace.hole*t.r*2/e,tx:0,ty:-t.titleBox.height/2+t.trace.title.font.size}}(d):C(d,a),r.attr(\"transform\",u(e.x,e.y)+c(Math.min(1,e.scale))+u(e.tx,e.ty))})),_&&function(t,e){var r,n,i,a,o,s,l,c,u,f,h,p,d;function m(t,e){return t.pxmid[1]-e.pxmid[1]}function v(t,e){return e.pxmid[1]-t.pxmid[1]}function y(t,r){r||(r={});var i,c,u,h,p=r.labelExtraY+(n?r.yLabelMax:r.yLabelMin),d=n?t.yLabelMin:t.yLabelMax,m=n?t.yLabelMax:t.yLabelMin,v=t.cyFinal+o(t.px0[1],t.px1[1]),y=p-d;if(y*l>0&&(t.labelExtraY=y),Array.isArray(e.pull))for(c=0;c<f.length;c++)(u=f[c])===t||(g.castOption(e.pull,t.pts)||0)>=(g.castOption(e.pull,u.pts)||0)||((t.pxmid[1]-u.pxmid[1])*l>0?(y=u.cyFinal+o(u.px0[1],u.px1[1])-d-t.labelExtraY)*l>0&&(t.labelExtraY+=y):(m+t.labelExtraY-v)*l>0&&(i=3*s*Math.abs(c-f.indexOf(t)),(h=u.cxFinal+a(u.px0[0],u.px1[0])+i-(t.cxFinal+t.pxmid[0])-t.labelExtraX)*s>0&&(t.labelExtraX+=h)))}for(n=0;n<2;n++)for(i=n?m:v,o=n?Math.max:Math.min,l=n?1:-1,r=0;r<2;r++){for(a=r?Math.max:Math.min,s=r?1:-1,(c=t[n][r]).sort(i),u=t[1-n][r],f=u.concat(c),p=[],h=0;h<c.length;h++)void 0!==c[h].yLabelMid&&p.push(c[h]);for(d=!1,h=0;n&&h<u.length;h++)if(void 0!==u[h].yLabelMid){d=u[h];break}for(h=0;h<p.length;h++){var x=h&&p[h-1];d&&!h&&(x=d),y(p[h],x)}}}(y,m),function(t,e){t.each((function(t){var r=n.select(this);if(t.labelExtraX||t.labelExtraY){var i=r.select(\"g.slicetext text\");t.transform.targetX+=t.labelExtraX,t.transform.targetY+=t.labelExtraY,i.attr(\"transform\",l.getTextTransform(t.transform));var a=t.cxFinal+t.pxmid[0],s=\"M\"+a+\",\"+(t.cyFinal+t.pxmid[1]),c=(t.yLabelMax-t.yLabelMin)*(t.pxmid[0]<0?-1:1)/4;if(t.labelExtraX){var u=t.labelExtraX*t.pxmid[1]/t.pxmid[0],f=t.yLabelMid+t.labelExtraY-(t.cyFinal+t.pxmid[1]);Math.abs(u)>Math.abs(f)?s+=\"l\"+f*t.pxmid[0]/t.pxmid[1]+\",\"+f+\"H\"+(a+t.labelExtraX+c):s+=\"l\"+t.labelExtraX+\",\"+u+\"v\"+(f-u)+\"h\"+c}else s+=\"V\"+(t.yLabelMid+t.labelExtraY)+\"h\"+c;l.ensureSingle(r,\"path\",\"textline\").call(o.stroke,e.outsidetextfont.color).attr({\"stroke-width\":Math.min(2,e.outsidetextfont.size/8),d:s,fill:\"none\"})}else r.select(\"path.textline\").remove()}))}(v,m),_&&m.automargin){var k=s.bBox(h.node()),M=m.domain,A=a.w*(M.x[1]-M.x[0]),S=a.h*(M.y[1]-M.y[0]),E=(.5*A-d.r)/a.w,P=(.5*S-d.r)/a.h;i.autoMargin(t,\"pie.\"+m.uid+\".automargin\",{xl:M.x[0]-E,xr:M.x[1]+E,yb:M.y[0]-P,yt:M.y[1]+P,l:Math.max(d.cx-d.r-k.left,0),r:Math.max(k.right-(d.cx+d.r),0),b:Math.max(k.bottom-(d.cy+d.r),0),t:Math.max(d.cy-d.r-k.top,0),pad:5})}}))}));setTimeout((function(){h.selectAll(\"tspan\").each((function(){var t=n.select(this);t.attr(\"dy\")&&t.attr(\"dy\",t.attr(\"dy\"))}))}),0)},formatSliceLabel:D,transformInsideText:w,determineInsideTextFont:b,positionTitleOutside:C,prerenderTitles:_,layoutAreas:O,attachFxHandlers:x,computeTransform:R}},{\"../../components/color\":662,\"../../components/drawing\":684,\"../../components/fx\":702,\"../../lib\":799,\"../../lib/svg_text_utils\":824,\"../../plots/plots\":913,\"../bar/constants\":939,\"../bar/uniform_text\":953,\"./event_data\":1192,\"./helpers\":1193,\"@plotly/d3\":58}],1198:[function(t,e,r){\"use strict\";var n=t(\"@plotly/d3\"),i=t(\"./style_one\"),a=t(\"../bar/uniform_text\").resizeText;e.exports=function(t){var e=t._fullLayout._pielayer.selectAll(\".trace\");a(t,e,\"pie\"),e.each((function(t){var e=t[0].trace,r=n.select(this);r.style({opacity:e.opacity}),r.selectAll(\"path.surface\").each((function(t){n.select(this).call(i,t,e)}))}))}},{\"../bar/uniform_text\":953,\"./style_one\":1199,\"@plotly/d3\":58}],1199:[function(t,e,r){\"use strict\";var n=t(\"../../components/color\"),i=t(\"./helpers\").castOption;e.exports=function(t,e,r){var a=r.marker.line,o=i(a.color,e.pts)||n.defaultLine,s=i(a.width,e.pts)||0;t.style(\"stroke-width\",s).call(n.fill,e.color).call(n.stroke,o)}},{\"../../components/color\":662,\"./helpers\":1193}],1200:[function(t,e,r){\"use strict\";var n=t(\"../scatter/attributes\");e.exports={x:n.x,y:n.y,xy:{valType:\"data_array\",editType:\"calc\"},indices:{valType:\"data_array\",editType:\"calc\"},xbounds:{valType:\"data_array\",editType:\"calc\"},ybounds:{valType:\"data_array\",editType:\"calc\"},text:n.text,marker:{color:{valType:\"color\",arrayOk:!1,editType:\"calc\"},opacity:{valType:\"number\",min:0,max:1,dflt:1,arrayOk:!1,editType:\"calc\"},blend:{valType:\"boolean\",dflt:null,editType:\"calc\"},sizemin:{valType:\"number\",min:.1,max:2,dflt:.5,editType:\"calc\"},sizemax:{valType:\"number\",min:.1,dflt:20,editType:\"calc\"},border:{color:{valType:\"color\",arrayOk:!1,editType:\"calc\"},arearatio:{valType:\"number\",min:0,max:1,dflt:0,editType:\"calc\"},editType:\"calc\"},editType:\"calc\"},transforms:void 0}},{\"../scatter/attributes\":1214}],1201:[function(t,e,r){\"use strict\";var n=t(\"gl-pointcloud2d\"),i=t(\"../../lib/str2rgbarray\"),a=t(\"../../plots/cartesian/autorange\").findExtremes,o=t(\"../scatter/get_trace_color\");function s(t,e){this.scene=t,this.uid=e,this.type=\"pointcloud\",this.pickXData=[],this.pickYData=[],this.xData=[],this.yData=[],this.textLabels=[],this.color=\"rgb(0, 0, 0)\",this.name=\"\",this.hoverinfo=\"all\",this.idToIndex=new Int32Array(0),this.bounds=[0,0,0,0],this.pointcloudOptions={positions:new Float32Array(0),idToIndex:this.idToIndex,sizemin:.5,sizemax:12,color:[0,0,0,1],areaRatio:1,borderColor:[0,0,0,1]},this.pointcloud=n(t.glplot,this.pointcloudOptions),this.pointcloud._trace=this}var l=s.prototype;l.handlePick=function(t){var e=this.idToIndex[t.pointId];return{trace:this,dataCoord:t.dataCoord,traceCoord:this.pickXYData?[this.pickXYData[2*e],this.pickXYData[2*e+1]]:[this.pickXData[e],this.pickYData[e]],textLabel:Array.isArray(this.textLabels)?this.textLabels[e]:this.textLabels,color:this.color,name:this.name,pointIndex:e,hoverinfo:this.hoverinfo}},l.update=function(t){this.index=t.index,this.textLabels=t.text,this.name=t.name,this.hoverinfo=t.hoverinfo,this.bounds=[1/0,1/0,-1/0,-1/0],this.updateFast(t),this.color=o(t,{})},l.updateFast=function(t){var e,r,n,o,s,l,c=this.xData=this.pickXData=t.x,u=this.yData=this.pickYData=t.y,f=this.pickXYData=t.xy,h=t.xbounds&&t.ybounds,p=t.indices,d=this.bounds;if(f){if(n=f,e=f.length>>>1,h)d[0]=t.xbounds[0],d[2]=t.xbounds[1],d[1]=t.ybounds[0],d[3]=t.ybounds[1];else for(l=0;l<e;l++)o=n[2*l],s=n[2*l+1],o<d[0]&&(d[0]=o),o>d[2]&&(d[2]=o),s<d[1]&&(d[1]=s),s>d[3]&&(d[3]=s);if(p)r=p;else for(r=new Int32Array(e),l=0;l<e;l++)r[l]=l}else for(e=c.length,n=new Float32Array(2*e),r=new Int32Array(e),l=0;l<e;l++)o=c[l],s=u[l],r[l]=l,n[2*l]=o,n[2*l+1]=s,o<d[0]&&(d[0]=o),o>d[2]&&(d[2]=o),s<d[1]&&(d[1]=s),s>d[3]&&(d[3]=s);this.idToIndex=r,this.pointcloudOptions.idToIndex=r,this.pointcloudOptions.positions=n;var m=i(t.marker.color),g=i(t.marker.border.color),v=t.opacity*t.marker.opacity;m[3]*=v,this.pointcloudOptions.color=m;var y=t.marker.blend;if(null===y){y=c.length<100||u.length<100}this.pointcloudOptions.blend=y,g[3]*=v,this.pointcloudOptions.borderColor=g;var x=t.marker.sizemin,b=Math.max(t.marker.sizemax,t.marker.sizemin);this.pointcloudOptions.sizeMin=x,this.pointcloudOptions.sizeMax=b,this.pointcloudOptions.areaRatio=t.marker.border.arearatio,this.pointcloud.update(this.pointcloudOptions);var _=this.scene.xaxis,w=this.scene.yaxis,T=b/2||.5;t._extremes[_._id]=a(_,[d[0],d[2]],{ppad:T}),t._extremes[w._id]=a(w,[d[1],d[3]],{ppad:T})},l.dispose=function(){this.pointcloud.dispose()},e.exports=function(t,e){var r=new s(t,e.uid);return r.update(e),r}},{\"../../lib/str2rgbarray\":823,\"../../plots/cartesian/autorange\":848,\"../scatter/get_trace_color\":1224,\"gl-pointcloud2d\":324}],1202:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\");e.exports=function(t,e,r){function a(r,a){return n.coerce(t,e,i,r,a)}a(\"x\"),a(\"y\"),a(\"xbounds\"),a(\"ybounds\"),t.xy&&t.xy instanceof Float32Array&&(e.xy=t.xy),t.indices&&t.indices instanceof Int32Array&&(e.indices=t.indices),a(\"text\"),a(\"marker.color\",r),a(\"marker.opacity\"),a(\"marker.blend\"),a(\"marker.sizemin\"),a(\"marker.sizemax\"),a(\"marker.border.color\",r),a(\"marker.border.arearatio\"),e._length=null}},{\"../../lib\":799,\"./attributes\":1200}],1203:[function(t,e,r){\"use strict\";[\"*pointcloud* trace is deprecated!\",\"Please consider switching to the *scattergl* trace type.\"].join(\" \");e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"../scatter3d/calc\"),plot:t(\"./convert\"),moduleType:\"trace\",name:\"pointcloud\",basePlotModule:t(\"../../plots/gl2d\"),categories:[\"gl\",\"gl2d\",\"showLegend\"],meta:{}}},{\"../../plots/gl2d\":890,\"../scatter3d/calc\":1243,\"./attributes\":1200,\"./convert\":1201,\"./defaults\":1202}],1204:[function(t,e,r){\"use strict\";var n=t(\"../../plots/font_attributes\"),i=t(\"../../plots/attributes\"),a=t(\"../../components/color/attributes\"),o=t(\"../../components/fx/attributes\"),s=t(\"../../plots/domain\").attributes,l=t(\"../../plots/template_attributes\").hovertemplateAttrs,c=t(\"../../components/colorscale/attributes\"),u=t(\"../../plot_api/plot_template\").templatedArray,f=t(\"../../plots/cartesian/axis_format_attributes\").descriptionOnlyNumbers,h=t(\"../../lib/extend\").extendFlat,p=t(\"../../plot_api/edit_types\").overrideAll;(e.exports=p({hoverinfo:h({},i.hoverinfo,{flags:[],arrayOk:!1}),hoverlabel:o.hoverlabel,domain:s({name:\"sankey\",trace:!0}),orientation:{valType:\"enumerated\",values:[\"v\",\"h\"],dflt:\"h\"},valueformat:{valType:\"string\",dflt:\".3s\",description:f(\"value\")},valuesuffix:{valType:\"string\",dflt:\"\"},arrangement:{valType:\"enumerated\",values:[\"snap\",\"perpendicular\",\"freeform\",\"fixed\"],dflt:\"snap\"},textfont:n({}),customdata:void 0,node:{label:{valType:\"data_array\",dflt:[]},groups:{valType:\"info_array\",impliedEdits:{x:[],y:[]},dimensions:2,freeLength:!0,dflt:[],items:{valType:\"number\",editType:\"calc\"}},x:{valType:\"data_array\",dflt:[]},y:{valType:\"data_array\",dflt:[]},color:{valType:\"color\",arrayOk:!0},customdata:{valType:\"data_array\",editType:\"calc\"},line:{color:{valType:\"color\",dflt:a.defaultLine,arrayOk:!0},width:{valType:\"number\",min:0,dflt:.5,arrayOk:!0}},pad:{valType:\"number\",arrayOk:!1,min:0,dflt:20},thickness:{valType:\"number\",arrayOk:!1,min:1,dflt:20},hoverinfo:{valType:\"enumerated\",values:[\"all\",\"none\",\"skip\"],dflt:\"all\"},hoverlabel:o.hoverlabel,hovertemplate:l({},{keys:[\"value\",\"label\"]})},link:{label:{valType:\"data_array\",dflt:[]},color:{valType:\"color\",arrayOk:!0},customdata:{valType:\"data_array\",editType:\"calc\"},line:{color:{valType:\"color\",dflt:a.defaultLine,arrayOk:!0},width:{valType:\"number\",min:0,dflt:0,arrayOk:!0}},source:{valType:\"data_array\",dflt:[]},target:{valType:\"data_array\",dflt:[]},value:{valType:\"data_array\",dflt:[]},hoverinfo:{valType:\"enumerated\",values:[\"all\",\"none\",\"skip\"],dflt:\"all\"},hoverlabel:o.hoverlabel,hovertemplate:l({},{keys:[\"value\",\"label\"]}),colorscales:u(\"concentrationscales\",{editType:\"calc\",label:{valType:\"string\",editType:\"calc\",dflt:\"\"},cmax:{valType:\"number\",editType:\"calc\",dflt:1},cmin:{valType:\"number\",editType:\"calc\",dflt:0},colorscale:h(c().colorscale,{dflt:[[0,\"white\"],[1,\"black\"]]})})}},\"calc\",\"nested\")).transforms=void 0},{\"../../components/color/attributes\":661,\"../../components/colorscale/attributes\":669,\"../../components/fx/attributes\":693,\"../../lib/extend\":789,\"../../plot_api/edit_types\":831,\"../../plot_api/plot_template\":838,\"../../plots/attributes\":845,\"../../plots/cartesian/axis_format_attributes\":852,\"../../plots/domain\":877,\"../../plots/font_attributes\":878,\"../../plots/template_attributes\":922}],1205:[function(t,e,r){\"use strict\";var n=t(\"../../plot_api/edit_types\").overrideAll,i=t(\"../../plots/get_data\").getModuleCalcData,a=t(\"./plot\"),o=t(\"../../components/fx/layout_attributes\"),s=t(\"../../lib/setcursor\"),l=t(\"../../components/dragelement\"),c=t(\"../../plots/cartesian/select\").prepSelect,u=t(\"../../lib\"),f=t(\"../../registry\");function h(t,e){var r=t._fullData[e],n=t._fullLayout,i=n.dragmode,a=\"pan\"===n.dragmode?\"move\":\"crosshair\",o=r._bgRect;if(\"pan\"!==i&&\"zoom\"!==i){s(o,a);var h={_id:\"x\",c2p:u.identity,_offset:r._sankey.translateX,_length:r._sankey.width},p={_id:\"y\",c2p:u.identity,_offset:r._sankey.translateY,_length:r._sankey.height},d={gd:t,element:o.node(),plotinfo:{id:e,xaxis:h,yaxis:p,fillRangeItems:u.noop},subplot:e,xaxes:[h],yaxes:[p],doneFnCompleted:function(r){var n,i=t._fullData[e],a=i.node.groups.slice(),o=[];function s(t){for(var e=i._sankey.graph.nodes,r=0;r<e.length;r++)if(e[r].pointNumber===t)return e[r]}for(var l=0;l<r.length;l++){var c=s(r[l].pointNumber);if(c)if(c.group){for(var u=0;u<c.childrenNodes.length;u++)o.push(c.childrenNodes[u].pointNumber);a[c.pointNumber-i.node._count]=!1}else o.push(c.pointNumber)}n=a.filter(Boolean).concat([o]),f.call(\"_guiRestyle\",t,{\"node.groups\":[n]},e)},prepFn:function(t,e,r){c(t,e,r,d,i)}};l.init(d)}}r.name=\"sankey\",r.baseLayoutAttrOverrides=n({hoverlabel:o.hoverlabel},\"plot\",\"nested\"),r.plot=function(t){var e=i(t.calcdata,\"sankey\")[0];a(t,e),r.updateFx(t)},r.clean=function(t,e,r,n){var i=n._has&&n._has(\"sankey\"),a=e._has&&e._has(\"sankey\");i&&!a&&(n._paperdiv.selectAll(\".sankey\").remove(),n._paperdiv.selectAll(\".bgsankey\").remove())},r.updateFx=function(t){for(var e=0;e<t._fullData.length;e++)h(t,e)}},{\"../../components/dragelement\":681,\"../../components/fx/layout_attributes\":703,\"../../lib\":799,\"../../lib/setcursor\":820,\"../../plot_api/edit_types\":831,\"../../plots/cartesian/select\":869,\"../../plots/get_data\":887,\"../../registry\":927,\"./plot\":1210}],1206:[function(t,e,r){\"use strict\";var n=t(\"strongly-connected-components\"),i=t(\"../../lib\"),a=t(\"../../lib/gup\").wrap,o=i.isArrayOrTypedArray,s=i.isIndex,l=t(\"../../components/colorscale\");function c(t){var e,r=t.node,a=t.link,c=[],u=o(a.color),f=o(a.customdata),h={},p={},d=a.colorscales.length;for(e=0;e<d;e++){var m=a.colorscales[e],g=l.extractScale(m,{cLetter:\"c\"}),v=l.makeColorScaleFunc(g);p[m.label]=v}var y=0;for(e=0;e<a.value.length;e++)a.source[e]>y&&(y=a.source[e]),a.target[e]>y&&(y=a.target[e]);var x,b=y+1;t.node._count=b;var _=t.node.groups,w={};for(e=0;e<_.length;e++){var T=_[e];for(x=0;x<T.length;x++){var k=T[x],M=b+e;w.hasOwnProperty(k)?i.warn(\"Node \"+k+\" is already part of a group.\"):w[k]=M}}var A={source:[],target:[]};for(e=0;e<a.value.length;e++){var S=a.value[e],E=a.source[e],L=a.target[e];if(S>0&&s(E,b)&&s(L,b)&&(!w.hasOwnProperty(E)||!w.hasOwnProperty(L)||w[E]!==w[L])){w.hasOwnProperty(L)&&(L=w[L]),w.hasOwnProperty(E)&&(E=w[E]),L=+L,h[E=+E]=h[L]=!0;var C=\"\";a.label&&a.label[e]&&(C=a.label[e]);var P=null;C&&p.hasOwnProperty(C)&&(P=p[C]),c.push({pointNumber:e,label:C,color:u?a.color[e]:a.color,customdata:f?a.customdata[e]:a.customdata,concentrationscale:P,source:E,target:L,value:+S}),A.source.push(E),A.target.push(L)}}var I=b+_.length,O=o(r.color),z=o(r.customdata),D=[];for(e=0;e<I;e++)if(h[e]){var R=r.label[e];D.push({group:e>b-1,childrenNodes:[],pointNumber:e,label:R,color:O?r.color[e]:r.color,customdata:z?r.customdata[e]:r.customdata})}var F=!1;return function(t,e,r){for(var a=i.init2dArray(t,0),o=0;o<Math.min(e.length,r.length);o++)if(i.isIndex(e[o],t)&&i.isIndex(r[o],t)){if(e[o]===r[o])return!0;a[e[o]].push(r[o])}return n(a).components.some((function(t){return t.length>1}))}(I,A.source,A.target)&&(F=!0),{circular:F,links:c,nodes:D,groups:_,groupLookup:w}}e.exports=function(t,e){var r=c(e);return a({circular:r.circular,_nodes:r.nodes,_links:r.links,_groups:r.groups,_groupLookup:r.groupLookup})}},{\"../../components/colorscale\":674,\"../../lib\":799,\"../../lib/gup\":796,\"strongly-connected-components\":586}],1207:[function(t,e,r){\"use strict\";e.exports={nodeTextOffsetHorizontal:4,nodeTextOffsetVertical:3,nodePadAcross:10,sankeyIterations:50,forceIterations:5,forceTicksPerFrame:10,duration:500,ease:\"linear\",cn:{sankey:\"sankey\",sankeyLinks:\"sankey-links\",sankeyLink:\"sankey-link\",sankeyNodeSet:\"sankey-node-set\",sankeyNode:\"sankey-node\",nodeRect:\"node-rect\",nodeLabel:\"node-label\"}}},{}],1208:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\"),a=t(\"../../components/color\"),o=t(\"tinycolor2\"),s=t(\"../../plots/domain\").defaults,l=t(\"../../components/fx/hoverlabel_defaults\"),c=t(\"../../plot_api/plot_template\"),u=t(\"../../plots/array_container_defaults\");function f(t,e){function r(r,a){return n.coerce(t,e,i.link.colorscales,r,a)}r(\"label\"),r(\"cmin\"),r(\"cmax\"),r(\"colorscale\")}e.exports=function(t,e,r,h){function p(r,a){return n.coerce(t,e,i,r,a)}var d=n.extendDeep(h.hoverlabel,t.hoverlabel),m=t.node,g=c.newContainer(e,\"node\");function v(t,e){return n.coerce(m,g,i.node,t,e)}v(\"label\"),v(\"groups\"),v(\"x\"),v(\"y\"),v(\"pad\"),v(\"thickness\"),v(\"line.color\"),v(\"line.width\"),v(\"hoverinfo\",t.hoverinfo),l(m,g,v,d),v(\"hovertemplate\");var y=h.colorway;v(\"color\",g.label.map((function(t,e){return a.addOpacity(function(t){return y[t%y.length]}(e),.8)}))),v(\"customdata\");var x=t.link||{},b=c.newContainer(e,\"link\");function _(t,e){return n.coerce(x,b,i.link,t,e)}_(\"label\"),_(\"source\"),_(\"target\"),_(\"value\"),_(\"line.color\"),_(\"line.width\"),_(\"hoverinfo\",t.hoverinfo),l(x,b,_,d),_(\"hovertemplate\");var w,T=o(h.paper_bgcolor).getLuminance()<.333?\"rgba(255, 255, 255, 0.6)\":\"rgba(0, 0, 0, 0.2)\";_(\"color\",n.repeat(T,b.value.length)),_(\"customdata\"),u(x,b,{name:\"colorscales\",handleItemDefaults:f}),s(e,h,p),p(\"orientation\"),p(\"valueformat\"),p(\"valuesuffix\"),g.x.length&&g.y.length&&(w=\"freeform\"),p(\"arrangement\",w),n.coerceFont(p,\"textfont\",n.extendFlat({},h.font)),e._length=null}},{\"../../components/color\":662,\"../../components/fx/hoverlabel_defaults\":700,\"../../lib\":799,\"../../plot_api/plot_template\":838,\"../../plots/array_container_defaults\":844,\"../../plots/domain\":877,\"./attributes\":1204,tinycolor2:594}],1209:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\"),plot:t(\"./plot\"),moduleType:\"trace\",name:\"sankey\",basePlotModule:t(\"./base_plot\"),selectPoints:t(\"./select.js\"),categories:[\"noOpacity\"],meta:{}}},{\"./attributes\":1204,\"./base_plot\":1205,\"./calc\":1206,\"./defaults\":1208,\"./plot\":1210,\"./select.js\":1212}],1210:[function(t,e,r){\"use strict\";var n=t(\"@plotly/d3\"),i=t(\"./render\"),a=t(\"../../components/fx\"),o=t(\"../../components/color\"),s=t(\"../../lib\"),l=t(\"./constants\").cn,c=s._;function u(t){return\"\"!==t}function f(t,e){return t.filter((function(t){return t.key===e.traceId}))}function h(t,e){n.select(t).select(\"path\").style(\"fill-opacity\",e),n.select(t).select(\"rect\").style(\"fill-opacity\",e)}function p(t){n.select(t).select(\"text.name\").style(\"fill\",\"black\")}function d(t){return function(e){return-1!==t.node.sourceLinks.indexOf(e.link)||-1!==t.node.targetLinks.indexOf(e.link)}}function m(t){return function(e){return-1!==e.node.sourceLinks.indexOf(t.link)||-1!==e.node.targetLinks.indexOf(t.link)}}function g(t,e,r){e&&r&&f(r,e).selectAll(\".\"+l.sankeyLink).filter(d(e)).call(y.bind(0,e,r,!1))}function v(t,e,r){e&&r&&f(r,e).selectAll(\".\"+l.sankeyLink).filter(d(e)).call(x.bind(0,e,r,!1))}function y(t,e,r,n){var i=n.datum().link.label;n.style(\"fill-opacity\",(function(t){if(!t.link.concentrationscale)return.4})),i&&f(e,t).selectAll(\".\"+l.sankeyLink).filter((function(t){return t.link.label===i})).style(\"fill-opacity\",(function(t){if(!t.link.concentrationscale)return.4})),r&&f(e,t).selectAll(\".\"+l.sankeyNode).filter(m(t)).call(g)}function x(t,e,r,n){var i=n.datum().link.label;n.style(\"fill-opacity\",(function(t){return t.tinyColorAlpha})),i&&f(e,t).selectAll(\".\"+l.sankeyLink).filter((function(t){return t.link.label===i})).style(\"fill-opacity\",(function(t){return t.tinyColorAlpha})),r&&f(e,t).selectAll(l.sankeyNode).filter(m(t)).call(v)}function b(t,e){var r=t.hoverlabel||{},n=s.nestedProperty(r,e).get();return!Array.isArray(n)&&n}e.exports=function(t,e){for(var r=t._fullLayout,s=r._paper,f=r._size,d=0;d<t._fullData.length;d++)if(t._fullData[d].visible&&t._fullData[d].type===l.sankey&&!t._fullData[d]._viewInitial){var m=t._fullData[d].node;t._fullData[d]._viewInitial={node:{groups:m.groups.slice(),x:m.x.slice(),y:m.y.slice()}}}var _=c(t,\"source:\")+\" \",w=c(t,\"target:\")+\" \",T=c(t,\"concentration:\")+\" \",k=c(t,\"incoming flow count:\")+\" \",M=c(t,\"outgoing flow count:\")+\" \";i(t,s,e,{width:f.w,height:f.h,margin:{t:f.t,r:f.r,b:f.b,l:f.l}},{linkEvents:{hover:function(e,r,i){!1!==t._fullLayout.hovermode&&(n.select(e).call(y.bind(0,r,i,!0)),\"skip\"!==r.link.trace.link.hoverinfo&&(r.link.fullData=r.link.trace,t.emit(\"plotly_hover\",{event:n.event,points:[r.link]})))},follow:function(e,i){if(!1!==t._fullLayout.hovermode){var s=i.link.trace.link;if(\"none\"!==s.hoverinfo&&\"skip\"!==s.hoverinfo){for(var l=[],c=0,f=0;f<i.flow.links.length;f++){var d=i.flow.links[f];if(\"closest\"!==t._fullLayout.hovermode||i.link.pointNumber===d.pointNumber){i.link.pointNumber===d.pointNumber&&(c=f),d.fullData=d.trace,s=i.link.trace.link;var m=v(d),g={valueLabel:n.format(i.valueFormat)(d.value)+i.valueSuffix};l.push({x:m[0],y:m[1],name:g.valueLabel,text:[d.label||\"\",_+d.source.label,w+d.target.label,d.concentrationscale?T+n.format(\"%0.2f\")(d.flow.labelConcentration):\"\"].filter(u).join(\"<br>\"),color:b(s,\"bgcolor\")||o.addOpacity(d.color,1),borderColor:b(s,\"bordercolor\"),fontFamily:b(s,\"font.family\"),fontSize:b(s,\"font.size\"),fontColor:b(s,\"font.color\"),nameLength:b(s,\"namelength\"),textAlign:b(s,\"align\"),idealAlign:n.event.x<m[0]?\"right\":\"left\",hovertemplate:s.hovertemplate,hovertemplateLabels:g,eventData:[d]})}}a.loneHover(l,{container:r._hoverlayer.node(),outerContainer:r._paper.node(),gd:t,anchorIndex:c}).each((function(){i.link.concentrationscale||h(this,.65),p(this)}))}}function v(t){var e,r;t.circular?(e=(t.circularPathData.leftInnerExtent+t.circularPathData.rightInnerExtent)/2,r=t.circularPathData.verticalFullExtent):(e=(t.source.x1+t.target.x0)/2,r=(t.y0+t.y1)/2);var n=[e,r];return\"v\"===t.trace.orientation&&n.reverse(),n[0]+=i.parent.translateX,n[1]+=i.parent.translateY,n}},unhover:function(e,i,o){!1!==t._fullLayout.hovermode&&(n.select(e).call(x.bind(0,i,o,!0)),\"skip\"!==i.link.trace.link.hoverinfo&&(i.link.fullData=i.link.trace,t.emit(\"plotly_unhover\",{event:n.event,points:[i.link]})),a.loneUnhover(r._hoverlayer.node()))},select:function(e,r){var i=r.link;i.originalEvent=n.event,t._hoverdata=[i],a.click(t,{target:!0})}},nodeEvents:{hover:function(e,r,i){!1!==t._fullLayout.hovermode&&(n.select(e).call(g,r,i),\"skip\"!==r.node.trace.node.hoverinfo&&(r.node.fullData=r.node.trace,t.emit(\"plotly_hover\",{event:n.event,points:[r.node]})))},follow:function(e,i){if(!1!==t._fullLayout.hovermode){var o=i.node.trace.node;if(\"none\"!==o.hoverinfo&&\"skip\"!==o.hoverinfo){var s=n.select(e).select(\".\"+l.nodeRect),c=t._fullLayout._paperdiv.node().getBoundingClientRect(),f=s.node().getBoundingClientRect(),d=f.left-2-c.left,m=f.right+2-c.left,g=f.top+f.height/4-c.top,v={valueLabel:n.format(i.valueFormat)(i.node.value)+i.valueSuffix};i.node.fullData=i.node.trace,t._fullLayout._calcInverseTransform(t);var y=t._fullLayout._invScaleX,x=t._fullLayout._invScaleY,_=a.loneHover({x0:y*d,x1:y*m,y:x*g,name:n.format(i.valueFormat)(i.node.value)+i.valueSuffix,text:[i.node.label,k+i.node.targetLinks.length,M+i.node.sourceLinks.length].filter(u).join(\"<br>\"),color:b(o,\"bgcolor\")||i.tinyColorHue,borderColor:b(o,\"bordercolor\"),fontFamily:b(o,\"font.family\"),fontSize:b(o,\"font.size\"),fontColor:b(o,\"font.color\"),nameLength:b(o,\"namelength\"),textAlign:b(o,\"align\"),idealAlign:\"left\",hovertemplate:o.hovertemplate,hovertemplateLabels:v,eventData:[i.node]},{container:r._hoverlayer.node(),outerContainer:r._paper.node(),gd:t});h(_,.85),p(_)}}},unhover:function(e,i,o){!1!==t._fullLayout.hovermode&&(n.select(e).call(v,i,o),\"skip\"!==i.node.trace.node.hoverinfo&&(i.node.fullData=i.node.trace,t.emit(\"plotly_unhover\",{event:n.event,points:[i.node]})),a.loneUnhover(r._hoverlayer.node()))},select:function(e,r,i){var o=r.node;o.originalEvent=n.event,t._hoverdata=[o],n.select(e).call(v,r,i),a.click(t,{target:!0})}}})}},{\"../../components/color\":662,\"../../components/fx\":702,\"../../lib\":799,\"./constants\":1207,\"./render\":1211,\"@plotly/d3\":58}],1211:[function(t,e,r){\"use strict\";var n=t(\"d3-force\"),i=t(\"d3-interpolate\").interpolateNumber,a=t(\"@plotly/d3\"),o=t(\"@plotly/d3-sankey\"),s=t(\"@plotly/d3-sankey-circular\"),l=t(\"./constants\"),c=t(\"tinycolor2\"),u=t(\"../../components/color\"),f=t(\"../../components/drawing\"),h=t(\"../../lib\"),p=h.strTranslate,d=h.strRotate,m=t(\"../../lib/gup\"),g=m.keyFun,v=m.repeat,y=m.unwrap,x=t(\"../../lib/svg_text_utils\"),b=t(\"../../registry\"),_=t(\"../../constants/alignment\"),w=_.CAP_SHIFT,T=_.LINE_SPACING;function k(t,e,r){var n,i=y(e),a=i.trace,u=a.domain,f=\"h\"===a.orientation,p=a.node.pad,d=a.node.thickness,m=t.width*(u.x[1]-u.x[0]),g=t.height*(u.y[1]-u.y[0]),v=i._nodes,x=i._links,b=i.circular;(n=b?s.sankeyCircular().circularLinkGap(0):o.sankey()).iterations(l.sankeyIterations).size(f?[m,g]:[g,m]).nodeWidth(d).nodePadding(p).nodeId((function(t){return t.pointNumber})).nodes(v).links(x);var _,w,T,k=n();for(var M in n.nodePadding()<p&&h.warn(\"node.pad was reduced to \",n.nodePadding(),\" to fit within the figure.\"),i._groupLookup){var A,S=parseInt(i._groupLookup[M]);for(_=0;_<k.nodes.length;_++)if(k.nodes[_].pointNumber===S){A=k.nodes[_];break}if(A){var E={pointNumber:parseInt(M),x0:A.x0,x1:A.x1,y0:A.y0,y1:A.y1,partOfGroup:!0,sourceLinks:[],targetLinks:[]};k.nodes.unshift(E),A.childrenNodes.unshift(E)}}if(function(){for(_=0;_<k.nodes.length;_++){var t,e,r=k.nodes[_],n={};for(w=0;w<r.targetLinks.length;w++)t=(e=r.targetLinks[w]).source.pointNumber+\":\"+e.target.pointNumber,n.hasOwnProperty(t)||(n[t]=[]),n[t].push(e);var i=Object.keys(n);for(w=0;w<i.length;w++){var a=n[t=i[w]],o=0,s={};for(T=0;T<a.length;T++)s[(e=a[T]).label]||(s[e.label]=0),s[e.label]+=e.value,o+=e.value;for(T=0;T<a.length;T++)(e=a[T]).flow={value:o,labelConcentration:s[e.label]/o,concentration:e.value/o,links:a},e.concentrationscale&&(e.color=c(e.concentrationscale(e.flow.labelConcentration)))}var l=0;for(w=0;w<r.sourceLinks.length;w++)l+=r.sourceLinks[w].value;for(w=0;w<r.sourceLinks.length;w++)(e=r.sourceLinks[w]).concentrationOut=e.value/l;var u=0;for(w=0;w<r.targetLinks.length;w++)u+=r.targetLinks[w].value;for(w=0;w<r.targetLinks.length;w++)(e=r.targetLinks[w]).concenrationIn=e.value/u}}(),a.node.x.length&&a.node.y.length){for(_=0;_<Math.min(a.node.x.length,a.node.y.length,k.nodes.length);_++)if(a.node.x[_]&&a.node.y[_]){var L=[a.node.x[_]*m,a.node.y[_]*g];k.nodes[_].x0=L[0]-d/2,k.nodes[_].x1=L[0]+d/2;var C=k.nodes[_].y1-k.nodes[_].y0;k.nodes[_].y0=L[1]-C/2,k.nodes[_].y1=L[1]+C/2}if(\"snap\"===a.arrangement)!function(t){t.forEach((function(t){var e,r,n,i=0,a=t.length;for(t.sort((function(t,e){return t.y0-e.y0})),n=0;n<a;++n)(e=t[n]).y0>=i||(r=i-e.y0)>1e-6&&(e.y0+=r,e.y1+=r),i=e.y1+p}))}(function(t){var e,r,n=t.map((function(t,e){return{x0:t.x0,index:e}})).sort((function(t,e){return t.x0-e.x0})),i=[],a=-1,o=-1/0;for(_=0;_<n.length;_++){var s=t[n[_].index];s.x0>o+d&&(a+=1,e=s.x0),o=s.x0,i[a]||(i[a]=[]),i[a].push(s),r=e-s.x0,s.x0+=r,s.x1+=r}return i}(v=k.nodes));n.update(k)}return{circular:b,key:r,trace:a,guid:h.randstr(),horizontal:f,width:m,height:g,nodePad:a.node.pad,nodeLineColor:a.node.line.color,nodeLineWidth:a.node.line.width,linkLineColor:a.link.line.color,linkLineWidth:a.link.line.width,valueFormat:a.valueformat,valueSuffix:a.valuesuffix,textFont:a.textfont,translateX:u.x[0]*t.width+t.margin.l,translateY:t.height-u.y[1]*t.height+t.margin.t,dragParallel:f?g:m,dragPerpendicular:f?m:g,arrangement:a.arrangement,sankey:n,graph:k,forceLayouts:{},interactionState:{dragInProgress:!1,hovered:!1}}}function M(t,e,r){var n=c(e.color),i=e.source.label+\"|\"+e.target.label+\"__\"+r;return e.trace=t.trace,e.curveNumber=t.trace.index,{circular:t.circular,key:i,traceId:t.key,pointNumber:e.pointNumber,link:e,tinyColorHue:u.tinyRGB(n),tinyColorAlpha:n.getAlpha(),linkPath:A,linkLineColor:t.linkLineColor,linkLineWidth:t.linkLineWidth,valueFormat:t.valueFormat,valueSuffix:t.valueSuffix,sankey:t.sankey,parent:t,interactionState:t.interactionState,flow:e.flow}}function A(){return function(t){if(t.link.circular)return e=t.link,r=e.width/2,n=e.circularPathData,\"top\"===e.circularLinkType?\"M \"+n.targetX+\" \"+(n.targetY+r)+\" L\"+n.rightInnerExtent+\" \"+(n.targetY+r)+\"A\"+(n.rightLargeArcRadius+r)+\" \"+(n.rightSmallArcRadius+r)+\" 0 0 1 \"+(n.rightFullExtent-r)+\" \"+(n.targetY-n.rightSmallArcRadius)+\"L\"+(n.rightFullExtent-r)+\" \"+n.verticalRightInnerExtent+\"A\"+(n.rightLargeArcRadius+r)+\" \"+(n.rightLargeArcRadius+r)+\" 0 0 1 \"+n.rightInnerExtent+\" \"+(n.verticalFullExtent-r)+\"L\"+n.leftInnerExtent+\" \"+(n.verticalFullExtent-r)+\"A\"+(n.leftLargeArcRadius+r)+\" \"+(n.leftLargeArcRadius+r)+\" 0 0 1 \"+(n.leftFullExtent+r)+\" \"+n.verticalLeftInnerExtent+\"L\"+(n.leftFullExtent+r)+\" \"+(n.sourceY-n.leftSmallArcRadius)+\"A\"+(n.leftLargeArcRadius+r)+\" \"+(n.leftSmallArcRadius+r)+\" 0 0 1 \"+n.leftInnerExtent+\" \"+(n.sourceY+r)+\"L\"+n.sourceX+\" \"+(n.sourceY+r)+\"L\"+n.sourceX+\" \"+(n.sourceY-r)+\"L\"+n.leftInnerExtent+\" \"+(n.sourceY-r)+\"A\"+(n.leftLargeArcRadius-r)+\" \"+(n.leftSmallArcRadius-r)+\" 0 0 0 \"+(n.leftFullExtent-r)+\" \"+(n.sourceY-n.leftSmallArcRadius)+\"L\"+(n.leftFullExtent-r)+\" \"+n.verticalLeftInnerExtent+\"A\"+(n.leftLargeArcRadius-r)+\" \"+(n.leftLargeArcRadius-r)+\" 0 0 0 \"+n.leftInnerExtent+\" \"+(n.verticalFullExtent+r)+\"L\"+n.rightInnerExtent+\" \"+(n.verticalFullExtent+r)+\"A\"+(n.rightLargeArcRadius-r)+\" \"+(n.rightLargeArcRadius-r)+\" 0 0 0 \"+(n.rightFullExtent+r)+\" \"+n.verticalRightInnerExtent+\"L\"+(n.rightFullExtent+r)+\" \"+(n.targetY-n.rightSmallArcRadius)+\"A\"+(n.rightLargeArcRadius-r)+\" \"+(n.rightSmallArcRadius-r)+\" 0 0 0 \"+n.rightInnerExtent+\" \"+(n.targetY-r)+\"L\"+n.targetX+\" \"+(n.targetY-r)+\"Z\":\"M \"+n.targetX+\" \"+(n.targetY-r)+\" L\"+n.rightInnerExtent+\" \"+(n.targetY-r)+\"A\"+(n.rightLargeArcRadius+r)+\" \"+(n.rightSmallArcRadius+r)+\" 0 0 0 \"+(n.rightFullExtent-r)+\" \"+(n.targetY+n.rightSmallArcRadius)+\"L\"+(n.rightFullExtent-r)+\" \"+n.verticalRightInnerExtent+\"A\"+(n.rightLargeArcRadius+r)+\" \"+(n.rightLargeArcRadius+r)+\" 0 0 0 \"+n.rightInnerExtent+\" \"+(n.verticalFullExtent+r)+\"L\"+n.leftInnerExtent+\" \"+(n.verticalFullExtent+r)+\"A\"+(n.leftLargeArcRadius+r)+\" \"+(n.leftLargeArcRadius+r)+\" 0 0 0 \"+(n.leftFullExtent+r)+\" \"+n.verticalLeftInnerExtent+\"L\"+(n.leftFullExtent+r)+\" \"+(n.sourceY+n.leftSmallArcRadius)+\"A\"+(n.leftLargeArcRadius+r)+\" \"+(n.leftSmallArcRadius+r)+\" 0 0 0 \"+n.leftInnerExtent+\" \"+(n.sourceY-r)+\"L\"+n.sourceX+\" \"+(n.sourceY-r)+\"L\"+n.sourceX+\" \"+(n.sourceY+r)+\"L\"+n.leftInnerExtent+\" \"+(n.sourceY+r)+\"A\"+(n.leftLargeArcRadius-r)+\" \"+(n.leftSmallArcRadius-r)+\" 0 0 1 \"+(n.leftFullExtent-r)+\" \"+(n.sourceY+n.leftSmallArcRadius)+\"L\"+(n.leftFullExtent-r)+\" \"+n.verticalLeftInnerExtent+\"A\"+(n.leftLargeArcRadius-r)+\" \"+(n.leftLargeArcRadius-r)+\" 0 0 1 \"+n.leftInnerExtent+\" \"+(n.verticalFullExtent-r)+\"L\"+n.rightInnerExtent+\" \"+(n.verticalFullExtent-r)+\"A\"+(n.rightLargeArcRadius-r)+\" \"+(n.rightLargeArcRadius-r)+\" 0 0 1 \"+(n.rightFullExtent+r)+\" \"+n.verticalRightInnerExtent+\"L\"+(n.rightFullExtent+r)+\" \"+(n.targetY+n.rightSmallArcRadius)+\"A\"+(n.rightLargeArcRadius-r)+\" \"+(n.rightSmallArcRadius-r)+\" 0 0 1 \"+n.rightInnerExtent+\" \"+(n.targetY+r)+\"L\"+n.targetX+\" \"+(n.targetY+r)+\"Z\";var e,r,n,a=t.link.source.x1,o=t.link.target.x0,s=i(a,o),l=s(.5),c=s(.5),u=t.link.y0-t.link.width/2,f=t.link.y0+t.link.width/2,h=t.link.y1-t.link.width/2,p=t.link.y1+t.link.width/2;return\"M\"+a+\",\"+u+\"C\"+l+\",\"+u+\" \"+c+\",\"+h+\" \"+o+\",\"+h+\"L\"+o+\",\"+p+\"C\"+c+\",\"+p+\" \"+l+\",\"+f+\" \"+a+\",\"+f+\"Z\"}}function S(t,e){var r=c(e.color),n=l.nodePadAcross,i=t.nodePad/2;e.dx=e.x1-e.x0,e.dy=e.y1-e.y0;var a=e.dx,o=Math.max(.5,e.dy),s=\"node_\"+e.pointNumber;return e.group&&(s=h.randstr()),e.trace=t.trace,e.curveNumber=t.trace.index,{index:e.pointNumber,key:s,partOfGroup:e.partOfGroup||!1,group:e.group,traceId:t.key,trace:t.trace,node:e,nodePad:t.nodePad,nodeLineColor:t.nodeLineColor,nodeLineWidth:t.nodeLineWidth,textFont:t.textFont,size:t.horizontal?t.height:t.width,visibleWidth:Math.ceil(a),visibleHeight:o,zoneX:-n,zoneY:-i,zoneWidth:a+2*n,zoneHeight:o+2*i,labelY:t.horizontal?e.dy/2+1:e.dx/2+1,left:1===e.originalLayer,sizeAcross:t.width,forceLayouts:t.forceLayouts,horizontal:t.horizontal,darkBackground:r.getBrightness()<=128,tinyColorHue:u.tinyRGB(r),tinyColorAlpha:r.getAlpha(),valueFormat:t.valueFormat,valueSuffix:t.valueSuffix,sankey:t.sankey,graph:t.graph,arrangement:t.arrangement,uniqueNodeLabelPathId:[t.guid,t.key,s].join(\"_\"),interactionState:t.interactionState,figure:t}}function E(t){t.attr(\"transform\",(function(t){return p(t.node.x0.toFixed(3),t.node.y0.toFixed(3))}))}function L(t){t.call(E)}function C(t,e){t.call(L),e.attr(\"d\",A())}function P(t){t.attr(\"width\",(function(t){return t.node.x1-t.node.x0})).attr(\"height\",(function(t){return t.visibleHeight}))}function I(t){return t.link.width>1||t.linkLineWidth>0}function O(t){return p(t.translateX,t.translateY)+(t.horizontal?\"matrix(1 0 0 1 0 0)\":\"matrix(0 1 1 0 0 0)\")}function z(t,e,r){t.on(\".basic\",null).on(\"mouseover.basic\",(function(t){t.interactionState.dragInProgress||t.partOfGroup||(r.hover(this,t,e),t.interactionState.hovered=[this,t])})).on(\"mousemove.basic\",(function(t){t.interactionState.dragInProgress||t.partOfGroup||(r.follow(this,t),t.interactionState.hovered=[this,t])})).on(\"mouseout.basic\",(function(t){t.interactionState.dragInProgress||t.partOfGroup||(r.unhover(this,t,e),t.interactionState.hovered=!1)})).on(\"click.basic\",(function(t){t.interactionState.hovered&&(r.unhover(this,t,e),t.interactionState.hovered=!1),t.interactionState.dragInProgress||t.partOfGroup||r.select(this,t,e)}))}function D(t,e,r,i){var o=a.behavior.drag().origin((function(t){return{x:t.node.x0+t.visibleWidth/2,y:t.node.y0+t.visibleHeight/2}})).on(\"dragstart\",(function(a){if(\"fixed\"!==a.arrangement&&(h.ensureSingle(i._fullLayout._infolayer,\"g\",\"dragcover\",(function(t){i._fullLayout._dragCover=t})),h.raiseToTop(this),a.interactionState.dragInProgress=a.node,F(a.node),a.interactionState.hovered&&(r.nodeEvents.unhover.apply(0,a.interactionState.hovered),a.interactionState.hovered=!1),\"snap\"===a.arrangement)){var o=a.traceId+\"|\"+a.key;a.forceLayouts[o]?a.forceLayouts[o].alpha(1):function(t,e,r,i){!function(t){for(var e=0;e<t.length;e++)t[e].y=(t[e].y0+t[e].y1)/2,t[e].x=(t[e].x0+t[e].x1)/2}(r.graph.nodes);var a=r.graph.nodes.filter((function(t){return t.originalX===r.node.originalX})).filter((function(t){return!t.partOfGroup}));r.forceLayouts[e]=n.forceSimulation(a).alphaDecay(0).force(\"collide\",n.forceCollide().radius((function(t){return t.dy/2+r.nodePad/2})).strength(1).iterations(l.forceIterations)).force(\"constrain\",function(t,e,r,n){return function(){for(var t=0,i=0;i<r.length;i++){var a=r[i];a===n.interactionState.dragInProgress?(a.x=a.lastDraggedX,a.y=a.lastDraggedY):(a.vx=(a.originalX-a.x)/l.forceTicksPerFrame,a.y=Math.min(n.size-a.dy/2,Math.max(a.dy/2,a.y))),t=Math.max(t,Math.abs(a.vx),Math.abs(a.vy))}!n.interactionState.dragInProgress&&t<.1&&n.forceLayouts[e].alpha()>0&&n.forceLayouts[e].alpha(0)}}(0,e,a,r)).stop()}(0,o,a),function(t,e,r,n,i){window.requestAnimationFrame((function a(){var o;for(o=0;o<l.forceTicksPerFrame;o++)r.forceLayouts[n].tick();if(function(t){for(var e=0;e<t.length;e++)t[e].y0=t[e].y-t[e].dy/2,t[e].y1=t[e].y0+t[e].dy,t[e].x0=t[e].x-t[e].dx/2,t[e].x1=t[e].x0+t[e].dx}(r.graph.nodes),r.sankey.update(r.graph),C(t.filter(B(r)),e),r.forceLayouts[n].alpha()>0)window.requestAnimationFrame(a);else{var s=r.node.originalX;r.node.x0=s-r.visibleWidth/2,r.node.x1=s+r.visibleWidth/2,R(r,i)}}))}(t,e,a,o,i)}})).on(\"drag\",(function(r){if(\"fixed\"!==r.arrangement){var n=a.event.x,i=a.event.y;\"snap\"===r.arrangement?(r.node.x0=n-r.visibleWidth/2,r.node.x1=n+r.visibleWidth/2,r.node.y0=i-r.visibleHeight/2,r.node.y1=i+r.visibleHeight/2):(\"freeform\"===r.arrangement&&(r.node.x0=n-r.visibleWidth/2,r.node.x1=n+r.visibleWidth/2),i=Math.max(0,Math.min(r.size-r.visibleHeight/2,i)),r.node.y0=i-r.visibleHeight/2,r.node.y1=i+r.visibleHeight/2),F(r.node),\"snap\"!==r.arrangement&&(r.sankey.update(r.graph),C(t.filter(B(r)),e))}})).on(\"dragend\",(function(t){if(\"fixed\"!==t.arrangement){t.interactionState.dragInProgress=!1;for(var e=0;e<t.node.childrenNodes.length;e++)t.node.childrenNodes[e].x=t.node.x,t.node.childrenNodes[e].y=t.node.y;\"snap\"!==t.arrangement&&R(t,i)}}));t.on(\".drag\",null).call(o)}function R(t,e){for(var r=[],n=[],i=0;i<t.graph.nodes.length;i++){var a=(t.graph.nodes[i].x0+t.graph.nodes[i].x1)/2,o=(t.graph.nodes[i].y0+t.graph.nodes[i].y1)/2;r.push(a/t.figure.width),n.push(o/t.figure.height)}b.call(\"_guiRestyle\",e,{\"node.x\":[r],\"node.y\":[n]},t.trace.index).then((function(){e._fullLayout._dragCover&&e._fullLayout._dragCover.remove()}))}function F(t){t.lastDraggedX=t.x0+t.dx/2,t.lastDraggedY=t.y0+t.dy/2}function B(t){return function(e){return e.node.originalX===t.node.originalX}}e.exports=function(t,e,r,n,i){var o=!1;h.ensureSingle(t._fullLayout._infolayer,\"g\",\"first-render\",(function(){o=!0}));var s=t._fullLayout._dragCover,m=r.filter((function(t){return y(t).trace.visible})).map(k.bind(null,n)),b=e.selectAll(\".\"+l.cn.sankey).data(m,g);b.exit().remove(),b.enter().append(\"g\").classed(l.cn.sankey,!0).style(\"box-sizing\",\"content-box\").style(\"position\",\"absolute\").style(\"left\",0).style(\"shape-rendering\",\"geometricPrecision\").style(\"pointer-events\",\"auto\").attr(\"transform\",O),b.each((function(e,r){t._fullData[r]._sankey=e;var n=\"bgsankey-\"+e.trace.uid+\"-\"+r;h.ensureSingle(t._fullLayout._draggers,\"rect\",n),t._fullData[r]._bgRect=a.select(\".\"+n),t._fullData[r]._bgRect.style(\"pointer-events\",\"all\").attr(\"width\",e.width).attr(\"height\",e.height).attr(\"x\",e.translateX).attr(\"y\",e.translateY).classed(\"bgsankey\",!0).style({fill:\"transparent\",\"stroke-width\":0})})),b.transition().ease(l.ease).duration(l.duration).attr(\"transform\",O);var _=b.selectAll(\".\"+l.cn.sankeyLinks).data(v,g);_.enter().append(\"g\").classed(l.cn.sankeyLinks,!0).style(\"fill\",\"none\");var L=_.selectAll(\".\"+l.cn.sankeyLink).data((function(t){return t.graph.links.filter((function(t){return t.value})).map(M.bind(null,t))}),g);L.enter().append(\"path\").classed(l.cn.sankeyLink,!0).call(z,b,i.linkEvents),L.style(\"stroke\",(function(t){return I(t)?u.tinyRGB(c(t.linkLineColor)):t.tinyColorHue})).style(\"stroke-opacity\",(function(t){return I(t)?u.opacity(t.linkLineColor):t.tinyColorAlpha})).style(\"fill\",(function(t){return t.tinyColorHue})).style(\"fill-opacity\",(function(t){return t.tinyColorAlpha})).style(\"stroke-width\",(function(t){return I(t)?t.linkLineWidth:1})).attr(\"d\",A()),L.style(\"opacity\",(function(){return t._context.staticPlot||o||s?1:0})).transition().ease(l.ease).duration(l.duration).style(\"opacity\",1),L.exit().transition().ease(l.ease).duration(l.duration).style(\"opacity\",0).remove();var C=b.selectAll(\".\"+l.cn.sankeyNodeSet).data(v,g);C.enter().append(\"g\").classed(l.cn.sankeyNodeSet,!0),C.style(\"cursor\",(function(t){switch(t.arrangement){case\"fixed\":return\"default\";case\"perpendicular\":return\"ns-resize\";default:return\"move\"}}));var R=C.selectAll(\".\"+l.cn.sankeyNode).data((function(t){var e=t.graph.nodes;return function(t){var e,r=[];for(e=0;e<t.length;e++)t[e].originalX=(t[e].x0+t[e].x1)/2,t[e].originalY=(t[e].y0+t[e].y1)/2,-1===r.indexOf(t[e].originalX)&&r.push(t[e].originalX);for(r.sort((function(t,e){return t-e})),e=0;e<t.length;e++)t[e].originalLayerIndex=r.indexOf(t[e].originalX),t[e].originalLayer=t[e].originalLayerIndex/(r.length-1)}(e),e.map(S.bind(null,t))}),g);R.enter().append(\"g\").classed(l.cn.sankeyNode,!0).call(E).style(\"opacity\",(function(e){return!t._context.staticPlot&&!o||e.partOfGroup?0:1})),R.call(z,b,i.nodeEvents).call(D,L,i,t),R.transition().ease(l.ease).duration(l.duration).call(E).style(\"opacity\",(function(t){return t.partOfGroup?0:1})),R.exit().transition().ease(l.ease).duration(l.duration).style(\"opacity\",0).remove();var F=R.selectAll(\".\"+l.cn.nodeRect).data(v);F.enter().append(\"rect\").classed(l.cn.nodeRect,!0).call(P),F.style(\"stroke-width\",(function(t){return t.nodeLineWidth})).style(\"stroke\",(function(t){return u.tinyRGB(c(t.nodeLineColor))})).style(\"stroke-opacity\",(function(t){return u.opacity(t.nodeLineColor)})).style(\"fill\",(function(t){return t.tinyColorHue})).style(\"fill-opacity\",(function(t){return t.tinyColorAlpha})),F.transition().ease(l.ease).duration(l.duration).call(P);var B=R.selectAll(\".\"+l.cn.nodeLabel).data(v);B.enter().append(\"text\").classed(l.cn.nodeLabel,!0).style(\"cursor\",\"default\"),B.attr(\"data-notex\",1).text((function(t){return t.node.label})).each((function(e){var r=a.select(this);f.font(r,e.textFont),x.convertToTspans(r,t)})).style(\"text-shadow\",x.makeTextShadow(t._fullLayout.paper_bgcolor)).attr(\"text-anchor\",(function(t){return t.horizontal&&t.left?\"end\":\"start\"})).attr(\"transform\",(function(t){var e=a.select(this),r=x.lineCount(e),n=t.textFont.size*((r-1)*T-w),i=t.nodeLineWidth/2+3,o=((t.horizontal?t.visibleHeight:t.visibleWidth)-n)/2;t.horizontal&&(t.left?i=-i:i+=t.visibleWidth);var s=t.horizontal?\"\":\"scale(-1,1)\"+d(90);return p(t.horizontal?i:o,t.horizontal?o:i)+s})),B.transition().ease(l.ease).duration(l.duration)}},{\"../../components/color\":662,\"../../components/drawing\":684,\"../../constants/alignment\":767,\"../../lib\":799,\"../../lib/gup\":796,\"../../lib/svg_text_utils\":824,\"../../registry\":927,\"./constants\":1207,\"@plotly/d3\":58,\"@plotly/d3-sankey\":57,\"@plotly/d3-sankey-circular\":56,\"d3-force\":166,\"d3-interpolate\":168,tinycolor2:594}],1212:[function(t,e,r){\"use strict\";e.exports=function(t,e){for(var r=[],n=t.cd[0].trace,i=n._sankey.graph.nodes,a=0;a<i.length;a++){var o=i[a];if(!o.partOfGroup){var s=[(o.x0+o.x1)/2,(o.y0+o.y1)/2];\"v\"===n.orientation&&s.reverse(),e&&e.contains(s,!1,a,t)&&r.push({pointNumber:o.pointNumber})}}return r}},{}],1213:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e){for(var r=0;r<t.length;r++)t[r].i=r;n.mergeArray(e.text,t,\"tx\"),n.mergeArray(e.texttemplate,t,\"txt\"),n.mergeArray(e.hovertext,t,\"htx\"),n.mergeArray(e.customdata,t,\"data\"),n.mergeArray(e.textposition,t,\"tp\"),e.textfont&&(n.mergeArrayCastPositive(e.textfont.size,t,\"ts\"),n.mergeArray(e.textfont.color,t,\"tc\"),n.mergeArray(e.textfont.family,t,\"tf\"));var i=e.marker;if(i){n.mergeArrayCastPositive(i.size,t,\"ms\"),n.mergeArrayCastPositive(i.opacity,t,\"mo\"),n.mergeArray(i.symbol,t,\"mx\"),n.mergeArray(i.color,t,\"mc\");var a=i.line;i.line&&(n.mergeArray(a.color,t,\"mlc\"),n.mergeArrayCastPositive(a.width,t,\"mlw\"));var o=i.gradient;o&&\"none\"!==o.type&&(n.mergeArray(o.type,t,\"mgt\"),n.mergeArray(o.color,t,\"mgc\"))}}},{\"../../lib\":799}],1214:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axis_format_attributes\").axisHoverFormat,i=t(\"../../plots/template_attributes\").texttemplateAttrs,a=t(\"../../plots/template_attributes\").hovertemplateAttrs,o=t(\"../../components/colorscale/attributes\"),s=t(\"../../plots/font_attributes\"),l=t(\"../../components/drawing/attributes\").dash,c=t(\"../../components/drawing\"),u=t(\"./constants\"),f=t(\"../../lib/extend\").extendFlat;e.exports={x:{valType:\"data_array\",editType:\"calc+clearAxisTypes\",anim:!0},x0:{valType:\"any\",dflt:0,editType:\"calc+clearAxisTypes\",anim:!0},dx:{valType:\"number\",dflt:1,editType:\"calc\",anim:!0},y:{valType:\"data_array\",editType:\"calc+clearAxisTypes\",anim:!0},y0:{valType:\"any\",dflt:0,editType:\"calc+clearAxisTypes\",anim:!0},dy:{valType:\"number\",dflt:1,editType:\"calc\",anim:!0},xperiod:{valType:\"any\",dflt:0,editType:\"calc\"},yperiod:{valType:\"any\",dflt:0,editType:\"calc\"},xperiod0:{valType:\"any\",editType:\"calc\"},yperiod0:{valType:\"any\",editType:\"calc\"},xperiodalignment:{valType:\"enumerated\",values:[\"start\",\"middle\",\"end\"],dflt:\"middle\",editType:\"calc\"},yperiodalignment:{valType:\"enumerated\",values:[\"start\",\"middle\",\"end\"],dflt:\"middle\",editType:\"calc\"},xhoverformat:n(\"x\"),yhoverformat:n(\"y\"),stackgroup:{valType:\"string\",dflt:\"\",editType:\"calc\"},orientation:{valType:\"enumerated\",values:[\"v\",\"h\"],editType:\"calc\"},groupnorm:{valType:\"enumerated\",values:[\"\",\"fraction\",\"percent\"],dflt:\"\",editType:\"calc\"},stackgaps:{valType:\"enumerated\",values:[\"infer zero\",\"interpolate\"],dflt:\"infer zero\",editType:\"calc\"},text:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"calc\"},texttemplate:i({},{}),hovertext:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"style\"},mode:{valType:\"flaglist\",flags:[\"lines\",\"markers\",\"text\"],extras:[\"none\"],editType:\"calc\"},hoveron:{valType:\"flaglist\",flags:[\"points\",\"fills\"],editType:\"style\"},hovertemplate:a({},{keys:u.eventDataKeys}),line:{color:{valType:\"color\",editType:\"style\",anim:!0},width:{valType:\"number\",min:0,dflt:2,editType:\"style\",anim:!0},shape:{valType:\"enumerated\",values:[\"linear\",\"spline\",\"hv\",\"vh\",\"hvh\",\"vhv\"],dflt:\"linear\",editType:\"plot\"},smoothing:{valType:\"number\",min:0,max:1.3,dflt:1,editType:\"plot\"},dash:f({},l,{editType:\"style\"}),simplify:{valType:\"boolean\",dflt:!0,editType:\"plot\"},editType:\"plot\"},connectgaps:{valType:\"boolean\",dflt:!1,editType:\"calc\"},cliponaxis:{valType:\"boolean\",dflt:!0,editType:\"plot\"},fill:{valType:\"enumerated\",values:[\"none\",\"tozeroy\",\"tozerox\",\"tonexty\",\"tonextx\",\"toself\",\"tonext\"],editType:\"calc\"},fillcolor:{valType:\"color\",editType:\"style\",anim:!0},marker:f({symbol:{valType:\"enumerated\",values:c.symbolList,dflt:\"circle\",arrayOk:!0,editType:\"style\"},opacity:{valType:\"number\",min:0,max:1,arrayOk:!0,editType:\"style\",anim:!0},size:{valType:\"number\",min:0,dflt:6,arrayOk:!0,editType:\"calc\",anim:!0},maxdisplayed:{valType:\"number\",min:0,dflt:0,editType:\"plot\"},sizeref:{valType:\"number\",dflt:1,editType:\"calc\"},sizemin:{valType:\"number\",min:0,dflt:0,editType:\"calc\"},sizemode:{valType:\"enumerated\",values:[\"diameter\",\"area\"],dflt:\"diameter\",editType:\"calc\"},line:f({width:{valType:\"number\",min:0,arrayOk:!0,editType:\"style\",anim:!0},editType:\"calc\"},o(\"marker.line\",{anim:!0})),gradient:{type:{valType:\"enumerated\",values:[\"radial\",\"horizontal\",\"vertical\",\"none\"],arrayOk:!0,dflt:\"none\",editType:\"calc\"},color:{valType:\"color\",arrayOk:!0,editType:\"calc\"},editType:\"calc\"},editType:\"calc\"},o(\"marker\",{anim:!0})),selected:{marker:{opacity:{valType:\"number\",min:0,max:1,editType:\"style\"},color:{valType:\"color\",editType:\"style\"},size:{valType:\"number\",min:0,editType:\"style\"},editType:\"style\"},textfont:{color:{valType:\"color\",editType:\"style\"},editType:\"style\"},editType:\"style\"},unselected:{marker:{opacity:{valType:\"number\",min:0,max:1,editType:\"style\"},color:{valType:\"color\",editType:\"style\"},size:{valType:\"number\",min:0,editType:\"style\"},editType:\"style\"},textfont:{color:{valType:\"color\",editType:\"style\"},editType:\"style\"},editType:\"style\"},textposition:{valType:\"enumerated\",values:[\"top left\",\"top center\",\"top right\",\"middle left\",\"middle center\",\"middle right\",\"bottom left\",\"bottom center\",\"bottom right\"],dflt:\"middle center\",arrayOk:!0,editType:\"calc\"},textfont:s({editType:\"calc\",colorEditType:\"style\",arrayOk:!0})}},{\"../../components/colorscale/attributes\":669,\"../../components/drawing\":684,\"../../components/drawing/attributes\":683,\"../../lib/extend\":789,\"../../plots/cartesian/axis_format_attributes\":852,\"../../plots/font_attributes\":878,\"../../plots/template_attributes\":922,\"./constants\":1218}],1215:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../../plots/cartesian/axes\"),o=t(\"../../plots/cartesian/align_period\"),s=t(\"../../constants/numerical\").BADNUM,l=t(\"./subtypes\"),c=t(\"./colorscale_calc\"),u=t(\"./arrays_to_calcdata\"),f=t(\"./calc_selection\");function h(t,e,r,n,i,o,s){var c=e._length,u=t._fullLayout,f=r._id,h=n._id,p=u._firstScatter[m(e)]===e.uid,d=(g(e,u,r,n)||{}).orientation,v=e.fill;r._minDtick=0,n._minDtick=0;var y={padded:!0},x={padded:!0};s&&(y.ppad=x.ppad=s);var b=c<2||i[0]!==i[c-1]||o[0]!==o[c-1];b&&(\"tozerox\"===v||\"tonextx\"===v&&(p||\"h\"===d))?y.tozero=!0:(e.error_y||{}).visible||\"tonexty\"!==v&&\"tozeroy\"!==v&&(l.hasMarkers(e)||l.hasText(e))||(y.padded=!1,y.ppad=0),b&&(\"tozeroy\"===v||\"tonexty\"===v&&(p||\"v\"===d))?x.tozero=!0:\"tonextx\"!==v&&\"tozerox\"!==v||(x.padded=!1),f&&(e._extremes[f]=a.findExtremes(r,i,y)),h&&(e._extremes[h]=a.findExtremes(n,o,x))}function p(t,e){if(l.hasMarkers(t)){var r,n=t.marker,o=1.6*(t.marker.sizeref||1);if(r=\"area\"===t.marker.sizemode?function(t){return Math.max(Math.sqrt((t||0)/o),3)}:function(t){return Math.max((t||0)/o,3)},i.isArrayOrTypedArray(n.size)){var s={type:\"linear\"};a.setConvert(s);for(var c=s.makeCalcdata(t.marker,\"size\"),u=new Array(e),f=0;f<e;f++)u[f]=r(c[f]);return u}return r(n.size)}}function d(t,e){var r=m(e),n=t._firstScatter;n[r]||(n[r]=e.uid)}function m(t){var e=t.stackgroup;return t.xaxis+t.yaxis+t.type+(e?\"-\"+e:\"\")}function g(t,e,r,n){var i=t.stackgroup;if(i){var a=e._scatterStackOpts[r._id+n._id][i],o=\"v\"===a.orientation?n:r;return\"linear\"===o.type||\"log\"===o.type?a:void 0}}e.exports={calc:function(t,e){var r,l,m,v,y,x,b=t._fullLayout,_=a.getFromId(t,e.xaxis||\"x\"),w=a.getFromId(t,e.yaxis||\"y\"),T=_.makeCalcdata(e,\"x\"),k=w.makeCalcdata(e,\"y\"),M=o(e,_,\"x\",T),A=o(e,w,\"y\",k),S=e._length,E=new Array(S),L=e.ids,C=g(e,b,_,w),P=!1;d(b,e);var I,O=\"x\",z=\"y\";C?(i.pushUnique(C.traceIndices,e._expandedIndex),(r=\"v\"===C.orientation)?(z=\"s\",I=\"x\"):(O=\"s\",I=\"y\"),y=\"interpolate\"===C.stackgaps):h(t,e,_,w,M,A,p(e,S));var D=!!e.xperiodalignment,R=!!e.yperiodalignment;for(l=0;l<S;l++){var F=E[l]={},B=n(M[l]),N=n(A[l]);B&&N?(F[O]=M[l],F[z]=A[l],D&&(F.orig_x=T[l]),R&&(F.orig_y=k[l])):C&&(r?B:N)?(F[I]=r?M[l]:A[l],F.gap=!0,y?(F.s=s,P=!0):F.s=0):F[O]=F[z]=s,L&&(F.id=String(L[l]))}if(u(E,e),c(t,e),f(E,e),C){for(l=0;l<E.length;)E[l][I]===s?E.splice(l,1):l++;if(i.sort(E,(function(t,e){return t[I]-e[I]||t.i-e.i})),P){for(l=0;l<E.length-1&&E[l].gap;)l++;for((x=E[l].s)||(x=E[l].s=0),m=0;m<l;m++)E[m].s=x;for(v=E.length-1;v>l&&E[v].gap;)v--;for(x=E[v].s,m=E.length-1;m>v;m--)E[m].s=x;for(;l<v;)if(E[++l].gap){for(m=l+1;E[m].gap;)m++;for(var j=E[l-1][I],U=E[l-1].s,V=(E[m].s-U)/(E[m][I]-j);l<m;)E[l].s=U+(E[l][I]-j)*V,l++}}}return E},calcMarkerSize:p,calcAxisExpansion:h,setFirstScatter:d,getStackOpts:g}},{\"../../constants/numerical\":775,\"../../lib\":799,\"../../plots/cartesian/align_period\":846,\"../../plots/cartesian/axes\":849,\"./arrays_to_calcdata\":1213,\"./calc_selection\":1216,\"./colorscale_calc\":1217,\"./subtypes\":1239,\"fast-isnumeric\":245}],1216:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e){n.isArrayOrTypedArray(e.selectedpoints)&&n.tagSelected(t,e)}},{\"../../lib\":799}],1217:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/helpers\").hasColorscale,i=t(\"../../components/colorscale/calc\"),a=t(\"./subtypes\");e.exports=function(t,e){a.hasLines(e)&&n(e,\"line\")&&i(t,e,{vals:e.line.color,containerStr:\"line\",cLetter:\"c\"}),a.hasMarkers(e)&&(n(e,\"marker\")&&i(t,e,{vals:e.marker.color,containerStr:\"marker\",cLetter:\"c\"}),n(e,\"marker.line\")&&i(t,e,{vals:e.marker.line.color,containerStr:\"marker.line\",cLetter:\"c\"}))}},{\"../../components/colorscale/calc\":670,\"../../components/colorscale/helpers\":673,\"./subtypes\":1239}],1218:[function(t,e,r){\"use strict\";e.exports={PTS_LINESONLY:20,minTolerance:.2,toleranceGrowth:10,maxScreensAway:20,eventDataKeys:[]}},{}],1219:[function(t,e,r){\"use strict\";var n=t(\"./calc\");function i(t,e,r,n,i,a,o){i[n]=!0;var s={i:null,gap:!0,s:0};if(s[o]=r,t.splice(e,0,s),e&&r===t[e-1][o]){var l=t[e-1];s.s=l.s,s.i=l.i,s.gap=l.gap}else a&&(s.s=function(t,e,r,n){var i=t[e-1],a=t[e+1];return a?i?i.s+(a.s-i.s)*(r-i[n])/(a[n]-i[n]):a.s:i.s}(t,e,r,o));e||(t[0].t=t[1].t,t[0].trace=t[1].trace,delete t[1].t,delete t[1].trace)}e.exports=function(t,e){var r=e.xaxis,a=e.yaxis,o=r._id+a._id,s=t._fullLayout._scatterStackOpts[o];if(s){var l,c,u,f,h,p,d,m,g,v,y,x,b,_,w,T=t.calcdata;for(var k in s){var M=(v=s[k]).traceIndices;if(M.length){for(y=\"interpolate\"===v.stackgaps,x=v.groupnorm,\"v\"===v.orientation?(b=\"x\",_=\"y\"):(b=\"y\",_=\"x\"),w=new Array(M.length),l=0;l<w.length;l++)w[l]=!1;p=T[M[0]];var A=new Array(p.length);for(l=0;l<p.length;l++)A[l]=p[l][b];for(l=1;l<M.length;l++){for(h=T[M[l]],c=u=0;c<h.length;c++){for(d=h[c][b];d>A[u]&&u<A.length;u++)i(h,c,A[u],l,w,y,b),c++;if(d!==A[u]){for(f=0;f<l;f++)i(T[M[f]],u,d,f,w,y,b);A.splice(u,0,d)}u++}for(;u<A.length;u++)i(h,c,A[u],l,w,y,b),c++}var S=A.length;for(c=0;c<p.length;c++){for(m=p[c][_]=p[c].s,l=1;l<M.length;l++)(h=T[M[l]])[0].trace._rawLength=h[0].trace._length,h[0].trace._length=S,m+=h[c].s,h[c][_]=m;if(x)for(g=(\"fraction\"===x?m:m/100)||1,l=0;l<M.length;l++){var E=T[M[l]][c];E[_]/=g,E.sNorm=E.s/g}}for(l=0;l<M.length;l++){var L=(h=T[M[l]])[0].trace,C=n.calcMarkerSize(L,L._rawLength),P=Array.isArray(C);if(C&&w[l]||P){var I=C;for(C=new Array(S),c=0;c<S;c++)C[c]=h[c].gap?0:P?I[h[c].i]:I}var O=new Array(S),z=new Array(S);for(c=0;c<S;c++)O[c]=h[c].x,z[c]=h[c].y;n.calcAxisExpansion(t,L,r,a,O,z,C),h[0].t.orientation=v.orientation}}}}}},{\"./calc\":1215}],1220:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=0;e<t.length;e++){var r=t[e];if(\"scatter\"===r.type){var n=r.fill;if(\"none\"!==n&&\"toself\"!==n&&(r.opacity=void 0,\"tonexty\"===n||\"tonextx\"===n))for(var i=e-1;i>=0;i--){var a=t[i];if(\"scatter\"===a.type&&a.xaxis===r.xaxis&&a.yaxis===r.yaxis){a.opacity=void 0;break}}}}}},{}],1221:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../registry\"),a=t(\"./attributes\"),o=t(\"./constants\"),s=t(\"./subtypes\"),l=t(\"./xy_defaults\"),c=t(\"./period_defaults\"),u=t(\"./stack_defaults\"),f=t(\"./marker_defaults\"),h=t(\"./line_defaults\"),p=t(\"./line_shape_defaults\"),d=t(\"./text_defaults\"),m=t(\"./fillcolor_defaults\");e.exports=function(t,e,r,g){function v(r,i){return n.coerce(t,e,a,r,i)}var y=l(t,e,g,v);if(y||(e.visible=!1),e.visible){c(t,e,g,v),v(\"xhoverformat\"),v(\"yhoverformat\");var x=u(t,e,g,v),b=!x&&y<o.PTS_LINESONLY?\"lines+markers\":\"lines\";v(\"text\"),v(\"hovertext\"),v(\"mode\",b),s.hasLines(e)&&(h(t,e,r,g,v),p(t,e,v),v(\"connectgaps\"),v(\"line.simplify\")),s.hasMarkers(e)&&f(t,e,r,g,v,{gradient:!0}),s.hasText(e)&&(v(\"texttemplate\"),d(t,e,g,v));var _=[];(s.hasMarkers(e)||s.hasText(e))&&(v(\"cliponaxis\"),v(\"marker.maxdisplayed\"),_.push(\"points\")),v(\"fill\",x?x.fillDflt:\"none\"),\"none\"!==e.fill&&(m(t,e,r,v),s.hasLines(e)||p(t,e,v));var w=(e.line||{}).color,T=(e.marker||{}).color;\"tonext\"!==e.fill&&\"toself\"!==e.fill||_.push(\"fills\"),v(\"hoveron\",_.join(\"+\")||\"points\"),\"fills\"!==e.hoveron&&v(\"hovertemplate\");var k=i.getComponentMethod(\"errorbars\",\"supplyDefaults\");k(t,e,w||T||r,{axis:\"y\"}),k(t,e,w||T||r,{axis:\"x\",inherit:\"y\"}),n.coerceSelectionMarkerOpacity(e,v)}}},{\"../../lib\":799,\"../../registry\":927,\"./attributes\":1214,\"./constants\":1218,\"./fillcolor_defaults\":1222,\"./line_defaults\":1227,\"./line_shape_defaults\":1229,\"./marker_defaults\":1233,\"./period_defaults\":1234,\"./stack_defaults\":1237,\"./subtypes\":1239,\"./text_defaults\":1240,\"./xy_defaults\":1241}],1222:[function(t,e,r){\"use strict\";var n=t(\"../../components/color\"),i=t(\"../../lib\").isArrayOrTypedArray;e.exports=function(t,e,r,a){var o=!1;if(e.marker){var s=e.marker.color,l=(e.marker.line||{}).color;s&&!i(s)?o=s:l&&!i(l)&&(o=l)}a(\"fillcolor\",n.addOpacity((e.line||{}).color||o||r,.5))}},{\"../../components/color\":662,\"../../lib\":799}],1223:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\");e.exports=function(t,e,r){var i={},a={_fullLayout:r},o=n.getFromTrace(a,e,\"x\"),s=n.getFromTrace(a,e,\"y\");return i.xLabel=n.tickText(o,o.c2l(t.x),!0).text,i.yLabel=n.tickText(s,s.c2l(t.y),!0).text,i}},{\"../../plots/cartesian/axes\":849}],1224:[function(t,e,r){\"use strict\";var n=t(\"../../components/color\"),i=t(\"./subtypes\");e.exports=function(t,e){var r,a;if(\"lines\"===t.mode)return(r=t.line.color)&&n.opacity(r)?r:t.fillcolor;if(\"none\"===t.mode)return t.fill?t.fillcolor:\"\";var o=e.mcc||(t.marker||{}).color,s=e.mlcc||((t.marker||{}).line||{}).color;return(a=o&&n.opacity(o)?o:s&&n.opacity(s)&&(e.mlw||((t.marker||{}).line||{}).width)?s:\"\")?n.opacity(a)<.3?n.addOpacity(a,.3):a:(r=(t.line||{}).color)&&n.opacity(r)&&i.hasLines(t)&&t.line.width?r:t.fillcolor}},{\"../../components/color\":662,\"./subtypes\":1239}],1225:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/fx\"),a=t(\"../../registry\"),o=t(\"./get_trace_color\"),s=t(\"../../components/color\"),l=n.fillText;e.exports=function(t,e,r,c){var u=t.cd,f=u[0].trace,h=t.xa,p=t.ya,d=h.c2p(e),m=p.c2p(r),g=[d,m],v=f.hoveron||\"\",y=-1!==f.mode.indexOf(\"markers\")?3:.5;if(-1!==v.indexOf(\"points\")){var x=function(t){var e=Math.max(y,t.mrc||0),r=h.c2p(t.x)-d,n=p.c2p(t.y)-m;return Math.max(Math.sqrt(r*r+n*n)-e,1-y/e)},b=i.getDistanceFunction(c,(function(t){var e=Math.max(3,t.mrc||0),r=1-1/e,n=Math.abs(h.c2p(t.x)-d);return void 0!==t.orig_x&&(n+=h.c2p(t.orig_x)-h.c2p(t.x)),n<e?r*n/e:n-e+r}),(function(t){var e=Math.max(3,t.mrc||0),r=1-1/e,n=Math.abs(p.c2p(t.y)-m);return void 0!==t.orig_y&&(n+=p.c2p(t.orig_y)-p.c2p(t.y)),n<e?r*n/e:n-e+r}),x);if(i.getClosest(u,b,t),!1!==t.index){var _=u[t.index],w=h.c2p(_.x,!0),T=p.c2p(_.y,!0),k=_.mrc||1;t.index=_.i;var M=u[0].t.orientation,A=M&&(_.sNorm||_.s),S=\"h\"===M?A:void 0!==_.orig_x?_.orig_x:_.x,E=\"v\"===M?A:void 0!==_.orig_y?_.orig_y:_.y;return n.extendFlat(t,{color:o(f,_),x0:w-k,x1:w+k,xLabelVal:S,y0:T-k,y1:T+k,yLabelVal:E,spikeDistance:x(_),hovertemplate:f.hovertemplate}),l(_,f,t),a.getComponentMethod(\"errorbars\",\"hoverInfo\")(_,f,t),[t]}}if(-1!==v.indexOf(\"fills\")&&f._polygons){var L,C,P,I,O,z,D,R,F,B=f._polygons,N=[],j=!1,U=1/0,V=-1/0,q=1/0,H=-1/0;for(L=0;L<B.length;L++)(P=B[L]).contains(g)&&(j=!j,N.push(P),q=Math.min(q,P.ymin),H=Math.max(H,P.ymax));if(j){var G=((q=Math.max(q,0))+(H=Math.min(H,p._length)))/2;for(L=0;L<N.length;L++)for(I=N[L].pts,C=1;C<I.length;C++)(R=I[C-1][1])>G!=(F=I[C][1])>=G&&(z=I[C-1][0],D=I[C][0],F-R&&(O=z+(D-z)*(G-R)/(F-R),U=Math.min(U,O),V=Math.max(V,O)));U=Math.max(U,0),V=Math.min(V,h._length);var Y=s.defaultLine;return s.opacity(f.fillcolor)?Y=f.fillcolor:s.opacity((f.line||{}).color)&&(Y=f.line.color),n.extendFlat(t,{distance:t.maxHoverDistance,x0:U,x1:V,y0:G,y1:G,color:Y,hovertemplate:!1}),delete t.index,f.text&&!Array.isArray(f.text)?t.text=String(f.text):t.text=f.name,[t]}}}},{\"../../components/color\":662,\"../../components/fx\":702,\"../../lib\":799,\"../../registry\":927,\"./get_trace_color\":1224}],1226:[function(t,e,r){\"use strict\";var n=t(\"./subtypes\");e.exports={hasLines:n.hasLines,hasMarkers:n.hasMarkers,hasText:n.hasText,isBubble:n.isBubble,attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),crossTraceDefaults:t(\"./cross_trace_defaults\"),calc:t(\"./calc\").calc,crossTraceCalc:t(\"./cross_trace_calc\"),arraysToCalcdata:t(\"./arrays_to_calcdata\"),plot:t(\"./plot\"),colorbar:t(\"./marker_colorbar\"),formatLabels:t(\"./format_labels\"),style:t(\"./style\").style,styleOnSelect:t(\"./style\").styleOnSelect,hoverPoints:t(\"./hover\"),selectPoints:t(\"./select\"),animatable:!0,moduleType:\"trace\",name:\"scatter\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"symbols\",\"errorBarsOK\",\"showLegend\",\"scatter-like\",\"zoomScale\"],meta:{}}},{\"../../plots/cartesian\":863,\"./arrays_to_calcdata\":1213,\"./attributes\":1214,\"./calc\":1215,\"./cross_trace_calc\":1219,\"./cross_trace_defaults\":1220,\"./defaults\":1221,\"./format_labels\":1223,\"./hover\":1225,\"./marker_colorbar\":1232,\"./plot\":1235,\"./select\":1236,\"./style\":1238,\"./subtypes\":1239}],1227:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").isArrayOrTypedArray,i=t(\"../../components/colorscale/helpers\").hasColorscale,a=t(\"../../components/colorscale/defaults\");e.exports=function(t,e,r,o,s,l){var c=(t.marker||{}).color;(s(\"line.color\",r),i(t,\"line\"))?a(t,e,o,s,{prefix:\"line.\",cLetter:\"c\"}):s(\"line.color\",!n(c)&&c||r);s(\"line.width\"),(l||{}).noDash||s(\"line.dash\")}},{\"../../components/colorscale/defaults\":672,\"../../components/colorscale/helpers\":673,\"../../lib\":799}],1228:[function(t,e,r){\"use strict\";var n=t(\"../../constants/numerical\"),i=n.BADNUM,a=n.LOG_CLIP,o=a+.5,s=a-.5,l=t(\"../../lib\"),c=l.segmentsIntersect,u=l.constrain,f=t(\"./constants\");e.exports=function(t,e){var r,n,a,h,p,d,m,g,v,y,x,b,_,w,T,k,M,A,S=e.xaxis,E=e.yaxis,L=\"log\"===S.type,C=\"log\"===E.type,P=S._length,I=E._length,O=e.connectGaps,z=e.baseTolerance,D=e.shape,R=\"linear\"===D,F=e.fill&&\"none\"!==e.fill,B=[],N=f.minTolerance,j=t.length,U=new Array(j),V=0;function q(r){var n=t[r];if(!n)return!1;var a=e.linearized?S.l2p(n.x):S.c2p(n.x),l=e.linearized?E.l2p(n.y):E.c2p(n.y);if(a===i){if(L&&(a=S.c2p(n.x,!0)),a===i)return!1;C&&l===i&&(a*=Math.abs(S._m*I*(S._m>0?o:s)/(E._m*P*(E._m>0?o:s)))),a*=1e3}if(l===i){if(C&&(l=E.c2p(n.y,!0)),l===i)return!1;l*=1e3}return[a,l]}function H(t,e,r,n){var i=r-t,a=n-e,o=.5-t,s=.5-e,l=i*i+a*a,c=i*o+a*s;if(c>0&&c<l){var u=o*a-s*i;if(u*u<l)return!0}}function G(t,e){var r=t[0]/P,n=t[1]/I,i=Math.max(0,-r,r-1,-n,n-1);return i&&void 0!==M&&H(r,n,M,A)&&(i=0),i&&e&&H(r,n,e[0]/P,e[1]/I)&&(i=0),(1+f.toleranceGrowth*i)*z}function Y(t,e){var r=t[0]-e[0],n=t[1]-e[1];return Math.sqrt(r*r+n*n)}var W,X,Z,J,K,Q,$,tt=f.maxScreensAway,et=-P*tt,rt=P*(1+tt),nt=-I*tt,it=I*(1+tt),at=[[et,nt,rt,nt],[rt,nt,rt,it],[rt,it,et,it],[et,it,et,nt]];function ot(t){if(t[0]<et||t[0]>rt||t[1]<nt||t[1]>it)return[u(t[0],et,rt),u(t[1],nt,it)]}function st(t,e){return t[0]===e[0]&&(t[0]===et||t[0]===rt)||(t[1]===e[1]&&(t[1]===nt||t[1]===it)||void 0)}function lt(t,e,r){return function(n,i){var a=ot(n),o=ot(i),s=[];if(a&&o&&st(a,o))return s;a&&s.push(a),o&&s.push(o);var c=2*l.constrain((n[t]+i[t])/2,e,r)-((a||n)[t]+(o||i)[t]);c&&((a&&o?c>0==a[t]>o[t]?a:o:a||o)[t]+=c);return s}}function ct(t){var e=t[0],r=t[1],n=e===U[V-1][0],i=r===U[V-1][1];if(!n||!i)if(V>1){var a=e===U[V-2][0],o=r===U[V-2][1];n&&(e===et||e===rt)&&a?o?V--:U[V-1]=t:i&&(r===nt||r===it)&&o?a?V--:U[V-1]=t:U[V++]=t}else U[V++]=t}function ut(t){U[V-1][0]!==t[0]&&U[V-1][1]!==t[1]&&ct([Z,J]),ct(t),K=null,Z=J=0}function ft(t){if(M=t[0]/P,A=t[1]/I,W=t[0]<et?et:t[0]>rt?rt:0,X=t[1]<nt?nt:t[1]>it?it:0,W||X){if(V)if(K){var e=$(K,t);e.length>1&&(ut(e[0]),U[V++]=e[1])}else Q=$(U[V-1],t)[0],U[V++]=Q;else U[V++]=[W||t[0],X||t[1]];var r=U[V-1];W&&X&&(r[0]!==W||r[1]!==X)?(K&&(Z!==W&&J!==X?ct(Z&&J?(n=K,a=(i=t)[0]-n[0],o=(i[1]-n[1])/a,(n[1]*i[0]-i[1]*n[0])/a>0?[o>0?et:rt,it]:[o>0?rt:et,nt]):[Z||W,J||X]):Z&&J&&ct([Z,J])),ct([W,X])):Z-W&&J-X&&ct([W||Z,X||J]),K=t,Z=W,J=X}else K&&ut($(K,t)[0]),U[V++]=t;var n,i,a,o}for(\"linear\"===D||\"spline\"===D?$=function(t,e){for(var r=[],n=0,i=0;i<4;i++){var a=at[i],o=c(t[0],t[1],e[0],e[1],a[0],a[1],a[2],a[3]);o&&(!n||Math.abs(o.x-r[0][0])>1||Math.abs(o.y-r[0][1])>1)&&(o=[o.x,o.y],n&&Y(o,t)<Y(r[0],t)?r.unshift(o):r.push(o),n++)}return r}:\"hv\"===D||\"vh\"===D?$=function(t,e){var r=[],n=ot(t),i=ot(e);return n&&i&&st(n,i)||(n&&r.push(n),i&&r.push(i)),r}:\"hvh\"===D?$=lt(0,et,rt):\"vhv\"===D&&($=lt(1,nt,it)),r=0;r<j;r++)if(n=q(r)){for(V=0,K=null,ft(n),r++;r<j;r++){if(!(h=q(r))){if(O)continue;break}if(R&&e.simplify){var ht=q(r+1);if(y=Y(h,n),F&&(0===V||V===j-1)||!(y<G(h,ht)*N)){for(g=[(h[0]-n[0])/y,(h[1]-n[1])/y],p=n,x=y,b=w=T=0,m=!1,a=h,r++;r<t.length;r++){if(d=ht,ht=q(r+1),!d){if(O)continue;break}if(k=(v=[d[0]-n[0],d[1]-n[1]])[0]*g[1]-v[1]*g[0],w=Math.min(w,k),(T=Math.max(T,k))-w>G(d,ht))break;a=d,(_=v[0]*g[0]+v[1]*g[1])>x?(x=_,h=d,m=!1):_<b&&(b=_,p=d,m=!0)}if(m?(ft(h),a!==p&&ft(p)):(p!==n&&ft(p),a!==h&&ft(h)),ft(a),r>=t.length||!d)break;ft(d),n=d}}else ft(h)}K&&ct([Z||K[0],J||K[1]]),B.push(U.slice(0,V))}return B}},{\"../../constants/numerical\":775,\"../../lib\":799,\"./constants\":1218}],1229:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){\"spline\"===r(\"line.shape\")&&r(\"line.smoothing\")}},{}],1230:[function(t,e,r){\"use strict\";var n={tonextx:1,tonexty:1,tonext:1};e.exports=function(t,e,r){var i,a,o,s,l,c={},u=!1,f=-1,h=0,p=-1;for(a=0;a<r.length;a++)(o=(i=r[a][0].trace).stackgroup||\"\")?o in c?l=c[o]:(l=c[o]=h,h++):i.fill in n&&p>=0?l=p:(l=p=h,h++),l<f&&(u=!0),i._groupIndex=f=l;var d=r.slice();u&&d.sort((function(t,e){var r=t[0].trace,n=e[0].trace;return r._groupIndex-n._groupIndex||r.index-n.index}));var m={};for(a=0;a<d.length;a++)o=(i=d[a][0].trace).stackgroup||\"\",!0===i.visible?(i._nexttrace=null,i.fill in n&&(s=m[o],i._prevtrace=s||null,s&&(s._nexttrace=i)),i._ownfill=i.fill&&(\"tozero\"===i.fill.substr(0,6)||\"toself\"===i.fill||\"to\"===i.fill.substr(0,2)&&!i._prevtrace),m[o]=i):i._prevtrace=i._nexttrace=i._ownfill=null;return d}},{}],1231:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\");e.exports=function(t){var e=t.marker,r=e.sizeref||1,i=e.sizemin||0,a=\"area\"===e.sizemode?function(t){return Math.sqrt(t/r)}:function(t){return t/r};return function(t){var e=a(t/2);return n(e)&&e>0?Math.max(e,i):0}}},{\"fast-isnumeric\":245}],1232:[function(t,e,r){\"use strict\";e.exports={container:\"marker\",min:\"cmin\",max:\"cmax\"}},{}],1233:[function(t,e,r){\"use strict\";var n=t(\"../../components/color\"),i=t(\"../../components/colorscale/helpers\").hasColorscale,a=t(\"../../components/colorscale/defaults\"),o=t(\"./subtypes\");e.exports=function(t,e,r,s,l,c){var u=o.isBubble(t),f=(t.line||{}).color;(c=c||{},f&&(r=f),l(\"marker.symbol\"),l(\"marker.opacity\",u?.7:1),l(\"marker.size\"),l(\"marker.color\",r),i(t,\"marker\")&&a(t,e,s,l,{prefix:\"marker.\",cLetter:\"c\"}),c.noSelect||(l(\"selected.marker.color\"),l(\"unselected.marker.color\"),l(\"selected.marker.size\"),l(\"unselected.marker.size\")),c.noLine||(l(\"marker.line.color\",f&&!Array.isArray(f)&&e.marker.color!==f?f:u?n.background:n.defaultLine),i(t,\"marker.line\")&&a(t,e,s,l,{prefix:\"marker.line.\",cLetter:\"c\"}),l(\"marker.line.width\",u?1:0)),u&&(l(\"marker.sizeref\"),l(\"marker.sizemin\"),l(\"marker.sizemode\")),c.gradient)&&(\"none\"!==l(\"marker.gradient.type\")&&l(\"marker.gradient.color\"))}},{\"../../components/color\":662,\"../../components/colorscale/defaults\":672,\"../../components/colorscale/helpers\":673,\"./subtypes\":1239}],1234:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").dateTick0,i=t(\"../../constants/numerical\").ONEWEEK;function a(t,e){return n(e,t%i==0?1:0)}e.exports=function(t,e,r,n,i){if(i||(i={x:!0,y:!0}),i.x){var o=n(\"xperiod\");o&&(n(\"xperiod0\",a(o,e.xcalendar)),n(\"xperiodalignment\"))}if(i.y){var s=n(\"yperiod\");s&&(n(\"yperiod0\",a(s,e.ycalendar)),n(\"yperiodalignment\"))}}},{\"../../constants/numerical\":775,\"../../lib\":799}],1235:[function(t,e,r){\"use strict\";var n=t(\"@plotly/d3\"),i=t(\"../../registry\"),a=t(\"../../lib\"),o=a.ensureSingle,s=a.identity,l=t(\"../../components/drawing\"),c=t(\"./subtypes\"),u=t(\"./line_points\"),f=t(\"./link_traces\"),h=t(\"../../lib/polygon\").tester;function p(t,e,r,f,p,d,m){var g;!function(t,e,r,i,o){var s=r.xaxis,l=r.yaxis,u=n.extent(a.simpleMap(s.range,s.r2c)),f=n.extent(a.simpleMap(l.range,l.r2c)),h=i[0].trace;if(!c.hasMarkers(h))return;var p=h.marker.maxdisplayed;if(0===p)return;var d=i.filter((function(t){return t.x>=u[0]&&t.x<=u[1]&&t.y>=f[0]&&t.y<=f[1]})),m=Math.ceil(d.length/p),g=0;o.forEach((function(t,r){var n=t[0].trace;c.hasMarkers(n)&&n.marker.maxdisplayed>0&&r<e&&g++}));var v=Math.round(g*m/3+Math.floor(g/3)*m/7.1);i.forEach((function(t){delete t.vis})),d.forEach((function(t,e){0===Math.round((e+v)%m)&&(t.vis=!0)}))}(0,e,r,f,p);var v=!!m&&m.duration>0;function y(t){return v?t.transition():t}var x=r.xaxis,b=r.yaxis,_=f[0].trace,w=_.line,T=n.select(d),k=o(T,\"g\",\"errorbars\"),M=o(T,\"g\",\"lines\"),A=o(T,\"g\",\"points\"),S=o(T,\"g\",\"text\");if(i.getComponentMethod(\"errorbars\",\"plot\")(t,k,r,m),!0===_.visible){var E,L;y(T).style(\"opacity\",_.opacity);var C=_.fill.charAt(_.fill.length-1);\"x\"!==C&&\"y\"!==C&&(C=\"\"),f[0][r.isRangePlot?\"nodeRangePlot3\":\"node3\"]=T;var P,I,O=\"\",z=[],D=_._prevtrace;D&&(O=D._prevRevpath||\"\",L=D._nextFill,z=D._polygons);var R,F,B,N,j,U,V,q=\"\",H=\"\",G=[],Y=a.noop;if(E=_._ownFill,c.hasLines(_)||\"none\"!==_.fill){for(L&&L.datum(f),-1!==[\"hv\",\"vh\",\"hvh\",\"vhv\"].indexOf(w.shape)?(R=l.steps(w.shape),F=l.steps(w.shape.split(\"\").reverse().join(\"\"))):R=F=\"spline\"===w.shape?function(t){var e=t[t.length-1];return t.length>1&&t[0][0]===e[0]&&t[0][1]===e[1]?l.smoothclosed(t.slice(1),w.smoothing):l.smoothopen(t,w.smoothing)}:function(t){return\"M\"+t.join(\"L\")},B=function(t){return F(t.reverse())},G=u(f,{xaxis:x,yaxis:b,connectGaps:_.connectgaps,baseTolerance:Math.max(w.width||1,3)/4,shape:w.shape,simplify:w.simplify,fill:_.fill}),V=_._polygons=new Array(G.length),g=0;g<G.length;g++)_._polygons[g]=h(G[g]);G.length&&(N=G[0][0],U=(j=G[G.length-1])[j.length-1]),Y=function(t){return function(e){if(P=R(e),I=B(e),q?C?(q+=\"L\"+P.substr(1),H=I+\"L\"+H.substr(1)):(q+=\"Z\"+P,H=I+\"Z\"+H):(q=P,H=I),c.hasLines(_)&&e.length>1){var r=n.select(this);if(r.datum(f),t)y(r.style(\"opacity\",0).attr(\"d\",P).call(l.lineGroupStyle)).style(\"opacity\",1);else{var i=y(r);i.attr(\"d\",P),l.singleLineStyle(f,i)}}}}}var W=M.selectAll(\".js-line\").data(G);y(W.exit()).style(\"opacity\",0).remove(),W.each(Y(!1)),W.enter().append(\"path\").classed(\"js-line\",!0).style(\"vector-effect\",\"non-scaling-stroke\").call(l.lineGroupStyle).each(Y(!0)),l.setClipUrl(W,r.layerClipId,t),G.length?(E?(E.datum(f),N&&U&&(C?(\"y\"===C?N[1]=U[1]=b.c2p(0,!0):\"x\"===C&&(N[0]=U[0]=x.c2p(0,!0)),y(E).attr(\"d\",\"M\"+U+\"L\"+N+\"L\"+q.substr(1)).call(l.singleFillStyle)):y(E).attr(\"d\",q+\"Z\").call(l.singleFillStyle))):L&&(\"tonext\"===_.fill.substr(0,6)&&q&&O?(\"tonext\"===_.fill?y(L).attr(\"d\",q+\"Z\"+O+\"Z\").call(l.singleFillStyle):y(L).attr(\"d\",q+\"L\"+O.substr(1)+\"Z\").call(l.singleFillStyle),_._polygons=_._polygons.concat(z)):(Z(L),_._polygons=null)),_._prevRevpath=H,_._prevPolygons=V):(E?Z(E):L&&Z(L),_._polygons=_._prevRevpath=_._prevPolygons=null),A.datum(f),S.datum(f),function(e,i,a){var o,u=a[0].trace,f=c.hasMarkers(u),h=c.hasText(u),p=tt(u),d=et,m=et;if(f||h){var g=s,_=u.stackgroup,w=_&&\"infer zero\"===t._fullLayout._scatterStackOpts[x._id+b._id][_].stackgaps;u.marker.maxdisplayed||u._needsCull?g=w?K:J:_&&!w&&(g=Q),f&&(d=g),h&&(m=g)}var T,k=(o=e.selectAll(\"path.point\").data(d,p)).enter().append(\"path\").classed(\"point\",!0);v&&k.call(l.pointStyle,u,t).call(l.translatePoints,x,b).style(\"opacity\",0).transition().style(\"opacity\",1),o.order(),f&&(T=l.makePointStyleFns(u)),o.each((function(e){var i=n.select(this),a=y(i);l.translatePoint(e,a,x,b)?(l.singlePointStyle(e,a,u,T,t),r.layerClipId&&l.hideOutsideRangePoint(e,a,x,b,u.xcalendar,u.ycalendar),u.customdata&&i.classed(\"plotly-customdata\",null!==e.data&&void 0!==e.data)):a.remove()})),v?o.exit().transition().style(\"opacity\",0).remove():o.exit().remove(),(o=i.selectAll(\"g\").data(m,p)).enter().append(\"g\").classed(\"textpoint\",!0).append(\"text\"),o.order(),o.each((function(t){var e=n.select(this),i=y(e.select(\"text\"));l.translatePoint(t,i,x,b)?r.layerClipId&&l.hideOutsideRangePoint(t,e,x,b,u.xcalendar,u.ycalendar):e.remove()})),o.selectAll(\"text\").call(l.textPointStyle,u,t).each((function(t){var e=x.c2p(t.x),r=b.c2p(t.y);n.select(this).selectAll(\"tspan.line\").each((function(){y(n.select(this)).attr({x:e,y:r})}))})),o.exit().remove()}(A,S,f);var X=!1===_.cliponaxis?null:r.layerClipId;l.setClipUrl(A,X,t),l.setClipUrl(S,X,t)}function Z(t){y(t).attr(\"d\",\"M0,0Z\")}function J(t){return t.filter((function(t){return!t.gap&&t.vis}))}function K(t){return t.filter((function(t){return t.vis}))}function Q(t){return t.filter((function(t){return!t.gap}))}function $(t){return t.id}function tt(t){if(t.ids)return $}function et(){return!1}}e.exports=function(t,e,r,i,a,c){var u,h,d=!a,m=!!a&&a.duration>0,g=f(t,e,r);((u=i.selectAll(\"g.trace\").data(g,(function(t){return t[0].trace.uid}))).enter().append(\"g\").attr(\"class\",(function(t){return\"trace scatter trace\"+t[0].trace.uid})).style(\"stroke-miterlimit\",2),u.order(),function(t,e,r){e.each((function(e){var i=o(n.select(this),\"g\",\"fills\");l.setClipUrl(i,r.layerClipId,t);var a=e[0].trace,c=[];a._ownfill&&c.push(\"_ownFill\"),a._nexttrace&&c.push(\"_nextFill\");var u=i.selectAll(\"g\").data(c,s);u.enter().append(\"g\"),u.exit().each((function(t){a[t]=null})).remove(),u.order().each((function(t){a[t]=o(n.select(this),\"path\",\"js-fill\")}))}))}(t,u,e),m)?(c&&(h=c()),n.transition().duration(a.duration).ease(a.easing).each(\"end\",(function(){h&&h()})).each(\"interrupt\",(function(){h&&h()})).each((function(){i.selectAll(\"g.trace\").each((function(r,n){p(t,n,e,r,g,this,a)}))}))):u.each((function(r,n){p(t,n,e,r,g,this,a)}));d&&u.exit().remove(),i.selectAll(\"path:not([d])\").remove()}},{\"../../components/drawing\":684,\"../../lib\":799,\"../../lib/polygon\":811,\"../../registry\":927,\"./line_points\":1228,\"./link_traces\":1230,\"./subtypes\":1239,\"@plotly/d3\":58}],1236:[function(t,e,r){\"use strict\";var n=t(\"./subtypes\");e.exports=function(t,e){var r,i,a,o,s=t.cd,l=t.xaxis,c=t.yaxis,u=[],f=s[0].trace;if(!n.hasMarkers(f)&&!n.hasText(f))return[];if(!1===e)for(r=0;r<s.length;r++)s[r].selected=0;else for(r=0;r<s.length;r++)i=s[r],a=l.c2p(i.x),o=c.c2p(i.y),null!==i.i&&e.contains([a,o],!1,r,t)?(u.push({pointNumber:i.i,x:l.c2d(i.x),y:c.c2d(i.y)}),i.selected=1):i.selected=0;return u}},{\"./subtypes\":1239}],1237:[function(t,e,r){\"use strict\";var n=[\"orientation\",\"groupnorm\",\"stackgaps\"];e.exports=function(t,e,r,i){var a=r._scatterStackOpts,o=i(\"stackgroup\");if(o){var s=e.xaxis+e.yaxis,l=a[s];l||(l=a[s]={});var c=l[o],u=!1;c?c.traces.push(e):(c=l[o]={traceIndices:[],traces:[e]},u=!0);for(var f={orientation:e.x&&!e.y?\"h\":\"v\"},h=0;h<n.length;h++){var p=n[h],d=p+\"Found\";if(!c[d]){var m=void 0!==t[p],g=\"orientation\"===p;if((m||u)&&(c[p]=i(p,f[p]),g&&(c.fillDflt=\"h\"===c[p]?\"tonextx\":\"tonexty\"),m&&(c[d]=!0,!u&&(delete c.traces[0][p],g))))for(var v=0;v<c.traces.length-1;v++){var y=c.traces[v];y._input.fill!==y.fill&&(y.fill=c.fillDflt)}}}return c}}},{}],1238:[function(t,e,r){\"use strict\";var n=t(\"@plotly/d3\"),i=t(\"../../components/drawing\"),a=t(\"../../registry\");function o(t,e,r){i.pointStyle(t.selectAll(\"path.point\"),e,r)}function s(t,e,r){i.textPointStyle(t.selectAll(\"text\"),e,r)}e.exports={style:function(t){var e=n.select(t).selectAll(\"g.trace.scatter\");e.style(\"opacity\",(function(t){return t[0].trace.opacity})),e.selectAll(\"g.points\").each((function(e){o(n.select(this),e.trace||e[0].trace,t)})),e.selectAll(\"g.text\").each((function(e){s(n.select(this),e.trace||e[0].trace,t)})),e.selectAll(\"g.trace path.js-line\").call(i.lineGroupStyle),e.selectAll(\"g.trace path.js-fill\").call(i.fillGroupStyle),a.getComponentMethod(\"errorbars\",\"style\")(e)},stylePoints:o,styleText:s,styleOnSelect:function(t,e,r){var n=e[0].trace;n.selectedpoints?(i.selectedPointStyle(r.selectAll(\"path.point\"),n),i.selectedTextStyle(r.selectAll(\"text\"),n)):(o(r,n,t),s(r,n,t))}}},{\"../../components/drawing\":684,\"../../registry\":927,\"@plotly/d3\":58}],1239:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports={hasLines:function(t){return t.visible&&t.mode&&-1!==t.mode.indexOf(\"lines\")},hasMarkers:function(t){return t.visible&&(t.mode&&-1!==t.mode.indexOf(\"markers\")||\"splom\"===t.type)},hasText:function(t){return t.visible&&t.mode&&-1!==t.mode.indexOf(\"text\")},isBubble:function(t){return n.isPlainObject(t.marker)&&n.isArrayOrTypedArray(t.marker.size)}}},{\"../../lib\":799}],1240:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e,r,i,a){a=a||{},i(\"textposition\"),n.coerceFont(i,\"textfont\",r.font),a.noSelect||(i(\"selected.textfont.color\"),i(\"unselected.textfont.color\"))}},{\"../../lib\":799}],1241:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../registry\");e.exports=function(t,e,r,a){var o,s=a(\"x\"),l=a(\"y\");if(i.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\",\"y\"],r),s){var c=n.minRowLength(s);l?o=Math.min(c,n.minRowLength(l)):(o=c,a(\"y0\"),a(\"dy\"))}else{if(!l)return 0;o=n.minRowLength(l),a(\"x0\"),a(\"dx\")}return e._length=o,o}},{\"../../lib\":799,\"../../registry\":927}],1242:[function(t,e,r){\"use strict\";var n=t(\"../scatter/attributes\"),i=t(\"../../components/colorscale/attributes\"),a=t(\"../../plots/cartesian/axis_format_attributes\").axisHoverFormat,o=t(\"../../plots/template_attributes\").hovertemplateAttrs,s=t(\"../../plots/template_attributes\").texttemplateAttrs,l=t(\"../../plots/attributes\"),c=t(\"../../constants/gl3d_dashes\"),u=t(\"../../constants/gl3d_markers\"),f=t(\"../../lib/extend\").extendFlat,h=t(\"../../plot_api/edit_types\").overrideAll,p=n.line,d=n.marker,m=d.line,g=f({width:p.width,dash:{valType:\"enumerated\",values:Object.keys(c),dflt:\"solid\"}},i(\"line\"));var v=e.exports=h({x:n.x,y:n.y,z:{valType:\"data_array\"},text:f({},n.text,{}),texttemplate:s({},{}),hovertext:f({},n.hovertext,{}),hovertemplate:o(),xhoverformat:a(\"x\"),yhoverformat:a(\"y\"),zhoverformat:a(\"z\"),mode:f({},n.mode,{dflt:\"lines+markers\"}),surfaceaxis:{valType:\"enumerated\",values:[-1,0,1,2],dflt:-1},surfacecolor:{valType:\"color\"},projection:{x:{show:{valType:\"boolean\",dflt:!1},opacity:{valType:\"number\",min:0,max:1,dflt:1},scale:{valType:\"number\",min:0,max:10,dflt:2/3}},y:{show:{valType:\"boolean\",dflt:!1},opacity:{valType:\"number\",min:0,max:1,dflt:1},scale:{valType:\"number\",min:0,max:10,dflt:2/3}},z:{show:{valType:\"boolean\",dflt:!1},opacity:{valType:\"number\",min:0,max:1,dflt:1},scale:{valType:\"number\",min:0,max:10,dflt:2/3}}},connectgaps:n.connectgaps,line:g,marker:f({symbol:{valType:\"enumerated\",values:Object.keys(u),dflt:\"circle\",arrayOk:!0},size:f({},d.size,{dflt:8}),sizeref:d.sizeref,sizemin:d.sizemin,sizemode:d.sizemode,opacity:f({},d.opacity,{arrayOk:!1}),colorbar:d.colorbar,line:f({width:f({},m.width,{arrayOk:!1})},i(\"marker.line\"))},i(\"marker\")),textposition:f({},n.textposition,{dflt:\"top center\"}),textfont:{color:n.textfont.color,size:n.textfont.size,family:f({},n.textfont.family,{arrayOk:!1})},hoverinfo:f({},l.hoverinfo)},\"calc\",\"nested\");v.x.editType=v.y.editType=v.z.editType=\"calc+clearAxisTypes\"},{\"../../components/colorscale/attributes\":669,\"../../constants/gl3d_dashes\":772,\"../../constants/gl3d_markers\":773,\"../../lib/extend\":789,\"../../plot_api/edit_types\":831,\"../../plots/attributes\":845,\"../../plots/cartesian/axis_format_attributes\":852,\"../../plots/template_attributes\":922,\"../scatter/attributes\":1214}],1243:[function(t,e,r){\"use strict\";var n=t(\"../scatter/arrays_to_calcdata\"),i=t(\"../scatter/colorscale_calc\");e.exports=function(t,e){var r=[{x:!1,y:!1,trace:e,t:{}}];return n(r,e),i(t,e),r}},{\"../scatter/arrays_to_calcdata\":1213,\"../scatter/colorscale_calc\":1217}],1244:[function(t,e,r){\"use strict\";var n=t(\"../../registry\");function i(t,e,r,i){if(!e||!e.visible)return null;for(var a=n.getComponentMethod(\"errorbars\",\"makeComputeError\")(e),o=new Array(t.length),s=0;s<t.length;s++){var l=a(+t[s],s);if(\"log\"===i.type){var c=i.c2l(t[s]),u=t[s]-l[0],f=t[s]+l[1];if(o[s]=[(i.c2l(u,!0)-c)*r,(i.c2l(f,!0)-c)*r],u>0){var h=i.c2l(u);i._lowerLogErrorBound||(i._lowerLogErrorBound=h),i._lowerErrorBound=Math.min(i._lowerLogErrorBound,h)}}else o[s]=[-l[0]*r,l[1]*r]}return o}e.exports=function(t,e,r){var n=[i(t.x,t.error_x,e[0],r.xaxis),i(t.y,t.error_y,e[1],r.yaxis),i(t.z,t.error_z,e[2],r.zaxis)],a=function(t){for(var e=0;e<t.length;e++)if(t[e])return t[e].length;return 0}(n);if(0===a)return null;for(var o=new Array(a),s=0;s<a;s++){for(var l=[[0,0,0],[0,0,0]],c=0;c<3;c++)if(n[c])for(var u=0;u<2;u++)l[u][c]=n[c][s][u];o[s]=l}return o}},{\"../../registry\":927}],1245:[function(t,e,r){\"use strict\";var n=t(\"gl-line3d\"),i=t(\"gl-scatter3d\"),a=t(\"gl-error3d\"),o=t(\"gl-mesh3d\"),s=t(\"delaunay-triangulate\"),l=t(\"../../lib\"),c=t(\"../../lib/str2rgbarray\"),u=t(\"../../lib/gl_format_color\").formatColor,f=t(\"../scatter/make_bubble_size_func\"),h=t(\"../../constants/gl3d_dashes\"),p=t(\"../../constants/gl3d_markers\"),d=t(\"../../plots/cartesian/axes\"),m=t(\"../../components/fx/helpers\").appendArrayPointValue,g=t(\"./calc_errors\");function v(t,e){this.scene=t,this.uid=e,this.linePlot=null,this.scatterPlot=null,this.errorBars=null,this.textMarkers=null,this.delaunayMesh=null,this.color=null,this.mode=\"\",this.dataPoints=[],this.axesBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.textLabels=null,this.data=null}var y=v.prototype;function x(t){return null==t?0:t.indexOf(\"left\")>-1?-1:t.indexOf(\"right\")>-1?1:0}function b(t){return null==t?0:t.indexOf(\"top\")>-1?-1:t.indexOf(\"bottom\")>-1?1:0}function _(t,e){return e(4*t)}function w(t){return p[t]}function T(t,e,r,n,i){var a=null;if(l.isArrayOrTypedArray(t)){a=[];for(var o=0;o<e;o++)void 0===t[o]?a[o]=n:a[o]=r(t[o],i)}else a=r(t,l.identity);return a}function k(t,e){var r,n,i,a,o,s,h=[],p=t.fullSceneLayout,v=t.dataScale,y=p.xaxis,k=p.yaxis,M=p.zaxis,A=e.marker,S=e.line,E=e.x||[],L=e.y||[],C=e.z||[],P=E.length,I=e.xcalendar,O=e.ycalendar,z=e.zcalendar;for(o=0;o<P;o++)r=y.d2l(E[o],0,I)*v[0],n=k.d2l(L[o],0,O)*v[1],i=M.d2l(C[o],0,z)*v[2],h[o]=[r,n,i];if(Array.isArray(e.text))s=e.text;else if(void 0!==e.text)for(s=new Array(P),o=0;o<P;o++)s[o]=e.text;function D(t,e){var r=p[t];return d.tickText(r,r.d2l(e),!0).text}var R=e.texttemplate;if(R){var F=t.fullLayout._d3locale,B=Array.isArray(R),N=B?Math.min(R.length,P):P,j=B?function(t){return R[t]}:function(){return R};for(s=new Array(N),o=0;o<N;o++){var U={x:E[o],y:L[o],z:C[o]},V={xLabel:D(\"xaxis\",E[o]),yLabel:D(\"yaxis\",L[o]),zLabel:D(\"zaxis\",C[o])},q={};m(q,e,o);var H=e._meta||{};s[o]=l.texttemplateString(j(o),V,F,q,U,H)}}if(a={position:h,mode:e.mode,text:s},\"line\"in e&&(a.lineColor=u(S,1,P),a.lineWidth=S.width,a.lineDashes=S.dash),\"marker\"in e){var G=f(e);a.scatterColor=u(A,1,P),a.scatterSize=T(A.size,P,_,20,G),a.scatterMarker=T(A.symbol,P,w,\"\\u25cf\"),a.scatterLineWidth=A.line.width,a.scatterLineColor=u(A.line,1,P),a.scatterAngle=0}\"textposition\"in e&&(a.textOffset=function(t){var e=[0,0];if(Array.isArray(t))for(var r=0;r<t.length;r++)e[r]=[0,0],t[r]&&(e[r][0]=x(t[r]),e[r][1]=b(t[r]));else e[0]=x(t),e[1]=b(t);return e}(e.textposition),a.textColor=u(e.textfont,1,P),a.textSize=T(e.textfont.size,P,l.identity,12),a.textFont=e.textfont.family,a.textAngle=0);var Y=[\"x\",\"y\",\"z\"];for(a.project=[!1,!1,!1],a.projectScale=[1,1,1],a.projectOpacity=[1,1,1],o=0;o<3;++o){var W=e.projection[Y[o]];(a.project[o]=W.show)&&(a.projectOpacity[o]=W.opacity,a.projectScale[o]=W.scale)}a.errorBounds=g(e,v,p);var X=function(t){for(var e=[0,0,0],r=[[0,0,0],[0,0,0],[0,0,0]],n=[1,1,1],i=0;i<3;i++){var a=t[i];a&&!1!==a.copy_zstyle&&!1!==t[2].visible&&(a=t[2]),a&&a.visible&&(e[i]=a.width/2,r[i]=c(a.color),n[i]=a.thickness)}return{capSize:e,color:r,lineWidth:n}}([e.error_x,e.error_y,e.error_z]);return a.errorColor=X.color,a.errorLineWidth=X.lineWidth,a.errorCapSize=X.capSize,a.delaunayAxis=e.surfaceaxis,a.delaunayColor=c(e.surfacecolor),a}function M(t){if(l.isArrayOrTypedArray(t)){var e=t[0];return l.isArrayOrTypedArray(e)&&(t=e),\"rgb(\"+t.slice(0,3).map((function(t){return Math.round(255*t)}))+\")\"}return null}function A(t){return l.isArrayOrTypedArray(t)?4===t.length&&\"number\"==typeof t[0]?M(t):t.map(M):null}y.handlePick=function(t){if(t.object&&(t.object===this.linePlot||t.object===this.delaunayMesh||t.object===this.textMarkers||t.object===this.scatterPlot)){var e=t.index=t.data.index;return t.object.highlight&&t.object.highlight(null),this.scatterPlot&&(t.object=this.scatterPlot,this.scatterPlot.highlight(t.data)),t.textLabel=\"\",this.textLabels&&(Array.isArray(this.textLabels)?(this.textLabels[e]||0===this.textLabels[e])&&(t.textLabel=this.textLabels[e]):t.textLabel=this.textLabels),t.traceCoordinate=[this.data.x[e],this.data.y[e],this.data.z[e]],!0}},y.update=function(t){var e,r,l,c,u=this.scene.glplot.gl,f=h.solid;this.data=t;var p=k(this.scene,t);\"mode\"in p&&(this.mode=p.mode),\"lineDashes\"in p&&p.lineDashes in h&&(f=h[p.lineDashes]),this.color=A(p.scatterColor)||A(p.lineColor),this.dataPoints=p.position,e={gl:this.scene.glplot.gl,position:p.position,color:p.lineColor,lineWidth:p.lineWidth||1,dashes:f[0],dashScale:f[1],opacity:t.opacity,connectGaps:t.connectgaps},-1!==this.mode.indexOf(\"lines\")?this.linePlot?this.linePlot.update(e):(this.linePlot=n(e),this.linePlot._trace=this,this.scene.glplot.add(this.linePlot)):this.linePlot&&(this.scene.glplot.remove(this.linePlot),this.linePlot.dispose(),this.linePlot=null);var d=t.opacity;if(t.marker&&t.marker.opacity&&(d*=t.marker.opacity),r={gl:this.scene.glplot.gl,position:p.position,color:p.scatterColor,size:p.scatterSize,glyph:p.scatterMarker,opacity:d,orthographic:!0,lineWidth:p.scatterLineWidth,lineColor:p.scatterLineColor,project:p.project,projectScale:p.projectScale,projectOpacity:p.projectOpacity},-1!==this.mode.indexOf(\"markers\")?this.scatterPlot?this.scatterPlot.update(r):(this.scatterPlot=i(r),this.scatterPlot._trace=this,this.scatterPlot.highlightScale=1,this.scene.glplot.add(this.scatterPlot)):this.scatterPlot&&(this.scene.glplot.remove(this.scatterPlot),this.scatterPlot.dispose(),this.scatterPlot=null),c={gl:this.scene.glplot.gl,position:p.position,glyph:p.text,color:p.textColor,size:p.textSize,angle:p.textAngle,alignment:p.textOffset,font:p.textFont,orthographic:!0,lineWidth:0,project:!1,opacity:t.opacity},this.textLabels=t.hovertext||t.text,-1!==this.mode.indexOf(\"text\")?this.textMarkers?this.textMarkers.update(c):(this.textMarkers=i(c),this.textMarkers._trace=this,this.textMarkers.highlightScale=1,this.scene.glplot.add(this.textMarkers)):this.textMarkers&&(this.scene.glplot.remove(this.textMarkers),this.textMarkers.dispose(),this.textMarkers=null),l={gl:this.scene.glplot.gl,position:p.position,color:p.errorColor,error:p.errorBounds,lineWidth:p.errorLineWidth,capSize:p.errorCapSize,opacity:t.opacity},this.errorBars?p.errorBounds?this.errorBars.update(l):(this.scene.glplot.remove(this.errorBars),this.errorBars.dispose(),this.errorBars=null):p.errorBounds&&(this.errorBars=a(l),this.errorBars._trace=this,this.scene.glplot.add(this.errorBars)),p.delaunayAxis>=0){var m=function(t,e,r){var n,i=(r+1)%3,a=(r+2)%3,o=[],l=[];for(n=0;n<t.length;++n){var c=t[n];!isNaN(c[i])&&isFinite(c[i])&&!isNaN(c[a])&&isFinite(c[a])&&(o.push([c[i],c[a]]),l.push(n))}var u=s(o);for(n=0;n<u.length;++n)for(var f=u[n],h=0;h<f.length;++h)f[h]=l[f[h]];return{positions:t,cells:u,meshColor:e}}(p.position,p.delaunayColor,p.delaunayAxis);m.opacity=t.opacity,this.delaunayMesh?this.delaunayMesh.update(m):(m.gl=u,this.delaunayMesh=o(m),this.delaunayMesh._trace=this,this.scene.glplot.add(this.delaunayMesh))}else this.delaunayMesh&&(this.scene.glplot.remove(this.delaunayMesh),this.delaunayMesh.dispose(),this.delaunayMesh=null)},y.dispose=function(){this.linePlot&&(this.scene.glplot.remove(this.linePlot),this.linePlot.dispose()),this.scatterPlot&&(this.scene.glplot.remove(this.scatterPlot),this.scatterPlot.dispose()),this.errorBars&&(this.scene.glplot.remove(this.errorBars),this.errorBars.dispose()),this.textMarkers&&(this.scene.glplot.remove(this.textMarkers),this.textMarkers.dispose()),this.delaunayMesh&&(this.scene.glplot.remove(this.delaunayMesh),this.delaunayMesh.dispose())},e.exports=function(t,e){var r=new v(t,e.uid);return r.update(e),r}},{\"../../components/fx/helpers\":698,\"../../constants/gl3d_dashes\":772,\"../../constants/gl3d_markers\":773,\"../../lib\":799,\"../../lib/gl_format_color\":795,\"../../lib/str2rgbarray\":823,\"../../plots/cartesian/axes\":849,\"../scatter/make_bubble_size_func\":1231,\"./calc_errors\":1244,\"delaunay-triangulate\":176,\"gl-error3d\":269,\"gl-line3d\":277,\"gl-mesh3d\":311,\"gl-scatter3d\":330}],1246:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"../scatter/subtypes\"),o=t(\"../scatter/marker_defaults\"),s=t(\"../scatter/line_defaults\"),l=t(\"../scatter/text_defaults\"),c=t(\"./attributes\");e.exports=function(t,e,r,u){function f(r,n){return i.coerce(t,e,c,r,n)}if(function(t,e,r,i){var a=0,o=r(\"x\"),s=r(\"y\"),l=r(\"z\");n.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\",\"y\",\"z\"],i),o&&s&&l&&(a=Math.min(o.length,s.length,l.length),e._length=e._xlength=e._ylength=e._zlength=a);return a}(t,e,f,u)){f(\"text\"),f(\"hovertext\"),f(\"hovertemplate\"),f(\"xhoverformat\"),f(\"yhoverformat\"),f(\"zhoverformat\"),f(\"mode\"),a.hasLines(e)&&(f(\"connectgaps\"),s(t,e,r,u,f)),a.hasMarkers(e)&&o(t,e,r,u,f,{noSelect:!0}),a.hasText(e)&&(f(\"texttemplate\"),l(t,e,u,f,{noSelect:!0}));var h=(e.line||{}).color,p=(e.marker||{}).color;f(\"surfaceaxis\")>=0&&f(\"surfacecolor\",h||p);for(var d=[\"x\",\"y\",\"z\"],m=0;m<3;++m){var g=\"projection.\"+d[m];f(g+\".show\")&&(f(g+\".opacity\"),f(g+\".scale\"))}var v=n.getComponentMethod(\"errorbars\",\"supplyDefaults\");v(t,e,h||p||r,{axis:\"z\"}),v(t,e,h||p||r,{axis:\"y\",inherit:\"z\"}),v(t,e,h||p||r,{axis:\"x\",inherit:\"z\"})}else e.visible=!1}},{\"../../lib\":799,\"../../registry\":927,\"../scatter/line_defaults\":1227,\"../scatter/marker_defaults\":1233,\"../scatter/subtypes\":1239,\"../scatter/text_defaults\":1240,\"./attributes\":1242}],1247:[function(t,e,r){\"use strict\";e.exports={plot:t(\"./convert\"),attributes:t(\"./attributes\"),markerSymbols:t(\"../../constants/gl3d_markers\"),supplyDefaults:t(\"./defaults\"),colorbar:[{container:\"marker\",min:\"cmin\",max:\"cmax\"},{container:\"line\",min:\"cmin\",max:\"cmax\"}],calc:t(\"./calc\"),moduleType:\"trace\",name:\"scatter3d\",basePlotModule:t(\"../../plots/gl3d\"),categories:[\"gl3d\",\"symbols\",\"showLegend\",\"scatter-like\"],meta:{}}},{\"../../constants/gl3d_markers\":773,\"../../plots/gl3d\":892,\"./attributes\":1242,\"./calc\":1243,\"./convert\":1245,\"./defaults\":1246}],1248:[function(t,e,r){\"use strict\";var n=t(\"../scatter/attributes\"),i=t(\"../../plots/attributes\"),a=t(\"../../plots/template_attributes\").hovertemplateAttrs,o=t(\"../../plots/template_attributes\").texttemplateAttrs,s=t(\"../../components/colorscale/attributes\"),l=t(\"../../lib/extend\").extendFlat,c=n.marker,u=n.line,f=c.line;e.exports={carpet:{valType:\"string\",editType:\"calc\"},a:{valType:\"data_array\",editType:\"calc\"},b:{valType:\"data_array\",editType:\"calc\"},mode:l({},n.mode,{dflt:\"markers\"}),text:l({},n.text,{}),texttemplate:o({editType:\"plot\"},{keys:[\"a\",\"b\",\"text\"]}),hovertext:l({},n.hovertext,{}),line:{color:u.color,width:u.width,dash:u.dash,shape:l({},u.shape,{values:[\"linear\",\"spline\"]}),smoothing:u.smoothing,editType:\"calc\"},connectgaps:n.connectgaps,fill:l({},n.fill,{values:[\"none\",\"toself\",\"tonext\"],dflt:\"none\"}),fillcolor:n.fillcolor,marker:l({symbol:c.symbol,opacity:c.opacity,maxdisplayed:c.maxdisplayed,size:c.size,sizeref:c.sizeref,sizemin:c.sizemin,sizemode:c.sizemode,line:l({width:f.width,editType:\"calc\"},s(\"marker.line\")),gradient:c.gradient,editType:\"calc\"},s(\"marker\")),textfont:n.textfont,textposition:n.textposition,selected:n.selected,unselected:n.unselected,hoverinfo:l({},i.hoverinfo,{flags:[\"a\",\"b\",\"text\",\"name\"]}),hoveron:n.hoveron,hovertemplate:a()}},{\"../../components/colorscale/attributes\":669,\"../../lib/extend\":789,\"../../plots/attributes\":845,\"../../plots/template_attributes\":922,\"../scatter/attributes\":1214}],1249:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../scatter/colorscale_calc\"),a=t(\"../scatter/arrays_to_calcdata\"),o=t(\"../scatter/calc_selection\"),s=t(\"../scatter/calc\").calcMarkerSize,l=t(\"../carpet/lookup_carpetid\");e.exports=function(t,e){var r=e._carpetTrace=l(t,e);if(r&&r.visible&&\"legendonly\"!==r.visible){var c;e.xaxis=r.xaxis,e.yaxis=r.yaxis;var u,f,h=e._length,p=new Array(h),d=!1;for(c=0;c<h;c++)if(u=e.a[c],f=e.b[c],n(u)&&n(f)){var m=r.ab2xy(+u,+f,!0),g=r.isVisible(+u,+f);g||(d=!0),p[c]={x:m[0],y:m[1],a:u,b:f,vis:g}}else p[c]={x:!1,y:!1};return e._needsCull=d,p[0].carpet=r,p[0].trace=e,s(e,h),i(t,e),a(p,e),o(p,e),p}}},{\"../carpet/lookup_carpetid\":997,\"../scatter/arrays_to_calcdata\":1213,\"../scatter/calc\":1215,\"../scatter/calc_selection\":1216,\"../scatter/colorscale_calc\":1217,\"fast-isnumeric\":245}],1250:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatter/constants\"),a=t(\"../scatter/subtypes\"),o=t(\"../scatter/marker_defaults\"),s=t(\"../scatter/line_defaults\"),l=t(\"../scatter/line_shape_defaults\"),c=t(\"../scatter/text_defaults\"),u=t(\"../scatter/fillcolor_defaults\"),f=t(\"./attributes\");e.exports=function(t,e,r,h){function p(r,i){return n.coerce(t,e,f,r,i)}p(\"carpet\"),e.xaxis=\"x\",e.yaxis=\"y\";var d=p(\"a\"),m=p(\"b\"),g=Math.min(d.length,m.length);if(g){e._length=g,p(\"text\"),p(\"texttemplate\"),p(\"hovertext\"),p(\"mode\",g<i.PTS_LINESONLY?\"lines+markers\":\"lines\"),a.hasLines(e)&&(s(t,e,r,h,p),l(t,e,p),p(\"connectgaps\")),a.hasMarkers(e)&&o(t,e,r,h,p,{gradient:!0}),a.hasText(e)&&c(t,e,h,p);var v=[];(a.hasMarkers(e)||a.hasText(e))&&(p(\"marker.maxdisplayed\"),v.push(\"points\")),p(\"fill\"),\"none\"!==e.fill&&(u(t,e,r,p),a.hasLines(e)||l(t,e,p)),\"tonext\"!==e.fill&&\"toself\"!==e.fill||v.push(\"fills\"),\"fills\"!==p(\"hoveron\",v.join(\"+\")||\"points\")&&p(\"hovertemplate\"),n.coerceSelectionMarkerOpacity(e,p)}else e.visible=!1}},{\"../../lib\":799,\"../scatter/constants\":1218,\"../scatter/fillcolor_defaults\":1222,\"../scatter/line_defaults\":1227,\"../scatter/line_shape_defaults\":1229,\"../scatter/marker_defaults\":1233,\"../scatter/subtypes\":1239,\"../scatter/text_defaults\":1240,\"./attributes\":1248}],1251:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,i){var a=n[i];return t.a=a.a,t.b=a.b,t.y=a.y,t}},{}],1252:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r={},n=e._carpet,i=n.ab2ij([t.a,t.b]),a=Math.floor(i[0]),o=i[0]-a,s=Math.floor(i[1]),l=i[1]-s,c=n.evalxy([],a,s,o,l);return r.yLabel=c[1].toFixed(3),r}},{}],1253:[function(t,e,r){\"use strict\";var n=t(\"../scatter/hover\"),i=t(\"../../lib\").fillText;e.exports=function(t,e,r,a){var o=n(t,e,r,a);if(o&&!1!==o[0].index){var s=o[0];if(void 0===s.index){var l=1-s.y0/t.ya._length,c=t.xa._length,u=c*l/2,f=c-u;return s.x0=Math.max(Math.min(s.x0,f),u),s.x1=Math.max(Math.min(s.x1,f),u),o}var h=s.cd[s.index];s.a=h.a,s.b=h.b,s.xLabelVal=void 0,s.yLabelVal=void 0;var p=s.trace,d=p._carpet,m=p._module.formatLabels(h,p);s.yLabel=m.yLabel,delete s.text;var g=[];if(!p.hovertemplate){var v=(h.hi||p.hoverinfo).split(\"+\");-1!==v.indexOf(\"all\")&&(v=[\"a\",\"b\",\"text\"]),-1!==v.indexOf(\"a\")&&y(d.aaxis,h.a),-1!==v.indexOf(\"b\")&&y(d.baxis,h.b),g.push(\"y: \"+s.yLabel),-1!==v.indexOf(\"text\")&&i(h,p,g),s.extraText=g.join(\"<br>\")}return o}function y(t,e){var r;r=t.labelprefix&&t.labelprefix.length>0?t.labelprefix.replace(/ = $/,\"\"):t._hovertitle,g.push(r+\": \"+e.toFixed(3)+t.labelsuffix)}}},{\"../../lib\":799,\"../scatter/hover\":1225}],1254:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../scatter/marker_colorbar\"),formatLabels:t(\"./format_labels\"),calc:t(\"./calc\"),plot:t(\"./plot\"),style:t(\"../scatter/style\").style,styleOnSelect:t(\"../scatter/style\").styleOnSelect,hoverPoints:t(\"./hover\"),selectPoints:t(\"../scatter/select\"),eventData:t(\"./event_data\"),moduleType:\"trace\",name:\"scattercarpet\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"svg\",\"carpet\",\"symbols\",\"showLegend\",\"carpetDependent\",\"zoomScale\"],meta:{}}},{\"../../plots/cartesian\":863,\"../scatter/marker_colorbar\":1232,\"../scatter/select\":1236,\"../scatter/style\":1238,\"./attributes\":1248,\"./calc\":1249,\"./defaults\":1250,\"./event_data\":1251,\"./format_labels\":1252,\"./hover\":1253,\"./plot\":1255}],1255:[function(t,e,r){\"use strict\";var n=t(\"../scatter/plot\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../../components/drawing\");e.exports=function(t,e,r,o){var s,l,c,u=r[0][0].carpet,f={xaxis:i.getFromId(t,u.xaxis||\"x\"),yaxis:i.getFromId(t,u.yaxis||\"y\"),plot:e.plot};for(n(t,f,r,o),s=0;s<r.length;s++)l=r[s][0].trace,c=o.selectAll(\"g.trace\"+l.uid+\" .js-line\"),a.setClipUrl(c,r[s][0].carpet._clipPathId,t)}},{\"../../components/drawing\":684,\"../../plots/cartesian/axes\":849,\"../scatter/plot\":1235}],1256:[function(t,e,r){\"use strict\";var n=t(\"../../plots/template_attributes\").hovertemplateAttrs,i=t(\"../../plots/template_attributes\").texttemplateAttrs,a=t(\"../scatter/attributes\"),o=t(\"../../plots/attributes\"),s=t(\"../../components/colorscale/attributes\"),l=t(\"../../components/drawing/attributes\").dash,c=t(\"../../lib/extend\").extendFlat,u=t(\"../../plot_api/edit_types\").overrideAll,f=a.marker,h=a.line,p=f.line;e.exports=u({lon:{valType:\"data_array\"},lat:{valType:\"data_array\"},locations:{valType:\"data_array\"},locationmode:{valType:\"enumerated\",values:[\"ISO-3\",\"USA-states\",\"country names\",\"geojson-id\"],dflt:\"ISO-3\"},geojson:{valType:\"any\",editType:\"calc\"},featureidkey:{valType:\"string\",editType:\"calc\",dflt:\"id\"},mode:c({},a.mode,{dflt:\"markers\"}),text:c({},a.text,{}),texttemplate:i({editType:\"plot\"},{keys:[\"lat\",\"lon\",\"location\",\"text\"]}),hovertext:c({},a.hovertext,{}),textfont:a.textfont,textposition:a.textposition,line:{color:h.color,width:h.width,dash:l},connectgaps:a.connectgaps,marker:c({symbol:f.symbol,opacity:f.opacity,size:f.size,sizeref:f.sizeref,sizemin:f.sizemin,sizemode:f.sizemode,colorbar:f.colorbar,line:c({width:p.width},s(\"marker.line\")),gradient:f.gradient},s(\"marker\")),fill:{valType:\"enumerated\",values:[\"none\",\"toself\"],dflt:\"none\"},fillcolor:a.fillcolor,selected:a.selected,unselected:a.unselected,hoverinfo:c({},o.hoverinfo,{flags:[\"lon\",\"lat\",\"location\",\"text\",\"name\"]}),hovertemplate:n()},\"calc\",\"nested\")},{\"../../components/colorscale/attributes\":669,\"../../components/drawing/attributes\":683,\"../../lib/extend\":789,\"../../plot_api/edit_types\":831,\"../../plots/attributes\":845,\"../../plots/template_attributes\":922,\"../scatter/attributes\":1214}],1257:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../constants/numerical\").BADNUM,a=t(\"../scatter/colorscale_calc\"),o=t(\"../scatter/arrays_to_calcdata\"),s=t(\"../scatter/calc_selection\"),l=t(\"../../lib\")._;function c(t){return t&&\"string\"==typeof t}e.exports=function(t,e){var r,u=Array.isArray(e.locations),f=u?e.locations.length:e._length,h=new Array(f);r=e.geojson?function(t){return c(t)||n(t)}:c;for(var p=0;p<f;p++){var d=h[p]={};if(u){var m=e.locations[p];d.loc=r(m)?m:null}else{var g=e.lon[p],v=e.lat[p];n(g)&&n(v)?d.lonlat=[+g,+v]:d.lonlat=[i,i]}}return o(h,e),a(t,e),s(h,e),f&&(h[0].t={labels:{lat:l(t,\"lat:\")+\" \",lon:l(t,\"lon:\")+\" \"}}),h}},{\"../../constants/numerical\":775,\"../../lib\":799,\"../scatter/arrays_to_calcdata\":1213,\"../scatter/calc_selection\":1216,\"../scatter/colorscale_calc\":1217,\"fast-isnumeric\":245}],1258:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatter/subtypes\"),a=t(\"../scatter/marker_defaults\"),o=t(\"../scatter/line_defaults\"),s=t(\"../scatter/text_defaults\"),l=t(\"../scatter/fillcolor_defaults\"),c=t(\"./attributes\");e.exports=function(t,e,r,u){function f(r,i){return n.coerce(t,e,c,r,i)}var h,p=f(\"locations\");if(p&&p.length){var d,m=f(\"geojson\");(\"string\"==typeof m&&\"\"!==m||n.isPlainObject(m))&&(d=\"geojson-id\"),\"geojson-id\"===f(\"locationmode\",d)&&f(\"featureidkey\"),h=p.length}else{var g=f(\"lon\")||[],v=f(\"lat\")||[];h=Math.min(g.length,v.length)}h?(e._length=h,f(\"text\"),f(\"hovertext\"),f(\"hovertemplate\"),f(\"mode\"),i.hasLines(e)&&(o(t,e,r,u,f),f(\"connectgaps\")),i.hasMarkers(e)&&a(t,e,r,u,f,{gradient:!0}),i.hasText(e)&&(f(\"texttemplate\"),s(t,e,u,f)),f(\"fill\"),\"none\"!==e.fill&&l(t,e,r,f),n.coerceSelectionMarkerOpacity(e,f)):e.visible=!1}},{\"../../lib\":799,\"../scatter/fillcolor_defaults\":1222,\"../scatter/line_defaults\":1227,\"../scatter/marker_defaults\":1233,\"../scatter/subtypes\":1239,\"../scatter/text_defaults\":1240,\"./attributes\":1256}],1259:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,i){t.lon=e.lon,t.lat=e.lat,t.location=e.loc?e.loc:null;var a=n[i];return a.fIn&&a.fIn.properties&&(t.properties=a.fIn.properties),t}},{}],1260:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\");e.exports=function(t,e,r){var i={},a=r[e.geo]._subplot.mockAxis,o=t.lonlat;return i.lonLabel=n.tickText(a,a.c2l(o[0]),!0).text,i.latLabel=n.tickText(a,a.c2l(o[1]),!0).text,i}},{\"../../plots/cartesian/axes\":849}],1261:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx\"),i=t(\"../../constants/numerical\").BADNUM,a=t(\"../scatter/get_trace_color\"),o=t(\"../../lib\").fillText,s=t(\"./attributes\");e.exports=function(t,e,r){var l=t.cd,c=l[0].trace,u=t.xa,f=t.ya,h=t.subplot,p=h.projection.isLonLatOverEdges,d=h.project;if(n.getClosest(l,(function(t){var n=t.lonlat;if(n[0]===i)return 1/0;if(p(n))return 1/0;var a=d(n),o=d([e,r]),s=Math.abs(a[0]-o[0]),l=Math.abs(a[1]-o[1]),c=Math.max(3,t.mrc||0);return Math.max(Math.sqrt(s*s+l*l)-c,1-3/c)}),t),!1!==t.index){var m=l[t.index],g=m.lonlat,v=[u.c2p(g),f.c2p(g)],y=m.mrc||1;t.x0=v[0]-y,t.x1=v[0]+y,t.y0=v[1]-y,t.y1=v[1]+y,t.loc=m.loc,t.lon=g[0],t.lat=g[1];var x={};x[c.geo]={_subplot:h};var b=c._module.formatLabels(m,c,x);return t.lonLabel=b.lonLabel,t.latLabel=b.latLabel,t.color=a(c,m),t.extraText=function(t,e,r,n){if(t.hovertemplate)return;var i=e.hi||t.hoverinfo,a=\"all\"===i?s.hoverinfo.flags:i.split(\"+\"),l=-1!==a.indexOf(\"location\")&&Array.isArray(t.locations),c=-1!==a.indexOf(\"lon\"),u=-1!==a.indexOf(\"lat\"),f=-1!==a.indexOf(\"text\"),h=[];function p(t){return t+\"\\xb0\"}l?h.push(e.loc):c&&u?h.push(\"(\"+p(r.latLabel)+\", \"+p(r.lonLabel)+\")\"):c?h.push(n.lon+p(r.lonLabel)):u&&h.push(n.lat+p(r.latLabel));f&&o(e,t,h);return h.join(\"<br>\")}(c,m,t,l[0].t.labels),t.hovertemplate=c.hovertemplate,[t]}}},{\"../../components/fx\":702,\"../../constants/numerical\":775,\"../../lib\":799,\"../scatter/get_trace_color\":1224,\"./attributes\":1256}],1262:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../scatter/marker_colorbar\"),formatLabels:t(\"./format_labels\"),calc:t(\"./calc\"),calcGeoJSON:t(\"./plot\").calcGeoJSON,plot:t(\"./plot\").plot,style:t(\"./style\"),styleOnSelect:t(\"../scatter/style\").styleOnSelect,hoverPoints:t(\"./hover\"),eventData:t(\"./event_data\"),selectPoints:t(\"./select\"),moduleType:\"trace\",name:\"scattergeo\",basePlotModule:t(\"../../plots/geo\"),categories:[\"geo\",\"symbols\",\"showLegend\",\"scatter-like\"],meta:{}}},{\"../../plots/geo\":882,\"../scatter/marker_colorbar\":1232,\"../scatter/style\":1238,\"./attributes\":1256,\"./calc\":1257,\"./defaults\":1258,\"./event_data\":1259,\"./format_labels\":1260,\"./hover\":1261,\"./plot\":1263,\"./select\":1264,\"./style\":1265}],1263:[function(t,e,r){\"use strict\";var n=t(\"@plotly/d3\"),i=t(\"../../lib\"),a=t(\"../../lib/topojson_utils\").getTopojsonFeatures,o=t(\"../../lib/geojson_utils\"),s=t(\"../../lib/geo_location_utils\"),l=t(\"../../plots/cartesian/autorange\").findExtremes,c=t(\"../../constants/numerical\").BADNUM,u=t(\"../scatter/calc\").calcMarkerSize,f=t(\"../scatter/subtypes\"),h=t(\"./style\");e.exports={calcGeoJSON:function(t,e){var r,n,i=t[0].trace,o=e[i.geo],f=o._subplot,h=i._length;if(Array.isArray(i.locations)){var p=i.locationmode,d=\"geojson-id\"===p?s.extractTraceFeature(t):a(i,f.topojson);for(r=0;r<h;r++){n=t[r];var m=\"geojson-id\"===p?n.fOut:s.locationToFeature(p,n.loc,d);n.lonlat=m?m.properties.ct:[c,c]}}var g,v,y={padded:!0};if(\"geojson\"===o.fitbounds&&\"geojson-id\"===i.locationmode){var x=s.computeBbox(s.getTraceGeojson(i));g=[x[0],x[2]],v=[x[1],x[3]]}else{for(g=new Array(h),v=new Array(h),r=0;r<h;r++)n=t[r],g[r]=n.lonlat[0],v[r]=n.lonlat[1];y.ppad=u(i,h)}i._extremes.lon=l(o.lonaxis._ax,g,y),i._extremes.lat=l(o.lataxis._ax,v,y)},plot:function(t,e,r){var a=e.layers.frontplot.select(\".scatterlayer\"),s=i.makeTraceGroups(a,r,\"trace scattergeo\");function l(t,e){t.lonlat[0]===c&&n.select(e).remove()}s.selectAll(\"*\").remove(),s.each((function(e){var r=n.select(this),a=e[0].trace;if(f.hasLines(a)||\"none\"!==a.fill){var s=o.calcTraceToLineCoords(e),c=\"none\"!==a.fill?o.makePolygon(s):o.makeLine(s);r.selectAll(\"path.js-line\").data([{geojson:c,trace:a}]).enter().append(\"path\").classed(\"js-line\",!0).style(\"stroke-miterlimit\",2)}f.hasMarkers(a)&&r.selectAll(\"path.point\").data(i.identity).enter().append(\"path\").classed(\"point\",!0).each((function(t){l(t,this)})),f.hasText(a)&&r.selectAll(\"g\").data(i.identity).enter().append(\"g\").append(\"text\").each((function(t){l(t,this)})),h(t,e)}))}}},{\"../../constants/numerical\":775,\"../../lib\":799,\"../../lib/geo_location_utils\":792,\"../../lib/geojson_utils\":793,\"../../lib/topojson_utils\":827,\"../../plots/cartesian/autorange\":848,\"../scatter/calc\":1215,\"../scatter/subtypes\":1239,\"./style\":1265,\"@plotly/d3\":58}],1264:[function(t,e,r){\"use strict\";var n=t(\"../scatter/subtypes\"),i=t(\"../../constants/numerical\").BADNUM;e.exports=function(t,e){var r,a,o,s,l,c=t.cd,u=t.xaxis,f=t.yaxis,h=[],p=c[0].trace;if(!n.hasMarkers(p)&&!n.hasText(p))return[];if(!1===e)for(l=0;l<c.length;l++)c[l].selected=0;else for(l=0;l<c.length;l++)(a=(r=c[l]).lonlat)[0]!==i&&(o=u.c2p(a),s=f.c2p(a),e.contains([o,s],null,l,t)?(h.push({pointNumber:l,lon:a[0],lat:a[1]}),r.selected=1):r.selected=0);return h}},{\"../../constants/numerical\":775,\"../scatter/subtypes\":1239}],1265:[function(t,e,r){\"use strict\";var n=t(\"@plotly/d3\"),i=t(\"../../components/drawing\"),a=t(\"../../components/color\"),o=t(\"../scatter/style\"),s=o.stylePoints,l=o.styleText;e.exports=function(t,e){e&&function(t,e){var r=e[0].trace,o=e[0].node3;o.style(\"opacity\",e[0].trace.opacity),s(o,r,t),l(o,r,t),o.selectAll(\"path.js-line\").style(\"fill\",\"none\").each((function(t){var e=n.select(this),r=t.trace,o=r.line||{};e.call(a.stroke,o.color).call(i.dashLine,o.dash||\"\",o.width||0),\"none\"!==r.fill&&e.call(a.fill,r.fillcolor)}))}(t,e)}},{\"../../components/color\":662,\"../../components/drawing\":684,\"../scatter/style\":1238,\"@plotly/d3\":58}],1266:[function(t,e,r){\"use strict\";var n=t(\"../../plots/attributes\"),i=t(\"../scatter/attributes\"),a=t(\"../../plots/cartesian/axis_format_attributes\").axisHoverFormat,o=t(\"../../components/colorscale/attributes\"),s=t(\"../../lib/extend\").extendFlat,l=t(\"../../plot_api/edit_types\").overrideAll,c=t(\"./constants\").DASHES,u=i.line,f=i.marker,h=f.line,p=e.exports=l({x:i.x,x0:i.x0,dx:i.dx,y:i.y,y0:i.y0,dy:i.dy,xperiod:i.xperiod,yperiod:i.yperiod,xperiod0:i.xperiod0,yperiod0:i.yperiod0,xperiodalignment:i.xperiodalignment,yperiodalignment:i.yperiodalignment,xhoverformat:a(\"x\"),yhoverformat:a(\"y\"),text:i.text,hovertext:i.hovertext,textposition:i.textposition,textfont:i.textfont,mode:{valType:\"flaglist\",flags:[\"lines\",\"markers\",\"text\"],extras:[\"none\"]},line:{color:u.color,width:u.width,shape:{valType:\"enumerated\",values:[\"linear\",\"hv\",\"vh\",\"hvh\",\"vhv\"],dflt:\"linear\",editType:\"plot\"},dash:{valType:\"enumerated\",values:Object.keys(c),dflt:\"solid\"}},marker:s({},o(\"marker\"),{symbol:f.symbol,size:f.size,sizeref:f.sizeref,sizemin:f.sizemin,sizemode:f.sizemode,opacity:f.opacity,colorbar:f.colorbar,line:s({},o(\"marker.line\"),{width:h.width})}),connectgaps:i.connectgaps,fill:s({},i.fill,{dflt:\"none\"}),fillcolor:i.fillcolor,selected:{marker:i.selected.marker,textfont:i.selected.textfont},unselected:{marker:i.unselected.marker,textfont:i.unselected.textfont},opacity:n.opacity},\"calc\",\"nested\");p.x.editType=p.y.editType=p.x0.editType=p.y0.editType=\"calc+clearAxisTypes\",p.hovertemplate=i.hovertemplate,p.texttemplate=i.texttemplate},{\"../../components/colorscale/attributes\":669,\"../../lib/extend\":789,\"../../plot_api/edit_types\":831,\"../../plots/attributes\":845,\"../../plots/cartesian/axis_format_attributes\":852,\"../scatter/attributes\":1214,\"./constants\":1268}],1267:[function(t,e,r){\"use strict\";var n=t(\"@plotly/point-cluster\"),i=t(\"../../lib\"),a=t(\"../../plots/cartesian/axis_ids\"),o=t(\"../../plots/cartesian/autorange\").findExtremes,s=t(\"../../plots/cartesian/align_period\"),l=t(\"../scatter/calc\"),c=l.calcMarkerSize,u=l.calcAxisExpansion,f=l.setFirstScatter,h=t(\"../scatter/colorscale_calc\"),p=t(\"./convert\"),d=t(\"./scene_update\"),m=t(\"../../constants/numerical\").BADNUM,g=t(\"./constants\").TOO_MANY_POINTS;function v(t,e,r){var n=t._extremes[e._id],i=o(e,r._bnds,{padded:!0});n.min=n.min.concat(i.min),n.max=n.max.concat(i.max)}e.exports=function(t,e){var r,o=t._fullLayout,l=a.getFromId(t,e.xaxis),y=a.getFromId(t,e.yaxis),x=o._plots[e.xaxis+e.yaxis],b=e._length,_=b>=g,w=2*b,T={},k=l.makeCalcdata(e,\"x\"),M=y.makeCalcdata(e,\"y\"),A=s(e,l,\"x\",k),S=s(e,y,\"y\",M);e._x=A,e._y=S,e.xperiodalignment&&(e._origX=k),e.yperiodalignment&&(e._origY=M);var E=new Array(w),L=new Array(b);for(r=0;r<b;r++)E[2*r]=A[r]===m?NaN:A[r],E[2*r+1]=S[r]===m?NaN:S[r],L[r]=r;if(\"log\"===l.type)for(r=0;r<w;r+=2)E[r]=l.c2l(E[r]);if(\"log\"===y.type)for(r=1;r<w;r+=2)E[r]=y.c2l(E[r]);_&&\"log\"!==l.type&&\"log\"!==y.type?T.tree=n(E):T.ids=L,h(t,e);var C,P=function(t,e,r,n,a,o){var s=p.style(t,r);s.marker&&(s.marker.positions=n);s.line&&n.length>1&&i.extendFlat(s.line,p.linePositions(t,r,n));if(s.errorX||s.errorY){var l=p.errorBarPositions(t,r,n,a,o);s.errorX&&i.extendFlat(s.errorX,l.x),s.errorY&&i.extendFlat(s.errorY,l.y)}s.text&&(i.extendFlat(s.text,{positions:n},p.textPosition(t,r,s.text,s.marker)),i.extendFlat(s.textSel,{positions:n},p.textPosition(t,r,s.text,s.markerSel)),i.extendFlat(s.textUnsel,{positions:n},p.textPosition(t,r,s.text,s.markerUnsel)));return s}(t,0,e,E,A,S),I=d(t,x);return f(o,e),_?P.marker&&(C=2*(P.marker.sizeAvg||Math.max(P.marker.size,3))):C=c(e,b),u(t,e,l,y,A,S,C),P.errorX&&v(e,l,P.errorX),P.errorY&&v(e,y,P.errorY),P.fill&&!I.fill2d&&(I.fill2d=!0),P.marker&&!I.scatter2d&&(I.scatter2d=!0),P.line&&!I.line2d&&(I.line2d=!0),!P.errorX&&!P.errorY||I.error2d||(I.error2d=!0),P.text&&!I.glText&&(I.glText=!0),P.marker&&(P.marker.snap=b),I.lineOptions.push(P.line),I.errorXOptions.push(P.errorX),I.errorYOptions.push(P.errorY),I.fillOptions.push(P.fill),I.markerOptions.push(P.marker),I.markerSelectedOptions.push(P.markerSel),I.markerUnselectedOptions.push(P.markerUnsel),I.textOptions.push(P.text),I.textSelectedOptions.push(P.textSel),I.textUnselectedOptions.push(P.textUnsel),I.selectBatch.push([]),I.unselectBatch.push([]),T._scene=I,T.index=I.count,T.x=A,T.y=S,T.positions=E,I.count++,[{x:!1,y:!1,t:T,trace:e}]}},{\"../../constants/numerical\":775,\"../../lib\":799,\"../../plots/cartesian/align_period\":846,\"../../plots/cartesian/autorange\":848,\"../../plots/cartesian/axis_ids\":853,\"../scatter/calc\":1215,\"../scatter/colorscale_calc\":1217,\"./constants\":1268,\"./convert\":1269,\"./scene_update\":1277,\"@plotly/point-cluster\":59}],1268:[function(t,e,r){\"use strict\";e.exports={TOO_MANY_POINTS:1e5,SYMBOL_SDF_SIZE:200,SYMBOL_SIZE:20,SYMBOL_STROKE:1,DOT_RE:/-dot/,OPEN_RE:/-open/,DASHES:{solid:[1],dot:[1,1],dash:[4,1],longdash:[8,1],dashdot:[4,1,1,1],longdashdot:[8,1,1,1]}}},{}],1269:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"svg-path-sdf\"),a=t(\"color-normalize\"),o=t(\"../../registry\"),s=t(\"../../lib\"),l=t(\"../../components/drawing\"),c=t(\"../../plots/cartesian/axis_ids\"),u=t(\"../../lib/gl_format_color\").formatColor,f=t(\"../scatter/subtypes\"),h=t(\"../scatter/make_bubble_size_func\"),p=t(\"./helpers\"),d=t(\"./constants\"),m=t(\"../../constants/interactions\").DESELECTDIM,g={start:1,left:1,end:-1,right:-1,middle:0,center:0,bottom:1,top:-1},v=t(\"../../components/fx/helpers\").appendArrayPointValue;function y(t,e){var r,i=t._fullLayout,a=e._length,o=e.textfont,l=e.textposition,c=Array.isArray(l)?l:[l],u=o.color,f=o.size,h=o.family,p={},d=e.texttemplate;if(d){p.text=[];var m=i._d3locale,g=Array.isArray(d),y=g?Math.min(d.length,a):a,x=g?function(t){return d[t]}:function(){return d};for(r=0;r<y;r++){var b={i:r},_=e._module.formatLabels(b,e,i),w={};v(w,e,r);var T=e._meta||{};p.text.push(s.texttemplateString(x(r),_,m,w,b,T))}}else Array.isArray(e.text)&&e.text.length<a?p.text=e.text.slice():p.text=e.text;if(Array.isArray(p.text))for(r=p.text.length;r<a;r++)p.text[r]=\"\";for(p.opacity=e.opacity,p.font={},p.align=[],p.baseline=[],r=0;r<c.length;r++){var k=c[r].split(/\\s+/);switch(k[1]){case\"left\":p.align.push(\"right\");break;case\"right\":p.align.push(\"left\");break;default:p.align.push(k[1])}switch(k[0]){case\"top\":p.baseline.push(\"bottom\");break;case\"bottom\":p.baseline.push(\"top\");break;default:p.baseline.push(k[0])}}if(Array.isArray(u))for(p.color=new Array(a),r=0;r<a;r++)p.color[r]=u[r];else p.color=u;if(s.isArrayOrTypedArray(f)||Array.isArray(h))for(p.font=new Array(a),r=0;r<a;r++){var M=p.font[r]={};M.size=s.isTypedArray(f)?f[r]:Array.isArray(f)?n(f[r])?f[r]:0:f,M.family=Array.isArray(h)?h[r]:h}else p.font={size:f,family:h};return p}function x(t){var e,r,n=t._length,i=t.marker,o={},l=s.isArrayOrTypedArray(i.symbol),c=s.isArrayOrTypedArray(i.color),f=s.isArrayOrTypedArray(i.line.color),d=s.isArrayOrTypedArray(i.opacity),m=s.isArrayOrTypedArray(i.size),g=s.isArrayOrTypedArray(i.line.width);if(l||(r=p.isOpenSymbol(i.symbol)),l||c||f||d){o.colors=new Array(n),o.borderColors=new Array(n);var v=u(i,i.opacity,n),y=u(i.line,i.opacity,n);if(!Array.isArray(y[0])){var x=y;for(y=Array(n),e=0;e<n;e++)y[e]=x}if(!Array.isArray(v[0])){var b=v;for(v=Array(n),e=0;e<n;e++)v[e]=b}for(o.colors=v,o.borderColors=y,e=0;e<n;e++){if(l){var _=i.symbol[e];r=p.isOpenSymbol(_)}r&&(y[e]=v[e].slice(),v[e]=v[e].slice(),v[e][3]=0)}o.opacity=t.opacity}else r?(o.color=a(i.color,\"uint8\"),o.color[3]=0,o.borderColor=a(i.color,\"uint8\")):(o.color=a(i.color,\"uint8\"),o.borderColor=a(i.line.color,\"uint8\")),o.opacity=t.opacity*i.opacity;if(l)for(o.markers=new Array(n),e=0;e<n;e++)o.markers[e]=E(i.symbol[e]);else o.marker=E(i.symbol);var w,T=h(t);if(m||g){var k,M=o.sizes=new Array(n),A=o.borderSizes=new Array(n),S=0;if(m){for(e=0;e<n;e++)M[e]=T(i.size[e]),S+=M[e];k=S/n}else for(w=T(i.size),e=0;e<n;e++)M[e]=w;if(g)for(e=0;e<n;e++)A[e]=i.line.width[e]/2;else for(w=i.line.width/2,e=0;e<n;e++)A[e]=w;o.sizeAvg=k}else o.size=T(i&&i.size||10),o.borderSizes=T(i.line.width);return o}function b(t,e){var r=t.marker,n={};return e?(e.marker&&e.marker.symbol?n=x(s.extendFlat({},r,e.marker)):e.marker&&(e.marker.size&&(n.size=e.marker.size/2),e.marker.color&&(n.colors=e.marker.color),void 0!==e.marker.opacity&&(n.opacity=e.marker.opacity)),n):n}function _(t,e,r){var n={};if(!r)return n;if(r.textfont){var i={opacity:1,text:e.text,texttemplate:e.texttemplate,textposition:e.textposition,textfont:s.extendFlat({},e.textfont)};r.textfont&&s.extendFlat(i.textfont,r.textfont),n=y(t,i)}return n}function w(t,e){var r={capSize:2*e.width,lineWidth:e.thickness,color:e.color};return e.copy_ystyle&&(r=t.error_y),r}var T=d.SYMBOL_SDF_SIZE,k=d.SYMBOL_SIZE,M=d.SYMBOL_STROKE,A={},S=l.symbolFuncs[0](.05*k);function E(t){if(\"circle\"===t)return null;var e,r,n=l.symbolNumber(t),a=l.symbolFuncs[n%100],o=!!l.symbolNoDot[n%100],s=!!l.symbolNoFill[n%100],c=p.isDotSymbol(t);return A[t]?A[t]:(e=c&&!o?a(1.1*k)+S:a(k),r=i(e,{w:T,h:T,viewBox:[-k,-k,k,k],stroke:s?M:-M}),A[t]=r,r||null)}e.exports={style:function(t,e){var r,n={marker:void 0,markerSel:void 0,markerUnsel:void 0,line:void 0,fill:void 0,errorX:void 0,errorY:void 0,text:void 0,textSel:void 0,textUnsel:void 0};if(!0!==e.visible)return n;if(f.hasText(e)&&(n.text=y(t,e),n.textSel=_(t,e,e.selected),n.textUnsel=_(t,e,e.unselected)),f.hasMarkers(e)&&(n.marker=x(e),n.markerSel=b(e,e.selected),n.markerUnsel=b(e,e.unselected),!e.unselected&&s.isArrayOrTypedArray(e.marker.opacity))){var i=e.marker.opacity;for(n.markerUnsel.opacity=new Array(i.length),r=0;r<i.length;r++)n.markerUnsel.opacity[r]=m*i[r]}if(f.hasLines(e)){n.line={overlay:!0,thickness:e.line.width,color:e.line.color,opacity:e.opacity};var a=(d.DASHES[e.line.dash]||[1]).slice();for(r=0;r<a.length;++r)a[r]*=e.line.width;n.line.dashes=a}return e.error_x&&e.error_x.visible&&(n.errorX=w(e,e.error_x)),e.error_y&&e.error_y.visible&&(n.errorY=w(e,e.error_y)),e.fill&&\"none\"!==e.fill&&(n.fill={closed:!0,fill:e.fillcolor,thickness:0}),n},markerStyle:x,markerSelection:b,linePositions:function(t,e,r){var n,i,a=r.length,o=a/2;if(f.hasLines(e)&&o)if(\"hv\"===e.line.shape){for(n=[],i=0;i<o-1;i++)isNaN(r[2*i])||isNaN(r[2*i+1])?n.push(NaN,NaN,NaN,NaN):(n.push(r[2*i],r[2*i+1]),isNaN(r[2*i+2])||isNaN(r[2*i+3])?n.push(NaN,NaN):n.push(r[2*i+2],r[2*i+1]));n.push(r[a-2],r[a-1])}else if(\"hvh\"===e.line.shape){for(n=[],i=0;i<o-1;i++)if(isNaN(r[2*i])||isNaN(r[2*i+1])||isNaN(r[2*i+2])||isNaN(r[2*i+3]))isNaN(r[2*i])||isNaN(r[2*i+1])?n.push(NaN,NaN):n.push(r[2*i],r[2*i+1]),n.push(NaN,NaN);else{var s=(r[2*i]+r[2*i+2])/2;n.push(r[2*i],r[2*i+1],s,r[2*i+1],s,r[2*i+3])}n.push(r[a-2],r[a-1])}else if(\"vhv\"===e.line.shape){for(n=[],i=0;i<o-1;i++)if(isNaN(r[2*i])||isNaN(r[2*i+1])||isNaN(r[2*i+2])||isNaN(r[2*i+3]))isNaN(r[2*i])||isNaN(r[2*i+1])?n.push(NaN,NaN):n.push(r[2*i],r[2*i+1]),n.push(NaN,NaN);else{var l=(r[2*i+1]+r[2*i+3])/2;n.push(r[2*i],r[2*i+1],r[2*i],l,r[2*i+2],l)}n.push(r[a-2],r[a-1])}else if(\"vh\"===e.line.shape){for(n=[],i=0;i<o-1;i++)isNaN(r[2*i])||isNaN(r[2*i+1])?n.push(NaN,NaN,NaN,NaN):(n.push(r[2*i],r[2*i+1]),isNaN(r[2*i+2])||isNaN(r[2*i+3])?n.push(NaN,NaN):n.push(r[2*i],r[2*i+3]));n.push(r[a-2],r[a-1])}else n=r;var c=!1;for(i=0;i<n.length;i++)if(isNaN(n[i])){c=!0;break}var u=c||n.length>d.TOO_MANY_POINTS||f.hasMarkers(e)?\"rect\":\"round\";if(c&&e.connectgaps){var h=n[0],p=n[1];for(i=0;i<n.length;i+=2)isNaN(n[i])||isNaN(n[i+1])?(n[i]=h,n[i+1]=p):(h=n[i],p=n[i+1])}return{join:u,positions:n}},errorBarPositions:function(t,e,r,i,a){var s=o.getComponentMethod(\"errorbars\",\"makeComputeError\"),l=c.getFromId(t,e.xaxis),u=c.getFromId(t,e.yaxis),f=r.length/2,h={};function p(t,i){var a=i._id.charAt(0),o=e[\"error_\"+a];if(o&&o.visible&&(\"linear\"===i.type||\"log\"===i.type)){for(var l=s(o),c={x:0,y:1}[a],u={x:[0,1,2,3],y:[2,3,0,1]}[a],p=new Float64Array(4*f),d=1/0,m=-1/0,g=0,v=0;g<f;g++,v+=4){var y=t[g];if(n(y)){var x=r[2*g+c],b=l(y,g),_=b[0],w=b[1];if(n(_)&&n(w)){var T=y-_,k=y+w;p[v+u[0]]=x-i.c2l(T),p[v+u[1]]=i.c2l(k)-x,p[v+u[2]]=0,p[v+u[3]]=0,d=Math.min(d,y-_),m=Math.max(m,y+w)}}}h[a]={positions:r,errors:p,_bnds:[d,m]}}}return p(i,l),p(a,u),h},textPosition:function(t,e,r,n){var i,a=e._length,o={};if(f.hasMarkers(e)){var s=r.font,l=r.align,c=r.baseline;for(o.offset=new Array(a),i=0;i<a;i++){var u=n.sizes?n.sizes[i]:n.size,h=Array.isArray(s)?s[i].size:s.size,p=Array.isArray(l)?l.length>1?l[i]:l[0]:l,d=Array.isArray(c)?c.length>1?c[i]:c[0]:c,m=g[p],v=g[d],y=u?u/.8+1:0,x=-v*y-.5*v;o.offset[i]=[m*y/h,x/h]}}return o}}},{\"../../components/drawing\":684,\"../../components/fx/helpers\":698,\"../../constants/interactions\":774,\"../../lib\":799,\"../../lib/gl_format_color\":795,\"../../plots/cartesian/axis_ids\":853,\"../../registry\":927,\"../scatter/make_bubble_size_func\":1231,\"../scatter/subtypes\":1239,\"./constants\":1268,\"./helpers\":1273,\"color-normalize\":131,\"fast-isnumeric\":245,\"svg-path-sdf\":591}],1270:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../registry\"),a=t(\"./helpers\"),o=t(\"./attributes\"),s=t(\"../scatter/constants\"),l=t(\"../scatter/subtypes\"),c=t(\"../scatter/xy_defaults\"),u=t(\"../scatter/period_defaults\"),f=t(\"../scatter/marker_defaults\"),h=t(\"../scatter/line_defaults\"),p=t(\"../scatter/fillcolor_defaults\"),d=t(\"../scatter/text_defaults\");e.exports=function(t,e,r,m){function g(r,i){return n.coerce(t,e,o,r,i)}var v=!!t.marker&&a.isOpenSymbol(t.marker.symbol),y=l.isBubble(t),x=c(t,e,m,g);if(x){u(t,e,m,g),g(\"xhoverformat\"),g(\"yhoverformat\");var b=x<s.PTS_LINESONLY?\"lines+markers\":\"lines\";g(\"text\"),g(\"hovertext\"),g(\"hovertemplate\"),g(\"mode\",b),l.hasLines(e)&&(g(\"connectgaps\"),h(t,e,r,m,g),g(\"line.shape\")),l.hasMarkers(e)&&(f(t,e,r,m,g),g(\"marker.line.width\",v||y?1:0)),l.hasText(e)&&(g(\"texttemplate\"),d(t,e,m,g));var _=(e.line||{}).color,w=(e.marker||{}).color;g(\"fill\"),\"none\"!==e.fill&&p(t,e,r,g);var T=i.getComponentMethod(\"errorbars\",\"supplyDefaults\");T(t,e,_||w||r,{axis:\"y\"}),T(t,e,_||w||r,{axis:\"x\",inherit:\"y\"}),n.coerceSelectionMarkerOpacity(e,g)}else e.visible=!1}},{\"../../lib\":799,\"../../registry\":927,\"../scatter/constants\":1218,\"../scatter/fillcolor_defaults\":1222,\"../scatter/line_defaults\":1227,\"../scatter/marker_defaults\":1233,\"../scatter/period_defaults\":1234,\"../scatter/subtypes\":1239,\"../scatter/text_defaults\":1240,\"../scatter/xy_defaults\":1241,\"./attributes\":1266,\"./helpers\":1273}],1271:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/color\"),a=t(\"../../constants/interactions\").DESELECTDIM;e.exports={styleTextSelection:function(t){var e,r,o=t[0],s=o.trace,l=o.t,c=l._scene,u=l.index,f=c.selectBatch[u],h=c.unselectBatch[u],p=c.textOptions[u],d=c.textSelectedOptions[u]||{},m=c.textUnselectedOptions[u]||{},g=n.extendFlat({},p);if(f.length||h.length){var v=d.color,y=m.color,x=p.color,b=Array.isArray(x);for(g.color=new Array(s._length),e=0;e<f.length;e++)r=f[e],g.color[r]=v||(b?x[r]:x);for(e=0;e<h.length;e++){r=h[e];var _=b?x[r]:x;g.color[r]=y||(v?_:i.addOpacity(_,a))}}c.glText[u].update(g)}}},{\"../../components/color\":662,\"../../constants/interactions\":774,\"../../lib\":799}],1272:[function(t,e,r){\"use strict\";var n=t(\"../scatter/format_labels\");e.exports=function(t,e,r){var i=t.i;return\"x\"in t||(t.x=e._x[i]),\"y\"in t||(t.y=e._y[i]),n(t,e,r)}},{\"../scatter/format_labels\":1223}],1273:[function(t,e,r){\"use strict\";var n=t(\"./constants\");r.isOpenSymbol=function(t){return\"string\"==typeof t?n.OPEN_RE.test(t):t%200>100},r.isDotSymbol=function(t){return\"string\"==typeof t?n.DOT_RE.test(t):t>200}},{\"./constants\":1268}],1274:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"../scatter/get_trace_color\");function o(t,e,r,o){var s=t.xa,l=t.ya,c=t.distance,u=t.dxy,f=t.index,h={pointNumber:f,x:e[f],y:r[f]};h.tx=Array.isArray(o.text)?o.text[f]:o.text,h.htx=Array.isArray(o.hovertext)?o.hovertext[f]:o.hovertext,h.data=Array.isArray(o.customdata)?o.customdata[f]:o.customdata,h.tp=Array.isArray(o.textposition)?o.textposition[f]:o.textposition;var p=o.textfont;p&&(h.ts=i.isArrayOrTypedArray(p.size)?p.size[f]:p.size,h.tc=Array.isArray(p.color)?p.color[f]:p.color,h.tf=Array.isArray(p.family)?p.family[f]:p.family);var d=o.marker;d&&(h.ms=i.isArrayOrTypedArray(d.size)?d.size[f]:d.size,h.mo=i.isArrayOrTypedArray(d.opacity)?d.opacity[f]:d.opacity,h.mx=i.isArrayOrTypedArray(d.symbol)?d.symbol[f]:d.symbol,h.mc=i.isArrayOrTypedArray(d.color)?d.color[f]:d.color);var m=d&&d.line;m&&(h.mlc=Array.isArray(m.color)?m.color[f]:m.color,h.mlw=i.isArrayOrTypedArray(m.width)?m.width[f]:m.width);var g=d&&d.gradient;g&&\"none\"!==g.type&&(h.mgt=Array.isArray(g.type)?g.type[f]:g.type,h.mgc=Array.isArray(g.color)?g.color[f]:g.color);var v=s.c2p(h.x,!0),y=l.c2p(h.y,!0),x=h.mrc||1,b=o.hoverlabel;b&&(h.hbg=Array.isArray(b.bgcolor)?b.bgcolor[f]:b.bgcolor,h.hbc=Array.isArray(b.bordercolor)?b.bordercolor[f]:b.bordercolor,h.hts=i.isArrayOrTypedArray(b.font.size)?b.font.size[f]:b.font.size,h.htc=Array.isArray(b.font.color)?b.font.color[f]:b.font.color,h.htf=Array.isArray(b.font.family)?b.font.family[f]:b.font.family,h.hnl=i.isArrayOrTypedArray(b.namelength)?b.namelength[f]:b.namelength);var _=o.hoverinfo;_&&(h.hi=Array.isArray(_)?_[f]:_);var w=o.hovertemplate;w&&(h.ht=Array.isArray(w)?w[f]:w);var T={};T[t.index]=h;var k=o._origX,M=o._origY,A=i.extendFlat({},t,{color:a(o,h),x0:v-x,x1:v+x,xLabelVal:k?k[f]:h.x,y0:y-x,y1:y+x,yLabelVal:M?M[f]:h.y,cd:T,distance:c,spikeDistance:u,hovertemplate:h.ht});return h.htx?A.text=h.htx:h.tx?A.text=h.tx:o.text&&(A.text=o.text),i.fillText(h,o,A),n.getComponentMethod(\"errorbars\",\"hoverInfo\")(h,o,A),A}e.exports={hoverPoints:function(t,e,r,n){var i,a,s,l,c,u,f,h,p,d=t.cd,m=d[0].t,g=d[0].trace,v=t.xa,y=t.ya,x=m.x,b=m.y,_=v.c2p(e),w=y.c2p(r),T=t.distance;if(m.tree){var k=v.p2c(_-T),M=v.p2c(_+T),A=y.p2c(w-T),S=y.p2c(w+T);i=\"x\"===n?m.tree.range(Math.min(k,M),Math.min(y._rl[0],y._rl[1]),Math.max(k,M),Math.max(y._rl[0],y._rl[1])):m.tree.range(Math.min(k,M),Math.min(A,S),Math.max(k,M),Math.max(A,S))}else i=m.ids;var E=T;if(\"x\"===n)for(c=0;c<i.length;c++)s=x[i[c]],u=Math.abs(v.c2p(s)-_),g._origX&&void 0!==g._origX[c]&&(u+=v.c2p(g._origX[c])-v.c2p(s)),u<E&&(E=u,f=y.c2p(b[i[c]])-w,g._origY&&void 0!==g._origY[c]&&(f+=y.c2p(g._origY[c])-y.c2p(l)),p=Math.sqrt(u*u+f*f),a=i[c]);else for(c=i.length-1;c>-1;c--)s=x[i[c]],l=b[i[c]],u=v.c2p(s)-_,f=y.c2p(l)-w,(h=Math.sqrt(u*u+f*f))<E&&(E=p=h,a=i[c]);return t.index=a,t.distance=E,t.dxy=p,void 0===a?[t]:[o(t,x,b,g)]},calcHover:o}},{\"../../lib\":799,\"../../registry\":927,\"../scatter/get_trace_color\":1224}],1275:[function(t,e,r){\"use strict\";var n=t(\"./hover\");e.exports={moduleType:\"trace\",name:\"scattergl\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"gl\",\"regl\",\"cartesian\",\"symbols\",\"errorBarsOK\",\"showLegend\",\"scatter-like\"],attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),crossTraceDefaults:t(\"../scatter/cross_trace_defaults\"),colorbar:t(\"../scatter/marker_colorbar\"),formatLabels:t(\"./format_labels\"),calc:t(\"./calc\"),plot:t(\"./plot\"),hoverPoints:n.hoverPoints,selectPoints:t(\"./select\"),meta:{}}},{\"../../plots/cartesian\":863,\"../scatter/cross_trace_defaults\":1220,\"../scatter/marker_colorbar\":1232,\"./attributes\":1266,\"./calc\":1267,\"./defaults\":1270,\"./format_labels\":1272,\"./hover\":1274,\"./plot\":1276,\"./select\":1278}],1276:[function(t,e,r){\"use strict\";var n=t(\"regl-scatter2d\"),i=t(\"regl-line2d\"),a=t(\"regl-error2d\"),o=t(\"gl-text\"),s=t(\"../../lib\"),l=t(\"../../components/dragelement/helpers\").selectMode,c=t(\"../../lib/prepare_regl\"),u=t(\"../scatter/subtypes\"),f=t(\"../scatter/link_traces\"),h=t(\"./edit_style\").styleTextSelection;function p(t,e,r){var n=t._size,i=t.width,a=t.height;return[n.l+e.domain[0]*n.w,n.b+r.domain[0]*n.h,i-n.r-(1-e.domain[1])*n.w,a-n.t-(1-r.domain[1])*n.h]}e.exports=function(t,e,r){if(r.length){var d,m,g=t._fullLayout,v=e._scene,y=e.xaxis,x=e.yaxis;if(v)if(c(t,[\"ANGLE_instanced_arrays\",\"OES_element_index_uint\"])){var b=v.count,_=g._glcanvas.data()[0].regl;if(f(t,e,r),v.dirty){if(!0===v.error2d&&(v.error2d=a(_)),!0===v.line2d&&(v.line2d=i(_)),!0===v.scatter2d&&(v.scatter2d=n(_,{constPointSize:!0})),!0===v.fill2d&&(v.fill2d=i(_)),!0===v.glText)for(v.glText=new Array(b),d=0;d<b;d++)v.glText[d]=new o(_);if(v.glText){if(b>v.glText.length){var w=b-v.glText.length;for(d=0;d<w;d++)v.glText.push(new o(_))}else if(b<v.glText.length){var T=v.glText.length-b;v.glText.splice(b,T).forEach((function(t){t.destroy()}))}for(d=0;d<b;d++)v.glText[d].update(v.textOptions[d])}if(v.line2d&&(v.line2d.update(v.lineOptions),v.lineOptions=v.lineOptions.map((function(t){if(t&&t.positions){for(var e=t.positions,r=0;r<e.length&&(isNaN(e[r])||isNaN(e[r+1]));)r+=2;for(var n=e.length-2;n>r&&(isNaN(e[n])||isNaN(e[n+1]));)n-=2;t.positions=e.slice(r,n+2)}return t})),v.line2d.update(v.lineOptions)),v.error2d){var k=(v.errorXOptions||[]).concat(v.errorYOptions||[]);v.error2d.update(k)}v.scatter2d&&v.scatter2d.update(v.markerOptions),v.fillOrder=s.repeat(null,b),v.fill2d&&(v.fillOptions=v.fillOptions.map((function(t,e){var n=r[e];if(t&&n&&n[0]&&n[0].trace){var i,a,o=n[0],s=o.trace,l=o.t,c=v.lineOptions[e],u=[];s._ownfill&&u.push(e),s._nexttrace&&u.push(e+1),u.length&&(v.fillOrder[e]=u);var f,h,p=[],d=c&&c.positions||l.positions;if(\"tozeroy\"===s.fill){for(f=0;f<d.length&&isNaN(d[f+1]);)f+=2;for(h=d.length-2;h>f&&isNaN(d[h+1]);)h-=2;0!==d[f+1]&&(p=[d[f],0]),p=p.concat(d.slice(f,h+2)),0!==d[h+1]&&(p=p.concat([d[h],0]))}else if(\"tozerox\"===s.fill){for(f=0;f<d.length&&isNaN(d[f]);)f+=2;for(h=d.length-2;h>f&&isNaN(d[h]);)h-=2;0!==d[f]&&(p=[0,d[f+1]]),p=p.concat(d.slice(f,h+2)),0!==d[h]&&(p=p.concat([0,d[h+1]]))}else if(\"toself\"===s.fill||\"tonext\"===s.fill){for(p=[],i=0,t.splitNull=!0,a=0;a<d.length;a+=2)(isNaN(d[a])||isNaN(d[a+1]))&&((p=p.concat(d.slice(i,a))).push(d[i],d[i+1]),p.push(null,null),i=a+2);p=p.concat(d.slice(i)),i&&p.push(d[i],d[i+1])}else{var m=s._nexttrace;if(m){var g=v.lineOptions[e+1];if(g){var y=g.positions;if(\"tonexty\"===s.fill){for(p=d.slice(),e=Math.floor(y.length/2);e--;){var x=y[2*e],b=y[2*e+1];isNaN(x)||isNaN(b)||p.push(x,b)}t.fill=m.fillcolor}}}}if(s._prevtrace&&\"tonext\"===s._prevtrace.fill){var _=v.lineOptions[e-1].positions,w=p.length/2,T=[i=w];for(a=0;a<_.length;a+=2)(isNaN(_[a])||isNaN(_[a+1]))&&(T.push(a/2+w+1),i=a+2);p=p.concat(_),t.hole=T}return t.fillmode=s.fill,t.opacity=s.opacity,t.positions=p,t}})),v.fill2d.update(v.fillOptions))}var M=g.dragmode,A=l(M),S=g.clickmode.indexOf(\"select\")>-1;for(d=0;d<b;d++){var E=r[d][0],L=E.trace,C=E.t,P=C.index,I=L._length,O=C.x,z=C.y;if(L.selectedpoints||A||S){if(A||(A=!0),L.selectedpoints){var D=v.selectBatch[P]=s.selIndices2selPoints(L),R={};for(m=0;m<D.length;m++)R[D[m]]=1;var F=[];for(m=0;m<I;m++)R[m]||F.push(m);v.unselectBatch[P]=F}var B=C.xpx=new Array(I),N=C.ypx=new Array(I);for(m=0;m<I;m++)B[m]=y.c2p(O[m]),N[m]=x.c2p(z[m])}else C.xpx=C.ypx=null}if(A){if(v.select2d||(v.select2d=n(g._glcanvas.data()[1].regl)),v.scatter2d){var j=new Array(b);for(d=0;d<b;d++)j[d]=v.selectBatch[d].length||v.unselectBatch[d].length?v.markerUnselectedOptions[d]:{};v.scatter2d.update(j)}v.select2d&&(v.select2d.update(v.markerOptions),v.select2d.update(v.markerSelectedOptions)),v.glText&&r.forEach((function(t){var e=((t||[])[0]||{}).trace||{};u.hasText(e)&&h(t)}))}else v.scatter2d&&v.scatter2d.update(v.markerOptions);var U={viewport:p(g,y,x),range:[(y._rl||y.range)[0],(x._rl||x.range)[0],(y._rl||y.range)[1],(x._rl||x.range)[1]]},V=s.repeat(U,v.count);v.fill2d&&v.fill2d.update(V),v.line2d&&v.line2d.update(V),v.error2d&&v.error2d.update(V.concat(V)),v.scatter2d&&v.scatter2d.update(V),v.select2d&&v.select2d.update(V),v.glText&&v.glText.forEach((function(t){t.update(U)}))}else v.init()}}},{\"../../components/dragelement/helpers\":680,\"../../lib\":799,\"../../lib/prepare_regl\":812,\"../scatter/link_traces\":1230,\"../scatter/subtypes\":1239,\"./edit_style\":1271,\"gl-text\":351,\"regl-error2d\":532,\"regl-line2d\":533,\"regl-scatter2d\":534}],1277:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e){var r=e._scene,i={count:0,dirty:!0,lineOptions:[],fillOptions:[],markerOptions:[],markerSelectedOptions:[],markerUnselectedOptions:[],errorXOptions:[],errorYOptions:[],textOptions:[],textSelectedOptions:[],textUnselectedOptions:[],selectBatch:[],unselectBatch:[]},a={fill2d:!1,scatter2d:!1,error2d:!1,line2d:!1,glText:!1,select2d:!1};return e._scene||((r=e._scene={}).init=function(){n.extendFlat(r,a,i)},r.init(),r.update=function(t){var e=n.repeat(t,r.count);if(r.fill2d&&r.fill2d.update(e),r.scatter2d&&r.scatter2d.update(e),r.line2d&&r.line2d.update(e),r.error2d&&r.error2d.update(e.concat(e)),r.select2d&&r.select2d.update(e),r.glText)for(var i=0;i<r.count;i++)r.glText[i].update(t)},r.draw=function(){for(var t=r.count,e=r.fill2d,i=r.error2d,a=r.line2d,o=r.scatter2d,s=r.glText,l=r.select2d,c=r.selectBatch,u=r.unselectBatch,f=0;f<t;f++){if(e&&r.fillOrder[f]&&e.draw(r.fillOrder[f]),a&&r.lineOptions[f]&&a.draw(f),i&&(r.errorXOptions[f]&&i.draw(f),r.errorYOptions[f]&&i.draw(f+t)),o&&r.markerOptions[f])if(u[f].length){var h=n.repeat([],r.count);h[f]=u[f],o.draw(h)}else c[f].length||o.draw(f);s[f]&&r.textOptions[f]&&s[f].render()}l&&l.draw(c),r.dirty=!1},r.destroy=function(){r.fill2d&&r.fill2d.destroy&&r.fill2d.destroy(),r.scatter2d&&r.scatter2d.destroy&&r.scatter2d.destroy(),r.error2d&&r.error2d.destroy&&r.error2d.destroy(),r.line2d&&r.line2d.destroy&&r.line2d.destroy(),r.select2d&&r.select2d.destroy&&r.select2d.destroy(),r.glText&&r.glText.forEach((function(t){t.destroy&&t.destroy()})),r.lineOptions=null,r.fillOptions=null,r.markerOptions=null,r.markerSelectedOptions=null,r.markerUnselectedOptions=null,r.errorXOptions=null,r.errorYOptions=null,r.textOptions=null,r.textSelectedOptions=null,r.textUnselectedOptions=null,r.selectBatch=null,r.unselectBatch=null,e._scene=null}),r.dirty||n.extendFlat(r,i),r}},{\"../../lib\":799}],1278:[function(t,e,r){\"use strict\";var n=t(\"../scatter/subtypes\"),i=t(\"./edit_style\").styleTextSelection;e.exports=function(t,e){var r=t.cd,a=t.xaxis,o=t.yaxis,s=[],l=r[0].trace,c=r[0].t,u=l._length,f=c.x,h=c.y,p=c._scene,d=c.index;if(!p)return s;var m=n.hasText(l),g=n.hasMarkers(l),v=!g&&!m;if(!0!==l.visible||v)return s;var y=[],x=[];if(!1!==e&&!e.degenerate)for(var b=0;b<u;b++)e.contains([c.xpx[b],c.ypx[b]],!1,b,t)?(y.push(b),s.push({pointNumber:b,x:a.c2d(f[b]),y:o.c2d(h[b])})):x.push(b);if(g){var _=p.scatter2d;if(y.length||x.length){if(!p.selectBatch[d].length&&!p.unselectBatch[d].length){var w=new Array(p.count);w[d]=p.markerUnselectedOptions[d],_.update.apply(_,w)}}else{var T=new Array(p.count);T[d]=p.markerOptions[d],_.update.apply(_,T)}}return p.selectBatch[d]=y,p.unselectBatch[d]=x,m&&i(r),s}},{\"../scatter/subtypes\":1239,\"./edit_style\":1271}],1279:[function(t,e,r){\"use strict\";var n=t(\"../../plots/template_attributes\").hovertemplateAttrs,i=t(\"../../plots/template_attributes\").texttemplateAttrs,a=t(\"../scattergeo/attributes\"),o=t(\"../scatter/attributes\"),s=t(\"../../plots/mapbox/layout_attributes\"),l=t(\"../../plots/attributes\"),c=t(\"../../components/colorscale/attributes\"),u=t(\"../../lib/extend\").extendFlat,f=t(\"../../plot_api/edit_types\").overrideAll,h=a.line,p=a.marker;e.exports=f({lon:a.lon,lat:a.lat,mode:u({},o.mode,{dflt:\"markers\"}),text:u({},o.text,{}),texttemplate:i({editType:\"plot\"},{keys:[\"lat\",\"lon\",\"text\"]}),hovertext:u({},o.hovertext,{}),line:{color:h.color,width:h.width},connectgaps:o.connectgaps,marker:u({symbol:{valType:\"string\",dflt:\"circle\",arrayOk:!0},angle:{valType:\"number\",dflt:\"auto\",arrayOk:!0},allowoverlap:{valType:\"boolean\",dflt:!1},opacity:p.opacity,size:p.size,sizeref:p.sizeref,sizemin:p.sizemin,sizemode:p.sizemode},c(\"marker\")),fill:a.fill,fillcolor:o.fillcolor,textfont:s.layers.symbol.textfont,textposition:s.layers.symbol.textposition,below:{valType:\"string\"},selected:{marker:o.selected.marker},unselected:{marker:o.unselected.marker},hoverinfo:u({},l.hoverinfo,{flags:[\"lon\",\"lat\",\"text\",\"name\"]}),hovertemplate:n()},\"calc\",\"nested\")},{\"../../components/colorscale/attributes\":669,\"../../lib/extend\":789,\"../../plot_api/edit_types\":831,\"../../plots/attributes\":845,\"../../plots/mapbox/layout_attributes\":909,\"../../plots/template_attributes\":922,\"../scatter/attributes\":1214,\"../scattergeo/attributes\":1256}],1280:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../../constants/numerical\").BADNUM,o=t(\"../../lib/geojson_utils\"),s=t(\"../../components/colorscale\"),l=t(\"../../components/drawing\"),c=t(\"../scatter/make_bubble_size_func\"),u=t(\"../scatter/subtypes\"),f=t(\"../../plots/mapbox/convert_text_opts\"),h=t(\"../../components/fx/helpers\").appendArrayPointValue,p=t(\"../../lib/svg_text_utils\").NEWLINES,d=t(\"../../lib/svg_text_utils\").BR_TAG_ALL;function m(){return{geojson:o.makeBlank(),layout:{visibility:\"none\"},paint:{}}}function g(t,e){return i.isArrayOrTypedArray(t)?e?function(e){return n(t[e])?+t[e]:0}:function(e){return t[e]}:t?function(){return t}:v}function v(){return\"\"}function y(t){return t[0]===a}e.exports=function(t,e){var r,a=e[0].trace,x=!0===a.visible&&0!==a._length,b=\"none\"!==a.fill,_=u.hasLines(a),w=u.hasMarkers(a),T=u.hasText(a),k=w&&\"circle\"===a.marker.symbol,M=w&&\"circle\"!==a.marker.symbol,A=m(),S=m(),E=m(),L=m(),C={fill:A,line:S,circle:E,symbol:L};if(!x)return C;if((b||_)&&(r=o.calcTraceToLineCoords(e)),b&&(A.geojson=o.makePolygon(r),A.layout.visibility=\"visible\",i.extendFlat(A.paint,{\"fill-color\":a.fillcolor})),_&&(S.geojson=o.makeLine(r),S.layout.visibility=\"visible\",i.extendFlat(S.paint,{\"line-width\":a.line.width,\"line-color\":a.line.color,\"line-opacity\":a.opacity})),k){var P=function(t){var e,r,a,o,u=t[0].trace,f=u.marker,h=u.selectedpoints,p=i.isArrayOrTypedArray(f.color),d=i.isArrayOrTypedArray(f.size),m=i.isArrayOrTypedArray(f.opacity);function g(t){return u.opacity*t}p&&(r=s.hasColorscale(u,\"marker\")?s.makeColorScaleFuncFromTrace(f):i.identity);d&&(a=c(u));m&&(o=function(t){return g(n(t)?+i.constrain(t,0,1):0)});var v,x=[];for(e=0;e<t.length;e++){var b=t[e],_=b.lonlat;if(!y(_)){var w={};r&&(w.mcc=b.mcc=r(b.mc)),a&&(w.mrc=b.mrc=a(b.ms)),o&&(w.mo=o(b.mo)),h&&(w.selected=b.selected||0),x.push({type:\"Feature\",geometry:{type:\"Point\",coordinates:_},properties:w})}}if(h)for(v=l.makeSelectedPointStyleFns(u),e=0;e<x.length;e++){var T=x[e].properties;v.selectedOpacityFn&&(T.mo=g(v.selectedOpacityFn(T))),v.selectedColorFn&&(T.mcc=v.selectedColorFn(T)),v.selectedSizeFn&&(T.mrc=v.selectedSizeFn(T))}return{geojson:{type:\"FeatureCollection\",features:x},mcc:p||v&&v.selectedColorFn?{type:\"identity\",property:\"mcc\"}:f.color,mrc:d||v&&v.selectedSizeFn?{type:\"identity\",property:\"mrc\"}:(k=f.size,k/2),mo:m||v&&v.selectedOpacityFn?{type:\"identity\",property:\"mo\"}:g(f.opacity)};var k}(e);E.geojson=P.geojson,E.layout.visibility=\"visible\",i.extendFlat(E.paint,{\"circle-color\":P.mcc,\"circle-radius\":P.mrc,\"circle-opacity\":P.mo})}if((M||T)&&(L.geojson=function(t,e){for(var r=e._fullLayout,n=t[0].trace,a=n.marker||{},o=a.symbol,s=a.angle,l=\"circle\"!==o?g(o):v,c=\"auto\"!==s?g(s,!0):v,f=u.hasText(n)?g(n.text):v,m=[],x=0;x<t.length;x++){var b=t[x];if(!y(b.lonlat)){var _,w=n.texttemplate;if(w){var T=Array.isArray(w)?w[x]||\"\":w,k=n._module.formatLabels(b,n,r),M={};h(M,n,b.i);var A=n._meta||{};_=i.texttemplateString(T,k,r._d3locale,M,b,A)}else _=f(x);_&&(_=_.replace(p,\"\").replace(d,\"\\n\")),m.push({type:\"Feature\",geometry:{type:\"Point\",coordinates:b.lonlat},properties:{symbol:l(x),angle:c(x),text:_}})}}return{type:\"FeatureCollection\",features:m}}(e,t),i.extendFlat(L.layout,{visibility:\"visible\",\"icon-image\":\"{symbol}-15\",\"text-field\":\"{text}\"}),M&&(i.extendFlat(L.layout,{\"icon-size\":a.marker.size/10}),\"angle\"in a.marker&&\"auto\"!==a.marker.angle&&i.extendFlat(L.layout,{\"icon-rotate\":{type:\"identity\",property:\"angle\"},\"icon-rotation-alignment\":\"map\"}),L.layout[\"icon-allow-overlap\"]=a.marker.allowoverlap,i.extendFlat(L.paint,{\"icon-opacity\":a.opacity*a.marker.opacity,\"icon-color\":a.marker.color})),T)){var I=(a.marker||{}).size,O=f(a.textposition,I);i.extendFlat(L.layout,{\"text-size\":a.textfont.size,\"text-anchor\":O.anchor,\"text-offset\":O.offset}),i.extendFlat(L.paint,{\"text-color\":a.textfont.color,\"text-opacity\":a.opacity})}return C}},{\"../../components/colorscale\":674,\"../../components/drawing\":684,\"../../components/fx/helpers\":698,\"../../constants/numerical\":775,\"../../lib\":799,\"../../lib/geojson_utils\":793,\"../../lib/svg_text_utils\":824,\"../../plots/mapbox/convert_text_opts\":906,\"../scatter/make_bubble_size_func\":1231,\"../scatter/subtypes\":1239,\"fast-isnumeric\":245}],1281:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatter/subtypes\"),a=t(\"../scatter/marker_defaults\"),o=t(\"../scatter/line_defaults\"),s=t(\"../scatter/text_defaults\"),l=t(\"../scatter/fillcolor_defaults\"),c=t(\"./attributes\");e.exports=function(t,e,r,u){function f(r,i){return n.coerce(t,e,c,r,i)}if(function(t,e,r){var n=r(\"lon\")||[],i=r(\"lat\")||[],a=Math.min(n.length,i.length);return e._length=a,a}(0,e,f)){if(f(\"text\"),f(\"texttemplate\"),f(\"hovertext\"),f(\"hovertemplate\"),f(\"mode\"),f(\"below\"),i.hasLines(e)&&(o(t,e,r,u,f,{noDash:!0}),f(\"connectgaps\")),i.hasMarkers(e)){a(t,e,r,u,f,{noLine:!0}),f(\"marker.allowoverlap\"),f(\"marker.angle\");var h=e.marker;\"circle\"!==h.symbol&&(n.isArrayOrTypedArray(h.size)&&(h.size=h.size[0]),n.isArrayOrTypedArray(h.color)&&(h.color=h.color[0]))}i.hasText(e)&&s(t,e,u,f,{noSelect:!0}),f(\"fill\"),\"none\"!==e.fill&&l(t,e,r,f),n.coerceSelectionMarkerOpacity(e,f)}else e.visible=!1}},{\"../../lib\":799,\"../scatter/fillcolor_defaults\":1222,\"../scatter/line_defaults\":1227,\"../scatter/marker_defaults\":1233,\"../scatter/subtypes\":1239,\"../scatter/text_defaults\":1240,\"./attributes\":1279}],1282:[function(t,e,r){\"use strict\";e.exports=function(t,e){return t.lon=e.lon,t.lat=e.lat,t}},{}],1283:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\");e.exports=function(t,e,r){var i={},a=r[e.subplot]._subplot.mockAxis,o=t.lonlat;return i.lonLabel=n.tickText(a,a.c2l(o[0]),!0).text,i.latLabel=n.tickText(a,a.c2l(o[1]),!0).text,i}},{\"../../plots/cartesian/axes\":849}],1284:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx\"),i=t(\"../../lib\"),a=t(\"../scatter/get_trace_color\"),o=i.fillText,s=t(\"../../constants/numerical\").BADNUM;function l(t,e,r){if(!t.hovertemplate){var n=(e.hi||t.hoverinfo).split(\"+\"),i=-1!==n.indexOf(\"all\"),a=-1!==n.indexOf(\"lon\"),s=-1!==n.indexOf(\"lat\"),l=e.lonlat,c=[];return i||a&&s?c.push(\"(\"+u(l[1])+\", \"+u(l[0])+\")\"):a?c.push(r.lon+u(l[0])):s&&c.push(r.lat+u(l[1])),(i||-1!==n.indexOf(\"text\"))&&o(e,t,c),c.join(\"<br>\")}function u(t){return t+\"\\xb0\"}}e.exports={hoverPoints:function(t,e,r){var o=t.cd,c=o[0].trace,u=t.xa,f=t.ya,h=t.subplot,p=360*(e>=0?Math.floor((e+180)/360):Math.ceil((e-180)/360)),d=e-p;if(n.getClosest(o,(function(t){var e=t.lonlat;if(e[0]===s)return 1/0;var n=i.modHalf(e[0],360),a=e[1],o=h.project([n,a]),l=o.x-u.c2p([d,a]),c=o.y-f.c2p([n,r]),p=Math.max(3,t.mrc||0);return Math.max(Math.sqrt(l*l+c*c)-p,1-3/p)}),t),!1!==t.index){var m=o[t.index],g=m.lonlat,v=[i.modHalf(g[0],360)+p,g[1]],y=u.c2p(v),x=f.c2p(v),b=m.mrc||1;t.x0=y-b,t.x1=y+b,t.y0=x-b,t.y1=x+b;var _={};_[c.subplot]={_subplot:h};var w=c._module.formatLabels(m,c,_);return t.lonLabel=w.lonLabel,t.latLabel=w.latLabel,t.color=a(c,m),t.extraText=l(c,m,o[0].t.labels),t.hovertemplate=c.hovertemplate,[t]}},getExtraText:l}},{\"../../components/fx\":702,\"../../constants/numerical\":775,\"../../lib\":799,\"../scatter/get_trace_color\":1224}],1285:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../scatter/marker_colorbar\"),formatLabels:t(\"./format_labels\"),calc:t(\"../scattergeo/calc\"),plot:t(\"./plot\"),hoverPoints:t(\"./hover\").hoverPoints,eventData:t(\"./event_data\"),selectPoints:t(\"./select\"),styleOnSelect:function(t,e){e&&e[0].trace._glTrace.update(e)},moduleType:\"trace\",name:\"scattermapbox\",basePlotModule:t(\"../../plots/mapbox\"),categories:[\"mapbox\",\"gl\",\"symbols\",\"showLegend\",\"scatter-like\"],meta:{}}},{\"../../plots/mapbox\":907,\"../scatter/marker_colorbar\":1232,\"../scattergeo/calc\":1257,\"./attributes\":1279,\"./defaults\":1281,\"./event_data\":1282,\"./format_labels\":1283,\"./hover\":1284,\"./plot\":1286,\"./select\":1287}],1286:[function(t,e,r){\"use strict\";var n=t(\"./convert\"),i=t(\"../../plots/mapbox/constants\").traceLayerPrefix,a=[\"fill\",\"line\",\"circle\",\"symbol\"];function o(t,e){this.type=\"scattermapbox\",this.subplot=t,this.uid=e,this.sourceIds={fill:\"source-\"+e+\"-fill\",line:\"source-\"+e+\"-line\",circle:\"source-\"+e+\"-circle\",symbol:\"source-\"+e+\"-symbol\"},this.layerIds={fill:i+e+\"-fill\",line:i+e+\"-line\",circle:i+e+\"-circle\",symbol:i+e+\"-symbol\"},this.below=null}var s=o.prototype;s.addSource=function(t,e){this.subplot.map.addSource(this.sourceIds[t],{type:\"geojson\",data:e.geojson})},s.setSourceData=function(t,e){this.subplot.map.getSource(this.sourceIds[t]).setData(e.geojson)},s.addLayer=function(t,e,r){this.subplot.addLayer({type:t,id:this.layerIds[t],source:this.sourceIds[t],layout:e.layout,paint:e.paint},r)},s.update=function(t){var e,r,i,o=this.subplot,s=o.map,l=n(o.gd,t),c=o.belowLookup[\"trace-\"+this.uid];if(c!==this.below){for(e=a.length-1;e>=0;e--)r=a[e],s.removeLayer(this.layerIds[r]);for(e=0;e<a.length;e++)i=l[r=a[e]],this.addLayer(r,i,c);this.below=c}for(e=0;e<a.length;e++)i=l[r=a[e]],o.setOptions(this.layerIds[r],\"setLayoutProperty\",i.layout),\"visible\"===i.layout.visibility&&(this.setSourceData(r,i),o.setOptions(this.layerIds[r],\"setPaintProperty\",i.paint));t[0].trace._glTrace=this},s.dispose=function(){for(var t=this.subplot.map,e=a.length-1;e>=0;e--){var r=a[e];t.removeLayer(this.layerIds[r]),t.removeSource(this.sourceIds[r])}},e.exports=function(t,e){for(var r=e[0].trace,i=new o(t,r.uid),s=n(t.gd,e),l=i.below=t.belowLookup[\"trace-\"+r.uid],c=0;c<a.length;c++){var u=a[c],f=s[u];i.addSource(u,f),i.addLayer(u,f,l)}return e[0].trace._glTrace=i,i}},{\"../../plots/mapbox/constants\":905,\"./convert\":1280}],1287:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatter/subtypes\"),a=t(\"../../constants/numerical\").BADNUM;e.exports=function(t,e){var r,o=t.cd,s=t.xaxis,l=t.yaxis,c=[],u=o[0].trace;if(!i.hasMarkers(u))return[];if(!1===e)for(r=0;r<o.length;r++)o[r].selected=0;else for(r=0;r<o.length;r++){var f=o[r],h=f.lonlat;if(h[0]!==a){var p=[n.modHalf(h[0],360),h[1]],d=[s.c2p(p),l.c2p(p)];e.contains(d,null,r,t)?(c.push({pointNumber:r,lon:h[0],lat:h[1]}),f.selected=1):f.selected=0}}return c}},{\"../../constants/numerical\":775,\"../../lib\":799,\"../scatter/subtypes\":1239}],1288:[function(t,e,r){\"use strict\";var n=t(\"../../plots/template_attributes\").hovertemplateAttrs,i=t(\"../../plots/template_attributes\").texttemplateAttrs,a=t(\"../../lib/extend\").extendFlat,o=t(\"../scatter/attributes\"),s=t(\"../../plots/attributes\"),l=o.line;e.exports={mode:o.mode,r:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},theta:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},r0:{valType:\"any\",dflt:0,editType:\"calc+clearAxisTypes\"},dr:{valType:\"number\",dflt:1,editType:\"calc\"},theta0:{valType:\"any\",dflt:0,editType:\"calc+clearAxisTypes\"},dtheta:{valType:\"number\",editType:\"calc\"},thetaunit:{valType:\"enumerated\",values:[\"radians\",\"degrees\",\"gradians\"],dflt:\"degrees\",editType:\"calc+clearAxisTypes\"},text:o.text,texttemplate:i({editType:\"plot\"},{keys:[\"r\",\"theta\",\"text\"]}),hovertext:o.hovertext,line:{color:l.color,width:l.width,dash:l.dash,shape:a({},l.shape,{values:[\"linear\",\"spline\"]}),smoothing:l.smoothing,editType:\"calc\"},connectgaps:o.connectgaps,marker:o.marker,cliponaxis:a({},o.cliponaxis,{dflt:!1}),textposition:o.textposition,textfont:o.textfont,fill:a({},o.fill,{values:[\"none\",\"toself\",\"tonext\"],dflt:\"none\"}),fillcolor:o.fillcolor,hoverinfo:a({},s.hoverinfo,{flags:[\"r\",\"theta\",\"text\",\"name\"]}),hoveron:o.hoveron,hovertemplate:n(),selected:o.selected,unselected:o.unselected}},{\"../../lib/extend\":789,\"../../plots/attributes\":845,\"../../plots/template_attributes\":922,\"../scatter/attributes\":1214}],1289:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../constants/numerical\").BADNUM,a=t(\"../../plots/cartesian/axes\"),o=t(\"../scatter/colorscale_calc\"),s=t(\"../scatter/arrays_to_calcdata\"),l=t(\"../scatter/calc_selection\"),c=t(\"../scatter/calc\").calcMarkerSize;e.exports=function(t,e){for(var r=t._fullLayout,u=e.subplot,f=r[u].radialaxis,h=r[u].angularaxis,p=f.makeCalcdata(e,\"r\"),d=h.makeCalcdata(e,\"theta\"),m=e._length,g=new Array(m),v=0;v<m;v++){var y=p[v],x=d[v],b=g[v]={};n(y)&&n(x)?(b.r=y,b.theta=x):b.r=i}var _=c(e,m);return e._extremes.x=a.findExtremes(f,p,{ppad:_}),o(t,e),s(g,e),l(g,e),g}},{\"../../constants/numerical\":775,\"../../plots/cartesian/axes\":849,\"../scatter/arrays_to_calcdata\":1213,\"../scatter/calc\":1215,\"../scatter/calc_selection\":1216,\"../scatter/colorscale_calc\":1217,\"fast-isnumeric\":245}],1290:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatter/subtypes\"),a=t(\"../scatter/marker_defaults\"),o=t(\"../scatter/line_defaults\"),s=t(\"../scatter/line_shape_defaults\"),l=t(\"../scatter/text_defaults\"),c=t(\"../scatter/fillcolor_defaults\"),u=t(\"../scatter/constants\").PTS_LINESONLY,f=t(\"./attributes\");function h(t,e,r,n){var i,a=n(\"r\"),o=n(\"theta\");if(a)o?i=Math.min(a.length,o.length):(i=a.length,n(\"theta0\"),n(\"dtheta\"));else{if(!o)return 0;i=e.theta.length,n(\"r0\"),n(\"dr\")}return e._length=i,i}e.exports={handleRThetaDefaults:h,supplyDefaults:function(t,e,r,p){function d(r,i){return n.coerce(t,e,f,r,i)}var m=h(t,e,p,d);if(m){d(\"thetaunit\"),d(\"mode\",m<u?\"lines+markers\":\"lines\"),d(\"text\"),d(\"hovertext\"),\"fills\"!==e.hoveron&&d(\"hovertemplate\"),i.hasLines(e)&&(o(t,e,r,p,d),s(t,e,d),d(\"connectgaps\")),i.hasMarkers(e)&&a(t,e,r,p,d,{gradient:!0}),i.hasText(e)&&(d(\"texttemplate\"),l(t,e,p,d));var g=[];(i.hasMarkers(e)||i.hasText(e))&&(d(\"cliponaxis\"),d(\"marker.maxdisplayed\"),g.push(\"points\")),d(\"fill\"),\"none\"!==e.fill&&(c(t,e,r,d),i.hasLines(e)||s(t,e,d)),\"tonext\"!==e.fill&&\"toself\"!==e.fill||g.push(\"fills\"),d(\"hoveron\",g.join(\"+\")||\"points\"),n.coerceSelectionMarkerOpacity(e,d)}else e.visible=!1}}},{\"../../lib\":799,\"../scatter/constants\":1218,\"../scatter/fillcolor_defaults\":1222,\"../scatter/line_defaults\":1227,\"../scatter/line_shape_defaults\":1229,\"../scatter/marker_defaults\":1233,\"../scatter/subtypes\":1239,\"../scatter/text_defaults\":1240,\"./attributes\":1288}],1291:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\");e.exports=function(t,e,r){var a,o,s={},l=r[e.subplot]._subplot;l?(a=l.radialAxis,o=l.angularAxis):(a=(l=r[e.subplot]).radialaxis,o=l.angularaxis);var c=a.c2l(t.r);s.rLabel=i.tickText(a,c,!0).text;var u=\"degrees\"===o.thetaunit?n.rad2deg(t.theta):t.theta;return s.thetaLabel=i.tickText(o,u,!0).text,s}},{\"../../lib\":799,\"../../plots/cartesian/axes\":849}],1292:[function(t,e,r){\"use strict\";var n=t(\"../scatter/hover\");function i(t,e,r,n){var i=r.radialAxis,a=r.angularAxis;i._hovertitle=\"r\",a._hovertitle=\"\\u03b8\";var o={};o[e.subplot]={_subplot:r};var s=e._module.formatLabels(t,e,o);n.rLabel=s.rLabel,n.thetaLabel=s.thetaLabel;var l=t.hi||e.hoverinfo,c=[];function u(t,e){c.push(t._hovertitle+\": \"+e)}if(!e.hovertemplate){var f=l.split(\"+\");-1!==f.indexOf(\"all\")&&(f=[\"r\",\"theta\",\"text\"]),-1!==f.indexOf(\"r\")&&u(i,n.rLabel),-1!==f.indexOf(\"theta\")&&u(a,n.thetaLabel),-1!==f.indexOf(\"text\")&&n.text&&(c.push(n.text),delete n.text),n.extraText=c.join(\"<br>\")}}e.exports={hoverPoints:function(t,e,r,a){var o=n(t,e,r,a);if(o&&!1!==o[0].index){var s=o[0];if(void 0===s.index)return o;var l=t.subplot,c=s.cd[s.index],u=s.trace;if(l.isPtInside(c))return s.xLabelVal=void 0,s.yLabelVal=void 0,i(c,u,l,s),s.hovertemplate=u.hovertemplate,o}},makeHoverPointText:i}},{\"../scatter/hover\":1225}],1293:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"scatterpolar\",basePlotModule:t(\"../../plots/polar\"),categories:[\"polar\",\"symbols\",\"showLegend\",\"scatter-like\"],attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\").supplyDefaults,colorbar:t(\"../scatter/marker_colorbar\"),formatLabels:t(\"./format_labels\"),calc:t(\"./calc\"),plot:t(\"./plot\"),style:t(\"../scatter/style\").style,styleOnSelect:t(\"../scatter/style\").styleOnSelect,hoverPoints:t(\"./hover\").hoverPoints,selectPoints:t(\"../scatter/select\"),meta:{}}},{\"../../plots/polar\":916,\"../scatter/marker_colorbar\":1232,\"../scatter/select\":1236,\"../scatter/style\":1238,\"./attributes\":1288,\"./calc\":1289,\"./defaults\":1290,\"./format_labels\":1291,\"./hover\":1292,\"./plot\":1294}],1294:[function(t,e,r){\"use strict\";var n=t(\"../scatter/plot\"),i=t(\"../../constants/numerical\").BADNUM;e.exports=function(t,e,r){for(var a=e.layers.frontplot.select(\"g.scatterlayer\"),o={xaxis:e.xaxis,yaxis:e.yaxis,plot:e.framework,layerClipId:e._hasClipOnAxisFalse?e.clipIds.forTraces:null},s=e.radialAxis,l=e.angularAxis,c=0;c<r.length;c++)for(var u=r[c],f=0;f<u.length;f++){var h=u[f],p=h.r;if(p===i)h.x=h.y=i;else{var d=s.c2g(p),m=l.c2g(h.theta);h.x=d*Math.cos(m),h.y=d*Math.sin(m)}}n(t,o,r,a)}},{\"../../constants/numerical\":775,\"../scatter/plot\":1235}],1295:[function(t,e,r){\"use strict\";var n=t(\"../scatterpolar/attributes\"),i=t(\"../scattergl/attributes\"),a=t(\"../../plots/template_attributes\").texttemplateAttrs;e.exports={mode:n.mode,r:n.r,theta:n.theta,r0:n.r0,dr:n.dr,theta0:n.theta0,dtheta:n.dtheta,thetaunit:n.thetaunit,text:n.text,texttemplate:a({editType:\"plot\"},{keys:[\"r\",\"theta\",\"text\"]}),hovertext:n.hovertext,hovertemplate:n.hovertemplate,line:i.line,connectgaps:i.connectgaps,marker:i.marker,fill:i.fill,fillcolor:i.fillcolor,textposition:i.textposition,textfont:i.textfont,hoverinfo:n.hoverinfo,selected:n.selected,unselected:n.unselected}},{\"../../plots/template_attributes\":922,\"../scattergl/attributes\":1266,\"../scatterpolar/attributes\":1288}],1296:[function(t,e,r){\"use strict\";var n=t(\"../scatter/colorscale_calc\"),i=t(\"../scatter/calc\").calcMarkerSize,a=t(\"../scattergl/convert\"),o=t(\"../../plots/cartesian/axes\"),s=t(\"../scattergl/constants\").TOO_MANY_POINTS;e.exports=function(t,e){var r=t._fullLayout,l=e.subplot,c=r[l].radialaxis,u=r[l].angularaxis,f=e._r=c.makeCalcdata(e,\"r\"),h=e._theta=u.makeCalcdata(e,\"theta\"),p=e._length,d={};p<f.length&&(f=f.slice(0,p)),p<h.length&&(h=h.slice(0,p)),d.r=f,d.theta=h,n(t,e);var m,g=d.opts=a.style(t,e);return p<s?m=i(e,p):g.marker&&(m=2*(g.marker.sizeAvg||Math.max(g.marker.size,3))),e._extremes.x=o.findExtremes(c,f,{ppad:m}),[{x:!1,y:!1,t:d,trace:e}]}},{\"../../plots/cartesian/axes\":849,\"../scatter/calc\":1215,\"../scatter/colorscale_calc\":1217,\"../scattergl/constants\":1268,\"../scattergl/convert\":1269}],1297:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatter/subtypes\"),a=t(\"../scatterpolar/defaults\").handleRThetaDefaults,o=t(\"../scatter/marker_defaults\"),s=t(\"../scatter/line_defaults\"),l=t(\"../scatter/text_defaults\"),c=t(\"../scatter/fillcolor_defaults\"),u=t(\"../scatter/constants\").PTS_LINESONLY,f=t(\"./attributes\");e.exports=function(t,e,r,h){function p(r,i){return n.coerce(t,e,f,r,i)}var d=a(t,e,h,p);d?(p(\"thetaunit\"),p(\"mode\",d<u?\"lines+markers\":\"lines\"),p(\"text\"),p(\"hovertext\"),\"fills\"!==e.hoveron&&p(\"hovertemplate\"),i.hasLines(e)&&(s(t,e,r,h,p),p(\"connectgaps\")),i.hasMarkers(e)&&o(t,e,r,h,p),i.hasText(e)&&(p(\"texttemplate\"),l(t,e,h,p)),p(\"fill\"),\"none\"!==e.fill&&c(t,e,r,p),n.coerceSelectionMarkerOpacity(e,p)):e.visible=!1}},{\"../../lib\":799,\"../scatter/constants\":1218,\"../scatter/fillcolor_defaults\":1222,\"../scatter/line_defaults\":1227,\"../scatter/marker_defaults\":1233,\"../scatter/subtypes\":1239,\"../scatter/text_defaults\":1240,\"../scatterpolar/defaults\":1290,\"./attributes\":1295}],1298:[function(t,e,r){\"use strict\";var n=t(\"../scatterpolar/format_labels\");e.exports=function(t,e,r){var i=t.i;return\"r\"in t||(t.r=e._r[i]),\"theta\"in t||(t.theta=e._theta[i]),n(t,e,r)}},{\"../scatterpolar/format_labels\":1291}],1299:[function(t,e,r){\"use strict\";var n=t(\"../scattergl/hover\"),i=t(\"../scatterpolar/hover\").makeHoverPointText;e.exports={hoverPoints:function(t,e,r,a){var o=t.cd[0].t,s=o.r,l=o.theta,c=n.hoverPoints(t,e,r,a);if(c&&!1!==c[0].index){var u=c[0];if(void 0===u.index)return c;var f=t.subplot,h=u.cd[u.index],p=u.trace;if(h.r=s[u.index],h.theta=l[u.index],f.isPtInside(h))return u.xLabelVal=void 0,u.yLabelVal=void 0,i(h,p,f,u),c}}}},{\"../scattergl/hover\":1274,\"../scatterpolar/hover\":1292}],1300:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"scatterpolargl\",basePlotModule:t(\"../../plots/polar\"),categories:[\"gl\",\"regl\",\"polar\",\"symbols\",\"showLegend\",\"scatter-like\"],attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../scatter/marker_colorbar\"),formatLabels:t(\"./format_labels\"),calc:t(\"./calc\"),plot:t(\"./plot\"),hoverPoints:t(\"./hover\").hoverPoints,selectPoints:t(\"../scattergl/select\"),meta:{}}},{\"../../plots/polar\":916,\"../scatter/marker_colorbar\":1232,\"../scattergl/select\":1278,\"./attributes\":1295,\"./calc\":1296,\"./defaults\":1297,\"./format_labels\":1298,\"./hover\":1299,\"./plot\":1301}],1301:[function(t,e,r){\"use strict\";var n=t(\"@plotly/point-cluster\"),i=t(\"fast-isnumeric\"),a=t(\"../scattergl/plot\"),o=t(\"../scattergl/scene_update\"),s=t(\"../scattergl/convert\"),l=t(\"../../lib\"),c=t(\"../scattergl/constants\").TOO_MANY_POINTS;e.exports=function(t,e,r){if(r.length){var u=e.radialAxis,f=e.angularAxis,h=o(t,e);return r.forEach((function(r){if(r&&r[0]&&r[0].trace){var a,o=r[0],p=o.trace,d=o.t,m=p._length,g=d.r,v=d.theta,y=d.opts,x=g.slice(),b=v.slice();for(a=0;a<g.length;a++)e.isPtInside({r:g[a],theta:v[a]})||(x[a]=NaN,b[a]=NaN);var _=new Array(2*m),w=Array(m),T=Array(m);for(a=0;a<m;a++){var k,M,A=x[a];if(i(A)){var S=u.c2g(A),E=f.c2g(b[a],p.thetaunit);k=S*Math.cos(E),M=S*Math.sin(E)}else k=M=NaN;w[a]=_[2*a]=k,T[a]=_[2*a+1]=M}d.tree=n(_),y.marker&&m>=c&&(y.marker.cluster=d.tree),y.marker&&(y.markerSel.positions=y.markerUnsel.positions=y.marker.positions=_),y.line&&_.length>1&&l.extendFlat(y.line,s.linePositions(t,p,_)),y.text&&(l.extendFlat(y.text,{positions:_},s.textPosition(t,p,y.text,y.marker)),l.extendFlat(y.textSel,{positions:_},s.textPosition(t,p,y.text,y.markerSel)),l.extendFlat(y.textUnsel,{positions:_},s.textPosition(t,p,y.text,y.markerUnsel))),y.fill&&!h.fill2d&&(h.fill2d=!0),y.marker&&!h.scatter2d&&(h.scatter2d=!0),y.line&&!h.line2d&&(h.line2d=!0),y.text&&!h.glText&&(h.glText=!0),h.lineOptions.push(y.line),h.fillOptions.push(y.fill),h.markerOptions.push(y.marker),h.markerSelectedOptions.push(y.markerSel),h.markerUnselectedOptions.push(y.markerUnsel),h.textOptions.push(y.text),h.textSelectedOptions.push(y.textSel),h.textUnselectedOptions.push(y.textUnsel),h.selectBatch.push([]),h.unselectBatch.push([]),d.x=w,d.y=T,d.rawx=w,d.rawy=T,d.r=g,d.theta=v,d.positions=_,d._scene=h,d.index=h.count,h.count++}})),a(t,e,r)}}},{\"../../lib\":799,\"../scattergl/constants\":1268,\"../scattergl/convert\":1269,\"../scattergl/plot\":1276,\"../scattergl/scene_update\":1277,\"@plotly/point-cluster\":59,\"fast-isnumeric\":245}],1302:[function(t,e,r){\"use strict\";var n=t(\"../../plots/template_attributes\").hovertemplateAttrs,i=t(\"../../plots/template_attributes\").texttemplateAttrs,a=t(\"../scatter/attributes\"),o=t(\"../../plots/attributes\"),s=t(\"../../components/colorscale/attributes\"),l=t(\"../../components/drawing/attributes\").dash,c=t(\"../../lib/extend\").extendFlat,u=a.marker,f=a.line,h=u.line;e.exports={a:{valType:\"data_array\",editType:\"calc\"},b:{valType:\"data_array\",editType:\"calc\"},c:{valType:\"data_array\",editType:\"calc\"},sum:{valType:\"number\",dflt:0,min:0,editType:\"calc\"},mode:c({},a.mode,{dflt:\"markers\"}),text:c({},a.text,{}),texttemplate:i({editType:\"plot\"},{keys:[\"a\",\"b\",\"c\",\"text\"]}),hovertext:c({},a.hovertext,{}),line:{color:f.color,width:f.width,dash:l,shape:c({},f.shape,{values:[\"linear\",\"spline\"]}),smoothing:f.smoothing,editType:\"calc\"},connectgaps:a.connectgaps,cliponaxis:a.cliponaxis,fill:c({},a.fill,{values:[\"none\",\"toself\",\"tonext\"],dflt:\"none\"}),fillcolor:a.fillcolor,marker:c({symbol:u.symbol,opacity:u.opacity,maxdisplayed:u.maxdisplayed,size:u.size,sizeref:u.sizeref,sizemin:u.sizemin,sizemode:u.sizemode,line:c({width:h.width,editType:\"calc\"},s(\"marker.line\")),gradient:u.gradient,editType:\"calc\"},s(\"marker\")),textfont:a.textfont,textposition:a.textposition,selected:a.selected,unselected:a.unselected,hoverinfo:c({},o.hoverinfo,{flags:[\"a\",\"b\",\"c\",\"text\",\"name\"]}),hoveron:a.hoveron,hovertemplate:n()}},{\"../../components/colorscale/attributes\":669,\"../../components/drawing/attributes\":683,\"../../lib/extend\":789,\"../../plots/attributes\":845,\"../../plots/template_attributes\":922,\"../scatter/attributes\":1214}],1303:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../scatter/colorscale_calc\"),a=t(\"../scatter/arrays_to_calcdata\"),o=t(\"../scatter/calc_selection\"),s=t(\"../scatter/calc\").calcMarkerSize,l=[\"a\",\"b\",\"c\"],c={a:[\"b\",\"c\"],b:[\"a\",\"c\"],c:[\"a\",\"b\"]};e.exports=function(t,e){var r,u,f,h,p,d,m=t._fullLayout[e.subplot].sum,g=e.sum||m,v={a:e.a,b:e.b,c:e.c};for(r=0;r<l.length;r++)if(!v[f=l[r]]){for(p=v[c[f][0]],d=v[c[f][1]],h=new Array(p.length),u=0;u<p.length;u++)h[u]=g-p[u]-d[u];v[f]=h}var y,x,b,_,w,T,k=e._length,M=new Array(k);for(r=0;r<k;r++)y=v.a[r],x=v.b[r],b=v.c[r],n(y)&&n(x)&&n(b)?(1!==(_=m/((y=+y)+(x=+x)+(b=+b)))&&(y*=_,x*=_,b*=_),T=y,w=b-x,M[r]={x:w,y:T,a:y,b:x,c:b}):M[r]={x:!1,y:!1};return s(e,k),i(t,e),a(M,e),o(M,e),M}},{\"../scatter/arrays_to_calcdata\":1213,\"../scatter/calc\":1215,\"../scatter/calc_selection\":1216,\"../scatter/colorscale_calc\":1217,\"fast-isnumeric\":245}],1304:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatter/constants\"),a=t(\"../scatter/subtypes\"),o=t(\"../scatter/marker_defaults\"),s=t(\"../scatter/line_defaults\"),l=t(\"../scatter/line_shape_defaults\"),c=t(\"../scatter/text_defaults\"),u=t(\"../scatter/fillcolor_defaults\"),f=t(\"./attributes\");e.exports=function(t,e,r,h){function p(r,i){return n.coerce(t,e,f,r,i)}var d,m=p(\"a\"),g=p(\"b\"),v=p(\"c\");if(m?(d=m.length,g?(d=Math.min(d,g.length),v&&(d=Math.min(d,v.length))):d=v?Math.min(d,v.length):0):g&&v&&(d=Math.min(g.length,v.length)),d){e._length=d,p(\"sum\"),p(\"text\"),p(\"hovertext\"),\"fills\"!==e.hoveron&&p(\"hovertemplate\"),p(\"mode\",d<i.PTS_LINESONLY?\"lines+markers\":\"lines\"),a.hasLines(e)&&(s(t,e,r,h,p),l(t,e,p),p(\"connectgaps\")),a.hasMarkers(e)&&o(t,e,r,h,p,{gradient:!0}),a.hasText(e)&&(p(\"texttemplate\"),c(t,e,h,p));var y=[];(a.hasMarkers(e)||a.hasText(e))&&(p(\"cliponaxis\"),p(\"marker.maxdisplayed\"),y.push(\"points\")),p(\"fill\"),\"none\"!==e.fill&&(u(t,e,r,p),a.hasLines(e)||l(t,e,p)),\"tonext\"!==e.fill&&\"toself\"!==e.fill||y.push(\"fills\"),p(\"hoveron\",y.join(\"+\")||\"points\"),n.coerceSelectionMarkerOpacity(e,p)}else e.visible=!1}},{\"../../lib\":799,\"../scatter/constants\":1218,\"../scatter/fillcolor_defaults\":1222,\"../scatter/line_defaults\":1227,\"../scatter/line_shape_defaults\":1229,\"../scatter/marker_defaults\":1233,\"../scatter/subtypes\":1239,\"../scatter/text_defaults\":1240,\"./attributes\":1302}],1305:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,i){if(e.xa&&(t.xaxis=e.xa),e.ya&&(t.yaxis=e.ya),n[i]){var a=n[i];t.a=a.a,t.b=a.b,t.c=a.c}else t.a=e.a,t.b=e.b,t.c=e.c;return t}},{}],1306:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\");e.exports=function(t,e,r){var i={},a=r[e.subplot]._subplot;return i.aLabel=n.tickText(a.aaxis,t.a,!0).text,i.bLabel=n.tickText(a.baxis,t.b,!0).text,i.cLabel=n.tickText(a.caxis,t.c,!0).text,i}},{\"../../plots/cartesian/axes\":849}],1307:[function(t,e,r){\"use strict\";var n=t(\"../scatter/hover\");e.exports=function(t,e,r,i){var a=n(t,e,r,i);if(a&&!1!==a[0].index){var o=a[0];if(void 0===o.index){var s=1-o.y0/t.ya._length,l=t.xa._length,c=l*s/2,u=l-c;return o.x0=Math.max(Math.min(o.x0,u),c),o.x1=Math.max(Math.min(o.x1,u),c),a}var f=o.cd[o.index],h=o.trace,p=o.subplot;o.a=f.a,o.b=f.b,o.c=f.c,o.xLabelVal=void 0,o.yLabelVal=void 0;var d={};d[h.subplot]={_subplot:p};var m=h._module.formatLabels(f,h,d);o.aLabel=m.aLabel,o.bLabel=m.bLabel,o.cLabel=m.cLabel;var g=f.hi||h.hoverinfo,v=[];if(!h.hovertemplate){var y=g.split(\"+\");-1!==y.indexOf(\"all\")&&(y=[\"a\",\"b\",\"c\"]),-1!==y.indexOf(\"a\")&&x(p.aaxis,o.aLabel),-1!==y.indexOf(\"b\")&&x(p.baxis,o.bLabel),-1!==y.indexOf(\"c\")&&x(p.caxis,o.cLabel)}return o.extraText=v.join(\"<br>\"),o.hovertemplate=h.hovertemplate,a}function x(t,e){v.push(t._hovertitle+\": \"+e)}}},{\"../scatter/hover\":1225}],1308:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../scatter/marker_colorbar\"),formatLabels:t(\"./format_labels\"),calc:t(\"./calc\"),plot:t(\"./plot\"),style:t(\"../scatter/style\").style,styleOnSelect:t(\"../scatter/style\").styleOnSelect,hoverPoints:t(\"./hover\"),selectPoints:t(\"../scatter/select\"),eventData:t(\"./event_data\"),moduleType:\"trace\",name:\"scatterternary\",basePlotModule:t(\"../../plots/ternary\"),categories:[\"ternary\",\"symbols\",\"showLegend\",\"scatter-like\"],meta:{}}},{\"../../plots/ternary\":923,\"../scatter/marker_colorbar\":1232,\"../scatter/select\":1236,\"../scatter/style\":1238,\"./attributes\":1302,\"./calc\":1303,\"./defaults\":1304,\"./event_data\":1305,\"./format_labels\":1306,\"./hover\":1307,\"./plot\":1309}],1309:[function(t,e,r){\"use strict\";var n=t(\"../scatter/plot\");e.exports=function(t,e,r){var i=e.plotContainer;i.select(\".scatterlayer\").selectAll(\"*\").remove();var a={xaxis:e.xaxis,yaxis:e.yaxis,plot:i,layerClipId:e._hasClipOnAxisFalse?e.clipIdRelative:null},o=e.layers.frontplot.select(\"g.scatterlayer\");n(t,a,r,o)}},{\"../scatter/plot\":1235}],1310:[function(t,e,r){\"use strict\";var n=t(\"../scatter/attributes\"),i=t(\"../../components/colorscale/attributes\"),a=t(\"../../plots/cartesian/axis_format_attributes\").axisHoverFormat,o=t(\"../../plots/template_attributes\").hovertemplateAttrs,s=t(\"../scattergl/attributes\"),l=t(\"../../plots/cartesian/constants\").idRegex,c=t(\"../../plot_api/plot_template\").templatedArray,u=t(\"../../lib/extend\").extendFlat,f=n.marker,h=f.line,p=u(i(\"marker.line\",{editTypeOverride:\"calc\"}),{width:u({},h.width,{editType:\"calc\"}),editType:\"calc\"}),d=u(i(\"marker\"),{symbol:f.symbol,size:u({},f.size,{editType:\"markerSize\"}),sizeref:f.sizeref,sizemin:f.sizemin,sizemode:f.sizemode,opacity:f.opacity,colorbar:f.colorbar,line:p,editType:\"calc\"});function m(t){return{valType:\"info_array\",freeLength:!0,editType:\"calc\",items:{valType:\"subplotid\",regex:l[t],editType:\"plot\"}}}d.color.editType=d.cmin.editType=d.cmax.editType=\"style\",e.exports={dimensions:c(\"dimension\",{visible:{valType:\"boolean\",dflt:!0,editType:\"calc\"},label:{valType:\"string\",editType:\"calc\"},values:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},axis:{type:{valType:\"enumerated\",values:[\"linear\",\"log\",\"date\",\"category\"],editType:\"calc+clearAxisTypes\"},matches:{valType:\"boolean\",dflt:!1,editType:\"calc\"},editType:\"calc+clearAxisTypes\"},editType:\"calc+clearAxisTypes\"}),text:u({},s.text,{}),hovertext:u({},s.hovertext,{}),hovertemplate:o(),xhoverformat:a(\"x\"),yhoverformat:a(\"y\"),marker:d,xaxes:m(\"x\"),yaxes:m(\"y\"),diagonal:{visible:{valType:\"boolean\",dflt:!0,editType:\"calc\"},editType:\"calc\"},showupperhalf:{valType:\"boolean\",dflt:!0,editType:\"calc\"},showlowerhalf:{valType:\"boolean\",dflt:!0,editType:\"calc\"},selected:{marker:s.selected.marker,editType:\"calc\"},unselected:{marker:s.unselected.marker,editType:\"calc\"},opacity:s.opacity}},{\"../../components/colorscale/attributes\":669,\"../../lib/extend\":789,\"../../plot_api/plot_template\":838,\"../../plots/cartesian/axis_format_attributes\":852,\"../../plots/cartesian/constants\":856,\"../../plots/template_attributes\":922,\"../scatter/attributes\":1214,\"../scattergl/attributes\":1266}],1311:[function(t,e,r){\"use strict\";var n=t(\"regl-line2d\"),i=t(\"../../registry\"),a=t(\"../../lib/prepare_regl\"),o=t(\"../../plots/get_data\").getModuleCalcData,s=t(\"../../plots/cartesian\"),l=t(\"../../plots/cartesian/axis_ids\").getFromId,c=t(\"../../plots/cartesian/axes\").shouldShowZeroLine;function u(t,e,r){for(var n=r.matrixOptions.data.length,i=e._visibleDims,a=r.viewOpts.ranges=new Array(n),o=0;o<i.length;o++){var s=i[o],c=a[o]=new Array(4),u=l(t,e._diag[s][0]);u&&(c[0]=u.r2l(u.range[0]),c[2]=u.r2l(u.range[1]));var f=l(t,e._diag[s][1]);f&&(c[1]=f.r2l(f.range[0]),c[3]=f.r2l(f.range[1]))}r.selectBatch.length||r.unselectBatch.length?r.matrix.update({ranges:a},{ranges:a}):r.matrix.update({ranges:a})}function f(t){var e=t._fullLayout,r=e._glcanvas.data()[0].regl,i=e._splomGrid;i||(i=e._splomGrid=n(r)),i.update(function(t){var e,r=t._fullLayout,n=r._size,i=[0,0,r.width,r.height],a={};function o(t,e,r,n,o,s){var l=e[t+\"color\"],c=e[t+\"width\"],u=String(l+c);u in a?a[u].data.push(NaN,NaN,r,n,o,s):a[u]={data:[r,n,o,s],join:\"rect\",thickness:c,color:l,viewport:i,range:i,overlay:!1}}for(e in r._splomSubplots){var s,l,u=r._plots[e],f=u.xaxis,h=u.yaxis,p=f._gridVals,d=h._gridVals,m=n.b+h.domain[0]*n.h,g=-h._m,v=-g*h.r2l(h.range[0],h.calendar);if(f.showgrid)for(e=0;e<p.length;e++)s=f._offset+f.l2p(p[e].x),o(\"grid\",f,s,m,s,m+h._length);if(h.showgrid)for(e=0;e<d.length;e++)l=m+v+g*d[e].x,o(\"grid\",h,f._offset,l,f._offset+f._length,l);c(t,f,h)&&(s=f._offset+f.l2p(0),o(\"zeroline\",f,s,m,s,m+h._length)),c(t,h,f)&&(l=m+v+0,o(\"zeroline\",h,f._offset,l,f._offset+f._length,l))}var y=[];for(e in a)y.push(a[e]);return y}(t))}e.exports={name:\"splom\",attr:s.attr,attrRegex:s.attrRegex,layoutAttributes:s.layoutAttributes,supplyLayoutDefaults:s.supplyLayoutDefaults,drawFramework:s.drawFramework,plot:function(t){var e=t._fullLayout,r=i.getModule(\"splom\"),n=o(t.calcdata,r)[0];a(t,[\"ANGLE_instanced_arrays\",\"OES_element_index_uint\"])&&(e._hasOnlyLargeSploms&&f(t),r.plot(t,{},n))},drag:function(t){var e=t.calcdata,r=t._fullLayout;r._hasOnlyLargeSploms&&f(t);for(var n=0;n<e.length;n++){var i=e[n][0].trace,a=r._splomScenes[i.uid];\"splom\"===i.type&&a&&a.matrix&&u(t,i,a)}},updateGrid:f,clean:function(t,e,r,n){var i,a={};if(n._splomScenes){for(i=0;i<t.length;i++){var o=t[i];\"splom\"===o.type&&(a[o.uid]=1)}for(i=0;i<r.length;i++){var l=r[i];if(!a[l.uid]){var c=n._splomScenes[l.uid];c&&c.destroy&&c.destroy(),n._splomScenes[l.uid]=null,delete n._splomScenes[l.uid]}}}0===Object.keys(n._splomScenes||{}).length&&delete n._splomScenes,n._splomGrid&&!e._hasOnlyLargeSploms&&n._hasOnlyLargeSploms&&(n._splomGrid.destroy(),n._splomGrid=null,delete n._splomGrid),s.clean(t,e,r,n)},updateFx:s.updateFx,toSVG:s.toSVG}},{\"../../lib/prepare_regl\":812,\"../../plots/cartesian\":863,\"../../plots/cartesian/axes\":849,\"../../plots/cartesian/axis_ids\":853,\"../../plots/get_data\":887,\"../../registry\":927,\"regl-line2d\":533}],1312:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axis_ids\"),a=t(\"../scatter/calc\").calcMarkerSize,o=t(\"../scatter/calc\").calcAxisExpansion,s=t(\"../scatter/colorscale_calc\"),l=t(\"../scattergl/convert\").markerSelection,c=t(\"../scattergl/convert\").markerStyle,u=t(\"./scene_update\"),f=t(\"../../constants/numerical\").BADNUM,h=t(\"../scattergl/constants\").TOO_MANY_POINTS;e.exports=function(t,e){var r,p,d,m,g,v,y=e.dimensions,x=e._length,b={},_=b.cdata=[],w=b.data=[],T=e._visibleDims=[];function k(t,r){for(var i=t.makeCalcdata({v:r.values,vcalendar:e.calendar},\"v\"),a=0;a<i.length;a++)i[a]=i[a]===f?NaN:i[a];_.push(i),w.push(\"log\"===t.type?n.simpleMap(i,t.c2l):i)}for(r=0;r<y.length;r++)if((d=y[r]).visible){if(m=i.getFromId(t,e._diag[r][0]),g=i.getFromId(t,e._diag[r][1]),m&&g&&m.type!==g.type){n.log(\"Skipping splom dimension \"+r+\" with conflicting axis types\");continue}m?(k(m,d),g&&\"category\"===g.type&&(g._categories=m._categories.slice())):k(g,d),T.push(r)}for(s(t,e),n.extendFlat(b,c(e)),v=_.length*x>h?2*(b.sizeAvg||Math.max(b.size,3)):a(e,x),p=0;p<T.length;p++)d=y[r=T[p]],m=i.getFromId(t,e._diag[r][0])||{},g=i.getFromId(t,e._diag[r][1])||{},o(t,e,m,g,_[p],_[p],v);var M=u(t,e);return M.matrix||(M.matrix=!0),M.matrixOptions=b,M.selectedOptions=l(e,e.selected),M.unselectedOptions=l(e,e.unselected),[{x:!1,y:!1,t:{},trace:e}]}},{\"../../constants/numerical\":775,\"../../lib\":799,\"../../plots/cartesian/axis_ids\":853,\"../scatter/calc\":1215,\"../scatter/colorscale_calc\":1217,\"../scattergl/constants\":1268,\"../scattergl/convert\":1269,\"./scene_update\":1319}],1313:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/array_container_defaults\"),a=t(\"./attributes\"),o=t(\"../scatter/subtypes\"),s=t(\"../scatter/marker_defaults\"),l=t(\"../parcoords/merge_length\"),c=t(\"../scattergl/helpers\").isOpenSymbol;function u(t,e){function r(r,i){return n.coerce(t,e,a.dimensions,r,i)}r(\"label\");var i=r(\"values\");i&&i.length?r(\"visible\"):e.visible=!1,r(\"axis.type\"),r(\"axis.matches\")}e.exports=function(t,e,r,f){function h(r,i){return n.coerce(t,e,a,r,i)}var p=i(t,e,{name:\"dimensions\",handleItemDefaults:u}),d=h(\"diagonal.visible\"),m=h(\"showupperhalf\"),g=h(\"showlowerhalf\");if(l(e,p,\"values\")&&(d||m||g)){h(\"text\"),h(\"hovertext\"),h(\"hovertemplate\"),h(\"xhoverformat\"),h(\"yhoverformat\"),s(t,e,r,f,h);var v=c(e.marker.symbol),y=o.isBubble(e);h(\"marker.line.width\",v||y?1:0),function(t,e,r,n){var i,a,o=e.dimensions,s=o.length,l=e.showupperhalf,c=e.showlowerhalf,u=e.diagonal.visible,f=new Array(s),h=new Array(s);for(i=0;i<s;i++){var p=i?i+1:\"\";f[i]=\"x\"+p,h[i]=\"y\"+p}var d=n(\"xaxes\",f),m=n(\"yaxes\",h),g=e._diag=new Array(s);e._xaxes={},e._yaxes={};var v=[],y=[];function x(t,n,i,a){if(t){var o=t.charAt(0),s=r._splomAxes[o];if(e[\"_\"+o+\"axes\"][t]=1,a.push(t),!(t in s)){var l=s[t]={};i&&(l.label=i.label||\"\",i.visible&&i.axis&&(i.axis.type&&(l.type=i.axis.type),i.axis.matches&&(l.matches=n)))}}}var b=!u&&!c,_=!u&&!l;for(e._axesDim={},i=0;i<s;i++){var w=o[i],T=0===i,k=i===s-1,M=T&&b||k&&_?void 0:d[i],A=T&&_||k&&b?void 0:m[i];x(M,A,w,v),x(A,M,w,y),g[i]=[M,A],e._axesDim[M]=i,e._axesDim[A]=i}for(i=0;i<v.length;i++)for(a=0;a<y.length;a++){var S=v[i]+y[a];i>a&&l||i<a&&c?r._splomSubplots[S]=1:i!==a||!u&&c&&l||(r._splomSubplots[S]=1)}(!c||!u&&l&&c)&&(r._splomGridDflt.xside=\"bottom\",r._splomGridDflt.yside=\"left\")}(0,e,f,h),n.coerceSelectionMarkerOpacity(e,h)}else e.visible=!1}},{\"../../lib\":799,\"../../plots/array_container_defaults\":844,\"../parcoords/merge_length\":1185,\"../scatter/marker_defaults\":1233,\"../scatter/subtypes\":1239,\"../scattergl/helpers\":1273,\"./attributes\":1310}],1314:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatter/colorscale_calc\"),a=t(\"../scattergl/convert\").markerStyle;e.exports=function(t,e){var r=e.trace,o=t._fullLayout._splomScenes[r.uid];if(o){i(t,r),n.extendFlat(o.matrixOptions,a(r));var s=n.extendFlat({},o.matrixOptions,o.viewOpts);o.matrix.update(s,null)}}},{\"../../lib\":799,\"../scatter/colorscale_calc\":1217,\"../scattergl/convert\":1269}],1315:[function(t,e,r){\"use strict\";r.getDimIndex=function(t,e){for(var r=e._id,n={x:0,y:1}[r.charAt(0)],i=t._visibleDims,a=0;a<i.length;a++){var o=i[a];if(t._diag[o][n]===r)return a}return!1}},{}],1316:[function(t,e,r){\"use strict\";var n=t(\"./helpers\"),i=t(\"../scattergl/hover\").calcHover;e.exports={hoverPoints:function(t,e,r){var a=t.cd[0].trace,o=t.scene.matrixOptions.cdata,s=t.xa,l=t.ya,c=s.c2p(e),u=l.c2p(r),f=t.distance,h=n.getDimIndex(a,s),p=n.getDimIndex(a,l);if(!1===h||!1===p)return[t];for(var d,m,g=o[h],v=o[p],y=f,x=0;x<g.length;x++){var b=g[x],_=v[x],w=s.c2p(b)-c,T=l.c2p(_)-u,k=Math.sqrt(w*w+T*T);k<y&&(y=m=k,d=x)}return t.index=d,t.distance=y,t.dxy=m,void 0===d?[t]:[i(t,g,v,a)]}}},{\"../scattergl/hover\":1274,\"./helpers\":1315}],1317:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../components/grid\");e.exports={moduleType:\"trace\",name:\"splom\",basePlotModule:t(\"./base_plot\"),categories:[\"gl\",\"regl\",\"cartesian\",\"symbols\",\"showLegend\",\"scatter-like\"],attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../scatter/marker_colorbar\"),calc:t(\"./calc\"),plot:t(\"./plot\"),hoverPoints:t(\"./hover\").hoverPoints,selectPoints:t(\"./select\"),editStyle:t(\"./edit_style\"),meta:{}},n.register(i)},{\"../../components/grid\":706,\"../../registry\":927,\"../scatter/marker_colorbar\":1232,\"./attributes\":1310,\"./base_plot\":1311,\"./calc\":1312,\"./defaults\":1313,\"./edit_style\":1314,\"./hover\":1316,\"./plot\":1318,\"./select\":1320}],1318:[function(t,e,r){\"use strict\";var n=t(\"regl-splom\"),i=t(\"../../lib\"),a=t(\"../../plots/cartesian/axis_ids\"),o=t(\"../../components/dragelement/helpers\").selectMode;function s(t,e){var r,s,l,c,u,f=t._fullLayout,h=f._size,p=e.trace,d=e.t,m=f._splomScenes[p.uid],g=m.matrixOptions,v=g.cdata,y=f._glcanvas.data()[0].regl,x=f.dragmode;if(0!==v.length){g.lower=p.showupperhalf,g.upper=p.showlowerhalf,g.diagonal=p.diagonal.visible;var b=p._visibleDims,_=v.length,w=m.viewOpts={};for(w.ranges=new Array(_),w.domains=new Array(_),u=0;u<b.length;u++){l=b[u];var T=w.ranges[u]=new Array(4),k=w.domains[u]=new Array(4);(r=a.getFromId(t,p._diag[l][0]))&&(T[0]=r._rl[0],T[2]=r._rl[1],k[0]=r.domain[0],k[2]=r.domain[1]),(s=a.getFromId(t,p._diag[l][1]))&&(T[1]=s._rl[0],T[3]=s._rl[1],k[1]=s.domain[0],k[3]=s.domain[1])}w.viewport=[h.l,h.b,h.w+h.l,h.h+h.b],!0===m.matrix&&(m.matrix=n(y));var M=f.clickmode.indexOf(\"select\")>-1,A=!0;if(o(x)||!!p.selectedpoints||M){var S=p._length;if(p.selectedpoints){m.selectBatch=p.selectedpoints;var E=p.selectedpoints,L={};for(l=0;l<E.length;l++)L[E[l]]=!0;var C=[];for(l=0;l<S;l++)L[l]||C.push(l);m.unselectBatch=C}var P=d.xpx=new Array(_),I=d.ypx=new Array(_);for(u=0;u<b.length;u++){if(l=b[u],r=a.getFromId(t,p._diag[l][0]))for(P[u]=new Array(S),c=0;c<S;c++)P[u][c]=r.c2p(v[u][c]);if(s=a.getFromId(t,p._diag[l][1]))for(I[u]=new Array(S),c=0;c<S;c++)I[u][c]=s.c2p(v[u][c])}if(m.selectBatch.length||m.unselectBatch.length){var O=i.extendFlat({},g,m.unselectedOptions,w),z=i.extendFlat({},g,m.selectedOptions,w);m.matrix.update(O,z),A=!1}}else d.xpx=d.ypx=null;if(A){var D=i.extendFlat({},g,w);m.matrix.update(D,null)}}}e.exports=function(t,e,r){if(r.length)for(var n=0;n<r.length;n++)s(t,r[n][0])}},{\"../../components/dragelement/helpers\":680,\"../../lib\":799,\"../../plots/cartesian/axis_ids\":853,\"regl-splom\":535}],1319:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e){var r=t._fullLayout,i=e.uid,a=r._splomScenes;a||(a=r._splomScenes={});var o={dirty:!0,selectBatch:[],unselectBatch:[]},s=a[e.uid];return s||((s=a[i]=n.extendFlat({},o,{matrix:!1,selectBatch:[],unselectBatch:[]})).draw=function(){s.matrix&&s.matrix.draw&&(s.selectBatch.length||s.unselectBatch.length?s.matrix.draw(s.unselectBatch,s.selectBatch):s.matrix.draw()),s.dirty=!1},s.destroy=function(){s.matrix&&s.matrix.destroy&&s.matrix.destroy(),s.matrixOptions=null,s.selectBatch=null,s.unselectBatch=null,s=null}),s.dirty||n.extendFlat(s,o),s}},{\"../../lib\":799}],1320:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatter/subtypes\"),a=t(\"./helpers\");e.exports=function(t,e){var r=t.cd,o=r[0].trace,s=r[0].t,l=t.scene,c=l.matrixOptions.cdata,u=t.xaxis,f=t.yaxis,h=[];if(!l)return h;var p=!i.hasMarkers(o)&&!i.hasText(o);if(!0!==o.visible||p)return h;var d=a.getDimIndex(o,u),m=a.getDimIndex(o,f);if(!1===d||!1===m)return h;var g=s.xpx[d],v=s.ypx[m],y=c[d],x=c[m],b=[],_=[];if(!1!==e&&!e.degenerate)for(var w=0;w<y.length;w++)e.contains([g[w],v[w]],null,w,t)?(b.push(w),h.push({pointNumber:w,x:y[w],y:x[w]})):_.push(w);var T=l.matrixOptions;return b.length||_.length?l.selectBatch.length||l.unselectBatch.length||l.matrix.update(l.unselectedOptions,n.extendFlat({},T,l.selectedOptions,l.viewOpts)):l.matrix.update(T,null),l.selectBatch=b,l.unselectBatch=_,h}},{\"../../lib\":799,\"../scatter/subtypes\":1239,\"./helpers\":1315}],1321:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/attributes\"),i=t(\"../../plots/cartesian/axis_format_attributes\").axisHoverFormat,a=t(\"../../plots/template_attributes\").hovertemplateAttrs,o=t(\"../mesh3d/attributes\"),s=t(\"../../plots/attributes\"),l=t(\"../../lib/extend\").extendFlat,c={x:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},y:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},z:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},u:{valType:\"data_array\",editType:\"calc\"},v:{valType:\"data_array\",editType:\"calc\"},w:{valType:\"data_array\",editType:\"calc\"},starts:{x:{valType:\"data_array\",editType:\"calc\"},y:{valType:\"data_array\",editType:\"calc\"},z:{valType:\"data_array\",editType:\"calc\"},editType:\"calc\"},maxdisplayed:{valType:\"integer\",min:0,dflt:1e3,editType:\"calc\"},sizeref:{valType:\"number\",editType:\"calc\",min:0,dflt:1},text:{valType:\"string\",dflt:\"\",editType:\"calc\"},hovertext:{valType:\"string\",dflt:\"\",editType:\"calc\"},hovertemplate:a({editType:\"calc\"},{keys:[\"tubex\",\"tubey\",\"tubez\",\"tubeu\",\"tubev\",\"tubew\",\"norm\",\"divergence\"]}),uhoverformat:i(\"u\",1),vhoverformat:i(\"v\",1),whoverformat:i(\"w\",1),xhoverformat:i(\"x\"),yhoverformat:i(\"y\"),zhoverformat:i(\"z\"),showlegend:l({},s.showlegend,{dflt:!1})};l(c,n(\"\",{colorAttr:\"u/v/w norm\",showScaleDflt:!0,editTypeOverride:\"calc\"}));[\"opacity\",\"lightposition\",\"lighting\"].forEach((function(t){c[t]=o[t]})),c.hoverinfo=l({},s.hoverinfo,{editType:\"calc\",flags:[\"x\",\"y\",\"z\",\"u\",\"v\",\"w\",\"norm\",\"divergence\",\"text\",\"name\"],dflt:\"x+y+z+norm+text+name\"}),c.transforms=void 0,e.exports=c},{\"../../components/colorscale/attributes\":669,\"../../lib/extend\":789,\"../../plots/attributes\":845,\"../../plots/cartesian/axis_format_attributes\":852,\"../../plots/template_attributes\":922,\"../mesh3d/attributes\":1155}],1322:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/colorscale/calc\");function a(t){var e,r,i,a,s,l,c,u,f,h,p,d,m=t._x,g=t._y,v=t._z,y=t._len,x=-1/0,b=1/0,_=-1/0,w=1/0,T=-1/0,k=1/0,M=\"\";for(y&&(c=m[0],f=g[0],p=v[0]),y>1&&(u=m[y-1],h=g[y-1],d=v[y-1]),e=0;e<y;e++)x=Math.max(x,m[e]),b=Math.min(b,m[e]),_=Math.max(_,g[e]),w=Math.min(w,g[e]),T=Math.max(T,v[e]),k=Math.min(k,v[e]),a||m[e]===c||(a=!0,M+=\"x\"),s||g[e]===f||(s=!0,M+=\"y\"),l||v[e]===p||(l=!0,M+=\"z\");a||(M+=\"x\"),s||(M+=\"y\"),l||(M+=\"z\");var A=o(t._x),S=o(t._y),E=o(t._z);M=(M=(M=M.replace(\"x\",(c>u?\"-\":\"+\")+\"x\")).replace(\"y\",(f>h?\"-\":\"+\")+\"y\")).replace(\"z\",(p>d?\"-\":\"+\")+\"z\");var L=function(){y=0,A=[],S=[],E=[]};(!y||y<A.length*S.length*E.length)&&L();var C=function(t){return\"x\"===t?m:\"y\"===t?g:v},P=function(t){return\"x\"===t?A:\"y\"===t?S:E},I=function(t){return t[y-1]<t[0]?-1:1},O=C(M[1]),z=C(M[3]),D=C(M[5]),R=P(M[1]).length,F=P(M[3]).length,B=P(M[5]).length,N=!1,j=function(t,e,r){return R*(F*t+e)+r},U=I(C(M[1])),V=I(C(M[3])),q=I(C(M[5]));for(e=0;e<B-1;e++){for(r=0;r<F-1;r++){for(i=0;i<R-1;i++){var H=j(e,r,i),G=j(e,r,i+1),Y=j(e,r+1,i),W=j(e+1,r,i);if(O[H]*U<O[G]*U&&z[H]*V<z[Y]*V&&D[H]*q<D[W]*q||(N=!0),N)break}if(N)break}if(N)break}return N&&(n.warn(\"Encountered arbitrary coordinates! Unable to input data grid.\"),L()),{xMin:b,yMin:w,zMin:k,xMax:x,yMax:_,zMax:T,Xs:A,Ys:S,Zs:E,len:y,fill:M}}function o(t){return n.distinctVals(t).vals}function s(t,e){if(void 0===e&&(e=t.length),n.isTypedArray(t))return t.subarray(0,e);for(var r=[],i=0;i<e;i++)r[i]=+t[i];return r}e.exports={calc:function(t,e){e._len=Math.min(e.u.length,e.v.length,e.w.length,e.x.length,e.y.length,e.z.length),e._u=s(e.u,e._len),e._v=s(e.v,e._len),e._w=s(e.w,e._len),e._x=s(e.x,e._len),e._y=s(e.y,e._len),e._z=s(e.z,e._len);var r=a(e);e._gridFill=r.fill,e._Xs=r.Xs,e._Ys=r.Ys,e._Zs=r.Zs,e._len=r.len;var n,o,l,c=0;e.starts&&(n=s(e.starts.x||[]),o=s(e.starts.y||[]),l=s(e.starts.z||[]),c=Math.min(n.length,o.length,l.length)),e._startsX=n||[],e._startsY=o||[],e._startsZ=l||[];var u,f=0,h=1/0;for(u=0;u<e._len;u++){var p=e._u[u],d=e._v[u],m=e._w[u],g=Math.sqrt(p*p+d*d+m*m);f=Math.max(f,g),h=Math.min(h,g)}for(i(t,e,{vals:[h,f],containerStr:\"\",cLetter:\"c\"}),u=0;u<c;u++){var v=n[u];r.xMax=Math.max(r.xMax,v),r.xMin=Math.min(r.xMin,v);var y=o[u];r.yMax=Math.max(r.yMax,y),r.yMin=Math.min(r.yMin,y);var x=l[u];r.zMax=Math.max(r.zMax,x),r.zMin=Math.min(r.zMin,x)}e._slen=c,e._normMax=f,e._xbnds=[r.xMin,r.xMax],e._ybnds=[r.yMin,r.yMax],e._zbnds=[r.zMin,r.zMax]},filter:s,processGrid:a}},{\"../../components/colorscale/calc\":670,\"../../lib\":799}],1323:[function(t,e,r){\"use strict\";var n=t(\"gl-streamtube3d\"),i=n.createTubeMesh,a=t(\"../../lib\"),o=t(\"../../lib/gl_format_color\").parseColorScale,s=t(\"../../components/colorscale\").extractOpts,l=t(\"../../plots/gl3d/zip3\"),c={xaxis:0,yaxis:1,zaxis:2};function u(t,e){this.scene=t,this.uid=e,this.mesh=null,this.data=null}var f=u.prototype;function h(t){var e=t.length;return e>2?t.slice(1,e-1):2===e?[(t[0]+t[1])/2]:t}function p(t){var e=t.length;return 1===e?[.5,.5]:[t[1]-t[0],t[e-1]-t[e-2]]}function d(t,e){var r=t.fullSceneLayout,i=t.dataScale,u=e._len,f={};function d(t,e){var n=r[e],o=i[c[e]];return a.simpleMap(t,(function(t){return n.d2l(t)*o}))}if(f.vectors=l(d(e._u,\"xaxis\"),d(e._v,\"yaxis\"),d(e._w,\"zaxis\"),u),!u)return{positions:[],cells:[]};var m=d(e._Xs,\"xaxis\"),g=d(e._Ys,\"yaxis\"),v=d(e._Zs,\"zaxis\");if(f.meshgrid=[m,g,v],f.gridFill=e._gridFill,e._slen)f.startingPositions=l(d(e._startsX,\"xaxis\"),d(e._startsY,\"yaxis\"),d(e._startsZ,\"zaxis\"));else{for(var y=g[0],x=h(m),b=h(v),_=new Array(x.length*b.length),w=0,T=0;T<x.length;T++)for(var k=0;k<b.length;k++)_[w++]=[x[T],y,b[k]];f.startingPositions=_}f.colormap=o(e),f.tubeSize=e.sizeref,f.maxLength=e.maxdisplayed;var M=d(e._xbnds,\"xaxis\"),A=d(e._ybnds,\"yaxis\"),S=d(e._zbnds,\"zaxis\"),E=p(m),L=p(g),C=p(v),P=[[M[0]-E[0],A[0]-L[0],S[0]-C[0]],[M[1]+E[1],A[1]+L[1],S[1]+C[1]]],I=n(f,P),O=s(e);I.vertexIntensityBounds=[O.min/e._normMax,O.max/e._normMax];var z=e.lightposition;return I.lightPosition=[z.x,z.y,z.z],I.ambient=e.lighting.ambient,I.diffuse=e.lighting.diffuse,I.specular=e.lighting.specular,I.roughness=e.lighting.roughness,I.fresnel=e.lighting.fresnel,I.opacity=e.opacity,e._pad=I.tubeScale*e.sizeref*2,I}f.handlePick=function(t){var e=this.scene.fullSceneLayout,r=this.scene.dataScale;function n(t,n){var i=e[n],a=r[c[n]];return i.l2c(t)/a}if(t.object===this.mesh){var i=t.data.position,a=t.data.velocity;return t.traceCoordinate=[n(i[0],\"xaxis\"),n(i[1],\"yaxis\"),n(i[2],\"zaxis\"),n(a[0],\"xaxis\"),n(a[1],\"yaxis\"),n(a[2],\"zaxis\"),t.data.intensity*this.data._normMax,t.data.divergence],t.textLabel=this.data.hovertext||this.data.text,!0}},f.update=function(t){this.data=t;var e=d(this.scene,t);this.mesh.update(e)},f.dispose=function(){this.scene.glplot.remove(this.mesh),this.mesh.dispose()},e.exports=function(t,e){var r=t.glplot.gl,n=d(t,e),a=i(r,n),o=new u(t,e.uid);return o.mesh=a,o.data=e,a._trace=o,t.glplot.add(a),o}},{\"../../components/colorscale\":674,\"../../lib\":799,\"../../lib/gl_format_color\":795,\"../../plots/gl3d/zip3\":903,\"gl-streamtube3d\":348}],1324:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/colorscale/defaults\"),a=t(\"./attributes\");e.exports=function(t,e,r,o){function s(r,i){return n.coerce(t,e,a,r,i)}var l=s(\"u\"),c=s(\"v\"),u=s(\"w\"),f=s(\"x\"),h=s(\"y\"),p=s(\"z\");l&&l.length&&c&&c.length&&u&&u.length&&f&&f.length&&h&&h.length&&p&&p.length?(s(\"starts.x\"),s(\"starts.y\"),s(\"starts.z\"),s(\"maxdisplayed\"),s(\"sizeref\"),s(\"lighting.ambient\"),s(\"lighting.diffuse\"),s(\"lighting.specular\"),s(\"lighting.roughness\"),s(\"lighting.fresnel\"),s(\"lightposition.x\"),s(\"lightposition.y\"),s(\"lightposition.z\"),i(t,e,o,s,{prefix:\"\",cLetter:\"c\"}),s(\"text\"),s(\"hovertext\"),s(\"hovertemplate\"),s(\"uhoverformat\"),s(\"vhoverformat\"),s(\"whoverformat\"),s(\"xhoverformat\"),s(\"yhoverformat\"),s(\"zhoverformat\"),e._length=null):e.visible=!1}},{\"../../components/colorscale/defaults\":672,\"../../lib\":799,\"./attributes\":1321}],1325:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"streamtube\",basePlotModule:t(\"../../plots/gl3d\"),categories:[\"gl3d\",\"showLegend\"],attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:{min:\"cmin\",max:\"cmax\"},calc:t(\"./calc\").calc,plot:t(\"./convert\"),eventData:function(t,e){return t.tubex=t.x,t.tubey=t.y,t.tubez=t.z,t.tubeu=e.traceCoordinate[3],t.tubev=e.traceCoordinate[4],t.tubew=e.traceCoordinate[5],t.norm=e.traceCoordinate[6],t.divergence=e.traceCoordinate[7],delete t.x,delete t.y,delete t.z,t},meta:{}}},{\"../../plots/gl3d\":892,\"./attributes\":1321,\"./calc\":1322,\"./convert\":1323,\"./defaults\":1324}],1326:[function(t,e,r){\"use strict\";var n=t(\"../../plots/attributes\"),i=t(\"../../plots/template_attributes\").hovertemplateAttrs,a=t(\"../../plots/template_attributes\").texttemplateAttrs,o=t(\"../../components/colorscale/attributes\"),s=t(\"../../plots/domain\").attributes,l=t(\"../pie/attributes\"),c=t(\"./constants\"),u=t(\"../../lib/extend\").extendFlat;e.exports={labels:{valType:\"data_array\",editType:\"calc\"},parents:{valType:\"data_array\",editType:\"calc\"},values:{valType:\"data_array\",editType:\"calc\"},branchvalues:{valType:\"enumerated\",values:[\"remainder\",\"total\"],dflt:\"remainder\",editType:\"calc\"},count:{valType:\"flaglist\",flags:[\"branches\",\"leaves\"],dflt:\"leaves\",editType:\"calc\"},level:{valType:\"any\",editType:\"plot\",anim:!0},maxdepth:{valType:\"integer\",editType:\"plot\",dflt:-1},marker:u({colors:{valType:\"data_array\",editType:\"calc\"},line:{color:u({},l.marker.line.color,{dflt:null}),width:u({},l.marker.line.width,{dflt:1}),editType:\"calc\"},editType:\"calc\"},o(\"marker\",{colorAttr:\"colors\",anim:!1})),leaf:{opacity:{valType:\"number\",editType:\"style\",min:0,max:1},editType:\"plot\"},text:l.text,textinfo:{valType:\"flaglist\",flags:[\"label\",\"text\",\"value\",\"current path\",\"percent root\",\"percent entry\",\"percent parent\"],extras:[\"none\"],editType:\"plot\"},texttemplate:a({editType:\"plot\"},{keys:c.eventDataKeys.concat([\"label\",\"value\"])}),hovertext:l.hovertext,hoverinfo:u({},n.hoverinfo,{flags:[\"label\",\"text\",\"value\",\"name\",\"current path\",\"percent root\",\"percent entry\",\"percent parent\"],dflt:\"label+text+value+name\"}),hovertemplate:i({},{keys:c.eventDataKeys}),textfont:l.textfont,insidetextorientation:l.insidetextorientation,insidetextfont:l.insidetextfont,outsidetextfont:u({},l.outsidetextfont,{}),rotation:{valType:\"angle\",dflt:0,editType:\"plot\"},sort:l.sort,root:{color:{valType:\"color\",editType:\"calc\",dflt:\"rgba(0,0,0,0)\"},editType:\"calc\"},domain:s({name:\"sunburst\",trace:!0,editType:\"calc\"})}},{\"../../components/colorscale/attributes\":669,\"../../lib/extend\":789,\"../../plots/attributes\":845,\"../../plots/domain\":877,\"../../plots/template_attributes\":922,\"../pie/attributes\":1188,\"./constants\":1329}],1327:[function(t,e,r){\"use strict\";var n=t(\"../../plots/plots\");r.name=\"sunburst\",r.plot=function(t,e,i,a){n.plotBasePlot(r.name,t,e,i,a)},r.clean=function(t,e,i,a){n.cleanBasePlot(r.name,t,e,i,a)}},{\"../../plots/plots\":913}],1328:[function(t,e,r){\"use strict\";var n=t(\"d3-hierarchy\"),i=t(\"fast-isnumeric\"),a=t(\"../../lib\"),o=t(\"../../components/colorscale\").makeColorScaleFuncFromTrace,s=t(\"../pie/calc\").makePullColorFn,l=t(\"../pie/calc\").generateExtendedColors,c=t(\"../../components/colorscale\").calc,u=t(\"../../constants/numerical\").ALMOST_EQUAL,f={},h={},p={};r.calc=function(t,e){var r,l,f,h,p,d,m=t._fullLayout,g=e.ids,v=a.isArrayOrTypedArray(g),y=e.labels,x=e.parents,b=e.values,_=a.isArrayOrTypedArray(b),w=[],T={},k={},M=function(t){return t||\"number\"==typeof t},A=function(t){return!_||i(b[t])&&b[t]>=0};v?(r=Math.min(g.length,x.length),l=function(t){return M(g[t])&&A(t)},f=function(t){return String(g[t])}):(r=Math.min(y.length,x.length),l=function(t){return M(y[t])&&A(t)},f=function(t){return String(y[t])}),_&&(r=Math.min(r,b.length));for(var S=0;S<r;S++)if(l(S)){var E=f(S),L=M(x[S])?String(x[S]):\"\",C={i:S,id:E,pid:L,label:M(y[S])?String(y[S]):\"\"};_&&(C.v=+b[S]),w.push(C),p=E,T[h=L]?T[h].push(p):T[h]=[p],k[p]=1}if(T[\"\"]){if(T[\"\"].length>1){for(var P=a.randstr(),I=0;I<w.length;I++)\"\"===w[I].pid&&(w[I].pid=P);w.unshift({hasMultipleRoots:!0,id:P,pid:\"\",label:\"\"})}}else{var O,z=[];for(O in T)k[O]||z.push(O);if(1!==z.length)return a.warn([\"Multiple implied roots, cannot build\",e.type,\"hierarchy of\",e.name+\".\",\"These roots include:\",z.join(\", \")].join(\" \"));O=z[0],w.unshift({hasImpliedRoot:!0,id:O,pid:\"\",label:O})}try{d=n.stratify().id((function(t){return t.id})).parentId((function(t){return t.pid}))(w)}catch(t){return a.warn([\"Failed to build\",e.type,\"hierarchy of\",e.name+\".\",\"Error:\",t.message].join(\" \"))}var D=n.hierarchy(d),R=!1;if(_)switch(e.branchvalues){case\"remainder\":D.sum((function(t){return t.data.v}));break;case\"total\":D.each((function(t){var r=t.data.data,n=r.v;if(t.children){var i=t.children.reduce((function(t,e){return t+e.data.data.v}),0);if((r.hasImpliedRoot||r.hasMultipleRoots)&&(n=i),n<i*u)return R=!0,a.warn([\"Total value for node\",t.data.data.id,\"of\",e.name,\"is smaller than the sum of its children.\",\"\\nparent value =\",n,\"\\nchildren sum =\",i].join(\" \"))}t.value=n}))}else!function t(e,r,n){var i=0,a=e.children;if(a){for(var o=a.length,s=0;s<o;s++)i+=t(a[s],r,n);n.branches&&i++}else n.leaves&&i++;e.value=e.data.data.value=i,r._values||(r._values=[]);return r._values[e.data.data.i]=i,i}(D,e,{branches:-1!==e.count.indexOf(\"branches\"),leaves:-1!==e.count.indexOf(\"leaves\")});if(!R){var F,B;e.sort&&D.sort((function(t,e){return e.value-t.value}));var N=e.marker.colors||[],j=!!N.length;return e._hasColorscale?(j||(N=_?e.values:e._values),c(t,e,{vals:N,containerStr:\"marker\",cLetter:\"c\"}),B=o(e.marker)):F=s(m[\"_\"+e.type+\"colormap\"]),D.each((function(t){var r=t.data.data;r.color=e._hasColorscale?B(N[r.i]):F(N[r.i],r.id)})),w[0].hierarchy=D,w}},r._runCrossTraceCalc=function(t,e){var r=e._fullLayout,n=e.calcdata,i=r[t+\"colorway\"],a=r[\"_\"+t+\"colormap\"];r[\"extend\"+t+\"colors\"]&&(i=l(i,\"icicle\"===t?p:\"treemap\"===t?h:f));var o,s=0;function c(t){var e=t.data.data,r=e.id;!1===e.color&&(a[r]?e.color=a[r]:t.parent?t.parent.parent?e.color=t.parent.data.data.color:(a[r]=e.color=i[s%i.length],s++):e.color=o)}for(var u=0;u<n.length;u++){var d=n[u][0];d.trace.type===t&&d.hierarchy&&(o=d.trace.root.color,d.hierarchy.each(c))}},r.crossTraceCalc=function(t){return r._runCrossTraceCalc(\"sunburst\",t)}},{\"../../components/colorscale\":674,\"../../constants/numerical\":775,\"../../lib\":799,\"../pie/calc\":1190,\"d3-hierarchy\":167,\"fast-isnumeric\":245}],1329:[function(t,e,r){\"use strict\";e.exports={CLICK_TRANSITION_TIME:750,CLICK_TRANSITION_EASING:\"linear\",eventDataKeys:[\"currentPath\",\"root\",\"entry\",\"percentRoot\",\"percentEntry\",\"percentParent\"]}},{}],1330:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\"),a=t(\"../../plots/domain\").defaults,o=t(\"../bar/defaults\").handleText,s=t(\"../../components/colorscale\"),l=s.hasColorscale,c=s.handleDefaults;e.exports=function(t,e,r,s){function u(r,a){return n.coerce(t,e,i,r,a)}var f=u(\"labels\"),h=u(\"parents\");if(f&&f.length&&h&&h.length){var p=u(\"values\");p&&p.length?u(\"branchvalues\"):u(\"count\"),u(\"level\"),u(\"maxdepth\"),u(\"marker.line.width\")&&u(\"marker.line.color\",s.paper_bgcolor),u(\"marker.colors\");var d=e._hasColorscale=l(t,\"marker\",\"colors\")||(t.marker||{}).coloraxis;d&&c(t,e,s,u,{prefix:\"marker.\",cLetter:\"c\"}),u(\"leaf.opacity\",d?1:.7);var m=u(\"text\");u(\"texttemplate\"),e.texttemplate||u(\"textinfo\",Array.isArray(m)?\"text+label\":\"label\"),u(\"hovertext\"),u(\"hovertemplate\");o(t,e,s,u,\"auto\",{moduleHasSelected:!1,moduleHasUnselected:!1,moduleHasConstrain:!1,moduleHasCliponaxis:!1,moduleHasTextangle:!1,moduleHasInsideanchor:!1}),u(\"insidetextorientation\"),u(\"sort\"),u(\"rotation\"),u(\"root.color\"),a(e,s,u),e._length=null}else e.visible=!1}},{\"../../components/colorscale\":674,\"../../lib\":799,\"../../plots/domain\":877,\"../bar/defaults\":941,\"./attributes\":1326}],1331:[function(t,e,r){\"use strict\";var n=t(\"@plotly/d3\"),i=t(\"../../registry\"),a=t(\"../../components/fx/helpers\").appendArrayPointValue,o=t(\"../../components/fx\"),s=t(\"../../lib\"),l=t(\"../../lib/events\"),c=t(\"./helpers\"),u=t(\"../pie/helpers\").formatPieValue;function f(t,e,r){for(var n=t.data.data,i={curveNumber:e.index,pointNumber:n.i,data:e._input,fullData:e},o=0;o<r.length;o++){var s=r[o];s in t&&(i[s]=t[s])}return\"parentString\"in t&&!c.isHierarchyRoot(t)&&(i.parent=t.parentString),a(i,e,n.i),i}e.exports=function(t,e,r,a,h){var p=a[0],d=p.trace,m=p.hierarchy,g=\"sunburst\"===d.type,v=\"treemap\"===d.type||\"icicle\"===d.type;\"_hasHoverLabel\"in d||(d._hasHoverLabel=!1),\"_hasHoverEvent\"in d||(d._hasHoverEvent=!1);t.on(\"mouseover\",(function(i){var a=r._fullLayout;if(!r._dragging&&!1!==a.hovermode){var l=r._fullData[d.index],y=i.data.data,x=y.i,b=c.isHierarchyRoot(i),_=c.getParent(m,i),w=c.getValue(i),T=function(t){return s.castOption(l,x,t)},k=T(\"hovertemplate\"),M=o.castHoverinfo(l,a,x),A=a.separators;if(k||M&&\"none\"!==M&&\"skip\"!==M){var S,E;g&&(S=p.cx+i.pxmid[0]*(1-i.rInscribed),E=p.cy+i.pxmid[1]*(1-i.rInscribed)),v&&(S=i._hoverX,E=i._hoverY);var L,C={},P=[],I=[],O=function(t){return-1!==P.indexOf(t)};M&&(P=\"all\"===M?l._module.attributes.hoverinfo.flags:M.split(\"+\")),C.label=y.label,O(\"label\")&&C.label&&I.push(C.label),y.hasOwnProperty(\"v\")&&(C.value=y.v,C.valueLabel=u(C.value,A),O(\"value\")&&I.push(C.valueLabel)),C.currentPath=i.currentPath=c.getPath(i.data),O(\"current path\")&&!b&&I.push(C.currentPath);var z=[],D=function(){-1===z.indexOf(L)&&(I.push(L),z.push(L))};C.percentParent=i.percentParent=w/c.getValue(_),C.parent=i.parentString=c.getPtLabel(_),O(\"percent parent\")&&(L=c.formatPercent(C.percentParent,A)+\" of \"+C.parent,D()),C.percentEntry=i.percentEntry=w/c.getValue(e),C.entry=i.entry=c.getPtLabel(e),!O(\"percent entry\")||b||i.onPathbar||(L=c.formatPercent(C.percentEntry,A)+\" of \"+C.entry,D()),C.percentRoot=i.percentRoot=w/c.getValue(m),C.root=i.root=c.getPtLabel(m),O(\"percent root\")&&!b&&(L=c.formatPercent(C.percentRoot,A)+\" of \"+C.root,D()),C.text=T(\"hovertext\")||T(\"text\"),O(\"text\")&&(L=C.text,s.isValidTextValue(L)&&I.push(L));var R={trace:l,y:E,text:I.join(\"<br>\"),name:k||O(\"name\")?l.name:void 0,color:T(\"hoverlabel.bgcolor\")||y.color,borderColor:T(\"hoverlabel.bordercolor\"),fontFamily:T(\"hoverlabel.font.family\"),fontSize:T(\"hoverlabel.font.size\"),fontColor:T(\"hoverlabel.font.color\"),nameLength:T(\"hoverlabel.namelength\"),textAlign:T(\"hoverlabel.align\"),hovertemplate:k,hovertemplateLabels:C,eventData:[f(i,l,h.eventDataKeys)]};g&&(R.x0=S-i.rInscribed*i.rpx1,R.x1=S+i.rInscribed*i.rpx1,R.idealAlign=i.pxmid[0]<0?\"left\":\"right\"),v&&(R.x=S,R.idealAlign=S<0?\"left\":\"right\"),o.loneHover(R,{container:a._hoverlayer.node(),outerContainer:a._paper.node(),gd:r}),d._hasHoverLabel=!0}if(v){var F=t.select(\"path.surface\");h.styleOne(F,i,l,{hovered:!0})}d._hasHoverEvent=!0,r.emit(\"plotly_hover\",{points:[f(i,l,h.eventDataKeys)],event:n.event})}})),t.on(\"mouseout\",(function(e){var i=r._fullLayout,a=r._fullData[d.index],s=n.select(this).datum();if(d._hasHoverEvent&&(e.originalEvent=n.event,r.emit(\"plotly_unhover\",{points:[f(s,a,h.eventDataKeys)],event:n.event}),d._hasHoverEvent=!1),d._hasHoverLabel&&(o.loneUnhover(i._hoverlayer.node()),d._hasHoverLabel=!1),v){var l=t.select(\"path.surface\");h.styleOne(l,s,a,{hovered:!1})}})),t.on(\"click\",(function(t){var e=r._fullLayout,a=r._fullData[d.index],s=g&&(c.isHierarchyRoot(t)||c.isLeaf(t)),u=c.getPtId(t),p=c.isEntry(t)?c.findEntryWithChild(m,u):c.findEntryWithLevel(m,u),v=c.getPtId(p),y={points:[f(t,a,h.eventDataKeys)],event:n.event};s||(y.nextLevel=v);var x=l.triggerHandler(r,\"plotly_\"+d.type+\"click\",y);if(!1!==x&&e.hovermode&&(r._hoverdata=[f(t,a,h.eventDataKeys)],o.click(r,n.event)),!s&&!1!==x&&!r._dragging&&!r._transitioning){i.call(\"_storeDirectGUIEdit\",a,e._tracePreGUI[a.uid],{level:a.level});var b={data:[{level:v}],traces:[d.index]},_={frame:{redraw:!1,duration:h.transitionTime},transition:{duration:h.transitionTime,easing:h.transitionEasing},mode:\"immediate\",fromcurrent:!0};o.loneUnhover(e._hoverlayer.node()),i.call(\"animate\",r,b,_)}}))}},{\"../../components/fx\":702,\"../../components/fx/helpers\":698,\"../../lib\":799,\"../../lib/events\":788,\"../../registry\":927,\"../pie/helpers\":1193,\"./helpers\":1332,\"@plotly/d3\":58}],1332:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/color\"),a=t(\"../../lib/setcursor\"),o=t(\"../pie/helpers\");function s(t){return t.data.data.pid}r.findEntryWithLevel=function(t,e){var n;return e&&t.eachAfter((function(t){if(r.getPtId(t)===e)return n=t.copy()})),n||t},r.findEntryWithChild=function(t,e){var n;return t.eachAfter((function(t){for(var i=t.children||[],a=0;a<i.length;a++){var o=i[a];if(r.getPtId(o)===e)return n=t.copy()}})),n||t},r.isEntry=function(t){return!t.parent},r.isLeaf=function(t){return!t.children},r.getPtId=function(t){return t.data.data.id},r.getPtLabel=function(t){return t.data.data.label},r.getValue=function(t){return t.value},r.isHierarchyRoot=function(t){return\"\"===s(t)},r.setSliceCursor=function(t,e,n){var i=n.isTransitioning;if(!i){var o=t.datum();i=n.hideOnRoot&&r.isHierarchyRoot(o)||n.hideOnLeaves&&r.isLeaf(o)}a(t,i?null:\"pointer\")},r.getInsideTextFontKey=function(t,e,r,i,a){var o=(a||{}).onPathbar?\"pathbar.textfont\":\"insidetextfont\",s=r.data.data.i;return n.castOption(e,s,o+\".\"+t)||n.castOption(e,s,\"textfont.\"+t)||i.size},r.getOutsideTextFontKey=function(t,e,r,i){var a=r.data.data.i;return n.castOption(e,a,\"outsidetextfont.\"+t)||n.castOption(e,a,\"textfont.\"+t)||i.size},r.isOutsideText=function(t,e){return!t._hasColorscale&&r.isHierarchyRoot(e)},r.determineTextFont=function(t,e,a,o){return r.isOutsideText(t,e)?function(t,e,n){return{color:r.getOutsideTextFontKey(\"color\",t,e,n),family:r.getOutsideTextFontKey(\"family\",t,e,n),size:r.getOutsideTextFontKey(\"size\",t,e,n)}}(t,e,a):function(t,e,a,o){var s=(o||{}).onPathbar,l=e.data.data,c=l.i,u=n.castOption(t,c,(s?\"pathbar.textfont\":\"insidetextfont\")+\".color\");return!u&&t._input.textfont&&(u=n.castOption(t._input,c,\"textfont.color\")),{color:u||i.contrast(l.color),family:r.getInsideTextFontKey(\"family\",t,e,a,o),size:r.getInsideTextFontKey(\"size\",t,e,a,o)}}(t,e,a,o)},r.hasTransition=function(t){return!!(t&&t.duration>0)},r.getMaxDepth=function(t){return t.maxdepth>=0?t.maxdepth:1/0},r.isHeader=function(t,e){return!(r.isLeaf(t)||t.depth===e._maxDepth-1)},r.getParent=function(t,e){return r.findEntryWithLevel(t,s(e))},r.listPath=function(t,e){var n=t.parent;if(!n)return[];var i=e?[n.data[e]]:[n];return r.listPath(n,e).concat(i)},r.getPath=function(t){return r.listPath(t,\"label\").join(\"/\")+\"/\"},r.formatValue=o.formatPieValue,r.formatPercent=function(t,e){var r=n.formatPercent(t,0);return\"0%\"===r&&(r=o.formatPiePercent(t,e)),r}},{\"../../components/color\":662,\"../../lib\":799,\"../../lib/setcursor\":820,\"../pie/helpers\":1193}],1333:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"sunburst\",basePlotModule:t(\"./base_plot\"),categories:[],animatable:!0,attributes:t(\"./attributes\"),layoutAttributes:t(\"./layout_attributes\"),supplyDefaults:t(\"./defaults\"),supplyLayoutDefaults:t(\"./layout_defaults\"),calc:t(\"./calc\").calc,crossTraceCalc:t(\"./calc\").crossTraceCalc,plot:t(\"./plot\").plot,style:t(\"./style\").style,colorbar:t(\"../scatter/marker_colorbar\"),meta:{}}},{\"../scatter/marker_colorbar\":1232,\"./attributes\":1326,\"./base_plot\":1327,\"./calc\":1328,\"./defaults\":1330,\"./layout_attributes\":1334,\"./layout_defaults\":1335,\"./plot\":1336,\"./style\":1337}],1334:[function(t,e,r){\"use strict\";e.exports={sunburstcolorway:{valType:\"colorlist\",editType:\"calc\"},extendsunburstcolors:{valType:\"boolean\",dflt:!0,editType:\"calc\"}}},{}],1335:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\");e.exports=function(t,e){function r(r,a){return n.coerce(t,e,i,r,a)}r(\"sunburstcolorway\",e.colorway),r(\"extendsunburstcolors\")}},{\"../../lib\":799,\"./layout_attributes\":1334}],1336:[function(t,e,r){\"use strict\";var n=t(\"@plotly/d3\"),i=t(\"d3-hierarchy\"),a=t(\"../../components/drawing\"),o=t(\"../../lib\"),s=t(\"../../lib/svg_text_utils\"),l=t(\"../bar/uniform_text\"),c=l.recordMinTextSize,u=l.clearMinTextSize,f=t(\"../pie/plot\"),h=t(\"../pie/helpers\").getRotationAngle,p=f.computeTransform,d=f.transformInsideText,m=t(\"./style\").styleOne,g=t(\"../bar/style\").resizeText,v=t(\"./fx\"),y=t(\"./constants\"),x=t(\"./helpers\");function b(t,e,l,u){var f=t._fullLayout,g=!f.uniformtext.mode&&x.hasTransition(u),b=n.select(l).selectAll(\"g.slice\"),w=e[0],T=w.trace,k=w.hierarchy,M=x.findEntryWithLevel(k,T.level),A=x.getMaxDepth(T),S=f._size,E=T.domain,L=S.w*(E.x[1]-E.x[0]),C=S.h*(E.y[1]-E.y[0]),P=.5*Math.min(L,C),I=w.cx=S.l+S.w*(E.x[1]+E.x[0])/2,O=w.cy=S.t+S.h*(1-E.y[0])-C/2;if(!M)return b.remove();var z=null,D={};g&&b.each((function(t){D[x.getPtId(t)]={rpx0:t.rpx0,rpx1:t.rpx1,x0:t.x0,x1:t.x1,transform:t.transform},!z&&x.isEntry(t)&&(z=t)}));var R=function(t){return i.partition().size([2*Math.PI,t.height+1])(t)}(M).descendants(),F=M.height+1,B=0,N=A;w.hasMultipleRoots&&x.isHierarchyRoot(M)&&(R=R.slice(1),F-=1,B=1,N+=1),R=R.filter((function(t){return t.y1<=N}));var j=h(T.rotation);j&&R.forEach((function(t){t.x0+=j,t.x1+=j}));var U=Math.min(F,A),V=function(t){return(t-B)/U*P},q=function(t,e){return[t*Math.cos(e),-t*Math.sin(e)]},H=function(t){return o.pathAnnulus(t.rpx0,t.rpx1,t.x0,t.x1,I,O)},G=function(t){return I+_(t)[0]*(t.transform.rCenter||0)+(t.transform.x||0)},Y=function(t){return O+_(t)[1]*(t.transform.rCenter||0)+(t.transform.y||0)};(b=b.data(R,x.getPtId)).enter().append(\"g\").classed(\"slice\",!0),g?b.exit().transition().each((function(){var t=n.select(this);t.select(\"path.surface\").transition().attrTween(\"d\",(function(t){var e=function(t){var e,r=x.getPtId(t),i=D[r],a=D[x.getPtId(M)];if(a){var o=(t.x1>a.x1?2*Math.PI:0)+j;e=t.rpx1<a.rpx1?{rpx0:0,rpx1:0}:{x0:o,x1:o}}else{var s,l=x.getPtId(t.parent);b.each((function(t){if(x.getPtId(t)===l)return s=t}));var c,u=s.children;u.forEach((function(t,e){if(x.getPtId(t)===r)return c=e}));var f=u.length,h=n.interpolate(s.x0,s.x1);e={rpx0:P,rpx1:P,x0:h(c/f),x1:h((c+1)/f)}}return n.interpolate(i,e)}(t);return function(t){return H(e(t))}})),t.select(\"g.slicetext\").attr(\"opacity\",0)})).remove():b.exit().remove(),b.order();var W=null;if(g&&z){var X=x.getPtId(z);b.each((function(t){null===W&&x.getPtId(t)===X&&(W=t.x1)}))}var Z=b;function J(t){var e=t.parent,r=D[x.getPtId(e)],i={};if(r){var a=e.children,o=a.indexOf(t),s=a.length,l=n.interpolate(r.x0,r.x1);i.x0=l(o/s),i.x1=l(o/s)}else i.x0=i.x1=0;return i}g&&(Z=Z.transition().each(\"end\",(function(){var e=n.select(this);x.setSliceCursor(e,t,{hideOnRoot:!0,hideOnLeaves:!0,isTransitioning:!1})}))),Z.each((function(i){var l=n.select(this),u=o.ensureSingle(l,\"path\",\"surface\",(function(t){t.style(\"pointer-events\",\"all\")}));i.rpx0=V(i.y0),i.rpx1=V(i.y1),i.xmid=(i.x0+i.x1)/2,i.pxmid=q(i.rpx1,i.xmid),i.midangle=-(i.xmid-Math.PI/2),i.startangle=-(i.x0-Math.PI/2),i.stopangle=-(i.x1-Math.PI/2),i.halfangle=.5*Math.min(o.angleDelta(i.x0,i.x1)||Math.PI,Math.PI),i.ring=1-i.rpx0/i.rpx1,i.rInscribed=function(t){return 0===t.rpx0&&o.isFullCircle([t.x0,t.x1])?1:Math.max(0,Math.min(1/(1+1/Math.sin(t.halfangle)),t.ring/2))}(i),g?u.transition().attrTween(\"d\",(function(t){var e=function(t){var e,r=D[x.getPtId(t)],i={x0:t.x0,x1:t.x1,rpx0:t.rpx0,rpx1:t.rpx1};if(r)e=r;else if(z)if(t.parent)if(W){var a=(t.x1>W?2*Math.PI:0)+j;e={x0:a,x1:a}}else e={rpx0:P,rpx1:P},o.extendFlat(e,J(t));else e={rpx0:0,rpx1:0};else e={x0:j,x1:j};return n.interpolate(e,i)}(t);return function(t){return H(e(t))}})):u.attr(\"d\",H),l.call(v,M,t,e,{eventDataKeys:y.eventDataKeys,transitionTime:y.CLICK_TRANSITION_TIME,transitionEasing:y.CLICK_TRANSITION_EASING}).call(x.setSliceCursor,t,{hideOnRoot:!0,hideOnLeaves:!0,isTransitioning:t._transitioning}),u.call(m,i,T);var h=o.ensureSingle(l,\"g\",\"slicetext\"),b=o.ensureSingle(h,\"text\",\"\",(function(t){t.attr(\"data-notex\",1)})),_=o.ensureUniformFontSize(t,x.determineTextFont(T,i,f.font));b.text(r.formatSliceLabel(i,M,T,e,f)).classed(\"slicetext\",!0).attr(\"text-anchor\",\"middle\").call(a.font,_).call(s.convertToTspans,t);var k=a.bBox(b.node());i.transform=d(k,i,w),i.transform.targetX=G(i),i.transform.targetY=Y(i);var A=function(t,e){var r=t.transform;return p(r,e),r.fontSize=_.size,c(T.type,r,f),o.getTextTransform(r)};g?b.transition().attrTween(\"transform\",(function(t){var e=function(t){var e,r=D[x.getPtId(t)],i=t.transform;if(r)e=r;else if(e={rpx1:t.rpx1,transform:{textPosAngle:i.textPosAngle,scale:0,rotate:i.rotate,rCenter:i.rCenter,x:i.x,y:i.y}},z)if(t.parent)if(W){var a=t.x1>W?2*Math.PI:0;e.x0=e.x1=a}else o.extendFlat(e,J(t));else e.x0=e.x1=j;else e.x0=e.x1=j;var s=n.interpolate(e.transform.textPosAngle,t.transform.textPosAngle),l=n.interpolate(e.rpx1,t.rpx1),u=n.interpolate(e.x0,t.x0),h=n.interpolate(e.x1,t.x1),p=n.interpolate(e.transform.scale,i.scale),d=n.interpolate(e.transform.rotate,i.rotate),m=0===i.rCenter?3:0===e.transform.rCenter?1/3:1,g=n.interpolate(e.transform.rCenter,i.rCenter);return function(t){var e=l(t),r=u(t),n=h(t),a=function(t){return g(Math.pow(t,m))}(t),o={pxmid:q(e,(r+n)/2),rpx1:e,transform:{textPosAngle:s(t),rCenter:a,x:i.x,y:i.y}};return c(T.type,i,f),{transform:{targetX:G(o),targetY:Y(o),scale:p(t),rotate:d(t),rCenter:a}}}}(t);return function(t){return A(e(t),k)}})):b.attr(\"transform\",A(i,k))}))}function _(t){return e=t.rpx1,r=t.transform.textPosAngle,[e*Math.sin(r),-e*Math.cos(r)];var e,r}r.plot=function(t,e,r,i){var a,o,s=t._fullLayout,l=s._sunburstlayer,c=!r,f=!s.uniformtext.mode&&x.hasTransition(r);(u(\"sunburst\",s),(a=l.selectAll(\"g.trace.sunburst\").data(e,(function(t){return t[0].trace.uid}))).enter().append(\"g\").classed(\"trace\",!0).classed(\"sunburst\",!0).attr(\"stroke-linejoin\",\"round\"),a.order(),f)?(i&&(o=i()),n.transition().duration(r.duration).ease(r.easing).each(\"end\",(function(){o&&o()})).each(\"interrupt\",(function(){o&&o()})).each((function(){l.selectAll(\"g.trace\").each((function(e){b(t,e,this,r)}))}))):(a.each((function(e){b(t,e,this,r)})),s.uniformtext.mode&&g(t,s._sunburstlayer.selectAll(\".trace\"),\"sunburst\"));c&&a.exit().remove()},r.formatSliceLabel=function(t,e,r,n,i){var a=r.texttemplate,s=r.textinfo;if(!(a||s&&\"none\"!==s))return\"\";var l=i.separators,c=n[0],u=t.data.data,f=c.hierarchy,h=x.isHierarchyRoot(t),p=x.getParent(f,t),d=x.getValue(t);if(!a){var m,g=s.split(\"+\"),v=function(t){return-1!==g.indexOf(t)},y=[];if(v(\"label\")&&u.label&&y.push(u.label),u.hasOwnProperty(\"v\")&&v(\"value\")&&y.push(x.formatValue(u.v,l)),!h){v(\"current path\")&&y.push(x.getPath(t.data));var b=0;v(\"percent parent\")&&b++,v(\"percent entry\")&&b++,v(\"percent root\")&&b++;var _=b>1;if(b){var w,T=function(t){m=x.formatPercent(w,l),_&&(m+=\" of \"+t),y.push(m)};v(\"percent parent\")&&!h&&(w=d/x.getValue(p),T(\"parent\")),v(\"percent entry\")&&(w=d/x.getValue(e),T(\"entry\")),v(\"percent root\")&&(w=d/x.getValue(f),T(\"root\"))}}return v(\"text\")&&(m=o.castOption(r,u.i,\"text\"),o.isValidTextValue(m)&&y.push(m)),y.join(\"<br>\")}var k=o.castOption(r,u.i,\"texttemplate\");if(!k)return\"\";var M={};u.label&&(M.label=u.label),u.hasOwnProperty(\"v\")&&(M.value=u.v,M.valueLabel=x.formatValue(u.v,l)),M.currentPath=x.getPath(t.data),h||(M.percentParent=d/x.getValue(p),M.percentParentLabel=x.formatPercent(M.percentParent,l),M.parent=x.getPtLabel(p)),M.percentEntry=d/x.getValue(e),M.percentEntryLabel=x.formatPercent(M.percentEntry,l),M.entry=x.getPtLabel(e),M.percentRoot=d/x.getValue(f),M.percentRootLabel=x.formatPercent(M.percentRoot,l),M.root=x.getPtLabel(f),u.hasOwnProperty(\"color\")&&(M.color=u.color);var A=o.castOption(r,u.i,\"text\");return(o.isValidTextValue(A)||\"\"===A)&&(M.text=A),M.customdata=o.castOption(r,u.i,\"customdata\"),o.texttemplateString(k,M,i._d3locale,M,r._meta||{})}},{\"../../components/drawing\":684,\"../../lib\":799,\"../../lib/svg_text_utils\":824,\"../bar/style\":951,\"../bar/uniform_text\":953,\"../pie/helpers\":1193,\"../pie/plot\":1197,\"./constants\":1329,\"./fx\":1331,\"./helpers\":1332,\"./style\":1337,\"@plotly/d3\":58,\"d3-hierarchy\":167}],1337:[function(t,e,r){\"use strict\";var n=t(\"@plotly/d3\"),i=t(\"../../components/color\"),a=t(\"../../lib\"),o=t(\"../bar/uniform_text\").resizeText;function s(t,e,r){var n=e.data.data,o=!e.children,s=n.i,l=a.castOption(r,s,\"marker.line.color\")||i.defaultLine,c=a.castOption(r,s,\"marker.line.width\")||0;t.style(\"stroke-width\",c).call(i.fill,n.color).call(i.stroke,l).style(\"opacity\",o?r.leaf.opacity:null)}e.exports={style:function(t){var e=t._fullLayout._sunburstlayer.selectAll(\".trace\");o(t,e,\"sunburst\"),e.each((function(t){var e=n.select(this),r=t[0].trace;e.style(\"opacity\",r.opacity),e.selectAll(\"path.surface\").each((function(t){n.select(this).call(s,t,r)}))}))},styleOne:s}},{\"../../components/color\":662,\"../../lib\":799,\"../bar/uniform_text\":953,\"@plotly/d3\":58}],1338:[function(t,e,r){\"use strict\";var n=t(\"../../components/color\"),i=t(\"../../components/colorscale/attributes\"),a=t(\"../../plots/cartesian/axis_format_attributes\").axisHoverFormat,o=t(\"../../plots/template_attributes\").hovertemplateAttrs,s=t(\"../../plots/attributes\"),l=t(\"../../lib/extend\").extendFlat,c=t(\"../../plot_api/edit_types\").overrideAll;function u(t){return{show:{valType:\"boolean\",dflt:!1},start:{valType:\"number\",dflt:null,editType:\"plot\"},end:{valType:\"number\",dflt:null,editType:\"plot\"},size:{valType:\"number\",dflt:null,min:0,editType:\"plot\"},project:{x:{valType:\"boolean\",dflt:!1},y:{valType:\"boolean\",dflt:!1},z:{valType:\"boolean\",dflt:!1}},color:{valType:\"color\",dflt:n.defaultLine},usecolormap:{valType:\"boolean\",dflt:!1},width:{valType:\"number\",min:1,max:16,dflt:2},highlight:{valType:\"boolean\",dflt:!0},highlightcolor:{valType:\"color\",dflt:n.defaultLine},highlightwidth:{valType:\"number\",min:1,max:16,dflt:2}}}var f=e.exports=c(l({z:{valType:\"data_array\"},x:{valType:\"data_array\"},y:{valType:\"data_array\"},text:{valType:\"string\",dflt:\"\",arrayOk:!0},hovertext:{valType:\"string\",dflt:\"\",arrayOk:!0},hovertemplate:o(),xhoverformat:a(\"x\"),yhoverformat:a(\"y\"),zhoverformat:a(\"z\"),connectgaps:{valType:\"boolean\",dflt:!1,editType:\"calc\"},surfacecolor:{valType:\"data_array\"}},i(\"\",{colorAttr:\"z or surfacecolor\",showScaleDflt:!0,autoColorDflt:!1,editTypeOverride:\"calc\"}),{contours:{x:u(),y:u(),z:u()},hidesurface:{valType:\"boolean\",dflt:!1},lightposition:{x:{valType:\"number\",min:-1e5,max:1e5,dflt:10},y:{valType:\"number\",min:-1e5,max:1e5,dflt:1e4},z:{valType:\"number\",min:-1e5,max:1e5,dflt:0}},lighting:{ambient:{valType:\"number\",min:0,max:1,dflt:.8},diffuse:{valType:\"number\",min:0,max:1,dflt:.8},specular:{valType:\"number\",min:0,max:2,dflt:.05},roughness:{valType:\"number\",min:0,max:1,dflt:.5},fresnel:{valType:\"number\",min:0,max:5,dflt:.2}},opacity:{valType:\"number\",min:0,max:1,dflt:1},opacityscale:{valType:\"any\",editType:\"calc\"},_deprecated:{zauto:l({},i.zauto,{}),zmin:l({},i.zmin,{}),zmax:l({},i.zmax,{})},hoverinfo:l({},s.hoverinfo),showlegend:l({},s.showlegend,{dflt:!1})}),\"calc\",\"nested\");f.x.editType=f.y.editType=f.z.editType=\"calc+clearAxisTypes\",f.transforms=void 0},{\"../../components/color\":662,\"../../components/colorscale/attributes\":669,\"../../lib/extend\":789,\"../../plot_api/edit_types\":831,\"../../plots/attributes\":845,\"../../plots/cartesian/axis_format_attributes\":852,\"../../plots/template_attributes\":922}],1339:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/calc\");e.exports=function(t,e){e.surfacecolor?n(t,e,{vals:e.surfacecolor,containerStr:\"\",cLetter:\"c\"}):n(t,e,{vals:e.z,containerStr:\"\",cLetter:\"c\"})}},{\"../../components/colorscale/calc\":670}],1340:[function(t,e,r){\"use strict\";var n=t(\"gl-surface3d\"),i=t(\"ndarray\"),a=t(\"ndarray-linear-interpolate\").d2,o=t(\"../heatmap/interp2d\"),s=t(\"../heatmap/find_empties\"),l=t(\"../../lib\").isArrayOrTypedArray,c=t(\"../../lib/gl_format_color\").parseColorScale,u=t(\"../../lib/str2rgbarray\"),f=t(\"../../components/colorscale\").extractOpts;function h(t,e,r){this.scene=t,this.uid=r,this.surface=e,this.data=null,this.showContour=[!1,!1,!1],this.contourStart=[null,null,null],this.contourEnd=[null,null,null],this.contourSize=[0,0,0],this.minValues=[1/0,1/0,1/0],this.maxValues=[-1/0,-1/0,-1/0],this.dataScaleX=1,this.dataScaleY=1,this.refineData=!0,this.objectOffset=[0,0,0]}var p=h.prototype;p.getXat=function(t,e,r,n){var i=l(this.data.x)?l(this.data.x[0])?this.data.x[e][t]:this.data.x[t]:t;return void 0===r?i:n.d2l(i,0,r)},p.getYat=function(t,e,r,n){var i=l(this.data.y)?l(this.data.y[0])?this.data.y[e][t]:this.data.y[e]:e;return void 0===r?i:n.d2l(i,0,r)},p.getZat=function(t,e,r,n){var i=this.data.z[e][t];return null===i&&this.data.connectgaps&&this.data._interpolatedZ&&(i=this.data._interpolatedZ[e][t]),void 0===r?i:n.d2l(i,0,r)},p.handlePick=function(t){if(t.object===this.surface){var e=(t.data.index[0]-1)/this.dataScaleX-1,r=(t.data.index[1]-1)/this.dataScaleY-1,n=Math.max(Math.min(Math.round(e),this.data.z[0].length-1),0),i=Math.max(Math.min(Math.round(r),this.data._ylength-1),0);t.index=[n,i],t.traceCoordinate=[this.getXat(n,i),this.getYat(n,i),this.getZat(n,i)],t.dataCoordinate=[this.getXat(n,i,this.data.xcalendar,this.scene.fullSceneLayout.xaxis),this.getYat(n,i,this.data.ycalendar,this.scene.fullSceneLayout.yaxis),this.getZat(n,i,this.data.zcalendar,this.scene.fullSceneLayout.zaxis)];for(var a=0;a<3;a++){var o=t.dataCoordinate[a];null!=o&&(t.dataCoordinate[a]*=this.scene.dataScale[a])}var s=this.data.hovertext||this.data.text;return Array.isArray(s)&&s[i]&&void 0!==s[i][n]?t.textLabel=s[i][n]:t.textLabel=s||\"\",t.data.dataCoordinate=t.dataCoordinate.slice(),this.surface.highlight(t.data),this.scene.glplot.spikes.position=t.dataCoordinate,!0}};var d=[2,3,5,7,11,13,17,19,23,29,31,37,41,43,47,53,59,61,67,71,73,79,83,89,97,101,103,107,109,113,127,131,137,139,149,151,157,163,167,173,179,181,191,193,197,199,211,223,227,229,233,239,241,251,257,263,269,271,277,281,283,293,307,311,313,317,331,337,347,349,353,359,367,373,379,383,389,397,401,409,419,421,431,433,439,443,449,457,461,463,467,479,487,491,499,503,509,521,523,541,547,557,563,569,571,577,587,593,599,601,607,613,617,619,631,641,643,647,653,659,661,673,677,683,691,701,709,719,727,733,739,743,751,757,761,769,773,787,797,809,811,821,823,827,829,839,853,857,859,863,877,881,883,887,907,911,919,929,937,941,947,953,967,971,977,983,991,997,1009,1013,1019,1021,1031,1033,1039,1049,1051,1061,1063,1069,1087,1091,1093,1097,1103,1109,1117,1123,1129,1151,1153,1163,1171,1181,1187,1193,1201,1213,1217,1223,1229,1231,1237,1249,1259,1277,1279,1283,1289,1291,1297,1301,1303,1307,1319,1321,1327,1361,1367,1373,1381,1399,1409,1423,1427,1429,1433,1439,1447,1451,1453,1459,1471,1481,1483,1487,1489,1493,1499,1511,1523,1531,1543,1549,1553,1559,1567,1571,1579,1583,1597,1601,1607,1609,1613,1619,1621,1627,1637,1657,1663,1667,1669,1693,1697,1699,1709,1721,1723,1733,1741,1747,1753,1759,1777,1783,1787,1789,1801,1811,1823,1831,1847,1861,1867,1871,1873,1877,1879,1889,1901,1907,1913,1931,1933,1949,1951,1973,1979,1987,1993,1997,1999,2003,2011,2017,2027,2029,2039,2053,2063,2069,2081,2083,2087,2089,2099,2111,2113,2129,2131,2137,2141,2143,2153,2161,2179,2203,2207,2213,2221,2237,2239,2243,2251,2267,2269,2273,2281,2287,2293,2297,2309,2311,2333,2339,2341,2347,2351,2357,2371,2377,2381,2383,2389,2393,2399,2411,2417,2423,2437,2441,2447,2459,2467,2473,2477,2503,2521,2531,2539,2543,2549,2551,2557,2579,2591,2593,2609,2617,2621,2633,2647,2657,2659,2663,2671,2677,2683,2687,2689,2693,2699,2707,2711,2713,2719,2729,2731,2741,2749,2753,2767,2777,2789,2791,2797,2801,2803,2819,2833,2837,2843,2851,2857,2861,2879,2887,2897,2903,2909,2917,2927,2939,2953,2957,2963,2969,2971,2999];function m(t,e){if(t<e)return 0;for(var r=0;0===Math.floor(t%e);)t/=e,r++;return r}function g(t){for(var e=[],r=0;r<d.length;r++){var n=d[r];e.push(m(t,n))}return e}function v(t){for(var e=g(t),r=t,n=0;n<d.length;n++)if(e[n]>0){r=d[n];break}return r}function y(t,e){if(!(t<1||e<1)){for(var r=g(t),n=g(e),i=1,a=0;a<d.length;a++)i*=Math.pow(d[a],Math.max(r[a],n[a]));return i}}p.calcXnums=function(t){var e,r=[];for(e=1;e<t;e++){var n=this.getXat(e-1,0),i=this.getXat(e,0);r[e-1]=i!==n&&null!=n&&null!=i?Math.abs(i-n):0}var a=0;for(e=1;e<t;e++)a+=r[e-1];for(e=1;e<t;e++)0===r[e-1]?r[e-1]=1:r[e-1]=Math.round(a/r[e-1]);return r},p.calcYnums=function(t){var e,r=[];for(e=1;e<t;e++){var n=this.getYat(0,e-1),i=this.getYat(0,e);r[e-1]=i!==n&&null!=n&&null!=i?Math.abs(i-n):0}var a=0;for(e=1;e<t;e++)a+=r[e-1];for(e=1;e<t;e++)0===r[e-1]?r[e-1]=1:r[e-1]=Math.round(a/r[e-1]);return r};var x=[1,2,4,6,12,24,36,48,60,120,180,240,360,720,840,1260],b=x[9],_=x[13];function w(t,e,r){var n=r[8]+r[2]*e[0]+r[5]*e[1];return t[0]=(r[6]+r[0]*e[0]+r[3]*e[1])/n,t[1]=(r[7]+r[1]*e[0]+r[4]*e[1])/n,t}function T(t,e,r){return function(t,e,r,n){for(var i=[0,0],o=t.shape[0],s=t.shape[1],l=0;l<o;l++)for(var c=0;c<s;c++)r(i,[l,c],n),t.set(l,c,a(e,i[0],i[1]))}(t,e,w,r),t}function k(t,e){for(var r=!1,n=0;n<t.length;n++)if(e===t[n]){r=!0;break}!1===r&&t.push(e)}p.estimateScale=function(t,e){for(var r=1+function(t){if(0!==t.length){for(var e=1,r=0;r<t.length;r++)e=y(e,t[r]);return e}}(0===e?this.calcXnums(t):this.calcYnums(t));r<b;)r*=2;for(;r>_;)r--,r/=v(r),++r<b&&(r=_);var n=Math.round(r/t);return n>1?n:1},p.refineCoords=function(t){for(var e=this.dataScaleX,r=this.dataScaleY,n=t[0].shape[0],a=t[0].shape[1],o=0|Math.floor(t[0].shape[0]*e+1),s=0|Math.floor(t[0].shape[1]*r+1),l=1+n+1,c=1+a+1,u=i(new Float32Array(l*c),[l,c]),f=[1/e,0,0,0,1/r,0,0,0,1],h=0;h<t.length;++h){this.surface.padField(u,t[h]);var p=i(new Float32Array(o*s),[o,s]);T(p,u,f),t[h]=p}},p.setContourLevels=function(){var t,e,r,n=[[],[],[]],i=[!1,!1,!1],a=!1;for(t=0;t<3;++t)if(this.showContour[t]&&(a=!0,this.contourSize[t]>0&&null!==this.contourStart[t]&&null!==this.contourEnd[t]&&this.contourEnd[t]>this.contourStart[t]))for(i[t]=!0,e=this.contourStart[t];e<this.contourEnd[t];e+=this.contourSize[t])r=e*this.scene.dataScale[t],k(n[t],r);if(a){var o=[[],[],[]];for(t=0;t<3;++t)this.showContour[t]&&(o[t]=i[t]?n[t]:this.scene.contourLevels[t]);this.surface.update({levels:o})}},p.update=function(t){var e,r,n,a,l=this.scene,h=l.fullSceneLayout,p=this.surface,d=c(t),m=l.dataScale,g=t.z[0].length,v=t._ylength,y=l.contourLevels;this.data=t;var x=[];for(e=0;e<3;e++)for(x[e]=[],r=0;r<g;r++)x[e][r]=[];for(r=0;r<g;r++)for(n=0;n<v;n++)x[0][r][n]=this.getXat(r,n,t.xcalendar,h.xaxis),x[1][r][n]=this.getYat(r,n,t.ycalendar,h.yaxis),x[2][r][n]=this.getZat(r,n,t.zcalendar,h.zaxis);if(t.connectgaps)for(t._emptypoints=s(x[2]),o(x[2],t._emptypoints),t._interpolatedZ=[],r=0;r<g;r++)for(t._interpolatedZ[r]=[],n=0;n<v;n++)t._interpolatedZ[r][n]=x[2][r][n];for(e=0;e<3;e++)for(r=0;r<g;r++)for(n=0;n<v;n++)null==(a=x[e][r][n])?x[e][r][n]=NaN:a=x[e][r][n]*=m[e];for(e=0;e<3;e++)for(r=0;r<g;r++)for(n=0;n<v;n++)null!=(a=x[e][r][n])&&(this.minValues[e]>a&&(this.minValues[e]=a),this.maxValues[e]<a&&(this.maxValues[e]=a));for(e=0;e<3;e++)this.objectOffset[e]=.5*(this.minValues[e]+this.maxValues[e]);for(e=0;e<3;e++)for(r=0;r<g;r++)for(n=0;n<v;n++)null!=(a=x[e][r][n])&&(x[e][r][n]-=this.objectOffset[e]);var b=[i(new Float32Array(g*v),[g,v]),i(new Float32Array(g*v),[g,v]),i(new Float32Array(g*v),[g,v])];for(e=0;e<3;e++)for(r=0;r<g;r++)for(n=0;n<v;n++)b[e].set(r,n,x[e][r][n]);x=[];var w={colormap:d,levels:[[],[],[]],showContour:[!0,!0,!0],showSurface:!t.hidesurface,contourProject:[[!1,!1,!1],[!1,!1,!1],[!1,!1,!1]],contourWidth:[1,1,1],contourColor:[[1,1,1,1],[1,1,1,1],[1,1,1,1]],contourTint:[1,1,1],dynamicColor:[[1,1,1,1],[1,1,1,1],[1,1,1,1]],dynamicWidth:[1,1,1],dynamicTint:[1,1,1],opacityscale:t.opacityscale,opacity:t.opacity},T=f(t);if(w.intensityBounds=[T.min,T.max],t.surfacecolor){var k=i(new Float32Array(g*v),[g,v]);for(r=0;r<g;r++)for(n=0;n<v;n++)k.set(r,n,t.surfacecolor[n][r]);b.push(k)}else w.intensityBounds[0]*=m[2],w.intensityBounds[1]*=m[2];(_<b[0].shape[0]||_<b[0].shape[1])&&(this.refineData=!1),!0===this.refineData&&(this.dataScaleX=this.estimateScale(b[0].shape[0],0),this.dataScaleY=this.estimateScale(b[0].shape[1],1),1===this.dataScaleX&&1===this.dataScaleY||this.refineCoords(b)),t.surfacecolor&&(w.intensity=b.pop());var M=[!0,!0,!0],A=[\"x\",\"y\",\"z\"];for(e=0;e<3;++e){var S=t.contours[A[e]];M[e]=S.highlight,w.showContour[e]=S.show||S.highlight,w.showContour[e]&&(w.contourProject[e]=[S.project.x,S.project.y,S.project.z],S.show?(this.showContour[e]=!0,w.levels[e]=y[e],p.highlightColor[e]=w.contourColor[e]=u(S.color),S.usecolormap?p.highlightTint[e]=w.contourTint[e]=0:p.highlightTint[e]=w.contourTint[e]=1,w.contourWidth[e]=S.width,this.contourStart[e]=S.start,this.contourEnd[e]=S.end,this.contourSize[e]=S.size):(this.showContour[e]=!1,this.contourStart[e]=null,this.contourEnd[e]=null,this.contourSize[e]=0),S.highlight&&(w.dynamicColor[e]=u(S.highlightcolor),w.dynamicWidth[e]=S.highlightwidth))}(function(t){var e=t[0].rgb,r=t[t.length-1].rgb;return e[0]===r[0]&&e[1]===r[1]&&e[2]===r[2]&&e[3]===r[3]})(d)&&(w.vertexColor=!0),w.objectOffset=this.objectOffset,w.coords=b,p.update(w),p.visible=t.visible,p.enableDynamic=M,p.enableHighlight=M,p.snapToData=!0,\"lighting\"in t&&(p.ambientLight=t.lighting.ambient,p.diffuseLight=t.lighting.diffuse,p.specularLight=t.lighting.specular,p.roughness=t.lighting.roughness,p.fresnel=t.lighting.fresnel),\"lightposition\"in t&&(p.lightPosition=[t.lightposition.x,t.lightposition.y,t.lightposition.z])},p.dispose=function(){this.scene.glplot.remove(this.surface),this.surface.dispose()},e.exports=function(t,e){var r=t.glplot.gl,i=n({gl:r}),a=new h(t,i,e.uid);return i._trace=a,a.update(e),t.glplot.add(i),a}},{\"../../components/colorscale\":674,\"../../lib\":799,\"../../lib/gl_format_color\":795,\"../../lib/str2rgbarray\":823,\"../heatmap/find_empties\":1087,\"../heatmap/interp2d\":1090,\"gl-surface3d\":350,ndarray:479,\"ndarray-linear-interpolate\":473}],1341:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"../../components/colorscale/defaults\"),o=t(\"./attributes\");function s(t,e,r,n){var i=n(\"opacityscale\");\"max\"===i?e.opacityscale=[[0,.1],[1,1]]:\"min\"===i?e.opacityscale=[[0,1],[1,.1]]:\"extremes\"===i?e.opacityscale=function(t,e){for(var r=[],n=0;n<32;n++){var i=n/31,a=e+(1-e)*(1-Math.pow(Math.sin(t*i*Math.PI),2));r.push([i,Math.max(0,Math.min(1,a))])}return r}(1,.1):function(t){var e=0;if(!Array.isArray(t)||t.length<2)return!1;if(!t[0]||!t[t.length-1])return!1;if(0!=+t[0][0]||1!=+t[t.length-1][0])return!1;for(var r=0;r<t.length;r++){var n=t[r];if(2!==n.length||+n[0]<e)return!1;e=+n[0]}return!0}(i)||(e.opacityscale=void 0)}function l(t,e,r){e in t&&!(r in t)&&(t[r]=t[e])}e.exports={supplyDefaults:function(t,e,r,c){var u,f;function h(r,n){return i.coerce(t,e,o,r,n)}var p=h(\"x\"),d=h(\"y\"),m=h(\"z\");if(!m||!m.length||p&&p.length<1||d&&d.length<1)e.visible=!1;else{e._xlength=Array.isArray(p)&&i.isArrayOrTypedArray(p[0])?m.length:m[0].length,e._ylength=m.length,n.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\",\"y\",\"z\"],c),h(\"text\"),h(\"hovertext\"),h(\"hovertemplate\"),h(\"xhoverformat\"),h(\"yhoverformat\"),h(\"zhoverformat\"),[\"lighting.ambient\",\"lighting.diffuse\",\"lighting.specular\",\"lighting.roughness\",\"lighting.fresnel\",\"lightposition.x\",\"lightposition.y\",\"lightposition.z\",\"hidesurface\",\"connectgaps\",\"opacity\"].forEach((function(t){h(t)}));var g=h(\"surfacecolor\"),v=[\"x\",\"y\",\"z\"];for(u=0;u<3;++u){var y=\"contours.\"+v[u],x=h(y+\".show\"),b=h(y+\".highlight\");if(x||b)for(f=0;f<3;++f)h(y+\".project.\"+v[f]);x&&(h(y+\".color\"),h(y+\".width\"),h(y+\".usecolormap\")),b&&(h(y+\".highlightcolor\"),h(y+\".highlightwidth\")),h(y+\".start\"),h(y+\".end\"),h(y+\".size\")}g||(l(t,\"zmin\",\"cmin\"),l(t,\"zmax\",\"cmax\"),l(t,\"zauto\",\"cauto\")),a(t,e,c,h,{prefix:\"\",cLetter:\"c\"}),s(t,e,c,h),e._length=null}},opacityscaleDefaults:s}},{\"../../components/colorscale/defaults\":672,\"../../lib\":799,\"../../registry\":927,\"./attributes\":1338}],1342:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\").supplyDefaults,colorbar:{min:\"cmin\",max:\"cmax\"},calc:t(\"./calc\"),plot:t(\"./convert\"),moduleType:\"trace\",name:\"surface\",basePlotModule:t(\"../../plots/gl3d\"),categories:[\"gl3d\",\"2dMap\",\"showLegend\"],meta:{}}},{\"../../plots/gl3d\":892,\"./attributes\":1338,\"./calc\":1339,\"./convert\":1340,\"./defaults\":1341}],1343:[function(t,e,r){\"use strict\";var n=t(\"../../components/annotations/attributes\"),i=t(\"../../lib/extend\").extendFlat,a=t(\"../../plot_api/edit_types\").overrideAll,o=t(\"../../plots/font_attributes\"),s=t(\"../../plots/domain\").attributes,l=t(\"../../plots/cartesian/axis_format_attributes\").descriptionOnlyNumbers;(e.exports=a({domain:s({name:\"table\",trace:!0}),columnwidth:{valType:\"number\",arrayOk:!0,dflt:null},columnorder:{valType:\"data_array\"},header:{values:{valType:\"data_array\",dflt:[]},format:{valType:\"data_array\",dflt:[],description:l(\"cell value\")},prefix:{valType:\"string\",arrayOk:!0,dflt:null},suffix:{valType:\"string\",arrayOk:!0,dflt:null},height:{valType:\"number\",dflt:28},align:i({},n.align,{arrayOk:!0}),line:{width:{valType:\"number\",arrayOk:!0,dflt:1},color:{valType:\"color\",arrayOk:!0,dflt:\"grey\"}},fill:{color:{valType:\"color\",arrayOk:!0,dflt:\"white\"}},font:i({},o({arrayOk:!0}))},cells:{values:{valType:\"data_array\",dflt:[]},format:{valType:\"data_array\",dflt:[],description:l(\"cell value\")},prefix:{valType:\"string\",arrayOk:!0,dflt:null},suffix:{valType:\"string\",arrayOk:!0,dflt:null},height:{valType:\"number\",dflt:20},align:i({},n.align,{arrayOk:!0}),line:{width:{valType:\"number\",arrayOk:!0,dflt:1},color:{valType:\"color\",arrayOk:!0,dflt:\"grey\"}},fill:{color:{valType:\"color\",arrayOk:!0,dflt:\"white\"}},font:i({},o({arrayOk:!0}))}},\"calc\",\"from-root\")).transforms=void 0},{\"../../components/annotations/attributes\":645,\"../../lib/extend\":789,\"../../plot_api/edit_types\":831,\"../../plots/cartesian/axis_format_attributes\":852,\"../../plots/domain\":877,\"../../plots/font_attributes\":878}],1344:[function(t,e,r){\"use strict\";var n=t(\"../../plots/get_data\").getModuleCalcData,i=t(\"./plot\");r.name=\"table\",r.plot=function(t){var e=n(t.calcdata,\"table\")[0];e.length&&i(t,e)},r.clean=function(t,e,r,n){var i=n._has&&n._has(\"table\"),a=e._has&&e._has(\"table\");i&&!a&&n._paperdiv.selectAll(\".table\").remove()}},{\"../../plots/get_data\":887,\"./plot\":1351}],1345:[function(t,e,r){\"use strict\";var n=t(\"../../lib/gup\").wrap;e.exports=function(){return n({})}},{\"../../lib/gup\":796}],1346:[function(t,e,r){\"use strict\";e.exports={cellPad:8,columnExtentOffset:10,columnTitleOffset:28,emptyHeaderHeight:16,latexCheck:/^\\$.*\\$$/,goldenRatio:1.618,lineBreaker:\"<br>\",maxDimensionCount:60,overdrag:45,releaseTransitionDuration:120,releaseTransitionEase:\"cubic-out\",scrollbarCaptureWidth:18,scrollbarHideDelay:1e3,scrollbarHideDuration:1e3,scrollbarOffset:5,scrollbarWidth:8,transitionDuration:100,transitionEase:\"cubic-out\",uplift:5,wrapSpacer:\" \",wrapSplitCharacter:\" \",cn:{table:\"table\",tableControlView:\"table-control-view\",scrollBackground:\"scroll-background\",yColumn:\"y-column\",columnBlock:\"column-block\",scrollAreaClip:\"scroll-area-clip\",scrollAreaClipRect:\"scroll-area-clip-rect\",columnBoundary:\"column-boundary\",columnBoundaryClippath:\"column-boundary-clippath\",columnBoundaryRect:\"column-boundary-rect\",columnCells:\"column-cells\",columnCell:\"column-cell\",cellRect:\"cell-rect\",cellText:\"cell-text\",cellTextHolder:\"cell-text-holder\",scrollbarKit:\"scrollbar-kit\",scrollbar:\"scrollbar\",scrollbarSlider:\"scrollbar-slider\",scrollbarGlyph:\"scrollbar-glyph\",scrollbarCaptureZone:\"scrollbar-capture-zone\"}}},{}],1347:[function(t,e,r){\"use strict\";var n=t(\"./constants\"),i=t(\"../../lib/extend\").extendFlat,a=t(\"fast-isnumeric\");function o(t){if(Array.isArray(t)){for(var e=0,r=0;r<t.length;r++)e=Math.max(e,o(t[r]));return e}return t}function s(t,e){return t+e}function l(t){var e,r=t.slice(),n=1/0,i=0;for(e=0;e<r.length;e++)Array.isArray(r[e])||(r[e]=[r[e]]),n=Math.min(n,r[e].length),i=Math.max(i,r[e].length);if(n!==i)for(e=0;e<r.length;e++){var a=i-r[e].length;a&&(r[e]=r[e].concat(c(a)))}return r}function c(t){for(var e=new Array(t),r=0;r<t;r++)e[r]=\"\";return e}function u(t){return t.calcdata.columns.reduce((function(e,r){return r.xIndex<t.xIndex?e+r.columnWidth:e}),0)}function f(t,e){return Object.keys(t).map((function(r){return i({},t[r],{auxiliaryBlocks:e})}))}function h(t,e){for(var r,n={},i=0,a=0,o={firstRowIndex:null,lastRowIndex:null,rows:[]},s=0,l=0,c=0;c<t.length;c++)r=t[c],o.rows.push({rowIndex:c,rowHeight:r}),((a+=r)>=e||c===t.length-1)&&(n[i]=o,o.key=l++,o.firstRowIndex=s,o.lastRowIndex=c,o={firstRowIndex:null,lastRowIndex:null,rows:[]},i+=a,s=c+1,a=0);return n}e.exports=function(t,e){var r=l(e.cells.values),p=function(t){return t.slice(e.header.values.length,t.length)},d=l(e.header.values);d.length&&!d[0].length&&(d[0]=[\"\"],d=l(d));var m=d.concat(p(r).map((function(){return c((d[0]||[\"\"]).length)}))),g=e.domain,v=Math.floor(t._fullLayout._size.w*(g.x[1]-g.x[0])),y=Math.floor(t._fullLayout._size.h*(g.y[1]-g.y[0])),x=e.header.values.length?m[0].map((function(){return e.header.height})):[n.emptyHeaderHeight],b=r.length?r[0].map((function(){return e.cells.height})):[],_=x.reduce(s,0),w=h(b,y-_+n.uplift),T=f(h(x,_),[]),k=f(w,T),M={},A=e._fullInput.columnorder.concat(p(r.map((function(t,e){return e})))),S=m.map((function(t,r){var n=Array.isArray(e.columnwidth)?e.columnwidth[Math.min(r,e.columnwidth.length-1)]:e.columnwidth;return a(n)?Number(n):1})),E=S.reduce(s,0);S=S.map((function(t){return t/E*v}));var L=Math.max(o(e.header.line.width),o(e.cells.line.width)),C={key:e.uid+t._context.staticPlot,translateX:g.x[0]*t._fullLayout._size.w,translateY:t._fullLayout._size.h*(1-g.y[1]),size:t._fullLayout._size,width:v,maxLineWidth:L,height:y,columnOrder:A,groupHeight:y,rowBlocks:k,headerRowBlocks:T,scrollY:0,cells:i({},e.cells,{values:r}),headerCells:i({},e.header,{values:m}),gdColumns:m.map((function(t){return t[0]})),gdColumnsOriginalOrder:m.map((function(t){return t[0]})),prevPages:[0,0],scrollbarState:{scrollbarScrollInProgress:!1},columns:m.map((function(t,e){var r=M[t];return M[t]=(r||0)+1,{key:t+\"__\"+M[t],label:t,specIndex:e,xIndex:A[e],xScale:u,x:void 0,calcdata:void 0,columnWidth:S[e]}}))};return C.columns.forEach((function(t){t.calcdata=C,t.x=u(t)})),C}},{\"../../lib/extend\":789,\"./constants\":1346,\"fast-isnumeric\":245}],1348:[function(t,e,r){\"use strict\";var n=t(\"../../lib/extend\").extendFlat;r.splitToPanels=function(t){var e=[0,0],r=n({},t,{key:\"header\",type:\"header\",page:0,prevPages:e,currentRepaint:[null,null],dragHandle:!0,values:t.calcdata.headerCells.values[t.specIndex],rowBlocks:t.calcdata.headerRowBlocks,calcdata:n({},t.calcdata,{cells:t.calcdata.headerCells})});return[n({},t,{key:\"cells1\",type:\"cells\",page:0,prevPages:e,currentRepaint:[null,null],dragHandle:!1,values:t.calcdata.cells.values[t.specIndex],rowBlocks:t.calcdata.rowBlocks}),n({},t,{key:\"cells2\",type:\"cells\",page:1,prevPages:e,currentRepaint:[null,null],dragHandle:!1,values:t.calcdata.cells.values[t.specIndex],rowBlocks:t.calcdata.rowBlocks}),r]},r.splitToCells=function(t){var e=function(t){var e=t.rowBlocks[t.page],r=e?e.rows[0].rowIndex:0,n=e?r+e.rows.length:0;return[r,n]}(t);return(t.values||[]).slice(e[0],e[1]).map((function(r,n){return{keyWithinBlock:n+(\"string\"==typeof r&&r.match(/[<$&> ]/)?\"_keybuster_\"+Math.random():\"\"),key:e[0]+n,column:t,calcdata:t.calcdata,page:t.page,rowBlocks:t.rowBlocks,value:r}}))}},{\"../../lib/extend\":789}],1349:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\"),a=t(\"../../plots/domain\").defaults;e.exports=function(t,e,r,o){function s(r,a){return n.coerce(t,e,i,r,a)}a(e,o,s),s(\"columnwidth\"),s(\"header.values\"),s(\"header.format\"),s(\"header.align\"),s(\"header.prefix\"),s(\"header.suffix\"),s(\"header.height\"),s(\"header.line.width\"),s(\"header.line.color\"),s(\"header.fill.color\"),n.coerceFont(s,\"header.font\",n.extendFlat({},o.font)),function(t,e){for(var r=t.columnorder||[],n=t.header.values.length,i=r.slice(0,n),a=i.slice().sort((function(t,e){return t-e})),o=i.map((function(t){return a.indexOf(t)})),s=o.length;s<n;s++)o.push(s);e(\"columnorder\",o)}(e,s),s(\"cells.values\"),s(\"cells.format\"),s(\"cells.align\"),s(\"cells.prefix\"),s(\"cells.suffix\"),s(\"cells.height\"),s(\"cells.line.width\"),s(\"cells.line.color\"),s(\"cells.fill.color\"),n.coerceFont(s,\"cells.font\",n.extendFlat({},o.font)),e._length=null}},{\"../../lib\":799,\"../../plots/domain\":877,\"./attributes\":1343}],1350:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\"),plot:t(\"./plot\"),moduleType:\"trace\",name:\"table\",basePlotModule:t(\"./base_plot\"),categories:[\"noOpacity\"],meta:{}}},{\"./attributes\":1343,\"./base_plot\":1344,\"./calc\":1345,\"./defaults\":1349,\"./plot\":1351}],1351:[function(t,e,r){\"use strict\";var n=t(\"./constants\"),i=t(\"@plotly/d3\"),a=t(\"../../lib/gup\"),o=t(\"../../components/drawing\"),s=t(\"../../lib/svg_text_utils\"),l=t(\"../../lib\").raiseToTop,c=t(\"../../lib\").strTranslate,u=t(\"../../lib\").cancelTransition,f=t(\"./data_preparation_helper\"),h=t(\"./data_split_helpers\"),p=t(\"../../components/color\");function d(t){return Math.ceil(t.calcdata.maxLineWidth/2)}function m(t,e){return\"clip\"+t._fullLayout._uid+\"_scrollAreaBottomClip_\"+e.key}function g(t,e){return\"clip\"+t._fullLayout._uid+\"_columnBoundaryClippath_\"+e.calcdata.key+\"_\"+e.specIndex}function v(t){return[].concat.apply([],t.map((function(t){return t}))).map((function(t){return t.__data__}))}function y(t,e,r){var o=t.selectAll(\".\"+n.cn.scrollbarKit).data(a.repeat,a.keyFun);o.enter().append(\"g\").classed(n.cn.scrollbarKit,!0).style(\"shape-rendering\",\"geometricPrecision\"),o.each((function(t){var e=t.scrollbarState;e.totalHeight=function(t){var e=t.rowBlocks;return z(e,e.length-1)+(e.length?D(e[e.length-1],1/0):1)}(t),e.scrollableAreaHeight=t.groupHeight-A(t),e.currentlyVisibleHeight=Math.min(e.totalHeight,e.scrollableAreaHeight),e.ratio=e.currentlyVisibleHeight/e.totalHeight,e.barLength=Math.max(e.ratio*e.currentlyVisibleHeight,n.goldenRatio*n.scrollbarWidth),e.barWiggleRoom=e.currentlyVisibleHeight-e.barLength,e.wiggleRoom=Math.max(0,e.totalHeight-e.scrollableAreaHeight),e.topY=0===e.barWiggleRoom?0:t.scrollY/e.wiggleRoom*e.barWiggleRoom,e.bottomY=e.topY+e.barLength,e.dragMultiplier=e.wiggleRoom/e.barWiggleRoom})).attr(\"transform\",(function(t){var e=t.width+n.scrollbarWidth/2+n.scrollbarOffset;return c(e,A(t))}));var s=o.selectAll(\".\"+n.cn.scrollbar).data(a.repeat,a.keyFun);s.enter().append(\"g\").classed(n.cn.scrollbar,!0);var l=s.selectAll(\".\"+n.cn.scrollbarSlider).data(a.repeat,a.keyFun);l.enter().append(\"g\").classed(n.cn.scrollbarSlider,!0),l.attr(\"transform\",(function(t){return c(0,t.scrollbarState.topY||0)}));var u=l.selectAll(\".\"+n.cn.scrollbarGlyph).data(a.repeat,a.keyFun);u.enter().append(\"line\").classed(n.cn.scrollbarGlyph,!0).attr(\"stroke\",\"black\").attr(\"stroke-width\",n.scrollbarWidth).attr(\"stroke-linecap\",\"round\").attr(\"y1\",n.scrollbarWidth/2),u.attr(\"y2\",(function(t){return t.scrollbarState.barLength-n.scrollbarWidth/2})).attr(\"stroke-opacity\",(function(t){return t.columnDragInProgress||!t.scrollbarState.barWiggleRoom||r?0:.4})),u.transition().delay(0).duration(0),u.transition().delay(n.scrollbarHideDelay).duration(n.scrollbarHideDuration).attr(\"stroke-opacity\",0);var f=s.selectAll(\".\"+n.cn.scrollbarCaptureZone).data(a.repeat,a.keyFun);f.enter().append(\"line\").classed(n.cn.scrollbarCaptureZone,!0).attr(\"stroke\",\"white\").attr(\"stroke-opacity\",.01).attr(\"stroke-width\",n.scrollbarCaptureWidth).attr(\"stroke-linecap\",\"butt\").attr(\"y1\",0).on(\"mousedown\",(function(r){var n=i.event.y,a=this.getBoundingClientRect(),o=r.scrollbarState,s=n-a.top,l=i.scale.linear().domain([0,o.scrollableAreaHeight]).range([0,o.totalHeight]).clamp(!0);o.topY<=s&&s<=o.bottomY||E(e,t,null,l(s-o.barLength/2))(r)})).call(i.behavior.drag().origin((function(t){return i.event.stopPropagation(),t.scrollbarState.scrollbarScrollInProgress=!0,t})).on(\"drag\",E(e,t)).on(\"dragend\",(function(){}))),f.attr(\"y2\",(function(t){return t.scrollbarState.scrollableAreaHeight})),e._context.staticPlot&&(u.remove(),f.remove())}function x(t,e,r,s){var l=function(t){var e=t.selectAll(\".\"+n.cn.columnCell).data(h.splitToCells,(function(t){return t.keyWithinBlock}));return e.enter().append(\"g\").classed(n.cn.columnCell,!0),e.exit().remove(),e}(function(t){var e=t.selectAll(\".\"+n.cn.columnCells).data(a.repeat,a.keyFun);return e.enter().append(\"g\").classed(n.cn.columnCells,!0),e.exit().remove(),e}(r));!function(t){t.each((function(t,e){var r=t.calcdata.cells.font,n=t.column.specIndex,i={size:w(r.size,n,e),color:w(r.color,n,e),family:w(r.family,n,e)};t.rowNumber=t.key,t.align=w(t.calcdata.cells.align,n,e),t.cellBorderWidth=w(t.calcdata.cells.line.width,n,e),t.font=i}))}(l),function(t){t.attr(\"width\",(function(t){return t.column.columnWidth})).attr(\"stroke-width\",(function(t){return t.cellBorderWidth})).each((function(t){var e=i.select(this);p.stroke(e,w(t.calcdata.cells.line.color,t.column.specIndex,t.rowNumber)),p.fill(e,w(t.calcdata.cells.fill.color,t.column.specIndex,t.rowNumber))}))}(function(t){var e=t.selectAll(\".\"+n.cn.cellRect).data(a.repeat,(function(t){return t.keyWithinBlock}));return e.enter().append(\"rect\").classed(n.cn.cellRect,!0),e}(l));var c=function(t){var e=t.selectAll(\".\"+n.cn.cellText).data(a.repeat,(function(t){return t.keyWithinBlock}));return e.enter().append(\"text\").classed(n.cn.cellText,!0).style(\"cursor\",(function(){return\"auto\"})).on(\"mousedown\",(function(){i.event.stopPropagation()})),e}(function(t){var e=t.selectAll(\".\"+n.cn.cellTextHolder).data(a.repeat,(function(t){return t.keyWithinBlock}));return e.enter().append(\"g\").classed(n.cn.cellTextHolder,!0).style(\"shape-rendering\",\"geometricPrecision\"),e}(l));!function(t){t.each((function(t){o.font(i.select(this),t.font)}))}(c),b(c,e,s,t),O(l)}function b(t,e,r,a){t.text((function(t){var e=t.column.specIndex,r=t.rowNumber,a=t.value,o=\"string\"==typeof a,s=o&&a.match(/<br>/i),l=!o||s;t.mayHaveMarkup=o&&a.match(/[<&>]/);var c,u=\"string\"==typeof(c=a)&&c.match(n.latexCheck);t.latex=u;var f,h,p=u?\"\":w(t.calcdata.cells.prefix,e,r)||\"\",d=u?\"\":w(t.calcdata.cells.suffix,e,r)||\"\",m=u?null:w(t.calcdata.cells.format,e,r)||null,g=p+(m?i.format(m)(t.value):t.value)+d;if(t.wrappingNeeded=!t.wrapped&&!l&&!u&&(f=_(g)),t.cellHeightMayIncrease=s||u||t.mayHaveMarkup||(void 0===f?_(g):f),t.needsConvertToTspans=t.mayHaveMarkup||t.wrappingNeeded||t.latex,t.wrappingNeeded){var v=(\" \"===n.wrapSplitCharacter?g.replace(/<a href=/gi,\"<a_href=\"):g).split(n.wrapSplitCharacter),y=\" \"===n.wrapSplitCharacter?v.map((function(t){return t.replace(/<a_href=/gi,\"<a href=\")})):v;t.fragments=y.map((function(t){return{text:t,width:null}})),t.fragments.push({fragment:n.wrapSpacer,width:null}),h=y.join(n.lineBreaker)+n.lineBreaker+n.wrapSpacer}else delete t.fragments,h=g;return h})).attr(\"dy\",(function(t){return t.needsConvertToTspans?0:\"0.75em\"})).each((function(t){var o=i.select(this),l=t.wrappingNeeded?C:P;t.needsConvertToTspans?s.convertToTspans(o,a,l(r,this,e,a,t)):i.select(this.parentNode).attr(\"transform\",(function(t){return c(I(t),n.cellPad)})).attr(\"text-anchor\",(function(t){return{left:\"start\",center:\"middle\",right:\"end\"}[t.align]}))}))}function _(t){return-1!==t.indexOf(n.wrapSplitCharacter)}function w(t,e,r){if(Array.isArray(t)){var n=t[Math.min(e,t.length-1)];return Array.isArray(n)?n[Math.min(r,n.length-1)]:n}return t}function T(t,e,r){t.transition().ease(n.releaseTransitionEase).duration(n.releaseTransitionDuration).attr(\"transform\",c(e.x,r))}function k(t){return\"cells\"===t.type}function M(t){return\"header\"===t.type}function A(t){return(t.rowBlocks.length?t.rowBlocks[0].auxiliaryBlocks:[]).reduce((function(t,e){return t+D(e,1/0)}),0)}function S(t,e,r){var n=v(e)[0];if(void 0!==n){var i=n.rowBlocks,a=n.calcdata,o=z(i,i.length),s=n.calcdata.groupHeight-A(n),l=a.scrollY=Math.max(0,Math.min(o-s,a.scrollY)),u=function(t,e,r){for(var n=[],i=0,a=0;a<t.length;a++){for(var o=t[a],s=o.rows,l=0,c=0;c<s.length;c++)l+=s[c].rowHeight;o.allRowsHeight=l;e<i+l&&e+r>i&&n.push(a),i+=l}return n}(i,l,s);1===u.length&&(u[0]===i.length-1?u.unshift(u[0]-1):u.push(u[0]+1)),u[0]%2&&u.reverse(),e.each((function(t,e){t.page=u[e],t.scrollY=l})),e.attr(\"transform\",(function(t){var e=z(t.rowBlocks,t.page)-t.scrollY;return c(0,e)})),t&&(L(t,r,e,u,n.prevPages,n,0),L(t,r,e,u,n.prevPages,n,1),y(r,t))}}function E(t,e,r,a){return function(o){var s=o.calcdata?o.calcdata:o,l=e.filter((function(t){return s.key===t.key})),c=r||s.scrollbarState.dragMultiplier,u=s.scrollY;s.scrollY=void 0===a?s.scrollY+c*i.event.dy:a;var f=l.selectAll(\".\"+n.cn.yColumn).selectAll(\".\"+n.cn.columnBlock).filter(k);return S(t,f,l),s.scrollY===u}}function L(t,e,r,n,i,a,o){n[o]!==i[o]&&(clearTimeout(a.currentRepaint[o]),a.currentRepaint[o]=setTimeout((function(){var a=r.filter((function(t,e){return e===o&&n[e]!==i[e]}));x(t,e,a,r),i[o]=n[o]})))}function C(t,e,r,a){return function(){var o=i.select(e.parentNode);o.each((function(t){var e=t.fragments;o.selectAll(\"tspan.line\").each((function(t,r){e[r].width=this.getComputedTextLength()}));var r,i,a=e[e.length-1].width,s=e.slice(0,-1),l=[],c=0,u=t.column.columnWidth-2*n.cellPad;for(t.value=\"\";s.length;)c+(i=(r=s.shift()).width+a)>u&&(t.value+=l.join(n.wrapSpacer)+n.lineBreaker,l=[],c=0),l.push(r.text),c+=i;c&&(t.value+=l.join(n.wrapSpacer)),t.wrapped=!0})),o.selectAll(\"tspan.line\").remove(),b(o.select(\".\"+n.cn.cellText),r,t,a),i.select(e.parentNode.parentNode).call(O)}}function P(t,e,r,a,o){return function(){if(!o.settledY){var s=i.select(e.parentNode),l=F(o),u=o.key-l.firstRowIndex,f=l.rows[u].rowHeight,h=o.cellHeightMayIncrease?e.parentNode.getBoundingClientRect().height+2*n.cellPad:f,p=Math.max(h,f);p-l.rows[u].rowHeight&&(l.rows[u].rowHeight=p,t.selectAll(\".\"+n.cn.columnCell).call(O),S(null,t.filter(k),0),y(r,a,!0)),s.attr(\"transform\",(function(){var t=this.parentNode.getBoundingClientRect(),e=i.select(this.parentNode).select(\".\"+n.cn.cellRect).node().getBoundingClientRect(),r=this.transform.baseVal.consolidate(),a=e.top-t.top+(r?r.matrix.f:n.cellPad);return c(I(o,i.select(this.parentNode).select(\".\"+n.cn.cellTextHolder).node().getBoundingClientRect().width),a)})),o.settledY=!0}}}function I(t,e){switch(t.align){case\"left\":return n.cellPad;case\"right\":return t.column.columnWidth-(e||0)-n.cellPad;case\"center\":return(t.column.columnWidth-(e||0))/2;default:return n.cellPad}}function O(t){t.attr(\"transform\",(function(t){var e=t.rowBlocks[0].auxiliaryBlocks.reduce((function(t,e){return t+D(e,1/0)}),0),r=D(F(t),t.key);return c(0,r+e)})).selectAll(\".\"+n.cn.cellRect).attr(\"height\",(function(t){return(e=F(t),r=t.key,e.rows[r-e.firstRowIndex]).rowHeight;var e,r}))}function z(t,e){for(var r=0,n=e-1;n>=0;n--)r+=R(t[n]);return r}function D(t,e){for(var r=0,n=0;n<t.rows.length&&t.rows[n].rowIndex<e;n++)r+=t.rows[n].rowHeight;return r}function R(t){var e=t.allRowsHeight;if(void 0!==e)return e;for(var r=0,n=0;n<t.rows.length;n++)r+=t.rows[n].rowHeight;return t.allRowsHeight=r,r}function F(t){return t.rowBlocks[t.page]}e.exports=function(t,e){var r=!t._context.staticPlot,s=t._fullLayout._paper.selectAll(\".\"+n.cn.table).data(e.map((function(e){var r=a.unwrap(e).trace;return f(t,r)})),a.keyFun);s.exit().remove(),s.enter().append(\"g\").classed(n.cn.table,!0).attr(\"overflow\",\"visible\").style(\"box-sizing\",\"content-box\").style(\"position\",\"absolute\").style(\"left\",0).style(\"overflow\",\"visible\").style(\"shape-rendering\",\"crispEdges\").style(\"pointer-events\",\"all\"),s.attr(\"width\",(function(t){return t.width+t.size.l+t.size.r})).attr(\"height\",(function(t){return t.height+t.size.t+t.size.b})).attr(\"transform\",(function(t){return c(t.translateX,t.translateY)}));var p=s.selectAll(\".\"+n.cn.tableControlView).data(a.repeat,a.keyFun),b=p.enter().append(\"g\").classed(n.cn.tableControlView,!0).style(\"box-sizing\",\"content-box\");if(r){var _=\"onwheel\"in document?\"wheel\":\"mousewheel\";b.on(\"mousemove\",(function(e){p.filter((function(t){return e===t})).call(y,t)})).on(_,(function(e){if(!e.scrollbarState.wheeling){e.scrollbarState.wheeling=!0;var r=e.scrollY+i.event.deltaY;E(t,p,null,r)(e)||(i.event.stopPropagation(),i.event.preventDefault()),e.scrollbarState.wheeling=!1}})).call(y,t,!0)}p.attr(\"transform\",(function(t){return c(t.size.l,t.size.t)}));var w=p.selectAll(\".\"+n.cn.scrollBackground).data(a.repeat,a.keyFun);w.enter().append(\"rect\").classed(n.cn.scrollBackground,!0).attr(\"fill\",\"none\"),w.attr(\"width\",(function(t){return t.width})).attr(\"height\",(function(t){return t.height})),p.each((function(e){o.setClipUrl(i.select(this),m(t,e),t)}));var A=p.selectAll(\".\"+n.cn.yColumn).data((function(t){return t.columns}),a.keyFun);A.enter().append(\"g\").classed(n.cn.yColumn,!0),A.exit().remove(),A.attr(\"transform\",(function(t){return c(t.x,0)})),r&&A.call(i.behavior.drag().origin((function(e){return T(i.select(this),e,-n.uplift),l(this),e.calcdata.columnDragInProgress=!0,y(p.filter((function(t){return e.calcdata.key===t.key})),t),e})).on(\"drag\",(function(t){var e=i.select(this),r=function(e){return(t===e?i.event.x:e.x)+e.columnWidth/2};t.x=Math.max(-n.overdrag,Math.min(t.calcdata.width+n.overdrag-t.columnWidth,i.event.x)),v(A).filter((function(e){return e.calcdata.key===t.calcdata.key})).sort((function(t,e){return r(t)-r(e)})).forEach((function(e,r){e.xIndex=r,e.x=t===e?e.x:e.xScale(e)})),A.filter((function(e){return t!==e})).transition().ease(n.transitionEase).duration(n.transitionDuration).attr(\"transform\",(function(t){return c(t.x,0)})),e.call(u).attr(\"transform\",c(t.x,-n.uplift))})).on(\"dragend\",(function(e){var r=i.select(this),n=e.calcdata;e.x=e.xScale(e),e.calcdata.columnDragInProgress=!1,T(r,e,0),function(t,e,r){var n=e.gdColumnsOriginalOrder;e.gdColumns.sort((function(t,e){return r[n.indexOf(t)]-r[n.indexOf(e)]})),e.columnorder=r,t.emit(\"plotly_restyle\")}(t,n,n.columns.map((function(t){return t.xIndex})))}))),A.each((function(e){o.setClipUrl(i.select(this),g(t,e),t)}));var L=A.selectAll(\".\"+n.cn.columnBlock).data(h.splitToPanels,a.keyFun);L.enter().append(\"g\").classed(n.cn.columnBlock,!0).attr(\"id\",(function(t){return t.key})),L.style(\"cursor\",(function(t){return t.dragHandle?\"ew-resize\":t.calcdata.scrollbarState.barWiggleRoom?\"ns-resize\":\"default\"}));var C=L.filter(M),P=L.filter(k);r&&P.call(i.behavior.drag().origin((function(t){return i.event.stopPropagation(),t})).on(\"drag\",E(t,p,-1)).on(\"dragend\",(function(){}))),x(t,p,C,L),x(t,p,P,L);var I=p.selectAll(\".\"+n.cn.scrollAreaClip).data(a.repeat,a.keyFun);I.enter().append(\"clipPath\").classed(n.cn.scrollAreaClip,!0).attr(\"id\",(function(e){return m(t,e)}));var O=I.selectAll(\".\"+n.cn.scrollAreaClipRect).data(a.repeat,a.keyFun);O.enter().append(\"rect\").classed(n.cn.scrollAreaClipRect,!0).attr(\"x\",-n.overdrag).attr(\"y\",-n.uplift).attr(\"fill\",\"none\"),O.attr(\"width\",(function(t){return t.width+2*n.overdrag})).attr(\"height\",(function(t){return t.height+n.uplift})),A.selectAll(\".\"+n.cn.columnBoundary).data(a.repeat,a.keyFun).enter().append(\"g\").classed(n.cn.columnBoundary,!0);var z=A.selectAll(\".\"+n.cn.columnBoundaryClippath).data(a.repeat,a.keyFun);z.enter().append(\"clipPath\").classed(n.cn.columnBoundaryClippath,!0),z.attr(\"id\",(function(e){return g(t,e)}));var D=z.selectAll(\".\"+n.cn.columnBoundaryRect).data(a.repeat,a.keyFun);D.enter().append(\"rect\").classed(n.cn.columnBoundaryRect,!0).attr(\"fill\",\"none\"),D.attr(\"width\",(function(t){return t.columnWidth+2*d(t)})).attr(\"height\",(function(t){return t.calcdata.height+2*d(t)+n.uplift})).attr(\"x\",(function(t){return-d(t)})).attr(\"y\",(function(t){return-d(t)})),S(null,P,p)}},{\"../../components/color\":662,\"../../components/drawing\":684,\"../../lib\":799,\"../../lib/gup\":796,\"../../lib/svg_text_utils\":824,\"./constants\":1346,\"./data_preparation_helper\":1347,\"./data_split_helpers\":1348,\"@plotly/d3\":58}],1352:[function(t,e,r){\"use strict\";var n=t(\"../../plots/template_attributes\").hovertemplateAttrs,i=t(\"../../plots/template_attributes\").texttemplateAttrs,a=t(\"../../components/colorscale/attributes\"),o=t(\"../../plots/domain\").attributes,s=t(\"../pie/attributes\"),l=t(\"../sunburst/attributes\"),c=t(\"./constants\"),u=t(\"../../lib/extend\").extendFlat;e.exports={labels:l.labels,parents:l.parents,values:l.values,branchvalues:l.branchvalues,count:l.count,level:l.level,maxdepth:l.maxdepth,tiling:{packing:{valType:\"enumerated\",values:[\"squarify\",\"binary\",\"dice\",\"slice\",\"slice-dice\",\"dice-slice\"],dflt:\"squarify\",editType:\"plot\"},squarifyratio:{valType:\"number\",min:1,dflt:1,editType:\"plot\"},flip:{valType:\"flaglist\",flags:[\"x\",\"y\"],dflt:\"\",editType:\"plot\"},pad:{valType:\"number\",min:0,dflt:3,editType:\"plot\"},editType:\"calc\"},marker:u({pad:{t:{valType:\"number\",min:0,editType:\"plot\"},l:{valType:\"number\",min:0,editType:\"plot\"},r:{valType:\"number\",min:0,editType:\"plot\"},b:{valType:\"number\",min:0,editType:\"plot\"},editType:\"calc\"},colors:l.marker.colors,depthfade:{valType:\"enumerated\",values:[!0,!1,\"reversed\"],editType:\"style\"},line:l.marker.line,editType:\"calc\"},a(\"marker\",{colorAttr:\"colors\",anim:!1})),pathbar:{visible:{valType:\"boolean\",dflt:!0,editType:\"plot\"},side:{valType:\"enumerated\",values:[\"top\",\"bottom\"],dflt:\"top\",editType:\"plot\"},edgeshape:{valType:\"enumerated\",values:[\">\",\"<\",\"|\",\"/\",\"\\\\\"],dflt:\">\",editType:\"plot\"},thickness:{valType:\"number\",min:12,editType:\"plot\"},textfont:u({},s.textfont,{}),editType:\"calc\"},text:s.text,textinfo:l.textinfo,texttemplate:i({editType:\"plot\"},{keys:c.eventDataKeys.concat([\"label\",\"value\"])}),hovertext:s.hovertext,hoverinfo:l.hoverinfo,hovertemplate:n({},{keys:c.eventDataKeys}),textfont:s.textfont,insidetextfont:s.insidetextfont,outsidetextfont:u({},s.outsidetextfont,{}),textposition:{valType:\"enumerated\",values:[\"top left\",\"top center\",\"top right\",\"middle left\",\"middle center\",\"middle right\",\"bottom left\",\"bottom center\",\"bottom right\"],dflt:\"top left\",editType:\"plot\"},sort:s.sort,root:l.root,domain:o({name:\"treemap\",trace:!0,editType:\"calc\"})}},{\"../../components/colorscale/attributes\":669,\"../../lib/extend\":789,\"../../plots/domain\":877,\"../../plots/template_attributes\":922,\"../pie/attributes\":1188,\"../sunburst/attributes\":1326,\"./constants\":1355}],1353:[function(t,e,r){\"use strict\";var n=t(\"../../plots/plots\");r.name=\"treemap\",r.plot=function(t,e,i,a){n.plotBasePlot(r.name,t,e,i,a)},r.clean=function(t,e,i,a){n.cleanBasePlot(r.name,t,e,i,a)}},{\"../../plots/plots\":913}],1354:[function(t,e,r){\"use strict\";var n=t(\"../sunburst/calc\");r.calc=function(t,e){return n.calc(t,e)},r.crossTraceCalc=function(t){return n._runCrossTraceCalc(\"treemap\",t)}},{\"../sunburst/calc\":1328}],1355:[function(t,e,r){\"use strict\";e.exports={CLICK_TRANSITION_TIME:750,CLICK_TRANSITION_EASING:\"poly\",eventDataKeys:[\"currentPath\",\"root\",\"entry\",\"percentRoot\",\"percentEntry\",\"percentParent\"],gapWithPathbar:1}},{}],1356:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\"),a=t(\"../../components/color\"),o=t(\"../../plots/domain\").defaults,s=t(\"../bar/defaults\").handleText,l=t(\"../bar/constants\").TEXTPAD,c=t(\"../../components/colorscale\"),u=c.hasColorscale,f=c.handleDefaults;e.exports=function(t,e,r,c){function h(r,a){return n.coerce(t,e,i,r,a)}var p=h(\"labels\"),d=h(\"parents\");if(p&&p.length&&d&&d.length){var m=h(\"values\");m&&m.length?h(\"branchvalues\"):h(\"count\"),h(\"level\"),h(\"maxdepth\"),\"squarify\"===h(\"tiling.packing\")&&h(\"tiling.squarifyratio\"),h(\"tiling.flip\"),h(\"tiling.pad\");var g=h(\"text\");h(\"texttemplate\"),e.texttemplate||h(\"textinfo\",Array.isArray(g)?\"text+label\":\"label\"),h(\"hovertext\"),h(\"hovertemplate\");var v=h(\"pathbar.visible\");s(t,e,c,h,\"auto\",{hasPathbar:v,moduleHasSelected:!1,moduleHasUnselected:!1,moduleHasConstrain:!1,moduleHasCliponaxis:!1,moduleHasTextangle:!1,moduleHasInsideanchor:!1}),h(\"textposition\");var y=-1!==e.textposition.indexOf(\"bottom\");h(\"marker.line.width\")&&h(\"marker.line.color\",c.paper_bgcolor);var x=h(\"marker.colors\");(e._hasColorscale=u(t,\"marker\",\"colors\")||(t.marker||{}).coloraxis)?f(t,e,c,h,{prefix:\"marker.\",cLetter:\"c\"}):h(\"marker.depthfade\",!(x||[]).length);var b=2*e.textfont.size;h(\"marker.pad.t\",y?b/4:b),h(\"marker.pad.l\",b/4),h(\"marker.pad.r\",b/4),h(\"marker.pad.b\",y?b:b/4),e._hovered={marker:{line:{width:2,color:a.contrast(c.paper_bgcolor)}}},v&&(h(\"pathbar.thickness\",e.pathbar.textfont.size+2*l),h(\"pathbar.side\"),h(\"pathbar.edgeshape\")),h(\"sort\"),h(\"root.color\"),o(e,c,h),e._length=null}else e.visible=!1}},{\"../../components/color\":662,\"../../components/colorscale\":674,\"../../lib\":799,\"../../plots/domain\":877,\"../bar/constants\":939,\"../bar/defaults\":941,\"./attributes\":1352}],1357:[function(t,e,r){\"use strict\";var n=t(\"@plotly/d3\"),i=t(\"../sunburst/helpers\"),a=t(\"../bar/uniform_text\").clearMinTextSize,o=t(\"../bar/style\").resizeText,s=t(\"./plot_one\");e.exports=function(t,e,r,l,c){var u,f,h=c.type,p=c.drawDescendants,d=t._fullLayout,m=d[\"_\"+h+\"layer\"],g=!r;(a(h,d),(u=m.selectAll(\"g.trace.\"+h).data(e,(function(t){return t[0].trace.uid}))).enter().append(\"g\").classed(\"trace\",!0).classed(h,!0),u.order(),!d.uniformtext.mode&&i.hasTransition(r))?(l&&(f=l()),n.transition().duration(r.duration).ease(r.easing).each(\"end\",(function(){f&&f()})).each(\"interrupt\",(function(){f&&f()})).each((function(){m.selectAll(\"g.trace\").each((function(e){s(t,e,this,r,p)}))}))):(u.each((function(e){s(t,e,this,r,p)})),d.uniformtext.mode&&o(t,m.selectAll(\".trace\"),h));g&&u.exit().remove()}},{\"../bar/style\":951,\"../bar/uniform_text\":953,\"../sunburst/helpers\":1332,\"./plot_one\":1366,\"@plotly/d3\":58}],1358:[function(t,e,r){\"use strict\";var n=t(\"@plotly/d3\"),i=t(\"../../lib\"),a=t(\"../../components/drawing\"),o=t(\"../../lib/svg_text_utils\"),s=t(\"./partition\"),l=t(\"./style\").styleOne,c=t(\"./constants\"),u=t(\"../sunburst/helpers\"),f=t(\"../sunburst/fx\");e.exports=function(t,e,r,h,p){var d=p.barDifY,m=p.width,g=p.height,v=p.viewX,y=p.viewY,x=p.pathSlice,b=p.toMoveInsideSlice,_=p.strTransform,w=p.hasTransition,T=p.handleSlicesExit,k=p.makeUpdateSliceInterpolator,M=p.makeUpdateTextInterpolator,A={},S=t._fullLayout,E=e[0],L=E.trace,C=E.hierarchy,P=m/L._entryDepth,I=u.listPath(r.data,\"id\"),O=s(C.copy(),[m,g],{packing:\"dice\",pad:{inner:0,top:0,left:0,right:0,bottom:0}}).descendants();(O=O.filter((function(t){var e=I.indexOf(t.data.id);return-1!==e&&(t.x0=P*e,t.x1=P*(e+1),t.y0=d,t.y1=d+g,t.onPathbar=!0,!0)}))).reverse(),(h=h.data(O,u.getPtId)).enter().append(\"g\").classed(\"pathbar\",!0),T(h,!0,A,[m,g],x),h.order();var z=h;w&&(z=z.transition().each(\"end\",(function(){var e=n.select(this);u.setSliceCursor(e,t,{hideOnRoot:!1,hideOnLeaves:!1,isTransitioning:!1})}))),z.each((function(s){s._hoverX=v(s.x1-Math.min(m,g)/2),s._hoverY=y(s.y1-g/2);var h=n.select(this),p=i.ensureSingle(h,\"path\",\"surface\",(function(t){t.style(\"pointer-events\",\"all\")}));w?p.transition().attrTween(\"d\",(function(t){var e=k(t,!0,A,[m,g]);return function(t){return x(e(t))}})):p.attr(\"d\",x),h.call(f,r,t,e,{styleOne:l,eventDataKeys:c.eventDataKeys,transitionTime:c.CLICK_TRANSITION_TIME,transitionEasing:c.CLICK_TRANSITION_EASING}).call(u.setSliceCursor,t,{hideOnRoot:!1,hideOnLeaves:!1,isTransitioning:t._transitioning}),p.call(l,s,L,{hovered:!1}),s._text=(u.getPtLabel(s)||\"\").split(\"<br>\").join(\" \")||\"\";var d=i.ensureSingle(h,\"g\",\"slicetext\"),T=i.ensureSingle(d,\"text\",\"\",(function(t){t.attr(\"data-notex\",1)})),E=i.ensureUniformFontSize(t,u.determineTextFont(L,s,S.font,{onPathbar:!0}));T.text(s._text||\" \").classed(\"slicetext\",!0).attr(\"text-anchor\",\"start\").call(a.font,E).call(o.convertToTspans,t),s.textBB=a.bBox(T.node()),s.transform=b(s,{fontSize:E.size,onPathbar:!0}),s.transform.fontSize=E.size,w?T.transition().attrTween(\"transform\",(function(t){var e=M(t,!0,A,[m,g]);return function(t){return _(e(t))}})):T.attr(\"transform\",_(s))}))}},{\"../../components/drawing\":684,\"../../lib\":799,\"../../lib/svg_text_utils\":824,\"../sunburst/fx\":1331,\"../sunburst/helpers\":1332,\"./constants\":1355,\"./partition\":1364,\"./style\":1367,\"@plotly/d3\":58}],1359:[function(t,e,r){\"use strict\";var n=t(\"@plotly/d3\"),i=t(\"../../lib\"),a=t(\"../../components/drawing\"),o=t(\"../../lib/svg_text_utils\"),s=t(\"./partition\"),l=t(\"./style\").styleOne,c=t(\"./constants\"),u=t(\"../sunburst/helpers\"),f=t(\"../sunburst/fx\"),h=t(\"../sunburst/plot\").formatSliceLabel;e.exports=function(t,e,r,p,d){var m=d.width,g=d.height,v=d.viewX,y=d.viewY,x=d.pathSlice,b=d.toMoveInsideSlice,_=d.strTransform,w=d.hasTransition,T=d.handleSlicesExit,k=d.makeUpdateSliceInterpolator,M=d.makeUpdateTextInterpolator,A=d.prevEntry,S=t._fullLayout,E=e[0].trace,L=-1!==E.textposition.indexOf(\"left\"),C=-1!==E.textposition.indexOf(\"right\"),P=-1!==E.textposition.indexOf(\"bottom\"),I=!P&&!E.marker.pad.t||P&&!E.marker.pad.b,O=s(r,[m,g],{packing:E.tiling.packing,squarifyratio:E.tiling.squarifyratio,flipX:E.tiling.flip.indexOf(\"x\")>-1,flipY:E.tiling.flip.indexOf(\"y\")>-1,pad:{inner:E.tiling.pad,top:E.marker.pad.t,left:E.marker.pad.l,right:E.marker.pad.r,bottom:E.marker.pad.b}}).descendants(),z=1/0,D=-1/0;O.forEach((function(t){var e=t.depth;e>=E._maxDepth?(t.x0=t.x1=(t.x0+t.x1)/2,t.y0=t.y1=(t.y0+t.y1)/2):(z=Math.min(z,e),D=Math.max(D,e))})),p=p.data(O,u.getPtId),E._maxVisibleLayers=isFinite(D)?D-z+1:0,p.enter().append(\"g\").classed(\"slice\",!0),T(p,!1,{},[m,g],x),p.order();var R=null;if(w&&A){var F=u.getPtId(A);p.each((function(t){null===R&&u.getPtId(t)===F&&(R={x0:t.x0,x1:t.x1,y0:t.y0,y1:t.y1})}))}var B=function(){return R||{x0:0,x1:m,y0:0,y1:g}},N=p;return w&&(N=N.transition().each(\"end\",(function(){var e=n.select(this);u.setSliceCursor(e,t,{hideOnRoot:!0,hideOnLeaves:!1,isTransitioning:!1})}))),N.each((function(s){var p=u.isHeader(s,E);s._hoverX=v(s.x1-E.marker.pad.r),s._hoverY=y(P?s.y1-E.marker.pad.b/2:s.y0+E.marker.pad.t/2);var d=n.select(this),T=i.ensureSingle(d,\"path\",\"surface\",(function(t){t.style(\"pointer-events\",\"all\")}));w?T.transition().attrTween(\"d\",(function(t){var e=k(t,!1,B(),[m,g]);return function(t){return x(e(t))}})):T.attr(\"d\",x),d.call(f,r,t,e,{styleOne:l,eventDataKeys:c.eventDataKeys,transitionTime:c.CLICK_TRANSITION_TIME,transitionEasing:c.CLICK_TRANSITION_EASING}).call(u.setSliceCursor,t,{isTransitioning:t._transitioning}),T.call(l,s,E,{hovered:!1}),s.x0===s.x1||s.y0===s.y1?s._text=\"\":s._text=p?I?\"\":u.getPtLabel(s)||\"\":h(s,r,E,e,S)||\"\";var A=i.ensureSingle(d,\"g\",\"slicetext\"),O=i.ensureSingle(A,\"text\",\"\",(function(t){t.attr(\"data-notex\",1)})),z=i.ensureUniformFontSize(t,u.determineTextFont(E,s,S.font));O.text(s._text||\" \").classed(\"slicetext\",!0).attr(\"text-anchor\",C?\"end\":L||p?\"start\":\"middle\").call(a.font,z).call(o.convertToTspans,t),s.textBB=a.bBox(O.node()),s.transform=b(s,{fontSize:z.size,isHeader:p}),s.transform.fontSize=z.size,w?O.transition().attrTween(\"transform\",(function(t){var e=M(t,!1,B(),[m,g]);return function(t){return _(e(t))}})):O.attr(\"transform\",_(s))})),R}},{\"../../components/drawing\":684,\"../../lib\":799,\"../../lib/svg_text_utils\":824,\"../sunburst/fx\":1331,\"../sunburst/helpers\":1332,\"../sunburst/plot\":1336,\"./constants\":1355,\"./partition\":1364,\"./style\":1367,\"@plotly/d3\":58}],1360:[function(t,e,r){\"use strict\";e.exports=function t(e,r,n){var i;n.swapXY&&(i=e.x0,e.x0=e.y0,e.y0=i,i=e.x1,e.x1=e.y1,e.y1=i),n.flipX&&(i=e.x0,e.x0=r[0]-e.x1,e.x1=r[0]-i),n.flipY&&(i=e.y0,e.y0=r[1]-e.y1,e.y1=r[1]-i);var a=e.children;if(a)for(var o=0;o<a.length;o++)t(a[o],r,n)}},{}],1361:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"treemap\",basePlotModule:t(\"./base_plot\"),categories:[],animatable:!0,attributes:t(\"./attributes\"),layoutAttributes:t(\"./layout_attributes\"),supplyDefaults:t(\"./defaults\"),supplyLayoutDefaults:t(\"./layout_defaults\"),calc:t(\"./calc\").calc,crossTraceCalc:t(\"./calc\").crossTraceCalc,plot:t(\"./plot\"),style:t(\"./style\").style,colorbar:t(\"../scatter/marker_colorbar\"),meta:{}}},{\"../scatter/marker_colorbar\":1232,\"./attributes\":1352,\"./base_plot\":1353,\"./calc\":1354,\"./defaults\":1356,\"./layout_attributes\":1362,\"./layout_defaults\":1363,\"./plot\":1365,\"./style\":1367}],1362:[function(t,e,r){\"use strict\";e.exports={treemapcolorway:{valType:\"colorlist\",editType:\"calc\"},extendtreemapcolors:{valType:\"boolean\",dflt:!0,editType:\"calc\"}}},{}],1363:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\");e.exports=function(t,e){function r(r,a){return n.coerce(t,e,i,r,a)}r(\"treemapcolorway\",e.colorway),r(\"extendtreemapcolors\")}},{\"../../lib\":799,\"./layout_attributes\":1362}],1364:[function(t,e,r){\"use strict\";var n=t(\"d3-hierarchy\"),i=t(\"./flip_tree\");e.exports=function(t,e,r){var a,o=r.flipX,s=r.flipY,l=\"dice-slice\"===r.packing,c=r.pad[s?\"bottom\":\"top\"],u=r.pad[o?\"right\":\"left\"],f=r.pad[o?\"left\":\"right\"],h=r.pad[s?\"top\":\"bottom\"];l&&(a=u,u=c,c=a,a=f,f=h,h=a);var p=n.treemap().tile(function(t,e){switch(t){case\"squarify\":return n.treemapSquarify.ratio(e);case\"binary\":return n.treemapBinary;case\"dice\":return n.treemapDice;case\"slice\":return n.treemapSlice;default:return n.treemapSliceDice}}(r.packing,r.squarifyratio)).paddingInner(r.pad.inner).paddingLeft(u).paddingRight(f).paddingTop(c).paddingBottom(h).size(l?[e[1],e[0]]:e)(t);return(l||o||s)&&i(p,e,{swapXY:l,flipX:o,flipY:s}),p}},{\"./flip_tree\":1360,\"d3-hierarchy\":167}],1365:[function(t,e,r){\"use strict\";var n=t(\"./draw\"),i=t(\"./draw_descendants\");e.exports=function(t,e,r,a){return n(t,e,r,a,{type:\"treemap\",drawDescendants:i})}},{\"./draw\":1357,\"./draw_descendants\":1359}],1366:[function(t,e,r){\"use strict\";var n=t(\"@plotly/d3\"),i=t(\"../sunburst/helpers\"),a=t(\"../../lib\"),o=t(\"../bar/constants\").TEXTPAD,s=t(\"../bar/plot\").toMoveInsideBar,l=t(\"../bar/uniform_text\").recordMinTextSize,c=t(\"./constants\"),u=t(\"./draw_ancestors\");function f(t){return i.isHierarchyRoot(t)?\"\":i.getPtId(t)}e.exports=function(t,e,r,h,p){var d=t._fullLayout,m=e[0],g=m.trace,v=\"icicle\"===g.type,y=m.hierarchy,x=i.findEntryWithLevel(y,g.level),b=n.select(r),_=b.selectAll(\"g.pathbar\"),w=b.selectAll(\"g.slice\");if(!x)return _.remove(),void w.remove();var T=i.isHierarchyRoot(x),k=!d.uniformtext.mode&&i.hasTransition(h),M=i.getMaxDepth(g),A=d._size,S=g.domain,E=A.w*(S.x[1]-S.x[0]),L=A.h*(S.y[1]-S.y[0]),C=E,P=g.pathbar.thickness,I=g.marker.line.width+c.gapWithPathbar,O=g.pathbar.visible?g.pathbar.side.indexOf(\"bottom\")>-1?L+I:-(P+I):0,z={x0:C,x1:C,y0:O,y1:O+P},D=function(t,e,r){var n=g.tiling.pad,i=function(t){return t-n<=e.x0},a=function(t){return t+n>=e.x1},o=function(t){return t-n<=e.y0},s=function(t){return t+n>=e.y1};return t.x0===e.x0&&t.x1===e.x1&&t.y0===e.y0&&t.y1===e.y1?{x0:t.x0,x1:t.x1,y0:t.y0,y1:t.y1}:{x0:i(t.x0-n)?0:a(t.x0-n)?r[0]:t.x0,x1:i(t.x1+n)?0:a(t.x1+n)?r[0]:t.x1,y0:o(t.y0-n)?0:s(t.y0-n)?r[1]:t.y0,y1:o(t.y1+n)?0:s(t.y1+n)?r[1]:t.y1}},R=null,F={},B={},N=null,j=function(t,e){return e?F[f(t)]:B[f(t)]},U=function(t,e,r,n){if(e)return F[f(y)]||z;var i=B[g.level]||r;return function(t){return t.data.depth-x.data.depth<M}(t)?D(t,i,n):{}};m.hasMultipleRoots&&T&&M++,g._maxDepth=M,g._backgroundColor=d.paper_bgcolor,g._entryDepth=x.data.depth,g._atRootLevel=T;var V=-E/2+A.l+A.w*(S.x[1]+S.x[0])/2,q=-L/2+A.t+A.h*(1-(S.y[1]+S.y[0])/2),H=function(t){return V+t},G=function(t){return q+t},Y=G(0),W=H(0),X=function(t){return W+t},Z=function(t){return Y+t};function J(t,e){return t+\",\"+e}var K=X(0),Q=function(t){t.x=Math.max(K,t.x)},$=g.pathbar.edgeshape,tt=function(t,e){var r=t.x0,n=t.x1,i=t.y0,a=t.y1,c=t.textBB,u=function(t){return-1!==g.textposition.indexOf(t)},f=u(\"bottom\"),h=u(\"top\")||e.isHeader&&!f?\"start\":f?\"end\":\"middle\",p=u(\"right\"),m=u(\"left\")||e.onPathbar?-1:p?1:0,y=g[v?\"tiling\":\"marker\"].pad;if(e.isHeader){if((r+=(v?y:y.l)-o)>=(n-=(v?y:y.r)-o)){var x=(r+n)/2;r=x,n=x}var b;f?i<(b=a-(v?y:y.b))&&b<a&&(i=b):i<(b=i+(v?y:y.t))&&b<a&&(a=b)}var _=s(r,n,i,a,c,{isHorizontal:!1,constrained:!0,angle:0,anchor:h,leftToRight:m});return _.fontSize=e.fontSize,_.targetX=H(_.targetX),_.targetY=G(_.targetY),isNaN(_.targetX)||isNaN(_.targetY)?{}:(r!==n&&i!==a&&l(g.type,_,d),{scale:_.scale,rotate:_.rotate,textX:_.textX,textY:_.textY,anchorX:_.anchorX,anchorY:_.anchorY,targetX:_.targetX,targetY:_.targetY})},et=function(t,e){for(var r,n=0,i=t;!r&&n<M;)n++,(i=i.parent)?r=j(i,e):n=M;return r||{}},rt=function(t,e,r,i,o){var s,l=j(t,e);if(l)s=l;else if(e)s=z;else if(R)if(t.parent){var c=N||r;c&&!e?s=D(t,c,i):(s={},a.extendFlat(s,et(t,e)))}else s=a.extendFlat({},t),v&&(\"h\"===o.orientation?o.flipX?s.x0=t.x1:s.x1=0:o.flipY?s.y0=t.y1:s.y1=0);else s={};return n.interpolate(s,{x0:t.x0,x1:t.x1,y0:t.y0,y1:t.y1})},nt=function(t,e,r,o){var s=j(t,e),c={},u=U(t,e,r,o);a.extendFlat(c,{transform:tt({x0:u.x0,x1:u.x1,y0:u.y0,y1:u.y1,textBB:t.textBB,_text:t._text},{isHeader:i.isHeader(t,g)})}),s?c=s:t.parent&&a.extendFlat(c,et(t,e));var f=t.transform;return t.x0!==t.x1&&t.y0!==t.y1&&l(g.type,f,d),n.interpolate(c,{transform:{scale:f.scale,rotate:f.rotate,textX:f.textX,textY:f.textY,anchorX:f.anchorX,anchorY:f.anchorY,targetX:f.targetX,targetY:f.targetY}})},it=function(t,e,r,i,a){var o=i[0],s=i[1];k?t.exit().transition().each((function(){var t=n.select(this);t.select(\"path.surface\").transition().attrTween(\"d\",(function(t){var r=function(t,e,r,i){var a,o=j(t,e);if(e)a=z;else{var s=j(x,e);a=s?D(t,s,i):{}}return n.interpolate(o,a)}(t,e,0,[o,s]);return function(t){return a(r(t))}})),t.select(\"g.slicetext\").attr(\"opacity\",0)})).remove():t.exit().remove()},at=function(t){var e=t.transform;return t.x0!==t.x1&&t.y0!==t.y1&&l(g.type,e,d),a.getTextTransform({textX:e.textX,textY:e.textY,anchorX:e.anchorX,anchorY:e.anchorY,targetX:e.targetX,targetY:e.targetY,scale:e.scale,rotate:e.rotate})};k&&(_.each((function(t){F[f(t)]={x0:t.x0,x1:t.x1,y0:t.y0,y1:t.y1},t.transform&&(F[f(t)].transform={textX:t.transform.textX,textY:t.transform.textY,anchorX:t.transform.anchorX,anchorY:t.transform.anchorY,targetX:t.transform.targetX,targetY:t.transform.targetY,scale:t.transform.scale,rotate:t.transform.rotate})})),w.each((function(t){B[f(t)]={x0:t.x0,x1:t.x1,y0:t.y0,y1:t.y1},t.transform&&(B[f(t)].transform={textX:t.transform.textX,textY:t.transform.textY,anchorX:t.transform.anchorX,anchorY:t.transform.anchorY,targetX:t.transform.targetX,targetY:t.transform.targetY,scale:t.transform.scale,rotate:t.transform.rotate}),!R&&i.isEntry(t)&&(R=t)}))),N=p(t,e,x,w,{width:E,height:L,viewX:H,viewY:G,pathSlice:function(t){var e=H(t.x0),r=H(t.x1),n=G(t.y0),i=G(t.y1),a=r-e,o=i-n;if(!a||!o)return\"\";return\"M\"+J(e,n+0)+\"L\"+J(r-0,n)+\"L\"+J(r,i-0)+\"L\"+J(e+0,i)+\"Z\"},toMoveInsideSlice:tt,prevEntry:R,makeUpdateSliceInterpolator:rt,makeUpdateTextInterpolator:nt,handleSlicesExit:it,hasTransition:k,strTransform:at}),g.pathbar.visible?u(t,e,x,_,{barDifY:O,width:C,height:P,viewX:X,viewY:Z,pathSlice:function(t){var e=X(Math.max(Math.min(t.x0,t.x0),0)),r=X(Math.min(Math.max(t.x1,t.x1),C)),n=Z(t.y0),i=Z(t.y1),a=P/2,o={},s={};o.x=e,s.x=r,o.y=s.y=(n+i)/2;var l={x:e,y:n},c={x:r,y:n},u={x:r,y:i},f={x:e,y:i};return\">\"===$?(l.x-=a,c.x-=a,u.x-=a,f.x-=a):\"/\"===$?(u.x-=a,f.x-=a,o.x-=a/2,s.x-=a/2):\"\\\\\"===$?(l.x-=a,c.x-=a,o.x-=a/2,s.x-=a/2):\"<\"===$&&(o.x-=a,s.x-=a),Q(l),Q(f),Q(o),Q(c),Q(u),Q(s),\"M\"+J(l.x,l.y)+\"L\"+J(c.x,c.y)+\"L\"+J(s.x,s.y)+\"L\"+J(u.x,u.y)+\"L\"+J(f.x,f.y)+\"L\"+J(o.x,o.y)+\"Z\"},toMoveInsideSlice:tt,makeUpdateSliceInterpolator:rt,makeUpdateTextInterpolator:nt,handleSlicesExit:it,hasTransition:k,strTransform:at}):_.remove()}},{\"../../lib\":799,\"../bar/constants\":939,\"../bar/plot\":948,\"../bar/uniform_text\":953,\"../sunburst/helpers\":1332,\"./constants\":1355,\"./draw_ancestors\":1358,\"@plotly/d3\":58}],1367:[function(t,e,r){\"use strict\";var n=t(\"@plotly/d3\"),i=t(\"../../components/color\"),a=t(\"../../lib\"),o=t(\"../sunburst/helpers\"),s=t(\"../bar/uniform_text\").resizeText;function l(t,e,r,n){var s,l,c=(n||{}).hovered,u=e.data.data,f=u.i,h=u.color,p=o.isHierarchyRoot(e),d=1;if(c)s=r._hovered.marker.line.color,l=r._hovered.marker.line.width;else if(p&&h===r.root.color)d=100,s=\"rgba(0,0,0,0)\",l=0;else if(s=a.castOption(r,f,\"marker.line.color\")||i.defaultLine,l=a.castOption(r,f,\"marker.line.width\")||0,!r._hasColorscale&&!e.onPathbar){var m=r.marker.depthfade;if(m){var g,v=i.combine(i.addOpacity(r._backgroundColor,.75),h);if(!0===m){var y=o.getMaxDepth(r);g=isFinite(y)?o.isLeaf(e)?0:r._maxVisibleLayers-(e.data.depth-r._entryDepth):e.data.height+1}else g=e.data.depth-r._entryDepth,r._atRootLevel||g++;if(g>0)for(var x=0;x<g;x++){var b=.5*x/g;h=i.combine(i.addOpacity(v,b),h)}}}t.style(\"stroke-width\",l).call(i.fill,h).call(i.stroke,s).style(\"opacity\",d)}e.exports={style:function(t){var e=t._fullLayout._treemaplayer.selectAll(\".trace\");s(t,e,\"treemap\"),e.each((function(t){var e=n.select(this),r=t[0].trace;e.style(\"opacity\",r.opacity),e.selectAll(\"path.surface\").each((function(t){n.select(this).call(l,t,r,{hovered:!1})}))}))},styleOne:l}},{\"../../components/color\":662,\"../../lib\":799,\"../bar/uniform_text\":953,\"../sunburst/helpers\":1332,\"@plotly/d3\":58}],1368:[function(t,e,r){\"use strict\";var n=t(\"../box/attributes\"),i=t(\"../../lib/extend\").extendFlat,a=t(\"../../plots/cartesian/axis_format_attributes\").axisHoverFormat;e.exports={y:n.y,x:n.x,x0:n.x0,y0:n.y0,xhoverformat:a(\"x\"),yhoverformat:a(\"y\"),name:i({},n.name,{}),orientation:i({},n.orientation,{}),bandwidth:{valType:\"number\",min:0,editType:\"calc\"},scalegroup:{valType:\"string\",dflt:\"\",editType:\"calc\"},scalemode:{valType:\"enumerated\",values:[\"width\",\"count\"],dflt:\"width\",editType:\"calc\"},spanmode:{valType:\"enumerated\",values:[\"soft\",\"hard\",\"manual\"],dflt:\"soft\",editType:\"calc\"},span:{valType:\"info_array\",items:[{valType:\"any\",editType:\"calc\"},{valType:\"any\",editType:\"calc\"}],editType:\"calc\"},line:{color:{valType:\"color\",editType:\"style\"},width:{valType:\"number\",min:0,dflt:2,editType:\"style\"},editType:\"plot\"},fillcolor:n.fillcolor,points:i({},n.boxpoints,{}),jitter:i({},n.jitter,{}),pointpos:i({},n.pointpos,{}),width:i({},n.width,{}),marker:n.marker,text:n.text,hovertext:n.hovertext,hovertemplate:n.hovertemplate,box:{visible:{valType:\"boolean\",dflt:!1,editType:\"plot\"},width:{valType:\"number\",min:0,max:1,dflt:.25,editType:\"plot\"},fillcolor:{valType:\"color\",editType:\"style\"},line:{color:{valType:\"color\",editType:\"style\"},width:{valType:\"number\",min:0,editType:\"style\"},editType:\"style\"},editType:\"plot\"},meanline:{visible:{valType:\"boolean\",dflt:!1,editType:\"plot\"},color:{valType:\"color\",editType:\"style\"},width:{valType:\"number\",min:0,editType:\"style\"},editType:\"plot\"},side:{valType:\"enumerated\",values:[\"both\",\"positive\",\"negative\"],dflt:\"both\",editType:\"calc\"},offsetgroup:n.offsetgroup,alignmentgroup:n.alignmentgroup,selected:n.selected,unselected:n.unselected,hoveron:{valType:\"flaglist\",flags:[\"violins\",\"points\",\"kde\"],dflt:\"violins+points+kde\",extras:[\"all\"],editType:\"style\"}}},{\"../../lib/extend\":789,\"../../plots/cartesian/axis_format_attributes\":852,\"../box/attributes\":962}],1369:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../box/calc\"),o=t(\"./helpers\"),s=t(\"../../constants/numerical\").BADNUM;function l(t,e,r){var i=e.max-e.min;if(!i)return t.bandwidth?t.bandwidth:0;if(t.bandwidth)return Math.max(t.bandwidth,i/1e4);var a=r.length,o=n.stdev(r,a-1,e.mean);return Math.max(function(t,e,r){return 1.059*Math.min(e,r/1.349)*Math.pow(t,-.2)}(a,o,e.q3-e.q1),i/100)}function c(t,e,r,n){var a,o=t.spanmode,l=t.span||[],c=[e.min,e.max],u=[e.min-2*n,e.max+2*n];function f(n){var i=l[n],a=\"multicategory\"===r.type?r.r2c(i):r.d2c(i,0,t[e.valLetter+\"calendar\"]);return a===s?u[n]:a}var h={type:\"linear\",range:a=\"soft\"===o?u:\"hard\"===o?c:[f(0),f(1)]};return i.setConvert(h),h.cleanRange(),a}e.exports=function(t,e){var r=a(t,e);if(r[0].t.empty)return r;for(var s=t._fullLayout,u=i.getFromId(t,e[\"h\"===e.orientation?\"xaxis\":\"yaxis\"]),f=1/0,h=-1/0,p=0,d=0,m=0;m<r.length;m++){var g=r[m],v=g.pts.map(o.extractVal),y=g.bandwidth=l(e,g,v),x=g.span=c(e,g,u,y);if(g.min===g.max&&0===y)x=g.span=[g.min,g.max],g.density=[{v:1,t:x[0]}],g.bandwidth=y,p=Math.max(p,1);else{var b=x[1]-x[0],_=Math.ceil(b/(y/3)),w=b/_;if(!isFinite(w)||!isFinite(_))return n.error(\"Something went wrong with computing the violin span\"),r[0].t.empty=!0,r;var T=o.makeKDE(g,e,v);g.density=new Array(_);for(var k=0,M=x[0];M<x[1]+w/2;k++,M+=w){var A=T(M);g.density[k]={v:A,t:M},p=Math.max(p,A)}}d=Math.max(d,v.length),f=Math.min(f,x[0]),h=Math.max(h,x[1])}var S=i.findExtremes(u,[f,h],{padded:!0});if(e._extremes[u._id]=S,e.width)r[0].t.maxKDE=p;else{var E=s._violinScaleGroupStats,L=e.scalegroup,C=E[L];C?(C.maxKDE=Math.max(C.maxKDE,p),C.maxCount=Math.max(C.maxCount,d)):E[L]={maxKDE:p,maxCount:d}}return r[0].t.labels.kde=n._(t,\"kde:\"),r}},{\"../../constants/numerical\":775,\"../../lib\":799,\"../../plots/cartesian/axes\":849,\"../box/calc\":963,\"./helpers\":1372}],1370:[function(t,e,r){\"use strict\";var n=t(\"../box/cross_trace_calc\").setPositionOffset,i=[\"v\",\"h\"];e.exports=function(t,e){for(var r=t.calcdata,a=e.xaxis,o=e.yaxis,s=0;s<i.length;s++){for(var l=i[s],c=\"h\"===l?o:a,u=[],f=0;f<r.length;f++){var h=r[f],p=h[0].t,d=h[0].trace;!0!==d.visible||\"violin\"!==d.type||p.empty||d.orientation!==l||d.xaxis!==a._id||d.yaxis!==o._id||u.push(f)}n(\"violin\",t,u,c)}}},{\"../box/cross_trace_calc\":964}],1371:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/color\"),a=t(\"../box/defaults\"),o=t(\"./attributes\");e.exports=function(t,e,r,s){function l(r,i){return n.coerce(t,e,o,r,i)}function c(r,i){return n.coerce2(t,e,o,r,i)}if(a.handleSampleDefaults(t,e,l,s),!1!==e.visible){l(\"bandwidth\"),l(\"side\"),l(\"width\")||(l(\"scalegroup\",e.name),l(\"scalemode\"));var u,f=l(\"span\");Array.isArray(f)&&(u=\"manual\"),l(\"spanmode\",u);var h=l(\"line.color\",(t.marker||{}).color||r),p=l(\"line.width\"),d=l(\"fillcolor\",i.addOpacity(e.line.color,.5));a.handlePointsDefaults(t,e,l,{prefix:\"\"});var m=c(\"box.width\"),g=c(\"box.fillcolor\",d),v=c(\"box.line.color\",h),y=c(\"box.line.width\",p);l(\"box.visible\",Boolean(m||g||v||y))||(e.box={visible:!1});var x=c(\"meanline.color\",h),b=c(\"meanline.width\",p);l(\"meanline.visible\",Boolean(x||b))||(e.meanline={visible:!1})}}},{\"../../components/color\":662,\"../../lib\":799,\"../box/defaults\":965,\"./attributes\":1368}],1372:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=function(t){return 1/Math.sqrt(2*Math.PI)*Math.exp(-.5*t*t)};r.makeKDE=function(t,e,r){var n=r.length,a=i,o=t.bandwidth,s=1/(n*o);return function(t){for(var e=0,i=0;i<n;i++)e+=a((t-r[i])/o);return s*e}},r.getPositionOnKdePath=function(t,e,r){var i,a;\"h\"===e.orientation?(i=\"y\",a=\"x\"):(i=\"x\",a=\"y\");var o=n.findPointOnPath(t.path,r,a,{pathLength:t.pathLength}),s=t.posCenterPx,l=o[i];return[l,\"both\"===e.side?2*s-l:s]},r.getKdeValue=function(t,e,n){var i=t.pts.map(r.extractVal);return r.makeKDE(t,e,i)(n)/t.posDensityScale},r.extractVal=function(t){return t.v}},{\"../../lib\":799}],1373:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../box/hover\"),o=t(\"./helpers\");e.exports=function(t,e,r,s,l){l||(l={});var c,u,f=l.hoverLayer,h=t.cd,p=h[0].trace,d=p.hoveron,m=-1!==d.indexOf(\"violins\"),g=-1!==d.indexOf(\"kde\"),v=[];if(m||g){var y=a.hoverOnBoxes(t,e,r,s);if(g&&y.length>0){var x,b,_,w,T,k=t.xa,M=t.ya;\"h\"===p.orientation?(T=e,x=\"y\",_=M,b=\"x\",w=k):(T=r,x=\"x\",_=k,b=\"y\",w=M);var A=h[t.index];if(T>=A.span[0]&&T<=A.span[1]){var S=n.extendFlat({},t),E=w.c2p(T,!0),L=o.getKdeValue(A,p,T),C=o.getPositionOnKdePath(A,p,E),P=_._offset,I=_._length;S[x+\"0\"]=C[0],S[x+\"1\"]=C[1],S[b+\"0\"]=S[b+\"1\"]=E,S[b+\"Label\"]=b+\": \"+i.hoverLabelText(w,T,p[b+\"hoverformat\"])+\", \"+h[0].t.labels.kde+\" \"+L.toFixed(3),S.spikeDistance=y[0].spikeDistance;var O=x+\"Spike\";S[O]=y[0][O],y[0].spikeDistance=void 0,y[0][O]=void 0,S.hovertemplate=!1,v.push(S),(u={stroke:t.color})[x+\"1\"]=n.constrain(P+C[0],P,P+I),u[x+\"2\"]=n.constrain(P+C[1],P,P+I),u[b+\"1\"]=u[b+\"2\"]=w._offset+E}}m&&(v=v.concat(y))}-1!==d.indexOf(\"points\")&&(c=a.hoverOnPoints(t,e,r));var z=f.selectAll(\".violinline-\"+p.uid).data(u?[0]:[]);return z.enter().append(\"line\").classed(\"violinline-\"+p.uid,!0).attr(\"stroke-width\",1.5),z.exit().remove(),z.attr(u),\"closest\"===s?c?[c]:v:c?(v.push(c),v):v}},{\"../../lib\":799,\"../../plots/cartesian/axes\":849,\"../box/hover\":967,\"./helpers\":1372}],1374:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),layoutAttributes:t(\"./layout_attributes\"),supplyDefaults:t(\"./defaults\"),crossTraceDefaults:t(\"../box/defaults\").crossTraceDefaults,supplyLayoutDefaults:t(\"./layout_defaults\"),calc:t(\"./calc\"),crossTraceCalc:t(\"./cross_trace_calc\"),plot:t(\"./plot\"),style:t(\"./style\"),styleOnSelect:t(\"../scatter/style\").styleOnSelect,hoverPoints:t(\"./hover\"),selectPoints:t(\"../box/select\"),moduleType:\"trace\",name:\"violin\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"symbols\",\"oriented\",\"box-violin\",\"showLegend\",\"violinLayout\",\"zoomScale\"],meta:{}}},{\"../../plots/cartesian\":863,\"../box/defaults\":965,\"../box/select\":972,\"../scatter/style\":1238,\"./attributes\":1368,\"./calc\":1369,\"./cross_trace_calc\":1370,\"./defaults\":1371,\"./hover\":1373,\"./layout_attributes\":1375,\"./layout_defaults\":1376,\"./plot\":1377,\"./style\":1378}],1375:[function(t,e,r){\"use strict\";var n=t(\"../box/layout_attributes\"),i=t(\"../../lib\").extendFlat;e.exports={violinmode:i({},n.boxmode,{}),violingap:i({},n.boxgap,{}),violingroupgap:i({},n.boxgroupgap,{})}},{\"../../lib\":799,\"../box/layout_attributes\":969}],1376:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\"),a=t(\"../box/layout_defaults\");e.exports=function(t,e,r){a._supply(t,e,r,(function(r,a){return n.coerce(t,e,i,r,a)}),\"violin\")}},{\"../../lib\":799,\"../box/layout_defaults\":970,\"./layout_attributes\":1375}],1377:[function(t,e,r){\"use strict\";var n=t(\"@plotly/d3\"),i=t(\"../../lib\"),a=t(\"../../components/drawing\"),o=t(\"../box/plot\"),s=t(\"../scatter/line_points\"),l=t(\"./helpers\");e.exports=function(t,e,r,c){var u=t._fullLayout,f=e.xaxis,h=e.yaxis;function p(t){var e=s(t,{xaxis:f,yaxis:h,connectGaps:!0,baseTolerance:.75,shape:\"spline\",simplify:!0,linearized:!0});return a.smoothopen(e[0],1)}i.makeTraceGroups(c,r,\"trace violins\").each((function(t){var r=n.select(this),a=t[0],s=a.t,c=a.trace;if(!0!==c.visible||s.empty)r.remove();else{var d=s.bPos,m=s.bdPos,g=e[s.valLetter+\"axis\"],v=e[s.posLetter+\"axis\"],y=\"both\"===c.side,x=y||\"positive\"===c.side,b=y||\"negative\"===c.side,_=r.selectAll(\"path.violin\").data(i.identity);_.enter().append(\"path\").style(\"vector-effect\",\"non-scaling-stroke\").attr(\"class\",\"violin\"),_.exit().remove(),_.each((function(t){var e,r,i,a,o,l,f,h,_=n.select(this),w=t.density,T=w.length,k=v.c2l(t.pos+d,!0),M=v.l2p(k);if(c.width)e=s.maxKDE/m;else{var A=u._violinScaleGroupStats[c.scalegroup];e=\"count\"===c.scalemode?A.maxKDE/m*(A.maxCount/t.pts.length):A.maxKDE/m}if(x){for(f=new Array(T),o=0;o<T;o++)(h=f[o]={})[s.posLetter]=k+w[o].v/e,h[s.valLetter]=g.c2l(w[o].t,!0);r=p(f)}if(b){for(f=new Array(T),l=0,o=T-1;l<T;l++,o--)(h=f[l]={})[s.posLetter]=k-w[o].v/e,h[s.valLetter]=g.c2l(w[o].t,!0);i=p(f)}if(y)a=r+\"L\"+i.substr(1)+\"Z\";else{var S=[M,g.c2p(w[0].t)],E=[M,g.c2p(w[T-1].t)];\"h\"===c.orientation&&(S.reverse(),E.reverse()),a=x?\"M\"+S+\"L\"+r.substr(1)+\"L\"+E:\"M\"+E+\"L\"+i.substr(1)+\"L\"+S}_.attr(\"d\",a),t.posCenterPx=M,t.posDensityScale=e*m,t.path=_.node(),t.pathLength=t.path.getTotalLength()/(y?2:1)}));var w,T,k,M=c.box,A=M.width,S=(M.line||{}).width;y?(w=m*A,T=0):x?(w=[0,m*A/2],T=S*{x:1,y:-1}[s.posLetter]):(w=[m*A/2,0],T=S*{x:-1,y:1}[s.posLetter]),o.plotBoxAndWhiskers(r,{pos:v,val:g},c,{bPos:d,bdPos:w,bPosPxOffset:T}),o.plotBoxMean(r,{pos:v,val:g},c,{bPos:d,bdPos:w,bPosPxOffset:T}),!c.box.visible&&c.meanline.visible&&(k=i.identity);var E=r.selectAll(\"path.meanline\").data(k||[]);E.enter().append(\"path\").attr(\"class\",\"meanline\").style(\"fill\",\"none\").style(\"vector-effect\",\"non-scaling-stroke\"),E.exit().remove(),E.each((function(t){var e=g.c2p(t.mean,!0),r=l.getPositionOnKdePath(t,c,e);n.select(this).attr(\"d\",\"h\"===c.orientation?\"M\"+e+\",\"+r[0]+\"V\"+r[1]:\"M\"+r[0]+\",\"+e+\"H\"+r[1])})),o.plotPoints(r,{x:f,y:h},c,s)}}))}},{\"../../components/drawing\":684,\"../../lib\":799,\"../box/plot\":971,\"../scatter/line_points\":1228,\"./helpers\":1372,\"@plotly/d3\":58}],1378:[function(t,e,r){\"use strict\";var n=t(\"@plotly/d3\"),i=t(\"../../components/color\"),a=t(\"../scatter/style\").stylePoints;e.exports=function(t){var e=n.select(t).selectAll(\"g.trace.violins\");e.style(\"opacity\",(function(t){return t[0].trace.opacity})),e.each((function(e){var r=e[0].trace,o=n.select(this),s=r.box||{},l=s.line||{},c=r.meanline||{},u=c.width;o.selectAll(\"path.violin\").style(\"stroke-width\",r.line.width+\"px\").call(i.stroke,r.line.color).call(i.fill,r.fillcolor),o.selectAll(\"path.box\").style(\"stroke-width\",l.width+\"px\").call(i.stroke,l.color).call(i.fill,s.fillcolor);var f={\"stroke-width\":u+\"px\",\"stroke-dasharray\":2*u+\"px,\"+u+\"px\"};o.selectAll(\"path.mean\").style(f).call(i.stroke,c.color),o.selectAll(\"path.meanline\").style(f).call(i.stroke,c.color),a(o,r,t)}))}},{\"../../components/color\":662,\"../scatter/style\":1238,\"@plotly/d3\":58}],1379:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/attributes\"),i=t(\"../isosurface/attributes\"),a=t(\"../surface/attributes\"),o=t(\"../../plots/attributes\"),s=t(\"../../lib/extend\").extendFlat,l=t(\"../../plot_api/edit_types\").overrideAll,c=e.exports=l(s({x:i.x,y:i.y,z:i.z,value:i.value,isomin:i.isomin,isomax:i.isomax,surface:i.surface,spaceframe:{show:{valType:\"boolean\",dflt:!1},fill:{valType:\"number\",min:0,max:1,dflt:1}},slices:i.slices,caps:i.caps,text:i.text,hovertext:i.hovertext,xhoverformat:i.xhoverformat,yhoverformat:i.yhoverformat,zhoverformat:i.zhoverformat,valuehoverformat:i.valuehoverformat,hovertemplate:i.hovertemplate},n(\"\",{colorAttr:\"`value`\",showScaleDflt:!0,editTypeOverride:\"calc\"}),{colorbar:i.colorbar,opacity:i.opacity,opacityscale:a.opacityscale,lightposition:i.lightposition,lighting:i.lighting,flatshading:i.flatshading,contour:i.contour,hoverinfo:s({},o.hoverinfo),showlegend:s({},o.showlegend,{dflt:!1})}),\"calc\",\"nested\");c.x.editType=c.y.editType=c.z.editType=c.value.editType=\"calc+clearAxisTypes\",c.transforms=void 0},{\"../../components/colorscale/attributes\":669,\"../../lib/extend\":789,\"../../plot_api/edit_types\":831,\"../../plots/attributes\":845,\"../isosurface/attributes\":1150,\"../surface/attributes\":1338}],1380:[function(t,e,r){\"use strict\";var n=t(\"gl-mesh3d\"),i=t(\"../../lib/gl_format_color\").parseColorScale,a=t(\"../../lib/str2rgbarray\"),o=t(\"../../components/colorscale\").extractOpts,s=t(\"../../plots/gl3d/zip3\"),l=t(\"../isosurface/convert\").findNearestOnAxis,c=t(\"../isosurface/convert\").generateIsoMeshes;function u(t,e,r){this.scene=t,this.uid=r,this.mesh=e,this.name=\"\",this.data=null,this.showContour=!1}var f=u.prototype;f.handlePick=function(t){if(t.object===this.mesh){var e=t.data.index,r=this.data._meshX[e],n=this.data._meshY[e],i=this.data._meshZ[e],a=this.data._Ys.length,o=this.data._Zs.length,s=l(r,this.data._Xs).id,c=l(n,this.data._Ys).id,u=l(i,this.data._Zs).id,f=t.index=u+o*c+o*a*s;t.traceCoordinate=[this.data._meshX[f],this.data._meshY[f],this.data._meshZ[f],this.data._value[f]];var h=this.data.hovertext||this.data.text;return Array.isArray(h)&&void 0!==h[f]?t.textLabel=h[f]:h&&(t.textLabel=h),!0}},f.update=function(t){var e=this.scene,r=e.fullSceneLayout;function n(t,e,r,n){return e.map((function(e){return t.d2l(e,0,n)*r}))}this.data=c(t);var l={positions:s(n(r.xaxis,t._meshX,e.dataScale[0],t.xcalendar),n(r.yaxis,t._meshY,e.dataScale[1],t.ycalendar),n(r.zaxis,t._meshZ,e.dataScale[2],t.zcalendar)),cells:s(t._meshI,t._meshJ,t._meshK),lightPosition:[t.lightposition.x,t.lightposition.y,t.lightposition.z],ambient:t.lighting.ambient,diffuse:t.lighting.diffuse,specular:t.lighting.specular,roughness:t.lighting.roughness,fresnel:t.lighting.fresnel,vertexNormalsEpsilon:t.lighting.vertexnormalsepsilon,faceNormalsEpsilon:t.lighting.facenormalsepsilon,opacity:t.opacity,opacityscale:t.opacityscale,contourEnable:t.contour.show,contourColor:a(t.contour.color).slice(0,3),contourWidth:t.contour.width,useFacetNormals:t.flatshading},u=o(t);l.vertexIntensity=t._meshIntensity,l.vertexIntensityBounds=[u.min,u.max],l.colormap=i(t),this.mesh.update(l)},f.dispose=function(){this.scene.glplot.remove(this.mesh),this.mesh.dispose()},e.exports=function(t,e){var r=t.glplot.gl,i=n({gl:r}),a=new u(t,i,e.uid);return i._trace=a,a.update(e),t.glplot.add(i),a}},{\"../../components/colorscale\":674,\"../../lib/gl_format_color\":795,\"../../lib/str2rgbarray\":823,\"../../plots/gl3d/zip3\":903,\"../isosurface/convert\":1152,\"gl-mesh3d\":311}],1381:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\"),a=t(\"../isosurface/defaults\").supplyIsoDefaults,o=t(\"../surface/defaults\").opacityscaleDefaults;e.exports=function(t,e,r,s){function l(r,a){return n.coerce(t,e,i,r,a)}a(t,e,r,s,l),o(t,e,s,l)}},{\"../../lib\":799,\"../isosurface/defaults\":1153,\"../surface/defaults\":1341,\"./attributes\":1379}],1382:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"../isosurface/calc\"),colorbar:{min:\"cmin\",max:\"cmax\"},plot:t(\"./convert\"),moduleType:\"trace\",name:\"volume\",basePlotModule:t(\"../../plots/gl3d\"),categories:[\"gl3d\",\"showLegend\"],meta:{}}},{\"../../plots/gl3d\":892,\"../isosurface/calc\":1151,\"./attributes\":1379,\"./convert\":1380,\"./defaults\":1381}],1383:[function(t,e,r){\"use strict\";var n=t(\"../bar/attributes\"),i=t(\"../scatter/attributes\").line,a=t(\"../../plots/attributes\"),o=t(\"../../plots/cartesian/axis_format_attributes\").axisHoverFormat,s=t(\"../../plots/template_attributes\").hovertemplateAttrs,l=t(\"../../plots/template_attributes\").texttemplateAttrs,c=t(\"./constants\"),u=t(\"../../lib/extend\").extendFlat,f=t(\"../../components/color\");function h(t){return{marker:{color:u({},n.marker.color,{arrayOk:!1,editType:\"style\"}),line:{color:u({},n.marker.line.color,{arrayOk:!1,editType:\"style\"}),width:u({},n.marker.line.width,{arrayOk:!1,editType:\"style\"}),editType:\"style\"},editType:\"style\"},editType:\"style\"}}e.exports={measure:{valType:\"data_array\",dflt:[],editType:\"calc\"},base:{valType:\"number\",dflt:null,arrayOk:!1,editType:\"calc\"},x:n.x,x0:n.x0,dx:n.dx,y:n.y,y0:n.y0,dy:n.dy,xperiod:n.xperiod,yperiod:n.yperiod,xperiod0:n.xperiod0,yperiod0:n.yperiod0,xperiodalignment:n.xperiodalignment,yperiodalignment:n.yperiodalignment,xhoverformat:o(\"x\"),yhoverformat:o(\"y\"),hovertext:n.hovertext,hovertemplate:s({},{keys:c.eventDataKeys}),hoverinfo:u({},a.hoverinfo,{flags:[\"name\",\"x\",\"y\",\"text\",\"initial\",\"delta\",\"final\"]}),textinfo:{valType:\"flaglist\",flags:[\"label\",\"text\",\"initial\",\"delta\",\"final\"],extras:[\"none\"],editType:\"plot\",arrayOk:!1},texttemplate:l({editType:\"plot\"},{keys:c.eventDataKeys.concat([\"label\"])}),text:n.text,textposition:n.textposition,insidetextanchor:n.insidetextanchor,textangle:n.textangle,textfont:n.textfont,insidetextfont:n.insidetextfont,outsidetextfont:n.outsidetextfont,constraintext:n.constraintext,cliponaxis:n.cliponaxis,orientation:n.orientation,offset:n.offset,width:n.width,increasing:h(),decreasing:h(),totals:h(),connector:{line:{color:u({},i.color,{dflt:f.defaultLine}),width:u({},i.width,{editType:\"plot\"}),dash:i.dash,editType:\"plot\"},mode:{valType:\"enumerated\",values:[\"spanning\",\"between\"],dflt:\"between\",editType:\"plot\"},visible:{valType:\"boolean\",dflt:!0,editType:\"plot\"},editType:\"plot\"},offsetgroup:n.offsetgroup,alignmentgroup:n.alignmentgroup}},{\"../../components/color\":662,\"../../lib/extend\":789,\"../../plots/attributes\":845,\"../../plots/cartesian/axis_format_attributes\":852,\"../../plots/template_attributes\":922,\"../bar/attributes\":937,\"../scatter/attributes\":1214,\"./constants\":1385}],1384:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"../../plots/cartesian/align_period\"),a=t(\"../../lib\").mergeArray,o=t(\"../scatter/calc_selection\"),s=t(\"../../constants/numerical\").BADNUM;function l(t){return\"a\"===t||\"absolute\"===t}function c(t){return\"t\"===t||\"total\"===t}e.exports=function(t,e){var r,u,f,h,p=n.getFromId(t,e.xaxis||\"x\"),d=n.getFromId(t,e.yaxis||\"y\");\"h\"===e.orientation?(r=p.makeCalcdata(e,\"x\"),f=d.makeCalcdata(e,\"y\"),u=i(e,d,\"y\",f),h=!!e.yperiodalignment):(r=d.makeCalcdata(e,\"y\"),f=p.makeCalcdata(e,\"x\"),u=i(e,p,\"x\",f),h=!!e.xperiodalignment);for(var m,g=Math.min(u.length,r.length),v=new Array(g),y=0,x=!1,b=0;b<g;b++){var _=r[b]||0,w=!1;(r[b]!==s||c(e.measure[b])||l(e.measure[b]))&&b+1<g&&(r[b+1]!==s||c(e.measure[b+1])||l(e.measure[b+1]))&&(w=!0);var T=v[b]={i:b,p:u[b],s:_,rawS:_,cNext:w};l(e.measure[b])?(y=T.s,T.isSum=!0,T.dir=\"totals\",T.s=y):c(e.measure[b])?(T.isSum=!0,T.dir=\"totals\",T.s=y):(T.isSum=!1,T.dir=T.rawS<0?\"decreasing\":\"increasing\",m=T.s,T.s=y+m,y+=m),\"totals\"===T.dir&&(x=!0),h&&(v[b].orig_p=f[b]),e.ids&&(T.id=String(e.ids[b])),T.v=(e.base||0)+y}return v.length&&(v[0].hasTotals=x),a(e.text,v,\"tx\"),a(e.hovertext,v,\"htx\"),o(v,e),v}},{\"../../constants/numerical\":775,\"../../lib\":799,\"../../plots/cartesian/align_period\":846,\"../../plots/cartesian/axes\":849,\"../scatter/calc_selection\":1216}],1385:[function(t,e,r){\"use strict\";e.exports={eventDataKeys:[\"initial\",\"delta\",\"final\"]}},{}],1386:[function(t,e,r){\"use strict\";var n=t(\"../bar/cross_trace_calc\").setGroupPositions;e.exports=function(t,e){var r,i,a=t._fullLayout,o=t._fullData,s=t.calcdata,l=e.xaxis,c=e.yaxis,u=[],f=[],h=[];for(i=0;i<o.length;i++){var p=o[i];!0===p.visible&&p.xaxis===l._id&&p.yaxis===c._id&&\"waterfall\"===p.type&&(r=s[i],\"h\"===p.orientation?h.push(r):f.push(r),u.push(r))}var d={mode:a.waterfallmode,norm:a.waterfallnorm,gap:a.waterfallgap,groupgap:a.waterfallgroupgap};for(n(t,l,c,f,d),n(t,c,l,h,d),i=0;i<u.length;i++){r=u[i];for(var m=0;m<r.length;m++){var g=r[m];!1===g.isSum&&(g.s0+=0===m?0:r[m-1].s),m+1<r.length&&(r[m].nextP0=r[m+1].p0,r[m].nextS0=r[m+1].s0)}}}},{\"../bar/cross_trace_calc\":940}],1387:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../bar/defaults\").handleGroupingDefaults,a=t(\"../bar/defaults\").handleText,o=t(\"../scatter/xy_defaults\"),s=t(\"../scatter/period_defaults\"),l=t(\"./attributes\"),c=t(\"../../components/color\"),u=t(\"../../constants/delta.js\"),f=u.INCREASING.COLOR,h=u.DECREASING.COLOR;function p(t,e,r){t(e+\".marker.color\",r),t(e+\".marker.line.color\",c.defaultLine),t(e+\".marker.line.width\")}e.exports={supplyDefaults:function(t,e,r,i){function c(r,i){return n.coerce(t,e,l,r,i)}if(o(t,e,i,c)){s(t,e,i,c),c(\"xhoverformat\"),c(\"yhoverformat\"),c(\"measure\"),c(\"orientation\",e.x&&!e.y?\"h\":\"v\"),c(\"base\"),c(\"offset\"),c(\"width\"),c(\"text\"),c(\"hovertext\"),c(\"hovertemplate\");var u=c(\"textposition\");if(a(t,e,i,c,u,{moduleHasSelected:!1,moduleHasUnselected:!1,moduleHasConstrain:!0,moduleHasCliponaxis:!0,moduleHasTextangle:!0,moduleHasInsideanchor:!0}),\"none\"!==e.textposition&&(c(\"texttemplate\"),e.texttemplate||c(\"textinfo\")),p(c,\"increasing\",f),p(c,\"decreasing\",h),p(c,\"totals\",\"#4499FF\"),c(\"connector.visible\"))c(\"connector.mode\"),c(\"connector.line.width\")&&(c(\"connector.line.color\"),c(\"connector.line.dash\"))}else e.visible=!1},crossTraceDefaults:function(t,e){var r,a;function o(t){return n.coerce(a._input,a,l,t)}if(\"group\"===e.waterfallmode)for(var s=0;s<t.length;s++)r=(a=t[s])._input,i(r,a,e,o)}}},{\"../../components/color\":662,\"../../constants/delta.js\":769,\"../../lib\":799,\"../bar/defaults\":941,\"../scatter/period_defaults\":1234,\"../scatter/xy_defaults\":1241,\"./attributes\":1383}],1388:[function(t,e,r){\"use strict\";e.exports=function(t,e){return t.x=\"xVal\"in e?e.xVal:e.x,t.y=\"yVal\"in e?e.yVal:e.y,\"initial\"in e&&(t.initial=e.initial),\"delta\"in e&&(t.delta=e.delta),\"final\"in e&&(t.final=e.final),e.xa&&(t.xaxis=e.xa),e.ya&&(t.yaxis=e.ya),t}},{}],1389:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\").hoverLabelText,i=t(\"../../components/color\").opacity,a=t(\"../bar/hover\").hoverOnBars,o=t(\"../../constants/delta.js\"),s=o.INCREASING.SYMBOL,l=o.DECREASING.SYMBOL;e.exports=function(t,e,r,o,c){var u=a(t,e,r,o,c);if(u){var f=u.cd,h=f[0].trace,p=\"h\"===h.orientation,d=p?\"x\":\"y\",m=p?t.xa:t.ya,g=f[u.index],v=g.isSum?g.b+g.s:g.rawS;if(!g.isSum){u.initial=g.b+g.s-v,u.delta=v,u.final=u.initial+u.delta;var y=k(Math.abs(u.delta));u.deltaLabel=v<0?\"(\"+y+\")\":y,u.finalLabel=k(u.final),u.initialLabel=k(u.initial)}var x=g.hi||h.hoverinfo,b=[];if(x&&\"none\"!==x&&\"skip\"!==x){var _=\"all\"===x,w=x.split(\"+\"),T=function(t){return _||-1!==w.indexOf(t)};g.isSum||(!T(\"final\")||T(p?\"x\":\"y\")||b.push(u.finalLabel),T(\"delta\")&&(v<0?b.push(u.deltaLabel+\" \"+l):b.push(u.deltaLabel+\" \"+s)),T(\"initial\")&&b.push(\"Initial: \"+u.initialLabel))}return b.length&&(u.extraText=b.join(\"<br>\")),u.color=function(t,e){var r=t[e.dir].marker,n=r.color,a=r.line.color,o=r.line.width;if(i(n))return n;if(i(a)&&o)return a}(h,g),[u]}function k(t){return n(m,t,h[d+\"hoverformat\"])}}},{\"../../components/color\":662,\"../../constants/delta.js\":769,\"../../plots/cartesian/axes\":849,\"../bar/hover\":944}],1390:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),layoutAttributes:t(\"./layout_attributes\"),supplyDefaults:t(\"./defaults\").supplyDefaults,crossTraceDefaults:t(\"./defaults\").crossTraceDefaults,supplyLayoutDefaults:t(\"./layout_defaults\"),calc:t(\"./calc\"),crossTraceCalc:t(\"./cross_trace_calc\"),plot:t(\"./plot\"),style:t(\"./style\").style,hoverPoints:t(\"./hover\"),eventData:t(\"./event_data\"),selectPoints:t(\"../bar/select\"),moduleType:\"trace\",name:\"waterfall\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"bar-like\",\"cartesian\",\"svg\",\"oriented\",\"showLegend\",\"zoomScale\"],meta:{}}},{\"../../plots/cartesian\":863,\"../bar/select\":949,\"./attributes\":1383,\"./calc\":1384,\"./cross_trace_calc\":1386,\"./defaults\":1387,\"./event_data\":1388,\"./hover\":1389,\"./layout_attributes\":1391,\"./layout_defaults\":1392,\"./plot\":1393,\"./style\":1394}],1391:[function(t,e,r){\"use strict\";e.exports={waterfallmode:{valType:\"enumerated\",values:[\"group\",\"overlay\"],dflt:\"group\",editType:\"calc\"},waterfallgap:{valType:\"number\",min:0,max:1,editType:\"calc\"},waterfallgroupgap:{valType:\"number\",min:0,max:1,dflt:0,editType:\"calc\"}}},{}],1392:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\");e.exports=function(t,e,r){var a=!1;function o(r,a){return n.coerce(t,e,i,r,a)}for(var s=0;s<r.length;s++){var l=r[s];if(l.visible&&\"waterfall\"===l.type){a=!0;break}}a&&(o(\"waterfallmode\"),o(\"waterfallgap\",.2),o(\"waterfallgroupgap\"))}},{\"../../lib\":799,\"./layout_attributes\":1391}],1393:[function(t,e,r){\"use strict\";var n=t(\"@plotly/d3\"),i=t(\"../../lib\"),a=t(\"../../components/drawing\"),o=t(\"../../constants/numerical\").BADNUM,s=t(\"../bar/plot\"),l=t(\"../bar/uniform_text\").clearMinTextSize;e.exports=function(t,e,r,c){var u=t._fullLayout;l(\"waterfall\",u),s.plot(t,e,r,c,{mode:u.waterfallmode,norm:u.waterfallmode,gap:u.waterfallgap,groupgap:u.waterfallgroupgap}),function(t,e,r,s){var l=e.xaxis,c=e.yaxis;i.makeTraceGroups(s,r,\"trace bars\").each((function(r){var s=n.select(this),u=r[0].trace,f=i.ensureSingle(s,\"g\",\"lines\");if(u.connector&&u.connector.visible){var h=\"h\"===u.orientation,p=u.connector.mode,d=f.selectAll(\"g.line\").data(i.identity);d.enter().append(\"g\").classed(\"line\",!0),d.exit().remove();var m=d.size();d.each((function(r,s){if(s===m-1||r.cNext){var u=function(t,e,r,n){var i=[],a=[],o=n?e:r,s=n?r:e;return i[0]=o.c2p(t.s0,!0),a[0]=s.c2p(t.p0,!0),i[1]=o.c2p(t.s1,!0),a[1]=s.c2p(t.p1,!0),i[2]=o.c2p(t.nextS0,!0),a[2]=s.c2p(t.nextP0,!0),n?[i,a]:[a,i]}(r,l,c,h),f=u[0],d=u[1],g=\"\";f[0]!==o&&d[0]!==o&&f[1]!==o&&d[1]!==o&&(\"spanning\"===p&&!r.isSum&&s>0&&(g+=h?\"M\"+f[0]+\",\"+d[1]+\"V\"+d[0]:\"M\"+f[1]+\",\"+d[0]+\"H\"+f[0]),\"between\"!==p&&(r.isSum||s<m-1)&&(g+=h?\"M\"+f[1]+\",\"+d[0]+\"V\"+d[1]:\"M\"+f[0]+\",\"+d[1]+\"H\"+f[1]),f[2]!==o&&d[2]!==o&&(g+=h?\"M\"+f[1]+\",\"+d[1]+\"V\"+d[2]:\"M\"+f[1]+\",\"+d[1]+\"H\"+f[2])),\"\"===g&&(g=\"M0,0Z\"),i.ensureSingle(n.select(this),\"path\").attr(\"d\",g).call(a.setClipUrl,e.layerClipId,t)}}))}else f.remove()}))}(t,e,r,c)}},{\"../../components/drawing\":684,\"../../constants/numerical\":775,\"../../lib\":799,\"../bar/plot\":948,\"../bar/uniform_text\":953,\"@plotly/d3\":58}],1394:[function(t,e,r){\"use strict\";var n=t(\"@plotly/d3\"),i=t(\"../../components/drawing\"),a=t(\"../../components/color\"),o=t(\"../../constants/interactions\").DESELECTDIM,s=t(\"../bar/style\"),l=t(\"../bar/uniform_text\").resizeText,c=s.styleTextPoints;e.exports={style:function(t,e,r){var s=r||n.select(t).selectAll(\"g.waterfalllayer\").selectAll(\"g.trace\");l(t,s,\"waterfall\"),s.style(\"opacity\",(function(t){return t[0].trace.opacity})),s.each((function(e){var r=n.select(this),s=e[0].trace;r.selectAll(\".point > path\").each((function(t){if(!t.isBlank){var e=s[t.dir].marker;n.select(this).call(a.fill,e.color).call(a.stroke,e.line.color).call(i.dashLine,e.line.dash,e.line.width).style(\"opacity\",s.selectedpoints&&!t.selected?o:1)}})),c(r,s,t),r.selectAll(\".lines\").each((function(){var t=s.connector.line;i.lineGroupStyle(n.select(this).selectAll(\"path\"),t.width,t.color,t.dash)}))}))}}},{\"../../components/color\":662,\"../../components/drawing\":684,\"../../constants/interactions\":774,\"../bar/style\":951,\"../bar/uniform_text\":953,\"@plotly/d3\":58}],1395:[function(t,e,r){\"use strict\";var n=t(\"../plots/cartesian/axes\"),i=t(\"../lib\"),a=t(\"../plot_api/plot_schema\"),o=t(\"./helpers\").pointsAccessorFunction,s=t(\"../constants/numerical\").BADNUM;r.moduleType=\"transform\",r.name=\"aggregate\";var l=r.attributes={enabled:{valType:\"boolean\",dflt:!0,editType:\"calc\"},groups:{valType:\"string\",strict:!0,noBlank:!0,arrayOk:!0,dflt:\"x\",editType:\"calc\"},aggregations:{_isLinkedToArray:\"aggregation\",target:{valType:\"string\",editType:\"calc\"},func:{valType:\"enumerated\",values:[\"count\",\"sum\",\"avg\",\"median\",\"mode\",\"rms\",\"stddev\",\"min\",\"max\",\"first\",\"last\",\"change\",\"range\"],dflt:\"first\",editType:\"calc\"},funcmode:{valType:\"enumerated\",values:[\"sample\",\"population\"],dflt:\"sample\",editType:\"calc\"},enabled:{valType:\"boolean\",dflt:!0,editType:\"calc\"},editType:\"calc\"},editType:\"calc\"},c=l.aggregations;function u(t,e,r,a){if(a.enabled){for(var o=a.target,l=i.nestedProperty(e,o),c=l.get(),u=function(t,e){var r=t.func,n=e.d2c,a=e.c2d;switch(r){case\"count\":return f;case\"first\":return h;case\"last\":return p;case\"sum\":return function(t,e){for(var r=0,i=0;i<e.length;i++){var o=n(t[e[i]]);o!==s&&(r+=o)}return a(r)};case\"avg\":return function(t,e){for(var r=0,i=0,o=0;o<e.length;o++){var l=n(t[e[o]]);l!==s&&(r+=l,i++)}return i?a(r/i):s};case\"min\":return function(t,e){for(var r=1/0,i=0;i<e.length;i++){var o=n(t[e[i]]);o!==s&&(r=Math.min(r,o))}return r===1/0?s:a(r)};case\"max\":return function(t,e){for(var r=-1/0,i=0;i<e.length;i++){var o=n(t[e[i]]);o!==s&&(r=Math.max(r,o))}return r===-1/0?s:a(r)};case\"range\":return function(t,e){for(var r=1/0,i=-1/0,o=0;o<e.length;o++){var l=n(t[e[o]]);l!==s&&(r=Math.min(r,l),i=Math.max(i,l))}return i===-1/0||r===1/0?s:a(i-r)};case\"change\":return function(t,e){var r=n(t[e[0]]),i=n(t[e[e.length-1]]);return r===s||i===s?s:a(i-r)};case\"median\":return function(t,e){for(var r=[],o=0;o<e.length;o++){var l=n(t[e[o]]);l!==s&&r.push(l)}if(!r.length)return s;r.sort(i.sorterAsc);var c=(r.length-1)/2;return a((r[Math.floor(c)]+r[Math.ceil(c)])/2)};case\"mode\":return function(t,e){for(var r={},i=0,o=s,l=0;l<e.length;l++){var c=n(t[e[l]]);if(c!==s){var u=r[c]=(r[c]||0)+1;u>i&&(i=u,o=c)}}return i?a(o):s};case\"rms\":return function(t,e){for(var r=0,i=0,o=0;o<e.length;o++){var l=n(t[e[o]]);l!==s&&(r+=l*l,i++)}return i?a(Math.sqrt(r/i)):s};case\"stddev\":return function(e,r){var i,a=0,o=0,l=1,c=s;for(i=0;i<r.length&&c===s;i++)c=n(e[r[i]]);if(c===s)return s;for(;i<r.length;i++){var u=n(e[r[i]]);if(u!==s){var f=u-c;a+=f,o+=f*f,l++}}var h=\"sample\"===t.funcmode?l-1:l;return h?Math.sqrt((o-a*a/l)/h):0}}}(a,n.getDataConversions(t,e,o,c)),d=new Array(r.length),m=0;m<r.length;m++)d[m]=u(c,r[m]);l.set(d),\"count\"===a.func&&i.pushUnique(e._arrayAttrs,o)}}function f(t,e){return e.length}function h(t,e){return t[e[0]]}function p(t,e){return t[e[e.length-1]]}r.supplyDefaults=function(t,e){var r,n={};function o(e,r){return i.coerce(t,n,l,e,r)}if(!o(\"enabled\"))return n;var s=a.findArrayAttributes(e),u={};for(r=0;r<s.length;r++)u[s[r]]=1;var f=o(\"groups\");if(!Array.isArray(f)){if(!u[f])return n.enabled=!1,n;u[f]=0}var h,p=t.aggregations||[],d=n.aggregations=new Array(p.length);function m(t,e){return i.coerce(p[r],h,c,t,e)}for(r=0;r<p.length;r++){h={_index:r};var g=m(\"target\"),v=m(\"func\");m(\"enabled\")&&g&&(u[g]||\"count\"===v&&void 0===u[g])?(\"stddev\"===v&&m(\"funcmode\"),u[g]=0,d[r]=h):d[r]={enabled:!1,_index:r}}for(r=0;r<s.length;r++)u[s[r]]&&d.push({target:s[r],func:c.func.dflt,enabled:!0,_index:-1});return n},r.calcTransform=function(t,e,r){if(r.enabled){var n=r.groups,a=i.getTargetArray(e,{target:n});if(a){var s,l,c,f,h={},p={},d=[],m=o(e.transforms,r),g=a.length;for(e._length&&(g=Math.min(g,e._length)),s=0;s<g;s++)void 0===(c=h[l=a[s]])?(h[l]=d.length,f=[s],d.push(f),p[h[l]]=m(s)):(d[c].push(s),p[h[l]]=(p[h[l]]||[]).concat(m(s)));r._indexToPoints=p;var v=r.aggregations;for(s=0;s<v.length;s++)u(t,e,d,v[s]);\"string\"==typeof n&&u(t,e,d,{target:n,func:\"first\",enabled:!0}),e._length=d.length}}}},{\"../constants/numerical\":775,\"../lib\":799,\"../plot_api/plot_schema\":837,\"../plots/cartesian/axes\":849,\"./helpers\":1398}],1396:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"../registry\"),a=t(\"../plots/cartesian/axes\"),o=t(\"./helpers\").pointsAccessorFunction,s=t(\"../constants/filter_ops\"),l=s.COMPARISON_OPS,c=s.INTERVAL_OPS,u=s.SET_OPS;r.moduleType=\"transform\",r.name=\"filter\",r.attributes={enabled:{valType:\"boolean\",dflt:!0,editType:\"calc\"},target:{valType:\"string\",strict:!0,noBlank:!0,arrayOk:!0,dflt:\"x\",editType:\"calc\"},operation:{valType:\"enumerated\",values:[].concat(l).concat(c).concat(u),dflt:\"=\",editType:\"calc\"},value:{valType:\"any\",dflt:0,editType:\"calc\"},preservegaps:{valType:\"boolean\",dflt:!1,editType:\"calc\"},editType:\"calc\"},r.supplyDefaults=function(t){var e={};function a(i,a){return n.coerce(t,e,r.attributes,i,a)}if(a(\"enabled\")){var o=a(\"target\");if(n.isArrayOrTypedArray(o)&&0===o.length)return e.enabled=!1,e;a(\"preservegaps\"),a(\"operation\"),a(\"value\");var s=i.getComponentMethod(\"calendars\",\"handleDefaults\");s(t,e,\"valuecalendar\",null),s(t,e,\"targetcalendar\",null)}return e},r.calcTransform=function(t,e,r){if(r.enabled){var i=n.getTargetArray(e,r);if(i){var s=r.target,f=i.length;e._length&&(f=Math.min(f,e._length));var h=r.targetcalendar,p=e._arrayAttrs,d=r.preservegaps;if(\"string\"==typeof s){var m=n.nestedProperty(e,s+\"calendar\").get();m&&(h=m)}var g,v,y=function(t,e,r){var n=t.operation,i=t.value,a=Array.isArray(i);function o(t){return-1!==t.indexOf(n)}var s,f=function(r){return e(r,0,t.valuecalendar)},h=function(t){return e(t,0,r)};o(l)?s=f(a?i[0]:i):o(c)?s=a?[f(i[0]),f(i[1])]:[f(i),f(i)]:o(u)&&(s=a?i.map(f):[f(i)]);switch(n){case\"=\":return function(t){return h(t)===s};case\"!=\":return function(t){return h(t)!==s};case\"<\":return function(t){return h(t)<s};case\"<=\":return function(t){return h(t)<=s};case\">\":return function(t){return h(t)>s};case\">=\":return function(t){return h(t)>=s};case\"[]\":return function(t){var e=h(t);return e>=s[0]&&e<=s[1]};case\"()\":return function(t){var e=h(t);return e>s[0]&&e<s[1]};case\"[)\":return function(t){var e=h(t);return e>=s[0]&&e<s[1]};case\"(]\":return function(t){var e=h(t);return e>s[0]&&e<=s[1]};case\"][\":return function(t){var e=h(t);return e<=s[0]||e>=s[1]};case\")(\":return function(t){var e=h(t);return e<s[0]||e>s[1]};case\"](\":return function(t){var e=h(t);return e<=s[0]||e>s[1]};case\")[\":return function(t){var e=h(t);return e<s[0]||e>=s[1]};case\"{}\":return function(t){return-1!==s.indexOf(h(t))};case\"}{\":return function(t){return-1===s.indexOf(h(t))}}}(r,a.getDataToCoordFunc(t,e,s,i),h),x={},b={},_=0;d?(g=function(t){x[t.astr]=n.extendDeep([],t.get()),t.set(new Array(f))},v=function(t,e){var r=x[t.astr][e];t.get()[e]=r}):(g=function(t){x[t.astr]=n.extendDeep([],t.get()),t.set([])},v=function(t,e){var r=x[t.astr][e];t.get().push(r)}),k(g);for(var w=o(e.transforms,r),T=0;T<f;T++){y(i[T])?(k(v,T),b[_++]=w(T)):d&&_++}r._indexToPoints=b,e._length=_}}function k(t,r){for(var i=0;i<p.length;i++){t(n.nestedProperty(e,p[i]),r)}}}},{\"../constants/filter_ops\":771,\"../lib\":799,\"../plots/cartesian/axes\":849,\"../registry\":927,\"./helpers\":1398}],1397:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"../plot_api/plot_schema\"),a=t(\"../plots/plots\"),o=t(\"./helpers\").pointsAccessorFunction;function s(t,e){var r,s,l,c,u,f,h,p,d,m,g=e.transform,v=e.transformIndex,y=t.transforms[v].groups,x=o(t.transforms,g);if(!n.isArrayOrTypedArray(y)||0===y.length)return[t];var b=n.filterUnique(y),_=new Array(b.length),w=y.length,T=i.findArrayAttributes(t),k=g.styles||[],M={};for(r=0;r<k.length;r++)M[k[r].target]=k[r].value;g.styles&&(m=n.keyedContainer(g,\"styles\",\"target\",\"value.name\"));var A={},S={};for(r=0;r<b.length;r++){A[f=b[r]]=r,S[f]=0,(h=_[r]=n.extendDeepNoArrays({},t))._group=f,h.transforms[v]._indexToPoints={};var E=null;for(m&&(E=m.get(f)),h.name=E||\"\"===E?E:n.templateString(g.nameformat,{trace:t.name,group:f}),p=h.transforms,h.transforms=[],s=0;s<p.length;s++)h.transforms[s]=n.extendDeepNoArrays({},p[s]);for(s=0;s<T.length;s++)n.nestedProperty(h,T[s]).set([])}for(l=0;l<T.length;l++){for(c=T[l],s=0,d=[];s<b.length;s++)d[s]=n.nestedProperty(_[s],c).get();for(u=n.nestedProperty(t,c).get(),s=0;s<w;s++)d[A[y[s]]].push(u[s])}for(s=0;s<w;s++){(h=_[A[y[s]]]).transforms[v]._indexToPoints[S[y[s]]]=x(s),S[y[s]]++}for(r=0;r<b.length;r++)f=b[r],h=_[r],a.clearExpandedTraceDefaultColors(h),h=n.extendDeepNoArrays(h,M[f]||{});return _}r.moduleType=\"transform\",r.name=\"groupby\",r.attributes={enabled:{valType:\"boolean\",dflt:!0,editType:\"calc\"},groups:{valType:\"data_array\",dflt:[],editType:\"calc\"},nameformat:{valType:\"string\",editType:\"calc\"},styles:{_isLinkedToArray:\"style\",target:{valType:\"string\",editType:\"calc\"},value:{valType:\"any\",dflt:{},editType:\"calc\",_compareAsJSON:!0},editType:\"calc\"},editType:\"calc\"},r.supplyDefaults=function(t,e,i){var a,o={};function s(e,i){return n.coerce(t,o,r.attributes,e,i)}if(!s(\"enabled\"))return o;s(\"groups\"),s(\"nameformat\",i._dataLength>1?\"%{group} (%{trace})\":\"%{group}\");var l=t.styles,c=o.styles=[];if(l)for(a=0;a<l.length;a++){var u=c[a]={};n.coerce(l[a],c[a],r.attributes.styles,\"target\");var f=n.coerce(l[a],c[a],r.attributes.styles,\"value\");n.isPlainObject(f)?u.value=n.extendDeep({},f):f&&delete u.value}return o},r.transform=function(t,e){var r,n,i,a=[];for(n=0;n<t.length;n++)for(r=s(t[n],e),i=0;i<r.length;i++)a.push(r[i]);return a}},{\"../lib\":799,\"../plot_api/plot_schema\":837,\"../plots/plots\":913,\"./helpers\":1398}],1398:[function(t,e,r){\"use strict\";r.pointsAccessorFunction=function(t,e){for(var r,n,i=0;i<t.length&&(r=t[i])!==e;i++)r._indexToPoints&&!1!==r.enabled&&(n=r._indexToPoints);return n?function(t){return n[t]}:function(t){return[t]}}},{}],1399:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"../plots/cartesian/axes\"),a=t(\"./helpers\").pointsAccessorFunction,o=t(\"../constants/numerical\").BADNUM;r.moduleType=\"transform\",r.name=\"sort\",r.attributes={enabled:{valType:\"boolean\",dflt:!0,editType:\"calc\"},target:{valType:\"string\",strict:!0,noBlank:!0,arrayOk:!0,dflt:\"x\",editType:\"calc\"},order:{valType:\"enumerated\",values:[\"ascending\",\"descending\"],dflt:\"ascending\",editType:\"calc\"},editType:\"calc\"},r.supplyDefaults=function(t){var e={};function i(i,a){return n.coerce(t,e,r.attributes,i,a)}return i(\"enabled\")&&(i(\"target\"),i(\"order\")),e},r.calcTransform=function(t,e,r){if(r.enabled){var s=n.getTargetArray(e,r);if(s){var l=r.target,c=s.length;e._length&&(c=Math.min(c,e._length));var u,f,h=e._arrayAttrs,p=function(t,e,r,n){var i,a=new Array(n),s=new Array(n);for(i=0;i<n;i++)a[i]={v:e[i],i:i};for(a.sort(function(t,e){switch(t.order){case\"ascending\":return function(t,r){var n=e(t.v),i=e(r.v);return n===o?1:i===o?-1:n-i};case\"descending\":return function(t,r){var n=e(t.v),i=e(r.v);return n===o?1:i===o?-1:i-n}}}(t,r)),i=0;i<n;i++)s[i]=a[i].i;return s}(r,s,i.getDataToCoordFunc(t,e,l,s),c),d=a(e.transforms,r),m={};for(u=0;u<h.length;u++){var g=n.nestedProperty(e,h[u]),v=g.get(),y=new Array(c);for(f=0;f<c;f++)y[f]=v[p[f]];g.set(y)}for(f=0;f<c;f++)m[f]=d(p[f]);r._indexToPoints=m,e._length=c}}}},{\"../constants/numerical\":775,\"../lib\":799,\"../plots/cartesian/axes\":849,\"./helpers\":1398}],1400:[function(t,e,r){\"use strict\";r.version=\"2.2.0\"},{}]},{},[27])(27)}));\n",
       "        });\n",
       "        require(['plotly'], function(Plotly) {\n",
       "            window._Plotly = Plotly;\n",
       "        });\n",
       "        }\n",
       "        </script>\n",
       "        "
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/vnd.plotly.v1+json": {
       "config": {
        "plotlyServerURL": "https://plot.ly"
       },
       "data": [
        {
         "hovertemplate": "M=0.2<br>Alpha=%{x}<br>Cl=%{y}<extra></extra>",
         "legendgroup": "0.2",
         "line": {
          "color": "#f0f921",
          "dash": "solid"
         },
         "mode": "lines",
         "name": "0.2",
         "orientation": "v",
         "showlegend": true,
         "textposition": "top center",
         "type": "scatter",
         "x": [
          -6,
          -5.76767677,
          -5.53535354,
          -5.3030303,
          -5.07070707,
          -4.83838384,
          -4.60606061,
          -4.37373737,
          -4.14141414,
          -3.90909091,
          -3.67676768,
          -3.44444444,
          -3.21212121,
          -2.97979798,
          -2.74747475,
          -2.51515152,
          -2.28282828,
          -2.05050505,
          -1.81818182,
          -1.58585859,
          -1.35353535,
          -1.12121212,
          -0.88888889,
          -0.65656566,
          -0.42424242,
          -0.19191919,
          0.04040404,
          0.27272727,
          0.50505051,
          0.73737374,
          0.96969697,
          1.2020202,
          1.43434343,
          1.66666667,
          1.8989899,
          2.13131313,
          2.36363636,
          2.5959596,
          2.82828283,
          3.06060606,
          3.29292929,
          3.52525253,
          3.75757576,
          3.98989899,
          4.22222222,
          4.45454545,
          4.68686869,
          4.91919192,
          5.15151515,
          5.38383838,
          5.61616162,
          5.84848485,
          6.08080808,
          6.31313131,
          6.54545455,
          6.77777778,
          7.01010101,
          7.24242424,
          7.47474747,
          7.70707071,
          7.93939394,
          8.17171717,
          8.4040404,
          8.63636364,
          8.86868687,
          9.1010101,
          9.33333333,
          9.56565657,
          9.7979798,
          10.03030303,
          10.26262626,
          10.49494949,
          10.72727273,
          10.95959596,
          11.19191919,
          11.42424242,
          11.65656566,
          11.88888889,
          12.12121212,
          12.35353535,
          12.58585859,
          12.81818182,
          13.05050505,
          13.28282828,
          13.51515152,
          13.74747475,
          13.97979798,
          14.21212121,
          14.44444444,
          14.67676768,
          14.90909091,
          15.14141414,
          15.37373737,
          15.60606061,
          15.83838384,
          16.07070707,
          16.3030303,
          16.53535354,
          16.76767677,
          17
         ],
         "xaxis": "x",
         "y": [
          -0.53228324,
          -0.50718964,
          -0.48195101,
          -0.45660799,
          -0.43120119,
          -0.40576803,
          -0.38031204,
          -0.35481676,
          -0.32926958,
          -0.30366183,
          -0.27799741,
          -0.2522964,
          -0.22653591,
          -0.20060492,
          -0.17445074,
          -0.14823331,
          -0.12212297,
          -0.09614174,
          -0.07026656,
          -0.04447435,
          -0.01874205,
          0.0069534,
          0.03263436,
          0.05830475,
          0.08394898,
          0.10955055,
          0.13509298,
          0.16057669,
          0.18604255,
          0.21153739,
          0.23710805,
          0.26279145,
          0.28856551,
          0.31438649,
          0.34021063,
          0.3659956,
          0.39172412,
          0.41740002,
          0.44302781,
          0.46861199,
          0.49415792,
          0.51967255,
          0.54516302,
          0.57063647,
          0.59609242,
          0.62149578,
          0.64680161,
          0.67196494,
          0.69694806,
          0.72180186,
          0.74663668,
          0.77156394,
          0.79668942,
          0.82181231,
          0.84647682,
          0.87085644,
          0.89513278,
          0.91937402,
          0.94348977,
          0.96739494,
          0.9911269,
          1.0148129,
          1.03836582,
          1.06169198,
          1.08482576,
          1.10780834,
          1.130642,
          1.15328983,
          1.17572899,
          1.19792788,
          1.21987775,
          1.24163348,
          1.26319091,
          1.28450409,
          1.30552967,
          1.32632225,
          1.34695995,
          1.36732392,
          1.3871706,
          1.40625753,
          1.42479816,
          1.44360507,
          1.46199796,
          1.47943116,
          1.49655565,
          1.51357538,
          1.5300637,
          1.5454421,
          1.55996393,
          1.57396867,
          1.58737427,
          1.59957767,
          1.60896095,
          1.61529641,
          1.62087053,
          1.62480481,
          1.62577474,
          1.62294933,
          1.61513429,
          1.60103413
         ],
         "yaxis": "y"
        },
        {
         "hovertemplate": "M=0.3<br>Alpha=%{x}<br>Cl=%{y}<extra></extra>",
         "legendgroup": "0.3",
         "line": {
          "color": "#fdca26",
          "dash": "solid"
         },
         "mode": "lines",
         "name": "0.3",
         "orientation": "v",
         "showlegend": true,
         "textposition": "top center",
         "type": "scatter",
         "x": [
          -6,
          -5.76767677,
          -5.53535354,
          -5.3030303,
          -5.07070707,
          -4.83838384,
          -4.60606061,
          -4.37373737,
          -4.14141414,
          -3.90909091,
          -3.67676768,
          -3.44444444,
          -3.21212121,
          -2.97979798,
          -2.74747475,
          -2.51515152,
          -2.28282828,
          -2.05050505,
          -1.81818182,
          -1.58585859,
          -1.35353535,
          -1.12121212,
          -0.88888889,
          -0.65656566,
          -0.42424242,
          -0.19191919,
          0.04040404,
          0.27272727,
          0.50505051,
          0.73737374,
          0.96969697,
          1.2020202,
          1.43434343,
          1.66666667,
          1.8989899,
          2.13131313,
          2.36363636,
          2.5959596,
          2.82828283,
          3.06060606,
          3.29292929,
          3.52525253,
          3.75757576,
          3.98989899,
          4.22222222,
          4.45454545,
          4.68686869,
          4.91919192,
          5.15151515,
          5.38383838,
          5.61616162,
          5.84848485,
          6.08080808,
          6.31313131,
          6.54545455,
          6.77777778,
          7.01010101,
          7.24242424,
          7.47474747,
          7.70707071,
          7.93939394,
          8.17171717,
          8.4040404,
          8.63636364,
          8.86868687,
          9.1010101,
          9.33333333,
          9.56565657,
          9.7979798,
          10.03030303,
          10.26262626,
          10.49494949,
          10.72727273,
          10.95959596,
          11.19191919,
          11.42424242,
          11.65656566,
          11.88888889,
          12.12121212,
          12.35353535,
          12.58585859,
          12.81818182,
          13.05050505,
          13.28282828,
          13.51515152,
          13.74747475,
          13.97979798,
          14.21212121,
          14.44444444,
          14.67676768,
          14.90909091,
          15.14141414,
          15.37373737,
          15.60606061,
          15.83838384,
          16.07070707,
          16.3030303,
          16.53535354,
          16.76767677,
          17
         ],
         "xaxis": "x",
         "y": [
          -0.54949398,
          -0.5236046,
          -0.49757824,
          -0.47145689,
          -0.44528256,
          -0.41909013,
          -0.39284002,
          -0.36645404,
          -0.33996472,
          -0.3135014,
          -0.2870942,
          -0.26063718,
          -0.23408515,
          -0.20753333,
          -0.18104614,
          -0.15454143,
          -0.12792844,
          -0.1012119,
          -0.07442552,
          -0.04760302,
          -0.02077814,
          0.0060154,
          0.03274484,
          0.0594021,
          0.0860052,
          0.11257344,
          0.13912609,
          0.1656794,
          0.19224242,
          0.21882311,
          0.24542945,
          0.27206643,
          0.29872142,
          0.32537529,
          0.3520089,
          0.37860374,
          0.40515223,
          0.43165601,
          0.458117,
          0.4845371,
          0.51091694,
          0.53725478,
          0.56354858,
          0.58979632,
          0.61599383,
          0.64212716,
          0.66817956,
          0.6941343,
          0.71997721,
          0.74572579,
          0.77141872,
          0.79709511,
          0.82279191,
          0.84843072,
          0.87382464,
          0.8989963,
          0.9240866,
          0.94919239,
          0.97414866,
          0.99889652,
          1.02348188,
          1.04796291,
          1.07231066,
          1.09645955,
          1.12039571,
          1.14420409,
          1.16787199,
          1.19129343,
          1.21446468,
          1.23740989,
          1.2601462,
          1.28265375,
          1.30486505,
          1.32676353,
          1.34838683,
          1.36972657,
          1.39075254,
          1.41141388,
          1.43164672,
          1.45138766,
          1.47067357,
          1.48965574,
          1.50807416,
          1.52575172,
          1.54289758,
          1.55942708,
          1.57503623,
          1.58940521,
          1.60253004,
          1.61436897,
          1.62458482,
          1.63253939,
          1.63761248,
          1.63934198,
          1.63734987,
          1.63083055,
          1.61894855,
          1.60080908,
          1.57482718,
          1.53924913
         ],
         "yaxis": "y"
        },
        {
         "hovertemplate": "M=0.4<br>Alpha=%{x}<br>Cl=%{y}<extra></extra>",
         "legendgroup": "0.4",
         "line": {
          "color": "#fb9f3a",
          "dash": "solid"
         },
         "mode": "lines",
         "name": "0.4",
         "orientation": "v",
         "showlegend": true,
         "textposition": "top center",
         "type": "scatter",
         "x": [
          -6,
          -5.76767677,
          -5.53535354,
          -5.3030303,
          -5.07070707,
          -4.83838384,
          -4.60606061,
          -4.37373737,
          -4.14141414,
          -3.90909091,
          -3.67676768,
          -3.44444444,
          -3.21212121,
          -2.97979798,
          -2.74747475,
          -2.51515152,
          -2.28282828,
          -2.05050505,
          -1.81818182,
          -1.58585859,
          -1.35353535,
          -1.12121212,
          -0.88888889,
          -0.65656566,
          -0.42424242,
          -0.19191919,
          0.04040404,
          0.27272727,
          0.50505051,
          0.73737374,
          0.96969697,
          1.2020202,
          1.43434343,
          1.66666667,
          1.8989899,
          2.13131313,
          2.36363636,
          2.5959596,
          2.82828283,
          3.06060606,
          3.29292929,
          3.52525253,
          3.75757576,
          3.98989899,
          4.22222222,
          4.45454545,
          4.68686869,
          4.91919192,
          5.15151515,
          5.38383838,
          5.61616162,
          5.84848485,
          6.08080808,
          6.31313131,
          6.54545455,
          6.77777778,
          7.01010101,
          7.24242424,
          7.47474747,
          7.70707071,
          7.93939394,
          8.17171717,
          8.4040404,
          8.63636364,
          8.86868687,
          9.1010101,
          9.33333333,
          9.56565657,
          9.7979798,
          10.03030303,
          10.26262626,
          10.49494949,
          10.72727273,
          10.95959596,
          11.19191919,
          11.42424242,
          11.65656566,
          11.88888889,
          12.12121212,
          12.35353535,
          12.58585859,
          12.81818182,
          13.05050505,
          13.28282828,
          13.51515152,
          13.74747475,
          13.97979798,
          14.21212121,
          14.44444444,
          14.67676768,
          14.90909091,
          15.14141414,
          15.37373737,
          15.60606061,
          15.83838384,
          16.07070707,
          16.3030303,
          16.53535354,
          16.76767677,
          17
         ],
         "xaxis": "x",
         "y": [
          -0.57438145,
          -0.54735084,
          -0.52020789,
          -0.49296479,
          -0.46563373,
          -0.43822654,
          -0.41075118,
          -0.3832134,
          -0.35562056,
          -0.32798138,
          -0.30029716,
          -0.27255951,
          -0.24478207,
          -0.2170239,
          -0.18931741,
          -0.16159605,
          -0.13378916,
          -0.10589883,
          -0.07794924,
          -0.04996457,
          -0.02196899,
          0.0060133,
          0.03395877,
          0.06186061,
          0.08972963,
          0.11757753,
          0.14541599,
          0.17325411,
          0.20109487,
          0.22894031,
          0.25679248,
          0.28465202,
          0.312511,
          0.3403584,
          0.36818316,
          0.39597458,
          0.42372762,
          0.45144208,
          0.47911787,
          0.50675493,
          0.53435186,
          0.56190482,
          0.58940969,
          0.61686235,
          0.64425883,
          0.67159577,
          0.69886997,
          0.72607828,
          0.75321725,
          0.7802805,
          0.80725965,
          0.83414628,
          0.86093217,
          0.88761952,
          0.91421151,
          0.94067323,
          0.96704023,
          0.99335133,
          1.01952369,
          1.04550619,
          1.07132642,
          1.09705174,
          1.12262195,
          1.14795714,
          1.17306592,
          1.19803623,
          1.22285062,
          1.24738903,
          1.27163161,
          1.29564366,
          1.31944963,
          1.34290603,
          1.36592873,
          1.38820392,
          1.40916159,
          1.42811212,
          1.44435644,
          1.45761343,
          1.46786655,
          1.47510391,
          1.47938053,
          1.48083297,
          1.47934846,
          1.47500414,
          1.46817606,
          1.45808435,
          1.44542869,
          1.43149019,
          1.413954,
          1.39357078,
          1.3719248,
          1.34726237,
          1.32124431,
          1.29516724,
          1.26664033,
          1.23808438,
          1.21162015,
          1.18707021,
          1.165009,
          1.14625038
         ],
         "yaxis": "y"
        },
        {
         "hovertemplate": "M=0.5<br>Alpha=%{x}<br>Cl=%{y}<extra></extra>",
         "legendgroup": "0.5",
         "line": {
          "color": "#ed7953",
          "dash": "solid"
         },
         "mode": "lines",
         "name": "0.5",
         "orientation": "v",
         "showlegend": true,
         "textposition": "top center",
         "type": "scatter",
         "x": [
          -5.5,
          -5.3030303,
          -5.10606061,
          -4.90909091,
          -4.71212121,
          -4.51515152,
          -4.31818182,
          -4.12121212,
          -3.92424242,
          -3.72727273,
          -3.53030303,
          -3.33333333,
          -3.13636364,
          -2.93939394,
          -2.74242424,
          -2.54545455,
          -2.34848485,
          -2.15151515,
          -1.95454545,
          -1.75757576,
          -1.56060606,
          -1.36363636,
          -1.16666667,
          -0.96969697,
          -0.77272727,
          -0.57575758,
          -0.37878788,
          -0.18181818,
          0.01515152,
          0.21212121,
          0.40909091,
          0.60606061,
          0.8030303,
          1,
          1.1969697,
          1.39393939,
          1.59090909,
          1.78787879,
          1.98484848,
          2.18181818,
          2.37878788,
          2.57575758,
          2.77272727,
          2.96969697,
          3.16666667,
          3.36363636,
          3.56060606,
          3.75757576,
          3.95454545,
          4.15151515,
          4.34848485,
          4.54545455,
          4.74242424,
          4.93939394,
          5.13636364,
          5.33333333,
          5.53030303,
          5.72727273,
          5.92424242,
          6.12121212,
          6.31818182,
          6.51515152,
          6.71212121,
          6.90909091,
          7.10606061,
          7.3030303,
          7.5,
          7.6969697,
          7.89393939,
          8.09090909,
          8.28787879,
          8.48484848,
          8.68181818,
          8.87878788,
          9.07575758,
          9.27272727,
          9.46969697,
          9.66666667,
          9.86363636,
          10.06060606,
          10.25757576,
          10.45454545,
          10.65151515,
          10.84848485,
          11.04545455,
          11.24242424,
          11.43939394,
          11.63636364,
          11.83333333,
          12.03030303,
          12.22727273,
          12.42424242,
          12.62121212,
          12.81818182,
          13.01515152,
          13.21212121,
          13.40909091,
          13.60606061,
          13.8030303,
          14
         ],
         "xaxis": "x",
         "y": [
          -0.52116637,
          -0.5053465,
          -0.4876147,
          -0.46812634,
          -0.44703678,
          -0.42450138,
          -0.40071908,
          -0.37610845,
          -0.35115258,
          -0.32613945,
          -0.30109306,
          -0.27601853,
          -0.25092008,
          -0.22580153,
          -0.20066605,
          -0.17551573,
          -0.15035255,
          -0.12517849,
          -0.09999554,
          -0.07480725,
          -0.04962032,
          -0.02444111,
          0.00073208,
          0.02590581,
          0.05108437,
          0.07626622,
          0.10144889,
          0.12662991,
          0.1518068,
          0.17697803,
          0.202145,
          0.22730969,
          0.2524741,
          0.2776402,
          0.30280895,
          0.32797715,
          0.35314053,
          0.37829486,
          0.40343589,
          0.42855997,
          0.45366653,
          0.47875594,
          0.50382858,
          0.52888483,
          0.55392472,
          0.57894598,
          0.60394545,
          0.62891999,
          0.65386642,
          0.67878203,
          0.7036678,
          0.72852645,
          0.75336076,
          0.77817349,
          0.8029662,
          0.8277278,
          0.85243958,
          0.8770827,
          0.90163835,
          0.92609114,
          0.95047424,
          0.97475035,
          0.99856461,
          1.02158181,
          1.04353936,
          1.0642775,
          1.08373362,
          1.10187824,
          1.11884838,
          1.13492179,
          1.14973324,
          1.16249617,
          1.17379424,
          1.18370929,
          1.19117799,
          1.19583986,
          1.19830109,
          1.19873925,
          1.19727929,
          1.19425211,
          1.18970857,
          1.18327383,
          1.17506077,
          1.16549512,
          1.15512225,
          1.14441115,
          1.1336475,
          1.12307549,
          1.1127375,
          1.10255435,
          1.09244519,
          1.08235948,
          1.07264912,
          1.06370838,
          1.05523056,
          1.04698518,
          1.03937203,
          1.03259282,
          1.02656534,
          1.02119797
         ],
         "yaxis": "y"
        },
        {
         "hovertemplate": "M=0.6<br>Alpha=%{x}<br>Cl=%{y}<extra></extra>",
         "legendgroup": "0.6",
         "line": {
          "color": "#d8576b",
          "dash": "solid"
         },
         "mode": "lines",
         "name": "0.6",
         "orientation": "v",
         "showlegend": true,
         "textposition": "top center",
         "type": "scatter",
         "x": [
          -6,
          -5.86262626,
          -5.72525253,
          -5.58787879,
          -5.45050505,
          -5.31313131,
          -5.17575758,
          -5.03838384,
          -4.9010101,
          -4.76363636,
          -4.62626263,
          -4.48888889,
          -4.35151515,
          -4.21414141,
          -4.07676768,
          -3.93939394,
          -3.8020202,
          -3.66464646,
          -3.52727273,
          -3.38989899,
          -3.25252525,
          -3.11515152,
          -2.97777778,
          -2.84040404,
          -2.7030303,
          -2.56565657,
          -2.42828283,
          -2.29090909,
          -2.15353535,
          -2.01616162,
          -1.87878788,
          -1.74141414,
          -1.6040404,
          -1.46666667,
          -1.32929293,
          -1.19191919,
          -1.05454545,
          -0.91717172,
          -0.77979798,
          -0.64242424,
          -0.50505051,
          -0.36767677,
          -0.23030303,
          -0.09292929,
          0.04444444,
          0.18181818,
          0.31919192,
          0.45656566,
          0.59393939,
          0.73131313,
          0.86868687,
          1.00606061,
          1.14343434,
          1.28080808,
          1.41818182,
          1.55555556,
          1.69292929,
          1.83030303,
          1.96767677,
          2.10505051,
          2.24242424,
          2.37979798,
          2.51717172,
          2.65454545,
          2.79191919,
          2.92929293,
          3.06666667,
          3.2040404,
          3.34141414,
          3.47878788,
          3.61616162,
          3.75353535,
          3.89090909,
          4.02828283,
          4.16565657,
          4.3030303,
          4.44040404,
          4.57777778,
          4.71515152,
          4.85252525,
          4.98989899,
          5.12727273,
          5.26464646,
          5.4020202,
          5.53939394,
          5.67676768,
          5.81414141,
          5.95151515,
          6.08888889,
          6.22626263,
          6.36363636,
          6.5010101,
          6.63838384,
          6.77575758,
          6.91313131,
          7.05050505,
          7.18787879,
          7.32525253,
          7.46262626,
          7.6
         ],
         "xaxis": "x",
         "y": [
          -0.51781498,
          -0.5143375,
          -0.50971647,
          -0.50399277,
          -0.49720726,
          -0.48940083,
          -0.48061435,
          -0.47088868,
          -0.46026384,
          -0.44877132,
          -0.43643792,
          -0.42329039,
          -0.40938284,
          -0.39485539,
          -0.37986503,
          -0.36456672,
          -0.3490524,
          -0.3333406,
          -0.31744569,
          -0.30136706,
          -0.28499392,
          -0.26816629,
          -0.25072421,
          -0.23259658,
          -0.2139332,
          -0.1949176,
          -0.17572959,
          -0.15647162,
          -0.13717309,
          -0.11786054,
          -0.09855718,
          -0.07926708,
          -0.05998753,
          -0.04071583,
          -0.02144913,
          -0.00218426,
          0.01708196,
          0.0363526,
          0.05562868,
          0.07490972,
          0.09419518,
          0.11348453,
          0.13277724,
          0.15207277,
          0.17137061,
          0.19067115,
          0.20997627,
          0.22928796,
          0.24860822,
          0.26793906,
          0.28728246,
          0.30664043,
          0.32601425,
          0.34540263,
          0.36480375,
          0.38421579,
          0.40363691,
          0.42306528,
          0.44249908,
          0.46193329,
          0.48133647,
          0.50066412,
          0.51987164,
          0.53891445,
          0.55774794,
          0.57632752,
          0.59460958,
          0.61257472,
          0.6302287,
          0.64757846,
          0.66463094,
          0.68139306,
          0.69787177,
          0.71407385,
          0.72997834,
          0.74550335,
          0.76055889,
          0.77505498,
          0.78890164,
          0.80200888,
          0.81428673,
          0.82564812,
          0.83602063,
          0.84533638,
          0.85352749,
          0.86052608,
          0.86626427,
          0.87067418,
          0.87369464,
          0.8753481,
          0.87571371,
          0.87486566,
          0.8728719,
          0.86983395,
          0.865914,
          0.86128071,
          0.85610886,
          0.85058181,
          0.84488363,
          0.83919834
         ],
         "yaxis": "y"
        },
        {
         "hovertemplate": "M=0.7<br>Alpha=%{x}<br>Cl=%{y}<extra></extra>",
         "legendgroup": "0.7",
         "line": {
          "color": "#bd3786",
          "dash": "solid"
         },
         "mode": "lines",
         "name": "0.7",
         "orientation": "v",
         "showlegend": true,
         "textposition": "top center",
         "type": "scatter",
         "x": [
          -6,
          -5.86868687,
          -5.73737374,
          -5.60606061,
          -5.47474747,
          -5.34343434,
          -5.21212121,
          -5.08080808,
          -4.94949495,
          -4.81818182,
          -4.68686869,
          -4.55555556,
          -4.42424242,
          -4.29292929,
          -4.16161616,
          -4.03030303,
          -3.8989899,
          -3.76767677,
          -3.63636364,
          -3.50505051,
          -3.37373737,
          -3.24242424,
          -3.11111111,
          -2.97979798,
          -2.84848485,
          -2.71717172,
          -2.58585859,
          -2.45454545,
          -2.32323232,
          -2.19191919,
          -2.06060606,
          -1.92929293,
          -1.7979798,
          -1.66666667,
          -1.53535354,
          -1.4040404,
          -1.27272727,
          -1.14141414,
          -1.01010101,
          -0.87878788,
          -0.74747475,
          -0.61616162,
          -0.48484848,
          -0.35353535,
          -0.22222222,
          -0.09090909,
          0.04040404,
          0.17171717,
          0.3030303,
          0.43434343,
          0.56565657,
          0.6969697,
          0.82828283,
          0.95959596,
          1.09090909,
          1.22222222,
          1.35353535,
          1.48484848,
          1.61616162,
          1.74747475,
          1.87878788,
          2.01010101,
          2.14141414,
          2.27272727,
          2.4040404,
          2.53535354,
          2.66666667,
          2.7979798,
          2.92929293,
          3.06060606,
          3.19191919,
          3.32323232,
          3.45454545,
          3.58585859,
          3.71717172,
          3.84848485,
          3.97979798,
          4.11111111,
          4.24242424,
          4.37373737,
          4.50505051,
          4.63636364,
          4.76767677,
          4.8989899,
          5.03030303,
          5.16161616,
          5.29292929,
          5.42424242,
          5.55555556,
          5.68686869,
          5.81818182,
          5.94949495,
          6.08080808,
          6.21212121,
          6.34343434,
          6.47474747,
          6.60606061,
          6.73737374,
          6.86868687,
          7
         ],
         "xaxis": "x",
         "y": [
          -0.67305743,
          -0.67165615,
          -0.66781238,
          -0.6617087,
          -0.65352768,
          -0.64345186,
          -0.63166383,
          -0.61834615,
          -0.60368038,
          -0.58780555,
          -0.57080312,
          -0.55275048,
          -0.53372423,
          -0.51378845,
          -0.49299691,
          -0.47140312,
          -0.44906808,
          -0.42611421,
          -0.40269388,
          -0.37895972,
          -0.3550803,
          -0.33129605,
          -0.30786752,
          -0.28505499,
          -0.26300741,
          -0.24159054,
          -0.2206258,
          -0.19993537,
          -0.17938138,
          -0.15888581,
          -0.13837557,
          -0.11777965,
          -0.09706693,
          -0.07624239,
          -0.05531234,
          -0.03428305,
          -0.01316083,
          0.00804805,
          0.02933728,
          0.05069917,
          0.07211889,
          0.09357939,
          0.11506359,
          0.13655445,
          0.15803488,
          0.17948784,
          0.20089625,
          0.22224251,
          0.24350816,
          0.26467465,
          0.28572341,
          0.30663589,
          0.32739356,
          0.34797784,
          0.36836799,
          0.38851996,
          0.40837567,
          0.42787683,
          0.44696516,
          0.46558239,
          0.48367024,
          0.50117042,
          0.51800357,
          0.53402334,
          0.54907008,
          0.56298414,
          0.57560588,
          0.58677565,
          0.59633381,
          0.60412572,
          0.61013597,
          0.61450307,
          0.61737348,
          0.61889368,
          0.61921013,
          0.6184693,
          0.61681767,
          0.61440354,
          0.6113871,
          0.60793318,
          0.60420661,
          0.60037224,
          0.59659492,
          0.59303947,
          0.58987036,
          0.58719683,
          0.58501497,
          0.58330701,
          0.5820552,
          0.58124178,
          0.58084899,
          0.58085907,
          0.58125252,
          0.58198542,
          0.58299619,
          0.58424999,
          0.58575434,
          0.58752041,
          0.58955939,
          0.59188248
         ],
         "yaxis": "y"
        },
        {
         "hovertemplate": "M=0.75<br>Alpha=%{x}<br>Cl=%{y}<extra></extra>",
         "legendgroup": "0.75",
         "line": {
          "color": "#9c179e",
          "dash": "solid"
         },
         "mode": "lines",
         "name": "0.75",
         "orientation": "v",
         "showlegend": true,
         "textposition": "top center",
         "type": "scatter",
         "x": [
          -6,
          -5.87272727,
          -5.74545455,
          -5.61818182,
          -5.49090909,
          -5.36363636,
          -5.23636364,
          -5.10909091,
          -4.98181818,
          -4.85454545,
          -4.72727273,
          -4.6,
          -4.47272727,
          -4.34545455,
          -4.21818182,
          -4.09090909,
          -3.96363636,
          -3.83636364,
          -3.70909091,
          -3.58181818,
          -3.45454545,
          -3.32727273,
          -3.2,
          -3.07272727,
          -2.94545455,
          -2.81818182,
          -2.69090909,
          -2.56363636,
          -2.43636364,
          -2.30909091,
          -2.18181818,
          -2.05454545,
          -1.92727273,
          -1.8,
          -1.67272727,
          -1.54545455,
          -1.41818182,
          -1.29090909,
          -1.16363636,
          -1.03636364,
          -0.90909091,
          -0.78181818,
          -0.65454545,
          -0.52727273,
          -0.4,
          -0.27272727,
          -0.14545455,
          -0.01818182,
          0.10909091,
          0.23636364,
          0.36363636,
          0.49090909,
          0.61818182,
          0.74545455,
          0.87272727,
          1,
          1.12727273,
          1.25454545,
          1.38181818,
          1.50909091,
          1.63636364,
          1.76363636,
          1.89090909,
          2.01818182,
          2.14545455,
          2.27272727,
          2.4,
          2.52727273,
          2.65454545,
          2.78181818,
          2.90909091,
          3.03636364,
          3.16363636,
          3.29090909,
          3.41818182,
          3.54545455,
          3.67272727,
          3.8,
          3.92727273,
          4.05454545,
          4.18181818,
          4.30909091,
          4.43636364,
          4.56363636,
          4.69090909,
          4.81818182,
          4.94545455,
          5.07272727,
          5.2,
          5.32727273,
          5.45454545,
          5.58181818,
          5.70909091,
          5.83636364,
          5.96363636,
          6.09090909,
          6.21818182,
          6.34545455,
          6.47272727,
          6.6
         ],
         "xaxis": "x",
         "y": [
          -0.5537476,
          -0.55598676,
          -0.55833145,
          -0.5606603,
          -0.56285197,
          -0.56478511,
          -0.56633838,
          -0.56739042,
          -0.56781969,
          -0.5674128,
          -0.56571524,
          -0.56223342,
          -0.55647496,
          -0.54815922,
          -0.53745945,
          -0.52460759,
          -0.50983515,
          -0.49333876,
          -0.47525355,
          -0.45570841,
          -0.4348329,
          -0.41279174,
          -0.3898008,
          -0.36607996,
          -0.34184485,
          -0.31717079,
          -0.29196397,
          -0.2661205,
          -0.23954852,
          -0.21243244,
          -0.18523296,
          -0.15842281,
          -0.13245453,
          -0.10744204,
          -0.08321824,
          -0.05960757,
          -0.03643442,
          -0.01352321,
          0.00930164,
          0.03221573,
          0.05537884,
          0.0787956,
          0.10238258,
          0.12605532,
          0.14972936,
          0.17332026,
          0.19674357,
          0.21991483,
          0.24274663,
          0.26513335,
          0.28696239,
          0.30812115,
          0.32849705,
          0.34797748,
          0.36644984,
          0.38380153,
          0.39992447,
          0.41472856,
          0.42812824,
          0.44003792,
          0.45037204,
          0.459045,
          0.46597124,
          0.47106541,
          0.4743594,
          0.47619275,
          0.47695484,
          0.47703461,
          0.47673912,
          0.47619998,
          0.4755261,
          0.47482614,
          0.47418549,
          0.47364852,
          0.47325545,
          0.47304613,
          0.47304166,
          0.47323596,
          0.47362078,
          0.474188,
          0.4749335,
          0.47585799,
          0.47696245,
          0.47824777,
          0.47971184,
          0.48134963,
          0.48315594,
          0.48512571,
          0.48725572,
          0.48954425,
          0.49198966,
          0.4945912,
          0.49735976,
          0.50031424,
          0.5034737,
          0.50685522,
          0.51045659,
          0.51426465,
          0.51826611,
          0.52244767
         ],
         "yaxis": "y"
        },
        {
         "hovertemplate": "M=0.8<br>Alpha=%{x}<br>Cl=%{y}<extra></extra>",
         "legendgroup": "0.8",
         "line": {
          "color": "#7201a8",
          "dash": "solid"
         },
         "mode": "lines",
         "name": "0.8",
         "orientation": "v",
         "showlegend": true,
         "textposition": "top center",
         "type": "scatter",
         "x": [
          -6,
          -5.86868687,
          -5.73737374,
          -5.60606061,
          -5.47474747,
          -5.34343434,
          -5.21212121,
          -5.08080808,
          -4.94949495,
          -4.81818182,
          -4.68686869,
          -4.55555556,
          -4.42424242,
          -4.29292929,
          -4.16161616,
          -4.03030303,
          -3.8989899,
          -3.76767677,
          -3.63636364,
          -3.50505051,
          -3.37373737,
          -3.24242424,
          -3.11111111,
          -2.97979798,
          -2.84848485,
          -2.71717172,
          -2.58585859,
          -2.45454545,
          -2.32323232,
          -2.19191919,
          -2.06060606,
          -1.92929293,
          -1.7979798,
          -1.66666667,
          -1.53535354,
          -1.4040404,
          -1.27272727,
          -1.14141414,
          -1.01010101,
          -0.87878788,
          -0.74747475,
          -0.61616162,
          -0.48484848,
          -0.35353535,
          -0.22222222,
          -0.09090909,
          0.04040404,
          0.17171717,
          0.3030303,
          0.43434343,
          0.56565657,
          0.6969697,
          0.82828283,
          0.95959596,
          1.09090909,
          1.22222222,
          1.35353535,
          1.48484848,
          1.61616162,
          1.74747475,
          1.87878788,
          2.01010101,
          2.14141414,
          2.27272727,
          2.4040404,
          2.53535354,
          2.66666667,
          2.7979798,
          2.92929293,
          3.06060606,
          3.19191919,
          3.32323232,
          3.45454545,
          3.58585859,
          3.71717172,
          3.84848485,
          3.97979798,
          4.11111111,
          4.24242424,
          4.37373737,
          4.50505051,
          4.63636364,
          4.76767677,
          4.8989899,
          5.03030303,
          5.16161616,
          5.29292929,
          5.42424242,
          5.55555556,
          5.68686869,
          5.81818182,
          5.94949495,
          6.08080808,
          6.21212121,
          6.34343434,
          6.47474747,
          6.60606061,
          6.73737374,
          6.86868687,
          7
         ],
         "xaxis": "x",
         "y": [
          -0.43980958,
          -0.43675397,
          -0.43391129,
          -0.43123788,
          -0.42869032,
          -0.42629094,
          -0.42421077,
          -0.42254684,
          -0.42122855,
          -0.42009117,
          -0.41887161,
          -0.41746019,
          -0.41592012,
          -0.41438398,
          -0.41303448,
          -0.41205581,
          -0.4115484,
          -0.41092853,
          -0.4092784,
          -0.40567796,
          -0.39936422,
          -0.39027936,
          -0.37856337,
          -0.36435625,
          -0.34778982,
          -0.32897521,
          -0.30802032,
          -0.28503277,
          -0.2601057,
          -0.23331059,
          -0.20471714,
          -0.1744047,
          -0.1426391,
          -0.10985485,
          -0.07649254,
          -0.04299275,
          -0.00979607,
          0.02265691,
          0.0539256,
          0.08361274,
          0.11153944,
          0.13759551,
          0.16167076,
          0.18365503,
          0.20343813,
          0.2209099,
          0.235962,
          0.24862019,
          0.2591329,
          0.26776952,
          0.27479945,
          0.28049211,
          0.28511688,
          0.28894319,
          0.29223092,
          0.29513904,
          0.29776575,
          0.30020843,
          0.30256443,
          0.30493112,
          0.30740586,
          0.31008601,
          0.31303967,
          0.31624187,
          0.31964922,
          0.32321848,
          0.3269236,
          0.33077017,
          0.3347672,
          0.33892348,
          0.34324206,
          0.34771967,
          0.35235268,
          0.35713543,
          0.3620374,
          0.36701146,
          0.37201017,
          0.37700063,
          0.38204275,
          0.38723295,
          0.39266773,
          0.39840188,
          0.40434155,
          0.41035978,
          0.41633001,
          0.4221865,
          0.42798804,
          0.43381194,
          0.43975097,
          0.44590242,
          0.45232302,
          0.45885019,
          0.46526624,
          0.47161734,
          0.47814242,
          0.48493892,
          0.49187647,
          0.49880486,
          0.50557391,
          0.51203345
         ],
         "yaxis": "y"
        }
       ],
       "layout": {
        "legend": {
         "title": {
          "text": "M"
         },
         "tracegroupgap": 0
        },
        "margin": {
         "t": 60
        },
        "template": {
         "data": {
          "bar": [
           {
            "error_x": {
             "color": "rgb(36,36,36)"
            },
            "error_y": {
             "color": "rgb(36,36,36)"
            },
            "marker": {
             "line": {
              "color": "white",
              "width": 0.5
             },
             "pattern": {
              "fillmode": "overlay",
              "size": 10,
              "solidity": 0.2
             }
            },
            "type": "bar"
           }
          ],
          "barpolar": [
           {
            "marker": {
             "line": {
              "color": "white",
              "width": 0.5
             },
             "pattern": {
              "fillmode": "overlay",
              "size": 10,
              "solidity": 0.2
             }
            },
            "type": "barpolar"
           }
          ],
          "carpet": [
           {
            "aaxis": {
             "endlinecolor": "rgb(36,36,36)",
             "gridcolor": "white",
             "linecolor": "white",
             "minorgridcolor": "white",
             "startlinecolor": "rgb(36,36,36)"
            },
            "baxis": {
             "endlinecolor": "rgb(36,36,36)",
             "gridcolor": "white",
             "linecolor": "white",
             "minorgridcolor": "white",
             "startlinecolor": "rgb(36,36,36)"
            },
            "type": "carpet"
           }
          ],
          "choropleth": [
           {
            "colorbar": {
             "outlinewidth": 1,
             "tickcolor": "rgb(36,36,36)",
             "ticks": "outside"
            },
            "type": "choropleth"
           }
          ],
          "contour": [
           {
            "colorbar": {
             "outlinewidth": 1,
             "tickcolor": "rgb(36,36,36)",
             "ticks": "outside"
            },
            "colorscale": [
             [
              0,
              "#440154"
             ],
             [
              0.1111111111111111,
              "#482878"
             ],
             [
              0.2222222222222222,
              "#3e4989"
             ],
             [
              0.3333333333333333,
              "#31688e"
             ],
             [
              0.4444444444444444,
              "#26828e"
             ],
             [
              0.5555555555555556,
              "#1f9e89"
             ],
             [
              0.6666666666666666,
              "#35b779"
             ],
             [
              0.7777777777777778,
              "#6ece58"
             ],
             [
              0.8888888888888888,
              "#b5de2b"
             ],
             [
              1,
              "#fde725"
             ]
            ],
            "type": "contour"
           }
          ],
          "contourcarpet": [
           {
            "colorbar": {
             "outlinewidth": 1,
             "tickcolor": "rgb(36,36,36)",
             "ticks": "outside"
            },
            "type": "contourcarpet"
           }
          ],
          "heatmap": [
           {
            "colorbar": {
             "outlinewidth": 1,
             "tickcolor": "rgb(36,36,36)",
             "ticks": "outside"
            },
            "colorscale": [
             [
              0,
              "#440154"
             ],
             [
              0.1111111111111111,
              "#482878"
             ],
             [
              0.2222222222222222,
              "#3e4989"
             ],
             [
              0.3333333333333333,
              "#31688e"
             ],
             [
              0.4444444444444444,
              "#26828e"
             ],
             [
              0.5555555555555556,
              "#1f9e89"
             ],
             [
              0.6666666666666666,
              "#35b779"
             ],
             [
              0.7777777777777778,
              "#6ece58"
             ],
             [
              0.8888888888888888,
              "#b5de2b"
             ],
             [
              1,
              "#fde725"
             ]
            ],
            "type": "heatmap"
           }
          ],
          "heatmapgl": [
           {
            "colorbar": {
             "outlinewidth": 1,
             "tickcolor": "rgb(36,36,36)",
             "ticks": "outside"
            },
            "colorscale": [
             [
              0,
              "#440154"
             ],
             [
              0.1111111111111111,
              "#482878"
             ],
             [
              0.2222222222222222,
              "#3e4989"
             ],
             [
              0.3333333333333333,
              "#31688e"
             ],
             [
              0.4444444444444444,
              "#26828e"
             ],
             [
              0.5555555555555556,
              "#1f9e89"
             ],
             [
              0.6666666666666666,
              "#35b779"
             ],
             [
              0.7777777777777778,
              "#6ece58"
             ],
             [
              0.8888888888888888,
              "#b5de2b"
             ],
             [
              1,
              "#fde725"
             ]
            ],
            "type": "heatmapgl"
           }
          ],
          "histogram": [
           {
            "marker": {
             "line": {
              "color": "white",
              "width": 0.6
             }
            },
            "type": "histogram"
           }
          ],
          "histogram2d": [
           {
            "colorbar": {
             "outlinewidth": 1,
             "tickcolor": "rgb(36,36,36)",
             "ticks": "outside"
            },
            "colorscale": [
             [
              0,
              "#440154"
             ],
             [
              0.1111111111111111,
              "#482878"
             ],
             [
              0.2222222222222222,
              "#3e4989"
             ],
             [
              0.3333333333333333,
              "#31688e"
             ],
             [
              0.4444444444444444,
              "#26828e"
             ],
             [
              0.5555555555555556,
              "#1f9e89"
             ],
             [
              0.6666666666666666,
              "#35b779"
             ],
             [
              0.7777777777777778,
              "#6ece58"
             ],
             [
              0.8888888888888888,
              "#b5de2b"
             ],
             [
              1,
              "#fde725"
             ]
            ],
            "type": "histogram2d"
           }
          ],
          "histogram2dcontour": [
           {
            "colorbar": {
             "outlinewidth": 1,
             "tickcolor": "rgb(36,36,36)",
             "ticks": "outside"
            },
            "colorscale": [
             [
              0,
              "#440154"
             ],
             [
              0.1111111111111111,
              "#482878"
             ],
             [
              0.2222222222222222,
              "#3e4989"
             ],
             [
              0.3333333333333333,
              "#31688e"
             ],
             [
              0.4444444444444444,
              "#26828e"
             ],
             [
              0.5555555555555556,
              "#1f9e89"
             ],
             [
              0.6666666666666666,
              "#35b779"
             ],
             [
              0.7777777777777778,
              "#6ece58"
             ],
             [
              0.8888888888888888,
              "#b5de2b"
             ],
             [
              1,
              "#fde725"
             ]
            ],
            "type": "histogram2dcontour"
           }
          ],
          "mesh3d": [
           {
            "colorbar": {
             "outlinewidth": 1,
             "tickcolor": "rgb(36,36,36)",
             "ticks": "outside"
            },
            "type": "mesh3d"
           }
          ],
          "parcoords": [
           {
            "line": {
             "colorbar": {
              "outlinewidth": 1,
              "tickcolor": "rgb(36,36,36)",
              "ticks": "outside"
             }
            },
            "type": "parcoords"
           }
          ],
          "pie": [
           {
            "automargin": true,
            "type": "pie"
           }
          ],
          "scatter": [
           {
            "marker": {
             "colorbar": {
              "outlinewidth": 1,
              "tickcolor": "rgb(36,36,36)",
              "ticks": "outside"
             }
            },
            "type": "scatter"
           }
          ],
          "scatter3d": [
           {
            "line": {
             "colorbar": {
              "outlinewidth": 1,
              "tickcolor": "rgb(36,36,36)",
              "ticks": "outside"
             }
            },
            "marker": {
             "colorbar": {
              "outlinewidth": 1,
              "tickcolor": "rgb(36,36,36)",
              "ticks": "outside"
             }
            },
            "type": "scatter3d"
           }
          ],
          "scattercarpet": [
           {
            "marker": {
             "colorbar": {
              "outlinewidth": 1,
              "tickcolor": "rgb(36,36,36)",
              "ticks": "outside"
             }
            },
            "type": "scattercarpet"
           }
          ],
          "scattergeo": [
           {
            "marker": {
             "colorbar": {
              "outlinewidth": 1,
              "tickcolor": "rgb(36,36,36)",
              "ticks": "outside"
             }
            },
            "type": "scattergeo"
           }
          ],
          "scattergl": [
           {
            "marker": {
             "colorbar": {
              "outlinewidth": 1,
              "tickcolor": "rgb(36,36,36)",
              "ticks": "outside"
             }
            },
            "type": "scattergl"
           }
          ],
          "scattermapbox": [
           {
            "marker": {
             "colorbar": {
              "outlinewidth": 1,
              "tickcolor": "rgb(36,36,36)",
              "ticks": "outside"
             }
            },
            "type": "scattermapbox"
           }
          ],
          "scatterpolar": [
           {
            "marker": {
             "colorbar": {
              "outlinewidth": 1,
              "tickcolor": "rgb(36,36,36)",
              "ticks": "outside"
             }
            },
            "type": "scatterpolar"
           }
          ],
          "scatterpolargl": [
           {
            "marker": {
             "colorbar": {
              "outlinewidth": 1,
              "tickcolor": "rgb(36,36,36)",
              "ticks": "outside"
             }
            },
            "type": "scatterpolargl"
           }
          ],
          "scatterternary": [
           {
            "marker": {
             "colorbar": {
              "outlinewidth": 1,
              "tickcolor": "rgb(36,36,36)",
              "ticks": "outside"
             }
            },
            "type": "scatterternary"
           }
          ],
          "surface": [
           {
            "colorbar": {
             "outlinewidth": 1,
             "tickcolor": "rgb(36,36,36)",
             "ticks": "outside"
            },
            "colorscale": [
             [
              0,
              "#440154"
             ],
             [
              0.1111111111111111,
              "#482878"
             ],
             [
              0.2222222222222222,
              "#3e4989"
             ],
             [
              0.3333333333333333,
              "#31688e"
             ],
             [
              0.4444444444444444,
              "#26828e"
             ],
             [
              0.5555555555555556,
              "#1f9e89"
             ],
             [
              0.6666666666666666,
              "#35b779"
             ],
             [
              0.7777777777777778,
              "#6ece58"
             ],
             [
              0.8888888888888888,
              "#b5de2b"
             ],
             [
              1,
              "#fde725"
             ]
            ],
            "type": "surface"
           }
          ],
          "table": [
           {
            "cells": {
             "fill": {
              "color": "rgb(237,237,237)"
             },
             "line": {
              "color": "white"
             }
            },
            "header": {
             "fill": {
              "color": "rgb(217,217,217)"
             },
             "line": {
              "color": "white"
             }
            },
            "type": "table"
           }
          ]
         },
         "layout": {
          "annotationdefaults": {
           "arrowhead": 0,
           "arrowwidth": 1
          },
          "autotypenumbers": "strict",
          "coloraxis": {
           "colorbar": {
            "outlinewidth": 1,
            "tickcolor": "rgb(36,36,36)",
            "ticks": "outside"
           }
          },
          "colorscale": {
           "diverging": [
            [
             0,
             "rgb(103,0,31)"
            ],
            [
             0.1,
             "rgb(178,24,43)"
            ],
            [
             0.2,
             "rgb(214,96,77)"
            ],
            [
             0.3,
             "rgb(244,165,130)"
            ],
            [
             0.4,
             "rgb(253,219,199)"
            ],
            [
             0.5,
             "rgb(247,247,247)"
            ],
            [
             0.6,
             "rgb(209,229,240)"
            ],
            [
             0.7,
             "rgb(146,197,222)"
            ],
            [
             0.8,
             "rgb(67,147,195)"
            ],
            [
             0.9,
             "rgb(33,102,172)"
            ],
            [
             1,
             "rgb(5,48,97)"
            ]
           ],
           "sequential": [
            [
             0,
             "#440154"
            ],
            [
             0.1111111111111111,
             "#482878"
            ],
            [
             0.2222222222222222,
             "#3e4989"
            ],
            [
             0.3333333333333333,
             "#31688e"
            ],
            [
             0.4444444444444444,
             "#26828e"
            ],
            [
             0.5555555555555556,
             "#1f9e89"
            ],
            [
             0.6666666666666666,
             "#35b779"
            ],
            [
             0.7777777777777778,
             "#6ece58"
            ],
            [
             0.8888888888888888,
             "#b5de2b"
            ],
            [
             1,
             "#fde725"
            ]
           ],
           "sequentialminus": [
            [
             0,
             "#440154"
            ],
            [
             0.1111111111111111,
             "#482878"
            ],
            [
             0.2222222222222222,
             "#3e4989"
            ],
            [
             0.3333333333333333,
             "#31688e"
            ],
            [
             0.4444444444444444,
             "#26828e"
            ],
            [
             0.5555555555555556,
             "#1f9e89"
            ],
            [
             0.6666666666666666,
             "#35b779"
            ],
            [
             0.7777777777777778,
             "#6ece58"
            ],
            [
             0.8888888888888888,
             "#b5de2b"
            ],
            [
             1,
             "#fde725"
            ]
           ]
          },
          "colorway": [
           "#1F77B4",
           "#FF7F0E",
           "#2CA02C",
           "#D62728",
           "#9467BD",
           "#8C564B",
           "#E377C2",
           "#7F7F7F",
           "#BCBD22",
           "#17BECF"
          ],
          "font": {
           "color": "rgb(36,36,36)"
          },
          "geo": {
           "bgcolor": "white",
           "lakecolor": "white",
           "landcolor": "white",
           "showlakes": true,
           "showland": true,
           "subunitcolor": "white"
          },
          "hoverlabel": {
           "align": "left"
          },
          "hovermode": "closest",
          "mapbox": {
           "style": "light"
          },
          "paper_bgcolor": "white",
          "plot_bgcolor": "white",
          "polar": {
           "angularaxis": {
            "gridcolor": "rgb(232,232,232)",
            "linecolor": "rgb(36,36,36)",
            "showgrid": false,
            "showline": true,
            "ticks": "outside"
           },
           "bgcolor": "white",
           "radialaxis": {
            "gridcolor": "rgb(232,232,232)",
            "linecolor": "rgb(36,36,36)",
            "showgrid": false,
            "showline": true,
            "ticks": "outside"
           }
          },
          "scene": {
           "xaxis": {
            "backgroundcolor": "white",
            "gridcolor": "rgb(232,232,232)",
            "gridwidth": 2,
            "linecolor": "rgb(36,36,36)",
            "showbackground": true,
            "showgrid": false,
            "showline": true,
            "ticks": "outside",
            "zeroline": false,
            "zerolinecolor": "rgb(36,36,36)"
           },
           "yaxis": {
            "backgroundcolor": "white",
            "gridcolor": "rgb(232,232,232)",
            "gridwidth": 2,
            "linecolor": "rgb(36,36,36)",
            "showbackground": true,
            "showgrid": false,
            "showline": true,
            "ticks": "outside",
            "zeroline": false,
            "zerolinecolor": "rgb(36,36,36)"
           },
           "zaxis": {
            "backgroundcolor": "white",
            "gridcolor": "rgb(232,232,232)",
            "gridwidth": 2,
            "linecolor": "rgb(36,36,36)",
            "showbackground": true,
            "showgrid": false,
            "showline": true,
            "ticks": "outside",
            "zeroline": false,
            "zerolinecolor": "rgb(36,36,36)"
           }
          },
          "shapedefaults": {
           "fillcolor": "black",
           "line": {
            "width": 0
           },
           "opacity": 0.3
          },
          "ternary": {
           "aaxis": {
            "gridcolor": "rgb(232,232,232)",
            "linecolor": "rgb(36,36,36)",
            "showgrid": false,
            "showline": true,
            "ticks": "outside"
           },
           "baxis": {
            "gridcolor": "rgb(232,232,232)",
            "linecolor": "rgb(36,36,36)",
            "showgrid": false,
            "showline": true,
            "ticks": "outside"
           },
           "bgcolor": "white",
           "caxis": {
            "gridcolor": "rgb(232,232,232)",
            "linecolor": "rgb(36,36,36)",
            "showgrid": false,
            "showline": true,
            "ticks": "outside"
           }
          },
          "title": {
           "x": 0.05
          },
          "xaxis": {
           "automargin": true,
           "gridcolor": "rgb(232,232,232)",
           "linecolor": "rgb(36,36,36)",
           "showgrid": false,
           "showline": true,
           "ticks": "outside",
           "title": {
            "standoff": 15
           },
           "zeroline": false,
           "zerolinecolor": "rgb(36,36,36)"
          },
          "yaxis": {
           "automargin": true,
           "gridcolor": "rgb(232,232,232)",
           "linecolor": "rgb(36,36,36)",
           "showgrid": false,
           "showline": true,
           "ticks": "outside",
           "title": {
            "standoff": 15
           },
           "zeroline": false,
           "zerolinecolor": "rgb(36,36,36)"
          }
         }
        },
        "title": {
         "text": "Cl vs. Alpha"
        },
        "xaxis": {
         "anchor": "y",
         "domain": [
          0,
          1
         ],
         "gridcolor": "Gray",
         "gridwidth": 1,
         "linecolor": "black",
         "linewidth": 1,
         "mirror": false,
         "range": [
          -15,
          15
         ],
         "showgrid": true,
         "showline": true,
         "title": {
          "text": "Alpha [deg]"
         },
         "zeroline": true,
         "zerolinecolor": "black",
         "zerolinewidth": 2
        },
        "yaxis": {
         "anchor": "x",
         "domain": [
          0,
          1
         ],
         "gridcolor": "Gray",
         "gridwidth": 0.5,
         "linecolor": "black",
         "linewidth": 1,
         "mirror": false,
         "showgrid": true,
         "showline": true,
         "title": {
          "text": "Cl"
         },
         "zeroline": true,
         "zerolinecolor": "Gray",
         "zerolinewidth": 1
        }
       }
      },
      "text/html": [
       "<div>                            <div id=\"fa0b3518-827a-484f-b029-b380c2aa587d\" class=\"plotly-graph-div\" style=\"height:525px; width:100%;\"></div>            <script type=\"text/javascript\">                require([\"plotly\"], function(Plotly) {                    window.PLOTLYENV=window.PLOTLYENV || {};                                    if (document.getElementById(\"fa0b3518-827a-484f-b029-b380c2aa587d\")) {                    Plotly.newPlot(                        \"fa0b3518-827a-484f-b029-b380c2aa587d\",                        [{\"hovertemplate\":\"M=0.2<br>Alpha=%{x}<br>Cl=%{y}<extra></extra>\",\"legendgroup\":\"0.2\",\"line\":{\"color\":\"#f0f921\",\"dash\":\"solid\"},\"mode\":\"lines\",\"name\":\"0.2\",\"orientation\":\"v\",\"showlegend\":true,\"textposition\":\"top center\",\"type\":\"scatter\",\"x\":[-6.0,-5.76767677,-5.53535354,-5.3030303,-5.07070707,-4.83838384,-4.60606061,-4.37373737,-4.14141414,-3.90909091,-3.67676768,-3.44444444,-3.21212121,-2.97979798,-2.74747475,-2.51515152,-2.28282828,-2.05050505,-1.81818182,-1.58585859,-1.35353535,-1.12121212,-0.88888889,-0.65656566,-0.42424242,-0.19191919,0.04040404,0.27272727,0.50505051,0.73737374,0.96969697,1.2020202,1.43434343,1.66666667,1.8989899,2.13131313,2.36363636,2.5959596,2.82828283,3.06060606,3.29292929,3.52525253,3.75757576,3.98989899,4.22222222,4.45454545,4.68686869,4.91919192,5.15151515,5.38383838,5.61616162,5.84848485,6.08080808,6.31313131,6.54545455,6.77777778,7.01010101,7.24242424,7.47474747,7.70707071,7.93939394,8.17171717,8.4040404,8.63636364,8.86868687,9.1010101,9.33333333,9.56565657,9.7979798,10.03030303,10.26262626,10.49494949,10.72727273,10.95959596,11.19191919,11.42424242,11.65656566,11.88888889,12.12121212,12.35353535,12.58585859,12.81818182,13.05050505,13.28282828,13.51515152,13.74747475,13.97979798,14.21212121,14.44444444,14.67676768,14.90909091,15.14141414,15.37373737,15.60606061,15.83838384,16.07070707,16.3030303,16.53535354,16.76767677,17.0],\"xaxis\":\"x\",\"y\":[-0.53228324,-0.50718964,-0.48195101,-0.45660799,-0.43120119,-0.40576803,-0.38031204,-0.35481676,-0.32926958,-0.30366183,-0.27799741,-0.2522964,-0.22653591,-0.20060492,-0.17445074,-0.14823331,-0.12212297,-0.09614174,-0.07026656,-0.04447435,-0.01874205,0.0069534,0.03263436,0.05830475,0.08394898,0.10955055,0.13509298,0.16057669,0.18604255,0.21153739,0.23710805,0.26279145,0.28856551,0.31438649,0.34021063,0.3659956,0.39172412,0.41740002,0.44302781,0.46861199,0.49415792,0.51967255,0.54516302,0.57063647,0.59609242,0.62149578,0.64680161,0.67196494,0.69694806,0.72180186,0.74663668,0.77156394,0.79668942,0.82181231,0.84647682,0.87085644,0.89513278,0.91937402,0.94348977,0.96739494,0.9911269,1.0148129,1.03836582,1.06169198,1.08482576,1.10780834,1.130642,1.15328983,1.17572899,1.19792788,1.21987775,1.24163348,1.26319091,1.28450409,1.30552967,1.32632225,1.34695995,1.36732392,1.3871706,1.40625753,1.42479816,1.44360507,1.46199796,1.47943116,1.49655565,1.51357538,1.5300637,1.5454421,1.55996393,1.57396867,1.58737427,1.59957767,1.60896095,1.61529641,1.62087053,1.62480481,1.62577474,1.62294933,1.61513429,1.60103413],\"yaxis\":\"y\"},{\"hovertemplate\":\"M=0.3<br>Alpha=%{x}<br>Cl=%{y}<extra></extra>\",\"legendgroup\":\"0.3\",\"line\":{\"color\":\"#fdca26\",\"dash\":\"solid\"},\"mode\":\"lines\",\"name\":\"0.3\",\"orientation\":\"v\",\"showlegend\":true,\"textposition\":\"top center\",\"type\":\"scatter\",\"x\":[-6.0,-5.76767677,-5.53535354,-5.3030303,-5.07070707,-4.83838384,-4.60606061,-4.37373737,-4.14141414,-3.90909091,-3.67676768,-3.44444444,-3.21212121,-2.97979798,-2.74747475,-2.51515152,-2.28282828,-2.05050505,-1.81818182,-1.58585859,-1.35353535,-1.12121212,-0.88888889,-0.65656566,-0.42424242,-0.19191919,0.04040404,0.27272727,0.50505051,0.73737374,0.96969697,1.2020202,1.43434343,1.66666667,1.8989899,2.13131313,2.36363636,2.5959596,2.82828283,3.06060606,3.29292929,3.52525253,3.75757576,3.98989899,4.22222222,4.45454545,4.68686869,4.91919192,5.15151515,5.38383838,5.61616162,5.84848485,6.08080808,6.31313131,6.54545455,6.77777778,7.01010101,7.24242424,7.47474747,7.70707071,7.93939394,8.17171717,8.4040404,8.63636364,8.86868687,9.1010101,9.33333333,9.56565657,9.7979798,10.03030303,10.26262626,10.49494949,10.72727273,10.95959596,11.19191919,11.42424242,11.65656566,11.88888889,12.12121212,12.35353535,12.58585859,12.81818182,13.05050505,13.28282828,13.51515152,13.74747475,13.97979798,14.21212121,14.44444444,14.67676768,14.90909091,15.14141414,15.37373737,15.60606061,15.83838384,16.07070707,16.3030303,16.53535354,16.76767677,17.0],\"xaxis\":\"x\",\"y\":[-0.54949398,-0.5236046,-0.49757824,-0.47145689,-0.44528256,-0.41909013,-0.39284002,-0.36645404,-0.33996472,-0.3135014,-0.2870942,-0.26063718,-0.23408515,-0.20753333,-0.18104614,-0.15454143,-0.12792844,-0.1012119,-0.07442552,-0.04760302,-0.02077814,0.0060154,0.03274484,0.0594021,0.0860052,0.11257344,0.13912609,0.1656794,0.19224242,0.21882311,0.24542945,0.27206643,0.29872142,0.32537529,0.3520089,0.37860374,0.40515223,0.43165601,0.458117,0.4845371,0.51091694,0.53725478,0.56354858,0.58979632,0.61599383,0.64212716,0.66817956,0.6941343,0.71997721,0.74572579,0.77141872,0.79709511,0.82279191,0.84843072,0.87382464,0.8989963,0.9240866,0.94919239,0.97414866,0.99889652,1.02348188,1.04796291,1.07231066,1.09645955,1.12039571,1.14420409,1.16787199,1.19129343,1.21446468,1.23740989,1.2601462,1.28265375,1.30486505,1.32676353,1.34838683,1.36972657,1.39075254,1.41141388,1.43164672,1.45138766,1.47067357,1.48965574,1.50807416,1.52575172,1.54289758,1.55942708,1.57503623,1.58940521,1.60253004,1.61436897,1.62458482,1.63253939,1.63761248,1.63934198,1.63734987,1.63083055,1.61894855,1.60080908,1.57482718,1.53924913],\"yaxis\":\"y\"},{\"hovertemplate\":\"M=0.4<br>Alpha=%{x}<br>Cl=%{y}<extra></extra>\",\"legendgroup\":\"0.4\",\"line\":{\"color\":\"#fb9f3a\",\"dash\":\"solid\"},\"mode\":\"lines\",\"name\":\"0.4\",\"orientation\":\"v\",\"showlegend\":true,\"textposition\":\"top center\",\"type\":\"scatter\",\"x\":[-6.0,-5.76767677,-5.53535354,-5.3030303,-5.07070707,-4.83838384,-4.60606061,-4.37373737,-4.14141414,-3.90909091,-3.67676768,-3.44444444,-3.21212121,-2.97979798,-2.74747475,-2.51515152,-2.28282828,-2.05050505,-1.81818182,-1.58585859,-1.35353535,-1.12121212,-0.88888889,-0.65656566,-0.42424242,-0.19191919,0.04040404,0.27272727,0.50505051,0.73737374,0.96969697,1.2020202,1.43434343,1.66666667,1.8989899,2.13131313,2.36363636,2.5959596,2.82828283,3.06060606,3.29292929,3.52525253,3.75757576,3.98989899,4.22222222,4.45454545,4.68686869,4.91919192,5.15151515,5.38383838,5.61616162,5.84848485,6.08080808,6.31313131,6.54545455,6.77777778,7.01010101,7.24242424,7.47474747,7.70707071,7.93939394,8.17171717,8.4040404,8.63636364,8.86868687,9.1010101,9.33333333,9.56565657,9.7979798,10.03030303,10.26262626,10.49494949,10.72727273,10.95959596,11.19191919,11.42424242,11.65656566,11.88888889,12.12121212,12.35353535,12.58585859,12.81818182,13.05050505,13.28282828,13.51515152,13.74747475,13.97979798,14.21212121,14.44444444,14.67676768,14.90909091,15.14141414,15.37373737,15.60606061,15.83838384,16.07070707,16.3030303,16.53535354,16.76767677,17.0],\"xaxis\":\"x\",\"y\":[-0.57438145,-0.54735084,-0.52020789,-0.49296479,-0.46563373,-0.43822654,-0.41075118,-0.3832134,-0.35562056,-0.32798138,-0.30029716,-0.27255951,-0.24478207,-0.2170239,-0.18931741,-0.16159605,-0.13378916,-0.10589883,-0.07794924,-0.04996457,-0.02196899,0.0060133,0.03395877,0.06186061,0.08972963,0.11757753,0.14541599,0.17325411,0.20109487,0.22894031,0.25679248,0.28465202,0.312511,0.3403584,0.36818316,0.39597458,0.42372762,0.45144208,0.47911787,0.50675493,0.53435186,0.56190482,0.58940969,0.61686235,0.64425883,0.67159577,0.69886997,0.72607828,0.75321725,0.7802805,0.80725965,0.83414628,0.86093217,0.88761952,0.91421151,0.94067323,0.96704023,0.99335133,1.01952369,1.04550619,1.07132642,1.09705174,1.12262195,1.14795714,1.17306592,1.19803623,1.22285062,1.24738903,1.27163161,1.29564366,1.31944963,1.34290603,1.36592873,1.38820392,1.40916159,1.42811212,1.44435644,1.45761343,1.46786655,1.47510391,1.47938053,1.48083297,1.47934846,1.47500414,1.46817606,1.45808435,1.44542869,1.43149019,1.413954,1.39357078,1.3719248,1.34726237,1.32124431,1.29516724,1.26664033,1.23808438,1.21162015,1.18707021,1.165009,1.14625038],\"yaxis\":\"y\"},{\"hovertemplate\":\"M=0.5<br>Alpha=%{x}<br>Cl=%{y}<extra></extra>\",\"legendgroup\":\"0.5\",\"line\":{\"color\":\"#ed7953\",\"dash\":\"solid\"},\"mode\":\"lines\",\"name\":\"0.5\",\"orientation\":\"v\",\"showlegend\":true,\"textposition\":\"top center\",\"type\":\"scatter\",\"x\":[-5.5,-5.3030303,-5.10606061,-4.90909091,-4.71212121,-4.51515152,-4.31818182,-4.12121212,-3.92424242,-3.72727273,-3.53030303,-3.33333333,-3.13636364,-2.93939394,-2.74242424,-2.54545455,-2.34848485,-2.15151515,-1.95454545,-1.75757576,-1.56060606,-1.36363636,-1.16666667,-0.96969697,-0.77272727,-0.57575758,-0.37878788,-0.18181818,0.01515152,0.21212121,0.40909091,0.60606061,0.8030303,1.0,1.1969697,1.39393939,1.59090909,1.78787879,1.98484848,2.18181818,2.37878788,2.57575758,2.77272727,2.96969697,3.16666667,3.36363636,3.56060606,3.75757576,3.95454545,4.15151515,4.34848485,4.54545455,4.74242424,4.93939394,5.13636364,5.33333333,5.53030303,5.72727273,5.92424242,6.12121212,6.31818182,6.51515152,6.71212121,6.90909091,7.10606061,7.3030303,7.5,7.6969697,7.89393939,8.09090909,8.28787879,8.48484848,8.68181818,8.87878788,9.07575758,9.27272727,9.46969697,9.66666667,9.86363636,10.06060606,10.25757576,10.45454545,10.65151515,10.84848485,11.04545455,11.24242424,11.43939394,11.63636364,11.83333333,12.03030303,12.22727273,12.42424242,12.62121212,12.81818182,13.01515152,13.21212121,13.40909091,13.60606061,13.8030303,14.0],\"xaxis\":\"x\",\"y\":[-0.52116637,-0.5053465,-0.4876147,-0.46812634,-0.44703678,-0.42450138,-0.40071908,-0.37610845,-0.35115258,-0.32613945,-0.30109306,-0.27601853,-0.25092008,-0.22580153,-0.20066605,-0.17551573,-0.15035255,-0.12517849,-0.09999554,-0.07480725,-0.04962032,-0.02444111,0.00073208,0.02590581,0.05108437,0.07626622,0.10144889,0.12662991,0.1518068,0.17697803,0.202145,0.22730969,0.2524741,0.2776402,0.30280895,0.32797715,0.35314053,0.37829486,0.40343589,0.42855997,0.45366653,0.47875594,0.50382858,0.52888483,0.55392472,0.57894598,0.60394545,0.62891999,0.65386642,0.67878203,0.7036678,0.72852645,0.75336076,0.77817349,0.8029662,0.8277278,0.85243958,0.8770827,0.90163835,0.92609114,0.95047424,0.97475035,0.99856461,1.02158181,1.04353936,1.0642775,1.08373362,1.10187824,1.11884838,1.13492179,1.14973324,1.16249617,1.17379424,1.18370929,1.19117799,1.19583986,1.19830109,1.19873925,1.19727929,1.19425211,1.18970857,1.18327383,1.17506077,1.16549512,1.15512225,1.14441115,1.1336475,1.12307549,1.1127375,1.10255435,1.09244519,1.08235948,1.07264912,1.06370838,1.05523056,1.04698518,1.03937203,1.03259282,1.02656534,1.02119797],\"yaxis\":\"y\"},{\"hovertemplate\":\"M=0.6<br>Alpha=%{x}<br>Cl=%{y}<extra></extra>\",\"legendgroup\":\"0.6\",\"line\":{\"color\":\"#d8576b\",\"dash\":\"solid\"},\"mode\":\"lines\",\"name\":\"0.6\",\"orientation\":\"v\",\"showlegend\":true,\"textposition\":\"top center\",\"type\":\"scatter\",\"x\":[-6.0,-5.86262626,-5.72525253,-5.58787879,-5.45050505,-5.31313131,-5.17575758,-5.03838384,-4.9010101,-4.76363636,-4.62626263,-4.48888889,-4.35151515,-4.21414141,-4.07676768,-3.93939394,-3.8020202,-3.66464646,-3.52727273,-3.38989899,-3.25252525,-3.11515152,-2.97777778,-2.84040404,-2.7030303,-2.56565657,-2.42828283,-2.29090909,-2.15353535,-2.01616162,-1.87878788,-1.74141414,-1.6040404,-1.46666667,-1.32929293,-1.19191919,-1.05454545,-0.91717172,-0.77979798,-0.64242424,-0.50505051,-0.36767677,-0.23030303,-0.09292929,0.04444444,0.18181818,0.31919192,0.45656566,0.59393939,0.73131313,0.86868687,1.00606061,1.14343434,1.28080808,1.41818182,1.55555556,1.69292929,1.83030303,1.96767677,2.10505051,2.24242424,2.37979798,2.51717172,2.65454545,2.79191919,2.92929293,3.06666667,3.2040404,3.34141414,3.47878788,3.61616162,3.75353535,3.89090909,4.02828283,4.16565657,4.3030303,4.44040404,4.57777778,4.71515152,4.85252525,4.98989899,5.12727273,5.26464646,5.4020202,5.53939394,5.67676768,5.81414141,5.95151515,6.08888889,6.22626263,6.36363636,6.5010101,6.63838384,6.77575758,6.91313131,7.05050505,7.18787879,7.32525253,7.46262626,7.6],\"xaxis\":\"x\",\"y\":[-0.51781498,-0.5143375,-0.50971647,-0.50399277,-0.49720726,-0.48940083,-0.48061435,-0.47088868,-0.46026384,-0.44877132,-0.43643792,-0.42329039,-0.40938284,-0.39485539,-0.37986503,-0.36456672,-0.3490524,-0.3333406,-0.31744569,-0.30136706,-0.28499392,-0.26816629,-0.25072421,-0.23259658,-0.2139332,-0.1949176,-0.17572959,-0.15647162,-0.13717309,-0.11786054,-0.09855718,-0.07926708,-0.05998753,-0.04071583,-0.02144913,-0.00218426,0.01708196,0.0363526,0.05562868,0.07490972,0.09419518,0.11348453,0.13277724,0.15207277,0.17137061,0.19067115,0.20997627,0.22928796,0.24860822,0.26793906,0.28728246,0.30664043,0.32601425,0.34540263,0.36480375,0.38421579,0.40363691,0.42306528,0.44249908,0.46193329,0.48133647,0.50066412,0.51987164,0.53891445,0.55774794,0.57632752,0.59460958,0.61257472,0.6302287,0.64757846,0.66463094,0.68139306,0.69787177,0.71407385,0.72997834,0.74550335,0.76055889,0.77505498,0.78890164,0.80200888,0.81428673,0.82564812,0.83602063,0.84533638,0.85352749,0.86052608,0.86626427,0.87067418,0.87369464,0.8753481,0.87571371,0.87486566,0.8728719,0.86983395,0.865914,0.86128071,0.85610886,0.85058181,0.84488363,0.83919834],\"yaxis\":\"y\"},{\"hovertemplate\":\"M=0.7<br>Alpha=%{x}<br>Cl=%{y}<extra></extra>\",\"legendgroup\":\"0.7\",\"line\":{\"color\":\"#bd3786\",\"dash\":\"solid\"},\"mode\":\"lines\",\"name\":\"0.7\",\"orientation\":\"v\",\"showlegend\":true,\"textposition\":\"top center\",\"type\":\"scatter\",\"x\":[-6.0,-5.86868687,-5.73737374,-5.60606061,-5.47474747,-5.34343434,-5.21212121,-5.08080808,-4.94949495,-4.81818182,-4.68686869,-4.55555556,-4.42424242,-4.29292929,-4.16161616,-4.03030303,-3.8989899,-3.76767677,-3.63636364,-3.50505051,-3.37373737,-3.24242424,-3.11111111,-2.97979798,-2.84848485,-2.71717172,-2.58585859,-2.45454545,-2.32323232,-2.19191919,-2.06060606,-1.92929293,-1.7979798,-1.66666667,-1.53535354,-1.4040404,-1.27272727,-1.14141414,-1.01010101,-0.87878788,-0.74747475,-0.61616162,-0.48484848,-0.35353535,-0.22222222,-0.09090909,0.04040404,0.17171717,0.3030303,0.43434343,0.56565657,0.6969697,0.82828283,0.95959596,1.09090909,1.22222222,1.35353535,1.48484848,1.61616162,1.74747475,1.87878788,2.01010101,2.14141414,2.27272727,2.4040404,2.53535354,2.66666667,2.7979798,2.92929293,3.06060606,3.19191919,3.32323232,3.45454545,3.58585859,3.71717172,3.84848485,3.97979798,4.11111111,4.24242424,4.37373737,4.50505051,4.63636364,4.76767677,4.8989899,5.03030303,5.16161616,5.29292929,5.42424242,5.55555556,5.68686869,5.81818182,5.94949495,6.08080808,6.21212121,6.34343434,6.47474747,6.60606061,6.73737374,6.86868687,7.0],\"xaxis\":\"x\",\"y\":[-0.67305743,-0.67165615,-0.66781238,-0.6617087,-0.65352768,-0.64345186,-0.63166383,-0.61834615,-0.60368038,-0.58780555,-0.57080312,-0.55275048,-0.53372423,-0.51378845,-0.49299691,-0.47140312,-0.44906808,-0.42611421,-0.40269388,-0.37895972,-0.3550803,-0.33129605,-0.30786752,-0.28505499,-0.26300741,-0.24159054,-0.2206258,-0.19993537,-0.17938138,-0.15888581,-0.13837557,-0.11777965,-0.09706693,-0.07624239,-0.05531234,-0.03428305,-0.01316083,0.00804805,0.02933728,0.05069917,0.07211889,0.09357939,0.11506359,0.13655445,0.15803488,0.17948784,0.20089625,0.22224251,0.24350816,0.26467465,0.28572341,0.30663589,0.32739356,0.34797784,0.36836799,0.38851996,0.40837567,0.42787683,0.44696516,0.46558239,0.48367024,0.50117042,0.51800357,0.53402334,0.54907008,0.56298414,0.57560588,0.58677565,0.59633381,0.60412572,0.61013597,0.61450307,0.61737348,0.61889368,0.61921013,0.6184693,0.61681767,0.61440354,0.6113871,0.60793318,0.60420661,0.60037224,0.59659492,0.59303947,0.58987036,0.58719683,0.58501497,0.58330701,0.5820552,0.58124178,0.58084899,0.58085907,0.58125252,0.58198542,0.58299619,0.58424999,0.58575434,0.58752041,0.58955939,0.59188248],\"yaxis\":\"y\"},{\"hovertemplate\":\"M=0.75<br>Alpha=%{x}<br>Cl=%{y}<extra></extra>\",\"legendgroup\":\"0.75\",\"line\":{\"color\":\"#9c179e\",\"dash\":\"solid\"},\"mode\":\"lines\",\"name\":\"0.75\",\"orientation\":\"v\",\"showlegend\":true,\"textposition\":\"top center\",\"type\":\"scatter\",\"x\":[-6.0,-5.87272727,-5.74545455,-5.61818182,-5.49090909,-5.36363636,-5.23636364,-5.10909091,-4.98181818,-4.85454545,-4.72727273,-4.6,-4.47272727,-4.34545455,-4.21818182,-4.09090909,-3.96363636,-3.83636364,-3.70909091,-3.58181818,-3.45454545,-3.32727273,-3.2,-3.07272727,-2.94545455,-2.81818182,-2.69090909,-2.56363636,-2.43636364,-2.30909091,-2.18181818,-2.05454545,-1.92727273,-1.8,-1.67272727,-1.54545455,-1.41818182,-1.29090909,-1.16363636,-1.03636364,-0.90909091,-0.78181818,-0.65454545,-0.52727273,-0.4,-0.27272727,-0.14545455,-0.01818182,0.10909091,0.23636364,0.36363636,0.49090909,0.61818182,0.74545455,0.87272727,1.0,1.12727273,1.25454545,1.38181818,1.50909091,1.63636364,1.76363636,1.89090909,2.01818182,2.14545455,2.27272727,2.4,2.52727273,2.65454545,2.78181818,2.90909091,3.03636364,3.16363636,3.29090909,3.41818182,3.54545455,3.67272727,3.8,3.92727273,4.05454545,4.18181818,4.30909091,4.43636364,4.56363636,4.69090909,4.81818182,4.94545455,5.07272727,5.2,5.32727273,5.45454545,5.58181818,5.70909091,5.83636364,5.96363636,6.09090909,6.21818182,6.34545455,6.47272727,6.6],\"xaxis\":\"x\",\"y\":[-0.5537476,-0.55598676,-0.55833145,-0.5606603,-0.56285197,-0.56478511,-0.56633838,-0.56739042,-0.56781969,-0.5674128,-0.56571524,-0.56223342,-0.55647496,-0.54815922,-0.53745945,-0.52460759,-0.50983515,-0.49333876,-0.47525355,-0.45570841,-0.4348329,-0.41279174,-0.3898008,-0.36607996,-0.34184485,-0.31717079,-0.29196397,-0.2661205,-0.23954852,-0.21243244,-0.18523296,-0.15842281,-0.13245453,-0.10744204,-0.08321824,-0.05960757,-0.03643442,-0.01352321,0.00930164,0.03221573,0.05537884,0.0787956,0.10238258,0.12605532,0.14972936,0.17332026,0.19674357,0.21991483,0.24274663,0.26513335,0.28696239,0.30812115,0.32849705,0.34797748,0.36644984,0.38380153,0.39992447,0.41472856,0.42812824,0.44003792,0.45037204,0.459045,0.46597124,0.47106541,0.4743594,0.47619275,0.47695484,0.47703461,0.47673912,0.47619998,0.4755261,0.47482614,0.47418549,0.47364852,0.47325545,0.47304613,0.47304166,0.47323596,0.47362078,0.474188,0.4749335,0.47585799,0.47696245,0.47824777,0.47971184,0.48134963,0.48315594,0.48512571,0.48725572,0.48954425,0.49198966,0.4945912,0.49735976,0.50031424,0.5034737,0.50685522,0.51045659,0.51426465,0.51826611,0.52244767],\"yaxis\":\"y\"},{\"hovertemplate\":\"M=0.8<br>Alpha=%{x}<br>Cl=%{y}<extra></extra>\",\"legendgroup\":\"0.8\",\"line\":{\"color\":\"#7201a8\",\"dash\":\"solid\"},\"mode\":\"lines\",\"name\":\"0.8\",\"orientation\":\"v\",\"showlegend\":true,\"textposition\":\"top center\",\"type\":\"scatter\",\"x\":[-6.0,-5.86868687,-5.73737374,-5.60606061,-5.47474747,-5.34343434,-5.21212121,-5.08080808,-4.94949495,-4.81818182,-4.68686869,-4.55555556,-4.42424242,-4.29292929,-4.16161616,-4.03030303,-3.8989899,-3.76767677,-3.63636364,-3.50505051,-3.37373737,-3.24242424,-3.11111111,-2.97979798,-2.84848485,-2.71717172,-2.58585859,-2.45454545,-2.32323232,-2.19191919,-2.06060606,-1.92929293,-1.7979798,-1.66666667,-1.53535354,-1.4040404,-1.27272727,-1.14141414,-1.01010101,-0.87878788,-0.74747475,-0.61616162,-0.48484848,-0.35353535,-0.22222222,-0.09090909,0.04040404,0.17171717,0.3030303,0.43434343,0.56565657,0.6969697,0.82828283,0.95959596,1.09090909,1.22222222,1.35353535,1.48484848,1.61616162,1.74747475,1.87878788,2.01010101,2.14141414,2.27272727,2.4040404,2.53535354,2.66666667,2.7979798,2.92929293,3.06060606,3.19191919,3.32323232,3.45454545,3.58585859,3.71717172,3.84848485,3.97979798,4.11111111,4.24242424,4.37373737,4.50505051,4.63636364,4.76767677,4.8989899,5.03030303,5.16161616,5.29292929,5.42424242,5.55555556,5.68686869,5.81818182,5.94949495,6.08080808,6.21212121,6.34343434,6.47474747,6.60606061,6.73737374,6.86868687,7.0],\"xaxis\":\"x\",\"y\":[-0.43980958,-0.43675397,-0.43391129,-0.43123788,-0.42869032,-0.42629094,-0.42421077,-0.42254684,-0.42122855,-0.42009117,-0.41887161,-0.41746019,-0.41592012,-0.41438398,-0.41303448,-0.41205581,-0.4115484,-0.41092853,-0.4092784,-0.40567796,-0.39936422,-0.39027936,-0.37856337,-0.36435625,-0.34778982,-0.32897521,-0.30802032,-0.28503277,-0.2601057,-0.23331059,-0.20471714,-0.1744047,-0.1426391,-0.10985485,-0.07649254,-0.04299275,-0.00979607,0.02265691,0.0539256,0.08361274,0.11153944,0.13759551,0.16167076,0.18365503,0.20343813,0.2209099,0.235962,0.24862019,0.2591329,0.26776952,0.27479945,0.28049211,0.28511688,0.28894319,0.29223092,0.29513904,0.29776575,0.30020843,0.30256443,0.30493112,0.30740586,0.31008601,0.31303967,0.31624187,0.31964922,0.32321848,0.3269236,0.33077017,0.3347672,0.33892348,0.34324206,0.34771967,0.35235268,0.35713543,0.3620374,0.36701146,0.37201017,0.37700063,0.38204275,0.38723295,0.39266773,0.39840188,0.40434155,0.41035978,0.41633001,0.4221865,0.42798804,0.43381194,0.43975097,0.44590242,0.45232302,0.45885019,0.46526624,0.47161734,0.47814242,0.48493892,0.49187647,0.49880486,0.50557391,0.51203345],\"yaxis\":\"y\"}],                        {\"legend\":{\"title\":{\"text\":\"M\"},\"tracegroupgap\":0},\"margin\":{\"t\":60},\"template\":{\"data\":{\"bar\":[{\"error_x\":{\"color\":\"rgb(36,36,36)\"},\"error_y\":{\"color\":\"rgb(36,36,36)\"},\"marker\":{\"line\":{\"color\":\"white\",\"width\":0.5},\"pattern\":{\"fillmode\":\"overlay\",\"size\":10,\"solidity\":0.2}},\"type\":\"bar\"}],\"barpolar\":[{\"marker\":{\"line\":{\"color\":\"white\",\"width\":0.5},\"pattern\":{\"fillmode\":\"overlay\",\"size\":10,\"solidity\":0.2}},\"type\":\"barpolar\"}],\"carpet\":[{\"aaxis\":{\"endlinecolor\":\"rgb(36,36,36)\",\"gridcolor\":\"white\",\"linecolor\":\"white\",\"minorgridcolor\":\"white\",\"startlinecolor\":\"rgb(36,36,36)\"},\"baxis\":{\"endlinecolor\":\"rgb(36,36,36)\",\"gridcolor\":\"white\",\"linecolor\":\"white\",\"minorgridcolor\":\"white\",\"startlinecolor\":\"rgb(36,36,36)\"},\"type\":\"carpet\"}],\"choropleth\":[{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"},\"type\":\"choropleth\"}],\"contour\":[{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"},\"colorscale\":[[0.0,\"#440154\"],[0.1111111111111111,\"#482878\"],[0.2222222222222222,\"#3e4989\"],[0.3333333333333333,\"#31688e\"],[0.4444444444444444,\"#26828e\"],[0.5555555555555556,\"#1f9e89\"],[0.6666666666666666,\"#35b779\"],[0.7777777777777778,\"#6ece58\"],[0.8888888888888888,\"#b5de2b\"],[1.0,\"#fde725\"]],\"type\":\"contour\"}],\"contourcarpet\":[{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"},\"type\":\"contourcarpet\"}],\"heatmap\":[{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"},\"colorscale\":[[0.0,\"#440154\"],[0.1111111111111111,\"#482878\"],[0.2222222222222222,\"#3e4989\"],[0.3333333333333333,\"#31688e\"],[0.4444444444444444,\"#26828e\"],[0.5555555555555556,\"#1f9e89\"],[0.6666666666666666,\"#35b779\"],[0.7777777777777778,\"#6ece58\"],[0.8888888888888888,\"#b5de2b\"],[1.0,\"#fde725\"]],\"type\":\"heatmap\"}],\"heatmapgl\":[{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"},\"colorscale\":[[0.0,\"#440154\"],[0.1111111111111111,\"#482878\"],[0.2222222222222222,\"#3e4989\"],[0.3333333333333333,\"#31688e\"],[0.4444444444444444,\"#26828e\"],[0.5555555555555556,\"#1f9e89\"],[0.6666666666666666,\"#35b779\"],[0.7777777777777778,\"#6ece58\"],[0.8888888888888888,\"#b5de2b\"],[1.0,\"#fde725\"]],\"type\":\"heatmapgl\"}],\"histogram\":[{\"marker\":{\"line\":{\"color\":\"white\",\"width\":0.6}},\"type\":\"histogram\"}],\"histogram2d\":[{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"},\"colorscale\":[[0.0,\"#440154\"],[0.1111111111111111,\"#482878\"],[0.2222222222222222,\"#3e4989\"],[0.3333333333333333,\"#31688e\"],[0.4444444444444444,\"#26828e\"],[0.5555555555555556,\"#1f9e89\"],[0.6666666666666666,\"#35b779\"],[0.7777777777777778,\"#6ece58\"],[0.8888888888888888,\"#b5de2b\"],[1.0,\"#fde725\"]],\"type\":\"histogram2d\"}],\"histogram2dcontour\":[{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"},\"colorscale\":[[0.0,\"#440154\"],[0.1111111111111111,\"#482878\"],[0.2222222222222222,\"#3e4989\"],[0.3333333333333333,\"#31688e\"],[0.4444444444444444,\"#26828e\"],[0.5555555555555556,\"#1f9e89\"],[0.6666666666666666,\"#35b779\"],[0.7777777777777778,\"#6ece58\"],[0.8888888888888888,\"#b5de2b\"],[1.0,\"#fde725\"]],\"type\":\"histogram2dcontour\"}],\"mesh3d\":[{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"},\"type\":\"mesh3d\"}],\"parcoords\":[{\"line\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"type\":\"parcoords\"}],\"pie\":[{\"automargin\":true,\"type\":\"pie\"}],\"scatter\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"type\":\"scatter\"}],\"scatter3d\":[{\"line\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"marker\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"type\":\"scatter3d\"}],\"scattercarpet\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"type\":\"scattercarpet\"}],\"scattergeo\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"type\":\"scattergeo\"}],\"scattergl\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"type\":\"scattergl\"}],\"scattermapbox\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"type\":\"scattermapbox\"}],\"scatterpolar\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"type\":\"scatterpolar\"}],\"scatterpolargl\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"type\":\"scatterpolargl\"}],\"scatterternary\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"type\":\"scatterternary\"}],\"surface\":[{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"},\"colorscale\":[[0.0,\"#440154\"],[0.1111111111111111,\"#482878\"],[0.2222222222222222,\"#3e4989\"],[0.3333333333333333,\"#31688e\"],[0.4444444444444444,\"#26828e\"],[0.5555555555555556,\"#1f9e89\"],[0.6666666666666666,\"#35b779\"],[0.7777777777777778,\"#6ece58\"],[0.8888888888888888,\"#b5de2b\"],[1.0,\"#fde725\"]],\"type\":\"surface\"}],\"table\":[{\"cells\":{\"fill\":{\"color\":\"rgb(237,237,237)\"},\"line\":{\"color\":\"white\"}},\"header\":{\"fill\":{\"color\":\"rgb(217,217,217)\"},\"line\":{\"color\":\"white\"}},\"type\":\"table\"}]},\"layout\":{\"annotationdefaults\":{\"arrowhead\":0,\"arrowwidth\":1},\"autotypenumbers\":\"strict\",\"coloraxis\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"colorscale\":{\"diverging\":[[0.0,\"rgb(103,0,31)\"],[0.1,\"rgb(178,24,43)\"],[0.2,\"rgb(214,96,77)\"],[0.3,\"rgb(244,165,130)\"],[0.4,\"rgb(253,219,199)\"],[0.5,\"rgb(247,247,247)\"],[0.6,\"rgb(209,229,240)\"],[0.7,\"rgb(146,197,222)\"],[0.8,\"rgb(67,147,195)\"],[0.9,\"rgb(33,102,172)\"],[1.0,\"rgb(5,48,97)\"]],\"sequential\":[[0.0,\"#440154\"],[0.1111111111111111,\"#482878\"],[0.2222222222222222,\"#3e4989\"],[0.3333333333333333,\"#31688e\"],[0.4444444444444444,\"#26828e\"],[0.5555555555555556,\"#1f9e89\"],[0.6666666666666666,\"#35b779\"],[0.7777777777777778,\"#6ece58\"],[0.8888888888888888,\"#b5de2b\"],[1.0,\"#fde725\"]],\"sequentialminus\":[[0.0,\"#440154\"],[0.1111111111111111,\"#482878\"],[0.2222222222222222,\"#3e4989\"],[0.3333333333333333,\"#31688e\"],[0.4444444444444444,\"#26828e\"],[0.5555555555555556,\"#1f9e89\"],[0.6666666666666666,\"#35b779\"],[0.7777777777777778,\"#6ece58\"],[0.8888888888888888,\"#b5de2b\"],[1.0,\"#fde725\"]]},\"colorway\":[\"#1F77B4\",\"#FF7F0E\",\"#2CA02C\",\"#D62728\",\"#9467BD\",\"#8C564B\",\"#E377C2\",\"#7F7F7F\",\"#BCBD22\",\"#17BECF\"],\"font\":{\"color\":\"rgb(36,36,36)\"},\"geo\":{\"bgcolor\":\"white\",\"lakecolor\":\"white\",\"landcolor\":\"white\",\"showlakes\":true,\"showland\":true,\"subunitcolor\":\"white\"},\"hoverlabel\":{\"align\":\"left\"},\"hovermode\":\"closest\",\"mapbox\":{\"style\":\"light\"},\"paper_bgcolor\":\"white\",\"plot_bgcolor\":\"white\",\"polar\":{\"angularaxis\":{\"gridcolor\":\"rgb(232,232,232)\",\"linecolor\":\"rgb(36,36,36)\",\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\"},\"bgcolor\":\"white\",\"radialaxis\":{\"gridcolor\":\"rgb(232,232,232)\",\"linecolor\":\"rgb(36,36,36)\",\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\"}},\"scene\":{\"xaxis\":{\"backgroundcolor\":\"white\",\"gridcolor\":\"rgb(232,232,232)\",\"gridwidth\":2,\"linecolor\":\"rgb(36,36,36)\",\"showbackground\":true,\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\",\"zeroline\":false,\"zerolinecolor\":\"rgb(36,36,36)\"},\"yaxis\":{\"backgroundcolor\":\"white\",\"gridcolor\":\"rgb(232,232,232)\",\"gridwidth\":2,\"linecolor\":\"rgb(36,36,36)\",\"showbackground\":true,\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\",\"zeroline\":false,\"zerolinecolor\":\"rgb(36,36,36)\"},\"zaxis\":{\"backgroundcolor\":\"white\",\"gridcolor\":\"rgb(232,232,232)\",\"gridwidth\":2,\"linecolor\":\"rgb(36,36,36)\",\"showbackground\":true,\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\",\"zeroline\":false,\"zerolinecolor\":\"rgb(36,36,36)\"}},\"shapedefaults\":{\"fillcolor\":\"black\",\"line\":{\"width\":0},\"opacity\":0.3},\"ternary\":{\"aaxis\":{\"gridcolor\":\"rgb(232,232,232)\",\"linecolor\":\"rgb(36,36,36)\",\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\"},\"baxis\":{\"gridcolor\":\"rgb(232,232,232)\",\"linecolor\":\"rgb(36,36,36)\",\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\"},\"bgcolor\":\"white\",\"caxis\":{\"gridcolor\":\"rgb(232,232,232)\",\"linecolor\":\"rgb(36,36,36)\",\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\"}},\"title\":{\"x\":0.05},\"xaxis\":{\"automargin\":true,\"gridcolor\":\"rgb(232,232,232)\",\"linecolor\":\"rgb(36,36,36)\",\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\",\"title\":{\"standoff\":15},\"zeroline\":false,\"zerolinecolor\":\"rgb(36,36,36)\"},\"yaxis\":{\"automargin\":true,\"gridcolor\":\"rgb(232,232,232)\",\"linecolor\":\"rgb(36,36,36)\",\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\",\"title\":{\"standoff\":15},\"zeroline\":false,\"zerolinecolor\":\"rgb(36,36,36)\"}}},\"title\":{\"text\":\"Cl vs. Alpha\"},\"xaxis\":{\"anchor\":\"y\",\"domain\":[0.0,1.0],\"gridcolor\":\"Gray\",\"gridwidth\":1,\"linecolor\":\"black\",\"linewidth\":1,\"mirror\":false,\"range\":[-15,15],\"showgrid\":true,\"showline\":true,\"title\":{\"text\":\"Alpha [deg]\"},\"zeroline\":true,\"zerolinecolor\":\"black\",\"zerolinewidth\":2},\"yaxis\":{\"anchor\":\"x\",\"domain\":[0.0,1.0],\"gridcolor\":\"Gray\",\"gridwidth\":0.5,\"linecolor\":\"black\",\"linewidth\":1,\"mirror\":false,\"showgrid\":true,\"showline\":true,\"title\":{\"text\":\"Cl\"},\"zeroline\":true,\"zerolinecolor\":\"Gray\",\"zerolinewidth\":1}},                        {\"responsive\": true}                    ).then(function(){\n",
       "                            \n",
       "var gd = document.getElementById('fa0b3518-827a-484f-b029-b380c2aa587d');\n",
       "var x = new MutationObserver(function (mutations, observer) {{\n",
       "        var display = window.getComputedStyle(gd).display;\n",
       "        if (!display || display === 'none') {{\n",
       "            console.log([gd, 'removed!']);\n",
       "            Plotly.purge(gd);\n",
       "            observer.disconnect();\n",
       "        }}\n",
       "}});\n",
       "\n",
       "// Listen for the removal of the full notebook cells\n",
       "var notebookContainer = gd.closest('#notebook-container');\n",
       "if (notebookContainer) {{\n",
       "    x.observe(notebookContainer, {childList: true});\n",
       "}}\n",
       "\n",
       "// Listen for the clearing of the current output cell\n",
       "var outputEl = gd.closest('.output');\n",
       "if (outputEl) {{\n",
       "    x.observe(outputEl, {childList: true});\n",
       "}}\n",
       "\n",
       "                        })                };                });            </script>        </div>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "import plotly.graph_objects as go\n",
    "import glob\n",
    "import matplotlib.pyplot as plt\n",
    "import plotly.express as px\n",
    "import pandas as pd\n",
    "from plotly.graph_objects import Layout\n",
    "import os\n",
    "import plotly.io as pio\n",
    "\n",
    "def pathformach(filepath=f\"MCC0.00/\"):\n",
    "    all_files = glob.glob(filepath + \"**/00_coeff00.dat\")\n",
    "    li = [pd.read_csv(filename, index_col=None, header=0, sep='\\s+') for filename in all_files]\n",
    "    df = pd.concat(li , axis=0, ignore_index=True)\n",
    "    col_names = {'MACH':'M', 'ALPHA':'Alpha', 'C-lift':'Cl','C-drag': 'Cd', 'C-my':'Cm'}\n",
    "    df.rename(columns=col_names, inplace=True)\n",
    "    df.sort_values(['M', 'Alpha','Cd'], inplace=True)\n",
    "    return(df)\n",
    "\n",
    "def machplot(filepath,coef):\n",
    "    df=pathformach(filepath)\n",
    "    pio.templates.default = \"simple_white\"\n",
    "\n",
    "    fig= px.line(df, x=\"Alpha\", y=coef, color=\"M\",color_discrete_sequence= px.colors.sequential.Plasma_r,)\n",
    "    pio.templates.default = \"simple_white\"\n",
    "\n",
    "    fig.update_layout(\n",
    "    title= coef + \" vs. Alpha\",\n",
    "    xaxis_title=\"Alpha [deg]\", \n",
    "    yaxis_title= coef)\n",
    "    fig.update_xaxes(range=[-15, 15])\n",
    "\n",
    "    fig.update_traces(textposition='top center')\n",
    "    fig.update_xaxes(showline=True, linewidth=1, linecolor='black',\n",
    "                 mirror=False, showgrid=True, gridwidth=1, gridcolor='Gray', zeroline=True, \n",
    "                 zerolinewidth=2, zerolinecolor='black')\n",
    "    fig.update_yaxes(showline=True, linewidth=1, linecolor='black', \n",
    "                 showgrid=True, gridwidth=0.5, gridcolor='Gray', mirror=False,zeroline=True,\n",
    "                 zerolinewidth=1, zerolinecolor='Gray')\n",
    "    return fig.show()\n",
    "\n",
    "machplot(f\"MCC0.00/\",\"Cl\")"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 2,
   "id": "f8ea38bd",
   "metadata": {
    "hide_input": true,
    "scrolled": false,
    "slideshow": {
     "slide_type": "subslide"
    },
    "tags": [
     "hide-input"
    ]
   },
   "outputs": [
    {
     "data": {
      "application/vnd.plotly.v1+json": {
       "config": {
        "plotlyServerURL": "https://plot.ly"
       },
       "data": [
        {
         "hovertemplate": "M=0.2<br>Alpha=%{x}<br>Cd=%{y}<extra></extra>",
         "legendgroup": "0.2",
         "line": {
          "color": "#f0f921",
          "dash": "solid"
         },
         "mode": "lines",
         "name": "0.2",
         "orientation": "v",
         "showlegend": true,
         "textposition": "top center",
         "type": "scatter",
         "x": [
          -6,
          -5.76767677,
          -5.53535354,
          -5.3030303,
          -5.07070707,
          -4.83838384,
          -4.60606061,
          -4.37373737,
          -4.14141414,
          -3.90909091,
          -3.67676768,
          -3.44444444,
          -3.21212121,
          -2.97979798,
          -2.74747475,
          -2.51515152,
          -2.28282828,
          -2.05050505,
          -1.81818182,
          -1.58585859,
          -1.35353535,
          -1.12121212,
          -0.88888889,
          -0.65656566,
          -0.42424242,
          -0.19191919,
          0.04040404,
          0.27272727,
          0.50505051,
          0.73737374,
          0.96969697,
          1.2020202,
          1.43434343,
          1.66666667,
          1.8989899,
          2.13131313,
          2.36363636,
          2.5959596,
          2.82828283,
          3.06060606,
          3.29292929,
          3.52525253,
          3.75757576,
          3.98989899,
          4.22222222,
          4.45454545,
          4.68686869,
          4.91919192,
          5.15151515,
          5.38383838,
          5.61616162,
          5.84848485,
          6.08080808,
          6.31313131,
          6.54545455,
          6.77777778,
          7.01010101,
          7.24242424,
          7.47474747,
          7.70707071,
          7.93939394,
          8.17171717,
          8.4040404,
          8.63636364,
          8.86868687,
          9.1010101,
          9.33333333,
          9.56565657,
          9.7979798,
          10.03030303,
          10.26262626,
          10.49494949,
          10.72727273,
          10.95959596,
          11.19191919,
          11.42424242,
          11.65656566,
          11.88888889,
          12.12121212,
          12.35353535,
          12.58585859,
          12.81818182,
          13.05050505,
          13.28282828,
          13.51515152,
          13.74747475,
          13.97979798,
          14.21212121,
          14.44444444,
          14.67676768,
          14.90909091,
          15.14141414,
          15.37373737,
          15.60606061,
          15.83838384,
          16.07070707,
          16.3030303,
          16.53535354,
          16.76767677,
          17
         ],
         "xaxis": "x",
         "y": [
          0.01225065,
          0.01209318,
          0.01194392,
          0.01180329,
          0.01167175,
          0.01154967,
          0.01143696,
          0.01133322,
          0.01123771,
          0.0111494,
          0.01106762,
          0.01099217,
          0.01092318,
          0.0108614,
          0.01080697,
          0.01075797,
          0.01071264,
          0.0106719,
          0.01063748,
          0.0106111,
          0.01059449,
          0.01058939,
          0.01059738,
          0.01061663,
          0.01064164,
          0.01066677,
          0.01068636,
          0.01069795,
          0.01070669,
          0.01071885,
          0.01074072,
          0.01077753,
          0.01082825,
          0.01088961,
          0.0109583,
          0.01103114,
          0.01110723,
          0.01118756,
          0.01127318,
          0.01136514,
          0.01146397,
          0.01156923,
          0.01168038,
          0.01179687,
          0.01191841,
          0.01204584,
          0.01218034,
          0.01232308,
          0.01247509,
          0.01263554,
          0.01280236,
          0.01297346,
          0.01314687,
          0.01332715,
          0.01352358,
          0.01373007,
          0.01394279,
          0.01416215,
          0.0143924,
          0.0146317,
          0.01488103,
          0.01514689,
          0.01542093,
          0.0157002,
          0.01599353,
          0.01630111,
          0.01662236,
          0.01695807,
          0.01730941,
          0.01767158,
          0.0180444,
          0.01844241,
          0.01885663,
          0.01928447,
          0.01973683,
          0.02021193,
          0.02070334,
          0.02121393,
          0.02175247,
          0.02232776,
          0.02293727,
          0.02356377,
          0.02422789,
          0.02493927,
          0.02567173,
          0.02645719,
          0.02731298,
          0.02823163,
          0.02920663,
          0.03024305,
          0.03135575,
          0.0325681,
          0.03398966,
          0.03566924,
          0.03750454,
          0.03956883,
          0.0419715,
          0.04482739,
          0.04832784,
          0.05268291
         ],
         "yaxis": "y"
        },
        {
         "hovertemplate": "M=0.3<br>Alpha=%{x}<br>Cd=%{y}<extra></extra>",
         "legendgroup": "0.3",
         "line": {
          "color": "#fdca26",
          "dash": "solid"
         },
         "mode": "lines",
         "name": "0.3",
         "orientation": "v",
         "showlegend": true,
         "textposition": "top center",
         "type": "scatter",
         "x": [
          -6,
          -5.76767677,
          -5.53535354,
          -5.3030303,
          -5.07070707,
          -4.83838384,
          -4.60606061,
          -4.37373737,
          -4.14141414,
          -3.90909091,
          -3.67676768,
          -3.44444444,
          -3.21212121,
          -2.97979798,
          -2.74747475,
          -2.51515152,
          -2.28282828,
          -2.05050505,
          -1.81818182,
          -1.58585859,
          -1.35353535,
          -1.12121212,
          -0.88888889,
          -0.65656566,
          -0.42424242,
          -0.19191919,
          0.04040404,
          0.27272727,
          0.50505051,
          0.73737374,
          0.96969697,
          1.2020202,
          1.43434343,
          1.66666667,
          1.8989899,
          2.13131313,
          2.36363636,
          2.5959596,
          2.82828283,
          3.06060606,
          3.29292929,
          3.52525253,
          3.75757576,
          3.98989899,
          4.22222222,
          4.45454545,
          4.68686869,
          4.91919192,
          5.15151515,
          5.38383838,
          5.61616162,
          5.84848485,
          6.08080808,
          6.31313131,
          6.54545455,
          6.77777778,
          7.01010101,
          7.24242424,
          7.47474747,
          7.70707071,
          7.93939394,
          8.17171717,
          8.4040404,
          8.63636364,
          8.86868687,
          9.1010101,
          9.33333333,
          9.56565657,
          9.7979798,
          10.03030303,
          10.26262626,
          10.49494949,
          10.72727273,
          10.95959596,
          11.19191919,
          11.42424242,
          11.65656566,
          11.88888889,
          12.12121212,
          12.35353535,
          12.58585859,
          12.81818182,
          13.05050505,
          13.28282828,
          13.51515152,
          13.74747475,
          13.97979798,
          14.21212121,
          14.44444444,
          14.67676768,
          14.90909091,
          15.14141414,
          15.37373737,
          15.60606061,
          15.83838384,
          16.07070707,
          16.3030303,
          16.53535354,
          16.76767677,
          17
         ],
         "xaxis": "x",
         "y": [
          0.01163722,
          0.01147413,
          0.01132013,
          0.01117569,
          0.01104129,
          0.01091725,
          0.01080215,
          0.01069364,
          0.01059182,
          0.01049888,
          0.0104154,
          0.01033972,
          0.01027059,
          0.01020791,
          0.0101517,
          0.01010204,
          0.01005897,
          0.01002249,
          0.00999262,
          0.00996934,
          0.00995266,
          0.00994257,
          0.00993906,
          0.00994196,
          0.00995089,
          0.00996546,
          0.0099853,
          0.01001023,
          0.0100405,
          0.01007646,
          0.01011843,
          0.01016672,
          0.0102213,
          0.01028204,
          0.01034884,
          0.01042155,
          0.01050016,
          0.0105847,
          0.01067521,
          0.01077172,
          0.01087434,
          0.01098328,
          0.01109877,
          0.01122104,
          0.01135027,
          0.0114864,
          0.01162934,
          0.01177895,
          0.01193518,
          0.01209874,
          0.01227081,
          0.0124526,
          0.01264524,
          0.01284637,
          0.0130517,
          0.01326692,
          0.01349368,
          0.01372874,
          0.01396523,
          0.01421489,
          0.01448181,
          0.01475234,
          0.01503302,
          0.0153302,
          0.01563984,
          0.01596409,
          0.01630207,
          0.01665189,
          0.01701986,
          0.01740221,
          0.01779621,
          0.01821186,
          0.01864629,
          0.01909901,
          0.01957641,
          0.02007911,
          0.02060554,
          0.02115756,
          0.02173918,
          0.02235446,
          0.02300517,
          0.02369107,
          0.02442344,
          0.02520992,
          0.0260458,
          0.0269404,
          0.02791218,
          0.02898077,
          0.03015748,
          0.03145759,
          0.03291651,
          0.0345941,
          0.03655889,
          0.0388804,
          0.04163367,
          0.04493745,
          0.04892769,
          0.05378463,
          0.05981498,
          0.06735561
         ],
         "yaxis": "y"
        },
        {
         "hovertemplate": "M=0.4<br>Alpha=%{x}<br>Cd=%{y}<extra></extra>",
         "legendgroup": "0.4",
         "line": {
          "color": "#fb9f3a",
          "dash": "solid"
         },
         "mode": "lines",
         "name": "0.4",
         "orientation": "v",
         "showlegend": true,
         "textposition": "top center",
         "type": "scatter",
         "x": [
          -6,
          -5.76767677,
          -5.53535354,
          -5.3030303,
          -5.07070707,
          -4.83838384,
          -4.60606061,
          -4.37373737,
          -4.14141414,
          -3.90909091,
          -3.67676768,
          -3.44444444,
          -3.21212121,
          -2.97979798,
          -2.74747475,
          -2.51515152,
          -2.28282828,
          -2.05050505,
          -1.81818182,
          -1.58585859,
          -1.35353535,
          -1.12121212,
          -0.88888889,
          -0.65656566,
          -0.42424242,
          -0.19191919,
          0.04040404,
          0.27272727,
          0.50505051,
          0.73737374,
          0.96969697,
          1.2020202,
          1.43434343,
          1.66666667,
          1.8989899,
          2.13131313,
          2.36363636,
          2.5959596,
          2.82828283,
          3.06060606,
          3.29292929,
          3.52525253,
          3.75757576,
          3.98989899,
          4.22222222,
          4.45454545,
          4.68686869,
          4.91919192,
          5.15151515,
          5.38383838,
          5.61616162,
          5.84848485,
          6.08080808,
          6.31313131,
          6.54545455,
          6.77777778,
          7.01010101,
          7.24242424,
          7.47474747,
          7.70707071,
          7.93939394,
          8.17171717,
          8.4040404,
          8.63636364,
          8.86868687,
          9.1010101,
          9.33333333,
          9.56565657,
          9.7979798,
          10.03030303,
          10.26262626,
          10.49494949,
          10.72727273,
          10.95959596,
          11.19191919,
          11.42424242,
          11.65656566,
          11.88888889,
          12.12121212,
          12.35353535,
          12.58585859,
          12.81818182,
          13.05050505,
          13.28282828,
          13.51515152,
          13.74747475,
          13.97979798,
          14.21212121,
          14.44444444,
          14.67676768,
          14.90909091,
          15.14141414,
          15.37373737,
          15.60606061,
          15.83838384,
          16.07070707,
          16.3030303,
          16.53535354,
          16.76767677,
          17
         ],
         "xaxis": "x",
         "y": [
          0.01139713,
          0.01120696,
          0.01103136,
          0.01086916,
          0.01071921,
          0.01058036,
          0.01045193,
          0.01033349,
          0.01022457,
          0.01012469,
          0.01003345,
          0.00995053,
          0.00987563,
          0.00980841,
          0.0097486,
          0.00969619,
          0.0096512,
          0.00961352,
          0.00958301,
          0.00955951,
          0.00954287,
          0.00953296,
          0.00952963,
          0.00953279,
          0.00954245,
          0.00955859,
          0.00958122,
          0.00961032,
          0.00964586,
          0.00968777,
          0.00973603,
          0.00979059,
          0.00985151,
          0.00991883,
          0.00999264,
          0.010073,
          0.01015997,
          0.01025362,
          0.01035401,
          0.0104612,
          0.01057531,
          0.01069648,
          0.01082489,
          0.01096071,
          0.0111041,
          0.01125509,
          0.01141368,
          0.01157988,
          0.01175374,
          0.01193586,
          0.01212721,
          0.01232875,
          0.01254143,
          0.01276405,
          0.01299389,
          0.01323319,
          0.01348299,
          0.0137435,
          0.014016,
          0.01429973,
          0.01459559,
          0.014907,
          0.01523226,
          0.01556999,
          0.01592241,
          0.01629189,
          0.01667924,
          0.01708373,
          0.01750572,
          0.01794838,
          0.01841474,
          0.01890593,
          0.0194322,
          0.02001885,
          0.02070299,
          0.02153367,
          0.02256262,
          0.02381718,
          0.02530925,
          0.02705054,
          0.029061,
          0.03137037,
          0.03397616,
          0.03687954,
          0.04013382,
          0.04388771,
          0.04805455,
          0.05247681,
          0.05756547,
          0.06330455,
          0.0695248,
          0.07648436,
          0.08390437,
          0.0916152,
          0.10006728,
          0.10883361,
          0.11752242,
          0.12613119,
          0.13453565,
          0.14257238
         ],
         "yaxis": "y"
        },
        {
         "hovertemplate": "M=0.5<br>Alpha=%{x}<br>Cd=%{y}<extra></extra>",
         "legendgroup": "0.5",
         "line": {
          "color": "#ed7953",
          "dash": "solid"
         },
         "mode": "lines",
         "name": "0.5",
         "orientation": "v",
         "showlegend": true,
         "textposition": "top center",
         "type": "scatter",
         "x": [
          -5.5,
          -5.3030303,
          -5.10606061,
          -4.90909091,
          -4.71212121,
          -4.51515152,
          -4.31818182,
          -4.12121212,
          -3.92424242,
          -3.72727273,
          -3.53030303,
          -3.33333333,
          -3.13636364,
          -2.93939394,
          -2.74242424,
          -2.54545455,
          -2.34848485,
          -2.15151515,
          -1.95454545,
          -1.75757576,
          -1.56060606,
          -1.36363636,
          -1.16666667,
          -0.96969697,
          -0.77272727,
          -0.57575758,
          -0.37878788,
          -0.18181818,
          0.01515152,
          0.21212121,
          0.40909091,
          0.60606061,
          0.8030303,
          1,
          1.1969697,
          1.39393939,
          1.59090909,
          1.78787879,
          1.98484848,
          2.18181818,
          2.37878788,
          2.57575758,
          2.77272727,
          2.96969697,
          3.16666667,
          3.36363636,
          3.56060606,
          3.75757576,
          3.95454545,
          4.15151515,
          4.34848485,
          4.54545455,
          4.74242424,
          4.93939394,
          5.13636364,
          5.33333333,
          5.53030303,
          5.72727273,
          5.92424242,
          6.12121212,
          6.31818182,
          6.51515152,
          6.71212121,
          6.90909091,
          7.10606061,
          7.3030303,
          7.5,
          7.6969697,
          7.89393939,
          8.09090909,
          8.28787879,
          8.48484848,
          8.68181818,
          8.87878788,
          9.07575758,
          9.27272727,
          9.46969697,
          9.66666667,
          9.86363636,
          10.06060606,
          10.25757576,
          10.45454545,
          10.65151515,
          10.84848485,
          11.04545455,
          11.24242424,
          11.43939394,
          11.63636364,
          11.83333333,
          12.03030303,
          12.22727273,
          12.42424242,
          12.62121212,
          12.81818182,
          13.01515152,
          13.21212121,
          13.40909091,
          13.60606061,
          13.8030303,
          14
         ],
         "xaxis": "x",
         "y": [
          0.01371416,
          0.01270822,
          0.01189516,
          0.01125661,
          0.0107742,
          0.01042958,
          0.01020138,
          0.01005317,
          0.00994414,
          0.00984915,
          0.00976424,
          0.00968717,
          0.00961714,
          0.0095539,
          0.00949727,
          0.00944712,
          0.00940333,
          0.00936559,
          0.00933352,
          0.00930693,
          0.00928607,
          0.0092712,
          0.00926219,
          0.00925871,
          0.00926049,
          0.00926754,
          0.00927989,
          0.00929758,
          0.00932065,
          0.00934911,
          0.00938294,
          0.0094221,
          0.00946658,
          0.00951632,
          0.00957132,
          0.00963161,
          0.00969728,
          0.00976837,
          0.00984497,
          0.00992713,
          0.01001492,
          0.01010843,
          0.01020771,
          0.01031284,
          0.01042391,
          0.01054105,
          0.01066443,
          0.01079423,
          0.0109306,
          0.01107371,
          0.01122367,
          0.01138057,
          0.0115445,
          0.01171554,
          0.01189382,
          0.01207993,
          0.01227472,
          0.01247905,
          0.01269379,
          0.01291985,
          0.01315909,
          0.01342017,
          0.01373035,
          0.01411816,
          0.01460998,
          0.0152271,
          0.0159845,
          0.01689041,
          0.01795021,
          0.01916796,
          0.02054756,
          0.02209239,
          0.02380385,
          0.02567702,
          0.02769986,
          0.02986326,
          0.03216596,
          0.03462689,
          0.03726369,
          0.04008045,
          0.04306854,
          0.04620789,
          0.0495362,
          0.05307373,
          0.05675539,
          0.06053447,
          0.0644214,
          0.06843281,
          0.07257714,
          0.07685788,
          0.08127844,
          0.08583532,
          0.09043313,
          0.09498016,
          0.09958346,
          0.10432483,
          0.10909516,
          0.11382484,
          0.11851221,
          0.12315785
         ],
         "yaxis": "y"
        },
        {
         "hovertemplate": "M=0.6<br>Alpha=%{x}<br>Cd=%{y}<extra></extra>",
         "legendgroup": "0.6",
         "line": {
          "color": "#d8576b",
          "dash": "solid"
         },
         "mode": "lines",
         "name": "0.6",
         "orientation": "v",
         "showlegend": true,
         "textposition": "top center",
         "type": "scatter",
         "x": [
          -6,
          -5.86262626,
          -5.72525253,
          -5.58787879,
          -5.45050505,
          -5.31313131,
          -5.17575758,
          -5.03838384,
          -4.9010101,
          -4.76363636,
          -4.62626263,
          -4.48888889,
          -4.35151515,
          -4.21414141,
          -4.07676768,
          -3.93939394,
          -3.8020202,
          -3.66464646,
          -3.52727273,
          -3.38989899,
          -3.25252525,
          -3.11515152,
          -2.97777778,
          -2.84040404,
          -2.7030303,
          -2.56565657,
          -2.42828283,
          -2.29090909,
          -2.15353535,
          -2.01616162,
          -1.87878788,
          -1.74141414,
          -1.6040404,
          -1.46666667,
          -1.32929293,
          -1.19191919,
          -1.05454545,
          -0.91717172,
          -0.77979798,
          -0.64242424,
          -0.50505051,
          -0.36767677,
          -0.23030303,
          -0.09292929,
          0.04444444,
          0.18181818,
          0.31919192,
          0.45656566,
          0.59393939,
          0.73131313,
          0.86868687,
          1.00606061,
          1.14343434,
          1.28080808,
          1.41818182,
          1.55555556,
          1.69292929,
          1.83030303,
          1.96767677,
          2.10505051,
          2.24242424,
          2.37979798,
          2.51717172,
          2.65454545,
          2.79191919,
          2.92929293,
          3.06666667,
          3.2040404,
          3.34141414,
          3.47878788,
          3.61616162,
          3.75353535,
          3.89090909,
          4.02828283,
          4.16565657,
          4.3030303,
          4.44040404,
          4.57777778,
          4.71515152,
          4.85252525,
          4.98989899,
          5.12727273,
          5.26464646,
          5.4020202,
          5.53939394,
          5.67676768,
          5.81414141,
          5.95151515,
          6.08888889,
          6.22626263,
          6.36363636,
          6.5010101,
          6.63838384,
          6.77575758,
          6.91313131,
          7.05050505,
          7.18787879,
          7.32525253,
          7.46262626,
          7.6
         ],
         "xaxis": "x",
         "y": [
          0.02891662,
          0.02732834,
          0.02584121,
          0.02444658,
          0.02313581,
          0.02190027,
          0.02073131,
          0.0196203,
          0.01855916,
          0.01754529,
          0.01657915,
          0.01566122,
          0.01479305,
          0.01397949,
          0.01322605,
          0.01253817,
          0.01191921,
          0.01137012,
          0.01089167,
          0.01048438,
          0.01014654,
          0.00987548,
          0.0096685,
          0.00952008,
          0.00941768,
          0.00934767,
          0.0092967,
          0.00925679,
          0.00922507,
          0.00919886,
          0.00917581,
          0.00915559,
          0.00913854,
          0.00912502,
          0.00911523,
          0.00910905,
          0.00910634,
          0.00910697,
          0.00911083,
          0.00911789,
          0.00912811,
          0.00914145,
          0.00915786,
          0.0091773,
          0.00919973,
          0.00922521,
          0.00925394,
          0.00928612,
          0.00932197,
          0.0093617,
          0.00940553,
          0.00945367,
          0.00950616,
          0.0095625,
          0.00962205,
          0.00968415,
          0.00974818,
          0.00981349,
          0.00987945,
          0.00994613,
          0.01001965,
          0.0101091,
          0.01022358,
          0.0103722,
          0.01056408,
          0.01080833,
          0.0111139,
          0.01148612,
          0.01192656,
          0.01243658,
          0.01301758,
          0.01367094,
          0.01439802,
          0.01520022,
          0.01607763,
          0.01702754,
          0.0180469,
          0.01913265,
          0.0202817,
          0.02149099,
          0.02275746,
          0.02407836,
          0.02545251,
          0.02687924,
          0.02835787,
          0.02988771,
          0.03146809,
          0.03309833,
          0.03477842,
          0.03651664,
          0.03832679,
          0.04021868,
          0.0421976,
          0.04426504,
          0.04641612,
          0.04864517,
          0.05094231,
          0.05329165,
          0.05567685,
          0.05808157
         ],
         "yaxis": "y"
        },
        {
         "hovertemplate": "M=0.7<br>Alpha=%{x}<br>Cd=%{y}<extra></extra>",
         "legendgroup": "0.7",
         "line": {
          "color": "#bd3786",
          "dash": "solid"
         },
         "mode": "lines",
         "name": "0.7",
         "orientation": "v",
         "showlegend": true,
         "textposition": "top center",
         "type": "scatter",
         "x": [
          -6,
          -5.86868687,
          -5.73737374,
          -5.60606061,
          -5.47474747,
          -5.34343434,
          -5.21212121,
          -5.08080808,
          -4.94949495,
          -4.81818182,
          -4.68686869,
          -4.55555556,
          -4.42424242,
          -4.29292929,
          -4.16161616,
          -4.03030303,
          -3.8989899,
          -3.76767677,
          -3.63636364,
          -3.50505051,
          -3.37373737,
          -3.24242424,
          -3.11111111,
          -2.97979798,
          -2.84848485,
          -2.71717172,
          -2.58585859,
          -2.45454545,
          -2.32323232,
          -2.19191919,
          -2.06060606,
          -1.92929293,
          -1.7979798,
          -1.66666667,
          -1.53535354,
          -1.4040404,
          -1.27272727,
          -1.14141414,
          -1.01010101,
          -0.87878788,
          -0.74747475,
          -0.61616162,
          -0.48484848,
          -0.35353535,
          -0.22222222,
          -0.09090909,
          0.04040404,
          0.17171717,
          0.3030303,
          0.43434343,
          0.56565657,
          0.6969697,
          0.82828283,
          0.95959596,
          1.09090909,
          1.22222222,
          1.35353535,
          1.48484848,
          1.61616162,
          1.74747475,
          1.87878788,
          2.01010101,
          2.14141414,
          2.27272727,
          2.4040404,
          2.53535354,
          2.66666667,
          2.7979798,
          2.92929293,
          3.06060606,
          3.19191919,
          3.32323232,
          3.45454545,
          3.58585859,
          3.71717172,
          3.84848485,
          3.97979798,
          4.11111111,
          4.24242424,
          4.37373737,
          4.50505051,
          4.63636364,
          4.76767677,
          4.8989899,
          5.03030303,
          5.16161616,
          5.29292929,
          5.42424242,
          5.55555556,
          5.68686869,
          5.81818182,
          5.94949495,
          6.08080808,
          6.21212121,
          6.34343434,
          6.47474747,
          6.60606061,
          6.73737374,
          6.86868687,
          7
         ],
         "xaxis": "x",
         "y": [
          0.0486028,
          0.04633352,
          0.04403339,
          0.04171795,
          0.03940277,
          0.03710341,
          0.03483542,
          0.03261436,
          0.03045577,
          0.02837364,
          0.02637998,
          0.02448662,
          0.02270596,
          0.02105944,
          0.01957595,
          0.01828457,
          0.01720879,
          0.01632643,
          0.01559297,
          0.01496376,
          0.01439772,
          0.01386975,
          0.01335929,
          0.01284579,
          0.01231898,
          0.01179484,
          0.01129344,
          0.01083471,
          0.01043149,
          0.01008597,
          0.00979947,
          0.00957307,
          0.00940318,
          0.00928198,
          0.00920153,
          0.00915385,
          0.00913098,
          0.00912496,
          0.00912783,
          0.00913361,
          0.0091463,
          0.00917305,
          0.00922101,
          0.00929734,
          0.00940917,
          0.00956366,
          0.00976796,
          0.01002847,
          0.01035042,
          0.01073892,
          0.01119909,
          0.01173604,
          0.01235487,
          0.01306071,
          0.01385819,
          0.01474704,
          0.01572404,
          0.0167859,
          0.01792936,
          0.01915113,
          0.02044795,
          0.02181654,
          0.0232525,
          0.02474786,
          0.02629397,
          0.02788213,
          0.02950369,
          0.03114998,
          0.03281231,
          0.03448218,
          0.03615541,
          0.03783264,
          0.03951474,
          0.04120261,
          0.04289711,
          0.04459913,
          0.04630955,
          0.04802916,
          0.04975825,
          0.05149686,
          0.05324506,
          0.05500292,
          0.0567705,
          0.05854785,
          0.06033505,
          0.06213251,
          0.06394139,
          0.06576292,
          0.06759836,
          0.06944894,
          0.0713159,
          0.07320048,
          0.07510376,
          0.07702426,
          0.07895871,
          0.08090597,
          0.08286834,
          0.08484841,
          0.08684876,
          0.088872
         ],
         "yaxis": "y"
        },
        {
         "hovertemplate": "M=0.75<br>Alpha=%{x}<br>Cd=%{y}<extra></extra>",
         "legendgroup": "0.75",
         "line": {
          "color": "#9c179e",
          "dash": "solid"
         },
         "mode": "lines",
         "name": "0.75",
         "orientation": "v",
         "showlegend": true,
         "textposition": "top center",
         "type": "scatter",
         "x": [
          -6,
          -5.87272727,
          -5.74545455,
          -5.61818182,
          -5.49090909,
          -5.36363636,
          -5.23636364,
          -5.10909091,
          -4.98181818,
          -4.85454545,
          -4.72727273,
          -4.6,
          -4.47272727,
          -4.34545455,
          -4.21818182,
          -4.09090909,
          -3.96363636,
          -3.83636364,
          -3.70909091,
          -3.58181818,
          -3.45454545,
          -3.32727273,
          -3.2,
          -3.07272727,
          -2.94545455,
          -2.81818182,
          -2.69090909,
          -2.56363636,
          -2.43636364,
          -2.30909091,
          -2.18181818,
          -2.05454545,
          -1.92727273,
          -1.8,
          -1.67272727,
          -1.54545455,
          -1.41818182,
          -1.29090909,
          -1.16363636,
          -1.03636364,
          -0.90909091,
          -0.78181818,
          -0.65454545,
          -0.52727273,
          -0.4,
          -0.27272727,
          -0.14545455,
          -0.01818182,
          0.10909091,
          0.23636364,
          0.36363636,
          0.49090909,
          0.61818182,
          0.74545455,
          0.87272727,
          1,
          1.12727273,
          1.25454545,
          1.38181818,
          1.50909091,
          1.63636364,
          1.76363636,
          1.89090909,
          2.01818182,
          2.14545455,
          2.27272727,
          2.4,
          2.52727273,
          2.65454545,
          2.78181818,
          2.90909091,
          3.03636364,
          3.16363636,
          3.29090909,
          3.41818182,
          3.54545455,
          3.67272727,
          3.8,
          3.92727273,
          4.05454545,
          4.18181818,
          4.30909091,
          4.43636364,
          4.56363636,
          4.69090909,
          4.81818182,
          4.94545455,
          5.07272727,
          5.2,
          5.32727273,
          5.45454545,
          5.58181818,
          5.70909091,
          5.83636364,
          5.96363636,
          6.09090909,
          6.21818182,
          6.34545455,
          6.47272727,
          6.6
         ],
         "xaxis": "x",
         "y": [
          0.06250026,
          0.0604718,
          0.05844354,
          0.0564152,
          0.05438647,
          0.05235707,
          0.0503267,
          0.04829506,
          0.04626186,
          0.04422262,
          0.04216196,
          0.04006268,
          0.03790769,
          0.03569186,
          0.03343573,
          0.03116314,
          0.02889794,
          0.02666304,
          0.02447975,
          0.02236918,
          0.02035247,
          0.01845133,
          0.01668831,
          0.01508602,
          0.01366723,
          0.01246007,
          0.0114991,
          0.01081928,
          0.01045243,
          0.01035815,
          0.01042379,
          0.01053359,
          0.01057643,
          0.01051911,
          0.01039315,
          0.010232,
          0.01006913,
          0.009938,
          0.00987208,
          0.00990481,
          0.01006728,
          0.01036709,
          0.01079851,
          0.01135567,
          0.0120327,
          0.01282372,
          0.01372285,
          0.01472423,
          0.01582187,
          0.01700912,
          0.01827907,
          0.0196248,
          0.02103941,
          0.02251598,
          0.02404761,
          0.02562739,
          0.02724771,
          0.02889817,
          0.0305677,
          0.03224521,
          0.0339196,
          0.03557979,
          0.03721469,
          0.03881324,
          0.0403698,
          0.04189311,
          0.04339421,
          0.04488412,
          0.04637097,
          0.04785667,
          0.04934233,
          0.05082906,
          0.05231841,
          0.05381269,
          0.05531427,
          0.05682553,
          0.0583477,
          0.05988037,
          0.06142301,
          0.0629751,
          0.06453693,
          0.06610978,
          0.06769496,
          0.06929377,
          0.07090688,
          0.07253436,
          0.07417621,
          0.07583253,
          0.07750404,
          0.07919206,
          0.08089789,
          0.08262283,
          0.08436786,
          0.08613375,
          0.08792127,
          0.08973116,
          0.0915639,
          0.09341984,
          0.09529932,
          0.09720267
         ],
         "yaxis": "y"
        },
        {
         "hovertemplate": "M=0.8<br>Alpha=%{x}<br>Cd=%{y}<extra></extra>",
         "legendgroup": "0.8",
         "line": {
          "color": "#7201a8",
          "dash": "solid"
         },
         "mode": "lines",
         "name": "0.8",
         "orientation": "v",
         "showlegend": true,
         "textposition": "top center",
         "type": "scatter",
         "x": [
          -6,
          -5.86868687,
          -5.73737374,
          -5.60606061,
          -5.47474747,
          -5.34343434,
          -5.21212121,
          -5.08080808,
          -4.94949495,
          -4.81818182,
          -4.68686869,
          -4.55555556,
          -4.42424242,
          -4.29292929,
          -4.16161616,
          -4.03030303,
          -3.8989899,
          -3.76767677,
          -3.63636364,
          -3.50505051,
          -3.37373737,
          -3.24242424,
          -3.11111111,
          -2.97979798,
          -2.84848485,
          -2.71717172,
          -2.58585859,
          -2.45454545,
          -2.32323232,
          -2.19191919,
          -2.06060606,
          -1.92929293,
          -1.7979798,
          -1.66666667,
          -1.53535354,
          -1.4040404,
          -1.27272727,
          -1.14141414,
          -1.01010101,
          -0.87878788,
          -0.74747475,
          -0.61616162,
          -0.48484848,
          -0.35353535,
          -0.22222222,
          -0.09090909,
          0.04040404,
          0.17171717,
          0.3030303,
          0.43434343,
          0.56565657,
          0.6969697,
          0.82828283,
          0.95959596,
          1.09090909,
          1.22222222,
          1.35353535,
          1.48484848,
          1.61616162,
          1.74747475,
          1.87878788,
          2.01010101,
          2.14141414,
          2.27272727,
          2.4040404,
          2.53535354,
          2.66666667,
          2.7979798,
          2.92929293,
          3.06060606,
          3.19191919,
          3.32323232,
          3.45454545,
          3.58585859,
          3.71717172,
          3.84848485,
          3.97979798,
          4.11111111,
          4.24242424,
          4.37373737,
          4.50505051,
          4.63636364,
          4.76767677,
          4.8989899,
          5.03030303,
          5.16161616,
          5.29292929,
          5.42424242,
          5.55555556,
          5.68686869,
          5.81818182,
          5.94949495,
          6.08080808,
          6.21212121,
          6.34343434,
          6.47474747,
          6.60606061,
          6.73737374,
          6.86868687,
          7
         ],
         "xaxis": "x",
         "y": [
          0.07382993,
          0.07177379,
          0.06974726,
          0.06774681,
          0.06576889,
          0.06381376,
          0.06189025,
          0.06000168,
          0.05813976,
          0.05629475,
          0.05445665,
          0.05261645,
          0.05076717,
          0.04891735,
          0.04708816,
          0.04530116,
          0.04357157,
          0.04186304,
          0.04011403,
          0.03826283,
          0.03626405,
          0.03414559,
          0.03195594,
          0.02974354,
          0.02754857,
          0.02539023,
          0.02328439,
          0.0212476,
          0.01933241,
          0.01764528,
          0.01629712,
          0.01539445,
          0.01495924,
          0.01493699,
          0.01527043,
          0.01590231,
          0.01677536,
          0.01783233,
          0.01901597,
          0.02027561,
          0.02159393,
          0.0229641,
          0.02437928,
          0.02583261,
          0.02731728,
          0.02882643,
          0.03035324,
          0.03189113,
          0.03343397,
          0.03497569,
          0.0365102,
          0.03803141,
          0.03953324,
          0.04100961,
          0.04245517,
          0.04387256,
          0.0452692,
          0.04665257,
          0.04803015,
          0.04940944,
          0.05079792,
          0.05220308,
          0.05363016,
          0.05507731,
          0.05654125,
          0.05801872,
          0.05950808,
          0.06101066,
          0.06252812,
          0.06406209,
          0.0656136,
          0.06718304,
          0.06877074,
          0.0703769,
          0.0719998,
          0.07363643,
          0.07528378,
          0.07693997,
          0.07861044,
          0.0803035,
          0.0820275,
          0.08378737,
          0.08557602,
          0.08738367,
          0.08920057,
          0.0910213,
          0.09284928,
          0.09469025,
          0.09655575,
          0.09845898,
          0.10040786,
          0.1023815,
          0.10435199,
          0.10632816,
          0.10834575,
          0.11041909,
          0.11252824,
          0.11465027,
          0.11676222,
          0.11884117
         ],
         "yaxis": "y"
        }
       ],
       "layout": {
        "legend": {
         "title": {
          "text": "M"
         },
         "tracegroupgap": 0
        },
        "margin": {
         "t": 60
        },
        "template": {
         "data": {
          "bar": [
           {
            "error_x": {
             "color": "rgb(36,36,36)"
            },
            "error_y": {
             "color": "rgb(36,36,36)"
            },
            "marker": {
             "line": {
              "color": "white",
              "width": 0.5
             },
             "pattern": {
              "fillmode": "overlay",
              "size": 10,
              "solidity": 0.2
             }
            },
            "type": "bar"
           }
          ],
          "barpolar": [
           {
            "marker": {
             "line": {
              "color": "white",
              "width": 0.5
             },
             "pattern": {
              "fillmode": "overlay",
              "size": 10,
              "solidity": 0.2
             }
            },
            "type": "barpolar"
           }
          ],
          "carpet": [
           {
            "aaxis": {
             "endlinecolor": "rgb(36,36,36)",
             "gridcolor": "white",
             "linecolor": "white",
             "minorgridcolor": "white",
             "startlinecolor": "rgb(36,36,36)"
            },
            "baxis": {
             "endlinecolor": "rgb(36,36,36)",
             "gridcolor": "white",
             "linecolor": "white",
             "minorgridcolor": "white",
             "startlinecolor": "rgb(36,36,36)"
            },
            "type": "carpet"
           }
          ],
          "choropleth": [
           {
            "colorbar": {
             "outlinewidth": 1,
             "tickcolor": "rgb(36,36,36)",
             "ticks": "outside"
            },
            "type": "choropleth"
           }
          ],
          "contour": [
           {
            "colorbar": {
             "outlinewidth": 1,
             "tickcolor": "rgb(36,36,36)",
             "ticks": "outside"
            },
            "colorscale": [
             [
              0,
              "#440154"
             ],
             [
              0.1111111111111111,
              "#482878"
             ],
             [
              0.2222222222222222,
              "#3e4989"
             ],
             [
              0.3333333333333333,
              "#31688e"
             ],
             [
              0.4444444444444444,
              "#26828e"
             ],
             [
              0.5555555555555556,
              "#1f9e89"
             ],
             [
              0.6666666666666666,
              "#35b779"
             ],
             [
              0.7777777777777778,
              "#6ece58"
             ],
             [
              0.8888888888888888,
              "#b5de2b"
             ],
             [
              1,
              "#fde725"
             ]
            ],
            "type": "contour"
           }
          ],
          "contourcarpet": [
           {
            "colorbar": {
             "outlinewidth": 1,
             "tickcolor": "rgb(36,36,36)",
             "ticks": "outside"
            },
            "type": "contourcarpet"
           }
          ],
          "heatmap": [
           {
            "colorbar": {
             "outlinewidth": 1,
             "tickcolor": "rgb(36,36,36)",
             "ticks": "outside"
            },
            "colorscale": [
             [
              0,
              "#440154"
             ],
             [
              0.1111111111111111,
              "#482878"
             ],
             [
              0.2222222222222222,
              "#3e4989"
             ],
             [
              0.3333333333333333,
              "#31688e"
             ],
             [
              0.4444444444444444,
              "#26828e"
             ],
             [
              0.5555555555555556,
              "#1f9e89"
             ],
             [
              0.6666666666666666,
              "#35b779"
             ],
             [
              0.7777777777777778,
              "#6ece58"
             ],
             [
              0.8888888888888888,
              "#b5de2b"
             ],
             [
              1,
              "#fde725"
             ]
            ],
            "type": "heatmap"
           }
          ],
          "heatmapgl": [
           {
            "colorbar": {
             "outlinewidth": 1,
             "tickcolor": "rgb(36,36,36)",
             "ticks": "outside"
            },
            "colorscale": [
             [
              0,
              "#440154"
             ],
             [
              0.1111111111111111,
              "#482878"
             ],
             [
              0.2222222222222222,
              "#3e4989"
             ],
             [
              0.3333333333333333,
              "#31688e"
             ],
             [
              0.4444444444444444,
              "#26828e"
             ],
             [
              0.5555555555555556,
              "#1f9e89"
             ],
             [
              0.6666666666666666,
              "#35b779"
             ],
             [
              0.7777777777777778,
              "#6ece58"
             ],
             [
              0.8888888888888888,
              "#b5de2b"
             ],
             [
              1,
              "#fde725"
             ]
            ],
            "type": "heatmapgl"
           }
          ],
          "histogram": [
           {
            "marker": {
             "line": {
              "color": "white",
              "width": 0.6
             }
            },
            "type": "histogram"
           }
          ],
          "histogram2d": [
           {
            "colorbar": {
             "outlinewidth": 1,
             "tickcolor": "rgb(36,36,36)",
             "ticks": "outside"
            },
            "colorscale": [
             [
              0,
              "#440154"
             ],
             [
              0.1111111111111111,
              "#482878"
             ],
             [
              0.2222222222222222,
              "#3e4989"
             ],
             [
              0.3333333333333333,
              "#31688e"
             ],
             [
              0.4444444444444444,
              "#26828e"
             ],
             [
              0.5555555555555556,
              "#1f9e89"
             ],
             [
              0.6666666666666666,
              "#35b779"
             ],
             [
              0.7777777777777778,
              "#6ece58"
             ],
             [
              0.8888888888888888,
              "#b5de2b"
             ],
             [
              1,
              "#fde725"
             ]
            ],
            "type": "histogram2d"
           }
          ],
          "histogram2dcontour": [
           {
            "colorbar": {
             "outlinewidth": 1,
             "tickcolor": "rgb(36,36,36)",
             "ticks": "outside"
            },
            "colorscale": [
             [
              0,
              "#440154"
             ],
             [
              0.1111111111111111,
              "#482878"
             ],
             [
              0.2222222222222222,
              "#3e4989"
             ],
             [
              0.3333333333333333,
              "#31688e"
             ],
             [
              0.4444444444444444,
              "#26828e"
             ],
             [
              0.5555555555555556,
              "#1f9e89"
             ],
             [
              0.6666666666666666,
              "#35b779"
             ],
             [
              0.7777777777777778,
              "#6ece58"
             ],
             [
              0.8888888888888888,
              "#b5de2b"
             ],
             [
              1,
              "#fde725"
             ]
            ],
            "type": "histogram2dcontour"
           }
          ],
          "mesh3d": [
           {
            "colorbar": {
             "outlinewidth": 1,
             "tickcolor": "rgb(36,36,36)",
             "ticks": "outside"
            },
            "type": "mesh3d"
           }
          ],
          "parcoords": [
           {
            "line": {
             "colorbar": {
              "outlinewidth": 1,
              "tickcolor": "rgb(36,36,36)",
              "ticks": "outside"
             }
            },
            "type": "parcoords"
           }
          ],
          "pie": [
           {
            "automargin": true,
            "type": "pie"
           }
          ],
          "scatter": [
           {
            "marker": {
             "colorbar": {
              "outlinewidth": 1,
              "tickcolor": "rgb(36,36,36)",
              "ticks": "outside"
             }
            },
            "type": "scatter"
           }
          ],
          "scatter3d": [
           {
            "line": {
             "colorbar": {
              "outlinewidth": 1,
              "tickcolor": "rgb(36,36,36)",
              "ticks": "outside"
             }
            },
            "marker": {
             "colorbar": {
              "outlinewidth": 1,
              "tickcolor": "rgb(36,36,36)",
              "ticks": "outside"
             }
            },
            "type": "scatter3d"
           }
          ],
          "scattercarpet": [
           {
            "marker": {
             "colorbar": {
              "outlinewidth": 1,
              "tickcolor": "rgb(36,36,36)",
              "ticks": "outside"
             }
            },
            "type": "scattercarpet"
           }
          ],
          "scattergeo": [
           {
            "marker": {
             "colorbar": {
              "outlinewidth": 1,
              "tickcolor": "rgb(36,36,36)",
              "ticks": "outside"
             }
            },
            "type": "scattergeo"
           }
          ],
          "scattergl": [
           {
            "marker": {
             "colorbar": {
              "outlinewidth": 1,
              "tickcolor": "rgb(36,36,36)",
              "ticks": "outside"
             }
            },
            "type": "scattergl"
           }
          ],
          "scattermapbox": [
           {
            "marker": {
             "colorbar": {
              "outlinewidth": 1,
              "tickcolor": "rgb(36,36,36)",
              "ticks": "outside"
             }
            },
            "type": "scattermapbox"
           }
          ],
          "scatterpolar": [
           {
            "marker": {
             "colorbar": {
              "outlinewidth": 1,
              "tickcolor": "rgb(36,36,36)",
              "ticks": "outside"
             }
            },
            "type": "scatterpolar"
           }
          ],
          "scatterpolargl": [
           {
            "marker": {
             "colorbar": {
              "outlinewidth": 1,
              "tickcolor": "rgb(36,36,36)",
              "ticks": "outside"
             }
            },
            "type": "scatterpolargl"
           }
          ],
          "scatterternary": [
           {
            "marker": {
             "colorbar": {
              "outlinewidth": 1,
              "tickcolor": "rgb(36,36,36)",
              "ticks": "outside"
             }
            },
            "type": "scatterternary"
           }
          ],
          "surface": [
           {
            "colorbar": {
             "outlinewidth": 1,
             "tickcolor": "rgb(36,36,36)",
             "ticks": "outside"
            },
            "colorscale": [
             [
              0,
              "#440154"
             ],
             [
              0.1111111111111111,
              "#482878"
             ],
             [
              0.2222222222222222,
              "#3e4989"
             ],
             [
              0.3333333333333333,
              "#31688e"
             ],
             [
              0.4444444444444444,
              "#26828e"
             ],
             [
              0.5555555555555556,
              "#1f9e89"
             ],
             [
              0.6666666666666666,
              "#35b779"
             ],
             [
              0.7777777777777778,
              "#6ece58"
             ],
             [
              0.8888888888888888,
              "#b5de2b"
             ],
             [
              1,
              "#fde725"
             ]
            ],
            "type": "surface"
           }
          ],
          "table": [
           {
            "cells": {
             "fill": {
              "color": "rgb(237,237,237)"
             },
             "line": {
              "color": "white"
             }
            },
            "header": {
             "fill": {
              "color": "rgb(217,217,217)"
             },
             "line": {
              "color": "white"
             }
            },
            "type": "table"
           }
          ]
         },
         "layout": {
          "annotationdefaults": {
           "arrowhead": 0,
           "arrowwidth": 1
          },
          "autotypenumbers": "strict",
          "coloraxis": {
           "colorbar": {
            "outlinewidth": 1,
            "tickcolor": "rgb(36,36,36)",
            "ticks": "outside"
           }
          },
          "colorscale": {
           "diverging": [
            [
             0,
             "rgb(103,0,31)"
            ],
            [
             0.1,
             "rgb(178,24,43)"
            ],
            [
             0.2,
             "rgb(214,96,77)"
            ],
            [
             0.3,
             "rgb(244,165,130)"
            ],
            [
             0.4,
             "rgb(253,219,199)"
            ],
            [
             0.5,
             "rgb(247,247,247)"
            ],
            [
             0.6,
             "rgb(209,229,240)"
            ],
            [
             0.7,
             "rgb(146,197,222)"
            ],
            [
             0.8,
             "rgb(67,147,195)"
            ],
            [
             0.9,
             "rgb(33,102,172)"
            ],
            [
             1,
             "rgb(5,48,97)"
            ]
           ],
           "sequential": [
            [
             0,
             "#440154"
            ],
            [
             0.1111111111111111,
             "#482878"
            ],
            [
             0.2222222222222222,
             "#3e4989"
            ],
            [
             0.3333333333333333,
             "#31688e"
            ],
            [
             0.4444444444444444,
             "#26828e"
            ],
            [
             0.5555555555555556,
             "#1f9e89"
            ],
            [
             0.6666666666666666,
             "#35b779"
            ],
            [
             0.7777777777777778,
             "#6ece58"
            ],
            [
             0.8888888888888888,
             "#b5de2b"
            ],
            [
             1,
             "#fde725"
            ]
           ],
           "sequentialminus": [
            [
             0,
             "#440154"
            ],
            [
             0.1111111111111111,
             "#482878"
            ],
            [
             0.2222222222222222,
             "#3e4989"
            ],
            [
             0.3333333333333333,
             "#31688e"
            ],
            [
             0.4444444444444444,
             "#26828e"
            ],
            [
             0.5555555555555556,
             "#1f9e89"
            ],
            [
             0.6666666666666666,
             "#35b779"
            ],
            [
             0.7777777777777778,
             "#6ece58"
            ],
            [
             0.8888888888888888,
             "#b5de2b"
            ],
            [
             1,
             "#fde725"
            ]
           ]
          },
          "colorway": [
           "#1F77B4",
           "#FF7F0E",
           "#2CA02C",
           "#D62728",
           "#9467BD",
           "#8C564B",
           "#E377C2",
           "#7F7F7F",
           "#BCBD22",
           "#17BECF"
          ],
          "font": {
           "color": "rgb(36,36,36)"
          },
          "geo": {
           "bgcolor": "white",
           "lakecolor": "white",
           "landcolor": "white",
           "showlakes": true,
           "showland": true,
           "subunitcolor": "white"
          },
          "hoverlabel": {
           "align": "left"
          },
          "hovermode": "closest",
          "mapbox": {
           "style": "light"
          },
          "paper_bgcolor": "white",
          "plot_bgcolor": "white",
          "polar": {
           "angularaxis": {
            "gridcolor": "rgb(232,232,232)",
            "linecolor": "rgb(36,36,36)",
            "showgrid": false,
            "showline": true,
            "ticks": "outside"
           },
           "bgcolor": "white",
           "radialaxis": {
            "gridcolor": "rgb(232,232,232)",
            "linecolor": "rgb(36,36,36)",
            "showgrid": false,
            "showline": true,
            "ticks": "outside"
           }
          },
          "scene": {
           "xaxis": {
            "backgroundcolor": "white",
            "gridcolor": "rgb(232,232,232)",
            "gridwidth": 2,
            "linecolor": "rgb(36,36,36)",
            "showbackground": true,
            "showgrid": false,
            "showline": true,
            "ticks": "outside",
            "zeroline": false,
            "zerolinecolor": "rgb(36,36,36)"
           },
           "yaxis": {
            "backgroundcolor": "white",
            "gridcolor": "rgb(232,232,232)",
            "gridwidth": 2,
            "linecolor": "rgb(36,36,36)",
            "showbackground": true,
            "showgrid": false,
            "showline": true,
            "ticks": "outside",
            "zeroline": false,
            "zerolinecolor": "rgb(36,36,36)"
           },
           "zaxis": {
            "backgroundcolor": "white",
            "gridcolor": "rgb(232,232,232)",
            "gridwidth": 2,
            "linecolor": "rgb(36,36,36)",
            "showbackground": true,
            "showgrid": false,
            "showline": true,
            "ticks": "outside",
            "zeroline": false,
            "zerolinecolor": "rgb(36,36,36)"
           }
          },
          "shapedefaults": {
           "fillcolor": "black",
           "line": {
            "width": 0
           },
           "opacity": 0.3
          },
          "ternary": {
           "aaxis": {
            "gridcolor": "rgb(232,232,232)",
            "linecolor": "rgb(36,36,36)",
            "showgrid": false,
            "showline": true,
            "ticks": "outside"
           },
           "baxis": {
            "gridcolor": "rgb(232,232,232)",
            "linecolor": "rgb(36,36,36)",
            "showgrid": false,
            "showline": true,
            "ticks": "outside"
           },
           "bgcolor": "white",
           "caxis": {
            "gridcolor": "rgb(232,232,232)",
            "linecolor": "rgb(36,36,36)",
            "showgrid": false,
            "showline": true,
            "ticks": "outside"
           }
          },
          "title": {
           "x": 0.05
          },
          "xaxis": {
           "automargin": true,
           "gridcolor": "rgb(232,232,232)",
           "linecolor": "rgb(36,36,36)",
           "showgrid": false,
           "showline": true,
           "ticks": "outside",
           "title": {
            "standoff": 15
           },
           "zeroline": false,
           "zerolinecolor": "rgb(36,36,36)"
          },
          "yaxis": {
           "automargin": true,
           "gridcolor": "rgb(232,232,232)",
           "linecolor": "rgb(36,36,36)",
           "showgrid": false,
           "showline": true,
           "ticks": "outside",
           "title": {
            "standoff": 15
           },
           "zeroline": false,
           "zerolinecolor": "rgb(36,36,36)"
          }
         }
        },
        "title": {
         "text": "Cd vs. Alpha"
        },
        "xaxis": {
         "anchor": "y",
         "domain": [
          0,
          1
         ],
         "gridcolor": "Gray",
         "gridwidth": 1,
         "linecolor": "black",
         "linewidth": 1,
         "mirror": false,
         "range": [
          -15,
          15
         ],
         "showgrid": true,
         "showline": true,
         "title": {
          "text": "Alpha [deg]"
         },
         "zeroline": true,
         "zerolinecolor": "black",
         "zerolinewidth": 2
        },
        "yaxis": {
         "anchor": "x",
         "domain": [
          0,
          1
         ],
         "gridcolor": "Gray",
         "gridwidth": 0.5,
         "linecolor": "black",
         "linewidth": 1,
         "mirror": false,
         "showgrid": true,
         "showline": true,
         "title": {
          "text": "Cd"
         },
         "zeroline": true,
         "zerolinecolor": "Gray",
         "zerolinewidth": 1
        }
       }
      },
      "text/html": [
       "<div>                            <div id=\"fe056d7c-69e6-46f9-a034-391a7a62d651\" class=\"plotly-graph-div\" style=\"height:525px; width:100%;\"></div>            <script type=\"text/javascript\">                require([\"plotly\"], function(Plotly) {                    window.PLOTLYENV=window.PLOTLYENV || {};                                    if (document.getElementById(\"fe056d7c-69e6-46f9-a034-391a7a62d651\")) {                    Plotly.newPlot(                        \"fe056d7c-69e6-46f9-a034-391a7a62d651\",                        [{\"hovertemplate\":\"M=0.2<br>Alpha=%{x}<br>Cd=%{y}<extra></extra>\",\"legendgroup\":\"0.2\",\"line\":{\"color\":\"#f0f921\",\"dash\":\"solid\"},\"mode\":\"lines\",\"name\":\"0.2\",\"orientation\":\"v\",\"showlegend\":true,\"textposition\":\"top center\",\"type\":\"scatter\",\"x\":[-6.0,-5.76767677,-5.53535354,-5.3030303,-5.07070707,-4.83838384,-4.60606061,-4.37373737,-4.14141414,-3.90909091,-3.67676768,-3.44444444,-3.21212121,-2.97979798,-2.74747475,-2.51515152,-2.28282828,-2.05050505,-1.81818182,-1.58585859,-1.35353535,-1.12121212,-0.88888889,-0.65656566,-0.42424242,-0.19191919,0.04040404,0.27272727,0.50505051,0.73737374,0.96969697,1.2020202,1.43434343,1.66666667,1.8989899,2.13131313,2.36363636,2.5959596,2.82828283,3.06060606,3.29292929,3.52525253,3.75757576,3.98989899,4.22222222,4.45454545,4.68686869,4.91919192,5.15151515,5.38383838,5.61616162,5.84848485,6.08080808,6.31313131,6.54545455,6.77777778,7.01010101,7.24242424,7.47474747,7.70707071,7.93939394,8.17171717,8.4040404,8.63636364,8.86868687,9.1010101,9.33333333,9.56565657,9.7979798,10.03030303,10.26262626,10.49494949,10.72727273,10.95959596,11.19191919,11.42424242,11.65656566,11.88888889,12.12121212,12.35353535,12.58585859,12.81818182,13.05050505,13.28282828,13.51515152,13.74747475,13.97979798,14.21212121,14.44444444,14.67676768,14.90909091,15.14141414,15.37373737,15.60606061,15.83838384,16.07070707,16.3030303,16.53535354,16.76767677,17.0],\"xaxis\":\"x\",\"y\":[0.01225065,0.01209318,0.01194392,0.01180329,0.01167175,0.01154967,0.01143696,0.01133322,0.01123771,0.0111494,0.01106762,0.01099217,0.01092318,0.0108614,0.01080697,0.01075797,0.01071264,0.0106719,0.01063748,0.0106111,0.01059449,0.01058939,0.01059738,0.01061663,0.01064164,0.01066677,0.01068636,0.01069795,0.01070669,0.01071885,0.01074072,0.01077753,0.01082825,0.01088961,0.0109583,0.01103114,0.01110723,0.01118756,0.01127318,0.01136514,0.01146397,0.01156923,0.01168038,0.01179687,0.01191841,0.01204584,0.01218034,0.01232308,0.01247509,0.01263554,0.01280236,0.01297346,0.01314687,0.01332715,0.01352358,0.01373007,0.01394279,0.01416215,0.0143924,0.0146317,0.01488103,0.01514689,0.01542093,0.0157002,0.01599353,0.01630111,0.01662236,0.01695807,0.01730941,0.01767158,0.0180444,0.01844241,0.01885663,0.01928447,0.01973683,0.02021193,0.02070334,0.02121393,0.02175247,0.02232776,0.02293727,0.02356377,0.02422789,0.02493927,0.02567173,0.02645719,0.02731298,0.02823163,0.02920663,0.03024305,0.03135575,0.0325681,0.03398966,0.03566924,0.03750454,0.03956883,0.0419715,0.04482739,0.04832784,0.05268291],\"yaxis\":\"y\"},{\"hovertemplate\":\"M=0.3<br>Alpha=%{x}<br>Cd=%{y}<extra></extra>\",\"legendgroup\":\"0.3\",\"line\":{\"color\":\"#fdca26\",\"dash\":\"solid\"},\"mode\":\"lines\",\"name\":\"0.3\",\"orientation\":\"v\",\"showlegend\":true,\"textposition\":\"top center\",\"type\":\"scatter\",\"x\":[-6.0,-5.76767677,-5.53535354,-5.3030303,-5.07070707,-4.83838384,-4.60606061,-4.37373737,-4.14141414,-3.90909091,-3.67676768,-3.44444444,-3.21212121,-2.97979798,-2.74747475,-2.51515152,-2.28282828,-2.05050505,-1.81818182,-1.58585859,-1.35353535,-1.12121212,-0.88888889,-0.65656566,-0.42424242,-0.19191919,0.04040404,0.27272727,0.50505051,0.73737374,0.96969697,1.2020202,1.43434343,1.66666667,1.8989899,2.13131313,2.36363636,2.5959596,2.82828283,3.06060606,3.29292929,3.52525253,3.75757576,3.98989899,4.22222222,4.45454545,4.68686869,4.91919192,5.15151515,5.38383838,5.61616162,5.84848485,6.08080808,6.31313131,6.54545455,6.77777778,7.01010101,7.24242424,7.47474747,7.70707071,7.93939394,8.17171717,8.4040404,8.63636364,8.86868687,9.1010101,9.33333333,9.56565657,9.7979798,10.03030303,10.26262626,10.49494949,10.72727273,10.95959596,11.19191919,11.42424242,11.65656566,11.88888889,12.12121212,12.35353535,12.58585859,12.81818182,13.05050505,13.28282828,13.51515152,13.74747475,13.97979798,14.21212121,14.44444444,14.67676768,14.90909091,15.14141414,15.37373737,15.60606061,15.83838384,16.07070707,16.3030303,16.53535354,16.76767677,17.0],\"xaxis\":\"x\",\"y\":[0.01163722,0.01147413,0.01132013,0.01117569,0.01104129,0.01091725,0.01080215,0.01069364,0.01059182,0.01049888,0.0104154,0.01033972,0.01027059,0.01020791,0.0101517,0.01010204,0.01005897,0.01002249,0.00999262,0.00996934,0.00995266,0.00994257,0.00993906,0.00994196,0.00995089,0.00996546,0.0099853,0.01001023,0.0100405,0.01007646,0.01011843,0.01016672,0.0102213,0.01028204,0.01034884,0.01042155,0.01050016,0.0105847,0.01067521,0.01077172,0.01087434,0.01098328,0.01109877,0.01122104,0.01135027,0.0114864,0.01162934,0.01177895,0.01193518,0.01209874,0.01227081,0.0124526,0.01264524,0.01284637,0.0130517,0.01326692,0.01349368,0.01372874,0.01396523,0.01421489,0.01448181,0.01475234,0.01503302,0.0153302,0.01563984,0.01596409,0.01630207,0.01665189,0.01701986,0.01740221,0.01779621,0.01821186,0.01864629,0.01909901,0.01957641,0.02007911,0.02060554,0.02115756,0.02173918,0.02235446,0.02300517,0.02369107,0.02442344,0.02520992,0.0260458,0.0269404,0.02791218,0.02898077,0.03015748,0.03145759,0.03291651,0.0345941,0.03655889,0.0388804,0.04163367,0.04493745,0.04892769,0.05378463,0.05981498,0.06735561],\"yaxis\":\"y\"},{\"hovertemplate\":\"M=0.4<br>Alpha=%{x}<br>Cd=%{y}<extra></extra>\",\"legendgroup\":\"0.4\",\"line\":{\"color\":\"#fb9f3a\",\"dash\":\"solid\"},\"mode\":\"lines\",\"name\":\"0.4\",\"orientation\":\"v\",\"showlegend\":true,\"textposition\":\"top center\",\"type\":\"scatter\",\"x\":[-6.0,-5.76767677,-5.53535354,-5.3030303,-5.07070707,-4.83838384,-4.60606061,-4.37373737,-4.14141414,-3.90909091,-3.67676768,-3.44444444,-3.21212121,-2.97979798,-2.74747475,-2.51515152,-2.28282828,-2.05050505,-1.81818182,-1.58585859,-1.35353535,-1.12121212,-0.88888889,-0.65656566,-0.42424242,-0.19191919,0.04040404,0.27272727,0.50505051,0.73737374,0.96969697,1.2020202,1.43434343,1.66666667,1.8989899,2.13131313,2.36363636,2.5959596,2.82828283,3.06060606,3.29292929,3.52525253,3.75757576,3.98989899,4.22222222,4.45454545,4.68686869,4.91919192,5.15151515,5.38383838,5.61616162,5.84848485,6.08080808,6.31313131,6.54545455,6.77777778,7.01010101,7.24242424,7.47474747,7.70707071,7.93939394,8.17171717,8.4040404,8.63636364,8.86868687,9.1010101,9.33333333,9.56565657,9.7979798,10.03030303,10.26262626,10.49494949,10.72727273,10.95959596,11.19191919,11.42424242,11.65656566,11.88888889,12.12121212,12.35353535,12.58585859,12.81818182,13.05050505,13.28282828,13.51515152,13.74747475,13.97979798,14.21212121,14.44444444,14.67676768,14.90909091,15.14141414,15.37373737,15.60606061,15.83838384,16.07070707,16.3030303,16.53535354,16.76767677,17.0],\"xaxis\":\"x\",\"y\":[0.01139713,0.01120696,0.01103136,0.01086916,0.01071921,0.01058036,0.01045193,0.01033349,0.01022457,0.01012469,0.01003345,0.00995053,0.00987563,0.00980841,0.0097486,0.00969619,0.0096512,0.00961352,0.00958301,0.00955951,0.00954287,0.00953296,0.00952963,0.00953279,0.00954245,0.00955859,0.00958122,0.00961032,0.00964586,0.00968777,0.00973603,0.00979059,0.00985151,0.00991883,0.00999264,0.010073,0.01015997,0.01025362,0.01035401,0.0104612,0.01057531,0.01069648,0.01082489,0.01096071,0.0111041,0.01125509,0.01141368,0.01157988,0.01175374,0.01193586,0.01212721,0.01232875,0.01254143,0.01276405,0.01299389,0.01323319,0.01348299,0.0137435,0.014016,0.01429973,0.01459559,0.014907,0.01523226,0.01556999,0.01592241,0.01629189,0.01667924,0.01708373,0.01750572,0.01794838,0.01841474,0.01890593,0.0194322,0.02001885,0.02070299,0.02153367,0.02256262,0.02381718,0.02530925,0.02705054,0.029061,0.03137037,0.03397616,0.03687954,0.04013382,0.04388771,0.04805455,0.05247681,0.05756547,0.06330455,0.0695248,0.07648436,0.08390437,0.0916152,0.10006728,0.10883361,0.11752242,0.12613119,0.13453565,0.14257238],\"yaxis\":\"y\"},{\"hovertemplate\":\"M=0.5<br>Alpha=%{x}<br>Cd=%{y}<extra></extra>\",\"legendgroup\":\"0.5\",\"line\":{\"color\":\"#ed7953\",\"dash\":\"solid\"},\"mode\":\"lines\",\"name\":\"0.5\",\"orientation\":\"v\",\"showlegend\":true,\"textposition\":\"top center\",\"type\":\"scatter\",\"x\":[-5.5,-5.3030303,-5.10606061,-4.90909091,-4.71212121,-4.51515152,-4.31818182,-4.12121212,-3.92424242,-3.72727273,-3.53030303,-3.33333333,-3.13636364,-2.93939394,-2.74242424,-2.54545455,-2.34848485,-2.15151515,-1.95454545,-1.75757576,-1.56060606,-1.36363636,-1.16666667,-0.96969697,-0.77272727,-0.57575758,-0.37878788,-0.18181818,0.01515152,0.21212121,0.40909091,0.60606061,0.8030303,1.0,1.1969697,1.39393939,1.59090909,1.78787879,1.98484848,2.18181818,2.37878788,2.57575758,2.77272727,2.96969697,3.16666667,3.36363636,3.56060606,3.75757576,3.95454545,4.15151515,4.34848485,4.54545455,4.74242424,4.93939394,5.13636364,5.33333333,5.53030303,5.72727273,5.92424242,6.12121212,6.31818182,6.51515152,6.71212121,6.90909091,7.10606061,7.3030303,7.5,7.6969697,7.89393939,8.09090909,8.28787879,8.48484848,8.68181818,8.87878788,9.07575758,9.27272727,9.46969697,9.66666667,9.86363636,10.06060606,10.25757576,10.45454545,10.65151515,10.84848485,11.04545455,11.24242424,11.43939394,11.63636364,11.83333333,12.03030303,12.22727273,12.42424242,12.62121212,12.81818182,13.01515152,13.21212121,13.40909091,13.60606061,13.8030303,14.0],\"xaxis\":\"x\",\"y\":[0.01371416,0.01270822,0.01189516,0.01125661,0.0107742,0.01042958,0.01020138,0.01005317,0.00994414,0.00984915,0.00976424,0.00968717,0.00961714,0.0095539,0.00949727,0.00944712,0.00940333,0.00936559,0.00933352,0.00930693,0.00928607,0.0092712,0.00926219,0.00925871,0.00926049,0.00926754,0.00927989,0.00929758,0.00932065,0.00934911,0.00938294,0.0094221,0.00946658,0.00951632,0.00957132,0.00963161,0.00969728,0.00976837,0.00984497,0.00992713,0.01001492,0.01010843,0.01020771,0.01031284,0.01042391,0.01054105,0.01066443,0.01079423,0.0109306,0.01107371,0.01122367,0.01138057,0.0115445,0.01171554,0.01189382,0.01207993,0.01227472,0.01247905,0.01269379,0.01291985,0.01315909,0.01342017,0.01373035,0.01411816,0.01460998,0.0152271,0.0159845,0.01689041,0.01795021,0.01916796,0.02054756,0.02209239,0.02380385,0.02567702,0.02769986,0.02986326,0.03216596,0.03462689,0.03726369,0.04008045,0.04306854,0.04620789,0.0495362,0.05307373,0.05675539,0.06053447,0.0644214,0.06843281,0.07257714,0.07685788,0.08127844,0.08583532,0.09043313,0.09498016,0.09958346,0.10432483,0.10909516,0.11382484,0.11851221,0.12315785],\"yaxis\":\"y\"},{\"hovertemplate\":\"M=0.6<br>Alpha=%{x}<br>Cd=%{y}<extra></extra>\",\"legendgroup\":\"0.6\",\"line\":{\"color\":\"#d8576b\",\"dash\":\"solid\"},\"mode\":\"lines\",\"name\":\"0.6\",\"orientation\":\"v\",\"showlegend\":true,\"textposition\":\"top center\",\"type\":\"scatter\",\"x\":[-6.0,-5.86262626,-5.72525253,-5.58787879,-5.45050505,-5.31313131,-5.17575758,-5.03838384,-4.9010101,-4.76363636,-4.62626263,-4.48888889,-4.35151515,-4.21414141,-4.07676768,-3.93939394,-3.8020202,-3.66464646,-3.52727273,-3.38989899,-3.25252525,-3.11515152,-2.97777778,-2.84040404,-2.7030303,-2.56565657,-2.42828283,-2.29090909,-2.15353535,-2.01616162,-1.87878788,-1.74141414,-1.6040404,-1.46666667,-1.32929293,-1.19191919,-1.05454545,-0.91717172,-0.77979798,-0.64242424,-0.50505051,-0.36767677,-0.23030303,-0.09292929,0.04444444,0.18181818,0.31919192,0.45656566,0.59393939,0.73131313,0.86868687,1.00606061,1.14343434,1.28080808,1.41818182,1.55555556,1.69292929,1.83030303,1.96767677,2.10505051,2.24242424,2.37979798,2.51717172,2.65454545,2.79191919,2.92929293,3.06666667,3.2040404,3.34141414,3.47878788,3.61616162,3.75353535,3.89090909,4.02828283,4.16565657,4.3030303,4.44040404,4.57777778,4.71515152,4.85252525,4.98989899,5.12727273,5.26464646,5.4020202,5.53939394,5.67676768,5.81414141,5.95151515,6.08888889,6.22626263,6.36363636,6.5010101,6.63838384,6.77575758,6.91313131,7.05050505,7.18787879,7.32525253,7.46262626,7.6],\"xaxis\":\"x\",\"y\":[0.02891662,0.02732834,0.02584121,0.02444658,0.02313581,0.02190027,0.02073131,0.0196203,0.01855916,0.01754529,0.01657915,0.01566122,0.01479305,0.01397949,0.01322605,0.01253817,0.01191921,0.01137012,0.01089167,0.01048438,0.01014654,0.00987548,0.0096685,0.00952008,0.00941768,0.00934767,0.0092967,0.00925679,0.00922507,0.00919886,0.00917581,0.00915559,0.00913854,0.00912502,0.00911523,0.00910905,0.00910634,0.00910697,0.00911083,0.00911789,0.00912811,0.00914145,0.00915786,0.0091773,0.00919973,0.00922521,0.00925394,0.00928612,0.00932197,0.0093617,0.00940553,0.00945367,0.00950616,0.0095625,0.00962205,0.00968415,0.00974818,0.00981349,0.00987945,0.00994613,0.01001965,0.0101091,0.01022358,0.0103722,0.01056408,0.01080833,0.0111139,0.01148612,0.01192656,0.01243658,0.01301758,0.01367094,0.01439802,0.01520022,0.01607763,0.01702754,0.0180469,0.01913265,0.0202817,0.02149099,0.02275746,0.02407836,0.02545251,0.02687924,0.02835787,0.02988771,0.03146809,0.03309833,0.03477842,0.03651664,0.03832679,0.04021868,0.0421976,0.04426504,0.04641612,0.04864517,0.05094231,0.05329165,0.05567685,0.05808157],\"yaxis\":\"y\"},{\"hovertemplate\":\"M=0.7<br>Alpha=%{x}<br>Cd=%{y}<extra></extra>\",\"legendgroup\":\"0.7\",\"line\":{\"color\":\"#bd3786\",\"dash\":\"solid\"},\"mode\":\"lines\",\"name\":\"0.7\",\"orientation\":\"v\",\"showlegend\":true,\"textposition\":\"top center\",\"type\":\"scatter\",\"x\":[-6.0,-5.86868687,-5.73737374,-5.60606061,-5.47474747,-5.34343434,-5.21212121,-5.08080808,-4.94949495,-4.81818182,-4.68686869,-4.55555556,-4.42424242,-4.29292929,-4.16161616,-4.03030303,-3.8989899,-3.76767677,-3.63636364,-3.50505051,-3.37373737,-3.24242424,-3.11111111,-2.97979798,-2.84848485,-2.71717172,-2.58585859,-2.45454545,-2.32323232,-2.19191919,-2.06060606,-1.92929293,-1.7979798,-1.66666667,-1.53535354,-1.4040404,-1.27272727,-1.14141414,-1.01010101,-0.87878788,-0.74747475,-0.61616162,-0.48484848,-0.35353535,-0.22222222,-0.09090909,0.04040404,0.17171717,0.3030303,0.43434343,0.56565657,0.6969697,0.82828283,0.95959596,1.09090909,1.22222222,1.35353535,1.48484848,1.61616162,1.74747475,1.87878788,2.01010101,2.14141414,2.27272727,2.4040404,2.53535354,2.66666667,2.7979798,2.92929293,3.06060606,3.19191919,3.32323232,3.45454545,3.58585859,3.71717172,3.84848485,3.97979798,4.11111111,4.24242424,4.37373737,4.50505051,4.63636364,4.76767677,4.8989899,5.03030303,5.16161616,5.29292929,5.42424242,5.55555556,5.68686869,5.81818182,5.94949495,6.08080808,6.21212121,6.34343434,6.47474747,6.60606061,6.73737374,6.86868687,7.0],\"xaxis\":\"x\",\"y\":[0.0486028,0.04633352,0.04403339,0.04171795,0.03940277,0.03710341,0.03483542,0.03261436,0.03045577,0.02837364,0.02637998,0.02448662,0.02270596,0.02105944,0.01957595,0.01828457,0.01720879,0.01632643,0.01559297,0.01496376,0.01439772,0.01386975,0.01335929,0.01284579,0.01231898,0.01179484,0.01129344,0.01083471,0.01043149,0.01008597,0.00979947,0.00957307,0.00940318,0.00928198,0.00920153,0.00915385,0.00913098,0.00912496,0.00912783,0.00913361,0.0091463,0.00917305,0.00922101,0.00929734,0.00940917,0.00956366,0.00976796,0.01002847,0.01035042,0.01073892,0.01119909,0.01173604,0.01235487,0.01306071,0.01385819,0.01474704,0.01572404,0.0167859,0.01792936,0.01915113,0.02044795,0.02181654,0.0232525,0.02474786,0.02629397,0.02788213,0.02950369,0.03114998,0.03281231,0.03448218,0.03615541,0.03783264,0.03951474,0.04120261,0.04289711,0.04459913,0.04630955,0.04802916,0.04975825,0.05149686,0.05324506,0.05500292,0.0567705,0.05854785,0.06033505,0.06213251,0.06394139,0.06576292,0.06759836,0.06944894,0.0713159,0.07320048,0.07510376,0.07702426,0.07895871,0.08090597,0.08286834,0.08484841,0.08684876,0.088872],\"yaxis\":\"y\"},{\"hovertemplate\":\"M=0.75<br>Alpha=%{x}<br>Cd=%{y}<extra></extra>\",\"legendgroup\":\"0.75\",\"line\":{\"color\":\"#9c179e\",\"dash\":\"solid\"},\"mode\":\"lines\",\"name\":\"0.75\",\"orientation\":\"v\",\"showlegend\":true,\"textposition\":\"top center\",\"type\":\"scatter\",\"x\":[-6.0,-5.87272727,-5.74545455,-5.61818182,-5.49090909,-5.36363636,-5.23636364,-5.10909091,-4.98181818,-4.85454545,-4.72727273,-4.6,-4.47272727,-4.34545455,-4.21818182,-4.09090909,-3.96363636,-3.83636364,-3.70909091,-3.58181818,-3.45454545,-3.32727273,-3.2,-3.07272727,-2.94545455,-2.81818182,-2.69090909,-2.56363636,-2.43636364,-2.30909091,-2.18181818,-2.05454545,-1.92727273,-1.8,-1.67272727,-1.54545455,-1.41818182,-1.29090909,-1.16363636,-1.03636364,-0.90909091,-0.78181818,-0.65454545,-0.52727273,-0.4,-0.27272727,-0.14545455,-0.01818182,0.10909091,0.23636364,0.36363636,0.49090909,0.61818182,0.74545455,0.87272727,1.0,1.12727273,1.25454545,1.38181818,1.50909091,1.63636364,1.76363636,1.89090909,2.01818182,2.14545455,2.27272727,2.4,2.52727273,2.65454545,2.78181818,2.90909091,3.03636364,3.16363636,3.29090909,3.41818182,3.54545455,3.67272727,3.8,3.92727273,4.05454545,4.18181818,4.30909091,4.43636364,4.56363636,4.69090909,4.81818182,4.94545455,5.07272727,5.2,5.32727273,5.45454545,5.58181818,5.70909091,5.83636364,5.96363636,6.09090909,6.21818182,6.34545455,6.47272727,6.6],\"xaxis\":\"x\",\"y\":[0.06250026,0.0604718,0.05844354,0.0564152,0.05438647,0.05235707,0.0503267,0.04829506,0.04626186,0.04422262,0.04216196,0.04006268,0.03790769,0.03569186,0.03343573,0.03116314,0.02889794,0.02666304,0.02447975,0.02236918,0.02035247,0.01845133,0.01668831,0.01508602,0.01366723,0.01246007,0.0114991,0.01081928,0.01045243,0.01035815,0.01042379,0.01053359,0.01057643,0.01051911,0.01039315,0.010232,0.01006913,0.009938,0.00987208,0.00990481,0.01006728,0.01036709,0.01079851,0.01135567,0.0120327,0.01282372,0.01372285,0.01472423,0.01582187,0.01700912,0.01827907,0.0196248,0.02103941,0.02251598,0.02404761,0.02562739,0.02724771,0.02889817,0.0305677,0.03224521,0.0339196,0.03557979,0.03721469,0.03881324,0.0403698,0.04189311,0.04339421,0.04488412,0.04637097,0.04785667,0.04934233,0.05082906,0.05231841,0.05381269,0.05531427,0.05682553,0.0583477,0.05988037,0.06142301,0.0629751,0.06453693,0.06610978,0.06769496,0.06929377,0.07090688,0.07253436,0.07417621,0.07583253,0.07750404,0.07919206,0.08089789,0.08262283,0.08436786,0.08613375,0.08792127,0.08973116,0.0915639,0.09341984,0.09529932,0.09720267],\"yaxis\":\"y\"},{\"hovertemplate\":\"M=0.8<br>Alpha=%{x}<br>Cd=%{y}<extra></extra>\",\"legendgroup\":\"0.8\",\"line\":{\"color\":\"#7201a8\",\"dash\":\"solid\"},\"mode\":\"lines\",\"name\":\"0.8\",\"orientation\":\"v\",\"showlegend\":true,\"textposition\":\"top center\",\"type\":\"scatter\",\"x\":[-6.0,-5.86868687,-5.73737374,-5.60606061,-5.47474747,-5.34343434,-5.21212121,-5.08080808,-4.94949495,-4.81818182,-4.68686869,-4.55555556,-4.42424242,-4.29292929,-4.16161616,-4.03030303,-3.8989899,-3.76767677,-3.63636364,-3.50505051,-3.37373737,-3.24242424,-3.11111111,-2.97979798,-2.84848485,-2.71717172,-2.58585859,-2.45454545,-2.32323232,-2.19191919,-2.06060606,-1.92929293,-1.7979798,-1.66666667,-1.53535354,-1.4040404,-1.27272727,-1.14141414,-1.01010101,-0.87878788,-0.74747475,-0.61616162,-0.48484848,-0.35353535,-0.22222222,-0.09090909,0.04040404,0.17171717,0.3030303,0.43434343,0.56565657,0.6969697,0.82828283,0.95959596,1.09090909,1.22222222,1.35353535,1.48484848,1.61616162,1.74747475,1.87878788,2.01010101,2.14141414,2.27272727,2.4040404,2.53535354,2.66666667,2.7979798,2.92929293,3.06060606,3.19191919,3.32323232,3.45454545,3.58585859,3.71717172,3.84848485,3.97979798,4.11111111,4.24242424,4.37373737,4.50505051,4.63636364,4.76767677,4.8989899,5.03030303,5.16161616,5.29292929,5.42424242,5.55555556,5.68686869,5.81818182,5.94949495,6.08080808,6.21212121,6.34343434,6.47474747,6.60606061,6.73737374,6.86868687,7.0],\"xaxis\":\"x\",\"y\":[0.07382993,0.07177379,0.06974726,0.06774681,0.06576889,0.06381376,0.06189025,0.06000168,0.05813976,0.05629475,0.05445665,0.05261645,0.05076717,0.04891735,0.04708816,0.04530116,0.04357157,0.04186304,0.04011403,0.03826283,0.03626405,0.03414559,0.03195594,0.02974354,0.02754857,0.02539023,0.02328439,0.0212476,0.01933241,0.01764528,0.01629712,0.01539445,0.01495924,0.01493699,0.01527043,0.01590231,0.01677536,0.01783233,0.01901597,0.02027561,0.02159393,0.0229641,0.02437928,0.02583261,0.02731728,0.02882643,0.03035324,0.03189113,0.03343397,0.03497569,0.0365102,0.03803141,0.03953324,0.04100961,0.04245517,0.04387256,0.0452692,0.04665257,0.04803015,0.04940944,0.05079792,0.05220308,0.05363016,0.05507731,0.05654125,0.05801872,0.05950808,0.06101066,0.06252812,0.06406209,0.0656136,0.06718304,0.06877074,0.0703769,0.0719998,0.07363643,0.07528378,0.07693997,0.07861044,0.0803035,0.0820275,0.08378737,0.08557602,0.08738367,0.08920057,0.0910213,0.09284928,0.09469025,0.09655575,0.09845898,0.10040786,0.1023815,0.10435199,0.10632816,0.10834575,0.11041909,0.11252824,0.11465027,0.11676222,0.11884117],\"yaxis\":\"y\"}],                        {\"legend\":{\"title\":{\"text\":\"M\"},\"tracegroupgap\":0},\"margin\":{\"t\":60},\"template\":{\"data\":{\"bar\":[{\"error_x\":{\"color\":\"rgb(36,36,36)\"},\"error_y\":{\"color\":\"rgb(36,36,36)\"},\"marker\":{\"line\":{\"color\":\"white\",\"width\":0.5},\"pattern\":{\"fillmode\":\"overlay\",\"size\":10,\"solidity\":0.2}},\"type\":\"bar\"}],\"barpolar\":[{\"marker\":{\"line\":{\"color\":\"white\",\"width\":0.5},\"pattern\":{\"fillmode\":\"overlay\",\"size\":10,\"solidity\":0.2}},\"type\":\"barpolar\"}],\"carpet\":[{\"aaxis\":{\"endlinecolor\":\"rgb(36,36,36)\",\"gridcolor\":\"white\",\"linecolor\":\"white\",\"minorgridcolor\":\"white\",\"startlinecolor\":\"rgb(36,36,36)\"},\"baxis\":{\"endlinecolor\":\"rgb(36,36,36)\",\"gridcolor\":\"white\",\"linecolor\":\"white\",\"minorgridcolor\":\"white\",\"startlinecolor\":\"rgb(36,36,36)\"},\"type\":\"carpet\"}],\"choropleth\":[{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"},\"type\":\"choropleth\"}],\"contour\":[{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"},\"colorscale\":[[0.0,\"#440154\"],[0.1111111111111111,\"#482878\"],[0.2222222222222222,\"#3e4989\"],[0.3333333333333333,\"#31688e\"],[0.4444444444444444,\"#26828e\"],[0.5555555555555556,\"#1f9e89\"],[0.6666666666666666,\"#35b779\"],[0.7777777777777778,\"#6ece58\"],[0.8888888888888888,\"#b5de2b\"],[1.0,\"#fde725\"]],\"type\":\"contour\"}],\"contourcarpet\":[{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"},\"type\":\"contourcarpet\"}],\"heatmap\":[{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"},\"colorscale\":[[0.0,\"#440154\"],[0.1111111111111111,\"#482878\"],[0.2222222222222222,\"#3e4989\"],[0.3333333333333333,\"#31688e\"],[0.4444444444444444,\"#26828e\"],[0.5555555555555556,\"#1f9e89\"],[0.6666666666666666,\"#35b779\"],[0.7777777777777778,\"#6ece58\"],[0.8888888888888888,\"#b5de2b\"],[1.0,\"#fde725\"]],\"type\":\"heatmap\"}],\"heatmapgl\":[{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"},\"colorscale\":[[0.0,\"#440154\"],[0.1111111111111111,\"#482878\"],[0.2222222222222222,\"#3e4989\"],[0.3333333333333333,\"#31688e\"],[0.4444444444444444,\"#26828e\"],[0.5555555555555556,\"#1f9e89\"],[0.6666666666666666,\"#35b779\"],[0.7777777777777778,\"#6ece58\"],[0.8888888888888888,\"#b5de2b\"],[1.0,\"#fde725\"]],\"type\":\"heatmapgl\"}],\"histogram\":[{\"marker\":{\"line\":{\"color\":\"white\",\"width\":0.6}},\"type\":\"histogram\"}],\"histogram2d\":[{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"},\"colorscale\":[[0.0,\"#440154\"],[0.1111111111111111,\"#482878\"],[0.2222222222222222,\"#3e4989\"],[0.3333333333333333,\"#31688e\"],[0.4444444444444444,\"#26828e\"],[0.5555555555555556,\"#1f9e89\"],[0.6666666666666666,\"#35b779\"],[0.7777777777777778,\"#6ece58\"],[0.8888888888888888,\"#b5de2b\"],[1.0,\"#fde725\"]],\"type\":\"histogram2d\"}],\"histogram2dcontour\":[{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"},\"colorscale\":[[0.0,\"#440154\"],[0.1111111111111111,\"#482878\"],[0.2222222222222222,\"#3e4989\"],[0.3333333333333333,\"#31688e\"],[0.4444444444444444,\"#26828e\"],[0.5555555555555556,\"#1f9e89\"],[0.6666666666666666,\"#35b779\"],[0.7777777777777778,\"#6ece58\"],[0.8888888888888888,\"#b5de2b\"],[1.0,\"#fde725\"]],\"type\":\"histogram2dcontour\"}],\"mesh3d\":[{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"},\"type\":\"mesh3d\"}],\"parcoords\":[{\"line\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"type\":\"parcoords\"}],\"pie\":[{\"automargin\":true,\"type\":\"pie\"}],\"scatter\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"type\":\"scatter\"}],\"scatter3d\":[{\"line\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"marker\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"type\":\"scatter3d\"}],\"scattercarpet\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"type\":\"scattercarpet\"}],\"scattergeo\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"type\":\"scattergeo\"}],\"scattergl\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"type\":\"scattergl\"}],\"scattermapbox\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"type\":\"scattermapbox\"}],\"scatterpolar\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"type\":\"scatterpolar\"}],\"scatterpolargl\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"type\":\"scatterpolargl\"}],\"scatterternary\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"type\":\"scatterternary\"}],\"surface\":[{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"},\"colorscale\":[[0.0,\"#440154\"],[0.1111111111111111,\"#482878\"],[0.2222222222222222,\"#3e4989\"],[0.3333333333333333,\"#31688e\"],[0.4444444444444444,\"#26828e\"],[0.5555555555555556,\"#1f9e89\"],[0.6666666666666666,\"#35b779\"],[0.7777777777777778,\"#6ece58\"],[0.8888888888888888,\"#b5de2b\"],[1.0,\"#fde725\"]],\"type\":\"surface\"}],\"table\":[{\"cells\":{\"fill\":{\"color\":\"rgb(237,237,237)\"},\"line\":{\"color\":\"white\"}},\"header\":{\"fill\":{\"color\":\"rgb(217,217,217)\"},\"line\":{\"color\":\"white\"}},\"type\":\"table\"}]},\"layout\":{\"annotationdefaults\":{\"arrowhead\":0,\"arrowwidth\":1},\"autotypenumbers\":\"strict\",\"coloraxis\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"colorscale\":{\"diverging\":[[0.0,\"rgb(103,0,31)\"],[0.1,\"rgb(178,24,43)\"],[0.2,\"rgb(214,96,77)\"],[0.3,\"rgb(244,165,130)\"],[0.4,\"rgb(253,219,199)\"],[0.5,\"rgb(247,247,247)\"],[0.6,\"rgb(209,229,240)\"],[0.7,\"rgb(146,197,222)\"],[0.8,\"rgb(67,147,195)\"],[0.9,\"rgb(33,102,172)\"],[1.0,\"rgb(5,48,97)\"]],\"sequential\":[[0.0,\"#440154\"],[0.1111111111111111,\"#482878\"],[0.2222222222222222,\"#3e4989\"],[0.3333333333333333,\"#31688e\"],[0.4444444444444444,\"#26828e\"],[0.5555555555555556,\"#1f9e89\"],[0.6666666666666666,\"#35b779\"],[0.7777777777777778,\"#6ece58\"],[0.8888888888888888,\"#b5de2b\"],[1.0,\"#fde725\"]],\"sequentialminus\":[[0.0,\"#440154\"],[0.1111111111111111,\"#482878\"],[0.2222222222222222,\"#3e4989\"],[0.3333333333333333,\"#31688e\"],[0.4444444444444444,\"#26828e\"],[0.5555555555555556,\"#1f9e89\"],[0.6666666666666666,\"#35b779\"],[0.7777777777777778,\"#6ece58\"],[0.8888888888888888,\"#b5de2b\"],[1.0,\"#fde725\"]]},\"colorway\":[\"#1F77B4\",\"#FF7F0E\",\"#2CA02C\",\"#D62728\",\"#9467BD\",\"#8C564B\",\"#E377C2\",\"#7F7F7F\",\"#BCBD22\",\"#17BECF\"],\"font\":{\"color\":\"rgb(36,36,36)\"},\"geo\":{\"bgcolor\":\"white\",\"lakecolor\":\"white\",\"landcolor\":\"white\",\"showlakes\":true,\"showland\":true,\"subunitcolor\":\"white\"},\"hoverlabel\":{\"align\":\"left\"},\"hovermode\":\"closest\",\"mapbox\":{\"style\":\"light\"},\"paper_bgcolor\":\"white\",\"plot_bgcolor\":\"white\",\"polar\":{\"angularaxis\":{\"gridcolor\":\"rgb(232,232,232)\",\"linecolor\":\"rgb(36,36,36)\",\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\"},\"bgcolor\":\"white\",\"radialaxis\":{\"gridcolor\":\"rgb(232,232,232)\",\"linecolor\":\"rgb(36,36,36)\",\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\"}},\"scene\":{\"xaxis\":{\"backgroundcolor\":\"white\",\"gridcolor\":\"rgb(232,232,232)\",\"gridwidth\":2,\"linecolor\":\"rgb(36,36,36)\",\"showbackground\":true,\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\",\"zeroline\":false,\"zerolinecolor\":\"rgb(36,36,36)\"},\"yaxis\":{\"backgroundcolor\":\"white\",\"gridcolor\":\"rgb(232,232,232)\",\"gridwidth\":2,\"linecolor\":\"rgb(36,36,36)\",\"showbackground\":true,\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\",\"zeroline\":false,\"zerolinecolor\":\"rgb(36,36,36)\"},\"zaxis\":{\"backgroundcolor\":\"white\",\"gridcolor\":\"rgb(232,232,232)\",\"gridwidth\":2,\"linecolor\":\"rgb(36,36,36)\",\"showbackground\":true,\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\",\"zeroline\":false,\"zerolinecolor\":\"rgb(36,36,36)\"}},\"shapedefaults\":{\"fillcolor\":\"black\",\"line\":{\"width\":0},\"opacity\":0.3},\"ternary\":{\"aaxis\":{\"gridcolor\":\"rgb(232,232,232)\",\"linecolor\":\"rgb(36,36,36)\",\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\"},\"baxis\":{\"gridcolor\":\"rgb(232,232,232)\",\"linecolor\":\"rgb(36,36,36)\",\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\"},\"bgcolor\":\"white\",\"caxis\":{\"gridcolor\":\"rgb(232,232,232)\",\"linecolor\":\"rgb(36,36,36)\",\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\"}},\"title\":{\"x\":0.05},\"xaxis\":{\"automargin\":true,\"gridcolor\":\"rgb(232,232,232)\",\"linecolor\":\"rgb(36,36,36)\",\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\",\"title\":{\"standoff\":15},\"zeroline\":false,\"zerolinecolor\":\"rgb(36,36,36)\"},\"yaxis\":{\"automargin\":true,\"gridcolor\":\"rgb(232,232,232)\",\"linecolor\":\"rgb(36,36,36)\",\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\",\"title\":{\"standoff\":15},\"zeroline\":false,\"zerolinecolor\":\"rgb(36,36,36)\"}}},\"title\":{\"text\":\"Cd vs. Alpha\"},\"xaxis\":{\"anchor\":\"y\",\"domain\":[0.0,1.0],\"gridcolor\":\"Gray\",\"gridwidth\":1,\"linecolor\":\"black\",\"linewidth\":1,\"mirror\":false,\"range\":[-15,15],\"showgrid\":true,\"showline\":true,\"title\":{\"text\":\"Alpha [deg]\"},\"zeroline\":true,\"zerolinecolor\":\"black\",\"zerolinewidth\":2},\"yaxis\":{\"anchor\":\"x\",\"domain\":[0.0,1.0],\"gridcolor\":\"Gray\",\"gridwidth\":0.5,\"linecolor\":\"black\",\"linewidth\":1,\"mirror\":false,\"showgrid\":true,\"showline\":true,\"title\":{\"text\":\"Cd\"},\"zeroline\":true,\"zerolinecolor\":\"Gray\",\"zerolinewidth\":1}},                        {\"responsive\": true}                    ).then(function(){\n",
       "                            \n",
       "var gd = document.getElementById('fe056d7c-69e6-46f9-a034-391a7a62d651');\n",
       "var x = new MutationObserver(function (mutations, observer) {{\n",
       "        var display = window.getComputedStyle(gd).display;\n",
       "        if (!display || display === 'none') {{\n",
       "            console.log([gd, 'removed!']);\n",
       "            Plotly.purge(gd);\n",
       "            observer.disconnect();\n",
       "        }}\n",
       "}});\n",
       "\n",
       "// Listen for the removal of the full notebook cells\n",
       "var notebookContainer = gd.closest('#notebook-container');\n",
       "if (notebookContainer) {{\n",
       "    x.observe(notebookContainer, {childList: true});\n",
       "}}\n",
       "\n",
       "// Listen for the clearing of the current output cell\n",
       "var outputEl = gd.closest('.output');\n",
       "if (outputEl) {{\n",
       "    x.observe(outputEl, {childList: true});\n",
       "}}\n",
       "\n",
       "                        })                };                });            </script>        </div>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "machplot(f\"MCC0.00/\",\"Cd\")"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 3,
   "id": "6f34f3f0",
   "metadata": {
    "hide_input": true,
    "slideshow": {
     "slide_type": "subslide"
    },
    "tags": [
     "hide-input"
    ]
   },
   "outputs": [
    {
     "data": {
      "application/vnd.plotly.v1+json": {
       "config": {
        "plotlyServerURL": "https://plot.ly"
       },
       "data": [
        {
         "hovertemplate": "M=0.2<br>Alpha=%{x}<br>Cm=%{y}<extra></extra>",
         "legendgroup": "0.2",
         "line": {
          "color": "#f0f921",
          "dash": "solid"
         },
         "mode": "lines",
         "name": "0.2",
         "orientation": "v",
         "showlegend": true,
         "textposition": "top center",
         "type": "scatter",
         "x": [
          -6,
          -5.76767677,
          -5.53535354,
          -5.3030303,
          -5.07070707,
          -4.83838384,
          -4.60606061,
          -4.37373737,
          -4.14141414,
          -3.90909091,
          -3.67676768,
          -3.44444444,
          -3.21212121,
          -2.97979798,
          -2.74747475,
          -2.51515152,
          -2.28282828,
          -2.05050505,
          -1.81818182,
          -1.58585859,
          -1.35353535,
          -1.12121212,
          -0.88888889,
          -0.65656566,
          -0.42424242,
          -0.19191919,
          0.04040404,
          0.27272727,
          0.50505051,
          0.73737374,
          0.96969697,
          1.2020202,
          1.43434343,
          1.66666667,
          1.8989899,
          2.13131313,
          2.36363636,
          2.5959596,
          2.82828283,
          3.06060606,
          3.29292929,
          3.52525253,
          3.75757576,
          3.98989899,
          4.22222222,
          4.45454545,
          4.68686869,
          4.91919192,
          5.15151515,
          5.38383838,
          5.61616162,
          5.84848485,
          6.08080808,
          6.31313131,
          6.54545455,
          6.77777778,
          7.01010101,
          7.24242424,
          7.47474747,
          7.70707071,
          7.93939394,
          8.17171717,
          8.4040404,
          8.63636364,
          8.86868687,
          9.1010101,
          9.33333333,
          9.56565657,
          9.7979798,
          10.03030303,
          10.26262626,
          10.49494949,
          10.72727273,
          10.95959596,
          11.19191919,
          11.42424242,
          11.65656566,
          11.88888889,
          12.12121212,
          12.35353535,
          12.58585859,
          12.81818182,
          13.05050505,
          13.28282828,
          13.51515152,
          13.74747475,
          13.97979798,
          14.21212121,
          14.44444444,
          14.67676768,
          14.90909091,
          15.14141414,
          15.37373737,
          15.60606061,
          15.83838384,
          16.07070707,
          16.3030303,
          16.53535354,
          16.76767677,
          17
         ],
         "xaxis": "x",
         "y": [
          -0.01249702,
          -0.01222183,
          -0.01195696,
          -0.01170415,
          -0.01146512,
          -0.0112412,
          -0.01102951,
          -0.0108249,
          -0.01062616,
          -0.01043556,
          -0.01025349,
          -0.01007765,
          -0.00991241,
          -0.00977588,
          -0.00967672,
          -0.00958935,
          -0.00948661,
          -0.0093657,
          -0.0092312,
          -0.0090877,
          -0.00893979,
          -0.00879204,
          -0.00864888,
          -0.00851041,
          -0.00837219,
          -0.00822953,
          -0.00807777,
          -0.00791587,
          -0.0077515,
          -0.00759357,
          -0.00745102,
          -0.00733097,
          -0.00722974,
          -0.00713967,
          -0.0070531,
          -0.00696267,
          -0.00686595,
          -0.0067647,
          -0.00666079,
          -0.00655609,
          -0.00645169,
          -0.0063471,
          -0.0062417,
          -0.00613486,
          -0.00602543,
          -0.00590992,
          -0.00578416,
          -0.00564399,
          -0.00548612,
          -0.00531781,
          -0.00515341,
          -0.00500741,
          -0.00489357,
          -0.00478586,
          -0.00462318,
          -0.00442045,
          -0.00420251,
          -0.00398339,
          -0.0037531,
          -0.0035068,
          -0.00324709,
          -0.00297805,
          -0.00269715,
          -0.00240206,
          -0.00209289,
          -0.00176521,
          -0.00142629,
          -0.00108583,
          -0.00072541,
          -0.0003426,
          5.757e-05,
          0.00047049,
          0.00088334,
          0.00129992,
          0.00173784,
          0.00218681,
          0.00262765,
          0.003075,
          0.00356496,
          0.00413345,
          0.00473572,
          0.00522466,
          0.00573383,
          0.006336,
          0.0068425,
          0.00731582,
          0.00780818,
          0.00830173,
          0.00879017,
          0.00924326,
          0.00964289,
          0.01002195,
          0.01040502,
          0.01073559,
          0.01087649,
          0.01081417,
          0.01052983,
          0.00992853,
          0.00885144,
          0.00712575
         ],
         "yaxis": "y"
        },
        {
         "hovertemplate": "M=0.3<br>Alpha=%{x}<br>Cm=%{y}<extra></extra>",
         "legendgroup": "0.3",
         "line": {
          "color": "#fdca26",
          "dash": "solid"
         },
         "mode": "lines",
         "name": "0.3",
         "orientation": "v",
         "showlegend": true,
         "textposition": "top center",
         "type": "scatter",
         "x": [
          -6,
          -5.76767677,
          -5.53535354,
          -5.3030303,
          -5.07070707,
          -4.83838384,
          -4.60606061,
          -4.37373737,
          -4.14141414,
          -3.90909091,
          -3.67676768,
          -3.44444444,
          -3.21212121,
          -2.97979798,
          -2.74747475,
          -2.51515152,
          -2.28282828,
          -2.05050505,
          -1.81818182,
          -1.58585859,
          -1.35353535,
          -1.12121212,
          -0.88888889,
          -0.65656566,
          -0.42424242,
          -0.19191919,
          0.04040404,
          0.27272727,
          0.50505051,
          0.73737374,
          0.96969697,
          1.2020202,
          1.43434343,
          1.66666667,
          1.8989899,
          2.13131313,
          2.36363636,
          2.5959596,
          2.82828283,
          3.06060606,
          3.29292929,
          3.52525253,
          3.75757576,
          3.98989899,
          4.22222222,
          4.45454545,
          4.68686869,
          4.91919192,
          5.15151515,
          5.38383838,
          5.61616162,
          5.84848485,
          6.08080808,
          6.31313131,
          6.54545455,
          6.77777778,
          7.01010101,
          7.24242424,
          7.47474747,
          7.70707071,
          7.93939394,
          8.17171717,
          8.4040404,
          8.63636364,
          8.86868687,
          9.1010101,
          9.33333333,
          9.56565657,
          9.7979798,
          10.03030303,
          10.26262626,
          10.49494949,
          10.72727273,
          10.95959596,
          11.19191919,
          11.42424242,
          11.65656566,
          11.88888889,
          12.12121212,
          12.35353535,
          12.58585859,
          12.81818182,
          13.05050505,
          13.28282828,
          13.51515152,
          13.74747475,
          13.97979798,
          14.21212121,
          14.44444444,
          14.67676768,
          14.90909091,
          15.14141414,
          15.37373737,
          15.60606061,
          15.83838384,
          16.07070707,
          16.3030303,
          16.53535354,
          16.76767677,
          17
         ],
         "xaxis": "x",
         "y": [
          -0.01315366,
          -0.01281752,
          -0.01250488,
          -0.01220998,
          -0.01192708,
          -0.01165149,
          -0.01138978,
          -0.01115426,
          -0.01094,
          -0.01072697,
          -0.01051058,
          -0.01030748,
          -0.0101249,
          -0.00994838,
          -0.00976777,
          -0.00959433,
          -0.00944068,
          -0.00930595,
          -0.00918515,
          -0.00907333,
          -0.00896551,
          -0.00885673,
          -0.00874215,
          -0.00862044,
          -0.00849398,
          -0.00836534,
          -0.00823708,
          -0.00811145,
          -0.00799,
          -0.00787416,
          -0.00776537,
          -0.00766454,
          -0.00756953,
          -0.00747707,
          -0.00738386,
          -0.00728675,
          -0.0071843,
          -0.0070766,
          -0.00696376,
          -0.00684589,
          -0.00672305,
          -0.00659514,
          -0.00646204,
          -0.00632365,
          -0.0061794,
          -0.00602661,
          -0.00586203,
          -0.00568237,
          -0.00548493,
          -0.00527386,
          -0.00505791,
          -0.00484589,
          -0.00464615,
          -0.00443972,
          -0.00418446,
          -0.00389484,
          -0.00360493,
          -0.00332812,
          -0.00300481,
          -0.00265837,
          -0.0023124,
          -0.00193712,
          -0.00154078,
          -0.00112917,
          -0.00069198,
          -0.00024691,
          0.00021051,
          0.00070162,
          0.00121394,
          0.00175176,
          0.00231741,
          0.0028901,
          0.00348609,
          0.00411208,
          0.00475305,
          0.00540739,
          0.00607934,
          0.00677209,
          0.00748815,
          0.00822995,
          0.0089885,
          0.00973972,
          0.01049649,
          0.01126663,
          0.01202713,
          0.01277645,
          0.01352164,
          0.01426413,
          0.01497562,
          0.01562972,
          0.01620456,
          0.01667041,
          0.01697369,
          0.01703236,
          0.01673982,
          0.01596421,
          0.01455497,
          0.01232725,
          0.0090478,
          0.00447226
         ],
         "yaxis": "y"
        },
        {
         "hovertemplate": "M=0.4<br>Alpha=%{x}<br>Cm=%{y}<extra></extra>",
         "legendgroup": "0.4",
         "line": {
          "color": "#fb9f3a",
          "dash": "solid"
         },
         "mode": "lines",
         "name": "0.4",
         "orientation": "v",
         "showlegend": true,
         "textposition": "top center",
         "type": "scatter",
         "x": [
          -6,
          -5.76767677,
          -5.53535354,
          -5.3030303,
          -5.07070707,
          -4.83838384,
          -4.60606061,
          -4.37373737,
          -4.14141414,
          -3.90909091,
          -3.67676768,
          -3.44444444,
          -3.21212121,
          -2.97979798,
          -2.74747475,
          -2.51515152,
          -2.28282828,
          -2.05050505,
          -1.81818182,
          -1.58585859,
          -1.35353535,
          -1.12121212,
          -0.88888889,
          -0.65656566,
          -0.42424242,
          -0.19191919,
          0.04040404,
          0.27272727,
          0.50505051,
          0.73737374,
          0.96969697,
          1.2020202,
          1.43434343,
          1.66666667,
          1.8989899,
          2.13131313,
          2.36363636,
          2.5959596,
          2.82828283,
          3.06060606,
          3.29292929,
          3.52525253,
          3.75757576,
          3.98989899,
          4.22222222,
          4.45454545,
          4.68686869,
          4.91919192,
          5.15151515,
          5.38383838,
          5.61616162,
          5.84848485,
          6.08080808,
          6.31313131,
          6.54545455,
          6.77777778,
          7.01010101,
          7.24242424,
          7.47474747,
          7.70707071,
          7.93939394,
          8.17171717,
          8.4040404,
          8.63636364,
          8.86868687,
          9.1010101,
          9.33333333,
          9.56565657,
          9.7979798,
          10.03030303,
          10.26262626,
          10.49494949,
          10.72727273,
          10.95959596,
          11.19191919,
          11.42424242,
          11.65656566,
          11.88888889,
          12.12121212,
          12.35353535,
          12.58585859,
          12.81818182,
          13.05050505,
          13.28282828,
          13.51515152,
          13.74747475,
          13.97979798,
          14.21212121,
          14.44444444,
          14.67676768,
          14.90909091,
          15.14141414,
          15.37373737,
          15.60606061,
          15.83838384,
          16.07070707,
          16.3030303,
          16.53535354,
          16.76767677,
          17
         ],
         "xaxis": "x",
         "y": [
          -0.01497397,
          -0.01446314,
          -0.01398811,
          -0.01354619,
          -0.01313468,
          -0.01275094,
          -0.01239299,
          -0.01205917,
          -0.01174763,
          -0.01145632,
          -0.01118442,
          -0.01093266,
          -0.01069827,
          -0.01047118,
          -0.01024558,
          -0.01003155,
          -0.00983981,
          -0.00966947,
          -0.00951612,
          -0.00937535,
          -0.00924274,
          -0.00911386,
          -0.00898443,
          -0.00885277,
          -0.00872007,
          -0.00858762,
          -0.00845673,
          -0.00832832,
          -0.00820239,
          -0.00807881,
          -0.00795745,
          -0.00783795,
          -0.00771852,
          -0.00759688,
          -0.00747074,
          -0.00733785,
          -0.00719692,
          -0.00704743,
          -0.00688888,
          -0.00672079,
          -0.0065425,
          -0.00635301,
          -0.00615132,
          -0.00593639,
          -0.00570718,
          -0.00546249,
          -0.00520108,
          -0.0049217,
          -0.00462314,
          -0.00430472,
          -0.00396603,
          -0.00360673,
          -0.0032264,
          -0.00282227,
          -0.00238893,
          -0.00192461,
          -0.00143726,
          -0.00093242,
          -0.00039339,
          0.00018608,
          0.00079894,
          0.00143474,
          0.00210498,
          0.00282217,
          0.00358258,
          0.00437275,
          0.00519526,
          0.00606848,
          0.00699627,
          0.00796452,
          0.00896682,
          0.01002916,
          0.01115229,
          0.01235877,
          0.01369849,
          0.0151972,
          0.01686539,
          0.01865942,
          0.02050146,
          0.02231298,
          0.023992,
          0.02540202,
          0.02646577,
          0.02710452,
          0.02716489,
          0.02637114,
          0.02483825,
          0.02281415,
          0.01971888,
          0.01565633,
          0.01100706,
          0.00553567,
          -0.00029295,
          -0.00612005,
          -0.01239507,
          -0.01861243,
          -0.02435003,
          -0.02969155,
          -0.03460075,
          -0.03899999
         ],
         "yaxis": "y"
        },
        {
         "hovertemplate": "M=0.5<br>Alpha=%{x}<br>Cm=%{y}<extra></extra>",
         "legendgroup": "0.5",
         "line": {
          "color": "#ed7953",
          "dash": "solid"
         },
         "mode": "lines",
         "name": "0.5",
         "orientation": "v",
         "showlegend": true,
         "textposition": "top center",
         "type": "scatter",
         "x": [
          -5.5,
          -5.3030303,
          -5.10606061,
          -4.90909091,
          -4.71212121,
          -4.51515152,
          -4.31818182,
          -4.12121212,
          -3.92424242,
          -3.72727273,
          -3.53030303,
          -3.33333333,
          -3.13636364,
          -2.93939394,
          -2.74242424,
          -2.54545455,
          -2.34848485,
          -2.15151515,
          -1.95454545,
          -1.75757576,
          -1.56060606,
          -1.36363636,
          -1.16666667,
          -0.96969697,
          -0.77272727,
          -0.57575758,
          -0.37878788,
          -0.18181818,
          0.01515152,
          0.21212121,
          0.40909091,
          0.60606061,
          0.8030303,
          1,
          1.1969697,
          1.39393939,
          1.59090909,
          1.78787879,
          1.98484848,
          2.18181818,
          2.37878788,
          2.57575758,
          2.77272727,
          2.96969697,
          3.16666667,
          3.36363636,
          3.56060606,
          3.75757576,
          3.95454545,
          4.15151515,
          4.34848485,
          4.54545455,
          4.74242424,
          4.93939394,
          5.13636364,
          5.33333333,
          5.53030303,
          5.72727273,
          5.92424242,
          6.12121212,
          6.31818182,
          6.51515152,
          6.71212121,
          6.90909091,
          7.10606061,
          7.3030303,
          7.5,
          7.6969697,
          7.89393939,
          8.09090909,
          8.28787879,
          8.48484848,
          8.68181818,
          8.87878788,
          9.07575758,
          9.27272727,
          9.46969697,
          9.66666667,
          9.86363636,
          10.06060606,
          10.25757576,
          10.45454545,
          10.65151515,
          10.84848485,
          11.04545455,
          11.24242424,
          11.43939394,
          11.63636364,
          11.83333333,
          12.03030303,
          12.22727273,
          12.42424242,
          12.62121212,
          12.81818182,
          13.01515152,
          13.21212121,
          13.40909091,
          13.60606061,
          13.8030303,
          14
         ],
         "xaxis": "x",
         "y": [
          -0.02131625,
          -0.01956493,
          -0.01802626,
          -0.01670279,
          -0.01559709,
          -0.01471171,
          -0.01403945,
          -0.01352395,
          -0.01309398,
          -0.01270503,
          -0.01234873,
          -0.01201965,
          -0.01171479,
          -0.01143211,
          -0.01116962,
          -0.01092541,
          -0.01069761,
          -0.01048456,
          -0.01028471,
          -0.01009626,
          -0.00991702,
          -0.00974483,
          -0.00957901,
          -0.00941975,
          -0.00926685,
          -0.00911904,
          -0.00897489,
          -0.00883298,
          -0.00869189,
          -0.00855037,
          -0.00840769,
          -0.00826325,
          -0.00811646,
          -0.00796669,
          -0.00781318,
          -0.0076545,
          -0.00748904,
          -0.00731521,
          -0.0071314,
          -0.00693609,
          -0.00672816,
          -0.00650661,
          -0.00627044,
          -0.00601866,
          -0.00575018,
          -0.00546351,
          -0.00515694,
          -0.00482877,
          -0.00447732,
          -0.00410092,
          -0.00369812,
          -0.00326763,
          -0.0028081,
          -0.00231824,
          -0.0017965,
          -0.00123911,
          -0.00064097,
          3.05e-06,
          0.00069809,
          0.00144904,
          0.00225754,
          0.00313358,
          0.00411884,
          0.00524149,
          0.00651276,
          0.00793203,
          0.00948536,
          0.01114589,
          0.01287478,
          0.01462563,
          0.01640056,
          0.01823168,
          0.02004008,
          0.0217761,
          0.02346859,
          0.02509156,
          0.02653618,
          0.0276771,
          0.02841647,
          0.02870522,
          0.02851672,
          0.02784137,
          0.02656907,
          0.02466312,
          0.02231624,
          0.01968844,
          0.01682075,
          0.01373985,
          0.01047509,
          0.00705739,
          0.00351769,
          -0.00010432,
          -0.00365291,
          -0.00699319,
          -0.01028847,
          -0.01365747,
          -0.01691295,
          -0.01995216,
          -0.02279984,
          -0.02548501
         ],
         "yaxis": "y"
        },
        {
         "hovertemplate": "M=0.6<br>Alpha=%{x}<br>Cm=%{y}<extra></extra>",
         "legendgroup": "0.6",
         "line": {
          "color": "#d8576b",
          "dash": "solid"
         },
         "mode": "lines",
         "name": "0.6",
         "orientation": "v",
         "showlegend": true,
         "textposition": "top center",
         "type": "scatter",
         "x": [
          -6,
          -5.86262626,
          -5.72525253,
          -5.58787879,
          -5.45050505,
          -5.31313131,
          -5.17575758,
          -5.03838384,
          -4.9010101,
          -4.76363636,
          -4.62626263,
          -4.48888889,
          -4.35151515,
          -4.21414141,
          -4.07676768,
          -3.93939394,
          -3.8020202,
          -3.66464646,
          -3.52727273,
          -3.38989899,
          -3.25252525,
          -3.11515152,
          -2.97777778,
          -2.84040404,
          -2.7030303,
          -2.56565657,
          -2.42828283,
          -2.29090909,
          -2.15353535,
          -2.01616162,
          -1.87878788,
          -1.74141414,
          -1.6040404,
          -1.46666667,
          -1.32929293,
          -1.19191919,
          -1.05454545,
          -0.91717172,
          -0.77979798,
          -0.64242424,
          -0.50505051,
          -0.36767677,
          -0.23030303,
          -0.09292929,
          0.04444444,
          0.18181818,
          0.31919192,
          0.45656566,
          0.59393939,
          0.73131313,
          0.86868687,
          1.00606061,
          1.14343434,
          1.28080808,
          1.41818182,
          1.55555556,
          1.69292929,
          1.83030303,
          1.96767677,
          2.10505051,
          2.24242424,
          2.37979798,
          2.51717172,
          2.65454545,
          2.79191919,
          2.92929293,
          3.06666667,
          3.2040404,
          3.34141414,
          3.47878788,
          3.61616162,
          3.75353535,
          3.89090909,
          4.02828283,
          4.16565657,
          4.3030303,
          4.44040404,
          4.57777778,
          4.71515152,
          4.85252525,
          4.98989899,
          5.12727273,
          5.26464646,
          5.4020202,
          5.53939394,
          5.67676768,
          5.81414141,
          5.95151515,
          6.08888889,
          6.22626263,
          6.36363636,
          6.5010101,
          6.63838384,
          6.77575758,
          6.91313131,
          7.05050505,
          7.18787879,
          7.32525253,
          7.46262626,
          7.6
         ],
         "xaxis": "x",
         "y": [
          -0.04078778,
          -0.03967414,
          -0.03841109,
          -0.037029,
          -0.03555824,
          -0.03402919,
          -0.03247221,
          -0.03091769,
          -0.02939491,
          -0.02792281,
          -0.02651453,
          -0.02518314,
          -0.02393547,
          -0.02275864,
          -0.0216359,
          -0.02055076,
          -0.01949411,
          -0.01846545,
          -0.01746478,
          -0.01649484,
          -0.01557849,
          -0.01474761,
          -0.01403406,
          -0.01345422,
          -0.01298596,
          -0.01260128,
          -0.01227262,
          -0.01198194,
          -0.01172013,
          -0.01147845,
          -0.01124907,
          -0.01102956,
          -0.01081937,
          -0.01061795,
          -0.01042469,
          -0.01023881,
          -0.01005954,
          -0.00988608,
          -0.00971736,
          -0.00955215,
          -0.00938919,
          -0.00922724,
          -0.00906505,
          -0.00890136,
          -0.00873493,
          -0.00856482,
          -0.00839054,
          -0.00821166,
          -0.00802775,
          -0.00783836,
          -0.00764307,
          -0.00744143,
          -0.00723245,
          -0.00701313,
          -0.00678005,
          -0.00652977,
          -0.00625886,
          -0.00596391,
          -0.00564147,
          -0.0052881,
          -0.00490015,
          -0.00447388,
          -0.00400553,
          -0.00349135,
          -0.00292761,
          -0.00231055,
          -0.00163664,
          -0.00090745,
          -0.0001299,
          0.00068886,
          0.00154169,
          0.00242142,
          0.00332091,
          0.00423301,
          0.00515377,
          0.0060862,
          0.00703424,
          0.00800183,
          0.00899291,
          0.01001143,
          0.01106132,
          0.01214307,
          0.01323999,
          0.01433001,
          0.01539107,
          0.01640111,
          0.01733807,
          0.01817989,
          0.0189024,
          0.01945529,
          0.01977095,
          0.01979609,
          0.01949368,
          0.01884695,
          0.01787387,
          0.01659639,
          0.0150549,
          0.01331581,
          0.01144751,
          0.00951839
         ],
         "yaxis": "y"
        },
        {
         "hovertemplate": "M=0.7<br>Alpha=%{x}<br>Cm=%{y}<extra></extra>",
         "legendgroup": "0.7",
         "line": {
          "color": "#bd3786",
          "dash": "solid"
         },
         "mode": "lines",
         "name": "0.7",
         "orientation": "v",
         "showlegend": true,
         "textposition": "top center",
         "type": "scatter",
         "x": [
          -6,
          -5.86868687,
          -5.73737374,
          -5.60606061,
          -5.47474747,
          -5.34343434,
          -5.21212121,
          -5.08080808,
          -4.94949495,
          -4.81818182,
          -4.68686869,
          -4.55555556,
          -4.42424242,
          -4.29292929,
          -4.16161616,
          -4.03030303,
          -3.8989899,
          -3.76767677,
          -3.63636364,
          -3.50505051,
          -3.37373737,
          -3.24242424,
          -3.11111111,
          -2.97979798,
          -2.84848485,
          -2.71717172,
          -2.58585859,
          -2.45454545,
          -2.32323232,
          -2.19191919,
          -2.06060606,
          -1.92929293,
          -1.7979798,
          -1.66666667,
          -1.53535354,
          -1.4040404,
          -1.27272727,
          -1.14141414,
          -1.01010101,
          -0.87878788,
          -0.74747475,
          -0.61616162,
          -0.48484848,
          -0.35353535,
          -0.22222222,
          -0.09090909,
          0.04040404,
          0.17171717,
          0.3030303,
          0.43434343,
          0.56565657,
          0.6969697,
          0.82828283,
          0.95959596,
          1.09090909,
          1.22222222,
          1.35353535,
          1.48484848,
          1.61616162,
          1.74747475,
          1.87878788,
          2.01010101,
          2.14141414,
          2.27272727,
          2.4040404,
          2.53535354,
          2.66666667,
          2.7979798,
          2.92929293,
          3.06060606,
          3.19191919,
          3.32323232,
          3.45454545,
          3.58585859,
          3.71717172,
          3.84848485,
          3.97979798,
          4.11111111,
          4.24242424,
          4.37373737,
          4.50505051,
          4.63636364,
          4.76767677,
          4.8989899,
          5.03030303,
          5.16161616,
          5.29292929,
          5.42424242,
          5.55555556,
          5.68686869,
          5.81818182,
          5.94949495,
          6.08080808,
          6.21212121,
          6.34343434,
          6.47474747,
          6.60606061,
          6.73737374,
          6.86868687,
          7
         ],
         "xaxis": "x",
         "y": [
          -0.04525966,
          -0.04508931,
          -0.04481651,
          -0.04444853,
          -0.0439926,
          -0.043456,
          -0.04284598,
          -0.0421698,
          -0.04143456,
          -0.04064136,
          -0.0397831,
          -0.03885212,
          -0.03784041,
          -0.0367343,
          -0.03551548,
          -0.03416549,
          -0.03267199,
          -0.03107243,
          -0.02942856,
          -0.02780233,
          -0.02624702,
          -0.02477706,
          -0.02339602,
          -0.02210744,
          -0.02091068,
          -0.0197945,
          -0.018746,
          -0.01775241,
          -0.01680867,
          -0.0159213,
          -0.01509775,
          -0.01434506,
          -0.0136622,
          -0.01304086,
          -0.01247247,
          -0.01194844,
          -0.0114602,
          -0.01099916,
          -0.01055676,
          -0.01012475,
          -0.0096965,
          -0.00926592,
          -0.00882692,
          -0.0083734,
          -0.00789926,
          -0.00739842,
          -0.00686485,
          -0.0062985,
          -0.00570917,
          -0.00510762,
          -0.00450459,
          -0.00391084,
          -0.0033371,
          -0.00279413,
          -0.00229173,
          -0.00182957,
          -0.00140124,
          -0.00100027,
          -0.00062016,
          -0.00025442,
          0.00010343,
          0.0004599,
          0.00081969,
          0.0011819,
          0.00154451,
          0.0019055,
          0.00226285,
          0.00261455,
          0.00295856,
          0.00329251,
          0.00360405,
          0.00386976,
          0.00406569,
          0.00416787,
          0.00415234,
          0.00399511,
          0.00367223,
          0.00316482,
          0.00248642,
          0.00166337,
          0.00072201,
          -0.00031129,
          -0.00141019,
          -0.00254834,
          -0.00369943,
          -0.00484541,
          -0.00598507,
          -0.00711928,
          -0.00824889,
          -0.00937477,
          -0.01049779,
          -0.0116188,
          -0.01273839,
          -0.01385306,
          -0.01495641,
          -0.01604647,
          -0.01712828,
          -0.0182075,
          -0.0192898,
          -0.02038083
         ],
         "yaxis": "y"
        },
        {
         "hovertemplate": "M=0.75<br>Alpha=%{x}<br>Cm=%{y}<extra></extra>",
         "legendgroup": "0.75",
         "line": {
          "color": "#9c179e",
          "dash": "solid"
         },
         "mode": "lines",
         "name": "0.75",
         "orientation": "v",
         "showlegend": true,
         "textposition": "top center",
         "type": "scatter",
         "x": [
          -6,
          -5.87272727,
          -5.74545455,
          -5.61818182,
          -5.49090909,
          -5.36363636,
          -5.23636364,
          -5.10909091,
          -4.98181818,
          -4.85454545,
          -4.72727273,
          -4.6,
          -4.47272727,
          -4.34545455,
          -4.21818182,
          -4.09090909,
          -3.96363636,
          -3.83636364,
          -3.70909091,
          -3.58181818,
          -3.45454545,
          -3.32727273,
          -3.2,
          -3.07272727,
          -2.94545455,
          -2.81818182,
          -2.69090909,
          -2.56363636,
          -2.43636364,
          -2.30909091,
          -2.18181818,
          -2.05454545,
          -1.92727273,
          -1.8,
          -1.67272727,
          -1.54545455,
          -1.41818182,
          -1.29090909,
          -1.16363636,
          -1.03636364,
          -0.90909091,
          -0.78181818,
          -0.65454545,
          -0.52727273,
          -0.4,
          -0.27272727,
          -0.14545455,
          -0.01818182,
          0.10909091,
          0.23636364,
          0.36363636,
          0.49090909,
          0.61818182,
          0.74545455,
          0.87272727,
          1,
          1.12727273,
          1.25454545,
          1.38181818,
          1.50909091,
          1.63636364,
          1.76363636,
          1.89090909,
          2.01818182,
          2.14545455,
          2.27272727,
          2.4,
          2.52727273,
          2.65454545,
          2.78181818,
          2.90909091,
          3.03636364,
          3.16363636,
          3.29090909,
          3.41818182,
          3.54545455,
          3.67272727,
          3.8,
          3.92727273,
          4.05454545,
          4.18181818,
          4.30909091,
          4.43636364,
          4.56363636,
          4.69090909,
          4.81818182,
          4.94545455,
          5.07272727,
          5.2,
          5.32727273,
          5.45454545,
          5.58181818,
          5.70909091,
          5.83636364,
          5.96363636,
          6.09090909,
          6.21818182,
          6.34545455,
          6.47272727,
          6.6
         ],
         "xaxis": "x",
         "y": [
          -0.02590667,
          -0.0264751,
          -0.0270202,
          -0.02752468,
          -0.02797124,
          -0.02834256,
          -0.02862134,
          -0.02879029,
          -0.02883213,
          -0.02874992,
          -0.02860003,
          -0.02844746,
          -0.02835707,
          -0.02836907,
          -0.02847085,
          -0.02864293,
          -0.02886582,
          -0.02911687,
          -0.02936784,
          -0.02958994,
          -0.02975416,
          -0.0298205,
          -0.02973297,
          -0.02943434,
          -0.02886843,
          -0.02801405,
          -0.02689218,
          -0.02552631,
          -0.02394158,
          -0.02220095,
          -0.0204052,
          -0.01865677,
          -0.01705435,
          -0.01563382,
          -0.01437892,
          -0.01327182,
          -0.01229471,
          -0.01142975,
          -0.0106591,
          -0.00996495,
          -0.00933118,
          -0.00875841,
          -0.00825683,
          -0.0078367,
          -0.00750829,
          -0.00728187,
          -0.00716771,
          -0.00717609,
          -0.00731352,
          -0.0075633,
          -0.00789991,
          -0.0082978,
          -0.00873143,
          -0.00917524,
          -0.0096037,
          -0.00999125,
          -0.01031607,
          -0.01057124,
          -0.01075356,
          -0.01085984,
          -0.01088687,
          -0.01083145,
          -0.0106904,
          -0.01046053,
          -0.01015128,
          -0.00980517,
          -0.00947004,
          -0.00919369,
          -0.00900663,
          -0.00890243,
          -0.00886987,
          -0.00889778,
          -0.0089789,
          -0.0091129,
          -0.00930016,
          -0.00954099,
          -0.00983322,
          -0.01017106,
          -0.0105484,
          -0.01095925,
          -0.01140061,
          -0.01187303,
          -0.01237732,
          -0.0129142,
          -0.01348286,
          -0.01408098,
          -0.01470616,
          -0.01535611,
          -0.01603043,
          -0.01673026,
          -0.01745679,
          -0.018211,
          -0.01899128,
          -0.0197942,
          -0.0206163,
          -0.02145435,
          -0.02230719,
          -0.02317482,
          -0.0240573,
          -0.02495464
         ],
         "yaxis": "y"
        },
        {
         "hovertemplate": "M=0.8<br>Alpha=%{x}<br>Cm=%{y}<extra></extra>",
         "legendgroup": "0.8",
         "line": {
          "color": "#7201a8",
          "dash": "solid"
         },
         "mode": "lines",
         "name": "0.8",
         "orientation": "v",
         "showlegend": true,
         "textposition": "top center",
         "type": "scatter",
         "x": [
          -6,
          -5.86868687,
          -5.73737374,
          -5.60606061,
          -5.47474747,
          -5.34343434,
          -5.21212121,
          -5.08080808,
          -4.94949495,
          -4.81818182,
          -4.68686869,
          -4.55555556,
          -4.42424242,
          -4.29292929,
          -4.16161616,
          -4.03030303,
          -3.8989899,
          -3.76767677,
          -3.63636364,
          -3.50505051,
          -3.37373737,
          -3.24242424,
          -3.11111111,
          -2.97979798,
          -2.84848485,
          -2.71717172,
          -2.58585859,
          -2.45454545,
          -2.32323232,
          -2.19191919,
          -2.06060606,
          -1.92929293,
          -1.7979798,
          -1.66666667,
          -1.53535354,
          -1.4040404,
          -1.27272727,
          -1.14141414,
          -1.01010101,
          -0.87878788,
          -0.74747475,
          -0.61616162,
          -0.48484848,
          -0.35353535,
          -0.22222222,
          -0.09090909,
          0.04040404,
          0.17171717,
          0.3030303,
          0.43434343,
          0.56565657,
          0.6969697,
          0.82828283,
          0.95959596,
          1.09090909,
          1.22222222,
          1.35353535,
          1.48484848,
          1.61616162,
          1.74747475,
          1.87878788,
          2.01010101,
          2.14141414,
          2.27272727,
          2.4040404,
          2.53535354,
          2.66666667,
          2.7979798,
          2.92929293,
          3.06060606,
          3.19191919,
          3.32323232,
          3.45454545,
          3.58585859,
          3.71717172,
          3.84848485,
          3.97979798,
          4.11111111,
          4.24242424,
          4.37373737,
          4.50505051,
          4.63636364,
          4.76767677,
          4.8989899,
          5.03030303,
          5.16161616,
          5.29292929,
          5.42424242,
          5.55555556,
          5.68686869,
          5.81818182,
          5.94949495,
          6.08080808,
          6.21212121,
          6.34343434,
          6.47474747,
          6.60606061,
          6.73737374,
          6.86868687,
          7
         ],
         "xaxis": "x",
         "y": [
          -0.01608658,
          -0.01619822,
          -0.01625344,
          -0.01625022,
          -0.01618646,
          -0.01605372,
          -0.01582903,
          -0.01549418,
          -0.0150434,
          -0.01449861,
          -0.01391638,
          -0.01332427,
          -0.01271475,
          -0.01204687,
          -0.01125367,
          -0.01026742,
          -0.00904132,
          -0.00769966,
          -0.00645028,
          -0.00550157,
          -0.00501918,
          -0.00497695,
          -0.00529486,
          -0.00589295,
          -0.00670558,
          -0.00770347,
          -0.00886308,
          -0.01016026,
          -0.01153901,
          -0.01289564,
          -0.01412254,
          -0.01511696,
          -0.01587044,
          -0.01645979,
          -0.01696487,
          -0.01746557,
          -0.01804175,
          -0.0187733,
          -0.01974008,
          -0.02099779,
          -0.02248019,
          -0.02408269,
          -0.02570069,
          -0.02722959,
          -0.0285648,
          -0.02960172,
          -0.03023657,
          -0.03042602,
          -0.03022707,
          -0.02970618,
          -0.02892981,
          -0.02796443,
          -0.0268765,
          -0.02573248,
          -0.02459557,
          -0.02349454,
          -0.02243735,
          -0.02143173,
          -0.02048536,
          -0.01960596,
          -0.01880123,
          -0.01807886,
          -0.01744361,
          -0.0168908,
          -0.0164139,
          -0.0160064,
          -0.0156636,
          -0.01538417,
          -0.01516712,
          -0.01501145,
          -0.01491568,
          -0.01487776,
          -0.01489561,
          -0.01496704,
          -0.01508816,
          -0.01525402,
          -0.01545961,
          -0.01570134,
          -0.01598448,
          -0.01631783,
          -0.01671017,
          -0.01716611,
          -0.01767544,
          -0.01822459,
          -0.01880008,
          -0.01939393,
          -0.0200095,
          -0.02065421,
          -0.02134786,
          -0.02211387,
          -0.02296418,
          -0.02384829,
          -0.02470101,
          -0.02554592,
          -0.02647134,
          -0.0275119,
          -0.02861604,
          -0.02972475,
          -0.030779,
          -0.03171976
         ],
         "yaxis": "y"
        }
       ],
       "layout": {
        "legend": {
         "title": {
          "text": "M"
         },
         "tracegroupgap": 0
        },
        "margin": {
         "t": 60
        },
        "template": {
         "data": {
          "bar": [
           {
            "error_x": {
             "color": "rgb(36,36,36)"
            },
            "error_y": {
             "color": "rgb(36,36,36)"
            },
            "marker": {
             "line": {
              "color": "white",
              "width": 0.5
             },
             "pattern": {
              "fillmode": "overlay",
              "size": 10,
              "solidity": 0.2
             }
            },
            "type": "bar"
           }
          ],
          "barpolar": [
           {
            "marker": {
             "line": {
              "color": "white",
              "width": 0.5
             },
             "pattern": {
              "fillmode": "overlay",
              "size": 10,
              "solidity": 0.2
             }
            },
            "type": "barpolar"
           }
          ],
          "carpet": [
           {
            "aaxis": {
             "endlinecolor": "rgb(36,36,36)",
             "gridcolor": "white",
             "linecolor": "white",
             "minorgridcolor": "white",
             "startlinecolor": "rgb(36,36,36)"
            },
            "baxis": {
             "endlinecolor": "rgb(36,36,36)",
             "gridcolor": "white",
             "linecolor": "white",
             "minorgridcolor": "white",
             "startlinecolor": "rgb(36,36,36)"
            },
            "type": "carpet"
           }
          ],
          "choropleth": [
           {
            "colorbar": {
             "outlinewidth": 1,
             "tickcolor": "rgb(36,36,36)",
             "ticks": "outside"
            },
            "type": "choropleth"
           }
          ],
          "contour": [
           {
            "colorbar": {
             "outlinewidth": 1,
             "tickcolor": "rgb(36,36,36)",
             "ticks": "outside"
            },
            "colorscale": [
             [
              0,
              "#440154"
             ],
             [
              0.1111111111111111,
              "#482878"
             ],
             [
              0.2222222222222222,
              "#3e4989"
             ],
             [
              0.3333333333333333,
              "#31688e"
             ],
             [
              0.4444444444444444,
              "#26828e"
             ],
             [
              0.5555555555555556,
              "#1f9e89"
             ],
             [
              0.6666666666666666,
              "#35b779"
             ],
             [
              0.7777777777777778,
              "#6ece58"
             ],
             [
              0.8888888888888888,
              "#b5de2b"
             ],
             [
              1,
              "#fde725"
             ]
            ],
            "type": "contour"
           }
          ],
          "contourcarpet": [
           {
            "colorbar": {
             "outlinewidth": 1,
             "tickcolor": "rgb(36,36,36)",
             "ticks": "outside"
            },
            "type": "contourcarpet"
           }
          ],
          "heatmap": [
           {
            "colorbar": {
             "outlinewidth": 1,
             "tickcolor": "rgb(36,36,36)",
             "ticks": "outside"
            },
            "colorscale": [
             [
              0,
              "#440154"
             ],
             [
              0.1111111111111111,
              "#482878"
             ],
             [
              0.2222222222222222,
              "#3e4989"
             ],
             [
              0.3333333333333333,
              "#31688e"
             ],
             [
              0.4444444444444444,
              "#26828e"
             ],
             [
              0.5555555555555556,
              "#1f9e89"
             ],
             [
              0.6666666666666666,
              "#35b779"
             ],
             [
              0.7777777777777778,
              "#6ece58"
             ],
             [
              0.8888888888888888,
              "#b5de2b"
             ],
             [
              1,
              "#fde725"
             ]
            ],
            "type": "heatmap"
           }
          ],
          "heatmapgl": [
           {
            "colorbar": {
             "outlinewidth": 1,
             "tickcolor": "rgb(36,36,36)",
             "ticks": "outside"
            },
            "colorscale": [
             [
              0,
              "#440154"
             ],
             [
              0.1111111111111111,
              "#482878"
             ],
             [
              0.2222222222222222,
              "#3e4989"
             ],
             [
              0.3333333333333333,
              "#31688e"
             ],
             [
              0.4444444444444444,
              "#26828e"
             ],
             [
              0.5555555555555556,
              "#1f9e89"
             ],
             [
              0.6666666666666666,
              "#35b779"
             ],
             [
              0.7777777777777778,
              "#6ece58"
             ],
             [
              0.8888888888888888,
              "#b5de2b"
             ],
             [
              1,
              "#fde725"
             ]
            ],
            "type": "heatmapgl"
           }
          ],
          "histogram": [
           {
            "marker": {
             "line": {
              "color": "white",
              "width": 0.6
             }
            },
            "type": "histogram"
           }
          ],
          "histogram2d": [
           {
            "colorbar": {
             "outlinewidth": 1,
             "tickcolor": "rgb(36,36,36)",
             "ticks": "outside"
            },
            "colorscale": [
             [
              0,
              "#440154"
             ],
             [
              0.1111111111111111,
              "#482878"
             ],
             [
              0.2222222222222222,
              "#3e4989"
             ],
             [
              0.3333333333333333,
              "#31688e"
             ],
             [
              0.4444444444444444,
              "#26828e"
             ],
             [
              0.5555555555555556,
              "#1f9e89"
             ],
             [
              0.6666666666666666,
              "#35b779"
             ],
             [
              0.7777777777777778,
              "#6ece58"
             ],
             [
              0.8888888888888888,
              "#b5de2b"
             ],
             [
              1,
              "#fde725"
             ]
            ],
            "type": "histogram2d"
           }
          ],
          "histogram2dcontour": [
           {
            "colorbar": {
             "outlinewidth": 1,
             "tickcolor": "rgb(36,36,36)",
             "ticks": "outside"
            },
            "colorscale": [
             [
              0,
              "#440154"
             ],
             [
              0.1111111111111111,
              "#482878"
             ],
             [
              0.2222222222222222,
              "#3e4989"
             ],
             [
              0.3333333333333333,
              "#31688e"
             ],
             [
              0.4444444444444444,
              "#26828e"
             ],
             [
              0.5555555555555556,
              "#1f9e89"
             ],
             [
              0.6666666666666666,
              "#35b779"
             ],
             [
              0.7777777777777778,
              "#6ece58"
             ],
             [
              0.8888888888888888,
              "#b5de2b"
             ],
             [
              1,
              "#fde725"
             ]
            ],
            "type": "histogram2dcontour"
           }
          ],
          "mesh3d": [
           {
            "colorbar": {
             "outlinewidth": 1,
             "tickcolor": "rgb(36,36,36)",
             "ticks": "outside"
            },
            "type": "mesh3d"
           }
          ],
          "parcoords": [
           {
            "line": {
             "colorbar": {
              "outlinewidth": 1,
              "tickcolor": "rgb(36,36,36)",
              "ticks": "outside"
             }
            },
            "type": "parcoords"
           }
          ],
          "pie": [
           {
            "automargin": true,
            "type": "pie"
           }
          ],
          "scatter": [
           {
            "marker": {
             "colorbar": {
              "outlinewidth": 1,
              "tickcolor": "rgb(36,36,36)",
              "ticks": "outside"
             }
            },
            "type": "scatter"
           }
          ],
          "scatter3d": [
           {
            "line": {
             "colorbar": {
              "outlinewidth": 1,
              "tickcolor": "rgb(36,36,36)",
              "ticks": "outside"
             }
            },
            "marker": {
             "colorbar": {
              "outlinewidth": 1,
              "tickcolor": "rgb(36,36,36)",
              "ticks": "outside"
             }
            },
            "type": "scatter3d"
           }
          ],
          "scattercarpet": [
           {
            "marker": {
             "colorbar": {
              "outlinewidth": 1,
              "tickcolor": "rgb(36,36,36)",
              "ticks": "outside"
             }
            },
            "type": "scattercarpet"
           }
          ],
          "scattergeo": [
           {
            "marker": {
             "colorbar": {
              "outlinewidth": 1,
              "tickcolor": "rgb(36,36,36)",
              "ticks": "outside"
             }
            },
            "type": "scattergeo"
           }
          ],
          "scattergl": [
           {
            "marker": {
             "colorbar": {
              "outlinewidth": 1,
              "tickcolor": "rgb(36,36,36)",
              "ticks": "outside"
             }
            },
            "type": "scattergl"
           }
          ],
          "scattermapbox": [
           {
            "marker": {
             "colorbar": {
              "outlinewidth": 1,
              "tickcolor": "rgb(36,36,36)",
              "ticks": "outside"
             }
            },
            "type": "scattermapbox"
           }
          ],
          "scatterpolar": [
           {
            "marker": {
             "colorbar": {
              "outlinewidth": 1,
              "tickcolor": "rgb(36,36,36)",
              "ticks": "outside"
             }
            },
            "type": "scatterpolar"
           }
          ],
          "scatterpolargl": [
           {
            "marker": {
             "colorbar": {
              "outlinewidth": 1,
              "tickcolor": "rgb(36,36,36)",
              "ticks": "outside"
             }
            },
            "type": "scatterpolargl"
           }
          ],
          "scatterternary": [
           {
            "marker": {
             "colorbar": {
              "outlinewidth": 1,
              "tickcolor": "rgb(36,36,36)",
              "ticks": "outside"
             }
            },
            "type": "scatterternary"
           }
          ],
          "surface": [
           {
            "colorbar": {
             "outlinewidth": 1,
             "tickcolor": "rgb(36,36,36)",
             "ticks": "outside"
            },
            "colorscale": [
             [
              0,
              "#440154"
             ],
             [
              0.1111111111111111,
              "#482878"
             ],
             [
              0.2222222222222222,
              "#3e4989"
             ],
             [
              0.3333333333333333,
              "#31688e"
             ],
             [
              0.4444444444444444,
              "#26828e"
             ],
             [
              0.5555555555555556,
              "#1f9e89"
             ],
             [
              0.6666666666666666,
              "#35b779"
             ],
             [
              0.7777777777777778,
              "#6ece58"
             ],
             [
              0.8888888888888888,
              "#b5de2b"
             ],
             [
              1,
              "#fde725"
             ]
            ],
            "type": "surface"
           }
          ],
          "table": [
           {
            "cells": {
             "fill": {
              "color": "rgb(237,237,237)"
             },
             "line": {
              "color": "white"
             }
            },
            "header": {
             "fill": {
              "color": "rgb(217,217,217)"
             },
             "line": {
              "color": "white"
             }
            },
            "type": "table"
           }
          ]
         },
         "layout": {
          "annotationdefaults": {
           "arrowhead": 0,
           "arrowwidth": 1
          },
          "autotypenumbers": "strict",
          "coloraxis": {
           "colorbar": {
            "outlinewidth": 1,
            "tickcolor": "rgb(36,36,36)",
            "ticks": "outside"
           }
          },
          "colorscale": {
           "diverging": [
            [
             0,
             "rgb(103,0,31)"
            ],
            [
             0.1,
             "rgb(178,24,43)"
            ],
            [
             0.2,
             "rgb(214,96,77)"
            ],
            [
             0.3,
             "rgb(244,165,130)"
            ],
            [
             0.4,
             "rgb(253,219,199)"
            ],
            [
             0.5,
             "rgb(247,247,247)"
            ],
            [
             0.6,
             "rgb(209,229,240)"
            ],
            [
             0.7,
             "rgb(146,197,222)"
            ],
            [
             0.8,
             "rgb(67,147,195)"
            ],
            [
             0.9,
             "rgb(33,102,172)"
            ],
            [
             1,
             "rgb(5,48,97)"
            ]
           ],
           "sequential": [
            [
             0,
             "#440154"
            ],
            [
             0.1111111111111111,
             "#482878"
            ],
            [
             0.2222222222222222,
             "#3e4989"
            ],
            [
             0.3333333333333333,
             "#31688e"
            ],
            [
             0.4444444444444444,
             "#26828e"
            ],
            [
             0.5555555555555556,
             "#1f9e89"
            ],
            [
             0.6666666666666666,
             "#35b779"
            ],
            [
             0.7777777777777778,
             "#6ece58"
            ],
            [
             0.8888888888888888,
             "#b5de2b"
            ],
            [
             1,
             "#fde725"
            ]
           ],
           "sequentialminus": [
            [
             0,
             "#440154"
            ],
            [
             0.1111111111111111,
             "#482878"
            ],
            [
             0.2222222222222222,
             "#3e4989"
            ],
            [
             0.3333333333333333,
             "#31688e"
            ],
            [
             0.4444444444444444,
             "#26828e"
            ],
            [
             0.5555555555555556,
             "#1f9e89"
            ],
            [
             0.6666666666666666,
             "#35b779"
            ],
            [
             0.7777777777777778,
             "#6ece58"
            ],
            [
             0.8888888888888888,
             "#b5de2b"
            ],
            [
             1,
             "#fde725"
            ]
           ]
          },
          "colorway": [
           "#1F77B4",
           "#FF7F0E",
           "#2CA02C",
           "#D62728",
           "#9467BD",
           "#8C564B",
           "#E377C2",
           "#7F7F7F",
           "#BCBD22",
           "#17BECF"
          ],
          "font": {
           "color": "rgb(36,36,36)"
          },
          "geo": {
           "bgcolor": "white",
           "lakecolor": "white",
           "landcolor": "white",
           "showlakes": true,
           "showland": true,
           "subunitcolor": "white"
          },
          "hoverlabel": {
           "align": "left"
          },
          "hovermode": "closest",
          "mapbox": {
           "style": "light"
          },
          "paper_bgcolor": "white",
          "plot_bgcolor": "white",
          "polar": {
           "angularaxis": {
            "gridcolor": "rgb(232,232,232)",
            "linecolor": "rgb(36,36,36)",
            "showgrid": false,
            "showline": true,
            "ticks": "outside"
           },
           "bgcolor": "white",
           "radialaxis": {
            "gridcolor": "rgb(232,232,232)",
            "linecolor": "rgb(36,36,36)",
            "showgrid": false,
            "showline": true,
            "ticks": "outside"
           }
          },
          "scene": {
           "xaxis": {
            "backgroundcolor": "white",
            "gridcolor": "rgb(232,232,232)",
            "gridwidth": 2,
            "linecolor": "rgb(36,36,36)",
            "showbackground": true,
            "showgrid": false,
            "showline": true,
            "ticks": "outside",
            "zeroline": false,
            "zerolinecolor": "rgb(36,36,36)"
           },
           "yaxis": {
            "backgroundcolor": "white",
            "gridcolor": "rgb(232,232,232)",
            "gridwidth": 2,
            "linecolor": "rgb(36,36,36)",
            "showbackground": true,
            "showgrid": false,
            "showline": true,
            "ticks": "outside",
            "zeroline": false,
            "zerolinecolor": "rgb(36,36,36)"
           },
           "zaxis": {
            "backgroundcolor": "white",
            "gridcolor": "rgb(232,232,232)",
            "gridwidth": 2,
            "linecolor": "rgb(36,36,36)",
            "showbackground": true,
            "showgrid": false,
            "showline": true,
            "ticks": "outside",
            "zeroline": false,
            "zerolinecolor": "rgb(36,36,36)"
           }
          },
          "shapedefaults": {
           "fillcolor": "black",
           "line": {
            "width": 0
           },
           "opacity": 0.3
          },
          "ternary": {
           "aaxis": {
            "gridcolor": "rgb(232,232,232)",
            "linecolor": "rgb(36,36,36)",
            "showgrid": false,
            "showline": true,
            "ticks": "outside"
           },
           "baxis": {
            "gridcolor": "rgb(232,232,232)",
            "linecolor": "rgb(36,36,36)",
            "showgrid": false,
            "showline": true,
            "ticks": "outside"
           },
           "bgcolor": "white",
           "caxis": {
            "gridcolor": "rgb(232,232,232)",
            "linecolor": "rgb(36,36,36)",
            "showgrid": false,
            "showline": true,
            "ticks": "outside"
           }
          },
          "title": {
           "x": 0.05
          },
          "xaxis": {
           "automargin": true,
           "gridcolor": "rgb(232,232,232)",
           "linecolor": "rgb(36,36,36)",
           "showgrid": false,
           "showline": true,
           "ticks": "outside",
           "title": {
            "standoff": 15
           },
           "zeroline": false,
           "zerolinecolor": "rgb(36,36,36)"
          },
          "yaxis": {
           "automargin": true,
           "gridcolor": "rgb(232,232,232)",
           "linecolor": "rgb(36,36,36)",
           "showgrid": false,
           "showline": true,
           "ticks": "outside",
           "title": {
            "standoff": 15
           },
           "zeroline": false,
           "zerolinecolor": "rgb(36,36,36)"
          }
         }
        },
        "title": {
         "text": "Cm vs. Alpha"
        },
        "xaxis": {
         "anchor": "y",
         "domain": [
          0,
          1
         ],
         "gridcolor": "Gray",
         "gridwidth": 1,
         "linecolor": "black",
         "linewidth": 1,
         "mirror": false,
         "range": [
          -15,
          15
         ],
         "showgrid": true,
         "showline": true,
         "title": {
          "text": "Alpha [deg]"
         },
         "zeroline": true,
         "zerolinecolor": "black",
         "zerolinewidth": 2
        },
        "yaxis": {
         "anchor": "x",
         "domain": [
          0,
          1
         ],
         "gridcolor": "Gray",
         "gridwidth": 0.5,
         "linecolor": "black",
         "linewidth": 1,
         "mirror": false,
         "showgrid": true,
         "showline": true,
         "title": {
          "text": "Cm"
         },
         "zeroline": true,
         "zerolinecolor": "Gray",
         "zerolinewidth": 1
        }
       }
      },
      "text/html": [
       "<div>                            <div id=\"057e8cc4-e080-4fe9-ae46-e442ffc12b0b\" class=\"plotly-graph-div\" style=\"height:525px; width:100%;\"></div>            <script type=\"text/javascript\">                require([\"plotly\"], function(Plotly) {                    window.PLOTLYENV=window.PLOTLYENV || {};                                    if (document.getElementById(\"057e8cc4-e080-4fe9-ae46-e442ffc12b0b\")) {                    Plotly.newPlot(                        \"057e8cc4-e080-4fe9-ae46-e442ffc12b0b\",                        [{\"hovertemplate\":\"M=0.2<br>Alpha=%{x}<br>Cm=%{y}<extra></extra>\",\"legendgroup\":\"0.2\",\"line\":{\"color\":\"#f0f921\",\"dash\":\"solid\"},\"mode\":\"lines\",\"name\":\"0.2\",\"orientation\":\"v\",\"showlegend\":true,\"textposition\":\"top center\",\"type\":\"scatter\",\"x\":[-6.0,-5.76767677,-5.53535354,-5.3030303,-5.07070707,-4.83838384,-4.60606061,-4.37373737,-4.14141414,-3.90909091,-3.67676768,-3.44444444,-3.21212121,-2.97979798,-2.74747475,-2.51515152,-2.28282828,-2.05050505,-1.81818182,-1.58585859,-1.35353535,-1.12121212,-0.88888889,-0.65656566,-0.42424242,-0.19191919,0.04040404,0.27272727,0.50505051,0.73737374,0.96969697,1.2020202,1.43434343,1.66666667,1.8989899,2.13131313,2.36363636,2.5959596,2.82828283,3.06060606,3.29292929,3.52525253,3.75757576,3.98989899,4.22222222,4.45454545,4.68686869,4.91919192,5.15151515,5.38383838,5.61616162,5.84848485,6.08080808,6.31313131,6.54545455,6.77777778,7.01010101,7.24242424,7.47474747,7.70707071,7.93939394,8.17171717,8.4040404,8.63636364,8.86868687,9.1010101,9.33333333,9.56565657,9.7979798,10.03030303,10.26262626,10.49494949,10.72727273,10.95959596,11.19191919,11.42424242,11.65656566,11.88888889,12.12121212,12.35353535,12.58585859,12.81818182,13.05050505,13.28282828,13.51515152,13.74747475,13.97979798,14.21212121,14.44444444,14.67676768,14.90909091,15.14141414,15.37373737,15.60606061,15.83838384,16.07070707,16.3030303,16.53535354,16.76767677,17.0],\"xaxis\":\"x\",\"y\":[-0.01249702,-0.01222183,-0.01195696,-0.01170415,-0.01146512,-0.0112412,-0.01102951,-0.0108249,-0.01062616,-0.01043556,-0.01025349,-0.01007765,-0.00991241,-0.00977588,-0.00967672,-0.00958935,-0.00948661,-0.0093657,-0.0092312,-0.0090877,-0.00893979,-0.00879204,-0.00864888,-0.00851041,-0.00837219,-0.00822953,-0.00807777,-0.00791587,-0.0077515,-0.00759357,-0.00745102,-0.00733097,-0.00722974,-0.00713967,-0.0070531,-0.00696267,-0.00686595,-0.0067647,-0.00666079,-0.00655609,-0.00645169,-0.0063471,-0.0062417,-0.00613486,-0.00602543,-0.00590992,-0.00578416,-0.00564399,-0.00548612,-0.00531781,-0.00515341,-0.00500741,-0.00489357,-0.00478586,-0.00462318,-0.00442045,-0.00420251,-0.00398339,-0.0037531,-0.0035068,-0.00324709,-0.00297805,-0.00269715,-0.00240206,-0.00209289,-0.00176521,-0.00142629,-0.00108583,-0.00072541,-0.0003426,5.757e-05,0.00047049,0.00088334,0.00129992,0.00173784,0.00218681,0.00262765,0.003075,0.00356496,0.00413345,0.00473572,0.00522466,0.00573383,0.006336,0.0068425,0.00731582,0.00780818,0.00830173,0.00879017,0.00924326,0.00964289,0.01002195,0.01040502,0.01073559,0.01087649,0.01081417,0.01052983,0.00992853,0.00885144,0.00712575],\"yaxis\":\"y\"},{\"hovertemplate\":\"M=0.3<br>Alpha=%{x}<br>Cm=%{y}<extra></extra>\",\"legendgroup\":\"0.3\",\"line\":{\"color\":\"#fdca26\",\"dash\":\"solid\"},\"mode\":\"lines\",\"name\":\"0.3\",\"orientation\":\"v\",\"showlegend\":true,\"textposition\":\"top center\",\"type\":\"scatter\",\"x\":[-6.0,-5.76767677,-5.53535354,-5.3030303,-5.07070707,-4.83838384,-4.60606061,-4.37373737,-4.14141414,-3.90909091,-3.67676768,-3.44444444,-3.21212121,-2.97979798,-2.74747475,-2.51515152,-2.28282828,-2.05050505,-1.81818182,-1.58585859,-1.35353535,-1.12121212,-0.88888889,-0.65656566,-0.42424242,-0.19191919,0.04040404,0.27272727,0.50505051,0.73737374,0.96969697,1.2020202,1.43434343,1.66666667,1.8989899,2.13131313,2.36363636,2.5959596,2.82828283,3.06060606,3.29292929,3.52525253,3.75757576,3.98989899,4.22222222,4.45454545,4.68686869,4.91919192,5.15151515,5.38383838,5.61616162,5.84848485,6.08080808,6.31313131,6.54545455,6.77777778,7.01010101,7.24242424,7.47474747,7.70707071,7.93939394,8.17171717,8.4040404,8.63636364,8.86868687,9.1010101,9.33333333,9.56565657,9.7979798,10.03030303,10.26262626,10.49494949,10.72727273,10.95959596,11.19191919,11.42424242,11.65656566,11.88888889,12.12121212,12.35353535,12.58585859,12.81818182,13.05050505,13.28282828,13.51515152,13.74747475,13.97979798,14.21212121,14.44444444,14.67676768,14.90909091,15.14141414,15.37373737,15.60606061,15.83838384,16.07070707,16.3030303,16.53535354,16.76767677,17.0],\"xaxis\":\"x\",\"y\":[-0.01315366,-0.01281752,-0.01250488,-0.01220998,-0.01192708,-0.01165149,-0.01138978,-0.01115426,-0.01094,-0.01072697,-0.01051058,-0.01030748,-0.0101249,-0.00994838,-0.00976777,-0.00959433,-0.00944068,-0.00930595,-0.00918515,-0.00907333,-0.00896551,-0.00885673,-0.00874215,-0.00862044,-0.00849398,-0.00836534,-0.00823708,-0.00811145,-0.00799,-0.00787416,-0.00776537,-0.00766454,-0.00756953,-0.00747707,-0.00738386,-0.00728675,-0.0071843,-0.0070766,-0.00696376,-0.00684589,-0.00672305,-0.00659514,-0.00646204,-0.00632365,-0.0061794,-0.00602661,-0.00586203,-0.00568237,-0.00548493,-0.00527386,-0.00505791,-0.00484589,-0.00464615,-0.00443972,-0.00418446,-0.00389484,-0.00360493,-0.00332812,-0.00300481,-0.00265837,-0.0023124,-0.00193712,-0.00154078,-0.00112917,-0.00069198,-0.00024691,0.00021051,0.00070162,0.00121394,0.00175176,0.00231741,0.0028901,0.00348609,0.00411208,0.00475305,0.00540739,0.00607934,0.00677209,0.00748815,0.00822995,0.0089885,0.00973972,0.01049649,0.01126663,0.01202713,0.01277645,0.01352164,0.01426413,0.01497562,0.01562972,0.01620456,0.01667041,0.01697369,0.01703236,0.01673982,0.01596421,0.01455497,0.01232725,0.0090478,0.00447226],\"yaxis\":\"y\"},{\"hovertemplate\":\"M=0.4<br>Alpha=%{x}<br>Cm=%{y}<extra></extra>\",\"legendgroup\":\"0.4\",\"line\":{\"color\":\"#fb9f3a\",\"dash\":\"solid\"},\"mode\":\"lines\",\"name\":\"0.4\",\"orientation\":\"v\",\"showlegend\":true,\"textposition\":\"top center\",\"type\":\"scatter\",\"x\":[-6.0,-5.76767677,-5.53535354,-5.3030303,-5.07070707,-4.83838384,-4.60606061,-4.37373737,-4.14141414,-3.90909091,-3.67676768,-3.44444444,-3.21212121,-2.97979798,-2.74747475,-2.51515152,-2.28282828,-2.05050505,-1.81818182,-1.58585859,-1.35353535,-1.12121212,-0.88888889,-0.65656566,-0.42424242,-0.19191919,0.04040404,0.27272727,0.50505051,0.73737374,0.96969697,1.2020202,1.43434343,1.66666667,1.8989899,2.13131313,2.36363636,2.5959596,2.82828283,3.06060606,3.29292929,3.52525253,3.75757576,3.98989899,4.22222222,4.45454545,4.68686869,4.91919192,5.15151515,5.38383838,5.61616162,5.84848485,6.08080808,6.31313131,6.54545455,6.77777778,7.01010101,7.24242424,7.47474747,7.70707071,7.93939394,8.17171717,8.4040404,8.63636364,8.86868687,9.1010101,9.33333333,9.56565657,9.7979798,10.03030303,10.26262626,10.49494949,10.72727273,10.95959596,11.19191919,11.42424242,11.65656566,11.88888889,12.12121212,12.35353535,12.58585859,12.81818182,13.05050505,13.28282828,13.51515152,13.74747475,13.97979798,14.21212121,14.44444444,14.67676768,14.90909091,15.14141414,15.37373737,15.60606061,15.83838384,16.07070707,16.3030303,16.53535354,16.76767677,17.0],\"xaxis\":\"x\",\"y\":[-0.01497397,-0.01446314,-0.01398811,-0.01354619,-0.01313468,-0.01275094,-0.01239299,-0.01205917,-0.01174763,-0.01145632,-0.01118442,-0.01093266,-0.01069827,-0.01047118,-0.01024558,-0.01003155,-0.00983981,-0.00966947,-0.00951612,-0.00937535,-0.00924274,-0.00911386,-0.00898443,-0.00885277,-0.00872007,-0.00858762,-0.00845673,-0.00832832,-0.00820239,-0.00807881,-0.00795745,-0.00783795,-0.00771852,-0.00759688,-0.00747074,-0.00733785,-0.00719692,-0.00704743,-0.00688888,-0.00672079,-0.0065425,-0.00635301,-0.00615132,-0.00593639,-0.00570718,-0.00546249,-0.00520108,-0.0049217,-0.00462314,-0.00430472,-0.00396603,-0.00360673,-0.0032264,-0.00282227,-0.00238893,-0.00192461,-0.00143726,-0.00093242,-0.00039339,0.00018608,0.00079894,0.00143474,0.00210498,0.00282217,0.00358258,0.00437275,0.00519526,0.00606848,0.00699627,0.00796452,0.00896682,0.01002916,0.01115229,0.01235877,0.01369849,0.0151972,0.01686539,0.01865942,0.02050146,0.02231298,0.023992,0.02540202,0.02646577,0.02710452,0.02716489,0.02637114,0.02483825,0.02281415,0.01971888,0.01565633,0.01100706,0.00553567,-0.00029295,-0.00612005,-0.01239507,-0.01861243,-0.02435003,-0.02969155,-0.03460075,-0.03899999],\"yaxis\":\"y\"},{\"hovertemplate\":\"M=0.5<br>Alpha=%{x}<br>Cm=%{y}<extra></extra>\",\"legendgroup\":\"0.5\",\"line\":{\"color\":\"#ed7953\",\"dash\":\"solid\"},\"mode\":\"lines\",\"name\":\"0.5\",\"orientation\":\"v\",\"showlegend\":true,\"textposition\":\"top center\",\"type\":\"scatter\",\"x\":[-5.5,-5.3030303,-5.10606061,-4.90909091,-4.71212121,-4.51515152,-4.31818182,-4.12121212,-3.92424242,-3.72727273,-3.53030303,-3.33333333,-3.13636364,-2.93939394,-2.74242424,-2.54545455,-2.34848485,-2.15151515,-1.95454545,-1.75757576,-1.56060606,-1.36363636,-1.16666667,-0.96969697,-0.77272727,-0.57575758,-0.37878788,-0.18181818,0.01515152,0.21212121,0.40909091,0.60606061,0.8030303,1.0,1.1969697,1.39393939,1.59090909,1.78787879,1.98484848,2.18181818,2.37878788,2.57575758,2.77272727,2.96969697,3.16666667,3.36363636,3.56060606,3.75757576,3.95454545,4.15151515,4.34848485,4.54545455,4.74242424,4.93939394,5.13636364,5.33333333,5.53030303,5.72727273,5.92424242,6.12121212,6.31818182,6.51515152,6.71212121,6.90909091,7.10606061,7.3030303,7.5,7.6969697,7.89393939,8.09090909,8.28787879,8.48484848,8.68181818,8.87878788,9.07575758,9.27272727,9.46969697,9.66666667,9.86363636,10.06060606,10.25757576,10.45454545,10.65151515,10.84848485,11.04545455,11.24242424,11.43939394,11.63636364,11.83333333,12.03030303,12.22727273,12.42424242,12.62121212,12.81818182,13.01515152,13.21212121,13.40909091,13.60606061,13.8030303,14.0],\"xaxis\":\"x\",\"y\":[-0.02131625,-0.01956493,-0.01802626,-0.01670279,-0.01559709,-0.01471171,-0.01403945,-0.01352395,-0.01309398,-0.01270503,-0.01234873,-0.01201965,-0.01171479,-0.01143211,-0.01116962,-0.01092541,-0.01069761,-0.01048456,-0.01028471,-0.01009626,-0.00991702,-0.00974483,-0.00957901,-0.00941975,-0.00926685,-0.00911904,-0.00897489,-0.00883298,-0.00869189,-0.00855037,-0.00840769,-0.00826325,-0.00811646,-0.00796669,-0.00781318,-0.0076545,-0.00748904,-0.00731521,-0.0071314,-0.00693609,-0.00672816,-0.00650661,-0.00627044,-0.00601866,-0.00575018,-0.00546351,-0.00515694,-0.00482877,-0.00447732,-0.00410092,-0.00369812,-0.00326763,-0.0028081,-0.00231824,-0.0017965,-0.00123911,-0.00064097,3.05e-06,0.00069809,0.00144904,0.00225754,0.00313358,0.00411884,0.00524149,0.00651276,0.00793203,0.00948536,0.01114589,0.01287478,0.01462563,0.01640056,0.01823168,0.02004008,0.0217761,0.02346859,0.02509156,0.02653618,0.0276771,0.02841647,0.02870522,0.02851672,0.02784137,0.02656907,0.02466312,0.02231624,0.01968844,0.01682075,0.01373985,0.01047509,0.00705739,0.00351769,-0.00010432,-0.00365291,-0.00699319,-0.01028847,-0.01365747,-0.01691295,-0.01995216,-0.02279984,-0.02548501],\"yaxis\":\"y\"},{\"hovertemplate\":\"M=0.6<br>Alpha=%{x}<br>Cm=%{y}<extra></extra>\",\"legendgroup\":\"0.6\",\"line\":{\"color\":\"#d8576b\",\"dash\":\"solid\"},\"mode\":\"lines\",\"name\":\"0.6\",\"orientation\":\"v\",\"showlegend\":true,\"textposition\":\"top center\",\"type\":\"scatter\",\"x\":[-6.0,-5.86262626,-5.72525253,-5.58787879,-5.45050505,-5.31313131,-5.17575758,-5.03838384,-4.9010101,-4.76363636,-4.62626263,-4.48888889,-4.35151515,-4.21414141,-4.07676768,-3.93939394,-3.8020202,-3.66464646,-3.52727273,-3.38989899,-3.25252525,-3.11515152,-2.97777778,-2.84040404,-2.7030303,-2.56565657,-2.42828283,-2.29090909,-2.15353535,-2.01616162,-1.87878788,-1.74141414,-1.6040404,-1.46666667,-1.32929293,-1.19191919,-1.05454545,-0.91717172,-0.77979798,-0.64242424,-0.50505051,-0.36767677,-0.23030303,-0.09292929,0.04444444,0.18181818,0.31919192,0.45656566,0.59393939,0.73131313,0.86868687,1.00606061,1.14343434,1.28080808,1.41818182,1.55555556,1.69292929,1.83030303,1.96767677,2.10505051,2.24242424,2.37979798,2.51717172,2.65454545,2.79191919,2.92929293,3.06666667,3.2040404,3.34141414,3.47878788,3.61616162,3.75353535,3.89090909,4.02828283,4.16565657,4.3030303,4.44040404,4.57777778,4.71515152,4.85252525,4.98989899,5.12727273,5.26464646,5.4020202,5.53939394,5.67676768,5.81414141,5.95151515,6.08888889,6.22626263,6.36363636,6.5010101,6.63838384,6.77575758,6.91313131,7.05050505,7.18787879,7.32525253,7.46262626,7.6],\"xaxis\":\"x\",\"y\":[-0.04078778,-0.03967414,-0.03841109,-0.037029,-0.03555824,-0.03402919,-0.03247221,-0.03091769,-0.02939491,-0.02792281,-0.02651453,-0.02518314,-0.02393547,-0.02275864,-0.0216359,-0.02055076,-0.01949411,-0.01846545,-0.01746478,-0.01649484,-0.01557849,-0.01474761,-0.01403406,-0.01345422,-0.01298596,-0.01260128,-0.01227262,-0.01198194,-0.01172013,-0.01147845,-0.01124907,-0.01102956,-0.01081937,-0.01061795,-0.01042469,-0.01023881,-0.01005954,-0.00988608,-0.00971736,-0.00955215,-0.00938919,-0.00922724,-0.00906505,-0.00890136,-0.00873493,-0.00856482,-0.00839054,-0.00821166,-0.00802775,-0.00783836,-0.00764307,-0.00744143,-0.00723245,-0.00701313,-0.00678005,-0.00652977,-0.00625886,-0.00596391,-0.00564147,-0.0052881,-0.00490015,-0.00447388,-0.00400553,-0.00349135,-0.00292761,-0.00231055,-0.00163664,-0.00090745,-0.0001299,0.00068886,0.00154169,0.00242142,0.00332091,0.00423301,0.00515377,0.0060862,0.00703424,0.00800183,0.00899291,0.01001143,0.01106132,0.01214307,0.01323999,0.01433001,0.01539107,0.01640111,0.01733807,0.01817989,0.0189024,0.01945529,0.01977095,0.01979609,0.01949368,0.01884695,0.01787387,0.01659639,0.0150549,0.01331581,0.01144751,0.00951839],\"yaxis\":\"y\"},{\"hovertemplate\":\"M=0.7<br>Alpha=%{x}<br>Cm=%{y}<extra></extra>\",\"legendgroup\":\"0.7\",\"line\":{\"color\":\"#bd3786\",\"dash\":\"solid\"},\"mode\":\"lines\",\"name\":\"0.7\",\"orientation\":\"v\",\"showlegend\":true,\"textposition\":\"top center\",\"type\":\"scatter\",\"x\":[-6.0,-5.86868687,-5.73737374,-5.60606061,-5.47474747,-5.34343434,-5.21212121,-5.08080808,-4.94949495,-4.81818182,-4.68686869,-4.55555556,-4.42424242,-4.29292929,-4.16161616,-4.03030303,-3.8989899,-3.76767677,-3.63636364,-3.50505051,-3.37373737,-3.24242424,-3.11111111,-2.97979798,-2.84848485,-2.71717172,-2.58585859,-2.45454545,-2.32323232,-2.19191919,-2.06060606,-1.92929293,-1.7979798,-1.66666667,-1.53535354,-1.4040404,-1.27272727,-1.14141414,-1.01010101,-0.87878788,-0.74747475,-0.61616162,-0.48484848,-0.35353535,-0.22222222,-0.09090909,0.04040404,0.17171717,0.3030303,0.43434343,0.56565657,0.6969697,0.82828283,0.95959596,1.09090909,1.22222222,1.35353535,1.48484848,1.61616162,1.74747475,1.87878788,2.01010101,2.14141414,2.27272727,2.4040404,2.53535354,2.66666667,2.7979798,2.92929293,3.06060606,3.19191919,3.32323232,3.45454545,3.58585859,3.71717172,3.84848485,3.97979798,4.11111111,4.24242424,4.37373737,4.50505051,4.63636364,4.76767677,4.8989899,5.03030303,5.16161616,5.29292929,5.42424242,5.55555556,5.68686869,5.81818182,5.94949495,6.08080808,6.21212121,6.34343434,6.47474747,6.60606061,6.73737374,6.86868687,7.0],\"xaxis\":\"x\",\"y\":[-0.04525966,-0.04508931,-0.04481651,-0.04444853,-0.0439926,-0.043456,-0.04284598,-0.0421698,-0.04143456,-0.04064136,-0.0397831,-0.03885212,-0.03784041,-0.0367343,-0.03551548,-0.03416549,-0.03267199,-0.03107243,-0.02942856,-0.02780233,-0.02624702,-0.02477706,-0.02339602,-0.02210744,-0.02091068,-0.0197945,-0.018746,-0.01775241,-0.01680867,-0.0159213,-0.01509775,-0.01434506,-0.0136622,-0.01304086,-0.01247247,-0.01194844,-0.0114602,-0.01099916,-0.01055676,-0.01012475,-0.0096965,-0.00926592,-0.00882692,-0.0083734,-0.00789926,-0.00739842,-0.00686485,-0.0062985,-0.00570917,-0.00510762,-0.00450459,-0.00391084,-0.0033371,-0.00279413,-0.00229173,-0.00182957,-0.00140124,-0.00100027,-0.00062016,-0.00025442,0.00010343,0.0004599,0.00081969,0.0011819,0.00154451,0.0019055,0.00226285,0.00261455,0.00295856,0.00329251,0.00360405,0.00386976,0.00406569,0.00416787,0.00415234,0.00399511,0.00367223,0.00316482,0.00248642,0.00166337,0.00072201,-0.00031129,-0.00141019,-0.00254834,-0.00369943,-0.00484541,-0.00598507,-0.00711928,-0.00824889,-0.00937477,-0.01049779,-0.0116188,-0.01273839,-0.01385306,-0.01495641,-0.01604647,-0.01712828,-0.0182075,-0.0192898,-0.02038083],\"yaxis\":\"y\"},{\"hovertemplate\":\"M=0.75<br>Alpha=%{x}<br>Cm=%{y}<extra></extra>\",\"legendgroup\":\"0.75\",\"line\":{\"color\":\"#9c179e\",\"dash\":\"solid\"},\"mode\":\"lines\",\"name\":\"0.75\",\"orientation\":\"v\",\"showlegend\":true,\"textposition\":\"top center\",\"type\":\"scatter\",\"x\":[-6.0,-5.87272727,-5.74545455,-5.61818182,-5.49090909,-5.36363636,-5.23636364,-5.10909091,-4.98181818,-4.85454545,-4.72727273,-4.6,-4.47272727,-4.34545455,-4.21818182,-4.09090909,-3.96363636,-3.83636364,-3.70909091,-3.58181818,-3.45454545,-3.32727273,-3.2,-3.07272727,-2.94545455,-2.81818182,-2.69090909,-2.56363636,-2.43636364,-2.30909091,-2.18181818,-2.05454545,-1.92727273,-1.8,-1.67272727,-1.54545455,-1.41818182,-1.29090909,-1.16363636,-1.03636364,-0.90909091,-0.78181818,-0.65454545,-0.52727273,-0.4,-0.27272727,-0.14545455,-0.01818182,0.10909091,0.23636364,0.36363636,0.49090909,0.61818182,0.74545455,0.87272727,1.0,1.12727273,1.25454545,1.38181818,1.50909091,1.63636364,1.76363636,1.89090909,2.01818182,2.14545455,2.27272727,2.4,2.52727273,2.65454545,2.78181818,2.90909091,3.03636364,3.16363636,3.29090909,3.41818182,3.54545455,3.67272727,3.8,3.92727273,4.05454545,4.18181818,4.30909091,4.43636364,4.56363636,4.69090909,4.81818182,4.94545455,5.07272727,5.2,5.32727273,5.45454545,5.58181818,5.70909091,5.83636364,5.96363636,6.09090909,6.21818182,6.34545455,6.47272727,6.6],\"xaxis\":\"x\",\"y\":[-0.02590667,-0.0264751,-0.0270202,-0.02752468,-0.02797124,-0.02834256,-0.02862134,-0.02879029,-0.02883213,-0.02874992,-0.02860003,-0.02844746,-0.02835707,-0.02836907,-0.02847085,-0.02864293,-0.02886582,-0.02911687,-0.02936784,-0.02958994,-0.02975416,-0.0298205,-0.02973297,-0.02943434,-0.02886843,-0.02801405,-0.02689218,-0.02552631,-0.02394158,-0.02220095,-0.0204052,-0.01865677,-0.01705435,-0.01563382,-0.01437892,-0.01327182,-0.01229471,-0.01142975,-0.0106591,-0.00996495,-0.00933118,-0.00875841,-0.00825683,-0.0078367,-0.00750829,-0.00728187,-0.00716771,-0.00717609,-0.00731352,-0.0075633,-0.00789991,-0.0082978,-0.00873143,-0.00917524,-0.0096037,-0.00999125,-0.01031607,-0.01057124,-0.01075356,-0.01085984,-0.01088687,-0.01083145,-0.0106904,-0.01046053,-0.01015128,-0.00980517,-0.00947004,-0.00919369,-0.00900663,-0.00890243,-0.00886987,-0.00889778,-0.0089789,-0.0091129,-0.00930016,-0.00954099,-0.00983322,-0.01017106,-0.0105484,-0.01095925,-0.01140061,-0.01187303,-0.01237732,-0.0129142,-0.01348286,-0.01408098,-0.01470616,-0.01535611,-0.01603043,-0.01673026,-0.01745679,-0.018211,-0.01899128,-0.0197942,-0.0206163,-0.02145435,-0.02230719,-0.02317482,-0.0240573,-0.02495464],\"yaxis\":\"y\"},{\"hovertemplate\":\"M=0.8<br>Alpha=%{x}<br>Cm=%{y}<extra></extra>\",\"legendgroup\":\"0.8\",\"line\":{\"color\":\"#7201a8\",\"dash\":\"solid\"},\"mode\":\"lines\",\"name\":\"0.8\",\"orientation\":\"v\",\"showlegend\":true,\"textposition\":\"top center\",\"type\":\"scatter\",\"x\":[-6.0,-5.86868687,-5.73737374,-5.60606061,-5.47474747,-5.34343434,-5.21212121,-5.08080808,-4.94949495,-4.81818182,-4.68686869,-4.55555556,-4.42424242,-4.29292929,-4.16161616,-4.03030303,-3.8989899,-3.76767677,-3.63636364,-3.50505051,-3.37373737,-3.24242424,-3.11111111,-2.97979798,-2.84848485,-2.71717172,-2.58585859,-2.45454545,-2.32323232,-2.19191919,-2.06060606,-1.92929293,-1.7979798,-1.66666667,-1.53535354,-1.4040404,-1.27272727,-1.14141414,-1.01010101,-0.87878788,-0.74747475,-0.61616162,-0.48484848,-0.35353535,-0.22222222,-0.09090909,0.04040404,0.17171717,0.3030303,0.43434343,0.56565657,0.6969697,0.82828283,0.95959596,1.09090909,1.22222222,1.35353535,1.48484848,1.61616162,1.74747475,1.87878788,2.01010101,2.14141414,2.27272727,2.4040404,2.53535354,2.66666667,2.7979798,2.92929293,3.06060606,3.19191919,3.32323232,3.45454545,3.58585859,3.71717172,3.84848485,3.97979798,4.11111111,4.24242424,4.37373737,4.50505051,4.63636364,4.76767677,4.8989899,5.03030303,5.16161616,5.29292929,5.42424242,5.55555556,5.68686869,5.81818182,5.94949495,6.08080808,6.21212121,6.34343434,6.47474747,6.60606061,6.73737374,6.86868687,7.0],\"xaxis\":\"x\",\"y\":[-0.01608658,-0.01619822,-0.01625344,-0.01625022,-0.01618646,-0.01605372,-0.01582903,-0.01549418,-0.0150434,-0.01449861,-0.01391638,-0.01332427,-0.01271475,-0.01204687,-0.01125367,-0.01026742,-0.00904132,-0.00769966,-0.00645028,-0.00550157,-0.00501918,-0.00497695,-0.00529486,-0.00589295,-0.00670558,-0.00770347,-0.00886308,-0.01016026,-0.01153901,-0.01289564,-0.01412254,-0.01511696,-0.01587044,-0.01645979,-0.01696487,-0.01746557,-0.01804175,-0.0187733,-0.01974008,-0.02099779,-0.02248019,-0.02408269,-0.02570069,-0.02722959,-0.0285648,-0.02960172,-0.03023657,-0.03042602,-0.03022707,-0.02970618,-0.02892981,-0.02796443,-0.0268765,-0.02573248,-0.02459557,-0.02349454,-0.02243735,-0.02143173,-0.02048536,-0.01960596,-0.01880123,-0.01807886,-0.01744361,-0.0168908,-0.0164139,-0.0160064,-0.0156636,-0.01538417,-0.01516712,-0.01501145,-0.01491568,-0.01487776,-0.01489561,-0.01496704,-0.01508816,-0.01525402,-0.01545961,-0.01570134,-0.01598448,-0.01631783,-0.01671017,-0.01716611,-0.01767544,-0.01822459,-0.01880008,-0.01939393,-0.0200095,-0.02065421,-0.02134786,-0.02211387,-0.02296418,-0.02384829,-0.02470101,-0.02554592,-0.02647134,-0.0275119,-0.02861604,-0.02972475,-0.030779,-0.03171976],\"yaxis\":\"y\"}],                        {\"legend\":{\"title\":{\"text\":\"M\"},\"tracegroupgap\":0},\"margin\":{\"t\":60},\"template\":{\"data\":{\"bar\":[{\"error_x\":{\"color\":\"rgb(36,36,36)\"},\"error_y\":{\"color\":\"rgb(36,36,36)\"},\"marker\":{\"line\":{\"color\":\"white\",\"width\":0.5},\"pattern\":{\"fillmode\":\"overlay\",\"size\":10,\"solidity\":0.2}},\"type\":\"bar\"}],\"barpolar\":[{\"marker\":{\"line\":{\"color\":\"white\",\"width\":0.5},\"pattern\":{\"fillmode\":\"overlay\",\"size\":10,\"solidity\":0.2}},\"type\":\"barpolar\"}],\"carpet\":[{\"aaxis\":{\"endlinecolor\":\"rgb(36,36,36)\",\"gridcolor\":\"white\",\"linecolor\":\"white\",\"minorgridcolor\":\"white\",\"startlinecolor\":\"rgb(36,36,36)\"},\"baxis\":{\"endlinecolor\":\"rgb(36,36,36)\",\"gridcolor\":\"white\",\"linecolor\":\"white\",\"minorgridcolor\":\"white\",\"startlinecolor\":\"rgb(36,36,36)\"},\"type\":\"carpet\"}],\"choropleth\":[{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"},\"type\":\"choropleth\"}],\"contour\":[{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"},\"colorscale\":[[0.0,\"#440154\"],[0.1111111111111111,\"#482878\"],[0.2222222222222222,\"#3e4989\"],[0.3333333333333333,\"#31688e\"],[0.4444444444444444,\"#26828e\"],[0.5555555555555556,\"#1f9e89\"],[0.6666666666666666,\"#35b779\"],[0.7777777777777778,\"#6ece58\"],[0.8888888888888888,\"#b5de2b\"],[1.0,\"#fde725\"]],\"type\":\"contour\"}],\"contourcarpet\":[{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"},\"type\":\"contourcarpet\"}],\"heatmap\":[{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"},\"colorscale\":[[0.0,\"#440154\"],[0.1111111111111111,\"#482878\"],[0.2222222222222222,\"#3e4989\"],[0.3333333333333333,\"#31688e\"],[0.4444444444444444,\"#26828e\"],[0.5555555555555556,\"#1f9e89\"],[0.6666666666666666,\"#35b779\"],[0.7777777777777778,\"#6ece58\"],[0.8888888888888888,\"#b5de2b\"],[1.0,\"#fde725\"]],\"type\":\"heatmap\"}],\"heatmapgl\":[{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"},\"colorscale\":[[0.0,\"#440154\"],[0.1111111111111111,\"#482878\"],[0.2222222222222222,\"#3e4989\"],[0.3333333333333333,\"#31688e\"],[0.4444444444444444,\"#26828e\"],[0.5555555555555556,\"#1f9e89\"],[0.6666666666666666,\"#35b779\"],[0.7777777777777778,\"#6ece58\"],[0.8888888888888888,\"#b5de2b\"],[1.0,\"#fde725\"]],\"type\":\"heatmapgl\"}],\"histogram\":[{\"marker\":{\"line\":{\"color\":\"white\",\"width\":0.6}},\"type\":\"histogram\"}],\"histogram2d\":[{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"},\"colorscale\":[[0.0,\"#440154\"],[0.1111111111111111,\"#482878\"],[0.2222222222222222,\"#3e4989\"],[0.3333333333333333,\"#31688e\"],[0.4444444444444444,\"#26828e\"],[0.5555555555555556,\"#1f9e89\"],[0.6666666666666666,\"#35b779\"],[0.7777777777777778,\"#6ece58\"],[0.8888888888888888,\"#b5de2b\"],[1.0,\"#fde725\"]],\"type\":\"histogram2d\"}],\"histogram2dcontour\":[{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"},\"colorscale\":[[0.0,\"#440154\"],[0.1111111111111111,\"#482878\"],[0.2222222222222222,\"#3e4989\"],[0.3333333333333333,\"#31688e\"],[0.4444444444444444,\"#26828e\"],[0.5555555555555556,\"#1f9e89\"],[0.6666666666666666,\"#35b779\"],[0.7777777777777778,\"#6ece58\"],[0.8888888888888888,\"#b5de2b\"],[1.0,\"#fde725\"]],\"type\":\"histogram2dcontour\"}],\"mesh3d\":[{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"},\"type\":\"mesh3d\"}],\"parcoords\":[{\"line\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"type\":\"parcoords\"}],\"pie\":[{\"automargin\":true,\"type\":\"pie\"}],\"scatter\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"type\":\"scatter\"}],\"scatter3d\":[{\"line\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"marker\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"type\":\"scatter3d\"}],\"scattercarpet\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"type\":\"scattercarpet\"}],\"scattergeo\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"type\":\"scattergeo\"}],\"scattergl\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"type\":\"scattergl\"}],\"scattermapbox\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"type\":\"scattermapbox\"}],\"scatterpolar\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"type\":\"scatterpolar\"}],\"scatterpolargl\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"type\":\"scatterpolargl\"}],\"scatterternary\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"type\":\"scatterternary\"}],\"surface\":[{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"},\"colorscale\":[[0.0,\"#440154\"],[0.1111111111111111,\"#482878\"],[0.2222222222222222,\"#3e4989\"],[0.3333333333333333,\"#31688e\"],[0.4444444444444444,\"#26828e\"],[0.5555555555555556,\"#1f9e89\"],[0.6666666666666666,\"#35b779\"],[0.7777777777777778,\"#6ece58\"],[0.8888888888888888,\"#b5de2b\"],[1.0,\"#fde725\"]],\"type\":\"surface\"}],\"table\":[{\"cells\":{\"fill\":{\"color\":\"rgb(237,237,237)\"},\"line\":{\"color\":\"white\"}},\"header\":{\"fill\":{\"color\":\"rgb(217,217,217)\"},\"line\":{\"color\":\"white\"}},\"type\":\"table\"}]},\"layout\":{\"annotationdefaults\":{\"arrowhead\":0,\"arrowwidth\":1},\"autotypenumbers\":\"strict\",\"coloraxis\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"colorscale\":{\"diverging\":[[0.0,\"rgb(103,0,31)\"],[0.1,\"rgb(178,24,43)\"],[0.2,\"rgb(214,96,77)\"],[0.3,\"rgb(244,165,130)\"],[0.4,\"rgb(253,219,199)\"],[0.5,\"rgb(247,247,247)\"],[0.6,\"rgb(209,229,240)\"],[0.7,\"rgb(146,197,222)\"],[0.8,\"rgb(67,147,195)\"],[0.9,\"rgb(33,102,172)\"],[1.0,\"rgb(5,48,97)\"]],\"sequential\":[[0.0,\"#440154\"],[0.1111111111111111,\"#482878\"],[0.2222222222222222,\"#3e4989\"],[0.3333333333333333,\"#31688e\"],[0.4444444444444444,\"#26828e\"],[0.5555555555555556,\"#1f9e89\"],[0.6666666666666666,\"#35b779\"],[0.7777777777777778,\"#6ece58\"],[0.8888888888888888,\"#b5de2b\"],[1.0,\"#fde725\"]],\"sequentialminus\":[[0.0,\"#440154\"],[0.1111111111111111,\"#482878\"],[0.2222222222222222,\"#3e4989\"],[0.3333333333333333,\"#31688e\"],[0.4444444444444444,\"#26828e\"],[0.5555555555555556,\"#1f9e89\"],[0.6666666666666666,\"#35b779\"],[0.7777777777777778,\"#6ece58\"],[0.8888888888888888,\"#b5de2b\"],[1.0,\"#fde725\"]]},\"colorway\":[\"#1F77B4\",\"#FF7F0E\",\"#2CA02C\",\"#D62728\",\"#9467BD\",\"#8C564B\",\"#E377C2\",\"#7F7F7F\",\"#BCBD22\",\"#17BECF\"],\"font\":{\"color\":\"rgb(36,36,36)\"},\"geo\":{\"bgcolor\":\"white\",\"lakecolor\":\"white\",\"landcolor\":\"white\",\"showlakes\":true,\"showland\":true,\"subunitcolor\":\"white\"},\"hoverlabel\":{\"align\":\"left\"},\"hovermode\":\"closest\",\"mapbox\":{\"style\":\"light\"},\"paper_bgcolor\":\"white\",\"plot_bgcolor\":\"white\",\"polar\":{\"angularaxis\":{\"gridcolor\":\"rgb(232,232,232)\",\"linecolor\":\"rgb(36,36,36)\",\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\"},\"bgcolor\":\"white\",\"radialaxis\":{\"gridcolor\":\"rgb(232,232,232)\",\"linecolor\":\"rgb(36,36,36)\",\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\"}},\"scene\":{\"xaxis\":{\"backgroundcolor\":\"white\",\"gridcolor\":\"rgb(232,232,232)\",\"gridwidth\":2,\"linecolor\":\"rgb(36,36,36)\",\"showbackground\":true,\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\",\"zeroline\":false,\"zerolinecolor\":\"rgb(36,36,36)\"},\"yaxis\":{\"backgroundcolor\":\"white\",\"gridcolor\":\"rgb(232,232,232)\",\"gridwidth\":2,\"linecolor\":\"rgb(36,36,36)\",\"showbackground\":true,\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\",\"zeroline\":false,\"zerolinecolor\":\"rgb(36,36,36)\"},\"zaxis\":{\"backgroundcolor\":\"white\",\"gridcolor\":\"rgb(232,232,232)\",\"gridwidth\":2,\"linecolor\":\"rgb(36,36,36)\",\"showbackground\":true,\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\",\"zeroline\":false,\"zerolinecolor\":\"rgb(36,36,36)\"}},\"shapedefaults\":{\"fillcolor\":\"black\",\"line\":{\"width\":0},\"opacity\":0.3},\"ternary\":{\"aaxis\":{\"gridcolor\":\"rgb(232,232,232)\",\"linecolor\":\"rgb(36,36,36)\",\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\"},\"baxis\":{\"gridcolor\":\"rgb(232,232,232)\",\"linecolor\":\"rgb(36,36,36)\",\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\"},\"bgcolor\":\"white\",\"caxis\":{\"gridcolor\":\"rgb(232,232,232)\",\"linecolor\":\"rgb(36,36,36)\",\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\"}},\"title\":{\"x\":0.05},\"xaxis\":{\"automargin\":true,\"gridcolor\":\"rgb(232,232,232)\",\"linecolor\":\"rgb(36,36,36)\",\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\",\"title\":{\"standoff\":15},\"zeroline\":false,\"zerolinecolor\":\"rgb(36,36,36)\"},\"yaxis\":{\"automargin\":true,\"gridcolor\":\"rgb(232,232,232)\",\"linecolor\":\"rgb(36,36,36)\",\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\",\"title\":{\"standoff\":15},\"zeroline\":false,\"zerolinecolor\":\"rgb(36,36,36)\"}}},\"title\":{\"text\":\"Cm vs. Alpha\"},\"xaxis\":{\"anchor\":\"y\",\"domain\":[0.0,1.0],\"gridcolor\":\"Gray\",\"gridwidth\":1,\"linecolor\":\"black\",\"linewidth\":1,\"mirror\":false,\"range\":[-15,15],\"showgrid\":true,\"showline\":true,\"title\":{\"text\":\"Alpha [deg]\"},\"zeroline\":true,\"zerolinecolor\":\"black\",\"zerolinewidth\":2},\"yaxis\":{\"anchor\":\"x\",\"domain\":[0.0,1.0],\"gridcolor\":\"Gray\",\"gridwidth\":0.5,\"linecolor\":\"black\",\"linewidth\":1,\"mirror\":false,\"showgrid\":true,\"showline\":true,\"title\":{\"text\":\"Cm\"},\"zeroline\":true,\"zerolinecolor\":\"Gray\",\"zerolinewidth\":1}},                        {\"responsive\": true}                    ).then(function(){\n",
       "                            \n",
       "var gd = document.getElementById('057e8cc4-e080-4fe9-ae46-e442ffc12b0b');\n",
       "var x = new MutationObserver(function (mutations, observer) {{\n",
       "        var display = window.getComputedStyle(gd).display;\n",
       "        if (!display || display === 'none') {{\n",
       "            console.log([gd, 'removed!']);\n",
       "            Plotly.purge(gd);\n",
       "            observer.disconnect();\n",
       "        }}\n",
       "}});\n",
       "\n",
       "// Listen for the removal of the full notebook cells\n",
       "var notebookContainer = gd.closest('#notebook-container');\n",
       "if (notebookContainer) {{\n",
       "    x.observe(notebookContainer, {childList: true});\n",
       "}}\n",
       "\n",
       "// Listen for the clearing of the current output cell\n",
       "var outputEl = gd.closest('.output');\n",
       "if (outputEl) {{\n",
       "    x.observe(outputEl, {childList: true});\n",
       "}}\n",
       "\n",
       "                        })                };                });            </script>        </div>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "machplot(f\"MCC0.00/\",\"Cm\")"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "1536de9f",
   "metadata": {
    "slideshow": {
     "slide_type": "skip"
    }
   },
   "source": [
    "Airfoil polars are generated for a limited range of interest where the rotor blade sections predominantly operate. This range is then extended to the range of angles of attack from -180° to 180° using empirical results. This is a valid excercise since conventional helicopter rotor blade sections, when they encounter such extreme operating conditions, generally do not encounter large dynamic pressure. So the rough estimate of airfoil characteristic provided by the empirical relations is acceptable. "
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 4,
   "id": "cecad025",
   "metadata": {
    "hide_input": true,
    "scrolled": false,
    "slideshow": {
     "slide_type": "subslide"
    },
    "tags": [
     "hide-input"
    ]
   },
   "outputs": [
    {
     "data": {
      "application/vnd.plotly.v1+json": {
       "config": {
        "plotlyServerURL": "https://plot.ly"
       },
       "data": [
        {
         "line": {
          "color": "#0000ff"
         },
         "mode": "lines",
         "name": "Empirical curve-fit",
         "type": "scatter",
         "x": [
          -180,
          -180,
          -180,
          -180,
          -180,
          -180,
          -180,
          -179,
          -179,
          -179,
          -179,
          -179,
          -179,
          -179,
          -178,
          -178,
          -178,
          -178,
          -178,
          -178,
          -178,
          -177,
          -177,
          -177,
          -177,
          -177,
          -177,
          -177,
          -175,
          -175,
          -175,
          -175,
          -175,
          -175,
          -175,
          -170,
          -170,
          -170,
          -170,
          -170,
          -170,
          -170,
          -165,
          -165,
          -165,
          -165,
          -165,
          -165,
          -165,
          -160,
          -160,
          -160,
          -160,
          -160,
          -160,
          -160,
          -155,
          -155,
          -155,
          -155,
          -155,
          -155,
          -155,
          -150,
          -150,
          -150,
          -150,
          -150,
          -150,
          -150,
          -145,
          -145,
          -145,
          -145,
          -145,
          -145,
          -145,
          -140,
          -140,
          -140,
          -140,
          -140,
          -140,
          -140,
          -135,
          -135,
          -135,
          -135,
          -135,
          -135,
          -135,
          -130,
          -130,
          -130,
          -130,
          -130,
          -130,
          -130,
          -125,
          -125,
          -125,
          -125,
          -125,
          -125,
          -125,
          -120,
          -120,
          -120,
          -120,
          -120,
          -120,
          -120,
          -115,
          -115,
          -115,
          -115,
          -115,
          -115,
          -115,
          -110,
          -110,
          -110,
          -110,
          -110,
          -110,
          -110,
          -105,
          -105,
          -105,
          -105,
          -105,
          -105,
          -105,
          -100,
          -100,
          -100,
          -100,
          -100,
          -100,
          -100,
          -95,
          -95,
          -95,
          -95,
          -95,
          -95,
          -95,
          -90,
          -90,
          -90,
          -90,
          -90,
          -90,
          -90,
          -85,
          -85,
          -85,
          -85,
          -85,
          -85,
          -85,
          -80,
          -80,
          -80,
          -80,
          -80,
          -80,
          -80,
          -75,
          -75,
          -75,
          -75,
          -75,
          -75,
          -75,
          -70,
          -70,
          -70,
          -70,
          -70,
          -70,
          -70,
          -65,
          -65,
          -65,
          -65,
          -65,
          -65,
          -65,
          -60,
          -60,
          -60,
          -60,
          -60,
          -60,
          -60,
          -55,
          -55,
          -55,
          -55,
          -55,
          -55,
          -55,
          -50,
          -50,
          -50,
          -50,
          -50,
          -50,
          -50,
          -45,
          -45,
          -45,
          -45,
          -45,
          -45,
          -45,
          -40,
          -40,
          -40,
          -40,
          -40,
          -40,
          -40,
          -35,
          -35,
          -35,
          -35,
          -35,
          -35,
          -35,
          -30,
          -30,
          -30,
          -30,
          -30,
          -30,
          -30,
          -25,
          -25,
          -25,
          -25,
          -25,
          -25,
          -25,
          -20,
          -20,
          -20,
          -20,
          -20,
          -20,
          -20,
          -19,
          -19,
          -19,
          -19,
          -19,
          -19,
          -19,
          -18,
          -18,
          -18,
          -18,
          -18,
          -18,
          -18,
          -17,
          -17,
          -17,
          -17,
          -17,
          -17,
          -17,
          -16,
          -16,
          -16,
          -16,
          -16,
          -16,
          -16,
          -15,
          -15,
          -15,
          -15,
          -15,
          -15,
          -15,
          -14,
          -14,
          -14,
          -14,
          -14,
          -14,
          -14,
          -13,
          -13,
          -13,
          -13,
          -13,
          -13,
          -13,
          -12,
          -12,
          -12,
          -12,
          -12,
          -12,
          -12,
          -11,
          -11,
          -11,
          -11,
          -11,
          -11,
          -11,
          -10,
          -10,
          -10,
          -10,
          -10,
          -10,
          -10,
          -9,
          -9,
          -9,
          -9,
          -9,
          -9,
          -9,
          -8,
          -8,
          -8,
          -8,
          -8,
          -8,
          -8,
          -7,
          -7,
          -7,
          -7,
          -7,
          -7,
          -7
         ],
         "y": [
          0.049203893131808875,
          0.049203893131808875,
          0.049203893131808875,
          0.049203893131808875,
          0.049203893131808875,
          0.049203893131808875,
          0.049203893131808875,
          0.0901448580490118,
          0.0901448580490118,
          0.0901448580490118,
          0.0901448580490118,
          0.0901448580490118,
          0.0901448580490118,
          0.0901448580490118,
          0.13097599534243187,
          0.13097599534243187,
          0.13097599534243187,
          0.13097599534243187,
          0.13097599534243187,
          0.13097599534243187,
          0.13097599534243187,
          0.17164755856083366,
          0.17164755856083366,
          0.17164755856083366,
          0.17164755856083366,
          0.17164755856083366,
          0.17164755856083366,
          0.17164755856083366,
          0.2523140094212994,
          0.2523140094212994,
          0.2523140094212994,
          0.2523140094212994,
          0.2523140094212994,
          0.2523140094212994,
          0.2523140094212994,
          0.4477576922115719,
          0.4477576922115719,
          0.4477576922115719,
          0.4477576922115719,
          0.4477576922115719,
          0.4477576922115719,
          0.4477576922115719,
          0.6295964841003207,
          0.6295964841003207,
          0.6295964841003207,
          0.6295964841003207,
          0.6295964841003207,
          0.6295964841003207,
          0.6295964841003207,
          0.7923053054108745,
          0.7923053054108745,
          0.7923053054108745,
          0.7923053054108745,
          0.7923053054108745,
          0.7923053054108745,
          0.7923053054108745,
          0.9309403309423486,
          0.9309403309423486,
          0.9309403309423486,
          0.9309403309423486,
          0.9309403309423486,
          0.9309403309423486,
          0.9309403309423486,
          1.0412892055966774,
          1.0412892055966774,
          1.0412892055966774,
          1.0412892055966774,
          1.0412892055966774,
          1.0412892055966774,
          1.0412892055966774,
          1.1199990346567126,
          1.1199990346567126,
          1.1199990346567126,
          1.1199990346567126,
          1.1199990346567126,
          1.1199990346567126,
          1.1199990346567126,
          1.1646782597955616,
          1.1646782597955616,
          1.1646782597955616,
          1.1646782597955616,
          1.1646782597955616,
          1.1646782597955616,
          1.1646782597955616,
          1.1739693253661587,
          1.1739693253661587,
          1.1739693253661587,
          1.1739693253661587,
          1.1739693253661587,
          1.1739693253661587,
          1.1739693253661587,
          1.1475899270426473,
          1.1475899270426473,
          1.1475899270426473,
          1.1475899270426473,
          1.1475899270426473,
          1.1475899270426473,
          1.1475899270426473,
          1.0863415894944681,
          1.0863415894944681,
          1.0863415894944681,
          1.0863415894944681,
          1.0863415894944681,
          1.0863415894944681,
          1.0863415894944681,
          0.9920853124648673,
          0.9920853124648673,
          0.9920853124648673,
          0.9920853124648673,
          0.9920853124648673,
          0.9920853124648673,
          0.9920853124648673,
          0.8676850252354132,
          0.8676850252354132,
          0.8676850252354132,
          0.8676850252354132,
          0.8676850252354132,
          0.8676850252354132,
          0.8676850252354132,
          0.7169205675839894,
          0.7169205675839894,
          0.7169205675839894,
          0.7169205675839894,
          0.7169205675839894,
          0.7169205675839894,
          0.7169205675839894,
          0.5443728412658372,
          0.5443728412658372,
          0.5443728412658372,
          0.5443728412658372,
          0.5443728412658372,
          0.5443728412658372,
          0.5443728412658372,
          0.3552846216317722,
          0.3552846216317722,
          0.3552846216317722,
          0.3552846216317722,
          0.3552846216317722,
          0.3552846216317722,
          0.3552846216317722,
          0.15540125855211898,
          0.15540125855211898,
          0.15540125855211898,
          0.15540125855211898,
          0.15540125855211898,
          0.15540125855211898,
          0.15540125855211898,
          -0.04920389313180978,
          -0.04920389313180978,
          -0.04920389313180978,
          -0.04920389313180978,
          -0.04920389313180978,
          -0.04920389313180978,
          -0.04920389313180978,
          -0.2523140094212992,
          -0.2523140094212992,
          -0.2523140094212992,
          -0.2523140094212992,
          -0.2523140094212992,
          -0.2523140094212992,
          -0.2523140094212992,
          -0.4477576922115723,
          -0.4477576922115723,
          -0.4477576922115723,
          -0.4477576922115723,
          -0.4477576922115723,
          -0.4477576922115723,
          -0.4477576922115723,
          -0.6295964841003211,
          -0.6295964841003211,
          -0.6295964841003211,
          -0.6295964841003211,
          -0.6295964841003211,
          -0.6295964841003211,
          -0.6295964841003211,
          -0.7923053054108752,
          -0.7923053054108752,
          -0.7923053054108752,
          -0.7923053054108752,
          -0.7923053054108752,
          -0.7923053054108752,
          -0.7923053054108752,
          -0.9309403309423491,
          -0.9309403309423491,
          -0.9309403309423491,
          -0.9309403309423491,
          -0.9309403309423491,
          -0.9309403309423491,
          -0.9309403309423491,
          -1.0412892055966776,
          -1.0412892055966776,
          -1.0412892055966776,
          -1.0412892055966776,
          -1.0412892055966776,
          -1.0412892055966776,
          -1.0412892055966776,
          -1.1199990346567128,
          -1.1199990346567128,
          -1.1199990346567128,
          -1.1199990346567128,
          -1.1199990346567128,
          -1.1199990346567128,
          -1.1199990346567128,
          -1.1646782597955616,
          -1.1646782597955616,
          -1.1646782597955616,
          -1.1646782597955616,
          -1.1646782597955616,
          -1.1646782597955616,
          -1.1646782597955616,
          -1.1739693253661587,
          -1.1739693253661587,
          -1.1739693253661587,
          -1.1739693253661587,
          -1.1739693253661587,
          -1.1739693253661587,
          -1.1739693253661587,
          -1.1475899270426473,
          -1.1475899270426473,
          -1.1475899270426473,
          -1.1475899270426473,
          -1.1475899270426473,
          -1.1475899270426473,
          -1.1475899270426473,
          -1.086341589494468,
          -1.086341589494468,
          -1.086341589494468,
          -1.086341589494468,
          -1.086341589494468,
          -1.086341589494468,
          -1.086341589494468,
          -0.9920853124648678,
          -0.9920853124648678,
          -0.9920853124648678,
          -0.9920853124648678,
          -0.9920853124648678,
          -0.9920853124648678,
          -0.9920853124648678,
          -0.8676850252354135,
          -0.8676850252354135,
          -0.8676850252354135,
          -0.8676850252354135,
          -0.8676850252354135,
          -0.8676850252354135,
          -0.8676850252354135,
          -0.7169205675839895,
          -0.7169205675839895,
          -0.7169205675839895,
          -0.7169205675839895,
          -0.7169205675839895,
          -0.7169205675839895,
          -0.7169205675839895,
          -0.683994489934815,
          -0.683994489934815,
          -0.683994489934815,
          -0.683994489934815,
          -0.683994489934815,
          -0.683994489934815,
          -0.683994489934815,
          -0.6502350703609293,
          -0.6502350703609293,
          -0.6502350703609293,
          -0.6502350703609293,
          -0.6502350703609293,
          -0.6502350703609293,
          -0.6502350703609293,
          -0.615683439514843,
          -0.615683439514843,
          -0.615683439514843,
          -0.615683439514843,
          -0.615683439514843,
          -0.615683439514843,
          -0.615683439514843,
          -0.5803816932364715,
          -0.5803816932364715,
          -0.5803816932364715,
          -0.5803816932364715,
          -0.5803816932364715,
          -0.5803816932364715,
          -0.5803816932364715,
          -0.5443728412658375,
          -0.5443728412658375,
          -0.5443728412658375,
          -0.5443728412658375,
          -0.5443728412658375,
          -0.5443728412658375,
          -0.5443728412658375,
          -0.5077007548423292,
          -0.5077007548423292,
          -0.5077007548423292,
          -0.5077007548423292,
          -0.5077007548423292,
          -0.5077007548423292,
          -0.5077007548423292,
          -0.4704101132543516,
          -0.4704101132543516,
          -0.4704101132543516,
          -0.4704101132543516,
          -0.4704101132543516,
          -0.4704101132543516,
          -0.4704101132543516,
          -0.43254634940449666,
          -0.43254634940449666,
          -0.43254634940449666,
          -0.43254634940449666,
          -0.43254634940449666,
          -0.43254634940449666,
          -0.43254634940449666,
          -0.3941555944565497,
          -0.3941555944565497,
          -0.3941555944565497,
          -0.3941555944565497,
          -0.3941555944565497,
          -0.3941555944565497,
          -0.3941555944565497,
          -0.3552846216317723,
          -0.3552846216317723,
          -0.3552846216317723,
          -0.3552846216317723,
          -0.3552846216317723,
          -0.3552846216317723,
          -0.3552846216317723,
          -0.3159807892229372,
          -0.3159807892229372,
          -0.3159807892229372,
          -0.3159807892229372,
          -0.3159807892229372,
          -0.3159807892229372,
          -0.3159807892229372,
          -0.27629198289554324,
          -0.27629198289554324,
          -0.27629198289554324,
          -0.27629198289554324,
          -0.27629198289554324,
          -0.27629198289554324,
          -0.27629198289554324,
          -0.2362665573465085,
          -0.2362665573465085,
          -0.2362665573465085,
          -0.2362665573465085,
          -0.2362665573465085,
          -0.2362665573465085,
          -0.2362665573465085
         ]
        },
        {
         "marker": {
          "color": "#0000ff"
         },
         "mode": "lines",
         "showlegend": false,
         "type": "scatter",
         "x": [
          18,
          18,
          18,
          18,
          18,
          18,
          18,
          19,
          19,
          19,
          19,
          19,
          19,
          19,
          20,
          20,
          20,
          20,
          20,
          20,
          20,
          25,
          25,
          25,
          25,
          25,
          25,
          25,
          30,
          30,
          30,
          30,
          30,
          30,
          30,
          35,
          35,
          35,
          35,
          35,
          35,
          35,
          40,
          40,
          40,
          40,
          40,
          40,
          40,
          45,
          45,
          45,
          45,
          45,
          45,
          45,
          50,
          50,
          50,
          50,
          50,
          50,
          50,
          55,
          55,
          55,
          55,
          55,
          55,
          55,
          60,
          60,
          60,
          60,
          60,
          60,
          60,
          65,
          65,
          65,
          65,
          65,
          65,
          65,
          70,
          70,
          70,
          70,
          70,
          70,
          70,
          75,
          75,
          75,
          75,
          75,
          75,
          75,
          80,
          80,
          80,
          80,
          80,
          80,
          80,
          85,
          85,
          85,
          85,
          85,
          85,
          85,
          90,
          90,
          90,
          90,
          90,
          90,
          90,
          95,
          95,
          95,
          95,
          95,
          95,
          95,
          100,
          100,
          100,
          100,
          100,
          100,
          100,
          105,
          105,
          105,
          105,
          105,
          105,
          105,
          110,
          110,
          110,
          110,
          110,
          110,
          110,
          115,
          115,
          115,
          115,
          115,
          115,
          115,
          120,
          120,
          120,
          120,
          120,
          120,
          120,
          125,
          125,
          125,
          125,
          125,
          125,
          125,
          130,
          130,
          130,
          130,
          130,
          130,
          130,
          135,
          135,
          135,
          135,
          135,
          135,
          135,
          140,
          140,
          140,
          140,
          140,
          140,
          140,
          145,
          145,
          145,
          145,
          145,
          145,
          145,
          150,
          150,
          150,
          150,
          150,
          150,
          150,
          155,
          155,
          155,
          155,
          155,
          155,
          155,
          160,
          160,
          160,
          160,
          160,
          160,
          160,
          165,
          165,
          165,
          165,
          165,
          165,
          165,
          170,
          170,
          170,
          170,
          170,
          170,
          170,
          175,
          175,
          175,
          175,
          175,
          175,
          175,
          177,
          177,
          177,
          177,
          177,
          177,
          177,
          178,
          178,
          178,
          178,
          178,
          178,
          178,
          179,
          179,
          179,
          179,
          179,
          179,
          179,
          180,
          180,
          180,
          180,
          180,
          180,
          180
         ],
         "y": [
          0.7298486418270146,
          0.7298486418270146,
          0.7298486418270146,
          0.7298486418270146,
          0.7298486418270146,
          0.7298486418270146,
          0.7298486418270146,
          0.7615408837491788,
          0.7615408837491788,
          0.7615408837491788,
          0.7615408837491788,
          0.7615408837491788,
          0.7615408837491788,
          0.7615408837491788,
          0.7923053054108751,
          0.7923053054108751,
          0.7923053054108751,
          0.7923053054108751,
          0.7923053054108751,
          0.7923053054108751,
          0.7923053054108751,
          0.9309403309423491,
          0.9309403309423491,
          0.9309403309423491,
          0.9309403309423491,
          0.9309403309423491,
          0.9309403309423491,
          0.9309403309423491,
          1.0412892055966774,
          1.0412892055966774,
          1.0412892055966774,
          1.0412892055966774,
          1.0412892055966774,
          1.0412892055966774,
          1.0412892055966774,
          1.1199990346567128,
          1.1199990346567128,
          1.1199990346567128,
          1.1199990346567128,
          1.1199990346567128,
          1.1199990346567128,
          1.1199990346567128,
          1.1646782597955616,
          1.1646782597955616,
          1.1646782597955616,
          1.1646782597955616,
          1.1646782597955616,
          1.1646782597955616,
          1.1646782597955616,
          1.1739693253661587,
          1.1739693253661587,
          1.1739693253661587,
          1.1739693253661587,
          1.1739693253661587,
          1.1739693253661587,
          1.1739693253661587,
          1.1475899270426473,
          1.1475899270426473,
          1.1475899270426473,
          1.1475899270426473,
          1.1475899270426473,
          1.1475899270426473,
          1.1475899270426473,
          1.086341589494468,
          1.086341589494468,
          1.086341589494468,
          1.086341589494468,
          1.086341589494468,
          1.086341589494468,
          1.086341589494468,
          0.9920853124648676,
          0.9920853124648676,
          0.9920853124648676,
          0.9920853124648676,
          0.9920853124648676,
          0.9920853124648676,
          0.9920853124648676,
          0.8676850252354135,
          0.8676850252354135,
          0.8676850252354135,
          0.8676850252354135,
          0.8676850252354135,
          0.8676850252354135,
          0.8676850252354135,
          0.7169205675839896,
          0.7169205675839896,
          0.7169205675839896,
          0.7169205675839896,
          0.7169205675839896,
          0.7169205675839896,
          0.7169205675839896,
          0.5443728412658374,
          0.5443728412658374,
          0.5443728412658374,
          0.5443728412658374,
          0.5443728412658374,
          0.5443728412658374,
          0.5443728412658374,
          0.3552846216317724,
          0.3552846216317724,
          0.3552846216317724,
          0.3552846216317724,
          0.3552846216317724,
          0.3552846216317724,
          0.3552846216317724,
          0.1554012585521187,
          0.1554012585521187,
          0.1554012585521187,
          0.1554012585521187,
          0.1554012585521187,
          0.1554012585521187,
          0.1554012585521187,
          -0.049203893131809485,
          -0.049203893131809485,
          -0.049203893131809485,
          -0.049203893131809485,
          -0.049203893131809485,
          -0.049203893131809485,
          -0.049203893131809485,
          -0.2523140094212995,
          -0.2523140094212995,
          -0.2523140094212995,
          -0.2523140094212995,
          -0.2523140094212995,
          -0.2523140094212995,
          -0.2523140094212995,
          -0.4477576922115721,
          -0.4477576922115721,
          -0.4477576922115721,
          -0.4477576922115721,
          -0.4477576922115721,
          -0.4477576922115721,
          -0.4477576922115721,
          -0.6295964841003212,
          -0.6295964841003212,
          -0.6295964841003212,
          -0.6295964841003212,
          -0.6295964841003212,
          -0.6295964841003212,
          -0.6295964841003212,
          -0.7923053054108751,
          -0.7923053054108751,
          -0.7923053054108751,
          -0.7923053054108751,
          -0.7923053054108751,
          -0.7923053054108751,
          -0.7923053054108751,
          -0.930940330942349,
          -0.930940330942349,
          -0.930940330942349,
          -0.930940330942349,
          -0.930940330942349,
          -0.930940330942349,
          -0.930940330942349,
          -1.0412892055966771,
          -1.0412892055966771,
          -1.0412892055966771,
          -1.0412892055966771,
          -1.0412892055966771,
          -1.0412892055966771,
          -1.0412892055966771,
          -1.119999034656713,
          -1.119999034656713,
          -1.119999034656713,
          -1.119999034656713,
          -1.119999034656713,
          -1.119999034656713,
          -1.119999034656713,
          -1.1646782597955614,
          -1.1646782597955614,
          -1.1646782597955614,
          -1.1646782597955614,
          -1.1646782597955614,
          -1.1646782597955614,
          -1.1646782597955614,
          -1.1739693253661587,
          -1.1739693253661587,
          -1.1739693253661587,
          -1.1739693253661587,
          -1.1739693253661587,
          -1.1739693253661587,
          -1.1739693253661587,
          -1.1475899270426473,
          -1.1475899270426473,
          -1.1475899270426473,
          -1.1475899270426473,
          -1.1475899270426473,
          -1.1475899270426473,
          -1.1475899270426473,
          -1.0863415894944681,
          -1.0863415894944681,
          -1.0863415894944681,
          -1.0863415894944681,
          -1.0863415894944681,
          -1.0863415894944681,
          -1.0863415894944681,
          -0.9920853124648683,
          -0.9920853124648683,
          -0.9920853124648683,
          -0.9920853124648683,
          -0.9920853124648683,
          -0.9920853124648683,
          -0.9920853124648683,
          -0.8676850252354135,
          -0.8676850252354135,
          -0.8676850252354135,
          -0.8676850252354135,
          -0.8676850252354135,
          -0.8676850252354135,
          -0.8676850252354135,
          -0.7169205675839897,
          -0.7169205675839897,
          -0.7169205675839897,
          -0.7169205675839897,
          -0.7169205675839897,
          -0.7169205675839897,
          -0.7169205675839897,
          -0.544372841265838,
          -0.544372841265838,
          -0.544372841265838,
          -0.544372841265838,
          -0.544372841265838,
          -0.544372841265838,
          -0.544372841265838,
          -0.35528462163177305,
          -0.35528462163177305,
          -0.35528462163177305,
          -0.35528462163177305,
          -0.35528462163177305,
          -0.35528462163177305,
          -0.35528462163177305,
          -0.15540125855211992,
          -0.15540125855211992,
          -0.15540125855211992,
          -0.15540125855211992,
          -0.15540125855211992,
          -0.15540125855211992,
          -0.15540125855211992,
          -0.07377886044694414,
          -0.07377886044694414,
          -0.07377886044694414,
          -0.07377886044694414,
          -0.07377886044694414,
          -0.07377886044694414,
          -0.07377886044694414,
          -0.03280792550019377,
          -0.03280792550019377,
          -0.03280792550019377,
          -0.03280792550019377,
          -0.03280792550019377,
          -0.03280792550019377,
          -0.03280792550019377,
          0.008202980850104026,
          0.008202980850104026,
          0.008202980850104026,
          0.008202980850104026,
          0.008202980850104026,
          0.008202980850104026,
          0.008202980850104026,
          0.04920389313180935,
          0.04920389313180935,
          0.04920389313180935,
          0.04920389313180935,
          0.04920389313180935,
          0.04920389313180935,
          0.04920389313180935
         ]
        },
        {
         "line": {
          "color": "#0000ff"
         },
         "mode": "markers",
         "name": "CFD",
         "type": "scatter",
         "x": [
          -6,
          -5.76767677,
          -5.53535354,
          -5.3030303,
          -5.07070707,
          -4.83838384,
          -4.60606061,
          -4.37373737,
          -4.14141414,
          -3.90909091,
          -3.67676768,
          -3.44444444,
          -3.21212121,
          -2.97979798,
          -2.74747475,
          -2.51515152,
          -2.28282828,
          -2.05050505,
          -1.81818182,
          -1.58585859,
          -1.35353535,
          -1.12121212,
          -0.88888889,
          -0.65656566,
          -0.42424242,
          -0.19191919,
          0.04040404,
          0.27272727,
          0.50505051,
          0.73737374,
          0.96969697,
          1.2020202,
          1.43434343,
          1.66666667,
          1.8989899,
          2.13131313,
          2.36363636,
          2.5959596,
          2.82828283,
          3.06060606,
          3.29292929,
          3.52525253,
          3.75757576,
          3.98989899,
          4.22222222,
          4.45454545,
          4.68686869,
          4.91919192,
          5.15151515,
          5.38383838,
          5.61616162,
          5.84848485,
          6.08080808,
          6.31313131,
          6.54545455,
          6.77777778,
          7.01010101,
          7.24242424,
          7.47474747,
          7.70707071,
          7.93939394,
          8.17171717,
          8.4040404,
          8.63636364,
          8.86868687,
          9.1010101,
          9.33333333,
          9.56565657,
          9.7979798,
          10.03030303,
          10.26262626,
          10.49494949,
          10.72727273,
          10.95959596,
          11.19191919,
          11.42424242,
          11.65656566,
          11.88888889,
          12.12121212,
          12.35353535,
          12.58585859,
          12.81818182,
          13.05050505,
          13.28282828,
          13.51515152,
          13.74747475,
          13.97979798,
          14.21212121,
          14.44444444,
          14.67676768,
          14.90909091,
          15.14141414,
          15.37373737,
          15.60606061,
          15.83838384,
          16.07070707,
          16.3030303,
          16.53535354,
          16.76767677,
          17
         ],
         "y": [
          -0.57438145,
          -0.54735084,
          -0.52020789,
          -0.49296479,
          -0.46563373,
          -0.43822654,
          -0.41075118,
          -0.3832134,
          -0.35562056,
          -0.32798138,
          -0.30029716,
          -0.27255951,
          -0.24478207,
          -0.2170239,
          -0.18931741,
          -0.16159605,
          -0.13378916,
          -0.10589883,
          -0.07794924,
          -0.04996457,
          -0.02196899,
          0.0060133,
          0.03395877,
          0.06186061,
          0.08972963,
          0.11757753,
          0.14541599,
          0.17325411,
          0.20109487,
          0.22894031,
          0.25679248,
          0.28465202,
          0.312511,
          0.3403584,
          0.36818316,
          0.39597458,
          0.42372762,
          0.45144208,
          0.47911787,
          0.50675493,
          0.53435186,
          0.56190482,
          0.58940969,
          0.61686235,
          0.64425883,
          0.67159577,
          0.69886997,
          0.72607828,
          0.75321725,
          0.7802805,
          0.80725965,
          0.83414628,
          0.86093217,
          0.88761952,
          0.91421151,
          0.94067323,
          0.96704023,
          0.99335133,
          1.01952369,
          1.04550619,
          1.07132642,
          1.09705174,
          1.12262195,
          1.14795714,
          1.17306592,
          1.19803623,
          1.22285062,
          1.24738903,
          1.27163161,
          1.29564366,
          1.31944963,
          1.34290603,
          1.36592873,
          1.38820392,
          1.40916159,
          1.42811212,
          1.44435644,
          1.45761343,
          1.46786655,
          1.47510391,
          1.47938053,
          1.48083297,
          1.47934846,
          1.47500414,
          1.46817606,
          1.45808435,
          1.44542869,
          1.43149019,
          1.413954,
          1.39357078,
          1.3719248,
          1.34726237,
          1.32124431,
          1.29516724,
          1.26664033,
          1.23808438,
          1.21162015,
          1.18707021,
          1.165009,
          1.14625038
         ]
        }
       ],
       "layout": {
        "plot_bgcolor": "rgba(0,0.5,0,0)",
        "template": {
         "data": {
          "bar": [
           {
            "error_x": {
             "color": "rgb(36,36,36)"
            },
            "error_y": {
             "color": "rgb(36,36,36)"
            },
            "marker": {
             "line": {
              "color": "white",
              "width": 0.5
             },
             "pattern": {
              "fillmode": "overlay",
              "size": 10,
              "solidity": 0.2
             }
            },
            "type": "bar"
           }
          ],
          "barpolar": [
           {
            "marker": {
             "line": {
              "color": "white",
              "width": 0.5
             },
             "pattern": {
              "fillmode": "overlay",
              "size": 10,
              "solidity": 0.2
             }
            },
            "type": "barpolar"
           }
          ],
          "carpet": [
           {
            "aaxis": {
             "endlinecolor": "rgb(36,36,36)",
             "gridcolor": "white",
             "linecolor": "white",
             "minorgridcolor": "white",
             "startlinecolor": "rgb(36,36,36)"
            },
            "baxis": {
             "endlinecolor": "rgb(36,36,36)",
             "gridcolor": "white",
             "linecolor": "white",
             "minorgridcolor": "white",
             "startlinecolor": "rgb(36,36,36)"
            },
            "type": "carpet"
           }
          ],
          "choropleth": [
           {
            "colorbar": {
             "outlinewidth": 1,
             "tickcolor": "rgb(36,36,36)",
             "ticks": "outside"
            },
            "type": "choropleth"
           }
          ],
          "contour": [
           {
            "colorbar": {
             "outlinewidth": 1,
             "tickcolor": "rgb(36,36,36)",
             "ticks": "outside"
            },
            "colorscale": [
             [
              0,
              "#440154"
             ],
             [
              0.1111111111111111,
              "#482878"
             ],
             [
              0.2222222222222222,
              "#3e4989"
             ],
             [
              0.3333333333333333,
              "#31688e"
             ],
             [
              0.4444444444444444,
              "#26828e"
             ],
             [
              0.5555555555555556,
              "#1f9e89"
             ],
             [
              0.6666666666666666,
              "#35b779"
             ],
             [
              0.7777777777777778,
              "#6ece58"
             ],
             [
              0.8888888888888888,
              "#b5de2b"
             ],
             [
              1,
              "#fde725"
             ]
            ],
            "type": "contour"
           }
          ],
          "contourcarpet": [
           {
            "colorbar": {
             "outlinewidth": 1,
             "tickcolor": "rgb(36,36,36)",
             "ticks": "outside"
            },
            "type": "contourcarpet"
           }
          ],
          "heatmap": [
           {
            "colorbar": {
             "outlinewidth": 1,
             "tickcolor": "rgb(36,36,36)",
             "ticks": "outside"
            },
            "colorscale": [
             [
              0,
              "#440154"
             ],
             [
              0.1111111111111111,
              "#482878"
             ],
             [
              0.2222222222222222,
              "#3e4989"
             ],
             [
              0.3333333333333333,
              "#31688e"
             ],
             [
              0.4444444444444444,
              "#26828e"
             ],
             [
              0.5555555555555556,
              "#1f9e89"
             ],
             [
              0.6666666666666666,
              "#35b779"
             ],
             [
              0.7777777777777778,
              "#6ece58"
             ],
             [
              0.8888888888888888,
              "#b5de2b"
             ],
             [
              1,
              "#fde725"
             ]
            ],
            "type": "heatmap"
           }
          ],
          "heatmapgl": [
           {
            "colorbar": {
             "outlinewidth": 1,
             "tickcolor": "rgb(36,36,36)",
             "ticks": "outside"
            },
            "colorscale": [
             [
              0,
              "#440154"
             ],
             [
              0.1111111111111111,
              "#482878"
             ],
             [
              0.2222222222222222,
              "#3e4989"
             ],
             [
              0.3333333333333333,
              "#31688e"
             ],
             [
              0.4444444444444444,
              "#26828e"
             ],
             [
              0.5555555555555556,
              "#1f9e89"
             ],
             [
              0.6666666666666666,
              "#35b779"
             ],
             [
              0.7777777777777778,
              "#6ece58"
             ],
             [
              0.8888888888888888,
              "#b5de2b"
             ],
             [
              1,
              "#fde725"
             ]
            ],
            "type": "heatmapgl"
           }
          ],
          "histogram": [
           {
            "marker": {
             "line": {
              "color": "white",
              "width": 0.6
             }
            },
            "type": "histogram"
           }
          ],
          "histogram2d": [
           {
            "colorbar": {
             "outlinewidth": 1,
             "tickcolor": "rgb(36,36,36)",
             "ticks": "outside"
            },
            "colorscale": [
             [
              0,
              "#440154"
             ],
             [
              0.1111111111111111,
              "#482878"
             ],
             [
              0.2222222222222222,
              "#3e4989"
             ],
             [
              0.3333333333333333,
              "#31688e"
             ],
             [
              0.4444444444444444,
              "#26828e"
             ],
             [
              0.5555555555555556,
              "#1f9e89"
             ],
             [
              0.6666666666666666,
              "#35b779"
             ],
             [
              0.7777777777777778,
              "#6ece58"
             ],
             [
              0.8888888888888888,
              "#b5de2b"
             ],
             [
              1,
              "#fde725"
             ]
            ],
            "type": "histogram2d"
           }
          ],
          "histogram2dcontour": [
           {
            "colorbar": {
             "outlinewidth": 1,
             "tickcolor": "rgb(36,36,36)",
             "ticks": "outside"
            },
            "colorscale": [
             [
              0,
              "#440154"
             ],
             [
              0.1111111111111111,
              "#482878"
             ],
             [
              0.2222222222222222,
              "#3e4989"
             ],
             [
              0.3333333333333333,
              "#31688e"
             ],
             [
              0.4444444444444444,
              "#26828e"
             ],
             [
              0.5555555555555556,
              "#1f9e89"
             ],
             [
              0.6666666666666666,
              "#35b779"
             ],
             [
              0.7777777777777778,
              "#6ece58"
             ],
             [
              0.8888888888888888,
              "#b5de2b"
             ],
             [
              1,
              "#fde725"
             ]
            ],
            "type": "histogram2dcontour"
           }
          ],
          "mesh3d": [
           {
            "colorbar": {
             "outlinewidth": 1,
             "tickcolor": "rgb(36,36,36)",
             "ticks": "outside"
            },
            "type": "mesh3d"
           }
          ],
          "parcoords": [
           {
            "line": {
             "colorbar": {
              "outlinewidth": 1,
              "tickcolor": "rgb(36,36,36)",
              "ticks": "outside"
             }
            },
            "type": "parcoords"
           }
          ],
          "pie": [
           {
            "automargin": true,
            "type": "pie"
           }
          ],
          "scatter": [
           {
            "marker": {
             "colorbar": {
              "outlinewidth": 1,
              "tickcolor": "rgb(36,36,36)",
              "ticks": "outside"
             }
            },
            "type": "scatter"
           }
          ],
          "scatter3d": [
           {
            "line": {
             "colorbar": {
              "outlinewidth": 1,
              "tickcolor": "rgb(36,36,36)",
              "ticks": "outside"
             }
            },
            "marker": {
             "colorbar": {
              "outlinewidth": 1,
              "tickcolor": "rgb(36,36,36)",
              "ticks": "outside"
             }
            },
            "type": "scatter3d"
           }
          ],
          "scattercarpet": [
           {
            "marker": {
             "colorbar": {
              "outlinewidth": 1,
              "tickcolor": "rgb(36,36,36)",
              "ticks": "outside"
             }
            },
            "type": "scattercarpet"
           }
          ],
          "scattergeo": [
           {
            "marker": {
             "colorbar": {
              "outlinewidth": 1,
              "tickcolor": "rgb(36,36,36)",
              "ticks": "outside"
             }
            },
            "type": "scattergeo"
           }
          ],
          "scattergl": [
           {
            "marker": {
             "colorbar": {
              "outlinewidth": 1,
              "tickcolor": "rgb(36,36,36)",
              "ticks": "outside"
             }
            },
            "type": "scattergl"
           }
          ],
          "scattermapbox": [
           {
            "marker": {
             "colorbar": {
              "outlinewidth": 1,
              "tickcolor": "rgb(36,36,36)",
              "ticks": "outside"
             }
            },
            "type": "scattermapbox"
           }
          ],
          "scatterpolar": [
           {
            "marker": {
             "colorbar": {
              "outlinewidth": 1,
              "tickcolor": "rgb(36,36,36)",
              "ticks": "outside"
             }
            },
            "type": "scatterpolar"
           }
          ],
          "scatterpolargl": [
           {
            "marker": {
             "colorbar": {
              "outlinewidth": 1,
              "tickcolor": "rgb(36,36,36)",
              "ticks": "outside"
             }
            },
            "type": "scatterpolargl"
           }
          ],
          "scatterternary": [
           {
            "marker": {
             "colorbar": {
              "outlinewidth": 1,
              "tickcolor": "rgb(36,36,36)",
              "ticks": "outside"
             }
            },
            "type": "scatterternary"
           }
          ],
          "surface": [
           {
            "colorbar": {
             "outlinewidth": 1,
             "tickcolor": "rgb(36,36,36)",
             "ticks": "outside"
            },
            "colorscale": [
             [
              0,
              "#440154"
             ],
             [
              0.1111111111111111,
              "#482878"
             ],
             [
              0.2222222222222222,
              "#3e4989"
             ],
             [
              0.3333333333333333,
              "#31688e"
             ],
             [
              0.4444444444444444,
              "#26828e"
             ],
             [
              0.5555555555555556,
              "#1f9e89"
             ],
             [
              0.6666666666666666,
              "#35b779"
             ],
             [
              0.7777777777777778,
              "#6ece58"
             ],
             [
              0.8888888888888888,
              "#b5de2b"
             ],
             [
              1,
              "#fde725"
             ]
            ],
            "type": "surface"
           }
          ],
          "table": [
           {
            "cells": {
             "fill": {
              "color": "rgb(237,237,237)"
             },
             "line": {
              "color": "white"
             }
            },
            "header": {
             "fill": {
              "color": "rgb(217,217,217)"
             },
             "line": {
              "color": "white"
             }
            },
            "type": "table"
           }
          ]
         },
         "layout": {
          "annotationdefaults": {
           "arrowhead": 0,
           "arrowwidth": 1
          },
          "autotypenumbers": "strict",
          "coloraxis": {
           "colorbar": {
            "outlinewidth": 1,
            "tickcolor": "rgb(36,36,36)",
            "ticks": "outside"
           }
          },
          "colorscale": {
           "diverging": [
            [
             0,
             "rgb(103,0,31)"
            ],
            [
             0.1,
             "rgb(178,24,43)"
            ],
            [
             0.2,
             "rgb(214,96,77)"
            ],
            [
             0.3,
             "rgb(244,165,130)"
            ],
            [
             0.4,
             "rgb(253,219,199)"
            ],
            [
             0.5,
             "rgb(247,247,247)"
            ],
            [
             0.6,
             "rgb(209,229,240)"
            ],
            [
             0.7,
             "rgb(146,197,222)"
            ],
            [
             0.8,
             "rgb(67,147,195)"
            ],
            [
             0.9,
             "rgb(33,102,172)"
            ],
            [
             1,
             "rgb(5,48,97)"
            ]
           ],
           "sequential": [
            [
             0,
             "#440154"
            ],
            [
             0.1111111111111111,
             "#482878"
            ],
            [
             0.2222222222222222,
             "#3e4989"
            ],
            [
             0.3333333333333333,
             "#31688e"
            ],
            [
             0.4444444444444444,
             "#26828e"
            ],
            [
             0.5555555555555556,
             "#1f9e89"
            ],
            [
             0.6666666666666666,
             "#35b779"
            ],
            [
             0.7777777777777778,
             "#6ece58"
            ],
            [
             0.8888888888888888,
             "#b5de2b"
            ],
            [
             1,
             "#fde725"
            ]
           ],
           "sequentialminus": [
            [
             0,
             "#440154"
            ],
            [
             0.1111111111111111,
             "#482878"
            ],
            [
             0.2222222222222222,
             "#3e4989"
            ],
            [
             0.3333333333333333,
             "#31688e"
            ],
            [
             0.4444444444444444,
             "#26828e"
            ],
            [
             0.5555555555555556,
             "#1f9e89"
            ],
            [
             0.6666666666666666,
             "#35b779"
            ],
            [
             0.7777777777777778,
             "#6ece58"
            ],
            [
             0.8888888888888888,
             "#b5de2b"
            ],
            [
             1,
             "#fde725"
            ]
           ]
          },
          "colorway": [
           "#1F77B4",
           "#FF7F0E",
           "#2CA02C",
           "#D62728",
           "#9467BD",
           "#8C564B",
           "#E377C2",
           "#7F7F7F",
           "#BCBD22",
           "#17BECF"
          ],
          "font": {
           "color": "rgb(36,36,36)"
          },
          "geo": {
           "bgcolor": "white",
           "lakecolor": "white",
           "landcolor": "white",
           "showlakes": true,
           "showland": true,
           "subunitcolor": "white"
          },
          "hoverlabel": {
           "align": "left"
          },
          "hovermode": "closest",
          "mapbox": {
           "style": "light"
          },
          "paper_bgcolor": "white",
          "plot_bgcolor": "white",
          "polar": {
           "angularaxis": {
            "gridcolor": "rgb(232,232,232)",
            "linecolor": "rgb(36,36,36)",
            "showgrid": false,
            "showline": true,
            "ticks": "outside"
           },
           "bgcolor": "white",
           "radialaxis": {
            "gridcolor": "rgb(232,232,232)",
            "linecolor": "rgb(36,36,36)",
            "showgrid": false,
            "showline": true,
            "ticks": "outside"
           }
          },
          "scene": {
           "xaxis": {
            "backgroundcolor": "white",
            "gridcolor": "rgb(232,232,232)",
            "gridwidth": 2,
            "linecolor": "rgb(36,36,36)",
            "showbackground": true,
            "showgrid": false,
            "showline": true,
            "ticks": "outside",
            "zeroline": false,
            "zerolinecolor": "rgb(36,36,36)"
           },
           "yaxis": {
            "backgroundcolor": "white",
            "gridcolor": "rgb(232,232,232)",
            "gridwidth": 2,
            "linecolor": "rgb(36,36,36)",
            "showbackground": true,
            "showgrid": false,
            "showline": true,
            "ticks": "outside",
            "zeroline": false,
            "zerolinecolor": "rgb(36,36,36)"
           },
           "zaxis": {
            "backgroundcolor": "white",
            "gridcolor": "rgb(232,232,232)",
            "gridwidth": 2,
            "linecolor": "rgb(36,36,36)",
            "showbackground": true,
            "showgrid": false,
            "showline": true,
            "ticks": "outside",
            "zeroline": false,
            "zerolinecolor": "rgb(36,36,36)"
           }
          },
          "shapedefaults": {
           "fillcolor": "black",
           "line": {
            "width": 0
           },
           "opacity": 0.3
          },
          "ternary": {
           "aaxis": {
            "gridcolor": "rgb(232,232,232)",
            "linecolor": "rgb(36,36,36)",
            "showgrid": false,
            "showline": true,
            "ticks": "outside"
           },
           "baxis": {
            "gridcolor": "rgb(232,232,232)",
            "linecolor": "rgb(36,36,36)",
            "showgrid": false,
            "showline": true,
            "ticks": "outside"
           },
           "bgcolor": "white",
           "caxis": {
            "gridcolor": "rgb(232,232,232)",
            "linecolor": "rgb(36,36,36)",
            "showgrid": false,
            "showline": true,
            "ticks": "outside"
           }
          },
          "title": {
           "x": 0.05
          },
          "xaxis": {
           "automargin": true,
           "gridcolor": "rgb(232,232,232)",
           "linecolor": "rgb(36,36,36)",
           "showgrid": false,
           "showline": true,
           "ticks": "outside",
           "title": {
            "standoff": 15
           },
           "zeroline": false,
           "zerolinecolor": "rgb(36,36,36)"
          },
          "yaxis": {
           "automargin": true,
           "gridcolor": "rgb(232,232,232)",
           "linecolor": "rgb(36,36,36)",
           "showgrid": false,
           "showline": true,
           "ticks": "outside",
           "title": {
            "standoff": 15
           },
           "zeroline": false,
           "zerolinecolor": "rgb(36,36,36)"
          }
         }
        },
        "title": {
         "text": "Cl vs Alpha"
        },
        "xaxis": {
         "gridcolor": "Gray",
         "gridwidth": 1,
         "linecolor": "black",
         "linewidth": 2,
         "mirror": false,
         "showgrid": true,
         "showline": true,
         "title": {
          "text": "Alpha [deg]"
         },
         "zeroline": true,
         "zerolinecolor": "Gray",
         "zerolinewidth": 1
        },
        "yaxis": {
         "gridcolor": "Gray",
         "gridwidth": 0.5,
         "linecolor": "black",
         "linewidth": 2,
         "mirror": false,
         "showgrid": true,
         "showline": true,
         "title": {
          "text": "Cl"
         },
         "zeroline": true,
         "zerolinecolor": "Gray",
         "zerolinewidth": 1
        }
       }
      },
      "text/html": [
       "<div>                            <div id=\"da87b911-685f-45cd-bcf6-51bfed1c7236\" class=\"plotly-graph-div\" style=\"height:525px; width:100%;\"></div>            <script type=\"text/javascript\">                require([\"plotly\"], function(Plotly) {                    window.PLOTLYENV=window.PLOTLYENV || {};                                    if (document.getElementById(\"da87b911-685f-45cd-bcf6-51bfed1c7236\")) {                    Plotly.newPlot(                        \"da87b911-685f-45cd-bcf6-51bfed1c7236\",                        [{\"line\":{\"color\":\"#0000ff\"},\"mode\":\"lines\",\"name\":\"Empirical curve-fit\",\"type\":\"scatter\",\"x\":[-180.0,-180.0,-180.0,-180.0,-180.0,-180.0,-180.0,-179.0,-179.0,-179.0,-179.0,-179.0,-179.0,-179.0,-178.0,-178.0,-178.0,-178.0,-178.0,-178.0,-178.0,-177.0,-177.0,-177.0,-177.0,-177.0,-177.0,-177.0,-175.0,-175.0,-175.0,-175.0,-175.0,-175.0,-175.0,-170.0,-170.0,-170.0,-170.0,-170.0,-170.0,-170.0,-165.0,-165.0,-165.0,-165.0,-165.0,-165.0,-165.0,-160.0,-160.0,-160.0,-160.0,-160.0,-160.0,-160.0,-155.0,-155.0,-155.0,-155.0,-155.0,-155.0,-155.0,-150.0,-150.0,-150.0,-150.0,-150.0,-150.0,-150.0,-145.0,-145.0,-145.0,-145.0,-145.0,-145.0,-145.0,-140.0,-140.0,-140.0,-140.0,-140.0,-140.0,-140.0,-135.0,-135.0,-135.0,-135.0,-135.0,-135.0,-135.0,-130.0,-130.0,-130.0,-130.0,-130.0,-130.0,-130.0,-125.0,-125.0,-125.0,-125.0,-125.0,-125.0,-125.0,-120.0,-120.0,-120.0,-120.0,-120.0,-120.0,-120.0,-115.0,-115.0,-115.0,-115.0,-115.0,-115.0,-115.0,-110.0,-110.0,-110.0,-110.0,-110.0,-110.0,-110.0,-105.0,-105.0,-105.0,-105.0,-105.0,-105.0,-105.0,-100.0,-100.0,-100.0,-100.0,-100.0,-100.0,-100.0,-95.0,-95.0,-95.0,-95.0,-95.0,-95.0,-95.0,-90.0,-90.0,-90.0,-90.0,-90.0,-90.0,-90.0,-85.0,-85.0,-85.0,-85.0,-85.0,-85.0,-85.0,-80.0,-80.0,-80.0,-80.0,-80.0,-80.0,-80.0,-75.0,-75.0,-75.0,-75.0,-75.0,-75.0,-75.0,-70.0,-70.0,-70.0,-70.0,-70.0,-70.0,-70.0,-65.0,-65.0,-65.0,-65.0,-65.0,-65.0,-65.0,-60.0,-60.0,-60.0,-60.0,-60.0,-60.0,-60.0,-55.0,-55.0,-55.0,-55.0,-55.0,-55.0,-55.0,-50.0,-50.0,-50.0,-50.0,-50.0,-50.0,-50.0,-45.0,-45.0,-45.0,-45.0,-45.0,-45.0,-45.0,-40.0,-40.0,-40.0,-40.0,-40.0,-40.0,-40.0,-35.0,-35.0,-35.0,-35.0,-35.0,-35.0,-35.0,-30.0,-30.0,-30.0,-30.0,-30.0,-30.0,-30.0,-25.0,-25.0,-25.0,-25.0,-25.0,-25.0,-25.0,-20.0,-20.0,-20.0,-20.0,-20.0,-20.0,-20.0,-19.0,-19.0,-19.0,-19.0,-19.0,-19.0,-19.0,-18.0,-18.0,-18.0,-18.0,-18.0,-18.0,-18.0,-17.0,-17.0,-17.0,-17.0,-17.0,-17.0,-17.0,-16.0,-16.0,-16.0,-16.0,-16.0,-16.0,-16.0,-15.0,-15.0,-15.0,-15.0,-15.0,-15.0,-15.0,-14.0,-14.0,-14.0,-14.0,-14.0,-14.0,-14.0,-13.0,-13.0,-13.0,-13.0,-13.0,-13.0,-13.0,-12.0,-12.0,-12.0,-12.0,-12.0,-12.0,-12.0,-11.0,-11.0,-11.0,-11.0,-11.0,-11.0,-11.0,-10.0,-10.0,-10.0,-10.0,-10.0,-10.0,-10.0,-9.0,-9.0,-9.0,-9.0,-9.0,-9.0,-9.0,-8.0,-8.0,-8.0,-8.0,-8.0,-8.0,-8.0,-7.0,-7.0,-7.0,-7.0,-7.0,-7.0,-7.0],\"y\":[0.049203893131808875,0.049203893131808875,0.049203893131808875,0.049203893131808875,0.049203893131808875,0.049203893131808875,0.049203893131808875,0.0901448580490118,0.0901448580490118,0.0901448580490118,0.0901448580490118,0.0901448580490118,0.0901448580490118,0.0901448580490118,0.13097599534243187,0.13097599534243187,0.13097599534243187,0.13097599534243187,0.13097599534243187,0.13097599534243187,0.13097599534243187,0.17164755856083366,0.17164755856083366,0.17164755856083366,0.17164755856083366,0.17164755856083366,0.17164755856083366,0.17164755856083366,0.2523140094212994,0.2523140094212994,0.2523140094212994,0.2523140094212994,0.2523140094212994,0.2523140094212994,0.2523140094212994,0.4477576922115719,0.4477576922115719,0.4477576922115719,0.4477576922115719,0.4477576922115719,0.4477576922115719,0.4477576922115719,0.6295964841003207,0.6295964841003207,0.6295964841003207,0.6295964841003207,0.6295964841003207,0.6295964841003207,0.6295964841003207,0.7923053054108745,0.7923053054108745,0.7923053054108745,0.7923053054108745,0.7923053054108745,0.7923053054108745,0.7923053054108745,0.9309403309423486,0.9309403309423486,0.9309403309423486,0.9309403309423486,0.9309403309423486,0.9309403309423486,0.9309403309423486,1.0412892055966774,1.0412892055966774,1.0412892055966774,1.0412892055966774,1.0412892055966774,1.0412892055966774,1.0412892055966774,1.1199990346567126,1.1199990346567126,1.1199990346567126,1.1199990346567126,1.1199990346567126,1.1199990346567126,1.1199990346567126,1.1646782597955616,1.1646782597955616,1.1646782597955616,1.1646782597955616,1.1646782597955616,1.1646782597955616,1.1646782597955616,1.1739693253661587,1.1739693253661587,1.1739693253661587,1.1739693253661587,1.1739693253661587,1.1739693253661587,1.1739693253661587,1.1475899270426473,1.1475899270426473,1.1475899270426473,1.1475899270426473,1.1475899270426473,1.1475899270426473,1.1475899270426473,1.0863415894944681,1.0863415894944681,1.0863415894944681,1.0863415894944681,1.0863415894944681,1.0863415894944681,1.0863415894944681,0.9920853124648673,0.9920853124648673,0.9920853124648673,0.9920853124648673,0.9920853124648673,0.9920853124648673,0.9920853124648673,0.8676850252354132,0.8676850252354132,0.8676850252354132,0.8676850252354132,0.8676850252354132,0.8676850252354132,0.8676850252354132,0.7169205675839894,0.7169205675839894,0.7169205675839894,0.7169205675839894,0.7169205675839894,0.7169205675839894,0.7169205675839894,0.5443728412658372,0.5443728412658372,0.5443728412658372,0.5443728412658372,0.5443728412658372,0.5443728412658372,0.5443728412658372,0.3552846216317722,0.3552846216317722,0.3552846216317722,0.3552846216317722,0.3552846216317722,0.3552846216317722,0.3552846216317722,0.15540125855211898,0.15540125855211898,0.15540125855211898,0.15540125855211898,0.15540125855211898,0.15540125855211898,0.15540125855211898,-0.04920389313180978,-0.04920389313180978,-0.04920389313180978,-0.04920389313180978,-0.04920389313180978,-0.04920389313180978,-0.04920389313180978,-0.2523140094212992,-0.2523140094212992,-0.2523140094212992,-0.2523140094212992,-0.2523140094212992,-0.2523140094212992,-0.2523140094212992,-0.4477576922115723,-0.4477576922115723,-0.4477576922115723,-0.4477576922115723,-0.4477576922115723,-0.4477576922115723,-0.4477576922115723,-0.6295964841003211,-0.6295964841003211,-0.6295964841003211,-0.6295964841003211,-0.6295964841003211,-0.6295964841003211,-0.6295964841003211,-0.7923053054108752,-0.7923053054108752,-0.7923053054108752,-0.7923053054108752,-0.7923053054108752,-0.7923053054108752,-0.7923053054108752,-0.9309403309423491,-0.9309403309423491,-0.9309403309423491,-0.9309403309423491,-0.9309403309423491,-0.9309403309423491,-0.9309403309423491,-1.0412892055966776,-1.0412892055966776,-1.0412892055966776,-1.0412892055966776,-1.0412892055966776,-1.0412892055966776,-1.0412892055966776,-1.1199990346567128,-1.1199990346567128,-1.1199990346567128,-1.1199990346567128,-1.1199990346567128,-1.1199990346567128,-1.1199990346567128,-1.1646782597955616,-1.1646782597955616,-1.1646782597955616,-1.1646782597955616,-1.1646782597955616,-1.1646782597955616,-1.1646782597955616,-1.1739693253661587,-1.1739693253661587,-1.1739693253661587,-1.1739693253661587,-1.1739693253661587,-1.1739693253661587,-1.1739693253661587,-1.1475899270426473,-1.1475899270426473,-1.1475899270426473,-1.1475899270426473,-1.1475899270426473,-1.1475899270426473,-1.1475899270426473,-1.086341589494468,-1.086341589494468,-1.086341589494468,-1.086341589494468,-1.086341589494468,-1.086341589494468,-1.086341589494468,-0.9920853124648678,-0.9920853124648678,-0.9920853124648678,-0.9920853124648678,-0.9920853124648678,-0.9920853124648678,-0.9920853124648678,-0.8676850252354135,-0.8676850252354135,-0.8676850252354135,-0.8676850252354135,-0.8676850252354135,-0.8676850252354135,-0.8676850252354135,-0.7169205675839895,-0.7169205675839895,-0.7169205675839895,-0.7169205675839895,-0.7169205675839895,-0.7169205675839895,-0.7169205675839895,-0.683994489934815,-0.683994489934815,-0.683994489934815,-0.683994489934815,-0.683994489934815,-0.683994489934815,-0.683994489934815,-0.6502350703609293,-0.6502350703609293,-0.6502350703609293,-0.6502350703609293,-0.6502350703609293,-0.6502350703609293,-0.6502350703609293,-0.615683439514843,-0.615683439514843,-0.615683439514843,-0.615683439514843,-0.615683439514843,-0.615683439514843,-0.615683439514843,-0.5803816932364715,-0.5803816932364715,-0.5803816932364715,-0.5803816932364715,-0.5803816932364715,-0.5803816932364715,-0.5803816932364715,-0.5443728412658375,-0.5443728412658375,-0.5443728412658375,-0.5443728412658375,-0.5443728412658375,-0.5443728412658375,-0.5443728412658375,-0.5077007548423292,-0.5077007548423292,-0.5077007548423292,-0.5077007548423292,-0.5077007548423292,-0.5077007548423292,-0.5077007548423292,-0.4704101132543516,-0.4704101132543516,-0.4704101132543516,-0.4704101132543516,-0.4704101132543516,-0.4704101132543516,-0.4704101132543516,-0.43254634940449666,-0.43254634940449666,-0.43254634940449666,-0.43254634940449666,-0.43254634940449666,-0.43254634940449666,-0.43254634940449666,-0.3941555944565497,-0.3941555944565497,-0.3941555944565497,-0.3941555944565497,-0.3941555944565497,-0.3941555944565497,-0.3941555944565497,-0.3552846216317723,-0.3552846216317723,-0.3552846216317723,-0.3552846216317723,-0.3552846216317723,-0.3552846216317723,-0.3552846216317723,-0.3159807892229372,-0.3159807892229372,-0.3159807892229372,-0.3159807892229372,-0.3159807892229372,-0.3159807892229372,-0.3159807892229372,-0.27629198289554324,-0.27629198289554324,-0.27629198289554324,-0.27629198289554324,-0.27629198289554324,-0.27629198289554324,-0.27629198289554324,-0.2362665573465085,-0.2362665573465085,-0.2362665573465085,-0.2362665573465085,-0.2362665573465085,-0.2362665573465085,-0.2362665573465085]},{\"marker\":{\"color\":\"#0000ff\"},\"mode\":\"lines\",\"showlegend\":false,\"type\":\"scatter\",\"x\":[18.0,18.0,18.0,18.0,18.0,18.0,18.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,20.0,20.0,20.0,20.0,20.0,20.0,20.0,25.0,25.0,25.0,25.0,25.0,25.0,25.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,40.0,40.0,40.0,40.0,40.0,40.0,40.0,45.0,45.0,45.0,45.0,45.0,45.0,45.0,50.0,50.0,50.0,50.0,50.0,50.0,50.0,55.0,55.0,55.0,55.0,55.0,55.0,55.0,60.0,60.0,60.0,60.0,60.0,60.0,60.0,65.0,65.0,65.0,65.0,65.0,65.0,65.0,70.0,70.0,70.0,70.0,70.0,70.0,70.0,75.0,75.0,75.0,75.0,75.0,75.0,75.0,80.0,80.0,80.0,80.0,80.0,80.0,80.0,85.0,85.0,85.0,85.0,85.0,85.0,85.0,90.0,90.0,90.0,90.0,90.0,90.0,90.0,95.0,95.0,95.0,95.0,95.0,95.0,95.0,100.0,100.0,100.0,100.0,100.0,100.0,100.0,105.0,105.0,105.0,105.0,105.0,105.0,105.0,110.0,110.0,110.0,110.0,110.0,110.0,110.0,115.0,115.0,115.0,115.0,115.0,115.0,115.0,120.0,120.0,120.0,120.0,120.0,120.0,120.0,125.0,125.0,125.0,125.0,125.0,125.0,125.0,130.0,130.0,130.0,130.0,130.0,130.0,130.0,135.0,135.0,135.0,135.0,135.0,135.0,135.0,140.0,140.0,140.0,140.0,140.0,140.0,140.0,145.0,145.0,145.0,145.0,145.0,145.0,145.0,150.0,150.0,150.0,150.0,150.0,150.0,150.0,155.0,155.0,155.0,155.0,155.0,155.0,155.0,160.0,160.0,160.0,160.0,160.0,160.0,160.0,165.0,165.0,165.0,165.0,165.0,165.0,165.0,170.0,170.0,170.0,170.0,170.0,170.0,170.0,175.0,175.0,175.0,175.0,175.0,175.0,175.0,177.0,177.0,177.0,177.0,177.0,177.0,177.0,178.0,178.0,178.0,178.0,178.0,178.0,178.0,179.0,179.0,179.0,179.0,179.0,179.0,179.0,180.0,180.0,180.0,180.0,180.0,180.0,180.0],\"y\":[0.7298486418270146,0.7298486418270146,0.7298486418270146,0.7298486418270146,0.7298486418270146,0.7298486418270146,0.7298486418270146,0.7615408837491788,0.7615408837491788,0.7615408837491788,0.7615408837491788,0.7615408837491788,0.7615408837491788,0.7615408837491788,0.7923053054108751,0.7923053054108751,0.7923053054108751,0.7923053054108751,0.7923053054108751,0.7923053054108751,0.7923053054108751,0.9309403309423491,0.9309403309423491,0.9309403309423491,0.9309403309423491,0.9309403309423491,0.9309403309423491,0.9309403309423491,1.0412892055966774,1.0412892055966774,1.0412892055966774,1.0412892055966774,1.0412892055966774,1.0412892055966774,1.0412892055966774,1.1199990346567128,1.1199990346567128,1.1199990346567128,1.1199990346567128,1.1199990346567128,1.1199990346567128,1.1199990346567128,1.1646782597955616,1.1646782597955616,1.1646782597955616,1.1646782597955616,1.1646782597955616,1.1646782597955616,1.1646782597955616,1.1739693253661587,1.1739693253661587,1.1739693253661587,1.1739693253661587,1.1739693253661587,1.1739693253661587,1.1739693253661587,1.1475899270426473,1.1475899270426473,1.1475899270426473,1.1475899270426473,1.1475899270426473,1.1475899270426473,1.1475899270426473,1.086341589494468,1.086341589494468,1.086341589494468,1.086341589494468,1.086341589494468,1.086341589494468,1.086341589494468,0.9920853124648676,0.9920853124648676,0.9920853124648676,0.9920853124648676,0.9920853124648676,0.9920853124648676,0.9920853124648676,0.8676850252354135,0.8676850252354135,0.8676850252354135,0.8676850252354135,0.8676850252354135,0.8676850252354135,0.8676850252354135,0.7169205675839896,0.7169205675839896,0.7169205675839896,0.7169205675839896,0.7169205675839896,0.7169205675839896,0.7169205675839896,0.5443728412658374,0.5443728412658374,0.5443728412658374,0.5443728412658374,0.5443728412658374,0.5443728412658374,0.5443728412658374,0.3552846216317724,0.3552846216317724,0.3552846216317724,0.3552846216317724,0.3552846216317724,0.3552846216317724,0.3552846216317724,0.1554012585521187,0.1554012585521187,0.1554012585521187,0.1554012585521187,0.1554012585521187,0.1554012585521187,0.1554012585521187,-0.049203893131809485,-0.049203893131809485,-0.049203893131809485,-0.049203893131809485,-0.049203893131809485,-0.049203893131809485,-0.049203893131809485,-0.2523140094212995,-0.2523140094212995,-0.2523140094212995,-0.2523140094212995,-0.2523140094212995,-0.2523140094212995,-0.2523140094212995,-0.4477576922115721,-0.4477576922115721,-0.4477576922115721,-0.4477576922115721,-0.4477576922115721,-0.4477576922115721,-0.4477576922115721,-0.6295964841003212,-0.6295964841003212,-0.6295964841003212,-0.6295964841003212,-0.6295964841003212,-0.6295964841003212,-0.6295964841003212,-0.7923053054108751,-0.7923053054108751,-0.7923053054108751,-0.7923053054108751,-0.7923053054108751,-0.7923053054108751,-0.7923053054108751,-0.930940330942349,-0.930940330942349,-0.930940330942349,-0.930940330942349,-0.930940330942349,-0.930940330942349,-0.930940330942349,-1.0412892055966771,-1.0412892055966771,-1.0412892055966771,-1.0412892055966771,-1.0412892055966771,-1.0412892055966771,-1.0412892055966771,-1.119999034656713,-1.119999034656713,-1.119999034656713,-1.119999034656713,-1.119999034656713,-1.119999034656713,-1.119999034656713,-1.1646782597955614,-1.1646782597955614,-1.1646782597955614,-1.1646782597955614,-1.1646782597955614,-1.1646782597955614,-1.1646782597955614,-1.1739693253661587,-1.1739693253661587,-1.1739693253661587,-1.1739693253661587,-1.1739693253661587,-1.1739693253661587,-1.1739693253661587,-1.1475899270426473,-1.1475899270426473,-1.1475899270426473,-1.1475899270426473,-1.1475899270426473,-1.1475899270426473,-1.1475899270426473,-1.0863415894944681,-1.0863415894944681,-1.0863415894944681,-1.0863415894944681,-1.0863415894944681,-1.0863415894944681,-1.0863415894944681,-0.9920853124648683,-0.9920853124648683,-0.9920853124648683,-0.9920853124648683,-0.9920853124648683,-0.9920853124648683,-0.9920853124648683,-0.8676850252354135,-0.8676850252354135,-0.8676850252354135,-0.8676850252354135,-0.8676850252354135,-0.8676850252354135,-0.8676850252354135,-0.7169205675839897,-0.7169205675839897,-0.7169205675839897,-0.7169205675839897,-0.7169205675839897,-0.7169205675839897,-0.7169205675839897,-0.544372841265838,-0.544372841265838,-0.544372841265838,-0.544372841265838,-0.544372841265838,-0.544372841265838,-0.544372841265838,-0.35528462163177305,-0.35528462163177305,-0.35528462163177305,-0.35528462163177305,-0.35528462163177305,-0.35528462163177305,-0.35528462163177305,-0.15540125855211992,-0.15540125855211992,-0.15540125855211992,-0.15540125855211992,-0.15540125855211992,-0.15540125855211992,-0.15540125855211992,-0.07377886044694414,-0.07377886044694414,-0.07377886044694414,-0.07377886044694414,-0.07377886044694414,-0.07377886044694414,-0.07377886044694414,-0.03280792550019377,-0.03280792550019377,-0.03280792550019377,-0.03280792550019377,-0.03280792550019377,-0.03280792550019377,-0.03280792550019377,0.008202980850104026,0.008202980850104026,0.008202980850104026,0.008202980850104026,0.008202980850104026,0.008202980850104026,0.008202980850104026,0.04920389313180935,0.04920389313180935,0.04920389313180935,0.04920389313180935,0.04920389313180935,0.04920389313180935,0.04920389313180935]},{\"line\":{\"color\":\"#0000ff\"},\"mode\":\"markers\",\"name\":\"CFD\",\"type\":\"scatter\",\"x\":[-6.0,-5.76767677,-5.53535354,-5.3030303,-5.07070707,-4.83838384,-4.60606061,-4.37373737,-4.14141414,-3.90909091,-3.67676768,-3.44444444,-3.21212121,-2.97979798,-2.74747475,-2.51515152,-2.28282828,-2.05050505,-1.81818182,-1.58585859,-1.35353535,-1.12121212,-0.88888889,-0.65656566,-0.42424242,-0.19191919,0.04040404,0.27272727,0.50505051,0.73737374,0.96969697,1.2020202,1.43434343,1.66666667,1.8989899,2.13131313,2.36363636,2.5959596,2.82828283,3.06060606,3.29292929,3.52525253,3.75757576,3.98989899,4.22222222,4.45454545,4.68686869,4.91919192,5.15151515,5.38383838,5.61616162,5.84848485,6.08080808,6.31313131,6.54545455,6.77777778,7.01010101,7.24242424,7.47474747,7.70707071,7.93939394,8.17171717,8.4040404,8.63636364,8.86868687,9.1010101,9.33333333,9.56565657,9.7979798,10.03030303,10.26262626,10.49494949,10.72727273,10.95959596,11.19191919,11.42424242,11.65656566,11.88888889,12.12121212,12.35353535,12.58585859,12.81818182,13.05050505,13.28282828,13.51515152,13.74747475,13.97979798,14.21212121,14.44444444,14.67676768,14.90909091,15.14141414,15.37373737,15.60606061,15.83838384,16.07070707,16.3030303,16.53535354,16.76767677,17.0],\"y\":[-0.57438145,-0.54735084,-0.52020789,-0.49296479,-0.46563373,-0.43822654,-0.41075118,-0.3832134,-0.35562056,-0.32798138,-0.30029716,-0.27255951,-0.24478207,-0.2170239,-0.18931741,-0.16159605,-0.13378916,-0.10589883,-0.07794924,-0.04996457,-0.02196899,0.0060133,0.03395877,0.06186061,0.08972963,0.11757753,0.14541599,0.17325411,0.20109487,0.22894031,0.25679248,0.28465202,0.312511,0.3403584,0.36818316,0.39597458,0.42372762,0.45144208,0.47911787,0.50675493,0.53435186,0.56190482,0.58940969,0.61686235,0.64425883,0.67159577,0.69886997,0.72607828,0.75321725,0.7802805,0.80725965,0.83414628,0.86093217,0.88761952,0.91421151,0.94067323,0.96704023,0.99335133,1.01952369,1.04550619,1.07132642,1.09705174,1.12262195,1.14795714,1.17306592,1.19803623,1.22285062,1.24738903,1.27163161,1.29564366,1.31944963,1.34290603,1.36592873,1.38820392,1.40916159,1.42811212,1.44435644,1.45761343,1.46786655,1.47510391,1.47938053,1.48083297,1.47934846,1.47500414,1.46817606,1.45808435,1.44542869,1.43149019,1.413954,1.39357078,1.3719248,1.34726237,1.32124431,1.29516724,1.26664033,1.23808438,1.21162015,1.18707021,1.165009,1.14625038]}],                        {\"plot_bgcolor\":\"rgba(0,0.5,0,0)\",\"template\":{\"data\":{\"bar\":[{\"error_x\":{\"color\":\"rgb(36,36,36)\"},\"error_y\":{\"color\":\"rgb(36,36,36)\"},\"marker\":{\"line\":{\"color\":\"white\",\"width\":0.5},\"pattern\":{\"fillmode\":\"overlay\",\"size\":10,\"solidity\":0.2}},\"type\":\"bar\"}],\"barpolar\":[{\"marker\":{\"line\":{\"color\":\"white\",\"width\":0.5},\"pattern\":{\"fillmode\":\"overlay\",\"size\":10,\"solidity\":0.2}},\"type\":\"barpolar\"}],\"carpet\":[{\"aaxis\":{\"endlinecolor\":\"rgb(36,36,36)\",\"gridcolor\":\"white\",\"linecolor\":\"white\",\"minorgridcolor\":\"white\",\"startlinecolor\":\"rgb(36,36,36)\"},\"baxis\":{\"endlinecolor\":\"rgb(36,36,36)\",\"gridcolor\":\"white\",\"linecolor\":\"white\",\"minorgridcolor\":\"white\",\"startlinecolor\":\"rgb(36,36,36)\"},\"type\":\"carpet\"}],\"choropleth\":[{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"},\"type\":\"choropleth\"}],\"contour\":[{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"},\"colorscale\":[[0.0,\"#440154\"],[0.1111111111111111,\"#482878\"],[0.2222222222222222,\"#3e4989\"],[0.3333333333333333,\"#31688e\"],[0.4444444444444444,\"#26828e\"],[0.5555555555555556,\"#1f9e89\"],[0.6666666666666666,\"#35b779\"],[0.7777777777777778,\"#6ece58\"],[0.8888888888888888,\"#b5de2b\"],[1.0,\"#fde725\"]],\"type\":\"contour\"}],\"contourcarpet\":[{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"},\"type\":\"contourcarpet\"}],\"heatmap\":[{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"},\"colorscale\":[[0.0,\"#440154\"],[0.1111111111111111,\"#482878\"],[0.2222222222222222,\"#3e4989\"],[0.3333333333333333,\"#31688e\"],[0.4444444444444444,\"#26828e\"],[0.5555555555555556,\"#1f9e89\"],[0.6666666666666666,\"#35b779\"],[0.7777777777777778,\"#6ece58\"],[0.8888888888888888,\"#b5de2b\"],[1.0,\"#fde725\"]],\"type\":\"heatmap\"}],\"heatmapgl\":[{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"},\"colorscale\":[[0.0,\"#440154\"],[0.1111111111111111,\"#482878\"],[0.2222222222222222,\"#3e4989\"],[0.3333333333333333,\"#31688e\"],[0.4444444444444444,\"#26828e\"],[0.5555555555555556,\"#1f9e89\"],[0.6666666666666666,\"#35b779\"],[0.7777777777777778,\"#6ece58\"],[0.8888888888888888,\"#b5de2b\"],[1.0,\"#fde725\"]],\"type\":\"heatmapgl\"}],\"histogram\":[{\"marker\":{\"line\":{\"color\":\"white\",\"width\":0.6}},\"type\":\"histogram\"}],\"histogram2d\":[{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"},\"colorscale\":[[0.0,\"#440154\"],[0.1111111111111111,\"#482878\"],[0.2222222222222222,\"#3e4989\"],[0.3333333333333333,\"#31688e\"],[0.4444444444444444,\"#26828e\"],[0.5555555555555556,\"#1f9e89\"],[0.6666666666666666,\"#35b779\"],[0.7777777777777778,\"#6ece58\"],[0.8888888888888888,\"#b5de2b\"],[1.0,\"#fde725\"]],\"type\":\"histogram2d\"}],\"histogram2dcontour\":[{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"},\"colorscale\":[[0.0,\"#440154\"],[0.1111111111111111,\"#482878\"],[0.2222222222222222,\"#3e4989\"],[0.3333333333333333,\"#31688e\"],[0.4444444444444444,\"#26828e\"],[0.5555555555555556,\"#1f9e89\"],[0.6666666666666666,\"#35b779\"],[0.7777777777777778,\"#6ece58\"],[0.8888888888888888,\"#b5de2b\"],[1.0,\"#fde725\"]],\"type\":\"histogram2dcontour\"}],\"mesh3d\":[{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"},\"type\":\"mesh3d\"}],\"parcoords\":[{\"line\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"type\":\"parcoords\"}],\"pie\":[{\"automargin\":true,\"type\":\"pie\"}],\"scatter\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"type\":\"scatter\"}],\"scatter3d\":[{\"line\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"marker\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"type\":\"scatter3d\"}],\"scattercarpet\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"type\":\"scattercarpet\"}],\"scattergeo\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"type\":\"scattergeo\"}],\"scattergl\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"type\":\"scattergl\"}],\"scattermapbox\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"type\":\"scattermapbox\"}],\"scatterpolar\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"type\":\"scatterpolar\"}],\"scatterpolargl\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"type\":\"scatterpolargl\"}],\"scatterternary\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"type\":\"scatterternary\"}],\"surface\":[{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"},\"colorscale\":[[0.0,\"#440154\"],[0.1111111111111111,\"#482878\"],[0.2222222222222222,\"#3e4989\"],[0.3333333333333333,\"#31688e\"],[0.4444444444444444,\"#26828e\"],[0.5555555555555556,\"#1f9e89\"],[0.6666666666666666,\"#35b779\"],[0.7777777777777778,\"#6ece58\"],[0.8888888888888888,\"#b5de2b\"],[1.0,\"#fde725\"]],\"type\":\"surface\"}],\"table\":[{\"cells\":{\"fill\":{\"color\":\"rgb(237,237,237)\"},\"line\":{\"color\":\"white\"}},\"header\":{\"fill\":{\"color\":\"rgb(217,217,217)\"},\"line\":{\"color\":\"white\"}},\"type\":\"table\"}]},\"layout\":{\"annotationdefaults\":{\"arrowhead\":0,\"arrowwidth\":1},\"autotypenumbers\":\"strict\",\"coloraxis\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"colorscale\":{\"diverging\":[[0.0,\"rgb(103,0,31)\"],[0.1,\"rgb(178,24,43)\"],[0.2,\"rgb(214,96,77)\"],[0.3,\"rgb(244,165,130)\"],[0.4,\"rgb(253,219,199)\"],[0.5,\"rgb(247,247,247)\"],[0.6,\"rgb(209,229,240)\"],[0.7,\"rgb(146,197,222)\"],[0.8,\"rgb(67,147,195)\"],[0.9,\"rgb(33,102,172)\"],[1.0,\"rgb(5,48,97)\"]],\"sequential\":[[0.0,\"#440154\"],[0.1111111111111111,\"#482878\"],[0.2222222222222222,\"#3e4989\"],[0.3333333333333333,\"#31688e\"],[0.4444444444444444,\"#26828e\"],[0.5555555555555556,\"#1f9e89\"],[0.6666666666666666,\"#35b779\"],[0.7777777777777778,\"#6ece58\"],[0.8888888888888888,\"#b5de2b\"],[1.0,\"#fde725\"]],\"sequentialminus\":[[0.0,\"#440154\"],[0.1111111111111111,\"#482878\"],[0.2222222222222222,\"#3e4989\"],[0.3333333333333333,\"#31688e\"],[0.4444444444444444,\"#26828e\"],[0.5555555555555556,\"#1f9e89\"],[0.6666666666666666,\"#35b779\"],[0.7777777777777778,\"#6ece58\"],[0.8888888888888888,\"#b5de2b\"],[1.0,\"#fde725\"]]},\"colorway\":[\"#1F77B4\",\"#FF7F0E\",\"#2CA02C\",\"#D62728\",\"#9467BD\",\"#8C564B\",\"#E377C2\",\"#7F7F7F\",\"#BCBD22\",\"#17BECF\"],\"font\":{\"color\":\"rgb(36,36,36)\"},\"geo\":{\"bgcolor\":\"white\",\"lakecolor\":\"white\",\"landcolor\":\"white\",\"showlakes\":true,\"showland\":true,\"subunitcolor\":\"white\"},\"hoverlabel\":{\"align\":\"left\"},\"hovermode\":\"closest\",\"mapbox\":{\"style\":\"light\"},\"paper_bgcolor\":\"white\",\"plot_bgcolor\":\"white\",\"polar\":{\"angularaxis\":{\"gridcolor\":\"rgb(232,232,232)\",\"linecolor\":\"rgb(36,36,36)\",\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\"},\"bgcolor\":\"white\",\"radialaxis\":{\"gridcolor\":\"rgb(232,232,232)\",\"linecolor\":\"rgb(36,36,36)\",\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\"}},\"scene\":{\"xaxis\":{\"backgroundcolor\":\"white\",\"gridcolor\":\"rgb(232,232,232)\",\"gridwidth\":2,\"linecolor\":\"rgb(36,36,36)\",\"showbackground\":true,\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\",\"zeroline\":false,\"zerolinecolor\":\"rgb(36,36,36)\"},\"yaxis\":{\"backgroundcolor\":\"white\",\"gridcolor\":\"rgb(232,232,232)\",\"gridwidth\":2,\"linecolor\":\"rgb(36,36,36)\",\"showbackground\":true,\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\",\"zeroline\":false,\"zerolinecolor\":\"rgb(36,36,36)\"},\"zaxis\":{\"backgroundcolor\":\"white\",\"gridcolor\":\"rgb(232,232,232)\",\"gridwidth\":2,\"linecolor\":\"rgb(36,36,36)\",\"showbackground\":true,\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\",\"zeroline\":false,\"zerolinecolor\":\"rgb(36,36,36)\"}},\"shapedefaults\":{\"fillcolor\":\"black\",\"line\":{\"width\":0},\"opacity\":0.3},\"ternary\":{\"aaxis\":{\"gridcolor\":\"rgb(232,232,232)\",\"linecolor\":\"rgb(36,36,36)\",\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\"},\"baxis\":{\"gridcolor\":\"rgb(232,232,232)\",\"linecolor\":\"rgb(36,36,36)\",\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\"},\"bgcolor\":\"white\",\"caxis\":{\"gridcolor\":\"rgb(232,232,232)\",\"linecolor\":\"rgb(36,36,36)\",\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\"}},\"title\":{\"x\":0.05},\"xaxis\":{\"automargin\":true,\"gridcolor\":\"rgb(232,232,232)\",\"linecolor\":\"rgb(36,36,36)\",\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\",\"title\":{\"standoff\":15},\"zeroline\":false,\"zerolinecolor\":\"rgb(36,36,36)\"},\"yaxis\":{\"automargin\":true,\"gridcolor\":\"rgb(232,232,232)\",\"linecolor\":\"rgb(36,36,36)\",\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\",\"title\":{\"standoff\":15},\"zeroline\":false,\"zerolinecolor\":\"rgb(36,36,36)\"}}},\"title\":{\"text\":\"Cl vs Alpha\"},\"xaxis\":{\"gridcolor\":\"Gray\",\"gridwidth\":1,\"linecolor\":\"black\",\"linewidth\":2,\"mirror\":false,\"showgrid\":true,\"showline\":true,\"title\":{\"text\":\"Alpha [deg]\"},\"zeroline\":true,\"zerolinecolor\":\"Gray\",\"zerolinewidth\":1},\"yaxis\":{\"gridcolor\":\"Gray\",\"gridwidth\":0.5,\"linecolor\":\"black\",\"linewidth\":2,\"mirror\":false,\"showgrid\":true,\"showline\":true,\"title\":{\"text\":\"Cl\"},\"zeroline\":true,\"zerolinecolor\":\"Gray\",\"zerolinewidth\":1}},                        {\"responsive\": true}                    ).then(function(){\n",
       "                            \n",
       "var gd = document.getElementById('da87b911-685f-45cd-bcf6-51bfed1c7236');\n",
       "var x = new MutationObserver(function (mutations, observer) {{\n",
       "        var display = window.getComputedStyle(gd).display;\n",
       "        if (!display || display === 'none') {{\n",
       "            console.log([gd, 'removed!']);\n",
       "            Plotly.purge(gd);\n",
       "            observer.disconnect();\n",
       "        }}\n",
       "}});\n",
       "\n",
       "// Listen for the removal of the full notebook cells\n",
       "var notebookContainer = gd.closest('#notebook-container');\n",
       "if (notebookContainer) {{\n",
       "    x.observe(notebookContainer, {childList: true});\n",
       "}}\n",
       "\n",
       "// Listen for the clearing of the current output cell\n",
       "var outputEl = gd.closest('.output');\n",
       "if (outputEl) {{\n",
       "    x.observe(outputEl, {childList: true});\n",
       "}}\n",
       "\n",
       "                        })                };                });            </script>        </div>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "import plotly.graph_objects as go\n",
    "import glob\n",
    "import matplotlib.pyplot as plt\n",
    "import plotly.express as px\n",
    "import pandas as pd\n",
    "import numpy as np\n",
    "from plotly.graph_objects import Layout\n",
    "\n",
    "path = f\"MCC0.00/Ma040\"\n",
    "all_files = glob.glob(path + \"/00_coeff00.dat\")\n",
    "#all_files = glob.glob(path + \"/**/**/*.dat\")\n",
    "li = [pd.read_csv(filename, index_col=None, header=0, sep='\\s+') for filename in all_files]\n",
    "df = pd.concat(li , axis=0, ignore_index=True)\n",
    "df\n",
    "col_names = {'MACH':'mach', 'ALPHA':'alpha', 'C-lift':'Cl','C-drag':'Cd', 'C-my':'Cm'}\n",
    "\n",
    "\n",
    "df.rename(columns=col_names, inplace=True)\n",
    "df.sort_values(['alpha'], inplace=True)\n",
    "\n",
    "       \n",
    "n=len(df)\n",
    "a= df.iloc[0:1, :]['alpha']          \n",
    "b= df.iloc[n-1:n, :]['alpha']\n",
    "df2 = pd.read_csv('./alpha.csv', index_col=None, header=0, sep='\\s+') \n",
    "alpha_0= -1.2 #degree\n",
    "\n",
    "df2['alpha_dif']= (df2['alpha']- alpha_0)\n",
    "\n",
    "def emp_C_l(x):\n",
    "    return 1.175*np.sin(np.deg2rad(2*x))\n",
    "def emp_C_m(x):\n",
    "    return -0.5*np.sin(np.deg2rad(x))+0.11*np.sin(np.deg2rad(2*x))\n",
    "def emp_C_d(x):\n",
    "    return 1.135-1.05*np.cos(np.deg2rad(2*x))\n",
    "\n",
    "df2['Cl']=df2['alpha_dif'].apply(emp_C_l)\n",
    "df2['Cm']=df2['alpha_dif'].apply(emp_C_m)\n",
    "df2['Cd']=df2['alpha_dif'].apply(emp_C_d)\n",
    "\n",
    "df2.sort_values(['alpha'], inplace=True)\n",
    "df2\n",
    "\n",
    "mask = df2['alpha'] < int(a)\n",
    "df3 = df2[mask]\n",
    "mask2 = df2['alpha'] > int(b)  \n",
    "df4 = df2[mask2]\n",
    "\n",
    "layout = Layout(plot_bgcolor='rgba(0,0.5,0,0)')\n",
    "fig = go.Figure(layout=layout)\n",
    "fig.add_trace(go.Scatter(x=df3['alpha'], y=df3['Cl'],\n",
    "                    mode='lines',\n",
    "                    name='Empirical curve-fit', line=dict(color=\"#0000ff\")))\n",
    "fig.add_trace(go.Scatter(x=df4['alpha'], y=df4['Cl'],mode='lines', showlegend=False, marker=dict(color=\"#0000ff\")))\n",
    "fig.add_trace(go.Scatter(x=df['alpha'], y=df['Cl'],\n",
    "                    mode='markers', name='CFD', line=dict(color=\"#0000ff\")))\n",
    "\n",
    "fig.update_layout(\n",
    "title=\"Cl vs Alpha\",\n",
    "xaxis_title=\"Alpha [deg]\", \n",
    "yaxis_title=\"Cl\")\n",
    "fig.update_xaxes(showline=True, linewidth=2, linecolor='black', mirror=False)\n",
    "fig.update_yaxes(showline=True, linewidth=2, linecolor='black', mirror=False)\n",
    "fig.update_xaxes(showgrid=True, gridwidth=1, gridcolor='Gray')\n",
    "fig.update_yaxes(showgrid=True, gridwidth=0.5, gridcolor='Gray')\n",
    "fig.update_xaxes(zeroline=True, zerolinewidth=1, zerolinecolor='Gray')\n",
    "fig.update_yaxes(zeroline=True, zerolinewidth=1, zerolinecolor='Gray')\n",
    "fig.show()\n",
    "\n"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 5,
   "id": "6d2fd84e",
   "metadata": {
    "hide_input": true,
    "scrolled": false,
    "slideshow": {
     "slide_type": "subslide"
    },
    "tags": [
     "hide-input"
    ]
   },
   "outputs": [
    {
     "data": {
      "application/vnd.plotly.v1+json": {
       "config": {
        "plotlyServerURL": "https://plot.ly"
       },
       "data": [
        {
         "line": {
          "color": "#0000ff"
         },
         "mode": "lines",
         "name": "Empirical curve-fit",
         "type": "scatter",
         "x": [
          -180,
          -180,
          -180,
          -180,
          -180,
          -180,
          -180,
          -179,
          -179,
          -179,
          -179,
          -179,
          -179,
          -179,
          -178,
          -178,
          -178,
          -178,
          -178,
          -178,
          -178,
          -177,
          -177,
          -177,
          -177,
          -177,
          -177,
          -177,
          -175,
          -175,
          -175,
          -175,
          -175,
          -175,
          -175,
          -170,
          -170,
          -170,
          -170,
          -170,
          -170,
          -170,
          -165,
          -165,
          -165,
          -165,
          -165,
          -165,
          -165,
          -160,
          -160,
          -160,
          -160,
          -160,
          -160,
          -160,
          -155,
          -155,
          -155,
          -155,
          -155,
          -155,
          -155,
          -150,
          -150,
          -150,
          -150,
          -150,
          -150,
          -150,
          -145,
          -145,
          -145,
          -145,
          -145,
          -145,
          -145,
          -140,
          -140,
          -140,
          -140,
          -140,
          -140,
          -140,
          -135,
          -135,
          -135,
          -135,
          -135,
          -135,
          -135,
          -130,
          -130,
          -130,
          -130,
          -130,
          -130,
          -130,
          -125,
          -125,
          -125,
          -125,
          -125,
          -125,
          -125,
          -120,
          -120,
          -120,
          -120,
          -120,
          -120,
          -120,
          -115,
          -115,
          -115,
          -115,
          -115,
          -115,
          -115,
          -110,
          -110,
          -110,
          -110,
          -110,
          -110,
          -110,
          -105,
          -105,
          -105,
          -105,
          -105,
          -105,
          -105,
          -100,
          -100,
          -100,
          -100,
          -100,
          -100,
          -100,
          -95,
          -95,
          -95,
          -95,
          -95,
          -95,
          -95,
          -90,
          -90,
          -90,
          -90,
          -90,
          -90,
          -90,
          -85,
          -85,
          -85,
          -85,
          -85,
          -85,
          -85,
          -80,
          -80,
          -80,
          -80,
          -80,
          -80,
          -80,
          -75,
          -75,
          -75,
          -75,
          -75,
          -75,
          -75,
          -70,
          -70,
          -70,
          -70,
          -70,
          -70,
          -70,
          -65,
          -65,
          -65,
          -65,
          -65,
          -65,
          -65,
          -60,
          -60,
          -60,
          -60,
          -60,
          -60,
          -60,
          -55,
          -55,
          -55,
          -55,
          -55,
          -55,
          -55,
          -50,
          -50,
          -50,
          -50,
          -50,
          -50,
          -50,
          -45,
          -45,
          -45,
          -45,
          -45,
          -45,
          -45,
          -40,
          -40,
          -40,
          -40,
          -40,
          -40,
          -40,
          -35,
          -35,
          -35,
          -35,
          -35,
          -35,
          -35,
          -30,
          -30,
          -30,
          -30,
          -30,
          -30,
          -30,
          -25,
          -25,
          -25,
          -25,
          -25,
          -25,
          -25,
          -20,
          -20,
          -20,
          -20,
          -20,
          -20,
          -20,
          -19,
          -19,
          -19,
          -19,
          -19,
          -19,
          -19,
          -18,
          -18,
          -18,
          -18,
          -18,
          -18,
          -18,
          -17,
          -17,
          -17,
          -17,
          -17,
          -17,
          -17,
          -16,
          -16,
          -16,
          -16,
          -16,
          -16,
          -16,
          -15,
          -15,
          -15,
          -15,
          -15,
          -15,
          -15,
          -14,
          -14,
          -14,
          -14,
          -14,
          -14,
          -14,
          -13,
          -13,
          -13,
          -13,
          -13,
          -13,
          -13,
          -12,
          -12,
          -12,
          -12,
          -12,
          -12,
          -12,
          -11,
          -11,
          -11,
          -11,
          -11,
          -11,
          -11,
          -10,
          -10,
          -10,
          -10,
          -10,
          -10,
          -10,
          -9,
          -9,
          -9,
          -9,
          -9,
          -9,
          -9,
          -8,
          -8,
          -8,
          -8,
          -8,
          -8,
          -8,
          -7,
          -7,
          -7,
          -7,
          -7,
          -7,
          -7
         ],
         "y": [
          0.015077531851890227,
          0.015077531851890227,
          0.015077531851890227,
          0.015077531851890227,
          0.015077531851890227,
          0.015077531851890227,
          0.015077531851890227,
          0.02763299763770999,
          0.02763299763770999,
          0.02763299763770999,
          0.02763299763770999,
          0.02763299763770999,
          0.02763299763770999,
          0.02763299763770999,
          0.04017233503927753,
          0.04017233503927753,
          0.04017233503927753,
          0.04017233503927753,
          0.04017233503927753,
          0.04017233503927753,
          0.04017233503927753,
          0.05268823170568113,
          0.05268823170568113,
          0.05268823170568113,
          0.05268823170568113,
          0.05268823170568113,
          0.05268823170568113,
          0.05268823170568113,
          0.0776205638413884,
          0.0776205638413884,
          0.0776205638413884,
          0.0776205638413884,
          0.0776205638413884,
          0.0776205638413884,
          0.0776205638413884,
          0.1390349170085161,
          0.1390349170085161,
          0.1390349170085161,
          0.1390349170085161,
          0.1390349170085161,
          0.1390349170085161,
          0.1390349170085161,
          0.19843650046730416,
          0.19843650046730416,
          0.19843650046730416,
          0.19843650046730416,
          0.19843650046730416,
          0.19843650046730416,
          0.19843650046730416,
          0.25498554767525555,
          0.25498554767525555,
          0.25498554767525555,
          0.25498554767525555,
          0.25498554767525555,
          0.25498554767525555,
          0.25498554767525555,
          0.30790478716494335,
          0.30790478716494335,
          0.30790478716494335,
          0.30790478716494335,
          0.30790478716494335,
          0.30790478716494335,
          0.30790478716494335,
          0.3564958984019987,
          0.3564958984019987,
          0.3564958984019987,
          0.3564958984019987,
          0.3564958984019987,
          0.3564958984019987,
          0.3564958984019987,
          0.4001538072671868,
          0.4001538072671868,
          0.4001538072671868,
          0.4001538072671868,
          0.4001538072671868,
          0.4001538072671868,
          0.4001538072671868,
          0.4383784394870098,
          0.4383784394870098,
          0.4383784394870098,
          0.4383784394870098,
          0.4383784394870098,
          0.4383784394870098,
          0.4383784394870098,
          0.47078362536005536,
          0.47078362536005536,
          0.47078362536005536,
          0.47078362536005536,
          0.47078362536005536,
          0.47078362536005536,
          0.47078362536005536,
          0.4971029330824956,
          0.4971029330824956,
          0.4971029330824956,
          0.4971029330824956,
          0.4971029330824956,
          0.4971029330824956,
          0.4971029330824956,
          0.5171922983345185,
          0.5171922983345185,
          0.5171922983345185,
          0.5171922983345185,
          0.5171922983345185,
          0.5171922983345185,
          0.5171922983345185,
          0.5310294118271535,
          0.5310294118271535,
          0.5310294118271535,
          0.5310294118271535,
          0.5310294118271535,
          0.5310294118271535,
          0.5310294118271535,
          0.5387099213937596,
          0.5387099213937596,
          0.5387099213937596,
          0.5387099213937596,
          0.5387099213937596,
          0.5387099213937596,
          0.5387099213937596,
          0.5404405980869876,
          0.5404405980869876,
          0.5404405980869876,
          0.5404405980869876,
          0.5404405980869876,
          0.5404405980869876,
          0.5404405980869876,
          0.5365297038180028,
          0.5365297038180028,
          0.5365297038180028,
          0.5365297038180028,
          0.5365297038180028,
          0.5365297038180028,
          0.5365297038180028,
          0.5273748787058252,
          0.5273748787058252,
          0.5273748787058252,
          0.5273748787058252,
          0.5273748787058252,
          0.5273748787058252,
          0.5273748787058252,
          0.5134489370743085,
          0.5134489370743085,
          0.5134489370743085,
          0.5134489370743085,
          0.5134489370743085,
          0.5134489370743085,
          0.5134489370743085,
          0.49528401982721076,
          0.49528401982721076,
          0.49528401982721076,
          0.49528401982721076,
          0.49528401982721076,
          0.49528401982721076,
          0.49528401982721076,
          0.4734545959977807,
          0.4734545959977807,
          0.4734545959977807,
          0.4734545959977807,
          0.4734545959977807,
          0.4734545959977807,
          0.4734545959977807,
          0.4485598362760656,
          0.4485598362760656,
          0.4485598362760656,
          0.4485598362760656,
          0.4485598362760656,
          0.4485598362760656,
          0.4485598362760656,
          0.4212058953907819,
          0.4212058953907819,
          0.4212058953907819,
          0.4212058953907819,
          0.4212058953907819,
          0.4212058953907819,
          0.4212058953907819,
          0.3919886379735465,
          0.3919886379735465,
          0.3919886379735465,
          0.3919886379735465,
          0.3919886379735465,
          0.3919886379735465,
          0.3919886379735465,
          0.3614773240680932,
          0.3614773240680932,
          0.3614773240680932,
          0.3614773240680932,
          0.3614773240680932,
          0.3614773240680932,
          0.3614773240680932,
          0.3301997363648196,
          0.3301997363648196,
          0.3301997363648196,
          0.3301997363648196,
          0.3301997363648196,
          0.3301997363648196,
          0.3301997363648196,
          0.2986291826146768,
          0.2986291826146768,
          0.2986291826146768,
          0.2986291826146768,
          0.2986291826146768,
          0.2986291826146768,
          0.2986291826146768,
          0.2671737450201926,
          0.2671737450201926,
          0.2671737450201926,
          0.2671737450201926,
          0.2671737450201926,
          0.2671737450201926,
          0.2671737450201926,
          0.23616807562432898,
          0.23616807562432898,
          0.23616807562432898,
          0.23616807562432898,
          0.23616807562432898,
          0.23616807562432898,
          0.23616807562432898,
          0.20586795506547173,
          0.20586795506547173,
          0.20586795506547173,
          0.20586795506547173,
          0.20586795506547173,
          0.20586795506547173,
          0.20586795506547173,
          0.17644774405279792,
          0.17644774405279792,
          0.17644774405279792,
          0.17644774405279792,
          0.17644774405279792,
          0.17644774405279792,
          0.17644774405279792,
          0.148000765245636,
          0.148000765245636,
          0.148000765245636,
          0.148000765245636,
          0.148000765245636,
          0.148000765245636,
          0.148000765245636,
          0.12054256070734781,
          0.12054256070734781,
          0.12054256070734781,
          0.12054256070734781,
          0.12054256070734781,
          0.12054256070734781,
          0.12054256070734781,
          0.0940168795861161,
          0.0940168795861161,
          0.0940168795861161,
          0.0940168795861161,
          0.0940168795861161,
          0.0940168795861161,
          0.0940168795861161,
          0.08881412576425099,
          0.08881412576425099,
          0.08881412576425099,
          0.08881412576425099,
          0.08881412576425099,
          0.08881412576425099,
          0.08881412576425099,
          0.08364282805546797,
          0.08364282805546797,
          0.08364282805546797,
          0.08364282805546797,
          0.08364282805546797,
          0.08364282805546797,
          0.08364282805546797,
          0.07850167386357848,
          0.07850167386357848,
          0.07850167386357848,
          0.07850167386357848,
          0.07850167386357848,
          0.07850167386357848,
          0.07850167386357848,
          0.07338927364362986,
          0.07338927364362986,
          0.07338927364362986,
          0.07338927364362986,
          0.07338927364362986,
          0.07338927364362986,
          0.07338927364362986,
          0.06830416492610565,
          0.06830416492610565,
          0.06830416492610565,
          0.06830416492610565,
          0.06830416492610565,
          0.06830416492610565,
          0.06830416492610565,
          0.06324481644151558,
          0.06324481644151558,
          0.06324481644151558,
          0.06324481644151558,
          0.06324481644151558,
          0.06324481644151558,
          0.06324481644151558,
          0.058209632339636726,
          0.058209632339636726,
          0.058209632339636726,
          0.058209632339636726,
          0.058209632339636726,
          0.058209632339636726,
          0.058209632339636726,
          0.053196956497547736,
          0.053196956497547736,
          0.053196956497547736,
          0.053196956497547736,
          0.053196956497547736,
          0.053196956497547736,
          0.053196956497547736,
          0.048205076910488226,
          0.048205076910488226,
          0.048205076910488226,
          0.048205076910488226,
          0.048205076910488226,
          0.048205076910488226,
          0.048205076910488226,
          0.04323223015947015,
          0.04323223015947015,
          0.04323223015947015,
          0.04323223015947015,
          0.04323223015947015,
          0.04323223015947015,
          0.04323223015947015,
          0.038276605949472964,
          0.038276605949472964,
          0.038276605949472964,
          0.038276605949472964,
          0.038276605949472964,
          0.038276605949472964,
          0.038276605949472964,
          0.03333635171196557,
          0.03333635171196557,
          0.03333635171196557,
          0.03333635171196557,
          0.03333635171196557,
          0.03333635171196557,
          0.03333635171196557,
          0.028409577265417055,
          0.028409577265417055,
          0.028409577265417055,
          0.028409577265417055,
          0.028409577265417055,
          0.028409577265417055,
          0.028409577265417055
         ]
        },
        {
         "marker": {
          "color": "#0000ff"
         },
         "mode": "lines",
         "showlegend": false,
         "type": "scatter",
         "x": [
          18,
          18,
          18,
          18,
          18,
          18,
          18,
          19,
          19,
          19,
          19,
          19,
          19,
          19,
          20,
          20,
          20,
          20,
          20,
          20,
          20,
          25,
          25,
          25,
          25,
          25,
          25,
          25,
          30,
          30,
          30,
          30,
          30,
          30,
          30,
          35,
          35,
          35,
          35,
          35,
          35,
          35,
          40,
          40,
          40,
          40,
          40,
          40,
          40,
          45,
          45,
          45,
          45,
          45,
          45,
          45,
          50,
          50,
          50,
          50,
          50,
          50,
          50,
          55,
          55,
          55,
          55,
          55,
          55,
          55,
          60,
          60,
          60,
          60,
          60,
          60,
          60,
          65,
          65,
          65,
          65,
          65,
          65,
          65,
          70,
          70,
          70,
          70,
          70,
          70,
          70,
          75,
          75,
          75,
          75,
          75,
          75,
          75,
          80,
          80,
          80,
          80,
          80,
          80,
          80,
          85,
          85,
          85,
          85,
          85,
          85,
          85,
          90,
          90,
          90,
          90,
          90,
          90,
          90,
          95,
          95,
          95,
          95,
          95,
          95,
          95,
          100,
          100,
          100,
          100,
          100,
          100,
          100,
          105,
          105,
          105,
          105,
          105,
          105,
          105,
          110,
          110,
          110,
          110,
          110,
          110,
          110,
          115,
          115,
          115,
          115,
          115,
          115,
          115,
          120,
          120,
          120,
          120,
          120,
          120,
          120,
          125,
          125,
          125,
          125,
          125,
          125,
          125,
          130,
          130,
          130,
          130,
          130,
          130,
          130,
          135,
          135,
          135,
          135,
          135,
          135,
          135,
          140,
          140,
          140,
          140,
          140,
          140,
          140,
          145,
          145,
          145,
          145,
          145,
          145,
          145,
          150,
          150,
          150,
          150,
          150,
          150,
          150,
          155,
          155,
          155,
          155,
          155,
          155,
          155,
          160,
          160,
          160,
          160,
          160,
          160,
          160,
          165,
          165,
          165,
          165,
          165,
          165,
          165,
          170,
          170,
          170,
          170,
          170,
          170,
          170,
          175,
          175,
          175,
          175,
          175,
          175,
          175,
          177,
          177,
          177,
          177,
          177,
          177,
          177,
          178,
          178,
          178,
          178,
          178,
          178,
          178,
          179,
          179,
          179,
          179,
          179,
          179,
          179,
          180,
          180,
          180,
          180,
          180,
          180,
          180
         ],
         "y": [
          -0.09610706753867748,
          -0.09610706753867748,
          -0.09610706753867748,
          -0.09610706753867748,
          -0.09610706753867748,
          -0.09610706753867748,
          -0.09610706753867748,
          -0.10135591038232293,
          -0.10135591038232293,
          -0.10135591038232293,
          -0.10135591038232293,
          -0.10135591038232293,
          -0.10135591038232293,
          -0.10135591038232293,
          -0.10663902240683658,
          -0.10663902240683658,
          -0.10663902240683658,
          -0.10663902240683658,
          -0.10663902240683658,
          -0.10663902240683658,
          -0.10663902240683658,
          -0.13360106562680163,
          -0.13360106562680163,
          -0.13360106562680163,
          -0.13360106562680163,
          -0.13360106562680163,
          -0.13360106562680163,
          -0.13360106562680163,
          -0.1615311109711315,
          -0.1615311109711315,
          -0.1615311109711315,
          -0.1615311109711315,
          -0.1615311109711315,
          -0.1615311109711315,
          -0.1615311109711315,
          -0.19045186035273853,
          -0.19045186035273853,
          -0.19045186035273853,
          -0.19045186035273853,
          -0.19045186035273853,
          -0.19045186035273853,
          -0.19045186035273853,
          -0.22031102063167063,
          -0.22031102063167063,
          -0.22031102063167063,
          -0.22031102063167063,
          -0.22031102063167063,
          -0.22031102063167063,
          -0.22031102063167063,
          -0.2509766027383067,
          -0.2509766027383067,
          -0.2509766027383067,
          -0.2509766027383067,
          -0.2509766027383067,
          -0.2509766027383067,
          -0.2509766027383067,
          -0.2822350318489786,
          -0.2822350318489786,
          -0.2822350318489786,
          -0.2822350318489786,
          -0.2822350318489786,
          -0.2822350318489786,
          -0.2822350318489786,
          -0.31379217093980966,
          -0.31379217093980966,
          -0.31379217093980966,
          -0.31379217093980966,
          -0.31379217093980966,
          -0.31379217093980966,
          -0.31379217093980966,
          -0.34527726821671023,
          -0.34527726821671023,
          -0.34527726821671023,
          -0.34527726821671023,
          -0.34527726821671023,
          -0.34527726821671023,
          -0.34527726821671023,
          -0.37624974645606524,
          -0.37624974645606524,
          -0.37624974645606524,
          -0.37624974645606524,
          -0.37624974645606524,
          -0.37624974645606524,
          -0.37624974645606524,
          -0.40620866202870876,
          -0.40620866202870876,
          -0.40620866202870876,
          -0.40620866202870876,
          -0.40620866202870876,
          -0.40620866202870876,
          -0.40620866202870876,
          -0.4346045760916333,
          -0.4346045760916333,
          -0.4346045760916333,
          -0.4346045760916333,
          -0.4346045760916333,
          -0.4346045760916333,
          -0.4346045760916333,
          -0.4608535027407275,
          -0.4608535027407275,
          -0.4608535027407275,
          -0.4608535027407275,
          -0.4608535027407275,
          -0.4608535027407275,
          -0.4608535027407275,
          -0.4843525312177415,
          -0.4843525312177415,
          -0.4843525312177415,
          -0.4843525312177415,
          -0.4843525312177415,
          -0.4843525312177415,
          -0.4843525312177415,
          -0.5044966636476347,
          -0.5044966636476347,
          -0.5044966636476347,
          -0.5044966636476347,
          -0.5044966636476347,
          -0.5044966636476347,
          -0.5044966636476347,
          -0.5206963679745347,
          -0.5206963679745347,
          -0.5206963679745347,
          -0.5206963679745347,
          -0.5206963679745347,
          -0.5206963679745347,
          -0.5206963679745347,
          -0.5323953190731259,
          -0.5323953190731259,
          -0.5323953190731259,
          -0.5323953190731259,
          -0.5323953190731259,
          -0.5323953190731259,
          -0.5323953190731259,
          -0.5390877902861612,
          -0.5390877902861612,
          -0.5390877902861612,
          -0.5390877902861612,
          -0.5390877902861612,
          -0.5390877902861612,
          -0.5390877902861612,
          -0.5403351632419656,
          -0.5403351632419656,
          -0.5403351632419656,
          -0.5403351632419656,
          -0.5403351632419656,
          -0.5403351632419656,
          -0.5403351632419656,
          -0.5357810456062352,
          -0.5357810456062352,
          -0.5357810456062352,
          -0.5357810456062352,
          -0.5357810456062352,
          -0.5357810456062352,
          -0.5357810456062352,
          -0.525164523795687,
          -0.525164523795687,
          -0.525164523795687,
          -0.525164523795687,
          -0.525164523795687,
          -0.525164523795687,
          -0.525164523795687,
          -0.5083311295291252,
          -0.5083311295291252,
          -0.5083311295291252,
          -0.5083311295291252,
          -0.5083311295291252,
          -0.5083311295291252,
          -0.5083311295291252,
          -0.48524116387553184,
          -0.48524116387553184,
          -0.48524116387553184,
          -0.48524116387553184,
          -0.48524116387553184,
          -0.48524116387553184,
          -0.48524116387553184,
          -0.45597509824607785,
          -0.45597509824607785,
          -0.45597509824607785,
          -0.45597509824607785,
          -0.45597509824607785,
          -0.45597509824607785,
          -0.45597509824607785,
          -0.4207358562989888,
          -0.4207358562989888,
          -0.4207358562989888,
          -0.4207358562989888,
          -0.4207358562989888,
          -0.4207358562989888,
          -0.4207358562989888,
          -0.379847871447507,
          -0.379847871447507,
          -0.379847871447507,
          -0.379847871447507,
          -0.379847871447507,
          -0.379847871447507,
          -0.379847871447507,
          -0.3337529088560795,
          -0.3337529088560795,
          -0.3337529088560795,
          -0.3337529088560795,
          -0.3337529088560795,
          -0.3337529088560795,
          -0.3337529088560795,
          -0.28300273564504225,
          -0.28300273564504225,
          -0.28300273564504225,
          -0.28300273564504225,
          -0.28300273564504225,
          -0.28300273564504225,
          -0.28300273564504225,
          -0.22824881564439506,
          -0.22824881564439506,
          -0.22824881564439506,
          -0.22824881564439506,
          -0.22824881564439506,
          -0.22824881564439506,
          -0.22824881564439506,
          -0.17022929265247538,
          -0.17022929265247538,
          -0.17022929265247538,
          -0.17022929265247538,
          -0.17022929265247538,
          -0.17022929265247538,
          -0.17022929265247538,
          -0.10975360612456816,
          -0.10975360612456816,
          -0.10975360612456816,
          -0.10975360612456816,
          -0.10975360612456816,
          -0.10975360612456816,
          -0.10975360612456816,
          -0.04768515312828386,
          -0.04768515312828386,
          -0.04768515312828386,
          -0.04768515312828386,
          -0.04768515312828386,
          -0.04768515312828386,
          -0.04768515312828386,
          -0.022612336687288896,
          -0.022612336687288896,
          -0.022612336687288896,
          -0.022612336687288896,
          -0.022612336687288896,
          -0.022612336687288896,
          -0.022612336687288896,
          -0.010052470429165315,
          -0.010052470429165315,
          -0.010052470429165315,
          -0.010052470429165315,
          -0.010052470429165315,
          -0.010052470429165315,
          -0.010052470429165315,
          0.002513264340387392,
          0.002513264340387392,
          0.002513264340387392,
          0.002513264340387392,
          0.002513264340387392,
          0.002513264340387392,
          0.002513264340387392,
          0.015077531851890372,
          0.015077531851890372,
          0.015077531851890372,
          0.015077531851890372,
          0.015077531851890372,
          0.015077531851890372,
          0.015077531851890372
         ]
        },
        {
         "line": {
          "color": "#0000ff"
         },
         "mode": "markers",
         "name": "CFD",
         "type": "scatter",
         "x": [
          -6,
          -5.76767677,
          -5.53535354,
          -5.3030303,
          -5.07070707,
          -4.83838384,
          -4.60606061,
          -4.37373737,
          -4.14141414,
          -3.90909091,
          -3.67676768,
          -3.44444444,
          -3.21212121,
          -2.97979798,
          -2.74747475,
          -2.51515152,
          -2.28282828,
          -2.05050505,
          -1.81818182,
          -1.58585859,
          -1.35353535,
          -1.12121212,
          -0.88888889,
          -0.65656566,
          -0.42424242,
          -0.19191919,
          0.04040404,
          0.27272727,
          0.50505051,
          0.73737374,
          0.96969697,
          1.2020202,
          1.43434343,
          1.66666667,
          1.8989899,
          2.13131313,
          2.36363636,
          2.5959596,
          2.82828283,
          3.06060606,
          3.29292929,
          3.52525253,
          3.75757576,
          3.98989899,
          4.22222222,
          4.45454545,
          4.68686869,
          4.91919192,
          5.15151515,
          5.38383838,
          5.61616162,
          5.84848485,
          6.08080808,
          6.31313131,
          6.54545455,
          6.77777778,
          7.01010101,
          7.24242424,
          7.47474747,
          7.70707071,
          7.93939394,
          8.17171717,
          8.4040404,
          8.63636364,
          8.86868687,
          9.1010101,
          9.33333333,
          9.56565657,
          9.7979798,
          10.03030303,
          10.26262626,
          10.49494949,
          10.72727273,
          10.95959596,
          11.19191919,
          11.42424242,
          11.65656566,
          11.88888889,
          12.12121212,
          12.35353535,
          12.58585859,
          12.81818182,
          13.05050505,
          13.28282828,
          13.51515152,
          13.74747475,
          13.97979798,
          14.21212121,
          14.44444444,
          14.67676768,
          14.90909091,
          15.14141414,
          15.37373737,
          15.60606061,
          15.83838384,
          16.07070707,
          16.3030303,
          16.53535354,
          16.76767677,
          17
         ],
         "y": [
          -0.01497397,
          -0.01446314,
          -0.01398811,
          -0.01354619,
          -0.01313468,
          -0.01275094,
          -0.01239299,
          -0.01205917,
          -0.01174763,
          -0.01145632,
          -0.01118442,
          -0.01093266,
          -0.01069827,
          -0.01047118,
          -0.01024558,
          -0.01003155,
          -0.00983981,
          -0.00966947,
          -0.00951612,
          -0.00937535,
          -0.00924274,
          -0.00911386,
          -0.00898443,
          -0.00885277,
          -0.00872007,
          -0.00858762,
          -0.00845673,
          -0.00832832,
          -0.00820239,
          -0.00807881,
          -0.00795745,
          -0.00783795,
          -0.00771852,
          -0.00759688,
          -0.00747074,
          -0.00733785,
          -0.00719692,
          -0.00704743,
          -0.00688888,
          -0.00672079,
          -0.0065425,
          -0.00635301,
          -0.00615132,
          -0.00593639,
          -0.00570718,
          -0.00546249,
          -0.00520108,
          -0.0049217,
          -0.00462314,
          -0.00430472,
          -0.00396603,
          -0.00360673,
          -0.0032264,
          -0.00282227,
          -0.00238893,
          -0.00192461,
          -0.00143726,
          -0.00093242,
          -0.00039339,
          0.00018608,
          0.00079894,
          0.00143474,
          0.00210498,
          0.00282217,
          0.00358258,
          0.00437275,
          0.00519526,
          0.00606848,
          0.00699627,
          0.00796452,
          0.00896682,
          0.01002916,
          0.01115229,
          0.01235877,
          0.01369849,
          0.0151972,
          0.01686539,
          0.01865942,
          0.02050146,
          0.02231298,
          0.023992,
          0.02540202,
          0.02646577,
          0.02710452,
          0.02716489,
          0.02637114,
          0.02483825,
          0.02281415,
          0.01971888,
          0.01565633,
          0.01100706,
          0.00553567,
          -0.00029295,
          -0.00612005,
          -0.01239507,
          -0.01861243,
          -0.02435003,
          -0.02969155,
          -0.03460075,
          -0.03899999
         ]
        }
       ],
       "layout": {
        "plot_bgcolor": "rgba(0,0.5,0,0)",
        "template": {
         "data": {
          "bar": [
           {
            "error_x": {
             "color": "rgb(36,36,36)"
            },
            "error_y": {
             "color": "rgb(36,36,36)"
            },
            "marker": {
             "line": {
              "color": "white",
              "width": 0.5
             },
             "pattern": {
              "fillmode": "overlay",
              "size": 10,
              "solidity": 0.2
             }
            },
            "type": "bar"
           }
          ],
          "barpolar": [
           {
            "marker": {
             "line": {
              "color": "white",
              "width": 0.5
             },
             "pattern": {
              "fillmode": "overlay",
              "size": 10,
              "solidity": 0.2
             }
            },
            "type": "barpolar"
           }
          ],
          "carpet": [
           {
            "aaxis": {
             "endlinecolor": "rgb(36,36,36)",
             "gridcolor": "white",
             "linecolor": "white",
             "minorgridcolor": "white",
             "startlinecolor": "rgb(36,36,36)"
            },
            "baxis": {
             "endlinecolor": "rgb(36,36,36)",
             "gridcolor": "white",
             "linecolor": "white",
             "minorgridcolor": "white",
             "startlinecolor": "rgb(36,36,36)"
            },
            "type": "carpet"
           }
          ],
          "choropleth": [
           {
            "colorbar": {
             "outlinewidth": 1,
             "tickcolor": "rgb(36,36,36)",
             "ticks": "outside"
            },
            "type": "choropleth"
           }
          ],
          "contour": [
           {
            "colorbar": {
             "outlinewidth": 1,
             "tickcolor": "rgb(36,36,36)",
             "ticks": "outside"
            },
            "colorscale": [
             [
              0,
              "#440154"
             ],
             [
              0.1111111111111111,
              "#482878"
             ],
             [
              0.2222222222222222,
              "#3e4989"
             ],
             [
              0.3333333333333333,
              "#31688e"
             ],
             [
              0.4444444444444444,
              "#26828e"
             ],
             [
              0.5555555555555556,
              "#1f9e89"
             ],
             [
              0.6666666666666666,
              "#35b779"
             ],
             [
              0.7777777777777778,
              "#6ece58"
             ],
             [
              0.8888888888888888,
              "#b5de2b"
             ],
             [
              1,
              "#fde725"
             ]
            ],
            "type": "contour"
           }
          ],
          "contourcarpet": [
           {
            "colorbar": {
             "outlinewidth": 1,
             "tickcolor": "rgb(36,36,36)",
             "ticks": "outside"
            },
            "type": "contourcarpet"
           }
          ],
          "heatmap": [
           {
            "colorbar": {
             "outlinewidth": 1,
             "tickcolor": "rgb(36,36,36)",
             "ticks": "outside"
            },
            "colorscale": [
             [
              0,
              "#440154"
             ],
             [
              0.1111111111111111,
              "#482878"
             ],
             [
              0.2222222222222222,
              "#3e4989"
             ],
             [
              0.3333333333333333,
              "#31688e"
             ],
             [
              0.4444444444444444,
              "#26828e"
             ],
             [
              0.5555555555555556,
              "#1f9e89"
             ],
             [
              0.6666666666666666,
              "#35b779"
             ],
             [
              0.7777777777777778,
              "#6ece58"
             ],
             [
              0.8888888888888888,
              "#b5de2b"
             ],
             [
              1,
              "#fde725"
             ]
            ],
            "type": "heatmap"
           }
          ],
          "heatmapgl": [
           {
            "colorbar": {
             "outlinewidth": 1,
             "tickcolor": "rgb(36,36,36)",
             "ticks": "outside"
            },
            "colorscale": [
             [
              0,
              "#440154"
             ],
             [
              0.1111111111111111,
              "#482878"
             ],
             [
              0.2222222222222222,
              "#3e4989"
             ],
             [
              0.3333333333333333,
              "#31688e"
             ],
             [
              0.4444444444444444,
              "#26828e"
             ],
             [
              0.5555555555555556,
              "#1f9e89"
             ],
             [
              0.6666666666666666,
              "#35b779"
             ],
             [
              0.7777777777777778,
              "#6ece58"
             ],
             [
              0.8888888888888888,
              "#b5de2b"
             ],
             [
              1,
              "#fde725"
             ]
            ],
            "type": "heatmapgl"
           }
          ],
          "histogram": [
           {
            "marker": {
             "line": {
              "color": "white",
              "width": 0.6
             }
            },
            "type": "histogram"
           }
          ],
          "histogram2d": [
           {
            "colorbar": {
             "outlinewidth": 1,
             "tickcolor": "rgb(36,36,36)",
             "ticks": "outside"
            },
            "colorscale": [
             [
              0,
              "#440154"
             ],
             [
              0.1111111111111111,
              "#482878"
             ],
             [
              0.2222222222222222,
              "#3e4989"
             ],
             [
              0.3333333333333333,
              "#31688e"
             ],
             [
              0.4444444444444444,
              "#26828e"
             ],
             [
              0.5555555555555556,
              "#1f9e89"
             ],
             [
              0.6666666666666666,
              "#35b779"
             ],
             [
              0.7777777777777778,
              "#6ece58"
             ],
             [
              0.8888888888888888,
              "#b5de2b"
             ],
             [
              1,
              "#fde725"
             ]
            ],
            "type": "histogram2d"
           }
          ],
          "histogram2dcontour": [
           {
            "colorbar": {
             "outlinewidth": 1,
             "tickcolor": "rgb(36,36,36)",
             "ticks": "outside"
            },
            "colorscale": [
             [
              0,
              "#440154"
             ],
             [
              0.1111111111111111,
              "#482878"
             ],
             [
              0.2222222222222222,
              "#3e4989"
             ],
             [
              0.3333333333333333,
              "#31688e"
             ],
             [
              0.4444444444444444,
              "#26828e"
             ],
             [
              0.5555555555555556,
              "#1f9e89"
             ],
             [
              0.6666666666666666,
              "#35b779"
             ],
             [
              0.7777777777777778,
              "#6ece58"
             ],
             [
              0.8888888888888888,
              "#b5de2b"
             ],
             [
              1,
              "#fde725"
             ]
            ],
            "type": "histogram2dcontour"
           }
          ],
          "mesh3d": [
           {
            "colorbar": {
             "outlinewidth": 1,
             "tickcolor": "rgb(36,36,36)",
             "ticks": "outside"
            },
            "type": "mesh3d"
           }
          ],
          "parcoords": [
           {
            "line": {
             "colorbar": {
              "outlinewidth": 1,
              "tickcolor": "rgb(36,36,36)",
              "ticks": "outside"
             }
            },
            "type": "parcoords"
           }
          ],
          "pie": [
           {
            "automargin": true,
            "type": "pie"
           }
          ],
          "scatter": [
           {
            "marker": {
             "colorbar": {
              "outlinewidth": 1,
              "tickcolor": "rgb(36,36,36)",
              "ticks": "outside"
             }
            },
            "type": "scatter"
           }
          ],
          "scatter3d": [
           {
            "line": {
             "colorbar": {
              "outlinewidth": 1,
              "tickcolor": "rgb(36,36,36)",
              "ticks": "outside"
             }
            },
            "marker": {
             "colorbar": {
              "outlinewidth": 1,
              "tickcolor": "rgb(36,36,36)",
              "ticks": "outside"
             }
            },
            "type": "scatter3d"
           }
          ],
          "scattercarpet": [
           {
            "marker": {
             "colorbar": {
              "outlinewidth": 1,
              "tickcolor": "rgb(36,36,36)",
              "ticks": "outside"
             }
            },
            "type": "scattercarpet"
           }
          ],
          "scattergeo": [
           {
            "marker": {
             "colorbar": {
              "outlinewidth": 1,
              "tickcolor": "rgb(36,36,36)",
              "ticks": "outside"
             }
            },
            "type": "scattergeo"
           }
          ],
          "scattergl": [
           {
            "marker": {
             "colorbar": {
              "outlinewidth": 1,
              "tickcolor": "rgb(36,36,36)",
              "ticks": "outside"
             }
            },
            "type": "scattergl"
           }
          ],
          "scattermapbox": [
           {
            "marker": {
             "colorbar": {
              "outlinewidth": 1,
              "tickcolor": "rgb(36,36,36)",
              "ticks": "outside"
             }
            },
            "type": "scattermapbox"
           }
          ],
          "scatterpolar": [
           {
            "marker": {
             "colorbar": {
              "outlinewidth": 1,
              "tickcolor": "rgb(36,36,36)",
              "ticks": "outside"
             }
            },
            "type": "scatterpolar"
           }
          ],
          "scatterpolargl": [
           {
            "marker": {
             "colorbar": {
              "outlinewidth": 1,
              "tickcolor": "rgb(36,36,36)",
              "ticks": "outside"
             }
            },
            "type": "scatterpolargl"
           }
          ],
          "scatterternary": [
           {
            "marker": {
             "colorbar": {
              "outlinewidth": 1,
              "tickcolor": "rgb(36,36,36)",
              "ticks": "outside"
             }
            },
            "type": "scatterternary"
           }
          ],
          "surface": [
           {
            "colorbar": {
             "outlinewidth": 1,
             "tickcolor": "rgb(36,36,36)",
             "ticks": "outside"
            },
            "colorscale": [
             [
              0,
              "#440154"
             ],
             [
              0.1111111111111111,
              "#482878"
             ],
             [
              0.2222222222222222,
              "#3e4989"
             ],
             [
              0.3333333333333333,
              "#31688e"
             ],
             [
              0.4444444444444444,
              "#26828e"
             ],
             [
              0.5555555555555556,
              "#1f9e89"
             ],
             [
              0.6666666666666666,
              "#35b779"
             ],
             [
              0.7777777777777778,
              "#6ece58"
             ],
             [
              0.8888888888888888,
              "#b5de2b"
             ],
             [
              1,
              "#fde725"
             ]
            ],
            "type": "surface"
           }
          ],
          "table": [
           {
            "cells": {
             "fill": {
              "color": "rgb(237,237,237)"
             },
             "line": {
              "color": "white"
             }
            },
            "header": {
             "fill": {
              "color": "rgb(217,217,217)"
             },
             "line": {
              "color": "white"
             }
            },
            "type": "table"
           }
          ]
         },
         "layout": {
          "annotationdefaults": {
           "arrowhead": 0,
           "arrowwidth": 1
          },
          "autotypenumbers": "strict",
          "coloraxis": {
           "colorbar": {
            "outlinewidth": 1,
            "tickcolor": "rgb(36,36,36)",
            "ticks": "outside"
           }
          },
          "colorscale": {
           "diverging": [
            [
             0,
             "rgb(103,0,31)"
            ],
            [
             0.1,
             "rgb(178,24,43)"
            ],
            [
             0.2,
             "rgb(214,96,77)"
            ],
            [
             0.3,
             "rgb(244,165,130)"
            ],
            [
             0.4,
             "rgb(253,219,199)"
            ],
            [
             0.5,
             "rgb(247,247,247)"
            ],
            [
             0.6,
             "rgb(209,229,240)"
            ],
            [
             0.7,
             "rgb(146,197,222)"
            ],
            [
             0.8,
             "rgb(67,147,195)"
            ],
            [
             0.9,
             "rgb(33,102,172)"
            ],
            [
             1,
             "rgb(5,48,97)"
            ]
           ],
           "sequential": [
            [
             0,
             "#440154"
            ],
            [
             0.1111111111111111,
             "#482878"
            ],
            [
             0.2222222222222222,
             "#3e4989"
            ],
            [
             0.3333333333333333,
             "#31688e"
            ],
            [
             0.4444444444444444,
             "#26828e"
            ],
            [
             0.5555555555555556,
             "#1f9e89"
            ],
            [
             0.6666666666666666,
             "#35b779"
            ],
            [
             0.7777777777777778,
             "#6ece58"
            ],
            [
             0.8888888888888888,
             "#b5de2b"
            ],
            [
             1,
             "#fde725"
            ]
           ],
           "sequentialminus": [
            [
             0,
             "#440154"
            ],
            [
             0.1111111111111111,
             "#482878"
            ],
            [
             0.2222222222222222,
             "#3e4989"
            ],
            [
             0.3333333333333333,
             "#31688e"
            ],
            [
             0.4444444444444444,
             "#26828e"
            ],
            [
             0.5555555555555556,
             "#1f9e89"
            ],
            [
             0.6666666666666666,
             "#35b779"
            ],
            [
             0.7777777777777778,
             "#6ece58"
            ],
            [
             0.8888888888888888,
             "#b5de2b"
            ],
            [
             1,
             "#fde725"
            ]
           ]
          },
          "colorway": [
           "#1F77B4",
           "#FF7F0E",
           "#2CA02C",
           "#D62728",
           "#9467BD",
           "#8C564B",
           "#E377C2",
           "#7F7F7F",
           "#BCBD22",
           "#17BECF"
          ],
          "font": {
           "color": "rgb(36,36,36)"
          },
          "geo": {
           "bgcolor": "white",
           "lakecolor": "white",
           "landcolor": "white",
           "showlakes": true,
           "showland": true,
           "subunitcolor": "white"
          },
          "hoverlabel": {
           "align": "left"
          },
          "hovermode": "closest",
          "mapbox": {
           "style": "light"
          },
          "paper_bgcolor": "white",
          "plot_bgcolor": "white",
          "polar": {
           "angularaxis": {
            "gridcolor": "rgb(232,232,232)",
            "linecolor": "rgb(36,36,36)",
            "showgrid": false,
            "showline": true,
            "ticks": "outside"
           },
           "bgcolor": "white",
           "radialaxis": {
            "gridcolor": "rgb(232,232,232)",
            "linecolor": "rgb(36,36,36)",
            "showgrid": false,
            "showline": true,
            "ticks": "outside"
           }
          },
          "scene": {
           "xaxis": {
            "backgroundcolor": "white",
            "gridcolor": "rgb(232,232,232)",
            "gridwidth": 2,
            "linecolor": "rgb(36,36,36)",
            "showbackground": true,
            "showgrid": false,
            "showline": true,
            "ticks": "outside",
            "zeroline": false,
            "zerolinecolor": "rgb(36,36,36)"
           },
           "yaxis": {
            "backgroundcolor": "white",
            "gridcolor": "rgb(232,232,232)",
            "gridwidth": 2,
            "linecolor": "rgb(36,36,36)",
            "showbackground": true,
            "showgrid": false,
            "showline": true,
            "ticks": "outside",
            "zeroline": false,
            "zerolinecolor": "rgb(36,36,36)"
           },
           "zaxis": {
            "backgroundcolor": "white",
            "gridcolor": "rgb(232,232,232)",
            "gridwidth": 2,
            "linecolor": "rgb(36,36,36)",
            "showbackground": true,
            "showgrid": false,
            "showline": true,
            "ticks": "outside",
            "zeroline": false,
            "zerolinecolor": "rgb(36,36,36)"
           }
          },
          "shapedefaults": {
           "fillcolor": "black",
           "line": {
            "width": 0
           },
           "opacity": 0.3
          },
          "ternary": {
           "aaxis": {
            "gridcolor": "rgb(232,232,232)",
            "linecolor": "rgb(36,36,36)",
            "showgrid": false,
            "showline": true,
            "ticks": "outside"
           },
           "baxis": {
            "gridcolor": "rgb(232,232,232)",
            "linecolor": "rgb(36,36,36)",
            "showgrid": false,
            "showline": true,
            "ticks": "outside"
           },
           "bgcolor": "white",
           "caxis": {
            "gridcolor": "rgb(232,232,232)",
            "linecolor": "rgb(36,36,36)",
            "showgrid": false,
            "showline": true,
            "ticks": "outside"
           }
          },
          "title": {
           "x": 0.05
          },
          "xaxis": {
           "automargin": true,
           "gridcolor": "rgb(232,232,232)",
           "linecolor": "rgb(36,36,36)",
           "showgrid": false,
           "showline": true,
           "ticks": "outside",
           "title": {
            "standoff": 15
           },
           "zeroline": false,
           "zerolinecolor": "rgb(36,36,36)"
          },
          "yaxis": {
           "automargin": true,
           "gridcolor": "rgb(232,232,232)",
           "linecolor": "rgb(36,36,36)",
           "showgrid": false,
           "showline": true,
           "ticks": "outside",
           "title": {
            "standoff": 15
           },
           "zeroline": false,
           "zerolinecolor": "rgb(36,36,36)"
          }
         }
        },
        "title": {
         "text": "Cm vs Alpha"
        },
        "xaxis": {
         "gridcolor": "Gray",
         "gridwidth": 1,
         "linecolor": "black",
         "linewidth": 2,
         "mirror": false,
         "showgrid": true,
         "showline": true,
         "title": {
          "text": "Alpha [deg]"
         },
         "zeroline": true,
         "zerolinecolor": "Gray",
         "zerolinewidth": 1
        },
        "yaxis": {
         "gridcolor": "Gray",
         "gridwidth": 0.5,
         "linecolor": "black",
         "linewidth": 2,
         "mirror": false,
         "showgrid": true,
         "showline": true,
         "title": {
          "text": "Cm"
         },
         "zeroline": true,
         "zerolinecolor": "Gray",
         "zerolinewidth": 1
        }
       }
      },
      "text/html": [
       "<div>                            <div id=\"b6ac7958-344a-42ee-8e91-b2c74d708cac\" class=\"plotly-graph-div\" style=\"height:525px; width:100%;\"></div>            <script type=\"text/javascript\">                require([\"plotly\"], function(Plotly) {                    window.PLOTLYENV=window.PLOTLYENV || {};                                    if (document.getElementById(\"b6ac7958-344a-42ee-8e91-b2c74d708cac\")) {                    Plotly.newPlot(                        \"b6ac7958-344a-42ee-8e91-b2c74d708cac\",                        [{\"line\":{\"color\":\"#0000ff\"},\"mode\":\"lines\",\"name\":\"Empirical curve-fit\",\"type\":\"scatter\",\"x\":[-180.0,-180.0,-180.0,-180.0,-180.0,-180.0,-180.0,-179.0,-179.0,-179.0,-179.0,-179.0,-179.0,-179.0,-178.0,-178.0,-178.0,-178.0,-178.0,-178.0,-178.0,-177.0,-177.0,-177.0,-177.0,-177.0,-177.0,-177.0,-175.0,-175.0,-175.0,-175.0,-175.0,-175.0,-175.0,-170.0,-170.0,-170.0,-170.0,-170.0,-170.0,-170.0,-165.0,-165.0,-165.0,-165.0,-165.0,-165.0,-165.0,-160.0,-160.0,-160.0,-160.0,-160.0,-160.0,-160.0,-155.0,-155.0,-155.0,-155.0,-155.0,-155.0,-155.0,-150.0,-150.0,-150.0,-150.0,-150.0,-150.0,-150.0,-145.0,-145.0,-145.0,-145.0,-145.0,-145.0,-145.0,-140.0,-140.0,-140.0,-140.0,-140.0,-140.0,-140.0,-135.0,-135.0,-135.0,-135.0,-135.0,-135.0,-135.0,-130.0,-130.0,-130.0,-130.0,-130.0,-130.0,-130.0,-125.0,-125.0,-125.0,-125.0,-125.0,-125.0,-125.0,-120.0,-120.0,-120.0,-120.0,-120.0,-120.0,-120.0,-115.0,-115.0,-115.0,-115.0,-115.0,-115.0,-115.0,-110.0,-110.0,-110.0,-110.0,-110.0,-110.0,-110.0,-105.0,-105.0,-105.0,-105.0,-105.0,-105.0,-105.0,-100.0,-100.0,-100.0,-100.0,-100.0,-100.0,-100.0,-95.0,-95.0,-95.0,-95.0,-95.0,-95.0,-95.0,-90.0,-90.0,-90.0,-90.0,-90.0,-90.0,-90.0,-85.0,-85.0,-85.0,-85.0,-85.0,-85.0,-85.0,-80.0,-80.0,-80.0,-80.0,-80.0,-80.0,-80.0,-75.0,-75.0,-75.0,-75.0,-75.0,-75.0,-75.0,-70.0,-70.0,-70.0,-70.0,-70.0,-70.0,-70.0,-65.0,-65.0,-65.0,-65.0,-65.0,-65.0,-65.0,-60.0,-60.0,-60.0,-60.0,-60.0,-60.0,-60.0,-55.0,-55.0,-55.0,-55.0,-55.0,-55.0,-55.0,-50.0,-50.0,-50.0,-50.0,-50.0,-50.0,-50.0,-45.0,-45.0,-45.0,-45.0,-45.0,-45.0,-45.0,-40.0,-40.0,-40.0,-40.0,-40.0,-40.0,-40.0,-35.0,-35.0,-35.0,-35.0,-35.0,-35.0,-35.0,-30.0,-30.0,-30.0,-30.0,-30.0,-30.0,-30.0,-25.0,-25.0,-25.0,-25.0,-25.0,-25.0,-25.0,-20.0,-20.0,-20.0,-20.0,-20.0,-20.0,-20.0,-19.0,-19.0,-19.0,-19.0,-19.0,-19.0,-19.0,-18.0,-18.0,-18.0,-18.0,-18.0,-18.0,-18.0,-17.0,-17.0,-17.0,-17.0,-17.0,-17.0,-17.0,-16.0,-16.0,-16.0,-16.0,-16.0,-16.0,-16.0,-15.0,-15.0,-15.0,-15.0,-15.0,-15.0,-15.0,-14.0,-14.0,-14.0,-14.0,-14.0,-14.0,-14.0,-13.0,-13.0,-13.0,-13.0,-13.0,-13.0,-13.0,-12.0,-12.0,-12.0,-12.0,-12.0,-12.0,-12.0,-11.0,-11.0,-11.0,-11.0,-11.0,-11.0,-11.0,-10.0,-10.0,-10.0,-10.0,-10.0,-10.0,-10.0,-9.0,-9.0,-9.0,-9.0,-9.0,-9.0,-9.0,-8.0,-8.0,-8.0,-8.0,-8.0,-8.0,-8.0,-7.0,-7.0,-7.0,-7.0,-7.0,-7.0,-7.0],\"y\":[0.015077531851890227,0.015077531851890227,0.015077531851890227,0.015077531851890227,0.015077531851890227,0.015077531851890227,0.015077531851890227,0.02763299763770999,0.02763299763770999,0.02763299763770999,0.02763299763770999,0.02763299763770999,0.02763299763770999,0.02763299763770999,0.04017233503927753,0.04017233503927753,0.04017233503927753,0.04017233503927753,0.04017233503927753,0.04017233503927753,0.04017233503927753,0.05268823170568113,0.05268823170568113,0.05268823170568113,0.05268823170568113,0.05268823170568113,0.05268823170568113,0.05268823170568113,0.0776205638413884,0.0776205638413884,0.0776205638413884,0.0776205638413884,0.0776205638413884,0.0776205638413884,0.0776205638413884,0.1390349170085161,0.1390349170085161,0.1390349170085161,0.1390349170085161,0.1390349170085161,0.1390349170085161,0.1390349170085161,0.19843650046730416,0.19843650046730416,0.19843650046730416,0.19843650046730416,0.19843650046730416,0.19843650046730416,0.19843650046730416,0.25498554767525555,0.25498554767525555,0.25498554767525555,0.25498554767525555,0.25498554767525555,0.25498554767525555,0.25498554767525555,0.30790478716494335,0.30790478716494335,0.30790478716494335,0.30790478716494335,0.30790478716494335,0.30790478716494335,0.30790478716494335,0.3564958984019987,0.3564958984019987,0.3564958984019987,0.3564958984019987,0.3564958984019987,0.3564958984019987,0.3564958984019987,0.4001538072671868,0.4001538072671868,0.4001538072671868,0.4001538072671868,0.4001538072671868,0.4001538072671868,0.4001538072671868,0.4383784394870098,0.4383784394870098,0.4383784394870098,0.4383784394870098,0.4383784394870098,0.4383784394870098,0.4383784394870098,0.47078362536005536,0.47078362536005536,0.47078362536005536,0.47078362536005536,0.47078362536005536,0.47078362536005536,0.47078362536005536,0.4971029330824956,0.4971029330824956,0.4971029330824956,0.4971029330824956,0.4971029330824956,0.4971029330824956,0.4971029330824956,0.5171922983345185,0.5171922983345185,0.5171922983345185,0.5171922983345185,0.5171922983345185,0.5171922983345185,0.5171922983345185,0.5310294118271535,0.5310294118271535,0.5310294118271535,0.5310294118271535,0.5310294118271535,0.5310294118271535,0.5310294118271535,0.5387099213937596,0.5387099213937596,0.5387099213937596,0.5387099213937596,0.5387099213937596,0.5387099213937596,0.5387099213937596,0.5404405980869876,0.5404405980869876,0.5404405980869876,0.5404405980869876,0.5404405980869876,0.5404405980869876,0.5404405980869876,0.5365297038180028,0.5365297038180028,0.5365297038180028,0.5365297038180028,0.5365297038180028,0.5365297038180028,0.5365297038180028,0.5273748787058252,0.5273748787058252,0.5273748787058252,0.5273748787058252,0.5273748787058252,0.5273748787058252,0.5273748787058252,0.5134489370743085,0.5134489370743085,0.5134489370743085,0.5134489370743085,0.5134489370743085,0.5134489370743085,0.5134489370743085,0.49528401982721076,0.49528401982721076,0.49528401982721076,0.49528401982721076,0.49528401982721076,0.49528401982721076,0.49528401982721076,0.4734545959977807,0.4734545959977807,0.4734545959977807,0.4734545959977807,0.4734545959977807,0.4734545959977807,0.4734545959977807,0.4485598362760656,0.4485598362760656,0.4485598362760656,0.4485598362760656,0.4485598362760656,0.4485598362760656,0.4485598362760656,0.4212058953907819,0.4212058953907819,0.4212058953907819,0.4212058953907819,0.4212058953907819,0.4212058953907819,0.4212058953907819,0.3919886379735465,0.3919886379735465,0.3919886379735465,0.3919886379735465,0.3919886379735465,0.3919886379735465,0.3919886379735465,0.3614773240680932,0.3614773240680932,0.3614773240680932,0.3614773240680932,0.3614773240680932,0.3614773240680932,0.3614773240680932,0.3301997363648196,0.3301997363648196,0.3301997363648196,0.3301997363648196,0.3301997363648196,0.3301997363648196,0.3301997363648196,0.2986291826146768,0.2986291826146768,0.2986291826146768,0.2986291826146768,0.2986291826146768,0.2986291826146768,0.2986291826146768,0.2671737450201926,0.2671737450201926,0.2671737450201926,0.2671737450201926,0.2671737450201926,0.2671737450201926,0.2671737450201926,0.23616807562432898,0.23616807562432898,0.23616807562432898,0.23616807562432898,0.23616807562432898,0.23616807562432898,0.23616807562432898,0.20586795506547173,0.20586795506547173,0.20586795506547173,0.20586795506547173,0.20586795506547173,0.20586795506547173,0.20586795506547173,0.17644774405279792,0.17644774405279792,0.17644774405279792,0.17644774405279792,0.17644774405279792,0.17644774405279792,0.17644774405279792,0.148000765245636,0.148000765245636,0.148000765245636,0.148000765245636,0.148000765245636,0.148000765245636,0.148000765245636,0.12054256070734781,0.12054256070734781,0.12054256070734781,0.12054256070734781,0.12054256070734781,0.12054256070734781,0.12054256070734781,0.0940168795861161,0.0940168795861161,0.0940168795861161,0.0940168795861161,0.0940168795861161,0.0940168795861161,0.0940168795861161,0.08881412576425099,0.08881412576425099,0.08881412576425099,0.08881412576425099,0.08881412576425099,0.08881412576425099,0.08881412576425099,0.08364282805546797,0.08364282805546797,0.08364282805546797,0.08364282805546797,0.08364282805546797,0.08364282805546797,0.08364282805546797,0.07850167386357848,0.07850167386357848,0.07850167386357848,0.07850167386357848,0.07850167386357848,0.07850167386357848,0.07850167386357848,0.07338927364362986,0.07338927364362986,0.07338927364362986,0.07338927364362986,0.07338927364362986,0.07338927364362986,0.07338927364362986,0.06830416492610565,0.06830416492610565,0.06830416492610565,0.06830416492610565,0.06830416492610565,0.06830416492610565,0.06830416492610565,0.06324481644151558,0.06324481644151558,0.06324481644151558,0.06324481644151558,0.06324481644151558,0.06324481644151558,0.06324481644151558,0.058209632339636726,0.058209632339636726,0.058209632339636726,0.058209632339636726,0.058209632339636726,0.058209632339636726,0.058209632339636726,0.053196956497547736,0.053196956497547736,0.053196956497547736,0.053196956497547736,0.053196956497547736,0.053196956497547736,0.053196956497547736,0.048205076910488226,0.048205076910488226,0.048205076910488226,0.048205076910488226,0.048205076910488226,0.048205076910488226,0.048205076910488226,0.04323223015947015,0.04323223015947015,0.04323223015947015,0.04323223015947015,0.04323223015947015,0.04323223015947015,0.04323223015947015,0.038276605949472964,0.038276605949472964,0.038276605949472964,0.038276605949472964,0.038276605949472964,0.038276605949472964,0.038276605949472964,0.03333635171196557,0.03333635171196557,0.03333635171196557,0.03333635171196557,0.03333635171196557,0.03333635171196557,0.03333635171196557,0.028409577265417055,0.028409577265417055,0.028409577265417055,0.028409577265417055,0.028409577265417055,0.028409577265417055,0.028409577265417055]},{\"marker\":{\"color\":\"#0000ff\"},\"mode\":\"lines\",\"showlegend\":false,\"type\":\"scatter\",\"x\":[18.0,18.0,18.0,18.0,18.0,18.0,18.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,20.0,20.0,20.0,20.0,20.0,20.0,20.0,25.0,25.0,25.0,25.0,25.0,25.0,25.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,40.0,40.0,40.0,40.0,40.0,40.0,40.0,45.0,45.0,45.0,45.0,45.0,45.0,45.0,50.0,50.0,50.0,50.0,50.0,50.0,50.0,55.0,55.0,55.0,55.0,55.0,55.0,55.0,60.0,60.0,60.0,60.0,60.0,60.0,60.0,65.0,65.0,65.0,65.0,65.0,65.0,65.0,70.0,70.0,70.0,70.0,70.0,70.0,70.0,75.0,75.0,75.0,75.0,75.0,75.0,75.0,80.0,80.0,80.0,80.0,80.0,80.0,80.0,85.0,85.0,85.0,85.0,85.0,85.0,85.0,90.0,90.0,90.0,90.0,90.0,90.0,90.0,95.0,95.0,95.0,95.0,95.0,95.0,95.0,100.0,100.0,100.0,100.0,100.0,100.0,100.0,105.0,105.0,105.0,105.0,105.0,105.0,105.0,110.0,110.0,110.0,110.0,110.0,110.0,110.0,115.0,115.0,115.0,115.0,115.0,115.0,115.0,120.0,120.0,120.0,120.0,120.0,120.0,120.0,125.0,125.0,125.0,125.0,125.0,125.0,125.0,130.0,130.0,130.0,130.0,130.0,130.0,130.0,135.0,135.0,135.0,135.0,135.0,135.0,135.0,140.0,140.0,140.0,140.0,140.0,140.0,140.0,145.0,145.0,145.0,145.0,145.0,145.0,145.0,150.0,150.0,150.0,150.0,150.0,150.0,150.0,155.0,155.0,155.0,155.0,155.0,155.0,155.0,160.0,160.0,160.0,160.0,160.0,160.0,160.0,165.0,165.0,165.0,165.0,165.0,165.0,165.0,170.0,170.0,170.0,170.0,170.0,170.0,170.0,175.0,175.0,175.0,175.0,175.0,175.0,175.0,177.0,177.0,177.0,177.0,177.0,177.0,177.0,178.0,178.0,178.0,178.0,178.0,178.0,178.0,179.0,179.0,179.0,179.0,179.0,179.0,179.0,180.0,180.0,180.0,180.0,180.0,180.0,180.0],\"y\":[-0.09610706753867748,-0.09610706753867748,-0.09610706753867748,-0.09610706753867748,-0.09610706753867748,-0.09610706753867748,-0.09610706753867748,-0.10135591038232293,-0.10135591038232293,-0.10135591038232293,-0.10135591038232293,-0.10135591038232293,-0.10135591038232293,-0.10135591038232293,-0.10663902240683658,-0.10663902240683658,-0.10663902240683658,-0.10663902240683658,-0.10663902240683658,-0.10663902240683658,-0.10663902240683658,-0.13360106562680163,-0.13360106562680163,-0.13360106562680163,-0.13360106562680163,-0.13360106562680163,-0.13360106562680163,-0.13360106562680163,-0.1615311109711315,-0.1615311109711315,-0.1615311109711315,-0.1615311109711315,-0.1615311109711315,-0.1615311109711315,-0.1615311109711315,-0.19045186035273853,-0.19045186035273853,-0.19045186035273853,-0.19045186035273853,-0.19045186035273853,-0.19045186035273853,-0.19045186035273853,-0.22031102063167063,-0.22031102063167063,-0.22031102063167063,-0.22031102063167063,-0.22031102063167063,-0.22031102063167063,-0.22031102063167063,-0.2509766027383067,-0.2509766027383067,-0.2509766027383067,-0.2509766027383067,-0.2509766027383067,-0.2509766027383067,-0.2509766027383067,-0.2822350318489786,-0.2822350318489786,-0.2822350318489786,-0.2822350318489786,-0.2822350318489786,-0.2822350318489786,-0.2822350318489786,-0.31379217093980966,-0.31379217093980966,-0.31379217093980966,-0.31379217093980966,-0.31379217093980966,-0.31379217093980966,-0.31379217093980966,-0.34527726821671023,-0.34527726821671023,-0.34527726821671023,-0.34527726821671023,-0.34527726821671023,-0.34527726821671023,-0.34527726821671023,-0.37624974645606524,-0.37624974645606524,-0.37624974645606524,-0.37624974645606524,-0.37624974645606524,-0.37624974645606524,-0.37624974645606524,-0.40620866202870876,-0.40620866202870876,-0.40620866202870876,-0.40620866202870876,-0.40620866202870876,-0.40620866202870876,-0.40620866202870876,-0.4346045760916333,-0.4346045760916333,-0.4346045760916333,-0.4346045760916333,-0.4346045760916333,-0.4346045760916333,-0.4346045760916333,-0.4608535027407275,-0.4608535027407275,-0.4608535027407275,-0.4608535027407275,-0.4608535027407275,-0.4608535027407275,-0.4608535027407275,-0.4843525312177415,-0.4843525312177415,-0.4843525312177415,-0.4843525312177415,-0.4843525312177415,-0.4843525312177415,-0.4843525312177415,-0.5044966636476347,-0.5044966636476347,-0.5044966636476347,-0.5044966636476347,-0.5044966636476347,-0.5044966636476347,-0.5044966636476347,-0.5206963679745347,-0.5206963679745347,-0.5206963679745347,-0.5206963679745347,-0.5206963679745347,-0.5206963679745347,-0.5206963679745347,-0.5323953190731259,-0.5323953190731259,-0.5323953190731259,-0.5323953190731259,-0.5323953190731259,-0.5323953190731259,-0.5323953190731259,-0.5390877902861612,-0.5390877902861612,-0.5390877902861612,-0.5390877902861612,-0.5390877902861612,-0.5390877902861612,-0.5390877902861612,-0.5403351632419656,-0.5403351632419656,-0.5403351632419656,-0.5403351632419656,-0.5403351632419656,-0.5403351632419656,-0.5403351632419656,-0.5357810456062352,-0.5357810456062352,-0.5357810456062352,-0.5357810456062352,-0.5357810456062352,-0.5357810456062352,-0.5357810456062352,-0.525164523795687,-0.525164523795687,-0.525164523795687,-0.525164523795687,-0.525164523795687,-0.525164523795687,-0.525164523795687,-0.5083311295291252,-0.5083311295291252,-0.5083311295291252,-0.5083311295291252,-0.5083311295291252,-0.5083311295291252,-0.5083311295291252,-0.48524116387553184,-0.48524116387553184,-0.48524116387553184,-0.48524116387553184,-0.48524116387553184,-0.48524116387553184,-0.48524116387553184,-0.45597509824607785,-0.45597509824607785,-0.45597509824607785,-0.45597509824607785,-0.45597509824607785,-0.45597509824607785,-0.45597509824607785,-0.4207358562989888,-0.4207358562989888,-0.4207358562989888,-0.4207358562989888,-0.4207358562989888,-0.4207358562989888,-0.4207358562989888,-0.379847871447507,-0.379847871447507,-0.379847871447507,-0.379847871447507,-0.379847871447507,-0.379847871447507,-0.379847871447507,-0.3337529088560795,-0.3337529088560795,-0.3337529088560795,-0.3337529088560795,-0.3337529088560795,-0.3337529088560795,-0.3337529088560795,-0.28300273564504225,-0.28300273564504225,-0.28300273564504225,-0.28300273564504225,-0.28300273564504225,-0.28300273564504225,-0.28300273564504225,-0.22824881564439506,-0.22824881564439506,-0.22824881564439506,-0.22824881564439506,-0.22824881564439506,-0.22824881564439506,-0.22824881564439506,-0.17022929265247538,-0.17022929265247538,-0.17022929265247538,-0.17022929265247538,-0.17022929265247538,-0.17022929265247538,-0.17022929265247538,-0.10975360612456816,-0.10975360612456816,-0.10975360612456816,-0.10975360612456816,-0.10975360612456816,-0.10975360612456816,-0.10975360612456816,-0.04768515312828386,-0.04768515312828386,-0.04768515312828386,-0.04768515312828386,-0.04768515312828386,-0.04768515312828386,-0.04768515312828386,-0.022612336687288896,-0.022612336687288896,-0.022612336687288896,-0.022612336687288896,-0.022612336687288896,-0.022612336687288896,-0.022612336687288896,-0.010052470429165315,-0.010052470429165315,-0.010052470429165315,-0.010052470429165315,-0.010052470429165315,-0.010052470429165315,-0.010052470429165315,0.002513264340387392,0.002513264340387392,0.002513264340387392,0.002513264340387392,0.002513264340387392,0.002513264340387392,0.002513264340387392,0.015077531851890372,0.015077531851890372,0.015077531851890372,0.015077531851890372,0.015077531851890372,0.015077531851890372,0.015077531851890372]},{\"line\":{\"color\":\"#0000ff\"},\"mode\":\"markers\",\"name\":\"CFD\",\"type\":\"scatter\",\"x\":[-6.0,-5.76767677,-5.53535354,-5.3030303,-5.07070707,-4.83838384,-4.60606061,-4.37373737,-4.14141414,-3.90909091,-3.67676768,-3.44444444,-3.21212121,-2.97979798,-2.74747475,-2.51515152,-2.28282828,-2.05050505,-1.81818182,-1.58585859,-1.35353535,-1.12121212,-0.88888889,-0.65656566,-0.42424242,-0.19191919,0.04040404,0.27272727,0.50505051,0.73737374,0.96969697,1.2020202,1.43434343,1.66666667,1.8989899,2.13131313,2.36363636,2.5959596,2.82828283,3.06060606,3.29292929,3.52525253,3.75757576,3.98989899,4.22222222,4.45454545,4.68686869,4.91919192,5.15151515,5.38383838,5.61616162,5.84848485,6.08080808,6.31313131,6.54545455,6.77777778,7.01010101,7.24242424,7.47474747,7.70707071,7.93939394,8.17171717,8.4040404,8.63636364,8.86868687,9.1010101,9.33333333,9.56565657,9.7979798,10.03030303,10.26262626,10.49494949,10.72727273,10.95959596,11.19191919,11.42424242,11.65656566,11.88888889,12.12121212,12.35353535,12.58585859,12.81818182,13.05050505,13.28282828,13.51515152,13.74747475,13.97979798,14.21212121,14.44444444,14.67676768,14.90909091,15.14141414,15.37373737,15.60606061,15.83838384,16.07070707,16.3030303,16.53535354,16.76767677,17.0],\"y\":[-0.01497397,-0.01446314,-0.01398811,-0.01354619,-0.01313468,-0.01275094,-0.01239299,-0.01205917,-0.01174763,-0.01145632,-0.01118442,-0.01093266,-0.01069827,-0.01047118,-0.01024558,-0.01003155,-0.00983981,-0.00966947,-0.00951612,-0.00937535,-0.00924274,-0.00911386,-0.00898443,-0.00885277,-0.00872007,-0.00858762,-0.00845673,-0.00832832,-0.00820239,-0.00807881,-0.00795745,-0.00783795,-0.00771852,-0.00759688,-0.00747074,-0.00733785,-0.00719692,-0.00704743,-0.00688888,-0.00672079,-0.0065425,-0.00635301,-0.00615132,-0.00593639,-0.00570718,-0.00546249,-0.00520108,-0.0049217,-0.00462314,-0.00430472,-0.00396603,-0.00360673,-0.0032264,-0.00282227,-0.00238893,-0.00192461,-0.00143726,-0.00093242,-0.00039339,0.00018608,0.00079894,0.00143474,0.00210498,0.00282217,0.00358258,0.00437275,0.00519526,0.00606848,0.00699627,0.00796452,0.00896682,0.01002916,0.01115229,0.01235877,0.01369849,0.0151972,0.01686539,0.01865942,0.02050146,0.02231298,0.023992,0.02540202,0.02646577,0.02710452,0.02716489,0.02637114,0.02483825,0.02281415,0.01971888,0.01565633,0.01100706,0.00553567,-0.00029295,-0.00612005,-0.01239507,-0.01861243,-0.02435003,-0.02969155,-0.03460075,-0.03899999]}],                        {\"plot_bgcolor\":\"rgba(0,0.5,0,0)\",\"template\":{\"data\":{\"bar\":[{\"error_x\":{\"color\":\"rgb(36,36,36)\"},\"error_y\":{\"color\":\"rgb(36,36,36)\"},\"marker\":{\"line\":{\"color\":\"white\",\"width\":0.5},\"pattern\":{\"fillmode\":\"overlay\",\"size\":10,\"solidity\":0.2}},\"type\":\"bar\"}],\"barpolar\":[{\"marker\":{\"line\":{\"color\":\"white\",\"width\":0.5},\"pattern\":{\"fillmode\":\"overlay\",\"size\":10,\"solidity\":0.2}},\"type\":\"barpolar\"}],\"carpet\":[{\"aaxis\":{\"endlinecolor\":\"rgb(36,36,36)\",\"gridcolor\":\"white\",\"linecolor\":\"white\",\"minorgridcolor\":\"white\",\"startlinecolor\":\"rgb(36,36,36)\"},\"baxis\":{\"endlinecolor\":\"rgb(36,36,36)\",\"gridcolor\":\"white\",\"linecolor\":\"white\",\"minorgridcolor\":\"white\",\"startlinecolor\":\"rgb(36,36,36)\"},\"type\":\"carpet\"}],\"choropleth\":[{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"},\"type\":\"choropleth\"}],\"contour\":[{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"},\"colorscale\":[[0.0,\"#440154\"],[0.1111111111111111,\"#482878\"],[0.2222222222222222,\"#3e4989\"],[0.3333333333333333,\"#31688e\"],[0.4444444444444444,\"#26828e\"],[0.5555555555555556,\"#1f9e89\"],[0.6666666666666666,\"#35b779\"],[0.7777777777777778,\"#6ece58\"],[0.8888888888888888,\"#b5de2b\"],[1.0,\"#fde725\"]],\"type\":\"contour\"}],\"contourcarpet\":[{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"},\"type\":\"contourcarpet\"}],\"heatmap\":[{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"},\"colorscale\":[[0.0,\"#440154\"],[0.1111111111111111,\"#482878\"],[0.2222222222222222,\"#3e4989\"],[0.3333333333333333,\"#31688e\"],[0.4444444444444444,\"#26828e\"],[0.5555555555555556,\"#1f9e89\"],[0.6666666666666666,\"#35b779\"],[0.7777777777777778,\"#6ece58\"],[0.8888888888888888,\"#b5de2b\"],[1.0,\"#fde725\"]],\"type\":\"heatmap\"}],\"heatmapgl\":[{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"},\"colorscale\":[[0.0,\"#440154\"],[0.1111111111111111,\"#482878\"],[0.2222222222222222,\"#3e4989\"],[0.3333333333333333,\"#31688e\"],[0.4444444444444444,\"#26828e\"],[0.5555555555555556,\"#1f9e89\"],[0.6666666666666666,\"#35b779\"],[0.7777777777777778,\"#6ece58\"],[0.8888888888888888,\"#b5de2b\"],[1.0,\"#fde725\"]],\"type\":\"heatmapgl\"}],\"histogram\":[{\"marker\":{\"line\":{\"color\":\"white\",\"width\":0.6}},\"type\":\"histogram\"}],\"histogram2d\":[{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"},\"colorscale\":[[0.0,\"#440154\"],[0.1111111111111111,\"#482878\"],[0.2222222222222222,\"#3e4989\"],[0.3333333333333333,\"#31688e\"],[0.4444444444444444,\"#26828e\"],[0.5555555555555556,\"#1f9e89\"],[0.6666666666666666,\"#35b779\"],[0.7777777777777778,\"#6ece58\"],[0.8888888888888888,\"#b5de2b\"],[1.0,\"#fde725\"]],\"type\":\"histogram2d\"}],\"histogram2dcontour\":[{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"},\"colorscale\":[[0.0,\"#440154\"],[0.1111111111111111,\"#482878\"],[0.2222222222222222,\"#3e4989\"],[0.3333333333333333,\"#31688e\"],[0.4444444444444444,\"#26828e\"],[0.5555555555555556,\"#1f9e89\"],[0.6666666666666666,\"#35b779\"],[0.7777777777777778,\"#6ece58\"],[0.8888888888888888,\"#b5de2b\"],[1.0,\"#fde725\"]],\"type\":\"histogram2dcontour\"}],\"mesh3d\":[{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"},\"type\":\"mesh3d\"}],\"parcoords\":[{\"line\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"type\":\"parcoords\"}],\"pie\":[{\"automargin\":true,\"type\":\"pie\"}],\"scatter\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"type\":\"scatter\"}],\"scatter3d\":[{\"line\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"marker\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"type\":\"scatter3d\"}],\"scattercarpet\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"type\":\"scattercarpet\"}],\"scattergeo\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"type\":\"scattergeo\"}],\"scattergl\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"type\":\"scattergl\"}],\"scattermapbox\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"type\":\"scattermapbox\"}],\"scatterpolar\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"type\":\"scatterpolar\"}],\"scatterpolargl\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"type\":\"scatterpolargl\"}],\"scatterternary\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"type\":\"scatterternary\"}],\"surface\":[{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"},\"colorscale\":[[0.0,\"#440154\"],[0.1111111111111111,\"#482878\"],[0.2222222222222222,\"#3e4989\"],[0.3333333333333333,\"#31688e\"],[0.4444444444444444,\"#26828e\"],[0.5555555555555556,\"#1f9e89\"],[0.6666666666666666,\"#35b779\"],[0.7777777777777778,\"#6ece58\"],[0.8888888888888888,\"#b5de2b\"],[1.0,\"#fde725\"]],\"type\":\"surface\"}],\"table\":[{\"cells\":{\"fill\":{\"color\":\"rgb(237,237,237)\"},\"line\":{\"color\":\"white\"}},\"header\":{\"fill\":{\"color\":\"rgb(217,217,217)\"},\"line\":{\"color\":\"white\"}},\"type\":\"table\"}]},\"layout\":{\"annotationdefaults\":{\"arrowhead\":0,\"arrowwidth\":1},\"autotypenumbers\":\"strict\",\"coloraxis\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"colorscale\":{\"diverging\":[[0.0,\"rgb(103,0,31)\"],[0.1,\"rgb(178,24,43)\"],[0.2,\"rgb(214,96,77)\"],[0.3,\"rgb(244,165,130)\"],[0.4,\"rgb(253,219,199)\"],[0.5,\"rgb(247,247,247)\"],[0.6,\"rgb(209,229,240)\"],[0.7,\"rgb(146,197,222)\"],[0.8,\"rgb(67,147,195)\"],[0.9,\"rgb(33,102,172)\"],[1.0,\"rgb(5,48,97)\"]],\"sequential\":[[0.0,\"#440154\"],[0.1111111111111111,\"#482878\"],[0.2222222222222222,\"#3e4989\"],[0.3333333333333333,\"#31688e\"],[0.4444444444444444,\"#26828e\"],[0.5555555555555556,\"#1f9e89\"],[0.6666666666666666,\"#35b779\"],[0.7777777777777778,\"#6ece58\"],[0.8888888888888888,\"#b5de2b\"],[1.0,\"#fde725\"]],\"sequentialminus\":[[0.0,\"#440154\"],[0.1111111111111111,\"#482878\"],[0.2222222222222222,\"#3e4989\"],[0.3333333333333333,\"#31688e\"],[0.4444444444444444,\"#26828e\"],[0.5555555555555556,\"#1f9e89\"],[0.6666666666666666,\"#35b779\"],[0.7777777777777778,\"#6ece58\"],[0.8888888888888888,\"#b5de2b\"],[1.0,\"#fde725\"]]},\"colorway\":[\"#1F77B4\",\"#FF7F0E\",\"#2CA02C\",\"#D62728\",\"#9467BD\",\"#8C564B\",\"#E377C2\",\"#7F7F7F\",\"#BCBD22\",\"#17BECF\"],\"font\":{\"color\":\"rgb(36,36,36)\"},\"geo\":{\"bgcolor\":\"white\",\"lakecolor\":\"white\",\"landcolor\":\"white\",\"showlakes\":true,\"showland\":true,\"subunitcolor\":\"white\"},\"hoverlabel\":{\"align\":\"left\"},\"hovermode\":\"closest\",\"mapbox\":{\"style\":\"light\"},\"paper_bgcolor\":\"white\",\"plot_bgcolor\":\"white\",\"polar\":{\"angularaxis\":{\"gridcolor\":\"rgb(232,232,232)\",\"linecolor\":\"rgb(36,36,36)\",\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\"},\"bgcolor\":\"white\",\"radialaxis\":{\"gridcolor\":\"rgb(232,232,232)\",\"linecolor\":\"rgb(36,36,36)\",\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\"}},\"scene\":{\"xaxis\":{\"backgroundcolor\":\"white\",\"gridcolor\":\"rgb(232,232,232)\",\"gridwidth\":2,\"linecolor\":\"rgb(36,36,36)\",\"showbackground\":true,\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\",\"zeroline\":false,\"zerolinecolor\":\"rgb(36,36,36)\"},\"yaxis\":{\"backgroundcolor\":\"white\",\"gridcolor\":\"rgb(232,232,232)\",\"gridwidth\":2,\"linecolor\":\"rgb(36,36,36)\",\"showbackground\":true,\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\",\"zeroline\":false,\"zerolinecolor\":\"rgb(36,36,36)\"},\"zaxis\":{\"backgroundcolor\":\"white\",\"gridcolor\":\"rgb(232,232,232)\",\"gridwidth\":2,\"linecolor\":\"rgb(36,36,36)\",\"showbackground\":true,\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\",\"zeroline\":false,\"zerolinecolor\":\"rgb(36,36,36)\"}},\"shapedefaults\":{\"fillcolor\":\"black\",\"line\":{\"width\":0},\"opacity\":0.3},\"ternary\":{\"aaxis\":{\"gridcolor\":\"rgb(232,232,232)\",\"linecolor\":\"rgb(36,36,36)\",\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\"},\"baxis\":{\"gridcolor\":\"rgb(232,232,232)\",\"linecolor\":\"rgb(36,36,36)\",\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\"},\"bgcolor\":\"white\",\"caxis\":{\"gridcolor\":\"rgb(232,232,232)\",\"linecolor\":\"rgb(36,36,36)\",\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\"}},\"title\":{\"x\":0.05},\"xaxis\":{\"automargin\":true,\"gridcolor\":\"rgb(232,232,232)\",\"linecolor\":\"rgb(36,36,36)\",\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\",\"title\":{\"standoff\":15},\"zeroline\":false,\"zerolinecolor\":\"rgb(36,36,36)\"},\"yaxis\":{\"automargin\":true,\"gridcolor\":\"rgb(232,232,232)\",\"linecolor\":\"rgb(36,36,36)\",\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\",\"title\":{\"standoff\":15},\"zeroline\":false,\"zerolinecolor\":\"rgb(36,36,36)\"}}},\"title\":{\"text\":\"Cm vs Alpha\"},\"xaxis\":{\"gridcolor\":\"Gray\",\"gridwidth\":1,\"linecolor\":\"black\",\"linewidth\":2,\"mirror\":false,\"showgrid\":true,\"showline\":true,\"title\":{\"text\":\"Alpha [deg]\"},\"zeroline\":true,\"zerolinecolor\":\"Gray\",\"zerolinewidth\":1},\"yaxis\":{\"gridcolor\":\"Gray\",\"gridwidth\":0.5,\"linecolor\":\"black\",\"linewidth\":2,\"mirror\":false,\"showgrid\":true,\"showline\":true,\"title\":{\"text\":\"Cm\"},\"zeroline\":true,\"zerolinecolor\":\"Gray\",\"zerolinewidth\":1}},                        {\"responsive\": true}                    ).then(function(){\n",
       "                            \n",
       "var gd = document.getElementById('b6ac7958-344a-42ee-8e91-b2c74d708cac');\n",
       "var x = new MutationObserver(function (mutations, observer) {{\n",
       "        var display = window.getComputedStyle(gd).display;\n",
       "        if (!display || display === 'none') {{\n",
       "            console.log([gd, 'removed!']);\n",
       "            Plotly.purge(gd);\n",
       "            observer.disconnect();\n",
       "        }}\n",
       "}});\n",
       "\n",
       "// Listen for the removal of the full notebook cells\n",
       "var notebookContainer = gd.closest('#notebook-container');\n",
       "if (notebookContainer) {{\n",
       "    x.observe(notebookContainer, {childList: true});\n",
       "}}\n",
       "\n",
       "// Listen for the clearing of the current output cell\n",
       "var outputEl = gd.closest('.output');\n",
       "if (outputEl) {{\n",
       "    x.observe(outputEl, {childList: true});\n",
       "}}\n",
       "\n",
       "                        })                };                });            </script>        </div>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "layout = Layout(plot_bgcolor='rgba(0,0.5,0,0)')\n",
    "fig2 = go.Figure(layout=layout)\n",
    "fig2.add_trace(go.Scatter(x=df3['alpha'], y=df3['Cm'],\n",
    "                    mode='lines',\n",
    "                    name='Empirical curve-fit', line=dict(color=\"#0000ff\")))\n",
    "fig2.add_trace(go.Scatter(x=df4['alpha'], y=df4['Cm'],mode='lines', showlegend=False, marker=dict(color=\"#0000ff\")))\n",
    "fig2.add_trace(go.Scatter(x=df['alpha'], y=df['Cm'],\n",
    "                    mode='markers', name='CFD', line=dict(color=\"#0000ff\")))\n",
    "\n",
    "fig2.update_layout(\n",
    "title=\"Cm vs Alpha\",\n",
    "xaxis_title=\"Alpha [deg]\", \n",
    "yaxis_title=\"Cm\")\n",
    "fig2.update_xaxes(showline=True, linewidth=2, linecolor='black', mirror=False)\n",
    "fig2.update_yaxes(showline=True, linewidth=2, linecolor='black', mirror=False)\n",
    "fig2.update_xaxes(showgrid=True, gridwidth=1, gridcolor='Gray')\n",
    "fig2.update_yaxes(showgrid=True, gridwidth=0.5, gridcolor='Gray')\n",
    "fig2.update_xaxes(zeroline=True, zerolinewidth=1, zerolinecolor='Gray')\n",
    "fig2.update_yaxes(zeroline=True, zerolinewidth=1, zerolinecolor='Gray')\n",
    "fig2.show()\n",
    "\n"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 6,
   "id": "25585cf6",
   "metadata": {
    "hide_input": true,
    "scrolled": false,
    "slideshow": {
     "slide_type": "subslide"
    },
    "tags": [
     "hide-input"
    ]
   },
   "outputs": [
    {
     "data": {
      "application/vnd.plotly.v1+json": {
       "config": {
        "plotlyServerURL": "https://plot.ly"
       },
       "data": [
        {
         "line": {
          "color": "#0000ff"
         },
         "mode": "lines",
         "name": "Empirical curve-fit",
         "type": "scatter",
         "x": [
          -180,
          -180,
          -180,
          -180,
          -180,
          -180,
          -180,
          -179,
          -179,
          -179,
          -179,
          -179,
          -179,
          -179,
          -178,
          -178,
          -178,
          -178,
          -178,
          -178,
          -178,
          -177,
          -177,
          -177,
          -177,
          -177,
          -177,
          -177,
          -175,
          -175,
          -175,
          -175,
          -175,
          -175,
          -175,
          -170,
          -170,
          -170,
          -170,
          -170,
          -170,
          -170,
          -165,
          -165,
          -165,
          -165,
          -165,
          -165,
          -165,
          -160,
          -160,
          -160,
          -160,
          -160,
          -160,
          -160,
          -155,
          -155,
          -155,
          -155,
          -155,
          -155,
          -155,
          -150,
          -150,
          -150,
          -150,
          -150,
          -150,
          -150,
          -145,
          -145,
          -145,
          -145,
          -145,
          -145,
          -145,
          -140,
          -140,
          -140,
          -140,
          -140,
          -140,
          -140,
          -135,
          -135,
          -135,
          -135,
          -135,
          -135,
          -135,
          -130,
          -130,
          -130,
          -130,
          -130,
          -130,
          -130,
          -125,
          -125,
          -125,
          -125,
          -125,
          -125,
          -125,
          -120,
          -120,
          -120,
          -120,
          -120,
          -120,
          -120,
          -115,
          -115,
          -115,
          -115,
          -115,
          -115,
          -115,
          -110,
          -110,
          -110,
          -110,
          -110,
          -110,
          -110,
          -105,
          -105,
          -105,
          -105,
          -105,
          -105,
          -105,
          -100,
          -100,
          -100,
          -100,
          -100,
          -100,
          -100,
          -95,
          -95,
          -95,
          -95,
          -95,
          -95,
          -95,
          -90,
          -90,
          -90,
          -90,
          -90,
          -90,
          -90,
          -85,
          -85,
          -85,
          -85,
          -85,
          -85,
          -85,
          -80,
          -80,
          -80,
          -80,
          -80,
          -80,
          -80,
          -75,
          -75,
          -75,
          -75,
          -75,
          -75,
          -75,
          -70,
          -70,
          -70,
          -70,
          -70,
          -70,
          -70,
          -65,
          -65,
          -65,
          -65,
          -65,
          -65,
          -65,
          -60,
          -60,
          -60,
          -60,
          -60,
          -60,
          -60,
          -55,
          -55,
          -55,
          -55,
          -55,
          -55,
          -55,
          -50,
          -50,
          -50,
          -50,
          -50,
          -50,
          -50,
          -45,
          -45,
          -45,
          -45,
          -45,
          -45,
          -45,
          -40,
          -40,
          -40,
          -40,
          -40,
          -40,
          -40,
          -35,
          -35,
          -35,
          -35,
          -35,
          -35,
          -35,
          -30,
          -30,
          -30,
          -30,
          -30,
          -30,
          -30,
          -25,
          -25,
          -25,
          -25,
          -25,
          -25,
          -25,
          -20,
          -20,
          -20,
          -20,
          -20,
          -20,
          -20,
          -19,
          -19,
          -19,
          -19,
          -19,
          -19,
          -19,
          -18,
          -18,
          -18,
          -18,
          -18,
          -18,
          -18,
          -17,
          -17,
          -17,
          -17,
          -17,
          -17,
          -17,
          -16,
          -16,
          -16,
          -16,
          -16,
          -16,
          -16,
          -15,
          -15,
          -15,
          -15,
          -15,
          -15,
          -15,
          -14,
          -14,
          -14,
          -14,
          -14,
          -14,
          -14,
          -13,
          -13,
          -13,
          -13,
          -13,
          -13,
          -13,
          -12,
          -12,
          -12,
          -12,
          -12,
          -12,
          -12,
          -11,
          -11,
          -11,
          -11,
          -11,
          -11,
          -11,
          -10,
          -10,
          -10,
          -10,
          -10,
          -10,
          -10,
          -9,
          -9,
          -9,
          -9,
          -9,
          -9,
          -9,
          -8,
          -8,
          -8,
          -8,
          -8,
          -8,
          -8,
          -7,
          -7,
          -7,
          -7,
          -7,
          -7,
          -7
         ],
         "y": [
          0.08592102839619864,
          0.08592102839619864,
          0.08592102839619864,
          0.08592102839619864,
          0.08592102839619864,
          0.08592102839619864,
          0.08592102839619864,
          0.0880946101617337,
          0.0880946101617337,
          0.0880946101617337,
          0.0880946101617337,
          0.0880946101617337,
          0.0880946101617337,
          0.0880946101617337,
          0.09154368488137377,
          0.09154368488137377,
          0.09154368488137377,
          0.09154368488137377,
          0.09154368488137377,
          0.09154368488137377,
          0.09154368488137377,
          0.09626405038886232,
          0.09626405038886232,
          0.09626405038886232,
          0.09626405038886232,
          0.09626405038886232,
          0.09626405038886232,
          0.09626405038886232,
          0.1094941077491236,
          0.1094941077491236,
          0.1094941077491236,
          0.1094941077491236,
          0.1094941077491236,
          0.1094941077491236,
          0.1094941077491236,
          0.16422666470707104,
          0.16422666470707104,
          0.16422666470707104,
          0.16422666470707104,
          0.16422666470707104,
          0.16422666470707104,
          0.16422666470707104,
          0.24845567822288395,
          0.24845567822288395,
          0.24845567822288395,
          0.24845567822288395,
          0.24845567822288395,
          0.24845567822288395,
          0.24845567822288395,
          0.3596218923428216,
          0.3596218923428216,
          0.3596218923428216,
          0.3596218923428216,
          0.3596218923428216,
          0.3596218923428216,
          0.3596218923428216,
          0.49434757790366846,
          0.49434757790366846,
          0.49434757790366846,
          0.49434757790366846,
          0.49434757790366846,
          0.49434757790366846,
          0.49434757790366846,
          0.6485391631241451,
          0.6485391631241451,
          0.6485391631241451,
          0.6485391631241451,
          0.6485391631241451,
          0.6485391631241451,
          0.6485391631241451,
          0.817511614712033,
          0.817511614712033,
          0.817511614712033,
          0.817511614712033,
          0.817511614712033,
          0.817511614712033,
          0.817511614712033,
          0.9961307902300209,
          0.9961307902300209,
          0.9961307902300209,
          0.9961307902300209,
          0.9961307902300209,
          0.9961307902300209,
          0.9961307902300209,
          1.1789694364156589,
          1.1789694364156589,
          1.1789694364156589,
          1.1789694364156589,
          1.1789694364156589,
          1.1789694364156589,
          1.1789694364156589,
          1.3604720935254164,
          1.3604720935254164,
          1.3604720935254164,
          1.3604720935254164,
          1.3604720935254164,
          1.3604720935254164,
          1.3604720935254164,
          1.5351238951677877,
          1.5351238951677877,
          1.5351238951677877,
          1.5351238951677877,
          1.5351238951677877,
          1.5351238951677877,
          1.5351238951677877,
          1.6976181347279469,
          1.6976181347279469,
          1.6976181347279469,
          1.6976181347279469,
          1.6976181347279469,
          1.6976181347279469,
          1.6976181347279469,
          1.84301750696291,
          1.84301750696291,
          1.84301750696291,
          1.84301750696291,
          1.84301750696291,
          1.84301750696291,
          1.84301750696291,
          1.9669041255229502,
          1.9669041255229502,
          1.9669041255229502,
          1.9669041255229502,
          1.9669041255229502,
          1.9669041255229502,
          1.9669041255229502,
          2.0655137581927754,
          2.0655137581927754,
          2.0655137581927754,
          2.0655137581927754,
          2.0655137581927754,
          2.0655137581927754,
          2.0655137581927754,
          2.1358502011825946,
          2.1358502011825946,
          2.1358502011825946,
          2.1358502011825946,
          2.1358502011825946,
          2.1358502011825946,
          2.1358502011825946,
          2.175776317264119,
          2.175776317264119,
          2.175776317264119,
          2.175776317264119,
          2.175776317264119,
          2.175776317264119,
          2.175776317264119,
          2.1840789716038014,
          2.1840789716038014,
          2.1840789716038014,
          2.1840789716038014,
          2.1840789716038014,
          2.1840789716038014,
          2.1840789716038014,
          2.1605058922508764,
          2.1605058922508764,
          2.1605058922508764,
          2.1605058922508764,
          2.1605058922508764,
          2.1605058922508764,
          2.1605058922508764,
          2.1057733352929286,
          2.1057733352929286,
          2.1057733352929286,
          2.1057733352929286,
          2.1057733352929286,
          2.1057733352929286,
          2.1057733352929286,
          2.0215443217771156,
          2.0215443217771156,
          2.0215443217771156,
          2.0215443217771156,
          2.0215443217771156,
          2.0215443217771156,
          2.0215443217771156,
          1.9103781076571777,
          1.9103781076571777,
          1.9103781076571777,
          1.9103781076571777,
          1.9103781076571777,
          1.9103781076571777,
          1.9103781076571777,
          1.7756524220963308,
          1.7756524220963308,
          1.7756524220963308,
          1.7756524220963308,
          1.7756524220963308,
          1.7756524220963308,
          1.7756524220963308,
          1.6214608368758547,
          1.6214608368758547,
          1.6214608368758547,
          1.6214608368758547,
          1.6214608368758547,
          1.6214608368758547,
          1.6214608368758547,
          1.4524883852879666,
          1.4524883852879666,
          1.4524883852879666,
          1.4524883852879666,
          1.4524883852879666,
          1.4524883852879666,
          1.4524883852879666,
          1.2738692097699784,
          1.2738692097699784,
          1.2738692097699784,
          1.2738692097699784,
          1.2738692097699784,
          1.2738692097699784,
          1.2738692097699784,
          1.0910305635843403,
          1.0910305635843403,
          1.0910305635843403,
          1.0910305635843403,
          1.0910305635843403,
          1.0910305635843403,
          1.0910305635843403,
          0.9095279064745835,
          0.9095279064745835,
          0.9095279064745835,
          0.9095279064745835,
          0.9095279064745835,
          0.9095279064745835,
          0.9095279064745835,
          0.7348761048322121,
          0.7348761048322121,
          0.7348761048322121,
          0.7348761048322121,
          0.7348761048322121,
          0.7348761048322121,
          0.7348761048322121,
          0.5723818652720535,
          0.5723818652720535,
          0.5723818652720535,
          0.5723818652720535,
          0.5723818652720535,
          0.5723818652720535,
          0.5723818652720535,
          0.42698249303709035,
          0.42698249303709035,
          0.42698249303709035,
          0.42698249303709035,
          0.42698249303709035,
          0.42698249303709035,
          0.42698249303709035,
          0.3030958744770498,
          0.3030958744770498,
          0.3030958744770498,
          0.3030958744770498,
          0.3030958744770498,
          0.3030958744770498,
          0.3030958744770498,
          0.28124420090062097,
          0.28124420090062097,
          0.28124420090062097,
          0.28124420090062097,
          0.28124420090062097,
          0.28124420090062097,
          0.28124420090062097,
          0.26043269725439555,
          0.26043269725439555,
          0.26043269725439555,
          0.26043269725439555,
          0.26043269725439555,
          0.26043269725439555,
          0.26043269725439555,
          0.2406867191498,
          0.2406867191498,
          0.2406867191498,
          0.2406867191498,
          0.2406867191498,
          0.2406867191498,
          0.2406867191498,
          0.22203032401952005,
          0.22203032401952005,
          0.22203032401952005,
          0.22203032401952005,
          0.22203032401952005,
          0.22203032401952005,
          0.22203032401952005,
          0.20448624180722452,
          0.20448624180722452,
          0.20448624180722452,
          0.20448624180722452,
          0.20448624180722452,
          0.20448624180722452,
          0.20448624180722452,
          0.18807584727463045,
          0.18807584727463045,
          0.18807584727463045,
          0.18807584727463045,
          0.18807584727463045,
          0.18807584727463045,
          0.18807584727463045,
          0.17281913395964832,
          0.17281913395964832,
          0.17281913395964832,
          0.17281913395964832,
          0.17281913395964832,
          0.17281913395964832,
          0.17281913395964832,
          0.15873468981733607,
          0.15873468981733607,
          0.15873468981733607,
          0.15873468981733607,
          0.15873468981733607,
          0.15873468981733607,
          0.15873468981733607,
          0.14583967457333846,
          0.14583967457333846,
          0.14583967457333846,
          0.14583967457333846,
          0.14583967457333846,
          0.14583967457333846,
          0.14583967457333846,
          0.13414979881740563,
          0.13414979881740563,
          0.13414979881740563,
          0.13414979881740563,
          0.13414979881740563,
          0.13414979881740563,
          0.13414979881740563,
          0.12367930486245893,
          0.12367930486245893,
          0.12367930486245893,
          0.12367930486245893,
          0.12367930486245893,
          0.12367930486245893,
          0.12367930486245893,
          0.11444094939252647,
          0.11444094939252647,
          0.11444094939252647,
          0.11444094939252647,
          0.11444094939252647,
          0.11444094939252647,
          0.11444094939252647,
          0.10644598792068871,
          0.10644598792068871,
          0.10644598792068871,
          0.10644598792068871,
          0.10644598792068871,
          0.10644598792068871,
          0.10644598792068871
         ]
        },
        {
         "marker": {
          "color": "#0000ff"
         },
         "mode": "lines",
         "showlegend": false,
         "type": "scatter",
         "x": [
          18,
          18,
          18,
          18,
          18,
          18,
          18,
          19,
          19,
          19,
          19,
          19,
          19,
          19,
          20,
          20,
          20,
          20,
          20,
          20,
          20,
          25,
          25,
          25,
          25,
          25,
          25,
          25,
          30,
          30,
          30,
          30,
          30,
          30,
          30,
          35,
          35,
          35,
          35,
          35,
          35,
          35,
          40,
          40,
          40,
          40,
          40,
          40,
          40,
          45,
          45,
          45,
          45,
          45,
          45,
          45,
          50,
          50,
          50,
          50,
          50,
          50,
          50,
          55,
          55,
          55,
          55,
          55,
          55,
          55,
          60,
          60,
          60,
          60,
          60,
          60,
          60,
          65,
          65,
          65,
          65,
          65,
          65,
          65,
          70,
          70,
          70,
          70,
          70,
          70,
          70,
          75,
          75,
          75,
          75,
          75,
          75,
          75,
          80,
          80,
          80,
          80,
          80,
          80,
          80,
          85,
          85,
          85,
          85,
          85,
          85,
          85,
          90,
          90,
          90,
          90,
          90,
          90,
          90,
          95,
          95,
          95,
          95,
          95,
          95,
          95,
          100,
          100,
          100,
          100,
          100,
          100,
          100,
          105,
          105,
          105,
          105,
          105,
          105,
          105,
          110,
          110,
          110,
          110,
          110,
          110,
          110,
          115,
          115,
          115,
          115,
          115,
          115,
          115,
          120,
          120,
          120,
          120,
          120,
          120,
          120,
          125,
          125,
          125,
          125,
          125,
          125,
          125,
          130,
          130,
          130,
          130,
          130,
          130,
          130,
          135,
          135,
          135,
          135,
          135,
          135,
          135,
          140,
          140,
          140,
          140,
          140,
          140,
          140,
          145,
          145,
          145,
          145,
          145,
          145,
          145,
          150,
          150,
          150,
          150,
          150,
          150,
          150,
          155,
          155,
          155,
          155,
          155,
          155,
          155,
          160,
          160,
          160,
          160,
          160,
          160,
          160,
          165,
          165,
          165,
          165,
          165,
          165,
          165,
          170,
          170,
          170,
          170,
          170,
          170,
          170,
          175,
          175,
          175,
          175,
          175,
          175,
          175,
          177,
          177,
          177,
          177,
          177,
          177,
          177,
          178,
          178,
          178,
          178,
          178,
          178,
          178,
          179,
          179,
          179,
          179,
          179,
          179,
          179,
          180,
          180,
          180,
          180,
          180,
          180,
          180
         ],
         "y": [
          0.31212186980786816,
          0.31212186980786816,
          0.31212186980786816,
          0.31212186980786816,
          0.31212186980786816,
          0.31212186980786816,
          0.31212186980786816,
          0.33538477708642633,
          0.33538477708642633,
          0.33538477708642633,
          0.33538477708642633,
          0.33538477708642633,
          0.33538477708642633,
          0.33538477708642633,
          0.35962189234282194,
          0.35962189234282194,
          0.35962189234282194,
          0.35962189234282194,
          0.35962189234282194,
          0.35962189234282194,
          0.35962189234282194,
          0.4943475779036689,
          0.4943475779036689,
          0.4943475779036689,
          0.4943475779036689,
          0.4943475779036689,
          0.4943475779036689,
          0.4943475779036689,
          0.6485391631241451,
          0.6485391631241451,
          0.6485391631241451,
          0.6485391631241451,
          0.6485391631241451,
          0.6485391631241451,
          0.6485391631241451,
          0.8175116147120334,
          0.8175116147120334,
          0.8175116147120334,
          0.8175116147120334,
          0.8175116147120334,
          0.8175116147120334,
          0.8175116147120334,
          0.9961307902300214,
          0.9961307902300214,
          0.9961307902300214,
          0.9961307902300214,
          0.9961307902300214,
          0.9961307902300214,
          0.9961307902300214,
          1.1789694364156595,
          1.1789694364156595,
          1.1789694364156595,
          1.1789694364156595,
          1.1789694364156595,
          1.1789694364156595,
          1.1789694364156595,
          1.3604720935254164,
          1.3604720935254164,
          1.3604720935254164,
          1.3604720935254164,
          1.3604720935254164,
          1.3604720935254164,
          1.3604720935254164,
          1.535123895167788,
          1.535123895167788,
          1.535123895167788,
          1.535123895167788,
          1.535123895167788,
          1.535123895167788,
          1.535123895167788,
          1.6976181347279466,
          1.6976181347279466,
          1.6976181347279466,
          1.6976181347279466,
          1.6976181347279466,
          1.6976181347279466,
          1.6976181347279466,
          1.8430175069629096,
          1.8430175069629096,
          1.8430175069629096,
          1.8430175069629096,
          1.8430175069629096,
          1.8430175069629096,
          1.8430175069629096,
          1.9669041255229502,
          1.9669041255229502,
          1.9669041255229502,
          1.9669041255229502,
          1.9669041255229502,
          1.9669041255229502,
          1.9669041255229502,
          2.0655137581927754,
          2.0655137581927754,
          2.0655137581927754,
          2.0655137581927754,
          2.0655137581927754,
          2.0655137581927754,
          2.0655137581927754,
          2.1358502011825946,
          2.1358502011825946,
          2.1358502011825946,
          2.1358502011825946,
          2.1358502011825946,
          2.1358502011825946,
          2.1358502011825946,
          2.175776317264119,
          2.175776317264119,
          2.175776317264119,
          2.175776317264119,
          2.175776317264119,
          2.175776317264119,
          2.175776317264119,
          2.1840789716038014,
          2.1840789716038014,
          2.1840789716038014,
          2.1840789716038014,
          2.1840789716038014,
          2.1840789716038014,
          2.1840789716038014,
          2.1605058922508764,
          2.1605058922508764,
          2.1605058922508764,
          2.1605058922508764,
          2.1605058922508764,
          2.1605058922508764,
          2.1605058922508764,
          2.1057733352929286,
          2.1057733352929286,
          2.1057733352929286,
          2.1057733352929286,
          2.1057733352929286,
          2.1057733352929286,
          2.1057733352929286,
          2.0215443217771156,
          2.0215443217771156,
          2.0215443217771156,
          2.0215443217771156,
          2.0215443217771156,
          2.0215443217771156,
          2.0215443217771156,
          1.910378107657178,
          1.910378107657178,
          1.910378107657178,
          1.910378107657178,
          1.910378107657178,
          1.910378107657178,
          1.910378107657178,
          1.7756524220963312,
          1.7756524220963312,
          1.7756524220963312,
          1.7756524220963312,
          1.7756524220963312,
          1.7756524220963312,
          1.7756524220963312,
          1.6214608368758552,
          1.6214608368758552,
          1.6214608368758552,
          1.6214608368758552,
          1.6214608368758552,
          1.6214608368758552,
          1.6214608368758552,
          1.4524883852879664,
          1.4524883852879664,
          1.4524883852879664,
          1.4524883852879664,
          1.4524883852879664,
          1.4524883852879664,
          1.4524883852879664,
          1.2738692097699795,
          1.2738692097699795,
          1.2738692097699795,
          1.2738692097699795,
          1.2738692097699795,
          1.2738692097699795,
          1.2738692097699795,
          1.0910305635843405,
          1.0910305635843405,
          1.0910305635843405,
          1.0910305635843405,
          1.0910305635843405,
          1.0910305635843405,
          1.0910305635843405,
          0.909527906474584,
          0.909527906474584,
          0.909527906474584,
          0.909527906474584,
          0.909527906474584,
          0.909527906474584,
          0.909527906474584,
          0.7348761048322127,
          0.7348761048322127,
          0.7348761048322127,
          0.7348761048322127,
          0.7348761048322127,
          0.7348761048322127,
          0.7348761048322127,
          0.5723818652720541,
          0.5723818652720541,
          0.5723818652720541,
          0.5723818652720541,
          0.5723818652720541,
          0.5723818652720541,
          0.5723818652720541,
          0.42698249303709057,
          0.42698249303709057,
          0.42698249303709057,
          0.42698249303709057,
          0.42698249303709057,
          0.42698249303709057,
          0.42698249303709057,
          0.3030958744770499,
          0.3030958744770499,
          0.3030958744770499,
          0.3030958744770499,
          0.3030958744770499,
          0.3030958744770499,
          0.3030958744770499,
          0.20448624180722474,
          0.20448624180722474,
          0.20448624180722474,
          0.20448624180722474,
          0.20448624180722474,
          0.20448624180722474,
          0.20448624180722474,
          0.13414979881740585,
          0.13414979881740585,
          0.13414979881740585,
          0.13414979881740585,
          0.13414979881740585,
          0.13414979881740585,
          0.13414979881740585,
          0.09422368273588133,
          0.09422368273588133,
          0.09422368273588133,
          0.09422368273588133,
          0.09422368273588133,
          0.09422368273588133,
          0.09422368273588133,
          0.08707193515031486,
          0.08707193515031486,
          0.08707193515031486,
          0.08707193515031486,
          0.08707193515031486,
          0.08707193515031486,
          0.08707193515031486,
          0.08540937920762781,
          0.08540937920762781,
          0.08540937920762781,
          0.08540937920762781,
          0.08540937920762781,
          0.08540937920762781,
          0.08540937920762781,
          0.08502558775933555,
          0.08502558775933555,
          0.08502558775933555,
          0.08502558775933555,
          0.08502558775933555,
          0.08502558775933555,
          0.08502558775933555,
          0.08592102839619864,
          0.08592102839619864,
          0.08592102839619864,
          0.08592102839619864,
          0.08592102839619864,
          0.08592102839619864,
          0.08592102839619864
         ]
        },
        {
         "line": {
          "color": "#0000ff"
         },
         "mode": "markers",
         "name": "CFD",
         "type": "scatter",
         "x": [
          -6,
          -5.76767677,
          -5.53535354,
          -5.3030303,
          -5.07070707,
          -4.83838384,
          -4.60606061,
          -4.37373737,
          -4.14141414,
          -3.90909091,
          -3.67676768,
          -3.44444444,
          -3.21212121,
          -2.97979798,
          -2.74747475,
          -2.51515152,
          -2.28282828,
          -2.05050505,
          -1.81818182,
          -1.58585859,
          -1.35353535,
          -1.12121212,
          -0.88888889,
          -0.65656566,
          -0.42424242,
          -0.19191919,
          0.04040404,
          0.27272727,
          0.50505051,
          0.73737374,
          0.96969697,
          1.2020202,
          1.43434343,
          1.66666667,
          1.8989899,
          2.13131313,
          2.36363636,
          2.5959596,
          2.82828283,
          3.06060606,
          3.29292929,
          3.52525253,
          3.75757576,
          3.98989899,
          4.22222222,
          4.45454545,
          4.68686869,
          4.91919192,
          5.15151515,
          5.38383838,
          5.61616162,
          5.84848485,
          6.08080808,
          6.31313131,
          6.54545455,
          6.77777778,
          7.01010101,
          7.24242424,
          7.47474747,
          7.70707071,
          7.93939394,
          8.17171717,
          8.4040404,
          8.63636364,
          8.86868687,
          9.1010101,
          9.33333333,
          9.56565657,
          9.7979798,
          10.03030303,
          10.26262626,
          10.49494949,
          10.72727273,
          10.95959596,
          11.19191919,
          11.42424242,
          11.65656566,
          11.88888889,
          12.12121212,
          12.35353535,
          12.58585859,
          12.81818182,
          13.05050505,
          13.28282828,
          13.51515152,
          13.74747475,
          13.97979798,
          14.21212121,
          14.44444444,
          14.67676768,
          14.90909091,
          15.14141414,
          15.37373737,
          15.60606061,
          15.83838384,
          16.07070707,
          16.3030303,
          16.53535354,
          16.76767677,
          17
         ],
         "y": [
          0.01139713,
          0.01120696,
          0.01103136,
          0.01086916,
          0.01071921,
          0.01058036,
          0.01045193,
          0.01033349,
          0.01022457,
          0.01012469,
          0.01003345,
          0.00995053,
          0.00987563,
          0.00980841,
          0.0097486,
          0.00969619,
          0.0096512,
          0.00961352,
          0.00958301,
          0.00955951,
          0.00954287,
          0.00953296,
          0.00952963,
          0.00953279,
          0.00954245,
          0.00955859,
          0.00958122,
          0.00961032,
          0.00964586,
          0.00968777,
          0.00973603,
          0.00979059,
          0.00985151,
          0.00991883,
          0.00999264,
          0.010073,
          0.01015997,
          0.01025362,
          0.01035401,
          0.0104612,
          0.01057531,
          0.01069648,
          0.01082489,
          0.01096071,
          0.0111041,
          0.01125509,
          0.01141368,
          0.01157988,
          0.01175374,
          0.01193586,
          0.01212721,
          0.01232875,
          0.01254143,
          0.01276405,
          0.01299389,
          0.01323319,
          0.01348299,
          0.0137435,
          0.014016,
          0.01429973,
          0.01459559,
          0.014907,
          0.01523226,
          0.01556999,
          0.01592241,
          0.01629189,
          0.01667924,
          0.01708373,
          0.01750572,
          0.01794838,
          0.01841474,
          0.01890593,
          0.0194322,
          0.02001885,
          0.02070299,
          0.02153367,
          0.02256262,
          0.02381718,
          0.02530925,
          0.02705054,
          0.029061,
          0.03137037,
          0.03397616,
          0.03687954,
          0.04013382,
          0.04388771,
          0.04805455,
          0.05247681,
          0.05756547,
          0.06330455,
          0.0695248,
          0.07648436,
          0.08390437,
          0.0916152,
          0.10006728,
          0.10883361,
          0.11752242,
          0.12613119,
          0.13453565,
          0.14257238
         ]
        }
       ],
       "layout": {
        "plot_bgcolor": "rgba(0,0.5,0,0)",
        "template": {
         "data": {
          "bar": [
           {
            "error_x": {
             "color": "rgb(36,36,36)"
            },
            "error_y": {
             "color": "rgb(36,36,36)"
            },
            "marker": {
             "line": {
              "color": "white",
              "width": 0.5
             },
             "pattern": {
              "fillmode": "overlay",
              "size": 10,
              "solidity": 0.2
             }
            },
            "type": "bar"
           }
          ],
          "barpolar": [
           {
            "marker": {
             "line": {
              "color": "white",
              "width": 0.5
             },
             "pattern": {
              "fillmode": "overlay",
              "size": 10,
              "solidity": 0.2
             }
            },
            "type": "barpolar"
           }
          ],
          "carpet": [
           {
            "aaxis": {
             "endlinecolor": "rgb(36,36,36)",
             "gridcolor": "white",
             "linecolor": "white",
             "minorgridcolor": "white",
             "startlinecolor": "rgb(36,36,36)"
            },
            "baxis": {
             "endlinecolor": "rgb(36,36,36)",
             "gridcolor": "white",
             "linecolor": "white",
             "minorgridcolor": "white",
             "startlinecolor": "rgb(36,36,36)"
            },
            "type": "carpet"
           }
          ],
          "choropleth": [
           {
            "colorbar": {
             "outlinewidth": 1,
             "tickcolor": "rgb(36,36,36)",
             "ticks": "outside"
            },
            "type": "choropleth"
           }
          ],
          "contour": [
           {
            "colorbar": {
             "outlinewidth": 1,
             "tickcolor": "rgb(36,36,36)",
             "ticks": "outside"
            },
            "colorscale": [
             [
              0,
              "#440154"
             ],
             [
              0.1111111111111111,
              "#482878"
             ],
             [
              0.2222222222222222,
              "#3e4989"
             ],
             [
              0.3333333333333333,
              "#31688e"
             ],
             [
              0.4444444444444444,
              "#26828e"
             ],
             [
              0.5555555555555556,
              "#1f9e89"
             ],
             [
              0.6666666666666666,
              "#35b779"
             ],
             [
              0.7777777777777778,
              "#6ece58"
             ],
             [
              0.8888888888888888,
              "#b5de2b"
             ],
             [
              1,
              "#fde725"
             ]
            ],
            "type": "contour"
           }
          ],
          "contourcarpet": [
           {
            "colorbar": {
             "outlinewidth": 1,
             "tickcolor": "rgb(36,36,36)",
             "ticks": "outside"
            },
            "type": "contourcarpet"
           }
          ],
          "heatmap": [
           {
            "colorbar": {
             "outlinewidth": 1,
             "tickcolor": "rgb(36,36,36)",
             "ticks": "outside"
            },
            "colorscale": [
             [
              0,
              "#440154"
             ],
             [
              0.1111111111111111,
              "#482878"
             ],
             [
              0.2222222222222222,
              "#3e4989"
             ],
             [
              0.3333333333333333,
              "#31688e"
             ],
             [
              0.4444444444444444,
              "#26828e"
             ],
             [
              0.5555555555555556,
              "#1f9e89"
             ],
             [
              0.6666666666666666,
              "#35b779"
             ],
             [
              0.7777777777777778,
              "#6ece58"
             ],
             [
              0.8888888888888888,
              "#b5de2b"
             ],
             [
              1,
              "#fde725"
             ]
            ],
            "type": "heatmap"
           }
          ],
          "heatmapgl": [
           {
            "colorbar": {
             "outlinewidth": 1,
             "tickcolor": "rgb(36,36,36)",
             "ticks": "outside"
            },
            "colorscale": [
             [
              0,
              "#440154"
             ],
             [
              0.1111111111111111,
              "#482878"
             ],
             [
              0.2222222222222222,
              "#3e4989"
             ],
             [
              0.3333333333333333,
              "#31688e"
             ],
             [
              0.4444444444444444,
              "#26828e"
             ],
             [
              0.5555555555555556,
              "#1f9e89"
             ],
             [
              0.6666666666666666,
              "#35b779"
             ],
             [
              0.7777777777777778,
              "#6ece58"
             ],
             [
              0.8888888888888888,
              "#b5de2b"
             ],
             [
              1,
              "#fde725"
             ]
            ],
            "type": "heatmapgl"
           }
          ],
          "histogram": [
           {
            "marker": {
             "line": {
              "color": "white",
              "width": 0.6
             }
            },
            "type": "histogram"
           }
          ],
          "histogram2d": [
           {
            "colorbar": {
             "outlinewidth": 1,
             "tickcolor": "rgb(36,36,36)",
             "ticks": "outside"
            },
            "colorscale": [
             [
              0,
              "#440154"
             ],
             [
              0.1111111111111111,
              "#482878"
             ],
             [
              0.2222222222222222,
              "#3e4989"
             ],
             [
              0.3333333333333333,
              "#31688e"
             ],
             [
              0.4444444444444444,
              "#26828e"
             ],
             [
              0.5555555555555556,
              "#1f9e89"
             ],
             [
              0.6666666666666666,
              "#35b779"
             ],
             [
              0.7777777777777778,
              "#6ece58"
             ],
             [
              0.8888888888888888,
              "#b5de2b"
             ],
             [
              1,
              "#fde725"
             ]
            ],
            "type": "histogram2d"
           }
          ],
          "histogram2dcontour": [
           {
            "colorbar": {
             "outlinewidth": 1,
             "tickcolor": "rgb(36,36,36)",
             "ticks": "outside"
            },
            "colorscale": [
             [
              0,
              "#440154"
             ],
             [
              0.1111111111111111,
              "#482878"
             ],
             [
              0.2222222222222222,
              "#3e4989"
             ],
             [
              0.3333333333333333,
              "#31688e"
             ],
             [
              0.4444444444444444,
              "#26828e"
             ],
             [
              0.5555555555555556,
              "#1f9e89"
             ],
             [
              0.6666666666666666,
              "#35b779"
             ],
             [
              0.7777777777777778,
              "#6ece58"
             ],
             [
              0.8888888888888888,
              "#b5de2b"
             ],
             [
              1,
              "#fde725"
             ]
            ],
            "type": "histogram2dcontour"
           }
          ],
          "mesh3d": [
           {
            "colorbar": {
             "outlinewidth": 1,
             "tickcolor": "rgb(36,36,36)",
             "ticks": "outside"
            },
            "type": "mesh3d"
           }
          ],
          "parcoords": [
           {
            "line": {
             "colorbar": {
              "outlinewidth": 1,
              "tickcolor": "rgb(36,36,36)",
              "ticks": "outside"
             }
            },
            "type": "parcoords"
           }
          ],
          "pie": [
           {
            "automargin": true,
            "type": "pie"
           }
          ],
          "scatter": [
           {
            "marker": {
             "colorbar": {
              "outlinewidth": 1,
              "tickcolor": "rgb(36,36,36)",
              "ticks": "outside"
             }
            },
            "type": "scatter"
           }
          ],
          "scatter3d": [
           {
            "line": {
             "colorbar": {
              "outlinewidth": 1,
              "tickcolor": "rgb(36,36,36)",
              "ticks": "outside"
             }
            },
            "marker": {
             "colorbar": {
              "outlinewidth": 1,
              "tickcolor": "rgb(36,36,36)",
              "ticks": "outside"
             }
            },
            "type": "scatter3d"
           }
          ],
          "scattercarpet": [
           {
            "marker": {
             "colorbar": {
              "outlinewidth": 1,
              "tickcolor": "rgb(36,36,36)",
              "ticks": "outside"
             }
            },
            "type": "scattercarpet"
           }
          ],
          "scattergeo": [
           {
            "marker": {
             "colorbar": {
              "outlinewidth": 1,
              "tickcolor": "rgb(36,36,36)",
              "ticks": "outside"
             }
            },
            "type": "scattergeo"
           }
          ],
          "scattergl": [
           {
            "marker": {
             "colorbar": {
              "outlinewidth": 1,
              "tickcolor": "rgb(36,36,36)",
              "ticks": "outside"
             }
            },
            "type": "scattergl"
           }
          ],
          "scattermapbox": [
           {
            "marker": {
             "colorbar": {
              "outlinewidth": 1,
              "tickcolor": "rgb(36,36,36)",
              "ticks": "outside"
             }
            },
            "type": "scattermapbox"
           }
          ],
          "scatterpolar": [
           {
            "marker": {
             "colorbar": {
              "outlinewidth": 1,
              "tickcolor": "rgb(36,36,36)",
              "ticks": "outside"
             }
            },
            "type": "scatterpolar"
           }
          ],
          "scatterpolargl": [
           {
            "marker": {
             "colorbar": {
              "outlinewidth": 1,
              "tickcolor": "rgb(36,36,36)",
              "ticks": "outside"
             }
            },
            "type": "scatterpolargl"
           }
          ],
          "scatterternary": [
           {
            "marker": {
             "colorbar": {
              "outlinewidth": 1,
              "tickcolor": "rgb(36,36,36)",
              "ticks": "outside"
             }
            },
            "type": "scatterternary"
           }
          ],
          "surface": [
           {
            "colorbar": {
             "outlinewidth": 1,
             "tickcolor": "rgb(36,36,36)",
             "ticks": "outside"
            },
            "colorscale": [
             [
              0,
              "#440154"
             ],
             [
              0.1111111111111111,
              "#482878"
             ],
             [
              0.2222222222222222,
              "#3e4989"
             ],
             [
              0.3333333333333333,
              "#31688e"
             ],
             [
              0.4444444444444444,
              "#26828e"
             ],
             [
              0.5555555555555556,
              "#1f9e89"
             ],
             [
              0.6666666666666666,
              "#35b779"
             ],
             [
              0.7777777777777778,
              "#6ece58"
             ],
             [
              0.8888888888888888,
              "#b5de2b"
             ],
             [
              1,
              "#fde725"
             ]
            ],
            "type": "surface"
           }
          ],
          "table": [
           {
            "cells": {
             "fill": {
              "color": "rgb(237,237,237)"
             },
             "line": {
              "color": "white"
             }
            },
            "header": {
             "fill": {
              "color": "rgb(217,217,217)"
             },
             "line": {
              "color": "white"
             }
            },
            "type": "table"
           }
          ]
         },
         "layout": {
          "annotationdefaults": {
           "arrowhead": 0,
           "arrowwidth": 1
          },
          "autotypenumbers": "strict",
          "coloraxis": {
           "colorbar": {
            "outlinewidth": 1,
            "tickcolor": "rgb(36,36,36)",
            "ticks": "outside"
           }
          },
          "colorscale": {
           "diverging": [
            [
             0,
             "rgb(103,0,31)"
            ],
            [
             0.1,
             "rgb(178,24,43)"
            ],
            [
             0.2,
             "rgb(214,96,77)"
            ],
            [
             0.3,
             "rgb(244,165,130)"
            ],
            [
             0.4,
             "rgb(253,219,199)"
            ],
            [
             0.5,
             "rgb(247,247,247)"
            ],
            [
             0.6,
             "rgb(209,229,240)"
            ],
            [
             0.7,
             "rgb(146,197,222)"
            ],
            [
             0.8,
             "rgb(67,147,195)"
            ],
            [
             0.9,
             "rgb(33,102,172)"
            ],
            [
             1,
             "rgb(5,48,97)"
            ]
           ],
           "sequential": [
            [
             0,
             "#440154"
            ],
            [
             0.1111111111111111,
             "#482878"
            ],
            [
             0.2222222222222222,
             "#3e4989"
            ],
            [
             0.3333333333333333,
             "#31688e"
            ],
            [
             0.4444444444444444,
             "#26828e"
            ],
            [
             0.5555555555555556,
             "#1f9e89"
            ],
            [
             0.6666666666666666,
             "#35b779"
            ],
            [
             0.7777777777777778,
             "#6ece58"
            ],
            [
             0.8888888888888888,
             "#b5de2b"
            ],
            [
             1,
             "#fde725"
            ]
           ],
           "sequentialminus": [
            [
             0,
             "#440154"
            ],
            [
             0.1111111111111111,
             "#482878"
            ],
            [
             0.2222222222222222,
             "#3e4989"
            ],
            [
             0.3333333333333333,
             "#31688e"
            ],
            [
             0.4444444444444444,
             "#26828e"
            ],
            [
             0.5555555555555556,
             "#1f9e89"
            ],
            [
             0.6666666666666666,
             "#35b779"
            ],
            [
             0.7777777777777778,
             "#6ece58"
            ],
            [
             0.8888888888888888,
             "#b5de2b"
            ],
            [
             1,
             "#fde725"
            ]
           ]
          },
          "colorway": [
           "#1F77B4",
           "#FF7F0E",
           "#2CA02C",
           "#D62728",
           "#9467BD",
           "#8C564B",
           "#E377C2",
           "#7F7F7F",
           "#BCBD22",
           "#17BECF"
          ],
          "font": {
           "color": "rgb(36,36,36)"
          },
          "geo": {
           "bgcolor": "white",
           "lakecolor": "white",
           "landcolor": "white",
           "showlakes": true,
           "showland": true,
           "subunitcolor": "white"
          },
          "hoverlabel": {
           "align": "left"
          },
          "hovermode": "closest",
          "mapbox": {
           "style": "light"
          },
          "paper_bgcolor": "white",
          "plot_bgcolor": "white",
          "polar": {
           "angularaxis": {
            "gridcolor": "rgb(232,232,232)",
            "linecolor": "rgb(36,36,36)",
            "showgrid": false,
            "showline": true,
            "ticks": "outside"
           },
           "bgcolor": "white",
           "radialaxis": {
            "gridcolor": "rgb(232,232,232)",
            "linecolor": "rgb(36,36,36)",
            "showgrid": false,
            "showline": true,
            "ticks": "outside"
           }
          },
          "scene": {
           "xaxis": {
            "backgroundcolor": "white",
            "gridcolor": "rgb(232,232,232)",
            "gridwidth": 2,
            "linecolor": "rgb(36,36,36)",
            "showbackground": true,
            "showgrid": false,
            "showline": true,
            "ticks": "outside",
            "zeroline": false,
            "zerolinecolor": "rgb(36,36,36)"
           },
           "yaxis": {
            "backgroundcolor": "white",
            "gridcolor": "rgb(232,232,232)",
            "gridwidth": 2,
            "linecolor": "rgb(36,36,36)",
            "showbackground": true,
            "showgrid": false,
            "showline": true,
            "ticks": "outside",
            "zeroline": false,
            "zerolinecolor": "rgb(36,36,36)"
           },
           "zaxis": {
            "backgroundcolor": "white",
            "gridcolor": "rgb(232,232,232)",
            "gridwidth": 2,
            "linecolor": "rgb(36,36,36)",
            "showbackground": true,
            "showgrid": false,
            "showline": true,
            "ticks": "outside",
            "zeroline": false,
            "zerolinecolor": "rgb(36,36,36)"
           }
          },
          "shapedefaults": {
           "fillcolor": "black",
           "line": {
            "width": 0
           },
           "opacity": 0.3
          },
          "ternary": {
           "aaxis": {
            "gridcolor": "rgb(232,232,232)",
            "linecolor": "rgb(36,36,36)",
            "showgrid": false,
            "showline": true,
            "ticks": "outside"
           },
           "baxis": {
            "gridcolor": "rgb(232,232,232)",
            "linecolor": "rgb(36,36,36)",
            "showgrid": false,
            "showline": true,
            "ticks": "outside"
           },
           "bgcolor": "white",
           "caxis": {
            "gridcolor": "rgb(232,232,232)",
            "linecolor": "rgb(36,36,36)",
            "showgrid": false,
            "showline": true,
            "ticks": "outside"
           }
          },
          "title": {
           "x": 0.05
          },
          "xaxis": {
           "automargin": true,
           "gridcolor": "rgb(232,232,232)",
           "linecolor": "rgb(36,36,36)",
           "showgrid": false,
           "showline": true,
           "ticks": "outside",
           "title": {
            "standoff": 15
           },
           "zeroline": false,
           "zerolinecolor": "rgb(36,36,36)"
          },
          "yaxis": {
           "automargin": true,
           "gridcolor": "rgb(232,232,232)",
           "linecolor": "rgb(36,36,36)",
           "showgrid": false,
           "showline": true,
           "ticks": "outside",
           "title": {
            "standoff": 15
           },
           "zeroline": false,
           "zerolinecolor": "rgb(36,36,36)"
          }
         }
        },
        "title": {
         "text": "Cd vs Alpha"
        },
        "xaxis": {
         "gridcolor": "Gray",
         "gridwidth": 1,
         "linecolor": "black",
         "linewidth": 2,
         "mirror": false,
         "showgrid": true,
         "showline": true,
         "title": {
          "text": "Alpha [deg]"
         },
         "zeroline": true,
         "zerolinecolor": "Gray",
         "zerolinewidth": 1
        },
        "yaxis": {
         "gridcolor": "Gray",
         "gridwidth": 0.5,
         "linecolor": "black",
         "linewidth": 2,
         "mirror": false,
         "showgrid": true,
         "showline": true,
         "title": {
          "text": "Cd"
         },
         "zeroline": true,
         "zerolinecolor": "Gray",
         "zerolinewidth": 1
        }
       }
      },
      "text/html": [
       "<div>                            <div id=\"d724a7e0-633e-4a3d-a6cc-548d8459db61\" class=\"plotly-graph-div\" style=\"height:525px; width:100%;\"></div>            <script type=\"text/javascript\">                require([\"plotly\"], function(Plotly) {                    window.PLOTLYENV=window.PLOTLYENV || {};                                    if (document.getElementById(\"d724a7e0-633e-4a3d-a6cc-548d8459db61\")) {                    Plotly.newPlot(                        \"d724a7e0-633e-4a3d-a6cc-548d8459db61\",                        [{\"line\":{\"color\":\"#0000ff\"},\"mode\":\"lines\",\"name\":\"Empirical curve-fit\",\"type\":\"scatter\",\"x\":[-180.0,-180.0,-180.0,-180.0,-180.0,-180.0,-180.0,-179.0,-179.0,-179.0,-179.0,-179.0,-179.0,-179.0,-178.0,-178.0,-178.0,-178.0,-178.0,-178.0,-178.0,-177.0,-177.0,-177.0,-177.0,-177.0,-177.0,-177.0,-175.0,-175.0,-175.0,-175.0,-175.0,-175.0,-175.0,-170.0,-170.0,-170.0,-170.0,-170.0,-170.0,-170.0,-165.0,-165.0,-165.0,-165.0,-165.0,-165.0,-165.0,-160.0,-160.0,-160.0,-160.0,-160.0,-160.0,-160.0,-155.0,-155.0,-155.0,-155.0,-155.0,-155.0,-155.0,-150.0,-150.0,-150.0,-150.0,-150.0,-150.0,-150.0,-145.0,-145.0,-145.0,-145.0,-145.0,-145.0,-145.0,-140.0,-140.0,-140.0,-140.0,-140.0,-140.0,-140.0,-135.0,-135.0,-135.0,-135.0,-135.0,-135.0,-135.0,-130.0,-130.0,-130.0,-130.0,-130.0,-130.0,-130.0,-125.0,-125.0,-125.0,-125.0,-125.0,-125.0,-125.0,-120.0,-120.0,-120.0,-120.0,-120.0,-120.0,-120.0,-115.0,-115.0,-115.0,-115.0,-115.0,-115.0,-115.0,-110.0,-110.0,-110.0,-110.0,-110.0,-110.0,-110.0,-105.0,-105.0,-105.0,-105.0,-105.0,-105.0,-105.0,-100.0,-100.0,-100.0,-100.0,-100.0,-100.0,-100.0,-95.0,-95.0,-95.0,-95.0,-95.0,-95.0,-95.0,-90.0,-90.0,-90.0,-90.0,-90.0,-90.0,-90.0,-85.0,-85.0,-85.0,-85.0,-85.0,-85.0,-85.0,-80.0,-80.0,-80.0,-80.0,-80.0,-80.0,-80.0,-75.0,-75.0,-75.0,-75.0,-75.0,-75.0,-75.0,-70.0,-70.0,-70.0,-70.0,-70.0,-70.0,-70.0,-65.0,-65.0,-65.0,-65.0,-65.0,-65.0,-65.0,-60.0,-60.0,-60.0,-60.0,-60.0,-60.0,-60.0,-55.0,-55.0,-55.0,-55.0,-55.0,-55.0,-55.0,-50.0,-50.0,-50.0,-50.0,-50.0,-50.0,-50.0,-45.0,-45.0,-45.0,-45.0,-45.0,-45.0,-45.0,-40.0,-40.0,-40.0,-40.0,-40.0,-40.0,-40.0,-35.0,-35.0,-35.0,-35.0,-35.0,-35.0,-35.0,-30.0,-30.0,-30.0,-30.0,-30.0,-30.0,-30.0,-25.0,-25.0,-25.0,-25.0,-25.0,-25.0,-25.0,-20.0,-20.0,-20.0,-20.0,-20.0,-20.0,-20.0,-19.0,-19.0,-19.0,-19.0,-19.0,-19.0,-19.0,-18.0,-18.0,-18.0,-18.0,-18.0,-18.0,-18.0,-17.0,-17.0,-17.0,-17.0,-17.0,-17.0,-17.0,-16.0,-16.0,-16.0,-16.0,-16.0,-16.0,-16.0,-15.0,-15.0,-15.0,-15.0,-15.0,-15.0,-15.0,-14.0,-14.0,-14.0,-14.0,-14.0,-14.0,-14.0,-13.0,-13.0,-13.0,-13.0,-13.0,-13.0,-13.0,-12.0,-12.0,-12.0,-12.0,-12.0,-12.0,-12.0,-11.0,-11.0,-11.0,-11.0,-11.0,-11.0,-11.0,-10.0,-10.0,-10.0,-10.0,-10.0,-10.0,-10.0,-9.0,-9.0,-9.0,-9.0,-9.0,-9.0,-9.0,-8.0,-8.0,-8.0,-8.0,-8.0,-8.0,-8.0,-7.0,-7.0,-7.0,-7.0,-7.0,-7.0,-7.0],\"y\":[0.08592102839619864,0.08592102839619864,0.08592102839619864,0.08592102839619864,0.08592102839619864,0.08592102839619864,0.08592102839619864,0.0880946101617337,0.0880946101617337,0.0880946101617337,0.0880946101617337,0.0880946101617337,0.0880946101617337,0.0880946101617337,0.09154368488137377,0.09154368488137377,0.09154368488137377,0.09154368488137377,0.09154368488137377,0.09154368488137377,0.09154368488137377,0.09626405038886232,0.09626405038886232,0.09626405038886232,0.09626405038886232,0.09626405038886232,0.09626405038886232,0.09626405038886232,0.1094941077491236,0.1094941077491236,0.1094941077491236,0.1094941077491236,0.1094941077491236,0.1094941077491236,0.1094941077491236,0.16422666470707104,0.16422666470707104,0.16422666470707104,0.16422666470707104,0.16422666470707104,0.16422666470707104,0.16422666470707104,0.24845567822288395,0.24845567822288395,0.24845567822288395,0.24845567822288395,0.24845567822288395,0.24845567822288395,0.24845567822288395,0.3596218923428216,0.3596218923428216,0.3596218923428216,0.3596218923428216,0.3596218923428216,0.3596218923428216,0.3596218923428216,0.49434757790366846,0.49434757790366846,0.49434757790366846,0.49434757790366846,0.49434757790366846,0.49434757790366846,0.49434757790366846,0.6485391631241451,0.6485391631241451,0.6485391631241451,0.6485391631241451,0.6485391631241451,0.6485391631241451,0.6485391631241451,0.817511614712033,0.817511614712033,0.817511614712033,0.817511614712033,0.817511614712033,0.817511614712033,0.817511614712033,0.9961307902300209,0.9961307902300209,0.9961307902300209,0.9961307902300209,0.9961307902300209,0.9961307902300209,0.9961307902300209,1.1789694364156589,1.1789694364156589,1.1789694364156589,1.1789694364156589,1.1789694364156589,1.1789694364156589,1.1789694364156589,1.3604720935254164,1.3604720935254164,1.3604720935254164,1.3604720935254164,1.3604720935254164,1.3604720935254164,1.3604720935254164,1.5351238951677877,1.5351238951677877,1.5351238951677877,1.5351238951677877,1.5351238951677877,1.5351238951677877,1.5351238951677877,1.6976181347279469,1.6976181347279469,1.6976181347279469,1.6976181347279469,1.6976181347279469,1.6976181347279469,1.6976181347279469,1.84301750696291,1.84301750696291,1.84301750696291,1.84301750696291,1.84301750696291,1.84301750696291,1.84301750696291,1.9669041255229502,1.9669041255229502,1.9669041255229502,1.9669041255229502,1.9669041255229502,1.9669041255229502,1.9669041255229502,2.0655137581927754,2.0655137581927754,2.0655137581927754,2.0655137581927754,2.0655137581927754,2.0655137581927754,2.0655137581927754,2.1358502011825946,2.1358502011825946,2.1358502011825946,2.1358502011825946,2.1358502011825946,2.1358502011825946,2.1358502011825946,2.175776317264119,2.175776317264119,2.175776317264119,2.175776317264119,2.175776317264119,2.175776317264119,2.175776317264119,2.1840789716038014,2.1840789716038014,2.1840789716038014,2.1840789716038014,2.1840789716038014,2.1840789716038014,2.1840789716038014,2.1605058922508764,2.1605058922508764,2.1605058922508764,2.1605058922508764,2.1605058922508764,2.1605058922508764,2.1605058922508764,2.1057733352929286,2.1057733352929286,2.1057733352929286,2.1057733352929286,2.1057733352929286,2.1057733352929286,2.1057733352929286,2.0215443217771156,2.0215443217771156,2.0215443217771156,2.0215443217771156,2.0215443217771156,2.0215443217771156,2.0215443217771156,1.9103781076571777,1.9103781076571777,1.9103781076571777,1.9103781076571777,1.9103781076571777,1.9103781076571777,1.9103781076571777,1.7756524220963308,1.7756524220963308,1.7756524220963308,1.7756524220963308,1.7756524220963308,1.7756524220963308,1.7756524220963308,1.6214608368758547,1.6214608368758547,1.6214608368758547,1.6214608368758547,1.6214608368758547,1.6214608368758547,1.6214608368758547,1.4524883852879666,1.4524883852879666,1.4524883852879666,1.4524883852879666,1.4524883852879666,1.4524883852879666,1.4524883852879666,1.2738692097699784,1.2738692097699784,1.2738692097699784,1.2738692097699784,1.2738692097699784,1.2738692097699784,1.2738692097699784,1.0910305635843403,1.0910305635843403,1.0910305635843403,1.0910305635843403,1.0910305635843403,1.0910305635843403,1.0910305635843403,0.9095279064745835,0.9095279064745835,0.9095279064745835,0.9095279064745835,0.9095279064745835,0.9095279064745835,0.9095279064745835,0.7348761048322121,0.7348761048322121,0.7348761048322121,0.7348761048322121,0.7348761048322121,0.7348761048322121,0.7348761048322121,0.5723818652720535,0.5723818652720535,0.5723818652720535,0.5723818652720535,0.5723818652720535,0.5723818652720535,0.5723818652720535,0.42698249303709035,0.42698249303709035,0.42698249303709035,0.42698249303709035,0.42698249303709035,0.42698249303709035,0.42698249303709035,0.3030958744770498,0.3030958744770498,0.3030958744770498,0.3030958744770498,0.3030958744770498,0.3030958744770498,0.3030958744770498,0.28124420090062097,0.28124420090062097,0.28124420090062097,0.28124420090062097,0.28124420090062097,0.28124420090062097,0.28124420090062097,0.26043269725439555,0.26043269725439555,0.26043269725439555,0.26043269725439555,0.26043269725439555,0.26043269725439555,0.26043269725439555,0.2406867191498,0.2406867191498,0.2406867191498,0.2406867191498,0.2406867191498,0.2406867191498,0.2406867191498,0.22203032401952005,0.22203032401952005,0.22203032401952005,0.22203032401952005,0.22203032401952005,0.22203032401952005,0.22203032401952005,0.20448624180722452,0.20448624180722452,0.20448624180722452,0.20448624180722452,0.20448624180722452,0.20448624180722452,0.20448624180722452,0.18807584727463045,0.18807584727463045,0.18807584727463045,0.18807584727463045,0.18807584727463045,0.18807584727463045,0.18807584727463045,0.17281913395964832,0.17281913395964832,0.17281913395964832,0.17281913395964832,0.17281913395964832,0.17281913395964832,0.17281913395964832,0.15873468981733607,0.15873468981733607,0.15873468981733607,0.15873468981733607,0.15873468981733607,0.15873468981733607,0.15873468981733607,0.14583967457333846,0.14583967457333846,0.14583967457333846,0.14583967457333846,0.14583967457333846,0.14583967457333846,0.14583967457333846,0.13414979881740563,0.13414979881740563,0.13414979881740563,0.13414979881740563,0.13414979881740563,0.13414979881740563,0.13414979881740563,0.12367930486245893,0.12367930486245893,0.12367930486245893,0.12367930486245893,0.12367930486245893,0.12367930486245893,0.12367930486245893,0.11444094939252647,0.11444094939252647,0.11444094939252647,0.11444094939252647,0.11444094939252647,0.11444094939252647,0.11444094939252647,0.10644598792068871,0.10644598792068871,0.10644598792068871,0.10644598792068871,0.10644598792068871,0.10644598792068871,0.10644598792068871]},{\"marker\":{\"color\":\"#0000ff\"},\"mode\":\"lines\",\"showlegend\":false,\"type\":\"scatter\",\"x\":[18.0,18.0,18.0,18.0,18.0,18.0,18.0,19.0,19.0,19.0,19.0,19.0,19.0,19.0,20.0,20.0,20.0,20.0,20.0,20.0,20.0,25.0,25.0,25.0,25.0,25.0,25.0,25.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,40.0,40.0,40.0,40.0,40.0,40.0,40.0,45.0,45.0,45.0,45.0,45.0,45.0,45.0,50.0,50.0,50.0,50.0,50.0,50.0,50.0,55.0,55.0,55.0,55.0,55.0,55.0,55.0,60.0,60.0,60.0,60.0,60.0,60.0,60.0,65.0,65.0,65.0,65.0,65.0,65.0,65.0,70.0,70.0,70.0,70.0,70.0,70.0,70.0,75.0,75.0,75.0,75.0,75.0,75.0,75.0,80.0,80.0,80.0,80.0,80.0,80.0,80.0,85.0,85.0,85.0,85.0,85.0,85.0,85.0,90.0,90.0,90.0,90.0,90.0,90.0,90.0,95.0,95.0,95.0,95.0,95.0,95.0,95.0,100.0,100.0,100.0,100.0,100.0,100.0,100.0,105.0,105.0,105.0,105.0,105.0,105.0,105.0,110.0,110.0,110.0,110.0,110.0,110.0,110.0,115.0,115.0,115.0,115.0,115.0,115.0,115.0,120.0,120.0,120.0,120.0,120.0,120.0,120.0,125.0,125.0,125.0,125.0,125.0,125.0,125.0,130.0,130.0,130.0,130.0,130.0,130.0,130.0,135.0,135.0,135.0,135.0,135.0,135.0,135.0,140.0,140.0,140.0,140.0,140.0,140.0,140.0,145.0,145.0,145.0,145.0,145.0,145.0,145.0,150.0,150.0,150.0,150.0,150.0,150.0,150.0,155.0,155.0,155.0,155.0,155.0,155.0,155.0,160.0,160.0,160.0,160.0,160.0,160.0,160.0,165.0,165.0,165.0,165.0,165.0,165.0,165.0,170.0,170.0,170.0,170.0,170.0,170.0,170.0,175.0,175.0,175.0,175.0,175.0,175.0,175.0,177.0,177.0,177.0,177.0,177.0,177.0,177.0,178.0,178.0,178.0,178.0,178.0,178.0,178.0,179.0,179.0,179.0,179.0,179.0,179.0,179.0,180.0,180.0,180.0,180.0,180.0,180.0,180.0],\"y\":[0.31212186980786816,0.31212186980786816,0.31212186980786816,0.31212186980786816,0.31212186980786816,0.31212186980786816,0.31212186980786816,0.33538477708642633,0.33538477708642633,0.33538477708642633,0.33538477708642633,0.33538477708642633,0.33538477708642633,0.33538477708642633,0.35962189234282194,0.35962189234282194,0.35962189234282194,0.35962189234282194,0.35962189234282194,0.35962189234282194,0.35962189234282194,0.4943475779036689,0.4943475779036689,0.4943475779036689,0.4943475779036689,0.4943475779036689,0.4943475779036689,0.4943475779036689,0.6485391631241451,0.6485391631241451,0.6485391631241451,0.6485391631241451,0.6485391631241451,0.6485391631241451,0.6485391631241451,0.8175116147120334,0.8175116147120334,0.8175116147120334,0.8175116147120334,0.8175116147120334,0.8175116147120334,0.8175116147120334,0.9961307902300214,0.9961307902300214,0.9961307902300214,0.9961307902300214,0.9961307902300214,0.9961307902300214,0.9961307902300214,1.1789694364156595,1.1789694364156595,1.1789694364156595,1.1789694364156595,1.1789694364156595,1.1789694364156595,1.1789694364156595,1.3604720935254164,1.3604720935254164,1.3604720935254164,1.3604720935254164,1.3604720935254164,1.3604720935254164,1.3604720935254164,1.535123895167788,1.535123895167788,1.535123895167788,1.535123895167788,1.535123895167788,1.535123895167788,1.535123895167788,1.6976181347279466,1.6976181347279466,1.6976181347279466,1.6976181347279466,1.6976181347279466,1.6976181347279466,1.6976181347279466,1.8430175069629096,1.8430175069629096,1.8430175069629096,1.8430175069629096,1.8430175069629096,1.8430175069629096,1.8430175069629096,1.9669041255229502,1.9669041255229502,1.9669041255229502,1.9669041255229502,1.9669041255229502,1.9669041255229502,1.9669041255229502,2.0655137581927754,2.0655137581927754,2.0655137581927754,2.0655137581927754,2.0655137581927754,2.0655137581927754,2.0655137581927754,2.1358502011825946,2.1358502011825946,2.1358502011825946,2.1358502011825946,2.1358502011825946,2.1358502011825946,2.1358502011825946,2.175776317264119,2.175776317264119,2.175776317264119,2.175776317264119,2.175776317264119,2.175776317264119,2.175776317264119,2.1840789716038014,2.1840789716038014,2.1840789716038014,2.1840789716038014,2.1840789716038014,2.1840789716038014,2.1840789716038014,2.1605058922508764,2.1605058922508764,2.1605058922508764,2.1605058922508764,2.1605058922508764,2.1605058922508764,2.1605058922508764,2.1057733352929286,2.1057733352929286,2.1057733352929286,2.1057733352929286,2.1057733352929286,2.1057733352929286,2.1057733352929286,2.0215443217771156,2.0215443217771156,2.0215443217771156,2.0215443217771156,2.0215443217771156,2.0215443217771156,2.0215443217771156,1.910378107657178,1.910378107657178,1.910378107657178,1.910378107657178,1.910378107657178,1.910378107657178,1.910378107657178,1.7756524220963312,1.7756524220963312,1.7756524220963312,1.7756524220963312,1.7756524220963312,1.7756524220963312,1.7756524220963312,1.6214608368758552,1.6214608368758552,1.6214608368758552,1.6214608368758552,1.6214608368758552,1.6214608368758552,1.6214608368758552,1.4524883852879664,1.4524883852879664,1.4524883852879664,1.4524883852879664,1.4524883852879664,1.4524883852879664,1.4524883852879664,1.2738692097699795,1.2738692097699795,1.2738692097699795,1.2738692097699795,1.2738692097699795,1.2738692097699795,1.2738692097699795,1.0910305635843405,1.0910305635843405,1.0910305635843405,1.0910305635843405,1.0910305635843405,1.0910305635843405,1.0910305635843405,0.909527906474584,0.909527906474584,0.909527906474584,0.909527906474584,0.909527906474584,0.909527906474584,0.909527906474584,0.7348761048322127,0.7348761048322127,0.7348761048322127,0.7348761048322127,0.7348761048322127,0.7348761048322127,0.7348761048322127,0.5723818652720541,0.5723818652720541,0.5723818652720541,0.5723818652720541,0.5723818652720541,0.5723818652720541,0.5723818652720541,0.42698249303709057,0.42698249303709057,0.42698249303709057,0.42698249303709057,0.42698249303709057,0.42698249303709057,0.42698249303709057,0.3030958744770499,0.3030958744770499,0.3030958744770499,0.3030958744770499,0.3030958744770499,0.3030958744770499,0.3030958744770499,0.20448624180722474,0.20448624180722474,0.20448624180722474,0.20448624180722474,0.20448624180722474,0.20448624180722474,0.20448624180722474,0.13414979881740585,0.13414979881740585,0.13414979881740585,0.13414979881740585,0.13414979881740585,0.13414979881740585,0.13414979881740585,0.09422368273588133,0.09422368273588133,0.09422368273588133,0.09422368273588133,0.09422368273588133,0.09422368273588133,0.09422368273588133,0.08707193515031486,0.08707193515031486,0.08707193515031486,0.08707193515031486,0.08707193515031486,0.08707193515031486,0.08707193515031486,0.08540937920762781,0.08540937920762781,0.08540937920762781,0.08540937920762781,0.08540937920762781,0.08540937920762781,0.08540937920762781,0.08502558775933555,0.08502558775933555,0.08502558775933555,0.08502558775933555,0.08502558775933555,0.08502558775933555,0.08502558775933555,0.08592102839619864,0.08592102839619864,0.08592102839619864,0.08592102839619864,0.08592102839619864,0.08592102839619864,0.08592102839619864]},{\"line\":{\"color\":\"#0000ff\"},\"mode\":\"markers\",\"name\":\"CFD\",\"type\":\"scatter\",\"x\":[-6.0,-5.76767677,-5.53535354,-5.3030303,-5.07070707,-4.83838384,-4.60606061,-4.37373737,-4.14141414,-3.90909091,-3.67676768,-3.44444444,-3.21212121,-2.97979798,-2.74747475,-2.51515152,-2.28282828,-2.05050505,-1.81818182,-1.58585859,-1.35353535,-1.12121212,-0.88888889,-0.65656566,-0.42424242,-0.19191919,0.04040404,0.27272727,0.50505051,0.73737374,0.96969697,1.2020202,1.43434343,1.66666667,1.8989899,2.13131313,2.36363636,2.5959596,2.82828283,3.06060606,3.29292929,3.52525253,3.75757576,3.98989899,4.22222222,4.45454545,4.68686869,4.91919192,5.15151515,5.38383838,5.61616162,5.84848485,6.08080808,6.31313131,6.54545455,6.77777778,7.01010101,7.24242424,7.47474747,7.70707071,7.93939394,8.17171717,8.4040404,8.63636364,8.86868687,9.1010101,9.33333333,9.56565657,9.7979798,10.03030303,10.26262626,10.49494949,10.72727273,10.95959596,11.19191919,11.42424242,11.65656566,11.88888889,12.12121212,12.35353535,12.58585859,12.81818182,13.05050505,13.28282828,13.51515152,13.74747475,13.97979798,14.21212121,14.44444444,14.67676768,14.90909091,15.14141414,15.37373737,15.60606061,15.83838384,16.07070707,16.3030303,16.53535354,16.76767677,17.0],\"y\":[0.01139713,0.01120696,0.01103136,0.01086916,0.01071921,0.01058036,0.01045193,0.01033349,0.01022457,0.01012469,0.01003345,0.00995053,0.00987563,0.00980841,0.0097486,0.00969619,0.0096512,0.00961352,0.00958301,0.00955951,0.00954287,0.00953296,0.00952963,0.00953279,0.00954245,0.00955859,0.00958122,0.00961032,0.00964586,0.00968777,0.00973603,0.00979059,0.00985151,0.00991883,0.00999264,0.010073,0.01015997,0.01025362,0.01035401,0.0104612,0.01057531,0.01069648,0.01082489,0.01096071,0.0111041,0.01125509,0.01141368,0.01157988,0.01175374,0.01193586,0.01212721,0.01232875,0.01254143,0.01276405,0.01299389,0.01323319,0.01348299,0.0137435,0.014016,0.01429973,0.01459559,0.014907,0.01523226,0.01556999,0.01592241,0.01629189,0.01667924,0.01708373,0.01750572,0.01794838,0.01841474,0.01890593,0.0194322,0.02001885,0.02070299,0.02153367,0.02256262,0.02381718,0.02530925,0.02705054,0.029061,0.03137037,0.03397616,0.03687954,0.04013382,0.04388771,0.04805455,0.05247681,0.05756547,0.06330455,0.0695248,0.07648436,0.08390437,0.0916152,0.10006728,0.10883361,0.11752242,0.12613119,0.13453565,0.14257238]}],                        {\"plot_bgcolor\":\"rgba(0,0.5,0,0)\",\"template\":{\"data\":{\"bar\":[{\"error_x\":{\"color\":\"rgb(36,36,36)\"},\"error_y\":{\"color\":\"rgb(36,36,36)\"},\"marker\":{\"line\":{\"color\":\"white\",\"width\":0.5},\"pattern\":{\"fillmode\":\"overlay\",\"size\":10,\"solidity\":0.2}},\"type\":\"bar\"}],\"barpolar\":[{\"marker\":{\"line\":{\"color\":\"white\",\"width\":0.5},\"pattern\":{\"fillmode\":\"overlay\",\"size\":10,\"solidity\":0.2}},\"type\":\"barpolar\"}],\"carpet\":[{\"aaxis\":{\"endlinecolor\":\"rgb(36,36,36)\",\"gridcolor\":\"white\",\"linecolor\":\"white\",\"minorgridcolor\":\"white\",\"startlinecolor\":\"rgb(36,36,36)\"},\"baxis\":{\"endlinecolor\":\"rgb(36,36,36)\",\"gridcolor\":\"white\",\"linecolor\":\"white\",\"minorgridcolor\":\"white\",\"startlinecolor\":\"rgb(36,36,36)\"},\"type\":\"carpet\"}],\"choropleth\":[{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"},\"type\":\"choropleth\"}],\"contour\":[{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"},\"colorscale\":[[0.0,\"#440154\"],[0.1111111111111111,\"#482878\"],[0.2222222222222222,\"#3e4989\"],[0.3333333333333333,\"#31688e\"],[0.4444444444444444,\"#26828e\"],[0.5555555555555556,\"#1f9e89\"],[0.6666666666666666,\"#35b779\"],[0.7777777777777778,\"#6ece58\"],[0.8888888888888888,\"#b5de2b\"],[1.0,\"#fde725\"]],\"type\":\"contour\"}],\"contourcarpet\":[{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"},\"type\":\"contourcarpet\"}],\"heatmap\":[{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"},\"colorscale\":[[0.0,\"#440154\"],[0.1111111111111111,\"#482878\"],[0.2222222222222222,\"#3e4989\"],[0.3333333333333333,\"#31688e\"],[0.4444444444444444,\"#26828e\"],[0.5555555555555556,\"#1f9e89\"],[0.6666666666666666,\"#35b779\"],[0.7777777777777778,\"#6ece58\"],[0.8888888888888888,\"#b5de2b\"],[1.0,\"#fde725\"]],\"type\":\"heatmap\"}],\"heatmapgl\":[{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"},\"colorscale\":[[0.0,\"#440154\"],[0.1111111111111111,\"#482878\"],[0.2222222222222222,\"#3e4989\"],[0.3333333333333333,\"#31688e\"],[0.4444444444444444,\"#26828e\"],[0.5555555555555556,\"#1f9e89\"],[0.6666666666666666,\"#35b779\"],[0.7777777777777778,\"#6ece58\"],[0.8888888888888888,\"#b5de2b\"],[1.0,\"#fde725\"]],\"type\":\"heatmapgl\"}],\"histogram\":[{\"marker\":{\"line\":{\"color\":\"white\",\"width\":0.6}},\"type\":\"histogram\"}],\"histogram2d\":[{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"},\"colorscale\":[[0.0,\"#440154\"],[0.1111111111111111,\"#482878\"],[0.2222222222222222,\"#3e4989\"],[0.3333333333333333,\"#31688e\"],[0.4444444444444444,\"#26828e\"],[0.5555555555555556,\"#1f9e89\"],[0.6666666666666666,\"#35b779\"],[0.7777777777777778,\"#6ece58\"],[0.8888888888888888,\"#b5de2b\"],[1.0,\"#fde725\"]],\"type\":\"histogram2d\"}],\"histogram2dcontour\":[{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"},\"colorscale\":[[0.0,\"#440154\"],[0.1111111111111111,\"#482878\"],[0.2222222222222222,\"#3e4989\"],[0.3333333333333333,\"#31688e\"],[0.4444444444444444,\"#26828e\"],[0.5555555555555556,\"#1f9e89\"],[0.6666666666666666,\"#35b779\"],[0.7777777777777778,\"#6ece58\"],[0.8888888888888888,\"#b5de2b\"],[1.0,\"#fde725\"]],\"type\":\"histogram2dcontour\"}],\"mesh3d\":[{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"},\"type\":\"mesh3d\"}],\"parcoords\":[{\"line\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"type\":\"parcoords\"}],\"pie\":[{\"automargin\":true,\"type\":\"pie\"}],\"scatter\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"type\":\"scatter\"}],\"scatter3d\":[{\"line\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"marker\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"type\":\"scatter3d\"}],\"scattercarpet\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"type\":\"scattercarpet\"}],\"scattergeo\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"type\":\"scattergeo\"}],\"scattergl\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"type\":\"scattergl\"}],\"scattermapbox\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"type\":\"scattermapbox\"}],\"scatterpolar\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"type\":\"scatterpolar\"}],\"scatterpolargl\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"type\":\"scatterpolargl\"}],\"scatterternary\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"type\":\"scatterternary\"}],\"surface\":[{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"},\"colorscale\":[[0.0,\"#440154\"],[0.1111111111111111,\"#482878\"],[0.2222222222222222,\"#3e4989\"],[0.3333333333333333,\"#31688e\"],[0.4444444444444444,\"#26828e\"],[0.5555555555555556,\"#1f9e89\"],[0.6666666666666666,\"#35b779\"],[0.7777777777777778,\"#6ece58\"],[0.8888888888888888,\"#b5de2b\"],[1.0,\"#fde725\"]],\"type\":\"surface\"}],\"table\":[{\"cells\":{\"fill\":{\"color\":\"rgb(237,237,237)\"},\"line\":{\"color\":\"white\"}},\"header\":{\"fill\":{\"color\":\"rgb(217,217,217)\"},\"line\":{\"color\":\"white\"}},\"type\":\"table\"}]},\"layout\":{\"annotationdefaults\":{\"arrowhead\":0,\"arrowwidth\":1},\"autotypenumbers\":\"strict\",\"coloraxis\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"colorscale\":{\"diverging\":[[0.0,\"rgb(103,0,31)\"],[0.1,\"rgb(178,24,43)\"],[0.2,\"rgb(214,96,77)\"],[0.3,\"rgb(244,165,130)\"],[0.4,\"rgb(253,219,199)\"],[0.5,\"rgb(247,247,247)\"],[0.6,\"rgb(209,229,240)\"],[0.7,\"rgb(146,197,222)\"],[0.8,\"rgb(67,147,195)\"],[0.9,\"rgb(33,102,172)\"],[1.0,\"rgb(5,48,97)\"]],\"sequential\":[[0.0,\"#440154\"],[0.1111111111111111,\"#482878\"],[0.2222222222222222,\"#3e4989\"],[0.3333333333333333,\"#31688e\"],[0.4444444444444444,\"#26828e\"],[0.5555555555555556,\"#1f9e89\"],[0.6666666666666666,\"#35b779\"],[0.7777777777777778,\"#6ece58\"],[0.8888888888888888,\"#b5de2b\"],[1.0,\"#fde725\"]],\"sequentialminus\":[[0.0,\"#440154\"],[0.1111111111111111,\"#482878\"],[0.2222222222222222,\"#3e4989\"],[0.3333333333333333,\"#31688e\"],[0.4444444444444444,\"#26828e\"],[0.5555555555555556,\"#1f9e89\"],[0.6666666666666666,\"#35b779\"],[0.7777777777777778,\"#6ece58\"],[0.8888888888888888,\"#b5de2b\"],[1.0,\"#fde725\"]]},\"colorway\":[\"#1F77B4\",\"#FF7F0E\",\"#2CA02C\",\"#D62728\",\"#9467BD\",\"#8C564B\",\"#E377C2\",\"#7F7F7F\",\"#BCBD22\",\"#17BECF\"],\"font\":{\"color\":\"rgb(36,36,36)\"},\"geo\":{\"bgcolor\":\"white\",\"lakecolor\":\"white\",\"landcolor\":\"white\",\"showlakes\":true,\"showland\":true,\"subunitcolor\":\"white\"},\"hoverlabel\":{\"align\":\"left\"},\"hovermode\":\"closest\",\"mapbox\":{\"style\":\"light\"},\"paper_bgcolor\":\"white\",\"plot_bgcolor\":\"white\",\"polar\":{\"angularaxis\":{\"gridcolor\":\"rgb(232,232,232)\",\"linecolor\":\"rgb(36,36,36)\",\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\"},\"bgcolor\":\"white\",\"radialaxis\":{\"gridcolor\":\"rgb(232,232,232)\",\"linecolor\":\"rgb(36,36,36)\",\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\"}},\"scene\":{\"xaxis\":{\"backgroundcolor\":\"white\",\"gridcolor\":\"rgb(232,232,232)\",\"gridwidth\":2,\"linecolor\":\"rgb(36,36,36)\",\"showbackground\":true,\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\",\"zeroline\":false,\"zerolinecolor\":\"rgb(36,36,36)\"},\"yaxis\":{\"backgroundcolor\":\"white\",\"gridcolor\":\"rgb(232,232,232)\",\"gridwidth\":2,\"linecolor\":\"rgb(36,36,36)\",\"showbackground\":true,\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\",\"zeroline\":false,\"zerolinecolor\":\"rgb(36,36,36)\"},\"zaxis\":{\"backgroundcolor\":\"white\",\"gridcolor\":\"rgb(232,232,232)\",\"gridwidth\":2,\"linecolor\":\"rgb(36,36,36)\",\"showbackground\":true,\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\",\"zeroline\":false,\"zerolinecolor\":\"rgb(36,36,36)\"}},\"shapedefaults\":{\"fillcolor\":\"black\",\"line\":{\"width\":0},\"opacity\":0.3},\"ternary\":{\"aaxis\":{\"gridcolor\":\"rgb(232,232,232)\",\"linecolor\":\"rgb(36,36,36)\",\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\"},\"baxis\":{\"gridcolor\":\"rgb(232,232,232)\",\"linecolor\":\"rgb(36,36,36)\",\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\"},\"bgcolor\":\"white\",\"caxis\":{\"gridcolor\":\"rgb(232,232,232)\",\"linecolor\":\"rgb(36,36,36)\",\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\"}},\"title\":{\"x\":0.05},\"xaxis\":{\"automargin\":true,\"gridcolor\":\"rgb(232,232,232)\",\"linecolor\":\"rgb(36,36,36)\",\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\",\"title\":{\"standoff\":15},\"zeroline\":false,\"zerolinecolor\":\"rgb(36,36,36)\"},\"yaxis\":{\"automargin\":true,\"gridcolor\":\"rgb(232,232,232)\",\"linecolor\":\"rgb(36,36,36)\",\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\",\"title\":{\"standoff\":15},\"zeroline\":false,\"zerolinecolor\":\"rgb(36,36,36)\"}}},\"title\":{\"text\":\"Cd vs Alpha\"},\"xaxis\":{\"gridcolor\":\"Gray\",\"gridwidth\":1,\"linecolor\":\"black\",\"linewidth\":2,\"mirror\":false,\"showgrid\":true,\"showline\":true,\"title\":{\"text\":\"Alpha [deg]\"},\"zeroline\":true,\"zerolinecolor\":\"Gray\",\"zerolinewidth\":1},\"yaxis\":{\"gridcolor\":\"Gray\",\"gridwidth\":0.5,\"linecolor\":\"black\",\"linewidth\":2,\"mirror\":false,\"showgrid\":true,\"showline\":true,\"title\":{\"text\":\"Cd\"},\"zeroline\":true,\"zerolinecolor\":\"Gray\",\"zerolinewidth\":1}},                        {\"responsive\": true}                    ).then(function(){\n",
       "                            \n",
       "var gd = document.getElementById('d724a7e0-633e-4a3d-a6cc-548d8459db61');\n",
       "var x = new MutationObserver(function (mutations, observer) {{\n",
       "        var display = window.getComputedStyle(gd).display;\n",
       "        if (!display || display === 'none') {{\n",
       "            console.log([gd, 'removed!']);\n",
       "            Plotly.purge(gd);\n",
       "            observer.disconnect();\n",
       "        }}\n",
       "}});\n",
       "\n",
       "// Listen for the removal of the full notebook cells\n",
       "var notebookContainer = gd.closest('#notebook-container');\n",
       "if (notebookContainer) {{\n",
       "    x.observe(notebookContainer, {childList: true});\n",
       "}}\n",
       "\n",
       "// Listen for the clearing of the current output cell\n",
       "var outputEl = gd.closest('.output');\n",
       "if (outputEl) {{\n",
       "    x.observe(outputEl, {childList: true});\n",
       "}}\n",
       "\n",
       "                        })                };                });            </script>        </div>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "layout = Layout(plot_bgcolor='rgba(0,0.5,0,0)')\n",
    "fig3 = go.Figure(layout=layout)\n",
    "fig3.add_trace(go.Scatter(x=df3['alpha'], y=df3['Cd'],\n",
    "                    mode='lines',\n",
    "                    name='Empirical curve-fit', line=dict(color=\"#0000ff\")))\n",
    "fig3.add_trace(go.Scatter(x=df4['alpha'], y=df4['Cd'],mode='lines', showlegend=False, marker=dict(color=\"#0000ff\")))\n",
    "fig3.add_trace(go.Scatter(x=df['alpha'], y=df['Cd'],\n",
    "                    mode='markers', name='CFD', line=dict(color=\"#0000ff\")))\n",
    "\n",
    "fig3.update_layout(\n",
    "title=\"Cd vs Alpha\",\n",
    "xaxis_title=\"Alpha [deg]\", \n",
    "yaxis_title=\"Cd\")\n",
    "fig3.update_xaxes(showline=True, linewidth=2, linecolor='black', mirror=False)\n",
    "fig3.update_yaxes(showline=True, linewidth=2, linecolor='black', mirror=False)\n",
    "fig3.update_xaxes(showgrid=True, gridwidth=1, gridcolor='Gray')\n",
    "fig3.update_yaxes(showgrid=True, gridwidth=0.5, gridcolor='Gray')\n",
    "fig3.update_xaxes(zeroline=True, zerolinewidth=1, zerolinecolor='Gray')\n",
    "fig3.update_yaxes(zeroline=True, zerolinewidth=1, zerolinecolor='Gray')\n",
    "fig3.show()\n",
    "\n"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "b720cf76",
   "metadata": {
    "slideshow": {
     "slide_type": "skip"
    }
   },
   "source": [
    "The airfoil L/D provides a clearer picture of the range of flow parameters where the rotor blade sections would perform better. As a rule of thumb the goal is for each blade section to be operating at or close to the the angle of attack that leads to best L/D."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 7,
   "id": "4a6cdb52",
   "metadata": {
    "hide_input": true,
    "scrolled": false,
    "slideshow": {
     "slide_type": "subslide"
    },
    "tags": [
     "hide-input"
    ]
   },
   "outputs": [
    {
     "data": {
      "application/vnd.plotly.v1+json": {
       "config": {
        "plotlyServerURL": "https://plot.ly"
       },
       "data": [
        {
         "colorscale": [
          [
           0,
           "#440154"
          ],
          [
           0.1111111111111111,
           "#482878"
          ],
          [
           0.2222222222222222,
           "#3e4989"
          ],
          [
           0.3333333333333333,
           "#31688e"
          ],
          [
           0.4444444444444444,
           "#26828e"
          ],
          [
           0.5555555555555556,
           "#1f9e89"
          ],
          [
           0.6666666666666666,
           "#35b779"
          ],
          [
           0.7777777777777778,
           "#6ece58"
          ],
          [
           0.8888888888888888,
           "#b5de2b"
          ],
          [
           1,
           "#fde725"
          ]
         ],
         "opacity": 0.8,
         "type": "surface",
         "x": [
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ],
          [
           0.2,
           0.20120240480961926,
           0.20240480961923848,
           0.20360721442885774,
           0.20480961923847696,
           0.2060120240480962,
           0.20721442885771543,
           0.20841683366733468,
           0.2096192384769539,
           0.21082164328657316,
           0.2120240480961924,
           0.21322645290581163,
           0.21442885771543088,
           0.2156312625250501,
           0.21683366733466936,
           0.2180360721442886,
           0.21923847695390783,
           0.22044088176352705,
           0.2216432865731463,
           0.22284569138276555,
           0.22404809619238478,
           0.22525050100200403,
           0.22645290581162325,
           0.2276553106212425,
           0.22885771543086175,
           0.23006012024048098,
           0.2312625250501002,
           0.23246492985971945,
           0.2336673346693387,
           0.23486973947895792,
           0.23607214428857717,
           0.2372745490981964,
           0.23847695390781565,
           0.2396793587174349,
           0.24088176352705412,
           0.24208416833667337,
           0.2432865731462926,
           0.24448897795591185,
           0.2456913827655311,
           0.24689378757515032,
           0.24809619238476954,
           0.2492985971943888,
           0.25050100200400804,
           0.2517034068136273,
           0.2529058116232465,
           0.25410821643286574,
           0.255310621242485,
           0.25651302605210424,
           0.25771543086172344,
           0.2589178356713427,
           0.26012024048096194,
           0.2613226452905812,
           0.26252505010020044,
           0.26372745490981964,
           0.2649298597194389,
           0.26613226452905814,
           0.2673346693386774,
           0.26853707414829664,
           0.26973947895791583,
           0.2709418837675351,
           0.27214428857715434,
           0.2733466933867736,
           0.27454909819639284,
           0.27575150300601203,
           0.2769539078156313,
           0.27815631262525053,
           0.27935871743486973,
           0.280561122244489,
           0.28176352705410823,
           0.2829659318637275,
           0.28416833667334673,
           0.28537074148296593,
           0.2865731462925852,
           0.28777555110220443,
           0.2889779559118237,
           0.29018036072144293,
           0.2913827655310621,
           0.2925851703406814,
           0.29378757515030063,
           0.2949899799599199,
           0.29619238476953913,
           0.2973947895791583,
           0.2985971943887776,
           0.2997995991983968,
           0.301002004008016,
           0.30220440881763533,
           0.3034068136272545,
           0.3046092184368738,
           0.305811623246493,
           0.3070140280561122,
           0.30821643286573147,
           0.3094188376753507,
           0.31062124248497,
           0.3118236472945892,
           0.3130260521042084,
           0.31422845691382767,
           0.3154308617234469,
           0.31663326653306617,
           0.3178356713426854,
           0.3190380761523046,
           0.32024048096192387,
           0.3214428857715431,
           0.32264529058116237,
           0.3238476953907816,
           0.3250501002004008,
           0.32625250501002007,
           0.3274549098196393,
           0.3286573146292585,
           0.3298597194388778,
           0.331062124248497,
           0.33226452905811626,
           0.3334669338677355,
           0.3346693386773547,
           0.335871743486974,
           0.3370741482965932,
           0.33827655310621246,
           0.3394789579158317,
           0.3406813627254509,
           0.34188376753507016,
           0.3430861723446894,
           0.34428857715430866,
           0.3454909819639279,
           0.3466933867735471,
           0.34789579158316636,
           0.3490981963927856,
           0.3503006012024048,
           0.3515030060120241,
           0.3527054108216433,
           0.35390781563126256,
           0.3551102204408818,
           0.356312625250501,
           0.3575150300601203,
           0.3587174348697395,
           0.35991983967935876,
           0.361122244488978,
           0.3623246492985972,
           0.36352705410821645,
           0.3647294589178357,
           0.36593186372745495,
           0.3671342685370742,
           0.3683366733466934,
           0.36953907815631265,
           0.3707414829659319,
           0.3719438877755511,
           0.3731462925851704,
           0.3743486973947896,
           0.37555110220440885,
           0.3767535070140281,
           0.3779559118236473,
           0.3791583166332666,
           0.3803607214428858,
           0.38156312625250505,
           0.3827655310621243,
           0.3839679358717435,
           0.3851703406813628,
           0.386372745490982,
           0.38757515030060125,
           0.3887775551102205,
           0.3899799599198397,
           0.39118236472945894,
           0.3923847695390782,
           0.39358717434869744,
           0.3947895791583167,
           0.3959919839679359,
           0.39719438877755514,
           0.3983967935871744,
           0.3995991983967936,
           0.4008016032064129,
           0.4020040080160321,
           0.40320641282565134,
           0.4044088176352706,
           0.4056112224448898,
           0.4068136272545091,
           0.4080160320641283,
           0.40921843687374754,
           0.4104208416833668,
           0.411623246492986,
           0.4128256513026053,
           0.4140280561122245,
           0.41523046092184374,
           0.416432865731463,
           0.4176352705410822,
           0.41883767535070143,
           0.4200400801603207,
           0.42124248496993993,
           0.4224448897795592,
           0.4236472945891784,
           0.42484969939879763,
           0.4260521042084169,
           0.4272545090180361,
           0.4284569138276554,
           0.4296593186372746,
           0.43086172344689383,
           0.4320641282565131,
           0.4332665330661323,
           0.4344689378757516,
           0.4356713426853708,
           0.43687374749499003,
           0.4380761523046093,
           0.4392785571142285,
           0.4404809619238477,
           0.441683366733467,
           0.4428857715430862,
           0.4440881763527055,
           0.4452905811623247,
           0.4464929859719439,
           0.4476953907815632,
           0.44889779559118237,
           0.4501002004008016,
           0.45130260521042087,
           0.4525050100200401,
           0.4537074148296594,
           0.4549098196392786,
           0.4561122244488978,
           0.45731462925851707,
           0.4585170340681363,
           0.45971943887775557,
           0.4609218436873748,
           0.462124248496994,
           0.46332665330661327,
           0.4645290581162325,
           0.46573146292585177,
           0.46693386773547096,
           0.4681362725450902,
           0.46933867735470947,
           0.4705410821643287,
           0.47174348697394797,
           0.47294589178356716,
           0.4741482965931864,
           0.47535070140280566,
           0.4765531062124249,
           0.4777555110220441,
           0.47895791583166336,
           0.4801603206412826,
           0.48136272545090186,
           0.4825651302605211,
           0.4837675350701403,
           0.48496993987975956,
           0.4861723446893788,
           0.48737474949899806,
           0.4885771543086173,
           0.4897795591182365,
           0.49098196392785576,
           0.492184368737475,
           0.49338677354709426,
           0.49458917835671345,
           0.4957915831663327,
           0.49699398797595196,
           0.4981963927855712,
           0.49939879759519046,
           0.5006012024048097,
           0.501803607214429,
           0.5030060120240482,
           0.5042084168336673,
           0.5054108216432867,
           0.5066132264529059,
           0.507815631262525,
           0.5090180360721444,
           0.5102204408817637,
           0.5114228456913827,
           0.512625250501002,
           0.5138276553106214,
           0.5150300601202406,
           0.5162324649298597,
           0.517434869739479,
           0.5186372745490982,
           0.5198396793587174,
           0.5210420841683367,
           0.522244488977956,
           0.5234468937875751,
           0.5246492985971944,
           0.5258517034068138,
           0.5270541082164328,
           0.5282565130260521,
           0.5294589178356714,
           0.5306613226452906,
           0.5318637274549098,
           0.5330661322645291,
           0.5342685370741483,
           0.5354709418837675,
           0.5366733466933868,
           0.5378757515030061,
           0.5390781563126252,
           0.5402805611222445,
           0.5414829659318638,
           0.542685370741483,
           0.5438877755511022,
           0.5450901803607215,
           0.5462925851703407,
           0.5474949899799599,
           0.5486973947895792,
           0.5498997995991984,
           0.5511022044088176,
           0.5523046092184369,
           0.5535070140280562,
           0.5547094188376753,
           0.5559118236472946,
           0.5571142284569139,
           0.5583166332665331,
           0.5595190380761523,
           0.5607214428857716,
           0.5619238476953908,
           0.56312625250501,
           0.5643286573146293,
           0.5655310621242486,
           0.5667334669338677,
           0.567935871743487,
           0.5691382765531063,
           0.5703406813627255,
           0.5715430861723447,
           0.572745490981964,
           0.5739478957915832,
           0.5751503006012024,
           0.5763527054108217,
           0.5775551102204409,
           0.5787575150300601,
           0.5799599198396794,
           0.5811623246492987,
           0.5823647294589178,
           0.5835671342685371,
           0.5847695390781564,
           0.5859719438877756,
           0.5871743486973948,
           0.5883767535070141,
           0.5895791583166333,
           0.5907815631262525,
           0.5919839679358718,
           0.593186372745491,
           0.5943887775551102,
           0.5955911823647295,
           0.5967935871743488,
           0.597995991983968,
           0.5991983967935872,
           0.6004008016032065,
           0.6016032064128257,
           0.6028056112224449,
           0.6040080160320642,
           0.6052104208416834,
           0.6064128256513026,
           0.6076152304609219,
           0.6088176352705412,
           0.6100200400801603,
           0.6112224448897796,
           0.6124248496993989,
           0.6136272545090181,
           0.6148296593186373,
           0.6160320641282566,
           0.6172344689378758,
           0.618436873747495,
           0.6196392785571143,
           0.6208416833667335,
           0.6220440881763527,
           0.623246492985972,
           0.6244488977955913,
           0.6256513026052105,
           0.6268537074148297,
           0.628056112224449,
           0.6292585170340682,
           0.6304609218436874,
           0.6316633266533067,
           0.6328657314629259,
           0.6340681362725451,
           0.6352705410821644,
           0.6364729458917837,
           0.6376753507014028,
           0.6388777555110221,
           0.6400801603206414,
           0.6412825651302606,
           0.6424849699398798,
           0.6436873747494991,
           0.6448897795591183,
           0.6460921843687375,
           0.6472945891783568,
           0.648496993987976,
           0.6496993987975952,
           0.6509018036072145,
           0.6521042084168338,
           0.653306613226453,
           0.6545090180360722,
           0.6557114228456915,
           0.6569138276553107,
           0.6581162324649299,
           0.6593186372745492,
           0.6605210420841684,
           0.6617234468937876,
           0.6629258517034069,
           0.6641282565130262,
           0.6653306613226453,
           0.6665330661322646,
           0.6677354709418839,
           0.6689378757515031,
           0.6701402805611223,
           0.6713426853707416,
           0.6725450901803608,
           0.67374749498998,
           0.6749498997995993,
           0.6761523046092185,
           0.6773547094188377,
           0.678557114228457,
           0.6797595190380763,
           0.6809619238476954,
           0.6821643286573147,
           0.683366733466934,
           0.6845691382765532,
           0.6857715430861724,
           0.6869739478957917,
           0.6881763527054109,
           0.6893787575150301,
           0.6905811623246494,
           0.6917835671342687,
           0.6929859719438878,
           0.6941883767535071,
           0.6953907815631264,
           0.6965931863727456,
           0.6977955911823648,
           0.6989979959919841,
           0.7002004008016032,
           0.7014028056112225,
           0.7026052104208418,
           0.7038076152304611,
           0.7050100200400802,
           0.7062124248496995,
           0.7074148296593188,
           0.7086172344689379,
           0.7098196392785572,
           0.7110220440881765,
           0.7122244488977956,
           0.7134268537074149,
           0.7146292585170342,
           0.7158316633266535,
           0.7170340681362726,
           0.7182364729458919,
           0.7194388777555112,
           0.7206412825651303,
           0.7218436873747496,
           0.7230460921843689,
           0.724248496993988,
           0.7254509018036073,
           0.7266533066132266,
           0.7278557114228457,
           0.729058116232465,
           0.7302605210420843,
           0.7314629258517036,
           0.7326653306613227,
           0.733867735470942,
           0.7350701402805613,
           0.7362725450901804,
           0.7374749498997997,
           0.738677354709419,
           0.7398797595190381,
           0.7410821643286574,
           0.7422845691382767,
           0.743486973947896,
           0.7446893787575151,
           0.7458917835671344,
           0.7470941883767537,
           0.7482965931863728,
           0.7494989979959921,
           0.7507014028056114,
           0.7519038076152305,
           0.7531062124248498,
           0.7543086172344691,
           0.7555110220440882,
           0.7567134268537075,
           0.7579158316633268,
           0.7591182364729461,
           0.7603206412825652,
           0.7615230460921845,
           0.7627254509018038,
           0.7639278557114229,
           0.7651302605210422,
           0.7663326653306615,
           0.7675350701402806,
           0.7687374749498999,
           0.7699398797595192,
           0.7711422845691385,
           0.7723446893787576,
           0.7735470941883769,
           0.7747494989979962,
           0.7759519038076153,
           0.7771543086172346,
           0.7783567134268539,
           0.779559118236473,
           0.7807615230460923,
           0.7819639278557116,
           0.7831663326653306,
           0.78436873747495,
           0.7855711422845693,
           0.7867735470941886,
           0.7879759519038076,
           0.789178356713427,
           0.7903807615230463,
           0.7915831663326653,
           0.7927855711422847,
           0.793987975951904,
           0.795190380761523,
           0.7963927855711423,
           0.7975951903807617,
           0.798797595190381,
           0.8
          ]
         ],
         "y": [
          [
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6,
           -6
          ],
          [
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262,
           -5.953907815631262
          ],
          [
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525,
           -5.907815631262525
          ],
          [
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787,
           -5.861723446893787
          ],
          [
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505,
           -5.81563126252505
          ],
          [
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125,
           -5.7695390781563125
          ],
          [
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755,
           -5.7234468937875755
          ],
          [
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838,
           -5.677354709418838
          ],
          [
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501,
           -5.6312625250501
          ],
          [
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363,
           -5.585170340681363
          ],
          [
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625,
           -5.539078156312625
          ],
          [
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888,
           -5.492985971943888
          ],
          [
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515,
           -5.44689378757515
          ],
          [
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413,
           -5.400801603206413
          ],
          [
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675,
           -5.354709418837675
          ],
          [
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938,
           -5.308617234468938
          ],
          [
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006,
           -5.2625250501002006
          ],
          [
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463,
           -5.216432865731463
          ],
          [
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726,
           -5.170340681362726
          ],
          [
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988,
           -5.124248496993988
          ],
          [
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251,
           -5.078156312625251
          ],
          [
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513,
           -5.032064128256513
          ],
          [
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776,
           -4.985971943887776
          ],
          [
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038,
           -4.939879759519038
          ],
          [
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503,
           -4.8937875751503
          ],
          [
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563,
           -4.847695390781563
          ],
          [
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826,
           -4.801603206412826
          ],
          [
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088,
           -4.755511022044088
          ],
          [
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351,
           -4.709418837675351
          ],
          [
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614,
           -4.663326653306614
          ],
          [
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876,
           -4.617234468937876
          ],
          [
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138,
           -4.571142284569138
          ],
          [
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401,
           -4.525050100200401
          ],
          [
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663,
           -4.478957915831663
          ],
          [
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925,
           -4.432865731462925
          ],
          [
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188,
           -4.386773547094188
          ],
          [
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515,
           -4.3406813627254515
          ],
          [
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714,
           -4.294589178356714
          ],
          [
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976,
           -4.248496993987976
          ],
          [
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239,
           -4.202404809619239
          ],
          [
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501,
           -4.156312625250501
          ],
          [
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763,
           -4.110220440881763
          ],
          [
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026,
           -4.064128256513026
          ],
          [
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289,
           -4.018036072144289
          ],
          [
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513,
           -3.9719438877755513
          ],
          [
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814,
           -3.925851703406814
          ],
          [
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765,
           -3.8797595190380765
          ],
          [
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386,
           -3.8336673346693386
          ],
          [
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601,
           -3.787575150300601
          ],
          [
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864,
           -3.741482965931864
          ],
          [
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264,
           -3.6953907815631264
          ],
          [
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389,
           -3.649298597194389
          ],
          [
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516,
           -3.6032064128256516
          ],
          [
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914,
           -3.557114228456914
          ],
          [
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763,
           -3.5110220440881763
          ],
          [
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439,
           -3.464929859719439
          ],
          [
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015,
           -3.4188376753507015
          ],
          [
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964,
           -3.372745490981964
          ],
          [
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267,
           -3.3266533066132267
          ],
          [
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893,
           -3.2805611222444893
          ],
          [
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752,
           -3.234468937875752
          ],
          [
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014,
           -3.188376753507014
          ],
          [
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766,
           -3.1422845691382766
          ],
          [
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539,
           -3.096192384769539
          ],
          [
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018,
           -3.0501002004008018
          ],
          [
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644,
           -3.0040080160320644
          ],
          [
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327,
           -2.957915831663327
          ],
          [
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895,
           -2.9118236472945895
          ],
          [
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517,
           -2.8657314629258517
          ],
          [
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143,
           -2.8196392785571143
          ],
          [
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377,
           -2.773547094188377
          ],
          [
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395,
           -2.7274549098196395
          ],
          [
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902,
           -2.681362725450902
          ],
          [
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646,
           -2.6352705410821646
          ],
          [
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427,
           -2.589178356713427
          ],
          [
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894,
           -2.5430861723446894
          ],
          [
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952,
           -2.496993987975952
          ],
          [
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145,
           -2.4509018036072145
          ],
          [
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477,
           -2.404809619238477
          ],
          [
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397,
           -2.3587174348697397
          ],
          [
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023,
           -2.3126252505010023
          ],
          [
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265,
           -2.266533066132265
          ],
          [
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527,
           -2.220440881763527
          ],
          [
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896,
           -2.1743486973947896
          ],
          [
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522,
           -2.1282565130260522
          ],
          [
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315,
           -2.082164328657315
          ],
          [
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774,
           -2.0360721442885774
          ],
          [
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396,
           -1.9899799599198396
          ],
          [
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026,
           -1.9438877755511026
          ],
          [
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647,
           -1.8977955911823647
          ],
          [
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278,
           -1.8517034068136278
          ],
          [
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489,
           -1.80561122244489
          ],
          [
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153,
           -1.759519038076153
          ],
          [
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415,
           -1.713426853707415
          ],
          [
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772,
           -1.6673346693386772
          ],
          [
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403,
           -1.6212424849699403
          ],
          [
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024,
           -1.5751503006012024
          ],
          [
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655,
           -1.5290581162324655
          ],
          [
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276,
           -1.4829659318637276
          ],
          [
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906,
           -1.4368737474949906
          ],
          [
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528,
           -1.3907815631262528
          ],
          [
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515,
           -1.344689378757515
          ],
          [
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778,
           -1.298597194388778
          ],
          [
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004,
           -1.25250501002004
          ],
          [
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031,
           -1.2064128256513031
          ],
          [
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653,
           -1.1603206412825653
          ],
          [
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283,
           -1.1142284569138283
          ],
          [
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905,
           -1.0681362725450905
          ],
          [
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526,
           -1.0220440881763526
          ],
          [
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157,
           -0.9759519038076157
          ],
          [
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778,
           -0.9298597194388778
          ],
          [
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408,
           -0.8837675350701408
          ],
          [
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403,
           -0.837675350701403
          ],
          [
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666,
           -0.791583166332666
          ],
          [
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282,
           -0.7454909819639282
          ],
          [
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903,
           -0.6993987975951903
          ],
          [
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533,
           -0.6533066132264533
          ],
          [
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155,
           -0.6072144288577155
          ],
          [
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785,
           -0.5611222444889785
          ],
          [
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407,
           -0.5150300601202407
          ],
          [
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037,
           -0.4689378757515037
          ],
          [
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584,
           -0.42284569138276584
          ],
          [
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028,
           -0.376753507014028
          ],
          [
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291,
           -0.330661322645291
          ],
          [
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317,
           -0.28456913827655317
          ],
          [
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162,
           -0.2384769539078162
          ],
          [
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835,
           -0.19238476953907835
          ],
          [
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138,
           -0.14629258517034138
          ],
          [
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353,
           -0.10020040080160353
          ],
          [
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675,
           -0.054108216432865675
          ],
          [
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709,
           -0.008016032064128709
          ],
          [
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145,
           0.038076152304609145
          ],
          [
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611,
           0.08416833667334611
          ],
          [
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397,
           0.13026052104208397
          ],
          [
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093,
           0.17635270541082093
          ],
          [
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879,
           0.22244488977955879
          ],
          [
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664,
           0.26853707414829664
          ],
          [
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336,
           0.3146292585170336
          ],
          [
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146,
           0.36072144288577146
          ],
          [
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084,
           0.4068136272545084
          ],
          [
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463,
           0.4529058116232463
          ],
          [
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325,
           0.49899799599198325
          ],
          [
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211,
           0.5450901803607211
          ],
          [
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459,
           0.591182364729459
          ],
          [
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959,
           0.6372745490981959
          ],
          [
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338,
           0.6833667334669338
          ],
          [
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707,
           0.7294589178356707
          ],
          [
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086,
           0.7755511022044086
          ],
          [
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456,
           0.8216432865731456
          ],
          [
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834,
           0.8677354709418834
          ],
          [
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213,
           0.9138276553106213
          ],
          [
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582,
           0.9599198396793582
          ],
          [
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096,
           1.006012024048096
          ],
          [
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833,
           1.052104208416833
          ],
          [
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571,
           1.098196392785571
          ],
          [
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079,
           1.1442885771543079
          ],
          [
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457,
           1.1903807615230457
          ],
          [
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836,
           1.2364729458917836
          ],
          [
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205,
           1.2825651302605205
          ],
          [
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584,
           1.3286573146292584
          ],
          [
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954,
           1.3747494989979954
          ],
          [
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332,
           1.4208416833667332
          ],
          [
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702,
           1.4669338677354702
          ],
          [
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208,
           1.513026052104208
          ],
          [
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946,
           1.559118236472946
          ],
          [
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829,
           1.6052104208416829
          ],
          [
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207,
           1.6513026052104207
          ],
          [
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577,
           1.6973947895791577
          ],
          [
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955,
           1.7434869739478955
          ],
          [
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325,
           1.7895791583166325
          ],
          [
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704,
           1.8356713426853704
          ],
          [
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082,
           1.8817635270541082
          ],
          [
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452,
           1.9278557114228452
          ],
          [
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583,
           1.973947895791583
          ],
          [
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321,
           2.020040080160321
          ],
          [
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058,
           2.066132264529058
          ],
          [
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795,
           2.112224448897795
          ],
          [
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532,
           2.158316633266532
          ],
          [
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705,
           2.2044088176352705
          ],
          [
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075,
           2.2505010020040075
          ],
          [
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445,
           2.2965931863727445
          ],
          [
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483,
           2.342685370741483
          ],
          [
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022,
           2.38877755511022
          ],
          [
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957,
           2.434869739478957
          ],
          [
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694,
           2.480961923847694
          ],
          [
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433,
           2.527054108216433
          ],
          [
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517,
           2.57314629258517
          ],
          [
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068,
           2.6192384769539068
          ],
          [
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455,
           2.6653306613226455
          ],
          [
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825,
           2.7114228456913825
          ],
          [
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194,
           2.7575150300601194
          ],
          [
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564,
           2.8036072144288564
          ],
          [
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595,
           2.849699398797595
          ],
          [
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332,
           2.895791583166332
          ],
          [
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069,
           2.941883767535069
          ],
          [
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808,
           2.987975951903808
          ],
          [
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545,
           3.034068136272545
          ],
          [
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818,
           3.0801603206412818
          ],
          [
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187,
           3.1262525050100187
          ],
          [
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575,
           3.1723446893787575
          ],
          [
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944,
           3.2184368737474944
          ],
          [
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314,
           3.2645290581162314
          ],
          [
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497,
           3.31062124248497
          ],
          [
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707,
           3.356713426853707
          ],
          [
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444,
           3.402805611222444
          ],
          [
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181,
           3.448897795591181
          ],
          [
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992,
           3.49498997995992
          ],
          [
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567,
           3.5410821643286567
          ],
          [
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937,
           3.5871743486973937
          ],
          [
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325,
           3.6332665330661325
          ],
          [
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694,
           3.6793587174348694
          ],
          [
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064,
           3.7254509018036064
          ],
          [
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434,
           3.7715430861723434
          ],
          [
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082,
           3.817635270541082
          ],
          [
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819,
           3.863727454909819
          ],
          [
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556,
           3.909819639278556
          ],
          [
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948,
           3.9559118236472948
          ],
          [
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032,
           4.002004008016032
          ],
          [
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769,
           4.048096192384769
          ],
          [
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506,
           4.094188376753506
          ],
          [
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244,
           4.140280561122244
          ],
          [
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981,
           4.186372745490981
          ],
          [
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718,
           4.232464929859718
          ],
          [
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457,
           4.278557114228457
          ],
          [
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194,
           4.324649298597194
          ],
          [
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931,
           4.370741482965931
          ],
          [
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668,
           4.416833667334668
          ],
          [
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407,
           4.462925851703407
          ],
          [
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144,
           4.509018036072144
          ],
          [
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881,
           4.555110220440881
          ],
          [
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619,
           4.601202404809619
          ],
          [
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356,
           4.647294589178356
          ],
          [
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093,
           4.693386773547093
          ],
          [
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583,
           4.73947895791583
          ],
          [
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569,
           4.785571142284569
          ],
          [
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306,
           4.831663326653306
          ],
          [
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043,
           4.877755511022043
          ],
          [
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782,
           4.923847695390782
          ],
          [
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519,
           4.969939879759519
          ],
          [
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256,
           5.016032064128256
          ],
          [
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993,
           5.062124248496993
          ],
          [
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731,
           5.108216432865731
          ],
          [
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468,
           5.154308617234468
          ],
          [
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205,
           5.200400801603205
          ],
          [
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944,
           5.246492985971944
          ],
          [
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681,
           5.292585170340681
          ],
          [
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418,
           5.338677354709418
          ],
          [
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155,
           5.384769539078155
          ],
          [
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894,
           5.430861723446894
          ],
          [
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631,
           5.476953907815631
          ],
          [
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368,
           5.523046092184368
          ],
          [
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106,
           5.569138276553106
          ],
          [
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843,
           5.615230460921843
          ],
          [
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058,
           5.66132264529058
          ],
          [
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317,
           5.707414829659317
          ],
          [
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056,
           5.753507014028056
          ],
          [
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793,
           5.799599198396793
          ],
          [
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553,
           5.84569138276553
          ],
          [
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269,
           5.891783567134269
          ],
          [
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006,
           5.937875751503006
          ],
          [
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743,
           5.983967935871743
          ],
          [
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795,
           6.0300601202404795
          ],
          [
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218,
           6.076152304609218
          ],
          [
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955,
           6.122244488977955
          ],
          [
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692,
           6.168336673346692
          ],
          [
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431,
           6.214428857715431
          ],
          [
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168,
           6.260521042084168
          ],
          [
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905,
           6.306613226452905
          ],
          [
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642,
           6.352705410821642
          ],
          [
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381,
           6.398797595190381
          ],
          [
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118,
           6.444889779559118
          ],
          [
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545,
           6.4909819639278545
          ],
          [
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593,
           6.537074148296593
          ],
          [
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533,
           6.58316633266533
          ],
          [
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067,
           6.629258517034067
          ],
          [
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804,
           6.675350701402804
          ],
          [
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543,
           6.721442885771543
          ],
          [
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028,
           6.76753507014028
          ],
          [
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017,
           6.813627254509017
          ],
          [
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756,
           6.859719438877756
          ],
          [
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493,
           6.905811623246493
          ],
          [
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295,
           6.9519038076152295
          ],
          [
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665,
           6.9979959919839665
          ],
          [
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705,
           7.044088176352705
          ],
          [
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442,
           7.090180360721442
          ],
          [
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179,
           7.136272545090179
          ],
          [
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918,
           7.182364729458918
          ],
          [
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655,
           7.228456913827655
          ],
          [
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392,
           7.274549098196392
          ],
          [
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129,
           7.320641282565129
          ],
          [
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675,
           7.3667334669338675
          ],
          [
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045,
           7.4128256513026045
          ],
          [
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415,
           7.4589178356713415
          ],
          [
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008,
           7.50501002004008
          ],
          [
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817,
           7.551102204408817
          ],
          [
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554,
           7.597194388777554
          ],
          [
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291,
           7.643286573146291
          ],
          [
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503,
           7.68937875751503
          ],
          [
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767,
           7.735470941883767
          ],
          [
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504,
           7.781563126252504
          ],
          [
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425,
           7.8276553106212425
          ],
          [
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795,
           7.8737474949899795
          ],
          [
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165,
           7.9198396793587165
          ],
          [
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453,
           7.965931863727453
          ],
          [
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192,
           8.012024048096192
          ],
          [
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493,
           8.05811623246493
          ],
          [
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666,
           8.104208416833666
          ],
          [
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405,
           8.150300601202405
          ],
          [
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142,
           8.196392785571142
          ],
          [
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879,
           8.242484969939879
          ],
          [
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616,
           8.288577154308616
          ],
          [
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354,
           8.334669338677354
          ],
          [
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091,
           8.380761523046091
          ],
          [
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828,
           8.426853707414828
          ],
          [
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567,
           8.472945891783567
          ],
          [
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304,
           8.519038076152304
          ],
          [
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041,
           8.565130260521041
          ],
          [
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778,
           8.611222444889778
          ],
          [
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517,
           8.657314629258517
          ],
          [
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254,
           8.703406813627254
          ],
          [
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599,
           8.74949899799599
          ],
          [
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473,
           8.79559118236473
          ],
          [
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466,
           8.841683366733466
          ],
          [
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203,
           8.887775551102203
          ],
          [
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094,
           8.93386773547094
          ],
          [
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968,
           8.97995991983968
          ],
          [
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416,
           9.026052104208416
          ],
          [
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153,
           9.072144288577153
          ],
          [
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892,
           9.118236472945892
          ],
          [
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629,
           9.164328657314629
          ],
          [
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366,
           9.210420841683366
          ],
          [
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103,
           9.256513026052103
          ],
          [
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841,
           9.302605210420841
          ],
          [
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578,
           9.348697394789578
          ],
          [
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315,
           9.394789579158315
          ],
          [
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054,
           9.440881763527054
          ],
          [
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791,
           9.486973947895791
          ],
          [
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528,
           9.533066132264528
          ],
          [
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265,
           9.579158316633265
          ],
          [
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004,
           9.625250501002004
          ],
          [
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074,
           9.67134268537074
          ],
          [
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478,
           9.717434869739478
          ],
          [
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216,
           9.763527054108216
          ],
          [
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953,
           9.809619238476953
          ],
          [
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569,
           9.85571142284569
          ],
          [
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427,
           9.901803607214427
          ],
          [
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166,
           9.947895791583166
          ],
          [
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903,
           9.993987975951903
          ],
          [
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642,
           10.040080160320642
          ],
          [
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377,
           10.086172344689377
          ],
          [
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116,
           10.132264529058116
          ],
          [
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854,
           10.178356713426854
          ],
          [
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559,
           10.22444889779559
          ],
          [
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328,
           10.270541082164328
          ],
          [
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064,
           10.316633266533064
          ],
          [
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802,
           10.362725450901802
          ],
          [
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541,
           10.408817635270541
          ],
          [
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276,
           10.454909819639276
          ],
          [
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015,
           10.501002004008015
          ],
          [
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754,
           10.547094188376754
          ],
          [
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489,
           10.593186372745489
          ],
          [
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228,
           10.639278557114228
          ],
          [
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966,
           10.685370741482966
          ],
          [
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702,
           10.731462925851702
          ],
          [
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044,
           10.77755511022044
          ],
          [
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179,
           10.823647294589179
          ],
          [
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914,
           10.869739478957914
          ],
          [
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653,
           10.915831663326653
          ],
          [
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388,
           10.961923847695388
          ],
          [
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127,
           11.008016032064127
          ],
          [
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866,
           11.054108216432866
          ],
          [
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016,
           11.1002004008016
          ],
          [
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034,
           11.14629258517034
          ],
          [
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078,
           11.192384769539078
          ],
          [
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814,
           11.238476953907814
          ],
          [
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552,
           11.284569138276552
          ],
          [
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291,
           11.330661322645291
          ],
          [
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026,
           11.376753507014026
          ],
          [
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765,
           11.422845691382765
          ],
          [
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504,
           11.468937875751504
          ],
          [
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239,
           11.515030060120239
          ],
          [
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978,
           11.561122244488978
          ],
          [
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713,
           11.607214428857713
          ],
          [
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452,
           11.653306613226452
          ],
          [
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519,
           11.69939879759519
          ],
          [
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925,
           11.745490981963925
          ],
          [
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664,
           11.791583166332664
          ],
          [
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403,
           11.837675350701403
          ],
          [
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138,
           11.883767535070138
          ],
          [
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877,
           11.929859719438877
          ],
          [
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616,
           11.975951903807616
          ],
          [
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635,
           12.02204408817635
          ],
          [
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509,
           12.06813627254509
          ],
          [
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828,
           12.114228456913828
          ],
          [
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564,
           12.160320641282564
          ],
          [
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302,
           12.206412825651302
          ],
          [
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037,
           12.252505010020037
          ],
          [
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776,
           12.298597194388776
          ],
          [
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515,
           12.344689378757515
          ],
          [
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625,
           12.39078156312625
          ],
          [
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989,
           12.436873747494989
          ],
          [
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728,
           12.482965931863728
          ],
          [
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463,
           12.529058116232463
          ],
          [
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202,
           12.575150300601202
          ],
          [
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994,
           12.62124248496994
          ],
          [
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675,
           12.667334669338675
          ],
          [
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414,
           12.713426853707414
          ],
          [
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153,
           12.759519038076153
          ],
          [
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888,
           12.805611222444888
          ],
          [
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627,
           12.851703406813627
          ],
          [
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362,
           12.897795591182362
          ],
          [
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511,
           12.9438877755511
          ],
          [
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984,
           12.98997995991984
          ],
          [
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575,
           13.036072144288575
          ],
          [
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313,
           13.082164328657313
          ],
          [
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052,
           13.128256513026052
          ],
          [
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787,
           13.174348697394787
          ],
          [
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526,
           13.220440881763526
          ],
          [
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265,
           13.266533066132265
          ],
          [
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501,
           13.312625250501
          ],
          [
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739,
           13.358717434869739
          ],
          [
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478,
           13.404809619238478
          ],
          [
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213,
           13.450901803607213
          ],
          [
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952,
           13.496993987975952
          ],
          [
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687,
           13.543086172344687
          ],
          [
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425,
           13.589178356713425
          ],
          [
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164,
           13.635270541082164
          ],
          [
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509,
           13.6813627254509
          ],
          [
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638,
           13.727454909819638
          ],
          [
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377,
           13.773547094188377
          ],
          [
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112,
           13.819639278557112
          ],
          [
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585,
           13.86573146292585
          ],
          [
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459,
           13.91182364729459
          ],
          [
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325,
           13.957915831663325
          ],
          [
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063,
           14.004008016032063
          ],
          [
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802,
           14.050100200400802
          ],
          [
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537,
           14.096192384769537
          ],
          [
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276,
           14.142284569138276
          ],
          [
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011,
           14.188376753507011
          ],
          [
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575,
           14.23446893787575
          ],
          [
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489,
           14.280561122244489
          ],
          [
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224,
           14.326653306613224
          ],
          [
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963,
           14.372745490981963
          ],
          [
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701,
           14.418837675350701
          ],
          [
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437,
           14.464929859719437
          ],
          [
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175,
           14.511022044088175
          ],
          [
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914,
           14.557114228456914
          ],
          [
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565,
           14.60320641282565
          ],
          [
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388,
           14.649298597194388
          ],
          [
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127,
           14.695390781563127
          ],
          [
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862,
           14.741482965931862
          ],
          [
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006,
           14.7875751503006
          ],
          [
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336,
           14.833667334669336
          ],
          [
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075,
           14.879759519038075
          ],
          [
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813,
           14.925851703406813
          ],
          [
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549,
           14.971943887775549
          ],
          [
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287,
           15.018036072144287
          ],
          [
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026,
           15.064128256513026
          ],
          [
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761,
           15.110220440881761
          ],
          [
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505,
           15.1563126252505
          ],
          [
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239,
           15.202404809619239
          ],
          [
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974,
           15.248496993987974
          ],
          [
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713,
           15.294589178356713
          ],
          [
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451,
           15.340681362725451
          ],
          [
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187,
           15.386773547094187
          ],
          [
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925,
           15.432865731462925
          ],
          [
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166,
           15.47895791583166
          ],
          [
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004,
           15.5250501002004
          ],
          [
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138,
           15.571142284569138
          ],
          [
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873,
           15.617234468937873
          ],
          [
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612,
           15.663326653306612
          ],
          [
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535,
           15.70941883767535
          ],
          [
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086,
           15.755511022044086
          ],
          [
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825,
           15.801603206412825
          ],
          [
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563,
           15.847695390781563
          ],
          [
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299,
           15.893787575150299
          ],
          [
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037,
           15.939879759519037
          ],
          [
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776,
           15.985971943887776
          ],
          [
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651,
           16.03206412825651
          ],
          [
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525,
           16.07815631262525
          ],
          [
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985,
           16.124248496993985
          ],
          [
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724,
           16.170340681362724
          ],
          [
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463,
           16.216432865731463
          ],
          [
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198,
           16.262525050100198
          ],
          [
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937,
           16.308617234468937
          ],
          [
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675,
           16.354709418837675
          ],
          [
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641,
           16.40080160320641
          ],
          [
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515,
           16.44689378757515
          ],
          [
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888,
           16.492985971943888
          ],
          [
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623,
           16.539078156312623
          ],
          [
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362,
           16.585170340681362
          ],
          [
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501,
           16.6312625250501
          ],
          [
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836,
           16.677354709418836
          ],
          [
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575,
           16.723446893787575
          ],
          [
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631,
           16.76953907815631
          ],
          [
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505,
           16.81563126252505
          ],
          [
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787,
           16.861723446893787
          ],
          [
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523,
           16.907815631262523
          ],
          [
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126,
           16.95390781563126
          ],
          [
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17,
           17
          ]
         ],
         "z": [
          [
           -43.44938758351598,
           -43.49470954332585,
           -43.54003150313571,
           -43.58535346294557,
           -43.63067542275544,
           -43.6759973825653,
           -43.72131934237516,
           -43.76664130218503,
           -43.8119632619949,
           -43.85728522180476,
           -43.90260718161463,
           -43.94792914142449,
           -43.99325110123436,
           -44.03857306104422,
           -44.08389502085408,
           -44.12921698066395,
           -44.17453894047381,
           -44.21986090028368,
           -44.265182860093546,
           -44.3105048199034,
           -44.35582677971327,
           -44.40114873952313,
           -44.44647069933299,
           -44.49179265914287,
           -44.53711461895273,
           -44.5824365787626,
           -44.62775853857246,
           -44.67308049838232,
           -44.71840245819219,
           -44.76372441800205,
           -44.80904637781192,
           -44.85436833762178,
           -44.89969029743164,
           -44.945012257241515,
           -44.99033421705137,
           -45.03565617686124,
           -45.080978136671106,
           -45.12630009648096,
           -45.171622056290836,
           -45.2169440161007,
           -45.262265975910566,
           -45.30758793572042,
           -45.35290989553029,
           -45.39823185534016,
           -45.44355381515002,
           -45.48887577495988,
           -45.53419773476975,
           -45.579519694579616,
           -45.62484165438948,
           -45.67016361419934,
           -45.71548557400921,
           -45.76080753381907,
           -45.80612949362894,
           -45.8514514534388,
           -45.89677341324867,
           -45.94209537305853,
           -45.98741733286839,
           -46.03273929267826,
           -46.07806125248812,
           -46.12338321229799,
           -46.16870517210785,
           -46.21402713191772,
           -46.25934909172758,
           -46.30467105153744,
           -46.34999301134731,
           -46.39531497115718,
           -46.44063693096704,
           -46.48595889077691,
           -46.53128085058677,
           -46.57660281039663,
           -46.6219247702065,
           -46.66724673001636,
           -46.71256868982623,
           -46.75789064963609,
           -46.80321260944596,
           -46.84853456925582,
           -46.89385652906569,
           -46.93917848887555,
           -46.98450044868542,
           -47.02982240849528,
           -47.075144368305146,
           -47.12046632811501,
           -47.16578828792487,
           -47.21111024773474,
           -47.25051121715973,
           -47.28872798850775,
           -47.32694475985577,
           -47.365161531203796,
           -47.403378302551815,
           -47.44159507389984,
           -47.47981184524786,
           -47.51802861659588,
           -47.5562453879439,
           -47.59446215929192,
           -47.63267893063994,
           -47.67089570198796,
           -47.709112473335985,
           -47.74732924468401,
           -47.78554601603203,
           -47.82376278738005,
           -47.861979558728066,
           -47.900196330076085,
           -47.93841310142411,
           -47.976629872772136,
           -48.014846644120155,
           -48.05306341546817,
           -48.09128018681619,
           -48.12949695816421,
           -48.16771372951224,
           -48.20593050086026,
           -48.24414727220828,
           -48.2823640435563,
           -48.32058081490432,
           -48.358797586252344,
           -48.39701435760036,
           -48.43523112894839,
           -48.47344790029641,
           -48.511664671644425,
           -48.54988144299245,
           -48.58809821434047,
           -48.626314985688495,
           -48.664531757036514,
           -48.70274852838453,
           -48.74096529973255,
           -48.77918207108057,
           -48.8173988424286,
           -48.85561561377662,
           -48.89383238512464,
           -48.93204915647266,
           -48.970265927820684,
           -49.0084826991687,
           -49.04669947051673,
           -49.08491624186475,
           -49.123133013212765,
           -49.161349784560784,
           -49.1995665559088,
           -49.23778332725682,
           -49.276000098604854,
           -49.31421686995287,
           -49.35243364130089,
           -49.39065041264891,
           -49.428867183996935,
           -49.467083955344954,
           -49.50530072669297,
           -49.543517498041,
           -49.58173426938902,
           -49.61995104073704,
           -49.65816781208506,
           -49.69638458343308,
           -49.734601354781105,
           -49.772818126129124,
           -49.81103489747715,
           -49.84925166882516,
           -49.88746844017318,
           -49.925685211521206,
           -49.96390198286923,
           -50.00211875421725,
           -50.04033552556527,
           -50.07855229691329,
           -50.11676906826131,
           -50.15498583960933,
           -50.19320261095735,
           -50.23141938230538,
           -50.2696361536534,
           -50.30785292500142,
           -50.34606969634944,
           -50.38428646769746,
           -50.266805550959596,
           -50.071475790178816,
           -49.87614602939802,
           -49.68081626861723,
           -49.48548650783644,
           -49.29015674705564,
           -49.09482698627485,
           -48.89949722549405,
           -48.704167464713265,
           -48.50883770393248,
           -48.31350794315168,
           -48.11817818237089,
           -47.922848421590096,
           -47.7275186608093,
           -47.532188900028515,
           -47.33685913924772,
           -47.14152937846693,
           -46.94619961768613,
           -46.75086985690534,
           -46.55554009612456,
           -46.36021033534376,
           -46.16488057456297,
           -45.969550813782185,
           -45.77422105300138,
           -45.57889129222059,
           -45.383561531439796,
           -45.188231770659,
           -44.992902009878215,
           -44.79757224909741,
           -44.602242488316634,
           -44.40691272753584,
           -44.211582966755046,
           -44.01625320597426,
           -43.82092344519346,
           -43.62559368441267,
           -43.43026392363187,
           -43.234934162851076,
           -43.039604402070296,
           -42.8442746412895,
           -42.64894488050871,
           -42.453615119727914,
           -42.25828535894713,
           -42.06295559816633,
           -41.86762583738554,
           -41.67229607660474,
           -41.476966315823944,
           -41.281636555043164,
           -41.08630679426237,
           -40.890977033481576,
           -40.69564727270078,
           -40.50031751191999,
           -40.3049877511392,
           -40.10965799035841,
           -39.91432822957761,
           -39.71899846879681,
           -39.52366870801603,
           -39.32833894723524,
           -39.133009186454444,
           -38.93767942567365,
           -38.74234966489286,
           -38.54701990411207,
           -38.351690143331275,
           -38.15636038255049,
           -37.96103062176969,
           -37.7657008609889,
           -37.570371100208106,
           -37.37504133942731,
           -37.17971157864652,
           -36.984381817865724,
           -36.789052057084945,
           -36.59372229630414,
           -36.39839253552336,
           -36.20306277474256,
           -36.00773301396176,
           -35.812403253180975,
           -35.61707349240019,
           -35.42174373161939,
           -35.22641397083859,
           -35.03108421005781,
           -34.83575444927702,
           -34.64042468849622,
           -34.445094927715424,
           -34.24976516693463,
           -34.05443540615384,
           -33.85910564537304,
           -33.66377588459226,
           -33.468446123811475,
           -33.27311636303067,
           -33.07778660224989,
           -32.8824568414691,
           -32.6871270806883,
           -32.49179731990749,
           -32.296467559126725,
           -32.101137798345924,
           -31.90580803756512,
           -31.710478276784336,
           -31.51514851600355,
           -31.319818755222748,
           -31.12448899444196,
           -30.929159233661174,
           -30.733829472880373,
           -30.538499712099586,
           -30.343169951318803,
           -30.147840190538,
           -29.952510429757197,
           -29.757180668976424,
           -29.561850908195623,
           -29.366521147414822,
           -29.171191386634035,
           -28.975861625853252,
           -28.780531865072447,
           -28.585202104291664,
           -28.389872343510877,
           -28.194542582730076,
           -27.99921282194927,
           -27.803883061168506,
           -27.6085533003877,
           -27.413223539606896,
           -27.217893778826113,
           -27.02256401804533,
           -26.82723425726452,
           -26.631904496483738,
           -26.436574735702955,
           -26.24124497492215,
           -26.045915214141367,
           -25.85058545336058,
           -25.655255692579775,
           -25.45992593179897,
           -25.264596171018205,
           -25.069266410237404,
           -24.8739366494566,
           -24.678606888675816,
           -24.48327712789503,
           -24.287947367114228,
           -24.09261760633344,
           -23.897287845552658,
           -23.701958084771853,
           -23.506628323991052,
           -23.311298563210283,
           -23.115968802429478,
           -22.920639041648677,
           -22.72530928086789,
           -22.529979520087107,
           -22.334649759306302,
           -22.139319998525515,
           -21.943990237744732,
           -21.748660476963927,
           -21.553330716183144,
           -21.35800095540236,
           -21.162671194621556,
           -20.96734143384075,
           -20.772011673059986,
           -20.57668191227918,
           -20.38135215149838,
           -20.186022390717593,
           -19.99069262993681,
           -19.795362869156,
           -19.600033108375218,
           -19.40470334759443,
           -19.209373586813626,
           -19.01404382603284,
           -18.818714065252056,
           -18.623384304471255,
           -18.42805454369045,
           -18.232724782909667,
           -18.03739502212888,
           -17.890906425283898,
           -17.84210015631052,
           -17.79329388733714,
           -17.744487618363756,
           -17.695681349390377,
           -17.646875080417,
           -17.598068811443618,
           -17.549262542470235,
           -17.50045627349686,
           -17.451650004523476,
           -17.402843735550093,
           -17.354037466576713,
           -17.305231197603334,
           -17.25642492862995,
           -17.20761865965657,
           -17.15881239068319,
           -17.11000612170981,
           -17.06119985273643,
           -17.012393583763053,
           -16.96358731478967,
           -16.914781045816287,
           -16.865974776842908,
           -16.81716850786953,
           -16.768362238896145,
           -16.719555969922766,
           -16.670749700949386,
           -16.621943431976003,
           -16.573137163002627,
           -16.524330894029248,
           -16.475524625055865,
           -16.426718356082482,
           -16.377912087109106,
           -16.329105818135723,
           -16.28029954916234,
           -16.23149328018896,
           -16.182687011215585,
           -16.133880742242198,
           -16.08507447326882,
           -16.03626820429544,
           -15.987461935322056,
           -15.938655666348678,
           -15.8898493973753,
           -15.841043128401916,
           -15.792236859428533,
           -15.743430590455153,
           -15.694624321481776,
           -15.645818052508393,
           -15.597011783535013,
           -15.548205514561634,
           -15.49939924558825,
           -15.450592976614871,
           -15.401786707641492,
           -15.35298043866811,
           -15.304174169694727,
           -15.255367900721353,
           -15.20656163174797,
           -15.157755362774587,
           -15.108949093801208,
           -15.060142824827828,
           -15.011336555854445,
           -14.962530286881066,
           -14.913724017907686,
           -14.864917748934303,
           -14.816111479960925,
           -14.767305210987546,
           -14.718498942014163,
           -14.66969267304078,
           -14.620886404067406,
           -14.572080135094023,
           -14.52327386612064,
           -14.47446759714726,
           -14.42566132817388,
           -14.376855059200498,
           -14.32804879022712,
           -14.27924252125374,
           -14.230436252280358,
           -14.181629983306975,
           -14.1328237143336,
           -14.084017445360217,
           -14.035211176386834,
           -13.986404907413455,
           -13.937598638440075,
           -13.888792369466692,
           -13.828127710174815,
           -13.708171099290421,
           -13.588214488406026,
           -13.468257877521634,
           -13.34830126663726,
           -13.228344655752863,
           -13.108388044868468,
           -12.988431433984097,
           -12.868474823099703,
           -12.748518212215306,
           -12.628561601330933,
           -12.508604990446539,
           -12.388648379562143,
           -12.26869176867775,
           -12.148735157793375,
           -12.028778546908981,
           -11.908821936024585,
           -11.788865325140215,
           -11.668908714255819,
           -11.548952103371423,
           -11.42899549248705,
           -11.309038881602657,
           -11.189082270718261,
           -11.069125659833889,
           -10.949169048949495,
           -10.829212438065099,
           -10.709255827180703,
           -10.58929921629633,
           -10.469342605411935,
           -10.349385994527541,
           -10.229429383643168,
           -10.109472772758773,
           -9.989516161874379,
           -9.869559550990006,
           -9.74960294010561,
           -9.629646329221217,
           -9.509689718336821,
           -9.389733107452448,
           -9.269776496568053,
           -9.149819885683659,
           -9.029863274799286,
           -8.90990666391489,
           -8.81920324208427,
           -8.749394955292065,
           -8.679586668499844,
           -8.609778381707628,
           -8.539970094915422,
           -8.470161808123201,
           -8.400353521330983,
           -8.330545234538764,
           -8.260736947746558,
           -8.19092866095434,
           -8.121120374162121,
           -8.051312087369915,
           -7.981503800577695,
           -7.911695513785476,
           -7.841887226993271,
           -7.772078940201052,
           -7.702270653408833,
           -7.632462366616614,
           -7.562654079824409,
           -7.49284579303219,
           -7.423037506239971,
           -7.353229219447764,
           -7.283420932655546,
           -7.213612645863327,
           -7.143804359071121,
           -7.073996072278902,
           -7.004187785486684,
           -6.934379498694478,
           -6.864571211902258,
           -6.794762925110039,
           -6.72495463831782,
           -6.655146351525614,
           -6.585338064733396,
           -6.515529777941177,
           -6.445721491148971,
           -6.375913204356753,
           -6.306104917564533,
           -6.236296630772328,
           -6.166488343980109,
           -6.096680057187889,
           -6.02687177039567,
           -5.957063483603465
          ],
          [
           -43.14995733427537,
           -43.19527929408523,
           -43.24060125389509,
           -43.28592321370496,
           -43.33124517351483,
           -43.3765671333247,
           -43.42188909313455,
           -43.46721105294442,
           -43.51253301275429,
           -43.55785497256415,
           -43.60317693237401,
           -43.64849889218388,
           -43.69382085199374,
           -43.7391428118036,
           -43.78446477161347,
           -43.82978673142334,
           -43.8751086912332,
           -43.92043065104306,
           -43.96575261085293,
           -44.0110745706628,
           -44.05639653047266,
           -44.10171849028252,
           -44.14704045009239,
           -44.19236240990226,
           -44.23768436971211,
           -44.28300632952198,
           -44.32832828933185,
           -44.373650249141704,
           -44.41897220895157,
           -44.46429416876144,
           -44.50961612857131,
           -44.55493808838118,
           -44.60026004819103,
           -44.6455820080009,
           -44.69090396781076,
           -44.73622592762063,
           -44.78154788743049,
           -44.82686984724035,
           -44.87219180705023,
           -44.91751376686008,
           -44.96283572666995,
           -45.00815768647981,
           -45.05347964628968,
           -45.09880160609954,
           -45.1441235659094,
           -45.18944552571927,
           -45.23476748552913,
           -45.280089445339,
           -45.32541140514887,
           -45.37073336495873,
           -45.4160553247686,
           -45.46137728457846,
           -45.50669924438833,
           -45.55202120419819,
           -45.59734316400805,
           -45.64266512381791,
           -45.68798708362778,
           -45.73330904343765,
           -45.77863100324751,
           -45.82395296305738,
           -45.86927492286725,
           -45.91459688267711,
           -45.959918842486964,
           -46.005240802296825,
           -46.05056276210669,
           -46.09588472191656,
           -46.14120668172642,
           -46.18622433601661,
           -46.23063337971931,
           -46.275042423422,
           -46.3194514671247,
           -46.3638605108274,
           -46.4082695545301,
           -46.4526785982328,
           -46.4970876419355,
           -46.5414966856382,
           -46.5859057293409,
           -46.630314773043594,
           -46.6747238167463,
           -46.719132860449,
           -46.7635419041517,
           -46.8079509478544,
           -46.852359991557094,
           -46.896769035259794,
           -46.93630250332687,
           -46.97486085626683,
           -47.01341920920677,
           -47.05197756214673,
           -47.090535915086676,
           -47.129094268026634,
           -47.16765262096658,
           -47.20621097390653,
           -47.24476932684648,
           -47.28332767978643,
           -47.32188603272638,
           -47.36044438566633,
           -47.39900273860628,
           -47.437561091546236,
           -47.47611944448619,
           -47.51467779742614,
           -47.5531222898918,
           -47.59133906123982,
           -47.62955583258785,
           -47.66777260393587,
           -47.70598937528389,
           -47.74420614663191,
           -47.78242291797993,
           -47.820639689327955,
           -47.85885646067598,
           -47.897073232024,
           -47.93529000337202,
           -47.973506774720036,
           -48.011723546068055,
           -48.04994031741609,
           -48.088157088764106,
           -48.126373860112125,
           -48.16459063146014,
           -48.20280740280816,
           -48.24102417415618,
           -48.2792409455042,
           -48.31745771685223,
           -48.35567448820025,
           -48.39389125954827,
           -48.432108030896295,
           -48.47032480224431,
           -48.50854157359233,
           -48.54675834494035,
           -48.584975116288376,
           -48.623191887636395,
           -48.66140865898441,
           -48.69962543033244,
           -48.737842201680465,
           -48.77605897302848,
           -48.8142757443765,
           -48.85249251572452,
           -48.890709287072546,
           -48.928926058420565,
           -48.96714282976859,
           -49.00535960111661,
           -49.04357637246463,
           -49.08179314381265,
           -49.12000991516067,
           -49.1582266865087,
           -49.19644345785672,
           -49.234660229204735,
           -49.272877000552754,
           -49.31109377190078,
           -49.3493105432488,
           -49.387527314596824,
           -49.42574408594484,
           -49.46396085729286,
           -49.50217762864088,
           -49.540394399988905,
           -49.578611171336924,
           -49.61682794268495,
           -49.65504471403297,
           -49.69326148538099,
           -49.731478256729005,
           -49.769695028077024,
           -49.80791179942505,
           -49.84612857077307,
           -49.884345342121094,
           -49.92256211346911,
           -49.96077888481713,
           -49.99899565616516,
           -50.037212427513175,
           -50.075429198861194,
           -49.96529902691087,
           -49.780995383311385,
           -49.596691739711886,
           -49.4123880961124,
           -49.22808445251292,
           -49.04378080891342,
           -48.859477165313926,
           -48.67517352171443,
           -48.49086987811494,
           -48.30656623451546,
           -48.12226259091596,
           -47.93795894731647,
           -47.753655303716975,
           -47.56935166011748,
           -47.385048016518,
           -47.20074437291851,
           -47.016440729319015,
           -46.83213708571952,
           -46.647833442120024,
           -46.46352979852054,
           -46.27922615492105,
           -46.094922511321556,
           -45.91061886772207,
           -45.726315224122565,
           -45.54201158052309,
           -45.35770793692359,
           -45.1734042933241,
           -44.98910064972461,
           -44.804797006125106,
           -44.62049336252563,
           -44.43618971892613,
           -44.25188607532664,
           -44.06758243172715,
           -43.88327878812766,
           -43.69897514452817,
           -43.51467150092867,
           -43.33036785732918,
           -43.146064213729694,
           -42.9617605701302,
           -42.77745692653071,
           -42.59315328293122,
           -42.408849639331734,
           -42.224545995732235,
           -42.04024235213274,
           -41.855938708533245,
           -41.67163506493376,
           -41.487331421334275,
           -41.303027777734776,
           -41.118724134135284,
           -40.93442049053579,
           -40.7501168469363,
           -40.565813203336816,
           -40.381509559737324,
           -40.19720591613783,
           -40.01290227253833,
           -39.828598628938856,
           -39.634836294620676,
           -39.43950653383988,
           -39.24417677305909,
           -39.0488470122783,
           -38.853517251497514,
           -38.65818749071671,
           -38.462857729935926,
           -38.26752796915513,
           -38.07219820837434,
           -37.87686844759355,
           -37.68153868681276,
           -37.48620892603196,
           -37.29087916525116,
           -37.09554940447038,
           -36.90021964368959,
           -36.70488988290879,
           -36.509560122128,
           -36.31423036134721,
           -36.11890060056642,
           -35.92357083978563,
           -35.72824107900483,
           -35.53291131822404,
           -35.337581557443244,
           -35.14225179666246,
           -34.94692203588166,
           -34.75159227510087,
           -34.55626251432007,
           -34.360932753539295,
           -34.165602992758494,
           -33.9702732319777,
           -33.77494347119692,
           -33.57961371041611,
           -33.384283949635325,
           -33.188954188854545,
           -32.993624428073744,
           -32.798294667292936,
           -32.60296490651217,
           -32.40763514573137,
           -32.21230538495057,
           -32.016975624169774,
           -31.821645863388994,
           -31.626316102608193,
           -31.4309863418274,
           -31.23565658104662,
           -31.04032682026582,
           -30.844997059485024,
           -30.649667298704248,
           -30.454337537923447,
           -30.259007777142642,
           -30.063678016361873,
           -29.86834825558107,
           -29.673018494800267,
           -29.477688734019477,
           -29.282358973238697,
           -29.087029212457896,
           -28.891699451677106,
           -28.696369690896322,
           -28.50103993011552,
           -28.305710169334716,
           -28.11038040855395,
           -27.915050647773146,
           -27.71972088699234,
           -27.524391126211555,
           -27.329061365430775,
           -27.13373160464997,
           -26.93840184386918,
           -26.7430720830884,
           -26.5477423223076,
           -26.352412561526805,
           -26.157082800746025,
           -25.961753039965224,
           -25.76642327918442,
           -25.57109351840365,
           -25.37576375762285,
           -25.180433996842048,
           -24.985104236061254,
           -24.789774475280474,
           -24.594444714499673,
           -24.39911495371888,
           -24.2037851929381,
           -24.008455432157298,
           -23.813125671376497,
           -23.617795910595728,
           -23.422466149814923,
           -23.227136389034122,
           -23.03180662825333,
           -22.83647686747255,
           -22.641147106691747,
           -22.44581734591096,
           -22.250487585130177,
           -22.055157824349376,
           -21.85982806356858,
           -21.6644983027878,
           -21.469168542006997,
           -21.273838781226196,
           -21.07850902044543,
           -20.883179259664626,
           -20.68784949888382,
           -20.492519738103034,
           -20.29718997732225,
           -20.10186021654144,
           -19.90653045576066,
           -19.711200694979873,
           -19.51587093419907,
           -19.320541173418288,
           -19.125211412637494,
           -18.929881651856693,
           -18.734551891075892,
           -18.53922213029511,
           -18.34389236951432,
           -18.196501205021363,
           -18.14498723310406,
           -18.093473261186755,
           -18.04195928926945,
           -17.990445317352144,
           -17.938931345434842,
           -17.887417373517533,
           -17.835903401600227,
           -17.784389429682925,
           -17.732875457765616,
           -17.681361485848306,
           -17.629847513931004,
           -17.578333542013702,
           -17.526819570096393,
           -17.47530559817909,
           -17.42379162626179,
           -17.37227765434448,
           -17.320763682427174,
           -17.269249710509868,
           -17.217735738592562,
           -17.166221766675253,
           -17.114707794757948,
           -17.063193822840645,
           -17.011679850923336,
           -16.960165879006034,
           -16.90865190708873,
           -16.85713793517142,
           -16.805623963254117,
           -16.75410999133681,
           -16.70297787417244,
           -16.654171605199053,
           -16.60536533622568,
           -16.556559067252294,
           -16.507752798278915,
           -16.458946529305535,
           -16.410140260332156,
           -16.361333991358773,
           -16.312527722385394,
           -16.263721453412014,
           -16.21491518443863,
           -16.166108915465255,
           -16.117302646491876,
           -16.068496377518493,
           -16.01969010854511,
           -15.97088383957173,
           -15.92207757059835,
           -15.873271301624968,
           -15.824465032651588,
           -15.775658763678209,
           -15.726852494704827,
           -15.678046225731446,
           -15.62923995675807,
           -15.580433687784687,
           -15.531627418811304,
           -15.482821149837928,
           -15.434014880864545,
           -15.385208611891162,
           -15.336402342917783,
           -15.287596073944403,
           -15.23878980497102,
           -15.18998353599764,
           -15.141177267024263,
           -15.09237099805088,
           -15.043564729077499,
           -14.994758460104123,
           -14.94595219113074,
           -14.897145922157357,
           -14.84833965318398,
           -14.799533384210598,
           -14.750727115237215,
           -14.701920846263835,
           -14.653114577290456,
           -14.604308308317073,
           -14.555502039343693,
           -14.506695770370317,
           -14.457889501396933,
           -14.40908323242355,
           -14.360276963450175,
           -14.311470694476789,
           -14.262664425503406,
           -14.213858156530028,
           -14.165051887556649,
           -14.116245618583266,
           -14.05440326761762,
           -13.927380506690582,
           -13.800357745763545,
           -13.673334984836512,
           -13.546312223909496,
           -13.41928946298246,
           -13.292266702055425,
           -13.165243941128413,
           -13.038221180201376,
           -12.91119841927434,
           -12.784175658347326,
           -12.657152897420291,
           -12.530130136493256,
           -12.403107375566218,
           -12.276084614639206,
           -12.149818943497017,
           -12.029862332612622,
           -11.909905721728247,
           -11.789949110843853,
           -11.66999249995946,
           -11.550035889075085,
           -11.43007927819069,
           -11.310122667306295,
           -11.190166056421921,
           -11.070209445537529,
           -10.950252834653133,
           -10.830296223768737,
           -10.710339612884365,
           -10.590383001999971,
           -10.470426391115573,
           -10.350469780231201,
           -10.230513169346807,
           -10.110556558462411,
           -9.99059994757804,
           -9.870643336693647,
           -9.75068672580925,
           -9.630730114924855,
           -9.510773504040483,
           -9.390816893156087,
           -9.270860282271693,
           -9.150903671387319,
           -9.030947060502925,
           -8.940243638672305,
           -8.870435351880099,
           -8.800627065087879,
           -8.73081877829566,
           -8.661010491503454,
           -8.591202204711236,
           -8.521393917919017,
           -8.451585631126799,
           -8.381777344334592,
           -8.311969057542374,
           -8.242160770750154,
           -8.17235248395795,
           -8.102544197165729,
           -8.03273591037351,
           -7.962927623581305,
           -7.893119336789086,
           -7.823311049996867,
           -7.753502763204649,
           -7.683694476412443,
           -7.6138861896202235,
           -7.544077902828004,
           -7.474269616035798,
           -7.4044613292435795,
           -7.334653042451361,
           -7.264844755659155,
           -7.195036468866936,
           -7.124927463175744,
           -7.050067071491204,
           -6.97520667980665,
           -6.900346288122096,
           -6.825485896437542,
           -6.7506255047530015,
           -6.675765113068448,
           -6.600904721383893,
           -6.526044329699355,
           -6.4511839380147995,
           -6.376323546330246,
           -6.301463154645706,
           -6.226602762961152,
           -6.1517423712765975,
           -6.076881979592043,
           -6.002021587907503
          ],
          [
           -42.85052708503476,
           -42.895849044844624,
           -42.94117100465449,
           -42.98649296446436,
           -43.03181492427422,
           -43.077136884084084,
           -43.12245884389395,
           -43.16778080370381,
           -43.213102763513675,
           -43.25842472332354,
           -43.30374668313341,
           -43.34906864294327,
           -43.394390602753134,
           -43.439712562563,
           -43.48503452237287,
           -43.53035648218274,
           -43.57567844199259,
           -43.62100040180246,
           -43.66632236161233,
           -43.71164432142219,
           -43.75696628123205,
           -43.80228824104192,
           -43.84761020085178,
           -43.892932160661644,
           -43.93825412047151,
           -43.98357608028138,
           -44.02889804009124,
           -44.0742199999011,
           -44.11954195971097,
           -44.16486391952083,
           -44.2101858793307,
           -44.25550783914057,
           -44.300829798950424,
           -44.34615175876029,
           -44.391473718570154,
           -44.43679567838002,
           -44.48211763818989,
           -44.52743959799975,
           -44.57276155780963,
           -44.61808351761948,
           -44.66340547742935,
           -44.70872743723921,
           -44.75404939704907,
           -44.799371356858934,
           -44.844693316668796,
           -44.890015276478664,
           -44.93533723628853,
           -44.9806591960984,
           -45.02598115590826,
           -45.07130311571813,
           -45.11662507552799,
           -45.16118627161396,
           -45.20559531531666,
           -45.25000435901936,
           -45.29441340272205,
           -45.33882244642475,
           -45.38323149012746,
           -45.42764053383016,
           -45.47204957753285,
           -45.51645862123556,
           -45.56086766493825,
           -45.60527670864095,
           -45.64968575234365,
           -45.69409479604634,
           -45.73850383974905,
           -45.78291288345175,
           -45.82732192715444,
           -45.87173097085715,
           -45.91614001455984,
           -45.960549058262544,
           -46.004958101965244,
           -46.049367145667944,
           -46.093776189370644,
           -46.138185233073344,
           -46.182594276776044,
           -46.22700332047875,
           -46.271412364181444,
           -46.315821407884144,
           -46.360230451586844,
           -46.404639495289544,
           -46.449048538992244,
           -46.493457582694944,
           -46.537866626397644,
           -46.582275670100344,
           -46.621809138167414,
           -46.660367491107365,
           -46.69892584404732,
           -46.73748419698727,
           -46.776042549927226,
           -46.81460090286717,
           -46.853159255807114,
           -46.89171760874707,
           -46.93027596168702,
           -46.968834314626974,
           -47.007392667566926,
           -47.04595102050687,
           -47.08450937344683,
           -47.12306772638678,
           -47.16162607932673,
           -47.20018443226668,
           -47.238742785206625,
           -47.277301138146576,
           -47.31585949108653,
           -47.35441784402648,
           -47.39297619696643,
           -47.43153454990638,
           -47.47009290284633,
           -47.50865125578628,
           -47.547209608726234,
           -47.585767961666185,
           -47.62432631460614,
           -47.66288466754609,
           -47.70144302048604,
           -47.74000137342599,
           -47.77855972636594,
           -47.817118079305885,
           -47.85567643224584,
           -47.893950133971906,
           -47.932166905319924,
           -47.97038367666794,
           -48.00860044801597,
           -48.04681721936399,
           -48.085033990712006,
           -48.12325076206003,
           -48.16146753340805,
           -48.199684304756076,
           -48.237901076104094,
           -48.27611784745211,
           -48.31433461880013,
           -48.35255139014815,
           -48.390768161496176,
           -48.4289849328442,
           -48.46720170419222,
           -48.505418475540246,
           -48.543635246888265,
           -48.58185201823628,
           -48.6200687895843,
           -48.65828556093232,
           -48.696502332280346,
           -48.73471910362837,
           -48.77293587497639,
           -48.81115264632441,
           -48.849369417672435,
           -48.88758618902045,
           -48.92580296036847,
           -48.96401973171649,
           -49.002236503064516,
           -49.04045327441254,
           -49.07867004576056,
           -49.11688681710858,
           -49.1551035884566,
           -49.193320359804616,
           -49.23153713115265,
           -49.26975390250067,
           -49.307970673848686,
           -49.346187445196705,
           -49.38440421654472,
           -49.42262098789275,
           -49.46083775924077,
           -49.499054530588786,
           -49.53727130193681,
           -49.57548807328483,
           -49.61370484463285,
           -49.65192161598087,
           -49.6901383873289,
           -49.72835515867692,
           -49.76657193002494,
           -49.65644175807461,
           -49.47213811447513,
           -49.28783447087563,
           -49.103530827276145,
           -48.919227183676654,
           -48.73492354007715,
           -48.55061989647767,
           -48.36631625287817,
           -48.18201260927869,
           -47.997708965679195,
           -47.81340532207969,
           -47.62910167848021,
           -47.44479803488071,
           -47.26049439128123,
           -47.07619074768175,
           -46.891887104082244,
           -46.70758346048275,
           -46.52327981688326,
           -46.33897617328377,
           -46.15467252968429,
           -45.970368886084785,
           -45.78606524248529,
           -45.601761598885815,
           -45.41745795528631,
           -45.233154311686825,
           -45.048850668087326,
           -44.86454702448784,
           -44.680243380888356,
           -44.49593973728885,
           -44.31163609368937,
           -44.12733245008987,
           -43.94302880649039,
           -43.7587251628909,
           -43.574421519291406,
           -43.390117875691914,
           -43.20581423209241,
           -43.02151058849293,
           -42.83720694489344,
           -42.65290330129395,
           -42.468599657694455,
           -42.28429601409496,
           -42.09999237049547,
           -41.91568872689598,
           -41.73138508329649,
           -41.547081439696996,
           -41.362777796097504,
           -41.17847415249801,
           -40.99417050889852,
           -40.80986686529903,
           -40.62556322169954,
           -40.441259578100045,
           -40.25695593450055,
           -40.07265229090106,
           -39.88834864730157,
           -39.70404500370207,
           -39.5197413601026,
           -39.335437716503094,
           -39.1511340729036,
           -38.96683042930411,
           -38.78252678570462,
           -38.598223142105134,
           -38.413919498505635,
           -38.22961585490615,
           -38.04531221130665,
           -37.86100856770717,
           -37.676704924107675,
           -37.49240128050818,
           -37.308097636908684,
           -37.1237939933092,
           -36.93949034970971,
           -36.755186706110216,
           -36.57088306251073,
           -36.38657941891124,
           -36.20227577531174,
           -36.017972131712256,
           -35.833668488112764,
           -35.649364844513265,
           -35.46506120091377,
           -35.28075755731429,
           -35.0964539137148,
           -34.912150270115305,
           -34.727846626515806,
           -34.54354298291632,
           -34.35923933931683,
           -34.17493569571733,
           -33.990632052117846,
           -33.80632840851836,
           -33.62202476491886,
           -33.43772112131937,
           -33.253417477719886,
           -33.06911383412039,
           -32.88481019052089,
           -32.70050654692142,
           -32.51620290332191,
           -32.33189925972241,
           -32.14759561612293,
           -31.963291972523443,
           -31.778988328923944,
           -31.59468468532446,
           -31.410381041724975,
           -31.226077398125472,
           -31.041773754525984,
           -30.8574701109265,
           -30.673166467327,
           -30.488862823727494,
           -30.30455918012803,
           -30.12025553652853,
           -29.935951892929026,
           -29.75164824932954,
           -29.567344605730057,
           -29.383040962130554,
           -29.198196799062544,
           -29.002867038281757,
           -28.807537277500955,
           -28.61220751672015,
           -28.416877755939385,
           -28.22154799515858,
           -28.02621823437778,
           -27.830888473596993,
           -27.635558712816206,
           -27.440228952035405,
           -27.244899191254618,
           -27.049569430473834,
           -26.85423966969303,
           -26.658909908912243,
           -26.463580148131463,
           -26.268250387350655,
           -26.072920626569854,
           -25.877590865789088,
           -25.68226110500828,
           -25.48693134422748,
           -25.291601583446695,
           -25.096271822665912,
           -24.900942061885104,
           -24.70561230110432,
           -24.510282540323537,
           -24.314952779542732,
           -24.119623018761928,
           -23.924293257981162,
           -23.728963497200358,
           -23.533633736419556,
           -23.338303975638773,
           -23.142974214857986,
           -22.947644454077185,
           -22.752314693296398,
           -22.55698493251561,
           -22.361655171734807,
           -22.166325410954023,
           -21.97099565017324,
           -21.775665889392435,
           -21.580336128611634,
           -21.385006367830865,
           -21.18967660705006,
           -20.994346846269256,
           -20.799017085488472,
           -20.60368732470769,
           -20.40835756392688,
           -20.213027803146097,
           -20.017698042365314,
           -19.82236828158451,
           -19.627038520803723,
           -19.431708760022936,
           -19.236378999242135,
           -19.04104923846133,
           -18.845719477680547,
           -18.65038971689976,
           -18.5029985524068,
           -18.4514845804895,
           -18.399970608572193,
           -18.348456636654888,
           -18.296942664737582,
           -18.24542869282028,
           -18.19391472090297,
           -18.14240074898566,
           -18.090886777068363,
           -18.039372805151054,
           -17.987858833233744,
           -17.936344861316442,
           -17.88483088939914,
           -17.83331691748183,
           -17.78180294556453,
           -17.730288973647223,
           -17.678775001729917,
           -17.62726102981261,
           -17.575747057895306,
           -17.524233085978,
           -17.47271911406069,
           -17.421205142143386,
           -17.369691170226083,
           -17.318177198308774,
           -17.266663226391472,
           -17.215149254474166,
           -17.16363528255686,
           -17.112121310639555,
           -17.06060733872225,
           -17.00909336680494,
           -16.957579394887635,
           -16.906065422970336,
           -16.854551451053027,
           -16.803037479135718,
           -16.751523507218415,
           -16.700009535301113,
           -16.648495563383804,
           -16.5969815914665,
           -16.545467619549196,
           -16.493953647631884,
           -16.44243967571458,
           -16.39092570379728,
           -16.33941173187997,
           -16.28789775996266,
           -16.23638378804536,
           -16.184869816128053,
           -16.133355844210747,
           -16.08184187229344,
           -16.030327900376136,
           -15.978813928458829,
           -15.927299956541525,
           -15.875785984624223,
           -15.824272012706912,
           -15.772758040789604,
           -15.721244068872306,
           -15.669730096954996,
           -15.618216125037687,
           -15.566702153120385,
           -15.515188181203083,
           -15.46624305408759,
           -15.417436785114212,
           -15.368630516140833,
           -15.31982424716745,
           -15.27101797819407,
           -15.22221170922069,
           -15.173405440247308,
           -15.124599171273923,
           -15.07579290230055,
           -15.026986633327168,
           -14.978180364353785,
           -14.929374095380405,
           -14.880567826407027,
           -14.831761557433644,
           -14.782955288460265,
           -14.734149019486885,
           -14.685342750513502,
           -14.636536481540118,
           -14.587730212566745,
           -14.538923943593362,
           -14.49011767461998,
           -14.441311405646598,
           -14.39250513667322,
           -14.343698867699837,
           -14.281856516734187,
           -14.154833755807152,
           -14.027810994880115,
           -13.90078823395308,
           -13.773765473026069,
           -13.64674271209903,
           -13.519719951171995,
           -13.392697190244984,
           -13.265674429317947,
           -13.13865166839091,
           -13.011628907463898,
           -12.884606146536862,
           -12.757583385609827,
           -12.630560624682788,
           -12.503537863755778,
           -12.37651510282874,
           -12.249492341901707,
           -12.122469580974693,
           -11.995446820047658,
           -11.868424059120622,
           -11.741401298193608,
           -11.614378537266573,
           -11.487355776339536,
           -11.360333015412523,
           -11.233310254485488,
           -11.106287493558451,
           -10.979264732631416,
           -10.852241971704403,
           -10.725219210777368,
           -10.598196449850331,
           -10.471510176819233,
           -10.351553565934838,
           -10.231596955050444,
           -10.111640344166071,
           -9.991683733281675,
           -9.871727122397282,
           -9.751770511512886,
           -9.631813900628513,
           -9.511857289744118,
           -9.391900678859724,
           -9.271944067975351,
           -9.151987457090955,
           -9.061284035260336,
           -8.99147574846813,
           -8.92166746167591,
           -8.851859174883693,
           -8.782050888091486,
           -8.712242601299266,
           -8.642434314507048,
           -8.57262602771483,
           -8.502817740922623,
           -8.433009454130403,
           -8.363201167338184,
           -8.292791442748037,
           -8.217931051063482,
           -8.14307065937893,
           -8.06821026769439,
           -7.993349876009835,
           -7.918489484325281,
           -7.843629092640727,
           -7.768768700956187,
           -7.693908309271634,
           -7.619047917587079,
           -7.544187525902539,
           -7.469327134217984,
           -7.39446674253343,
           -7.31960635084889,
           -7.2447459591643355,
           -7.169885567479782,
           -7.095025175795242,
           -7.020164784110689,
           -6.945304392426133,
           -6.870444000741579,
           -6.795583609057039,
           -6.720723217372486,
           -6.6458628256879315,
           -6.5710024340033915,
           -6.496142042318837,
           -6.421281650634283,
           -6.346421258949743,
           -6.271560867265189,
           -6.196700475580635,
           -6.12184008389608,
           -6.04697969221154
          ],
          [
           -42.551096835794155,
           -42.59641879560401,
           -42.64174075541388,
           -42.687062715223746,
           -42.73238467503361,
           -42.777706634843476,
           -42.82302859465334,
           -42.8683505544632,
           -42.91367251427307,
           -42.958994474082935,
           -43.0043164338928,
           -43.04963839370266,
           -43.09496035351252,
           -43.14028231332239,
           -43.185604273132256,
           -43.230926232942124,
           -43.276248192751986,
           -43.321570152561854,
           -43.366892112371715,
           -43.41221407218158,
           -43.45753603199144,
           -43.50285799180131,
           -43.54817995161116,
           -43.593501911421036,
           -43.6388238712309,
           -43.684145831040766,
           -43.729467790850634,
           -43.774789750660496,
           -43.82011171047036,
           -43.86543367028022,
           -43.91075563009009,
           -43.956077589899955,
           -44.00139954970981,
           -44.04672150951968,
           -44.0917391635086,
           -44.13614820721129,
           -44.180557250914,
           -44.2249662946167,
           -44.2693753383194,
           -44.3137843820221,
           -44.35819342572479,
           -44.4026024694275,
           -44.44701151313019,
           -44.49142055683289,
           -44.53582960053559,
           -44.58023864423829,
           -44.62464768794099,
           -44.66905673164369,
           -44.71346577534639,
           -44.75787481904909,
           -44.80228386275179,
           -44.84669290645449,
           -44.89110195015719,
           -44.93551099385989,
           -44.97992003756259,
           -45.02432908126529,
           -45.06873812496799,
           -45.11314716867069,
           -45.15755621237339,
           -45.20196525607609,
           -45.24637429977879,
           -45.290783343481486,
           -45.33519238718419,
           -45.379601430886886,
           -45.424010474589586,
           -45.468419518292286,
           -45.512828561994986,
           -45.557237605697686,
           -45.60164664940038,
           -45.64605569310308,
           -45.69046473680579,
           -45.73487378050848,
           -45.77928282421118,
           -45.82369186791388,
           -45.86810091161659,
           -45.91250995531929,
           -45.95691899902198,
           -46.00132804272468,
           -46.04573708642739,
           -46.09014613013008,
           -46.13455517383279,
           -46.17896421753548,
           -46.22337326123818,
           -46.26778230494088,
           -46.30731577300796,
           -46.3458741259479,
           -46.38443247888785,
           -46.4229908318278,
           -46.461549184767755,
           -46.500107537707706,
           -46.53866589064766,
           -46.57722424358761,
           -46.61578259652755,
           -46.65434094946752,
           -46.69289930240746,
           -46.73145765534741,
           -46.77001600828737,
           -46.808574361227315,
           -46.847132714167266,
           -46.88569106710722,
           -46.92424942004716,
           -46.96280777298712,
           -47.00136612592707,
           -47.03992447886702,
           -47.078482831806966,
           -47.11704118474692,
           -47.15559953768687,
           -47.19415789062681,
           -47.23271624356677,
           -47.27127459650672,
           -47.30983294944667,
           -47.34839130238662,
           -47.386949655326575,
           -47.42550800826652,
           -47.46406636120647,
           -47.50262471414643,
           -47.54118306708638,
           -47.57974142002632,
           -47.61829977296628,
           -47.656858125906226,
           -47.695416478846184,
           -47.73397483178613,
           -47.77253318472607,
           -47.81109153766603,
           -47.84964989060598,
           -47.88820824354593,
           -47.92676659648589,
           -47.965324949425835,
           -48.00388330236578,
           -48.04244165530574,
           -48.081000008245695,
           -48.11955836118564,
           -48.15811671412559,
           -48.19656120670398,
           -48.234777978052,
           -48.27299474940002,
           -48.31121152074804,
           -48.34942829209606,
           -48.38764506344408,
           -48.42586183479211,
           -48.46407860614013,
           -48.502295377488146,
           -48.54051214883617,
           -48.57872892018418,
           -48.61694569153221,
           -48.655162462880234,
           -48.69337923422825,
           -48.73159600557627,
           -48.76981277692429,
           -48.808029548272316,
           -48.846246319620334,
           -48.88446309096836,
           -48.92267986231638,
           -48.960896633664404,
           -48.99911340501242,
           -49.03733017636044,
           -49.07554694770847,
           -49.113763719056486,
           -49.151980490404505,
           -49.19019726175252,
           -49.22841403310055,
           -49.26663080444857,
           -49.304847575796586,
           -49.343064347144605,
           -49.38128111849264,
           -49.419497889840656,
           -49.457714661188675,
           -49.34758448923834,
           -49.16328084563886,
           -48.97897720203937,
           -48.794673558439875,
           -48.61036991484039,
           -48.426066271240884,
           -48.24176262764141,
           -48.05745898404191,
           -47.87315534044242,
           -47.68885169684293,
           -47.504548053243425,
           -47.32024440964395,
           -47.135940766044456,
           -46.95163712244496,
           -46.76733347884548,
           -46.58302983524598,
           -46.39872619164649,
           -46.214422548047,
           -46.030118904447505,
           -45.84581526084802,
           -45.66151161724852,
           -45.47720797364903,
           -45.292904330049545,
           -45.108600686450046,
           -44.92429704285056,
           -44.73999339925107,
           -44.55568975565157,
           -44.37138611205209,
           -44.18708246845259,
           -44.0027788248531,
           -43.8184751812536,
           -43.63417153765412,
           -43.449867894054634,
           -43.265564250455135,
           -43.08126060685565,
           -42.896956963256144,
           -42.71265331965666,
           -42.528349676057175,
           -42.344046032457676,
           -42.15974238885819,
           -41.9754387452587,
           -41.79113510165921,
           -41.606831458059716,
           -41.422527814460224,
           -41.238224170860725,
           -41.05392052726123,
           -40.86961688366175,
           -40.68531324006226,
           -40.501009596462765,
           -40.31670595286327,
           -40.132402309263774,
           -39.9480986656643,
           -39.763795022064805,
           -39.579491378465306,
           -39.39518773486581,
           -39.21088409126633,
           -39.02658044766684,
           -38.84227680406734,
           -38.65797316046785,
           -38.473669516868355,
           -38.28936587326886,
           -38.10506222966937,
           -37.92075858606989,
           -37.73645494247039,
           -37.5521512988709,
           -37.36784765527141,
           -37.18354401167192,
           -36.99924036807242,
           -36.814936724472936,
           -36.63063308087345,
           -36.44632943727395,
           -36.26202579367447,
           -36.07772215007497,
           -35.89341850647547,
           -35.70911486287599,
           -35.5248112192765,
           -35.340507575677,
           -35.1562039320775,
           -34.971900288478025,
           -34.78759664487853,
           -34.603293001279035,
           -34.41898935767954,
           -34.23468571408006,
           -34.050382070480566,
           -33.86607842688107,
           -33.68177478328158,
           -33.49747113968209,
           -33.31316749608259,
           -33.12886385248311,
           -32.94456020888362,
           -32.760256565284124,
           -32.575952921684625,
           -32.39164927808515,
           -32.207345634485655,
           -32.02304199088615,
           -31.838738347286668,
           -31.65443470368718,
           -31.47013106008768,
           -31.285827416488193,
           -31.10152377288871,
           -30.91722012928921,
           -30.73291648568972,
           -30.548612842090236,
           -30.364309198490737,
           -30.18000555489124,
           -29.995701911291768,
           -29.811398267692265,
           -29.627094624092763,
           -29.44279098049328,
           -29.258487336893793,
           -29.074183693294295,
           -28.889880049694806,
           -28.705576406095325,
           -28.521272762495823,
           -28.33696911889632,
           -28.15266547529685,
           -27.96836183169735,
           -27.78405818809785,
           -27.59975454449836,
           -27.41545090089888,
           -27.231147257299376,
           -27.04684361369989,
           -26.862539970100407,
           -26.678236326500905,
           -26.49393268290142,
           -26.309629039301935,
           -26.125325395702433,
           -25.94102175210293,
           -25.756718108503463,
           -25.572414464903964,
           -25.38811082130446,
           -25.203807177704974,
           -25.019503534105493,
           -24.83519989050599,
           -24.650896246906505,
           -24.46659260330702,
           -24.282288959707518,
           -24.097985316108016,
           -23.91368167250855,
           -23.729378028909046,
           -23.545074385309547,
           -23.360770741710063,
           -23.176467098110578,
           -22.992163454511076,
           -22.807859810911587,
           -22.623556167312106,
           -22.439252523712604,
           -22.25494888011312,
           -22.07064523651363,
           -21.88634159291413,
           -21.702037949314633,
           -21.517734305715162,
           -21.33343066211566,
           -21.149127018516158,
           -20.964823374916673,
           -20.780519731317188,
           -20.596216087717686,
           -20.4119124441182,
           -20.227608800518716,
           -20.04330515691921,
           -19.85900151331973,
           -19.674697869720244,
           -19.49039422612074,
           -19.306090582521236,
           -19.121786938921755,
           -18.944420657763136,
           -18.808654369774533,
           -18.756434059976232,
           -18.7048072876067,
           -18.653180515237164,
           -18.60155374286763,
           -18.549926970498095,
           -18.498300198128558,
           -18.44667342575902,
           -18.39504665338949,
           -18.343419881019955,
           -18.291793108650413,
           -18.240166336280883,
           -18.188539563911345,
           -18.136912791541807,
           -18.085286019172276,
           -18.033659246802742,
           -17.982032474433204,
           -17.93040570206367,
           -17.878778929694136,
           -17.827152157324598,
           -17.77552538495506,
           -17.72389861258553,
           -17.67227184021599,
           -17.620645067846457,
           -17.569018295476923,
           -17.51739152310739,
           -17.46576475073785,
           -17.414137978368316,
           -17.36251120599878,
           -17.310884433629248,
           -17.259257661259706,
           -17.20763088889018,
           -17.15600411652064,
           -17.1043773441511,
           -17.052750571781566,
           -17.001123799412035,
           -16.949497027042497,
           -16.897870254672963,
           -16.84624348230343,
           -16.79461670993389,
           -16.742989937564356,
           -16.691363165194822,
           -16.639736392825284,
           -16.58810962045575,
           -16.536482848086216,
           -16.48485607571668,
           -16.433229303347144,
           -16.38160253097761,
           -16.32997575860808,
           -16.27834898623854,
           -16.226722213869003,
           -16.175095441499472,
           -16.123468669129934,
           -16.071841896760397,
           -16.020215124390866,
           -15.96858835202133,
           -15.91696157965179,
           -15.865334807282256,
           -15.813708034912722,
           -15.762081262543186,
           -15.710454490173651,
           -15.658827717804117,
           -15.607200945434581,
           -15.555574173065047,
           -15.503947400695512,
           -15.452320628325976,
           -15.400693855956437,
           -15.349067083586906,
           -15.29744031121737,
           -15.245813538847832,
           -15.194186766478296,
           -15.142559994108764,
           -15.090933221739228,
           -15.039306449369693,
           -14.987679677000159,
           -14.936052904630621,
           -14.884426132261083,
           -14.832799359891554,
           -14.781172587522017,
           -14.729545815152479,
           -14.677919042782944,
           -14.626292270413412,
           -14.574665498043872,
           -14.509312641647519,
           -14.375329365117038,
           -14.241346088586555,
           -14.112881449410155,
           -13.985653432142266,
           -13.858425414874356,
           -13.731197397606444,
           -13.603969380338556,
           -13.476741363070646,
           -13.349513345802734,
           -13.222285328534849,
           -13.095057311266935,
           -12.967829293999023,
           -12.840601276731112,
           -12.713373259463223,
           -12.586145242195313,
           -12.458917224927403,
           -12.331689207659515,
           -12.204461190391603,
           -12.077233173123693,
           -11.950005155855804,
           -11.822777138587895,
           -11.695549121319983,
           -11.568321104052096,
           -11.441093086784184,
           -11.313865069516272,
           -11.186637052248363,
           -11.059409034980474,
           -10.932181017712562,
           -10.804953000444653,
           -10.677724983176763,
           -10.550496965908852,
           -10.423268948640942,
           -10.296040931373055,
           -10.168812914105144,
           -10.041584896837232,
           -9.91435687956932,
           -9.787128862301435,
           -9.659900845033523,
           -9.53267282776561,
           -9.405444810497723,
           -9.278216793229811,
           -9.181431878518502,
           -9.106392037061916,
           -9.031352195605317,
           -8.956312354148714,
           -8.881272512692128,
           -8.806232671235527,
           -8.731192829778927,
           -8.656152988322324,
           -8.581113146865738,
           -8.506073305409137,
           -8.431033463952536,
           -8.355993622495948,
           -8.280953781039347,
           -8.205913939582747,
           -8.13087409812616,
           -8.05583425666956,
           -7.980794415212957,
           -7.905754573756357,
           -7.83071473229977,
           -7.755674890843169,
           -7.6806350493865665,
           -7.605595207929981,
           -7.53055536647338,
           -7.4555155250167795,
           -7.380475683560192,
           -7.3054358421035905,
           -7.23039600064699,
           -7.1553561591904025,
           -7.080316317733802,
           -7.005276476277201,
           -6.9302366348205995,
           -6.855196793364013,
           -6.780156951907412,
           -6.705117110450811,
           -6.630077268994224,
           -6.555037427537623,
           -6.479997586081022,
           -6.404957744624435,
           -6.329917903167834,
           -6.2530268063338985,
           -6.1726935391723226,
           -6.092360272010761
          ],
          [
           -42.25166658655355,
           -42.296988546363416,
           -42.34231050617328,
           -42.38763246598314,
           -42.43295442579301,
           -42.47827638560287,
           -42.523598345412736,
           -42.5689203052226,
           -42.614242265032466,
           -42.65956422484233,
           -42.704886184652196,
           -42.75020814446206,
           -42.795530104271926,
           -42.84085206408179,
           -42.88617402389165,
           -42.93149598370152,
           -42.97681794351138,
           -43.022139903321246,
           -43.06670109910595,
           -43.11111014280864,
           -43.15551918651134,
           -43.19992823021404,
           -43.24433727391674,
           -43.28874631761944,
           -43.33315536132214,
           -43.37756440502484,
           -43.42197344872754,
           -43.466382492430235,
           -43.51079153613294,
           -43.55520057983564,
           -43.59960962353834,
           -43.64401866724104,
           -43.688427710943735,
           -43.73283675464644,
           -43.77724579834914,
           -43.82165484205184,
           -43.866063885754535,
           -43.910472929457235,
           -43.954881973159935,
           -43.999291016862635,
           -44.043700060565335,
           -44.08810910426803,
           -44.13251814797073,
           -44.176927191673435,
           -44.22133623537613,
           -44.26574527907883,
           -44.310154322781536,
           -44.35456336648423,
           -44.39897241018693,
           -44.44338145388963,
           -44.48779049759233,
           -44.53219954129503,
           -44.57660858499773,
           -44.62101762870043,
           -44.66542667240313,
           -44.70983571610583,
           -44.75424475980853,
           -44.79865380351123,
           -44.84306284721392,
           -44.88747189091663,
           -44.93188093461933,
           -44.97628997832203,
           -45.02069902202473,
           -45.06510806572743,
           -45.10951710943013,
           -45.15392615313283,
           -45.19833519683553,
           -45.24274424053823,
           -45.28715328424092,
           -45.33156232794362,
           -45.37597137164632,
           -45.42038041534902,
           -45.46478945905172,
           -45.509198502754415,
           -45.553607546457116,
           -45.59801659015982,
           -45.642425633862516,
           -45.686834677565216,
           -45.73124372126792,
           -45.775652764970616,
           -45.820061808673316,
           -45.864470852376016,
           -45.908879896078716,
           -45.953288939781416,
           -45.99282240784849,
           -46.031380760788444,
           -46.069939113728395,
           -46.10849746666835,
           -46.1470558196083,
           -46.18561417254825,
           -46.2241725254882,
           -46.26273087842815,
           -46.3012892313681,
           -46.33984758430805,
           -46.378405937248004,
           -46.416964290187956,
           -46.4555226431279,
           -46.49408099606785,
           -46.5326393490078,
           -46.57119770194775,
           -46.609756054887704,
           -46.648314407827655,
           -46.68687276076761,
           -46.72543111370756,
           -46.76398946664751,
           -46.80254781958746,
           -46.84110617252741,
           -46.87966452546736,
           -46.918222878407306,
           -46.956781231347264,
           -46.99533958428721,
           -47.03389793722717,
           -47.07245629016711,
           -47.11101464310707,
           -47.14957299604701,
           -47.188131348986964,
           -47.226689701926915,
           -47.265248054866866,
           -47.30380640780682,
           -47.34236476074677,
           -47.38092311368672,
           -47.41948146662667,
           -47.45803981956662,
           -47.49659817250657,
           -47.535156525446524,
           -47.573714878386475,
           -47.61227323132643,
           -47.65083158426637,
           -47.68938993720632,
           -47.72794829014627,
           -47.766506643086224,
           -47.805064996026175,
           -47.843623348966126,
           -47.88218170190608,
           -47.92074005484603,
           -47.95929840778598,
           -47.99785676072593,
           -48.03641511366588,
           -48.07497346660583,
           -48.113531819545784,
           -48.152090172485735,
           -48.190648525425686,
           -48.22920687836564,
           -48.26776523130559,
           -48.30632358424553,
           -48.344881937185484,
           -48.38344029012544,
           -48.421998643065386,
           -48.46055699600534,
           -48.49911534894529,
           -48.53738905078407,
           -48.5756058221321,
           -48.613822593480116,
           -48.652039364828134,
           -48.69025613617616,
           -48.728472907524186,
           -48.766689678872204,
           -48.80490645022022,
           -48.84312322156824,
           -48.88133999291627,
           -48.919556764264286,
           -48.957773535612304,
           -48.99599030696034,
           -49.034207078308356,
           -49.072423849656374,
           -49.11064062100439,
           -49.14885739235241,
           -49.03872722040209,
           -48.8544235768026,
           -48.67011993320311,
           -48.48581628960362,
           -48.301512646004134,
           -48.117209002404635,
           -47.93290535880515,
           -47.74860171520565,
           -47.56429807160616,
           -47.37999442800668,
           -47.19569078440718,
           -47.01138714080769,
           -46.82708349720819,
           -46.6427798536087,
           -46.45847621000921,
           -46.27417256640972,
           -46.08986892281023,
           -45.905565279210734,
           -45.72126163561125,
           -45.53695799201176,
           -45.352654348412266,
           -45.16835070481278,
           -44.98404706121329,
           -44.79974341761378,
           -44.6154397740143,
           -44.43113613041481,
           -44.246832486815315,
           -44.06252884321583,
           -43.87822519961633,
           -43.693921556016846,
           -43.50961791241735,
           -43.32531426881786,
           -43.14101062521838,
           -42.95670698161888,
           -42.77240333801939,
           -42.588099694419896,
           -42.4037960508204,
           -42.21949240722092,
           -42.03518876362142,
           -41.85088512002193,
           -41.666581476422444,
           -41.482277832822945,
           -41.29797418922346,
           -41.11367054562396,
           -40.92936690202446,
           -40.74506325842498,
           -40.56075961482549,
           -40.376455971226,
           -40.1921523276265,
           -40.00784868402702,
           -39.82354504042752,
           -39.639241396828034,
           -39.45493775322855,
           -39.27063410962904,
           -39.08633046602955,
           -38.902026822430074,
           -38.71772317883058,
           -38.53341953523108,
           -38.34911589163159,
           -38.1648122480321,
           -37.98050860443261,
           -37.79620496083312,
           -37.611901317233624,
           -37.42759767363413,
           -37.24329403003465,
           -37.058990386435156,
           -36.874686742835664,
           -36.690383099236165,
           -36.50607945563667,
           -36.32177581203719,
           -36.13747216843769,
           -35.953168524838205,
           -35.76886488123871,
           -35.58456123763922,
           -35.40025759403973,
           -35.215953950440245,
           -35.031650306840746,
           -34.84734666324125,
           -34.66304301964177,
           -34.47873937604227,
           -34.29443573244278,
           -34.11013208884329,
           -33.925828445243795,
           -33.74152480164431,
           -33.56222253471745,
           -33.38550162704772,
           -33.208780719377984,
           -33.03205981170823,
           -32.8553389040385,
           -32.67861799636876,
           -32.50189708869901,
           -32.32517618102926,
           -32.148455273359545,
           -31.97173436568979,
           -31.79501345802004,
           -31.618292550350308,
           -31.44157164268057,
           -31.26485073501082,
           -31.08812982734109,
           -30.911408919671356,
           -30.7346880120016,
           -30.55796710433187,
           -30.381246196662133,
           -30.20452528899238,
           -30.027804381322632,
           -29.851083473652913,
           -29.674362565983166,
           -29.497641658313412,
           -29.320920750643683,
           -29.144199842973947,
           -28.9674789353042,
           -28.790758027634464,
           -28.614037119964728,
           -28.437316212294977,
           -28.260595304625227,
           -28.08387439695551,
           -27.90715348928576,
           -27.730432581616007,
           -27.553711673946275,
           -27.376990766276542,
           -27.200269858606788,
           -27.02354895093706,
           -26.84682804326732,
           -26.670107135597576,
           -26.49338622792784,
           -26.316665320258103,
           -26.139944412588353,
           -25.963223504918602,
           -25.786502597248887,
           -25.609781689579137,
           -25.433060781909386,
           -25.256339874239654,
           -25.079618966569917,
           -24.902898058900167,
           -24.726177151230434,
           -24.5494562435607,
           -24.37273533589095,
           -24.196014428221197,
           -24.01929352055148,
           -23.842572612881728,
           -23.665851705211978,
           -23.489130797542245,
           -23.31240988987251,
           -23.135688982202762,
           -22.95896807453303,
           -22.782247166863293,
           -22.605526259193542,
           -22.428805351523806,
           -22.252084443854073,
           -22.07536353618432,
           -21.898642628514573,
           -21.721921720844854,
           -21.545200813175104,
           -21.368479905505353,
           -21.19175899783562,
           -21.015038090165884,
           -20.838317182496134,
           -20.6615962748264,
           -20.48487536715667,
           -20.308154459486918,
           -20.131433551817185,
           -19.95471264414745,
           -19.7779917364777,
           -19.601270828807948,
           -19.424549921138215,
           -19.24782901346848,
           -19.112062725479873,
           -19.05820567685353,
           -19.004348628227184,
           -18.950491579600833,
           -18.896634530974488,
           -18.842777482348144,
           -18.788920433721795,
           -18.735063385095444,
           -18.681206336469103,
           -18.627349287842755,
           -18.573492239216403,
           -18.51963519059006,
           -18.465778141963714,
           -18.411921093337362,
           -18.358064044711018,
           -18.304206996084673,
           -18.25034994745832,
           -18.196492898831977,
           -18.142635850205632,
           -18.08877880157928,
           -18.034921752952933,
           -17.981064704326588,
           -17.927207655700244,
           -17.873350607073892,
           -17.819493558447547,
           -17.765636509821203,
           -17.71177946119485,
           -17.657922412568507,
           -17.604065363942162,
           -17.55020831531581,
           -17.496351266689462,
           -17.442781996615373,
           -17.391155224245836,
           -17.339528451876298,
           -17.287901679506763,
           -17.23627490713723,
           -17.18464813476769,
           -17.133021362398157,
           -17.081394590028623,
           -17.029767817659085,
           -16.978141045289554,
           -16.92651427292002,
           -16.874887500550482,
           -16.82326072818094,
           -16.77163395581141,
           -16.720007183441876,
           -16.66838041107234,
           -16.616753638702804,
           -16.565126866333273,
           -16.51350009396373,
           -16.4618733215942,
           -16.410246549224667,
           -16.35861977685513,
           -16.30699300448559,
           -16.255366232116064,
           -16.203739459746526,
           -16.152112687376984,
           -16.10048591500745,
           -16.048859142637916,
           -15.997232370268382,
           -15.945605597898847,
           -15.893978825529313,
           -15.842352053159775,
           -15.790725280790241,
           -15.739098508420707,
           -15.687471736051169,
           -15.635844963681633,
           -15.584218191312104,
           -15.532591418942564,
           -15.480964646573026,
           -15.42933787420349,
           -15.377711101833958,
           -15.326084329464422,
           -15.274457557094888,
           -15.222830784725357,
           -15.171204012355817,
           -15.119577239986278,
           -15.06795046761675,
           -15.01632369524721,
           -14.964696922877673,
           -14.91307015050814,
           -14.861443378138606,
           -14.809816605769068,
           -14.744463749372716,
           -14.610480472842234,
           -14.47649719631175,
           -14.342513919781268,
           -14.208530643250809,
           -14.074547366720326,
           -13.940564090189845,
           -13.806580813659387,
           -13.672597537128905,
           -13.538614260598422,
           -13.404630984067964,
           -13.27064770753748,
           -13.136664431006999,
           -13.002681154476518,
           -12.868697877946058,
           -12.734714601415575,
           -12.600731324885093,
           -12.466748048354635,
           -12.334545865436954,
           -12.207317848169044,
           -12.080089830901155,
           -11.952861813633245,
           -11.825633796365334,
           -11.698405779097445,
           -11.571177761829535,
           -11.443949744561625,
           -11.316721727293714,
           -11.189493710025825,
           -11.062265692757915,
           -10.935037675490003,
           -10.807809658222116,
           -10.680581640954204,
           -10.553353623686295,
           -10.426125606418406,
           -10.298897589150496,
           -10.171669571882584,
           -10.044441554614671,
           -9.917213537346784,
           -9.789985520078874,
           -9.662757502810962,
           -9.535529485543075,
           -9.408301468275162,
           -9.311516553563855,
           -9.236476712107267,
           -9.161436870650666,
           -9.086397029194066,
           -9.011357187737477,
           -8.936317346280877,
           -8.861277504824276,
           -8.786237663367675,
           -8.711197821911089,
           -8.636157980454488,
           -8.561118138997887,
           -8.486078297541301,
           -8.411038456084698,
           -8.335998614628098,
           -8.26095877317151,
           -8.185918931714909,
           -8.110879090258308,
           -8.035839248801707,
           -7.960799407345121,
           -7.885759565888521,
           -7.8107197244319195,
           -7.735679882975331,
           -7.660640041518731,
           -7.58560020006213,
           -7.50578036143688,
           -7.425447094275304,
           -7.345113827113728,
           -7.264780559952166,
           -7.1844472927905905,
           -7.1041140256290145,
           -7.023780758467437,
           -6.943447491305876,
           -6.8631142241443,
           -6.782780956982723,
           -6.702447689821162,
           -6.622114422659585,
           -6.541781155498009,
           -6.461447888336448,
           -6.381114621174872,
           -6.300781354013295,
           -6.220448086851719,
           -6.140114819690157
          ],
          [
           -41.95223633731293,
           -41.99725399100058,
           -42.041663034703284,
           -42.086072078405984,
           -42.130481122108684,
           -42.174890165811384,
           -42.219299209514084,
           -42.263708253216784,
           -42.308117296919484,
           -42.352526340622184,
           -42.39693538432488,
           -42.44134442802758,
           -42.48575347173028,
           -42.53016251543298,
           -42.57457155913568,
           -42.61898060283838,
           -42.663389646541084,
           -42.70779869024378,
           -42.75220773394648,
           -42.79661677764918,
           -42.84102582135188,
           -42.88543486505458,
           -42.92984390875728,
           -42.97425295245998,
           -43.01866199616268,
           -43.06307103986538,
           -43.10748008356808,
           -43.15188912727078,
           -43.19629817097348,
           -43.24070721467617,
           -43.28511625837888,
           -43.32952530208158,
           -43.37393434578428,
           -43.41834338948698,
           -43.46275243318968,
           -43.50716147689238,
           -43.55157052059507,
           -43.59597956429778,
           -43.64038860800047,
           -43.68479765170317,
           -43.72920669540588,
           -43.77361573910857,
           -43.81802478281127,
           -43.86243382651397,
           -43.90684287021667,
           -43.951251913919364,
           -43.99566095762207,
           -44.040070001324764,
           -44.084479045027464,
           -44.128888088730164,
           -44.173297132432864,
           -44.217706176135565,
           -44.262115219838265,
           -44.306524263540965,
           -44.350933307243665,
           -44.395342350946365,
           -44.439751394649065,
           -44.484160438351765,
           -44.528569482054465,
           -44.572978525757165,
           -44.617387569459865,
           -44.661796613162565,
           -44.70620565686526,
           -44.750614700567965,
           -44.79502374427066,
           -44.83943278797336,
           -44.88384183167605,
           -44.92825087537876,
           -44.97265991908146,
           -45.01706896278416,
           -45.06147800648685,
           -45.10588705018956,
           -45.15029609389225,
           -45.19470513759495,
           -45.23911418129765,
           -45.28352322500036,
           -45.32793226870305,
           -45.37234131240575,
           -45.41675035610845,
           -45.46115939981115,
           -45.50556844351385,
           -45.54997748721655,
           -45.59438653091925,
           -45.63879557462195,
           -45.67832904268903,
           -45.71688739562898,
           -45.75544574856893,
           -45.79400410150888,
           -45.83256245444883,
           -45.871120807388785,
           -45.909679160328736,
           -45.94823751326868,
           -45.98679586620863,
           -46.02535421914859,
           -46.06391257208853,
           -46.10247092502849,
           -46.14102927796844,
           -46.17958763090839,
           -46.21814598384834,
           -46.25670433678829,
           -46.29526268972824,
           -46.33382104266819,
           -46.37237939560814,
           -46.41093774854809,
           -46.44949610148804,
           -46.488054454427996,
           -46.52661280736795,
           -46.5651711603079,
           -46.60372951324785,
           -46.6422878661878,
           -46.680846219127744,
           -46.7194045720677,
           -46.75796292500765,
           -46.796521277947605,
           -46.835079630887556,
           -46.87363798382751,
           -46.91219633676745,
           -46.95075468970741,
           -46.98931304264735,
           -47.02787139558731,
           -47.066429748527256,
           -47.104988101467214,
           -47.14354645440716,
           -47.18210480734711,
           -47.22066316028706,
           -47.25922151322701,
           -47.29777986616696,
           -47.336338219106906,
           -47.37489657204686,
           -47.41345492498681,
           -47.45201327792676,
           -47.49057163086671,
           -47.52912998380667,
           -47.56768833674661,
           -47.606246689686564,
           -47.644805042626516,
           -47.68336339556646,
           -47.72192174850642,
           -47.76048010144637,
           -47.79903845438632,
           -47.83759680732627,
           -47.876155160266215,
           -47.91471351320617,
           -47.953271866146125,
           -47.991830219086076,
           -48.03038857202603,
           -48.06894692496597,
           -48.10750527790592,
           -48.14606363084587,
           -48.18462198378583,
           -48.223180336725775,
           -48.261738689665734,
           -48.30029704260568,
           -48.33885539554563,
           -48.37741374848558,
           -48.41597210142553,
           -48.45453045436548,
           -48.493088807305426,
           -48.53164716024538,
           -48.57020551318533,
           -48.60876386612529,
           -48.64732221906524,
           -48.68588057200519,
           -48.72443892494514,
           -48.762997277885084,
           -48.80155563082504,
           -48.84000012351615,
           -48.729869951565824,
           -48.54556630796634,
           -48.36126266436685,
           -48.18002441167178,
           -48.00330350400204,
           -47.826582596332294,
           -47.64986168866256,
           -47.47314078099282,
           -47.296419873323075,
           -47.11969896565334,
           -46.942978057983595,
           -46.766257150313855,
           -46.589536242644115,
           -46.41281533497437,
           -46.23609442730463,
           -46.059373519634896,
           -45.88265261196515,
           -45.705931704295416,
           -45.52921079662567,
           -45.35248988895593,
           -45.1757689812862,
           -44.99904807361645,
           -44.82232716594671,
           -44.64560625827696,
           -44.46888535060723,
           -44.292164442937484,
           -44.11544353526775,
           -43.93872262759801,
           -43.762001719928264,
           -43.585280812258524,
           -43.408559904588785,
           -43.23183899691904,
           -43.05511808924931,
           -42.878397181579565,
           -42.701676273909825,
           -42.52495536624008,
           -42.34823445857034,
           -42.171513550900606,
           -41.994792643230866,
           -41.818071735561126,
           -41.641350827891394,
           -41.46462992022165,
           -41.28790901255191,
           -41.11118810488217,
           -40.93446719721242,
           -40.75774628954268,
           -40.58102538187295,
           -40.40430447420321,
           -40.22758356653346,
           -40.05086265886372,
           -39.874141751193974,
           -39.69742084352425,
           -39.520699935854495,
           -39.34397902818476,
           -39.16725812051501,
           -38.990537212845275,
           -38.813816305175536,
           -38.63709539750579,
           -38.460374489836056,
           -38.28365358216631,
           -38.106932674496576,
           -37.93021176682683,
           -37.75349085915709,
           -37.57676995148735,
           -37.40004904381762,
           -37.22332813614787,
           -37.04660722847813,
           -36.86988632080839,
           -36.69316541313865,
           -36.51644450546891,
           -36.33972359779917,
           -36.163002690129424,
           -35.986281782459685,
           -35.80956087478994,
           -35.632839967120205,
           -35.456119059450465,
           -35.279398151780725,
           -35.102677244110986,
           -34.925956336441246,
           -34.7492354287715,
           -34.572514521101766,
           -34.39579361343202,
           -34.21907270576228,
           -34.04235179809255,
           -33.86563089042279,
           -33.68890998275306,
           -33.51218907508333,
           -33.33546816741358,
           -33.15874725974384,
           -32.98202635207411,
           -32.805305444404354,
           -32.62858453673461,
           -32.45186362906489,
           -32.27514272139514,
           -32.09842181372539,
           -31.921700906055655,
           -31.744979998385915,
           -31.568259090716168,
           -31.39153818304644,
           -31.2148172753767,
           -31.03809636770695,
           -30.86137546003722,
           -30.68465455236748,
           -30.50793364469773,
           -30.331212737027982,
           -30.15449182935826,
           -29.977770921688514,
           -29.80105001401876,
           -29.62432910634903,
           -29.447608198679294,
           -29.270887291009544,
           -29.09416638333981,
           -28.917445475670075,
           -28.740724568000324,
           -28.564003660330577,
           -28.38728275266086,
           -28.210561844991105,
           -28.033840937321358,
           -27.857120029651625,
           -27.680399121981885,
           -27.50367821431214,
           -27.326957306642406,
           -27.15023639897267,
           -26.97351549130292,
           -26.796794583633186,
           -26.62007367596345,
           -26.4433527682937,
           -26.266631860623953,
           -26.08991095295423,
           -25.91319004528448,
           -25.736469137614733,
           -25.559748229944997,
           -25.383027322275268,
           -25.206306414605514,
           -25.02958550693578,
           -24.852864599266045,
           -24.676143691596295,
           -24.499422783926548,
           -24.322701876256826,
           -24.145980968587075,
           -23.96926006091733,
           -23.792539153247592,
           -23.615818245577856,
           -23.43909733790811,
           -23.262376430238376,
           -23.085655522568644,
           -22.90893461489889,
           -22.732213707229157,
           -22.55549279955942,
           -22.37877189188967,
           -22.20205098421992,
           -22.0253300765502,
           -21.84860916888045,
           -21.671888261210704,
           -21.495167353540968,
           -21.31844644587123,
           -21.141725538201484,
           -20.965004630531748,
           -20.788283722862012,
           -20.61156281519226,
           -20.43484190752253,
           -20.258120999852792,
           -20.081400092183046,
           -19.904679184513295,
           -19.72795827684356,
           -19.551237369173826,
           -19.41547108118522,
           -19.361614032558876,
           -19.30775698393253,
           -19.25389993530618,
           -19.200042886679835,
           -19.14618583805349,
           -19.092328789427143,
           -19.038471740800787,
           -18.98461469217445,
           -18.930757643548098,
           -18.87690059492175,
           -18.823043546295402,
           -18.76918649766906,
           -18.71532944904271,
           -18.661472400416365,
           -18.607615351790017,
           -18.55375830316367,
           -18.499901254537324,
           -18.44604420591098,
           -18.39218715728463,
           -18.33833010865828,
           -18.284473060031935,
           -18.230616011405587,
           -18.17675896277924,
           -18.12290191415289,
           -18.06904486552655,
           -18.015187816900198,
           -17.961330768273854,
           -17.90747371964751,
           -17.853616671021157,
           -17.799759622394806,
           -17.74590257376847,
           -17.692045525142117,
           -17.63818847651577,
           -17.58433142788942,
           -17.530474379263076,
           -17.476617330636728,
           -17.422760282010383,
           -17.36890323338404,
           -17.315046184757687,
           -17.261189136131343,
           -17.207332087504998,
           -17.153475038878646,
           -17.0996179902523,
           -17.045760941625954,
           -16.991903892999606,
           -16.938046844373254,
           -16.884189795746913,
           -16.83033274712057,
           -16.776475698494217,
           -16.722618649867872,
           -16.668761601241524,
           -16.614904552615172,
           -16.561047503988828,
           -16.507190455362487,
           -16.453333406736135,
           -16.39947635810979,
           -16.34561930948344,
           -16.291762260857094,
           -16.237905212230746,
           -16.184048163604402,
           -16.130191114978054,
           -16.077503160884973,
           -16.025876388515442,
           -15.974249616145908,
           -15.922622843776368,
           -15.87099607140683,
           -15.819369299037303,
           -15.767742526667764,
           -15.716115754298226,
           -15.664488981928692,
           -15.612862209559157,
           -15.561235437189623,
           -15.509608664820089,
           -15.457981892450553,
           -15.406355120081015,
           -15.354728347711479,
           -15.303101575341948,
           -15.251474802972412,
           -15.199848030602872,
           -15.148221258233338,
           -15.096594485863806,
           -15.044967713494268,
           -14.979614857097914,
           -14.845631580567433,
           -14.711648304036947,
           -14.577665027506468,
           -14.44368175097601,
           -14.309698474445526,
           -14.175715197915045,
           -14.041731921384587,
           -13.907748644854102,
           -13.773765368323621,
           -13.639782091793164,
           -13.505798815262681,
           -13.371815538732198,
           -13.237832262201717,
           -13.103848985671258,
           -12.969865709140775,
           -12.835882432610294,
           -12.701899156079834,
           -12.567915879549354,
           -12.43393260301887,
           -12.299949326488411,
           -12.165966049957929,
           -12.031982773427448,
           -11.89799949689699,
           -11.764016220366507,
           -11.630032943836024,
           -11.496049667305542,
           -11.362066390775084,
           -11.228083114244601,
           -11.094099837714118,
           -10.96011656118366,
           -10.826133284653178,
           -10.692150008122695,
           -10.558166731592237,
           -10.428982264195849,
           -10.301754246927937,
           -10.174526229660026,
           -10.047298212392139,
           -9.920070195124229,
           -9.792842177856315,
           -9.665614160588428,
           -9.538386143320517,
           -9.441601228609208,
           -9.36656138715262,
           -9.291521545696021,
           -9.21648170423942,
           -9.141441862782832,
           -9.06640202132623,
           -8.991362179869629,
           -8.91632233841303,
           -8.838867183701424,
           -8.758533916539848,
           -8.678200649378272,
           -8.59786738221671,
           -8.517534115055135,
           -8.437200847893559,
           -8.356867580731997,
           -8.27653431357042,
           -8.196201046408843,
           -8.115867779247267,
           -8.035534512085706,
           -7.95520124492413,
           -7.874867977762554,
           -7.794534710600993,
           -7.714201443439415,
           -7.633868176277838,
           -7.553534909116278,
           -7.473201641954702,
           -7.3928683747931245,
           -7.312535107631565,
           -7.232201840469988,
           -7.15186857330841,
           -7.071535306146835,
           -6.991202038985273,
           -6.910868771823698,
           -6.8305355046621195,
           -6.7502022375005595,
           -6.6698689703389835,
           -6.589535703177407,
           -6.509202436015845,
           -6.428869168854269,
           -6.348535901692693,
           -6.268202634531116,
           -6.187869367369554
          ],
          [
           -41.6376269992285,
           -41.6820360429312,
           -41.7264450866339,
           -41.7708541303366,
           -41.8152631740393,
           -41.859672217742,
           -41.904081261444695,
           -41.9484903051474,
           -41.9928993488501,
           -42.0373083925528,
           -42.081717436255495,
           -42.126126479958195,
           -42.170535523660895,
           -42.214944567363595,
           -42.25935361106629,
           -42.303762654768995,
           -42.348171698471695,
           -42.39258074217439,
           -42.43698978587709,
           -42.48139882957979,
           -42.52580787328249,
           -42.57021691698519,
           -42.61462596068789,
           -42.65903500439059,
           -42.703444048093296,
           -42.74785309179599,
           -42.79226213549869,
           -42.836671179201396,
           -42.88108022290409,
           -42.92548926660679,
           -42.96989831030949,
           -43.01430735401219,
           -43.05871639771489,
           -43.10312544141759,
           -43.14753448512029,
           -43.19194352882299,
           -43.23635257252568,
           -43.28076161622839,
           -43.32517065993108,
           -43.36957970363379,
           -43.413988747336475,
           -43.45839779103919,
           -43.502806834741875,
           -43.54721587844459,
           -43.591624922147275,
           -43.636033965849975,
           -43.68044300955269,
           -43.724852053255375,
           -43.769261096958076,
           -43.813670140660776,
           -43.858079184363476,
           -43.902488228066176,
           -43.946897271768876,
           -43.991306315471576,
           -44.035715359174276,
           -44.080124402876976,
           -44.124533446579676,
           -44.168942490282376,
           -44.213351533985076,
           -44.257760577687776,
           -44.302169621390476,
           -44.346578665093176,
           -44.390987708795876,
           -44.435396752498576,
           -44.479805796201276,
           -44.524214839903976,
           -44.568623883606676,
           -44.613032927309376,
           -44.65672581291794,
           -44.700060621074684,
           -44.74339542923143,
           -44.78673023738816,
           -44.83006504554491,
           -44.873399853701656,
           -44.91673466185839,
           -44.960069470015135,
           -45.00340427817188,
           -45.04673908632862,
           -45.09007389448537,
           -45.13340870264211,
           -45.17674351079885,
           -45.2200783189556,
           -45.26341312711234,
           -45.30674793526908,
           -45.34605472582639,
           -45.384555912863824,
           -45.42305709990124,
           -45.461558286938676,
           -45.500059473976094,
           -45.53856066101353,
           -45.577061848050946,
           -45.61556303508837,
           -45.6540642221258,
           -45.69256540916322,
           -45.73106659620065,
           -45.769567783238074,
           -45.8080689702755,
           -45.846570157312925,
           -45.88507134435035,
           -45.92357253138778,
           -45.96213088427113,
           -46.000689237211084,
           -46.039247590151035,
           -46.077805943090986,
           -46.11636429603093,
           -46.15492264897089,
           -46.19348100191084,
           -46.23203935485079,
           -46.270597707790735,
           -46.30915606073069,
           -46.34771441367064,
           -46.386272766610595,
           -46.42483111955054,
           -46.4633894724905,
           -46.50194782543044,
           -46.5405061783704,
           -46.579064531310344,
           -46.617622884250295,
           -46.656181237190246,
           -46.6947395901302,
           -46.73329794307015,
           -46.7718562960101,
           -46.81041464895005,
           -46.84897300189,
           -46.88753135482995,
           -46.926089707769904,
           -46.96464806070986,
           -47.00320641364981,
           -47.04176476658976,
           -47.08032311952971,
           -47.11888147246965,
           -47.15743982540961,
           -47.195998178349555,
           -47.234556531289506,
           -47.273114884229464,
           -47.31167323716941,
           -47.35023159010936,
           -47.38878994304931,
           -47.42734829598926,
           -47.46590664892921,
           -47.504465001869164,
           -47.543023354809115,
           -47.58158170774906,
           -47.62014006068901,
           -47.65869841362896,
           -47.69725676656891,
           -47.73581511950887,
           -47.77437347244882,
           -47.812931825388766,
           -47.851490178328724,
           -47.89004853126867,
           -47.92860688420863,
           -47.96716523714857,
           -48.005723590088515,
           -48.04428194302847,
           -48.08284029596842,
           -48.121398648908375,
           -48.159957001848326,
           -48.19851535478828,
           -48.23707370772823,
           -48.27563206066817,
           -48.314190413608124,
           -48.35274876654808,
           -48.391307119488026,
           -48.429865472427984,
           -48.46842382536793,
           -48.50698217830788,
           -48.411932671099365,
           -48.25007923381663,
           -48.08822579653388,
           -47.92637235925112,
           -47.76451892196839,
           -47.60266548468563,
           -47.440812047402886,
           -47.27895861012014,
           -47.11710517283739,
           -46.955251735554654,
           -46.7933982982719,
           -46.63154486098915,
           -46.46969142370641,
           -46.307837986423664,
           -46.14598454914093,
           -45.984131111858176,
           -45.822277674575425,
           -45.66042423729267,
           -45.49857080000993,
           -45.336717362727185,
           -45.174863925444434,
           -45.01301048816169,
           -44.85115705087895,
           -44.689303613596195,
           -44.52745017631346,
           -44.365596739030714,
           -44.20374330174796,
           -44.04188986446522,
           -43.88003642718247,
           -43.718182989899724,
           -43.55632955261698,
           -43.39447611533423,
           -43.23262267805149,
           -43.07076924076873,
           -42.90891580348599,
           -42.74706236620324,
           -42.585208928920494,
           -42.42335549163776,
           -42.26150205435501,
           -42.09964861707226,
           -41.93779517978952,
           -41.76482337065654,
           -41.588126865276294,
           -41.41143035989605,
           -41.234733854515795,
           -41.05803734913555,
           -40.88134084375531,
           -40.70464433837507,
           -40.52794783299482,
           -40.35125132761456,
           -40.17455482223432,
           -39.997858316854085,
           -39.82116181147383,
           -39.64446530609358,
           -39.46776880071334,
           -39.29107229533309,
           -39.114375789952845,
           -38.937679284572596,
           -38.760982779192354,
           -38.5842862738121,
           -38.40758976843186,
           -38.23089326305161,
           -38.05419675767136,
           -37.877500252291114,
           -37.70080374691088,
           -37.52410724153063,
           -37.34741073615037,
           -37.17071423077013,
           -36.99401772538988,
           -36.817321220009646,
           -36.640624714629396,
           -36.46392820924915,
           -36.2872317038689,
           -36.11053519848865,
           -35.93383869310841,
           -35.757142187728164,
           -35.580445682347914,
           -35.403749176967665,
           -35.22705267158742,
           -35.05035616620717,
           -34.87365966082693,
           -34.69696315544668,
           -34.52026665006644,
           -34.3435701446862,
           -34.16687363930593,
           -33.9901771339257,
           -33.813480628545456,
           -33.6367841231652,
           -33.46008761778496,
           -33.283391112404715,
           -33.106694607024465,
           -32.92999810164421,
           -32.75330159626398,
           -32.57660509088373,
           -32.39990858550347,
           -32.22321208012323,
           -32.04651557474299,
           -31.869819069362734,
           -31.69312256398249,
           -31.516426058602256,
           -31.339729553221996,
           -31.163033047841758,
           -30.986336542461515,
           -30.809640037081262,
           -30.632943531701002,
           -30.456247026320778,
           -30.279550520940525,
           -30.10285401556027,
           -29.92615751018003,
           -29.749461004799787,
           -29.57276449941953,
           -29.396067994039292,
           -29.219371488659053,
           -29.042674983278793,
           -28.86597847789854,
           -28.689281972518316,
           -28.51258546713806,
           -28.335888961757803,
           -28.159192456377564,
           -27.982495950997325,
           -27.805799445617065,
           -27.629102940236827,
           -27.452406434856588,
           -27.275709929476328,
           -27.099013424096093,
           -26.92231691871585,
           -26.745620413335594,
           -26.568923907955337,
           -26.392227402575116,
           -26.21553089719486,
           -26.038834391814603,
           -25.86213788643436,
           -25.68544138105412,
           -25.508744875673862,
           -25.332048370293627,
           -25.155351864913385,
           -24.97865535953313,
           -24.801958854152872,
           -24.625262348772647,
           -24.448565843392394,
           -24.271869338012138,
           -24.095172832631896,
           -23.918476327251657,
           -23.7417798218714,
           -23.565083316491158,
           -23.388386811110916,
           -23.211690305730663,
           -23.034993800350424,
           -22.858297294970182,
           -22.68160078958993,
           -22.50490428420967,
           -22.328207778829444,
           -22.15151127344919,
           -21.97481476806893,
           -21.79811826268869,
           -21.621421757308454,
           -21.444725251928197,
           -21.268028746547955,
           -21.091332241167716,
           -20.91463573578746,
           -20.73793923040722,
           -20.56124272502698,
           -20.384546219646722,
           -20.207849714266466,
           -20.031153208886227,
           -19.85445670350599,
           -19.718075251340487,
           -19.662449256830374,
           -19.60840469302773,
           -19.554360129225074,
           -19.50031556542243,
           -19.446271001619785,
           -19.39222643781713,
           -19.33818187401448,
           -19.28413731021184,
           -19.230092746409184,
           -19.176048182606536,
           -19.122003618803888,
           -19.06795905500124,
           -19.013914491198587,
           -18.959869927395943,
           -18.905825363593294,
           -18.851780799790642,
           -18.797736235987994,
           -18.74369167218535,
           -18.689647108382697,
           -18.635602544580046,
           -18.581557980777397,
           -18.527513416974752,
           -18.4734688531721,
           -18.419424289369452,
           -18.365379725566807,
           -18.311335161764156,
           -18.257290597961507,
           -18.203246034158862,
           -18.14920147035621,
           -18.095156906553555,
           -18.041112342750914,
           -17.987067778948266,
           -17.93302321514561,
           -17.878978651342965,
           -17.82493408754032,
           -17.770889523737665,
           -17.716844959935017,
           -17.662800396132372,
           -17.60875583232972,
           -17.554711268527075,
           -17.500666704724427,
           -17.446622140921775,
           -17.392577577119123,
           -17.33853301331648,
           -17.28448844951383,
           -17.230443885711175,
           -17.17639932190853,
           -17.122354758105885,
           -17.068310194303233,
           -17.01426563050059,
           -16.96022106669794,
           -16.90617650289529,
           -16.852131939092633,
           -16.79808737528999,
           -16.74404281148734,
           -16.68999824768469,
           -16.635953683882043,
           -16.581909120079395,
           -16.527864556276747,
           -16.4738199924741,
           -16.41977542867145,
           -16.365730864868798,
           -16.311686301066153,
           -16.257641737263505,
           -16.203597173460853,
           -16.1495526096582,
           -16.09550804585556,
           -16.041463482052908,
           -15.987418918250256,
           -15.933374354447611,
           -15.879329790644961,
           -15.825285226842311,
           -15.771240663039661,
           -15.717196099237016,
           -15.663151535434364,
           -15.609106971631713,
           -15.555062407829071,
           -15.501017844026418,
           -15.446973280223768,
           -15.39292871642112,
           -15.338884152618473,
           -15.284839588815823,
           -15.216318745697054,
           -15.075416505997637,
           -14.93451426629822,
           -14.793612026598803,
           -14.652709786899411,
           -14.513813579864824,
           -14.379426364023422,
           -14.245039148182045,
           -14.110651932340646,
           -13.976264716499246,
           -13.841877500657867,
           -13.707490284816467,
           -13.573103068975067,
           -13.438715853133667,
           -13.30432863729229,
           -13.16994142145089,
           -13.035554205609488,
           -12.901166989768111,
           -12.766779773926713,
           -12.63239255808531,
           -12.498005342243935,
           -12.363618126402534,
           -12.229230910561133,
           -12.094843694719758,
           -11.960456478878356,
           -11.826069263036956,
           -11.691682047195556,
           -11.55729483135418,
           -11.422907615512777,
           -11.288520399671379,
           -11.154133183830002,
           -11.019745967988602,
           -10.885358752147201,
           -10.750971536305826,
           -10.616584320464423,
           -10.482197104623022,
           -10.347809888781622,
           -10.213422672940247,
           -10.079035457098847,
           -9.944648241257443,
           -9.810261025416068,
           -9.675873809574668,
           -9.572792816279698,
           -9.492073410517898,
           -9.411354004756081,
           -9.33063459899427,
           -9.249915193232468,
           -9.169195787470654,
           -9.088476381708837,
           -9.007756975947025,
           -8.927037570185224,
           -8.846318164423408,
           -8.765598758661593,
           -8.684879352899793,
           -8.60415994713798,
           -8.523440541376164,
           -8.442721135614363,
           -8.36200172985255,
           -8.281282324090734,
           -8.20056291832892,
           -8.119843512567119,
           -8.039124106805303,
           -7.95840470104349,
           -7.877685295281689,
           -7.796965889519875,
           -7.71624648375806,
           -7.63552707799626,
           -7.554807672234444,
           -7.47408826647263,
           -7.393368860710829,
           -7.312649454949015,
           -7.2319300491872,
           -7.151210643425385,
           -7.0704912376635844,
           -6.98977183190177,
           -6.909052426139954,
           -6.828333020378155,
           -6.74761361461634,
           -6.666894208854526,
           -6.581437245020068,
           -6.495201083229661,
           -6.408964921439252,
           -6.322728759648844,
           -6.236492597858452
          ],
          [
           -41.32237854244467,
           -41.36678758614737,
           -41.41119662985007,
           -41.45560567355277,
           -41.50001471725547,
           -41.54442376095817,
           -41.58883280466087,
           -41.63324184836357,
           -41.67765089206627,
           -41.72205993576897,
           -41.76646897947167,
           -41.81087802317436,
           -41.85528706687707,
           -41.89969611057977,
           -41.94410515428246,
           -41.98851419798517,
           -42.032923241687854,
           -42.077332285390554,
           -42.12174132909326,
           -42.16615037279596,
           -42.210559416498654,
           -42.254968460201354,
           -42.29937750390406,
           -42.343786547606754,
           -42.38819559130946,
           -42.432604635012154,
           -42.477013678714854,
           -42.52142272241756,
           -42.565831766120255,
           -42.610240809822955,
           -42.654649853525655,
           -42.699058897228355,
           -42.743467940931055,
           -42.787876984633755,
           -42.832286028336455,
           -42.876695072039155,
           -42.92110411574185,
           -42.965513159444555,
           -43.009922203147255,
           -43.054331246849955,
           -43.098740290552655,
           -43.143149334255355,
           -43.18755837795805,
           -43.231967421660755,
           -43.27637646536345,
           -43.32078550906615,
           -43.365194552768855,
           -43.40960359647155,
           -43.45401264017425,
           -43.49842168387694,
           -43.54283072757965,
           -43.587060730783946,
           -43.63039553894069,
           -43.67373034709743,
           -43.717065155254176,
           -43.76039996341092,
           -43.80373477156766,
           -43.847069579724405,
           -43.89040438788115,
           -43.93373919603789,
           -43.97707400419463,
           -44.02040881235138,
           -44.06374362050812,
           -44.107078428664856,
           -44.1504132368216,
           -44.19374804497835,
           -44.237082853135085,
           -44.28041766129183,
           -44.32375246944858,
           -44.36708727760532,
           -44.41042208576206,
           -44.4537568939188,
           -44.497091702075544,
           -44.54042651023229,
           -44.58376131838903,
           -44.62709612654577,
           -44.670430934702516,
           -44.71376574285926,
           -44.757100551016,
           -44.800435359172745,
           -44.84377016732949,
           -44.88710497548623,
           -44.930439783642974,
           -44.97377459179971,
           -45.01308138235702,
           -45.051582569394455,
           -45.09008375643188,
           -45.128584943469306,
           -45.16708613050673,
           -45.20558731754415,
           -45.244088504581576,
           -45.282589691619,
           -45.32109087865643,
           -45.35959206569386,
           -45.39809325273128,
           -45.43659443976871,
           -45.47509562680613,
           -45.513596813843556,
           -45.55209800088098,
           -45.59059918791841,
           -45.62910037495583,
           -45.66760156199326,
           -45.706102749030684,
           -45.7446039360681,
           -45.78310512310553,
           -45.821606310142954,
           -45.86010749718038,
           -45.898608684217805,
           -45.93710987125524,
           -45.97561105829266,
           -46.01411224533008,
           -46.05261343236751,
           -46.091114619404934,
           -46.12961580644236,
           -46.168116993479785,
           -46.20661818051721,
           -46.24514795043987,
           -46.28370630337983,
           -46.322264656319774,
           -46.360823009259725,
           -46.39938136219968,
           -46.43793971513963,
           -46.47649806807958,
           -46.51505642101953,
           -46.55361477395948,
           -46.59217312689943,
           -46.63073147983938,
           -46.669289832779334,
           -46.70784818571928,
           -46.74640653865924,
           -46.78496489159919,
           -46.82352324453913,
           -46.86208159747909,
           -46.900639950419034,
           -46.93919830335899,
           -46.977756656298936,
           -47.016315009238895,
           -47.05487336217884,
           -47.0934317151188,
           -47.13199006805874,
           -47.17054842099869,
           -47.20910677393864,
           -47.247665126878594,
           -47.286223479818545,
           -47.3247818327585,
           -47.36334018569845,
           -47.401898538638406,
           -47.44045689157835,
           -47.479015244518294,
           -47.51757359745825,
           -47.556131950398196,
           -47.594690303338155,
           -47.6332486562781,
           -47.67180700921805,
           -47.710365362158,
           -47.74892371509795,
           -47.7874820680379,
           -47.826040420977854,
           -47.864598773917805,
           -47.90315712685776,
           -47.94171547979771,
           -47.98027383273766,
           -48.01883218567761,
           -48.057390538617554,
           -48.09594889155751,
           -48.13450724449746,
           -48.173065597437414,
           -48.078016090228886,
           -47.916162652946156,
           -47.754309215663405,
           -47.59245577838065,
           -47.43060234109792,
           -47.26874890381516,
           -47.10689546653242,
           -46.94504202924967,
           -46.78318859196692,
           -46.62133515468418,
           -46.45948171740143,
           -46.29762828011869,
           -46.135774842835936,
           -45.973921405553185,
           -45.81206796827045,
           -45.6502145309877,
           -45.48836109370495,
           -45.32650765642221,
           -45.16465421913946,
           -45.00280078185672,
           -44.84094734457397,
           -44.67909390729122,
           -44.51724047000849,
           -44.35538703272573,
           -44.193533595442986,
           -44.03168015816024,
           -43.86982672087749,
           -43.70797328359475,
           -43.546119846311996,
           -43.38426640902925,
           -43.22241297174651,
           -43.060559534463756,
           -42.89870609718102,
           -42.73685265989827,
           -42.57499922261552,
           -42.41314578533277,
           -42.25129234805003,
           -42.089438910767285,
           -41.92758547348454,
           -41.76573203620179,
           -41.60387859891905,
           -41.4420251616363,
           -41.28017172435355,
           -41.11831828707081,
           -40.95646484978806,
           -40.79461141250531,
           -40.63275797522257,
           -40.470904537939816,
           -40.30905110065707,
           -40.14719766337432,
           -39.98534422609157,
           -39.82349078880883,
           -39.66163735152609,
           -39.49978391424334,
           -39.337930476960594,
           -39.17607703967785,
           -39.0142236023951,
           -38.852370165112355,
           -38.69051672782961,
           -38.52866329054686,
           -38.36680985326412,
           -38.20495641598137,
           -38.04310297869863,
           -37.881249541415876,
           -37.71939610413314,
           -37.55754266685038,
           -37.39568922956764,
           -37.233835792284886,
           -37.07198235500214,
           -36.910128917719405,
           -36.748275480436654,
           -36.5864220431539,
           -36.42456860587116,
           -36.262715168588414,
           -36.10086173130567,
           -35.939008294022926,
           -35.777154856740175,
           -35.61530141945743,
           -35.45344798217468,
           -35.291594544891936,
           -35.12974110760919,
           -34.96788767032644,
           -34.80603423304369,
           -34.64256865782384,
           -34.46587215244358,
           -34.28917564706334,
           -34.112479141683096,
           -33.93578263630285,
           -33.759086130922604,
           -33.58238962554236,
           -33.405693120162105,
           -33.228996614781856,
           -33.05230010940163,
           -32.87560360402137,
           -32.69890709864111,
           -32.52221059326087,
           -32.34551408788063,
           -32.168817582500374,
           -31.99212107712014,
           -31.8154245717399,
           -31.63872806635964,
           -31.4620315609794,
           -31.285335055599163,
           -31.108638550218902,
           -30.93194204483865,
           -30.755245539458425,
           -30.57854903407817,
           -30.40185252869791,
           -30.225156023317666,
           -30.048459517937427,
           -29.871763012557174,
           -29.695066507176936,
           -29.518370001796693,
           -29.341673496416437,
           -29.164976991036184,
           -28.98828048565596,
           -28.811583980275703,
           -28.63488747489545,
           -28.458190969515208,
           -28.281494464134965,
           -28.104797958754713,
           -27.92810145337447,
           -27.75140494799423,
           -27.574708442613975,
           -27.398011937233733,
           -27.221315431853494,
           -27.044618926473234,
           -26.867922421092985,
           -26.691225915712756,
           -26.5145294103325,
           -26.337832904952247,
           -26.16113639957201,
           -25.984439894191766,
           -25.807743388811506,
           -25.631046883431267,
           -25.454350378051032,
           -25.27765387267077,
           -25.100957367290512,
           -24.92426086191029,
           -24.747564356530035,
           -24.570867851149778,
           -24.394171345769536,
           -24.217474840389297,
           -24.040778335009044,
           -23.8640818296288,
           -23.687385324248563,
           -23.510688818868307,
           -23.333992313488064,
           -23.157295808107826,
           -22.98059930272757,
           -22.803902797347313,
           -22.62720629196709,
           -22.45050978658683,
           -22.27381328120658,
           -22.097116775826336,
           -21.920420270446094,
           -21.743723765065837,
           -21.567027259685602,
           -21.39033075430536,
           -21.213634248925104,
           -21.036937743544865,
           -20.860241238164623,
           -20.683544732784366,
           -20.50684822740411,
           -20.33015172202387,
           -20.15345521664363,
           -20.01707376447813,
           -19.961322418742114,
           -19.905571073006094,
           -19.84981972727007,
           -19.794068381534053,
           -19.738317035798033,
           -19.68256569006201,
           -19.626814344325986,
           -19.571062998589973,
           -19.51531165285395,
           -19.459560307117926,
           -19.403808961381905,
           -19.348057615645892,
           -19.292306269909865,
           -19.23655492417385,
           -19.180803578437832,
           -19.125052232701805,
           -19.06930088696579,
           -19.01354954122977,
           -18.957798195493748,
           -18.902046849757724,
           -18.846295504021708,
           -18.790544158285687,
           -18.734792812549664,
           -18.679041466813647,
           -18.623290121077627,
           -18.567538775341603,
           -18.511787429605583,
           -18.45603608386957,
           -18.400284738133543,
           -18.344533392397523,
           -18.28878204666151,
           -18.233030700925482,
           -18.177279355189462,
           -18.123085322165085,
           -18.06904075836244,
           -18.014996194559792,
           -17.960951630757144,
           -17.906907066954496,
           -17.852862503151844,
           -17.7988179393492,
           -17.74477337554655,
           -17.6907288117439,
           -17.636684247941247,
           -17.5826396841386,
           -17.52859512033595,
           -17.474550556533302,
           -17.420505992730654,
           -17.366461428928005,
           -17.312416865125357,
           -17.25837230132271,
           -17.20432773752006,
           -17.150283173717412,
           -17.09623860991476,
           -17.042194046112115,
           -16.988149482309467,
           -16.93410491850681,
           -16.880060354704167,
           -16.82601579090152,
           -16.771971227098867,
           -16.71792666329622,
           -16.663882099493573,
           -16.60983753569092,
           -16.555792971888273,
           -16.50174840808563,
           -16.447703844282977,
           -16.393659280480325,
           -16.339614716677684,
           -16.28557015287503,
           -16.23152558907238,
           -16.17748102526973,
           -16.123436461467087,
           -16.069391897664435,
           -16.015347333861786,
           -15.96130277005914,
           -15.907258206256486,
           -15.853213642453836,
           -15.799169078651193,
           -15.745124514848541,
           -15.691079951045891,
           -15.637035387243245,
           -15.582990823440596,
           -15.528946259637944,
           -15.460425416519175,
           -15.31952317681976,
           -15.178620937120344,
           -15.037718697420926,
           -14.896816457721537,
           -14.75591421802212,
           -14.615011978322702,
           -14.474109738623312,
           -14.333207498923896,
           -14.192305259224481,
           -14.051403019525091,
           -13.910500779825673,
           -13.76959854012626,
           -13.628696300426842,
           -13.487794060727452,
           -13.346891821028036,
           -13.205989581328618,
           -13.06508734162923,
           -12.924185101929812,
           -12.783282862230397,
           -12.642380622531007,
           -12.502959901574046,
           -12.368572685732646,
           -12.23418546989127,
           -12.099798254049869,
           -11.965411038208469,
           -11.831023822367069,
           -11.696636606525692,
           -11.562249390684292,
           -11.42786217484289,
           -11.293474959001514,
           -11.159087743160114,
           -11.024700527318714,
           -10.890313311477339,
           -10.755926095635937,
           -10.621538879794535,
           -10.487151663953135,
           -10.35276444811176,
           -10.218377232270358,
           -10.083990016428958,
           -9.94960280058758,
           -9.81521558474618,
           -9.71213459145121,
           -9.63141518568941,
           -9.550695779927594,
           -9.46997637416578,
           -9.38925696840398,
           -9.308537562642165,
           -9.227818156880351,
           -9.147098751118536,
           -9.066379345356737,
           -8.985659939594921,
           -8.904940533833106,
           -8.824221128071306,
           -8.74350172230949,
           -8.662782316547677,
           -8.582062910785877,
           -8.501343505024062,
           -8.420624099262247,
           -8.339904693500431,
           -8.259185287738632,
           -8.178465881976818,
           -8.097746476215,
           -8.011845367369512,
           -7.925609205579104,
           -7.839373043788695,
           -7.753136881998303,
           -7.666900720207895,
           -7.580664558417487,
           -7.494428396627094,
           -7.408192234836687,
           -7.3219560730462785,
           -7.235719911255871,
           -7.149483749465478,
           -7.06324758767507,
           -6.977011425884663,
           -6.89077526409427,
           -6.8045391023038615,
           -6.718302940513453,
           -6.632066778723061,
           -6.545830616932655,
           -6.459594455142245,
           -6.373358293351838,
           -6.287122131561446
          ],
          [
           -41.00713008566083,
           -41.05153912936353,
           -41.09594817306623,
           -41.14035721676893,
           -41.18476626047163,
           -41.22917530417433,
           -41.27358434787703,
           -41.31799339157973,
           -41.36240243528243,
           -41.406811478985134,
           -41.451220522687834,
           -41.49562956639053,
           -41.540038610093234,
           -41.58444765379593,
           -41.628856697498634,
           -41.67326574120133,
           -41.71767478490402,
           -41.76208382860673,
           -41.80649287230943,
           -41.85090191601213,
           -41.89531095971482,
           -41.93972000341753,
           -41.98412904712022,
           -42.02853809082292,
           -42.07294713452562,
           -42.11735617822832,
           -42.16176522193102,
           -42.20617426563372,
           -42.25058330933642,
           -42.29499235303912,
           -42.33940139674182,
           -42.38381044044452,
           -42.42821948414722,
           -42.47262852784992,
           -42.51703757155262,
           -42.56073045680668,
           -42.60406526496343,
           -42.647400073120174,
           -42.69073488127692,
           -42.73406968943366,
           -42.777404497590396,
           -42.82073930574715,
           -42.86407411390388,
           -42.90740892206063,
           -42.950743730217376,
           -42.99407853837411,
           -43.03741334653086,
           -43.0807481546876,
           -43.12408296284434,
           -43.16741777100109,
           -43.21075257915783,
           -43.25408738731457,
           -43.29742219547131,
           -43.340757003628056,
           -43.3840918117848,
           -43.42742661994154,
           -43.47076142809829,
           -43.51409623625503,
           -43.55743104441177,
           -43.600765852568514,
           -43.64410066072526,
           -43.687435468882,
           -43.730770277038744,
           -43.77410508519549,
           -43.81743989335223,
           -43.860774701508966,
           -43.904109509665716,
           -43.94744431782246,
           -43.9907791259792,
           -44.034113934135945,
           -44.07744874229269,
           -44.120783550449424,
           -44.164118358606174,
           -44.20745316676292,
           -44.25078797491966,
           -44.2941227830764,
           -44.33745759123314,
           -44.38079239938989,
           -44.42412720754663,
           -44.467462015703376,
           -44.51079682386011,
           -44.55413163201686,
           -44.597466440173605,
           -44.64080124833035,
           -44.68010803888765,
           -44.71860922592508,
           -44.757110412962504,
           -44.79561159999994,
           -44.834112787037355,
           -44.87261397407478,
           -44.91111516111221,
           -44.94961634814963,
           -44.98811753518706,
           -45.02661872222448,
           -45.06511990926191,
           -45.103621096299335,
           -45.14212228333676,
           -45.180623470374194,
           -45.21912465741161,
           -45.25762584444903,
           -45.29612703148646,
           -45.33462821852388,
           -45.37312940556131,
           -45.41163059259874,
           -45.450131779636166,
           -45.488632966673585,
           -45.52713415371102,
           -45.56563534074844,
           -45.60413652778587,
           -45.642637714823294,
           -45.68113890186071,
           -45.719640088898146,
           -45.75814127593557,
           -45.796642462973,
           -45.83514365001042,
           -45.873644837047834,
           -45.912146024085274,
           -45.95064721112269,
           -45.98914839816011,
           -46.02764958519755,
           -46.06615077223496,
           -46.104651959272395,
           -46.14315314630983,
           -46.18165433334724,
           -46.22015552038467,
           -46.2586567074221,
           -46.297157894459524,
           -46.33565908149695,
           -46.37416026853437,
           -46.4126614555718,
           -46.451162642609226,
           -46.48966382964665,
           -46.52816501668408,
           -46.56672336954856,
           -46.60528172248851,
           -46.64384007542846,
           -46.682398428368415,
           -46.72095678130836,
           -46.75951513424832,
           -46.79807348718827,
           -46.83663184012822,
           -46.875190193068164,
           -46.91374854600812,
           -46.952306898948066,
           -46.990865251888025,
           -47.02942360482797,
           -47.06798195776793,
           -47.106540310707885,
           -47.14509866364783,
           -47.18365701658779,
           -47.22221536952773,
           -47.26077372246768,
           -47.29933207540763,
           -47.33789042834758,
           -47.37644878128753,
           -47.41500713422748,
           -47.453565487167424,
           -47.49212384010738,
           -47.530682193047326,
           -47.569240545987284,
           -47.60779889892723,
           -47.64635725186719,
           -47.68491560480713,
           -47.72347395774708,
           -47.76203231068703,
           -47.800590663626984,
           -47.839149016566935,
           -47.74409950935842,
           -47.58224607207568,
           -47.420392634792925,
           -47.25853919751019,
           -47.096685760227444,
           -46.934832322944686,
           -46.77297888566194,
           -46.6111254483792,
           -46.449272011096454,
           -46.28741857381371,
           -46.12556513653095,
           -45.963711699248215,
           -45.801858261965464,
           -45.64000482468272,
           -45.478151387399976,
           -45.316297950117225,
           -45.15444451283448,
           -44.992591075551736,
           -44.830737638268985,
           -44.66888420098625,
           -44.5070307637035,
           -44.34517732642075,
           -44.18332388913801,
           -44.02147045185525,
           -43.859617014572514,
           -43.69776357728976,
           -43.53591014000702,
           -43.374056702724275,
           -43.212203265441524,
           -43.05034982815879,
           -42.88849639087603,
           -42.726642953593284,
           -42.56478951631055,
           -42.402936079027796,
           -42.24108264174505,
           -42.079229204462294,
           -41.91737576717956,
           -41.75552232989682,
           -41.59366889261406,
           -41.43181545533132,
           -41.269962018048574,
           -41.10810858076583,
           -40.94625514348308,
           -40.78440170620034,
           -40.62254826891758,
           -40.46069483163484,
           -40.298841394352095,
           -40.13698795706935,
           -39.9751345197866,
           -39.81328108250385,
           -39.651427645221105,
           -39.48957420793836,
           -39.32772077065562,
           -39.165867333372866,
           -39.00401389609012,
           -38.84216045880738,
           -38.680307021524634,
           -38.51845358424188,
           -38.35660014695914,
           -38.19474670967639,
           -38.03289327239365,
           -37.8710398351109,
           -37.70918639782815,
           -37.547332960545404,
           -37.38547952326267,
           -37.223626085979916,
           -37.06177264869717,
           -36.89991921141442,
           -36.73806577413167,
           -36.57621233684893,
           -36.41435889956619,
           -36.25250546228344,
           -36.090652025000686,
           -35.92879858771794,
           -35.7669451504352,
           -35.60509171315245,
           -35.4432382758697,
           -35.28138483858696,
           -35.119531401304215,
           -34.95767796402147,
           -34.79582452673872,
           -34.63397108945597,
           -34.47211765217322,
           -34.31026421489049,
           -34.14841077760773,
           -33.986557340324985,
           -33.82470390304225,
           -33.6628504657595,
           -33.500997028476746,
           -33.339143591194016,
           -33.17729015391126,
           -33.0154367166285,
           -32.85358327934578,
           -32.69172984206302,
           -32.52987640478026,
           -32.368022967497524,
           -32.20616953021479,
           -32.04431609293203,
           -31.882462655649284,
           -31.720609218366548,
           -31.55875578108379,
           -31.396902343801052,
           -31.235048906518315,
           -31.073195469235557,
           -30.9113420319528,
           -30.749488594670073,
           -30.587635157387318,
           -30.425781720104563,
           -30.263928282821823,
           -30.102074845539082,
           -29.940221408256328,
           -29.778367970973587,
           -29.616514533690847,
           -29.45466109640809,
           -29.292807659125334,
           -29.130954221842607,
           -28.969100784559856,
           -28.807247347277098,
           -28.64539390999436,
           -28.48354047271162,
           -28.321687035428866,
           -28.159833598146122,
           -27.99798016086338,
           -27.836126723580627,
           -27.674273286297886,
           -27.51241984901515,
           -27.34361743961088,
           -27.166920934230625,
           -26.9902244288504,
           -26.813527923470144,
           -26.63683141808989,
           -26.46013491270965,
           -26.28343840732941,
           -26.10674190194915,
           -25.930045396568907,
           -25.753348891188672,
           -25.576652385808412,
           -25.39995588042816,
           -25.22325937504793,
           -25.046562869667678,
           -24.86986636428742,
           -24.693169858907183,
           -24.516473353526944,
           -24.339776848146688,
           -24.163080342766445,
           -23.986383837386207,
           -23.80968733200595,
           -23.63299082662571,
           -23.45629432124547,
           -23.27959781586521,
           -23.102901310484956,
           -22.926204805104735,
           -22.749508299724475,
           -22.572811794344222,
           -22.39611528896398,
           -22.21941878358374,
           -22.042722278203485,
           -21.866025772823242,
           -21.689329267443,
           -21.512632762062747,
           -21.33593625668251,
           -21.159239751302266,
           -20.98254324592201,
           -20.805846740541753,
           -20.629150235161514,
           -20.452453729781272,
           -20.31607227761577,
           -20.260320931879754,
           -20.204569586143737,
           -20.148818240407714,
           -20.093066894671693,
           -20.037315548935677,
           -19.981564203199653,
           -19.92581285746363,
           -19.870061511727616,
           -19.814310165991593,
           -19.75855882025557,
           -19.702807474519552,
           -19.647056128783532,
           -19.59130478304751,
           -19.535553437311492,
           -19.479802091575472,
           -19.42405074583945,
           -19.36829940010343,
           -19.312548054367415,
           -19.25679670863139,
           -19.201045362895368,
           -19.145294017159348,
           -19.08954267142333,
           -19.033791325687307,
           -18.97803997995129,
           -18.92228863421527,
           -18.866537288479247,
           -18.81078594274323,
           -18.75503459700721,
           -18.69928325127119,
           -18.643531905535163,
           -18.58778055979915,
           -18.532029214063126,
           -18.476277868327102,
           -18.420526522591086,
           -18.36477517685507,
           -18.309023831119045,
           -18.253272485383025,
           -18.19752113964701,
           -18.141769793910985,
           -18.086018448174965,
           -18.03026710243895,
           -17.97451575670292,
           -17.9187644109669,
           -17.86301306523088,
           -17.807261719494864,
           -17.75151037375884,
           -17.69575902802282,
           -17.640007682286804,
           -17.58425633655078,
           -17.528504990814763,
           -17.472753645078743,
           -17.41700229934272,
           -17.3612509536067,
           -17.305499607870683,
           -17.24974826213466,
           -17.19399691639864,
           -17.13824557066262,
           -17.0824942249266,
           -17.02674287919058,
           -16.97099153345456,
           -16.91524018771854,
           -16.859488841982518,
           -16.803737496246498,
           -16.74798615051048,
           -16.692234804774458,
           -16.63776595130245,
           -16.583721387499807,
           -16.52967682369715,
           -16.475632259894503,
           -16.421587696091855,
           -16.367543132289207,
           -16.313498568486555,
           -16.25945400468391,
           -16.20540944088126,
           -16.15136487707861,
           -16.097320313275958,
           -16.043275749473317,
           -15.989231185670665,
           -15.935186621868015,
           -15.881142058065366,
           -15.827097494262718,
           -15.773052930460068,
           -15.704532087341299,
           -15.563629847641883,
           -15.422727607942464,
           -15.28182536824305,
           -15.14092312854366,
           -15.000020888844242,
           -14.859118649144825,
           -14.718216409445434,
           -14.577314169746021,
           -14.436411930046603,
           -14.295509690347213,
           -14.154607450647799,
           -14.01370521094838,
           -13.872802971248966,
           -13.731900731549574,
           -13.59099849185016,
           -13.450096252150741,
           -13.309194012451352,
           -13.168291772751935,
           -13.02738953305252,
           -12.886487293353127,
           -12.745585053653713,
           -12.604682813954296,
           -12.463780574254907,
           -12.32287833455549,
           -12.181976094856076,
           -12.041073855156657,
           -11.900171615457268,
           -11.75926937575785,
           -11.618367136058433,
           -11.477464896359045,
           -11.336562656659627,
           -11.195660416960212,
           -11.054758177260823,
           -10.913855937561406,
           -10.77295369786199,
           -10.632051458162573,
           -10.492106223283272,
           -10.357719007441872,
           -10.223331791600472,
           -10.088944575759095,
           -9.954557359917693,
           -9.851476366622723,
           -9.770756960860924,
           -9.690037555099108,
           -9.609318149337293,
           -9.528489651509362,
           -9.442253489718954,
           -9.356017327928546,
           -9.269781166138138,
           -9.183545004347746,
           -9.09730884255734,
           -9.01107268076693,
           -8.924836518976537,
           -8.83860035718613,
           -8.752364195395721,
           -8.666128033605329,
           -8.579891871814922,
           -8.493655710024514,
           -8.407419548234104,
           -8.321183386443712,
           -8.234947224653304,
           -8.148711062862898,
           -8.062474901072505,
           -7.976238739282097,
           -7.890002577491689,
           -7.803766415701297,
           -7.717530253910889,
           -7.631294092120481,
           -7.545057930330088,
           -7.45882176853968,
           -7.372585606749272,
           -7.286349444958864,
           -7.200113283168472,
           -7.113877121378064,
           -7.027640959587656,
           -6.941404797797263,
           -6.855168636006855,
           -6.768932474216448,
           -6.682696312426056,
           -6.5964601506356475,
           -6.510223988845239,
           -6.423987827054831,
           -6.337751665264439
          ],
          [
           -40.691881628877006,
           -40.736290672579706,
           -40.7806997162824,
           -40.8251087599851,
           -40.869517803687806,
           -40.9139268473905,
           -40.9583358910932,
           -41.0027449347959,
           -41.0471539784986,
           -41.0915630222013,
           -41.135972065904,
           -41.1803811096067,
           -41.2247901533094,
           -41.2691991970121,
           -41.3136082407148,
           -41.3580172844175,
           -41.4024263281202,
           -41.4468353718229,
           -41.4910653746727,
           -41.534400182829444,
           -41.57773499098619,
           -41.62106979914293,
           -41.66440460729967,
           -41.707739415456416,
           -41.75107422361316,
           -41.794409031769895,
           -41.837743839926645,
           -41.88107864808339,
           -41.92441345624013,
           -41.967748264396874,
           -42.01108307255361,
           -42.05441788071035,
           -42.0977526888671,
           -42.14108749702385,
           -42.18442230518059,
           -42.22775711333732,
           -42.271091921494076,
           -42.31442672965081,
           -42.357761537807555,
           -42.40109634596429,
           -42.444431154121034,
           -42.487765962277784,
           -42.53110077043452,
           -42.57443557859127,
           -42.617770386748006,
           -42.66110519490475,
           -42.70444000306149,
           -42.747774811218235,
           -42.79110961937498,
           -42.83444442753172,
           -42.877779235688465,
           -42.92111404384521,
           -42.96444885200195,
           -43.007783660158694,
           -43.05111846831544,
           -43.09445327647218,
           -43.13778808462892,
           -43.181122892785666,
           -43.22445770094241,
           -43.26779250909915,
           -43.311127317255895,
           -43.35446212541264,
           -43.39779693356939,
           -43.44113174172612,
           -43.48446654988287,
           -43.52780135803961,
           -43.571136166196354,
           -43.6144709743531,
           -43.65780578250984,
           -43.701140590666576,
           -43.74447539882332,
           -43.78781020698006,
           -43.83114501513681,
           -43.874479823293555,
           -43.9178146314503,
           -43.961149439607034,
           -44.00448424776378,
           -44.04781905592052,
           -44.09115386407726,
           -44.13448867223401,
           -44.17782348039075,
           -44.22115828854749,
           -44.264493096704236,
           -44.30782790486098,
           -44.34713469541829,
           -44.385635882455716,
           -44.42413706949314,
           -44.46263825653057,
           -44.50113944356799,
           -44.53964063060542,
           -44.578141817642845,
           -44.61664300468027,
           -44.65514419171769,
           -44.693645378755114,
           -44.73214656579255,
           -44.77064775282997,
           -44.8091489398674,
           -44.847650126904824,
           -44.88615131394225,
           -44.92465250097967,
           -44.9631536880171,
           -45.00165487505452,
           -45.040156062091945,
           -45.07865724912938,
           -45.1171584361668,
           -45.15565962320422,
           -45.194160810241655,
           -45.23266199727908,
           -45.27116318431651,
           -45.30966437135393,
           -45.34816555839135,
           -45.386666745428776,
           -45.42516793246621,
           -45.463669119503635,
           -45.50217030654106,
           -45.54067149357847,
           -45.57917268061591,
           -45.61767386765333,
           -45.65617505469075,
           -45.69467624172818,
           -45.7331774287656,
           -45.77167861580303,
           -45.81017980284046,
           -45.84868098987788,
           -45.88718217691531,
           -45.92568336395273,
           -45.96418455099016,
           -46.00268573802758,
           -46.041186925065006,
           -46.07968811210244,
           -46.11818929913986,
           -46.15669048617729,
           -46.19519167321471,
           -46.233692860252134,
           -46.27219404728956,
           -46.31069523432698,
           -46.34919642136441,
           -46.38769760840183,
           -46.42619879543926,
           -46.46469998247669,
           -46.50320116951411,
           -46.54170235655154,
           -46.58020354358895,
           -46.61870473062638,
           -46.65720591766381,
           -46.695707104701235,
           -46.73420829173867,
           -46.772709478776086,
           -46.81121066581351,
           -46.84974043571732,
           -46.888298788657266,
           -46.92685714159722,
           -46.96541549453716,
           -47.00397384747711,
           -47.042532200417064,
           -47.081090553357015,
           -47.119648906296966,
           -47.15820725923692,
           -47.19676561217687,
           -47.23532396511682,
           -47.27388231805677,
           -47.31244067099672,
           -47.35099902393667,
           -47.389557376876624,
           -47.42811572981657,
           -47.466674082756526,
           -47.50523243569647,
           -47.410182928487956,
           -47.24832949120521,
           -47.08647605392247,
           -46.92462261663972,
           -46.76276917935698,
           -46.60091574207422,
           -46.439062304791484,
           -46.27720886750873,
           -46.11535543022599,
           -45.953501992943245,
           -45.791648555660494,
           -45.62979511837776,
           -45.46794168109499,
           -45.306088243812255,
           -45.14423480652951,
           -44.98238136924676,
           -44.820527931964016,
           -44.65867449468127,
           -44.49682105739852,
           -44.334967620115776,
           -44.17311418283304,
           -44.01126074555029,
           -43.849407308267544,
           -43.68755387098479,
           -43.525700433702056,
           -43.3638469964193,
           -43.201993559136554,
           -43.04014012185381,
           -42.87828668457106,
           -42.71643324728832,
           -42.55457981000557,
           -42.39272637272282,
           -42.23087293544008,
           -42.06901949815733,
           -41.90716606087459,
           -41.745312623591836,
           -41.583459186309085,
           -41.42160574902635,
           -41.2597523117436,
           -41.09789887446085,
           -40.936045437178116,
           -40.774191999895365,
           -40.612338562612614,
           -40.45048512532987,
           -40.28863168804712,
           -40.126778250764374,
           -39.96492481348163,
           -39.803071376198886,
           -39.64121793891614,
           -39.47936450163339,
           -39.31751106435064,
           -39.155657627067896,
           -38.99380418978515,
           -38.83195075250241,
           -38.67009731521966,
           -38.50824387793692,
           -38.34639044065417,
           -38.18453700337142,
           -38.02268356608867,
           -37.86083012880592,
           -37.698976691523185,
           -37.537123254240434,
           -37.37526981695768,
           -37.21341637967494,
           -37.0515629423922,
           -36.88970950510945,
           -36.72785606782671,
           -36.566002630543956,
           -36.404149193261205,
           -36.24229575597847,
           -36.08044231869572,
           -35.91858888141297,
           -35.75673544413022,
           -35.59488200684748,
           -35.43302856956474,
           -35.27117513228198,
           -35.10932169499924,
           -34.947468257716494,
           -34.78561482043375,
           -34.623761383151,
           -34.46190794586826,
           -34.300054508585504,
           -34.13820107130276,
           -33.976347634020016,
           -33.814494196737265,
           -33.65264075945453,
           -33.490787322171784,
           -33.328933884889025,
           -33.16708044760629,
           -33.00522701032355,
           -32.84337357304079,
           -32.681520135758035,
           -32.51966669847531,
           -32.357813261192554,
           -32.1959598239098,
           -32.03410638662706,
           -31.872252949344322,
           -31.710399512061564,
           -31.54854607477882,
           -31.386692637496083,
           -31.22483920021333,
           -31.062985762930587,
           -30.901132325647847,
           -30.739278888365092,
           -30.577425451082338,
           -30.41557201379961,
           -30.253718576516853,
           -30.091865139234102,
           -29.930011701951358,
           -29.76815826466862,
           -29.606304827385863,
           -29.444451390103122,
           -29.282597952820385,
           -29.120744515537627,
           -28.958891078254872,
           -28.79703764097215,
           -28.63518420368939,
           -28.473330766406633,
           -28.311477329123896,
           -28.149623891841156,
           -27.987770454558397,
           -27.82591701727566,
           -27.66406357999292,
           -27.50221014271016,
           -27.340356705427425,
           -27.17850326814468,
           -27.01664983086193,
           -26.85479639357917,
           -26.692942956296445,
           -26.53108951901369,
           -26.369236081730936,
           -26.207382644448195,
           -26.04552920716545,
           -25.8836757698827,
           -25.721822332599956,
           -25.559968895317215,
           -25.39811545803446,
           -25.236262020751706,
           -25.07440858346898,
           -24.912555146186225,
           -24.75070170890347,
           -24.588848271620726,
           -24.426994834337986,
           -24.265141397055235,
           -24.103287959772494,
           -23.941434522489754,
           -23.779581085207,
           -23.61772764792426,
           -23.455874210641518,
           -23.29402077335876,
           -23.132167336076,
           -22.97031389879328,
           -22.808460461510524,
           -22.646607024227766,
           -22.48475358694503,
           -22.32290014966229,
           -22.16104671237953,
           -21.99919327509679,
           -21.858621147260116,
           -21.720146993572524,
           -21.581672839884945,
           -21.44319868619736,
           -21.304724532509763,
           -21.166250378822173,
           -20.970533572836107,
           -20.76821198398587,
           -20.614290385363983,
           -20.55716876719879,
           -20.500443498816967,
           -20.444479916190282,
           -20.388516333563604,
           -20.332552750936927,
           -20.27658916831024,
           -20.220625585683557,
           -20.164662003056883,
           -20.1086984204302,
           -20.052734837803516,
           -19.99677125517684,
           -19.940807672550157,
           -19.884844089923476,
           -19.828880507296795,
           -19.772916924670117,
           -19.716953342043432,
           -19.660989759416754,
           -19.605026176790073,
           -19.549062594163395,
           -19.493099011536707,
           -19.437135428910032,
           -19.38117184628335,
           -19.325208263656666,
           -19.26924468102999,
           -19.213281098403307,
           -19.157317515776626,
           -19.101353933149944,
           -19.04539035052327,
           -18.989426767896582,
           -18.9334631852699,
           -18.877499602643223,
           -18.821536020016545,
           -18.76557243738986,
           -18.709608854763182,
           -18.6536452721365,
           -18.59768168950982,
           -18.54171810688314,
           -18.48575452425646,
           -18.429790941629776,
           -18.373827359003098,
           -18.317863776376416,
           -18.26190019374973,
           -18.20593661112305,
           -18.14997302849637,
           -18.094009445869695,
           -18.038045863243006,
           -17.98208228061633,
           -17.92611869798965,
           -17.87015511536297,
           -17.814191532736288,
           -17.75822795010961,
           -17.702264367482925,
           -17.64630078485624,
           -17.590337202229566,
           -17.534373619602885,
           -17.4784100369762,
           -17.422446454349522,
           -17.366482871722845,
           -17.31051928909616,
           -17.25455570646948,
           -17.1985921238428,
           -17.142628541216116,
           -17.086664958589438,
           -17.03070137596276,
           -16.974737793336075,
           -16.918774210709394,
           -16.862810628082716,
           -16.806847045456035,
           -16.75088346282935,
           -16.694919880202672,
           -16.638956297575994,
           -16.58299271494931,
           -16.52702913232263,
           -16.47106554969595,
           -16.41510196706927,
           -16.359138384442584,
           -16.30317480181591,
           -16.247211219189225,
           -16.19124763656254,
           -16.135284053935866,
           -16.079320471309185,
           -16.023356888682503,
           -15.952081037685959,
           -15.804243844840077,
           -15.656406651994192,
           -15.508569459148307,
           -15.360732266302447,
           -15.212895073456563,
           -15.065057880610677,
           -14.91722068776482,
           -14.773327432477311,
           -14.631822770326197,
           -14.490318108175105,
           -14.348813446023991,
           -14.207308783872875,
           -14.065804121721762,
           -13.924299459570673,
           -13.782794797419557,
           -13.641290135268441,
           -13.499785473117353,
           -13.358280810966239,
           -13.216776148815125,
           -13.075271486664036,
           -12.93376682451292,
           -12.792262162361805,
           -12.650757500210716,
           -12.5092528380596,
           -12.367748175908485,
           -12.226243513757371,
           -12.084738851606282,
           -11.943234189455167,
           -11.801729527304051,
           -11.660224865152962,
           -11.518720203001847,
           -11.377215540850733,
           -11.235710878699642,
           -11.094206216548528,
           -10.95270155439741,
           -10.811196892246297,
           -10.669692230095208,
           -10.528187567944094,
           -10.386682905792977,
           -10.245178243641888,
           -10.103673581490774,
           -9.994046541455688,
           -9.907189231503489,
           -9.820331921551274,
           -9.733474611599059,
           -9.64661730164686,
           -9.559759991694646,
           -9.472902681742429,
           -9.386045371790212,
           -9.299188061838016,
           -9.2123307518858,
           -9.125473441933584,
           -9.038616131981385,
           -8.95175882202917,
           -8.864901512076955,
           -8.778044202124754,
           -8.69118689217254,
           -8.604329582220325,
           -8.51747227226811,
           -8.43061496231591,
           -8.343757652363696,
           -8.25690034241148,
           -8.170043032459281,
           -8.083185722507068,
           -7.996328412554851,
           -7.909471102602652,
           -7.822613792650436,
           -7.735756482698221,
           -7.648899172746021,
           -7.562041862793807,
           -7.475184552841592,
           -7.388327242889376,
           -7.301469932937177,
           -7.214612622984962,
           -7.127755313032746,
           -7.037785736421382,
           -6.945205883270655,
           -6.852626030119929,
           -6.760046176969219,
           -6.667466323818493,
           -6.5748864706677645,
           -6.482306617517038,
           -6.389726764366328
          ],
          [
           -40.37663317209317,
           -40.42104221579587,
           -40.46473510069544,
           -40.50806990885219,
           -40.55140471700893,
           -40.59473952516567,
           -40.63807433332242,
           -40.68140914147916,
           -40.724743949635894,
           -40.768078757792644,
           -40.81141356594939,
           -40.85474837410613,
           -40.89808318226287,
           -40.941417990419616,
           -40.98475279857636,
           -41.028087606733095,
           -41.071422414889845,
           -41.11475722304658,
           -41.158092031203324,
           -41.201426839360074,
           -41.24476164751681,
           -41.28809645567355,
           -41.331431263830304,
           -41.37476607198704,
           -41.41810088014378,
           -41.461435688300526,
           -41.50477049645727,
           -41.54810530461401,
           -41.591440112770755,
           -41.6347749209275,
           -41.67810972908424,
           -41.721444537240984,
           -41.76477934539773,
           -41.80811415355447,
           -41.85144896171121,
           -41.894783769867956,
           -41.9381185780247,
           -41.98145338618144,
           -42.024788194338186,
           -42.06812300249493,
           -42.11145781065167,
           -42.154792618808415,
           -42.19812742696516,
           -42.2414622351219,
           -42.284797043278644,
           -42.32813185143539,
           -42.37146665959213,
           -42.41480146774887,
           -42.45813627590561,
           -42.50147108406236,
           -42.544805892219095,
           -42.588140700375845,
           -42.63147550853258,
           -42.674810316689324,
           -42.71814512484607,
           -42.76147993300281,
           -42.80481474115956,
           -42.8481495493163,
           -42.89148435747304,
           -42.934819165629776,
           -42.97815397378652,
           -43.02148878194327,
           -43.06482359010001,
           -43.10815839825675,
           -43.1514932064135,
           -43.19482801457024,
           -43.23816282272698,
           -43.28149763088373,
           -43.32483243904047,
           -43.36816724719721,
           -43.41150205535395,
           -43.4548368635107,
           -43.498171671667436,
           -43.54150647982418,
           -43.58484128798092,
           -43.62817609613767,
           -43.67151090429441,
           -43.71484571245115,
           -43.758180520607894,
           -43.80151532876464,
           -43.84485013692139,
           -43.88818494507812,
           -43.931519753234866,
           -43.97485456139161,
           -44.01416135194892,
           -44.05266253898635,
           -44.09116372602377,
           -44.12966491306119,
           -44.16816610009862,
           -44.20666728713604,
           -44.24516847417347,
           -44.2836696612109,
           -44.32217084824833,
           -44.360672035285745,
           -44.39917322232318,
           -44.437674409360596,
           -44.47617559639802,
           -44.51467678343545,
           -44.55317797047288,
           -44.5916791575103,
           -44.63018034454773,
           -44.66868153158515,
           -44.707182718622576,
           -44.74568390566,
           -44.78418509269743,
           -44.82268627973485,
           -44.86118746677228,
           -44.899688653809704,
           -44.93818984084713,
           -44.976691027884556,
           -45.01519221492198,
           -45.05369340195941,
           -45.09219458899683,
           -45.13069577603426,
           -45.169196963071684,
           -45.20769815010911,
           -45.246199337146535,
           -45.28470052418396,
           -45.32320171122138,
           -45.36170289825881,
           -45.40020408529623,
           -45.438705272333664,
           -45.47720645937108,
           -45.51570764640851,
           -45.55420883344594,
           -45.59271002048336,
           -45.63121120752079,
           -45.66971239455821,
           -45.70821358159564,
           -45.74671476863307,
           -45.78521595567049,
           -45.82371714270792,
           -45.86221832974534,
           -45.900719516782765,
           -45.93922070382019,
           -45.97772189085761,
           -46.01622307789505,
           -46.05472426493247,
           -46.0932254519699,
           -46.13172663900732,
           -46.170227826044744,
           -46.20872901308217,
           -46.24723020011959,
           -46.285731387157014,
           -46.32423257419445,
           -46.36273376123187,
           -46.4012349482693,
           -46.43973613530672,
           -46.47823732234415,
           -46.516738509381575,
           -46.555239696418994,
           -46.59374088345643,
           -46.63224207049385,
           -46.67074325753128,
           -46.7092444445687,
           -46.74774563160612,
           -46.78624681864355,
           -46.82474800568098,
           -46.8632491927184,
           -46.90175037975583,
           -46.94025156679326,
           -46.978752753830676,
           -47.0172539408681,
           -47.05575512790553,
           -47.094256314942946,
           -47.13275750198038,
           -47.171315854826005,
           -47.076266347617484,
           -46.91441291033475,
           -46.752559473051996,
           -46.590706035769244,
           -46.42885259848651,
           -46.26699916120375,
           -46.10514572392101,
           -45.94329228663827,
           -45.78143884935551,
           -45.61958541207277,
           -45.45773197479002,
           -45.29587853750728,
           -45.154407370516765,
           -45.01593321682917,
           -44.87745906314159,
           -44.73898490945401,
           -44.60051075576642,
           -44.46203660207883,
           -44.323562448391236,
           -44.18508829470366,
           -44.04661414101608,
           -43.90813998732848,
           -43.769665833640914,
           -43.63119167995332,
           -43.492717526265736,
           -43.354243372578146,
           -43.215769218890564,
           -43.07729506520298,
           -42.93882091151539,
           -42.80034675782781,
           -42.66187260414023,
           -42.52339845045264,
           -42.38492429676505,
           -42.24645014307747,
           -42.10797598938988,
           -41.96950183570229,
           -41.8310276820147,
           -41.692553528327124,
           -41.55407937463954,
           -41.41560522095195,
           -41.27713106726437,
           -41.13865691357679,
           -41.00018275988919,
           -40.86170860620162,
           -40.72323445251402,
           -40.58476029882644,
           -40.44628614513886,
           -40.307811991451274,
           -40.16933783776368,
           -40.030863684076095,
           -39.89238953038851,
           -39.75391537670093,
           -39.61544122301334,
           -39.47696706932575,
           -39.33849291563817,
           -39.20001876195059,
           -39.061544608263,
           -38.92307045457541,
           -38.78459630088782,
           -38.64612214720024,
           -38.50764799351266,
           -38.36917383982507,
           -38.230699686137484,
           -38.092225532449895,
           -37.95375137876232,
           -37.81527722507472,
           -37.67680307138714,
           -37.53832891769956,
           -37.39985476401198,
           -37.261380610324395,
           -37.1229064566368,
           -36.984432302949216,
           -36.845958149261634,
           -36.707483995574044,
           -36.569009841886455,
           -36.43053568819887,
           -36.29206153451129,
           -36.1535873808237,
           -36.01511322713612,
           -35.87663907344853,
           -35.73816491976095,
           -35.59969076607336,
           -35.46121661238577,
           -35.322742458698194,
           -35.1842683050106,
           -35.04579415132302,
           -34.90731999763544,
           -34.768845843947844,
           -34.63037169026026,
           -34.49189753657269,
           -34.35342338288509,
           -34.214949229197494,
           -34.07647507550993,
           -33.938000921822336,
           -33.79952676813475,
           -33.66105261444716,
           -33.52257846075958,
           -33.384104307071986,
           -33.24563015338441,
           -33.10715599969683,
           -32.96868184600923,
           -32.83020769232165,
           -32.69173353863407,
           -32.55325938494648,
           -32.41478523125889,
           -32.27631107757132,
           -32.137836923883725,
           -31.99936277019613,
           -31.860888616508554,
           -31.722414462820968,
           -31.583940309133375,
           -31.445466155445793,
           -31.306992001758218,
           -31.16851784807062,
           -31.03004369438303,
           -30.891569540695468,
           -30.753095387007875,
           -30.614621233320275,
           -30.476147079632696,
           -30.337672925945114,
           -30.16617417983274,
           -29.963852590982498,
           -29.761531002132266,
           -29.559209413282012,
           -29.356887824431773,
           -29.154566235581534,
           -28.95224464673128,
           -28.749923057881027,
           -28.54760146903081,
           -28.345279880180552,
           -28.1429582913303,
           -27.94063670248006,
           -27.738315113629824,
           -27.53599352477957,
           -27.33367193592933,
           -27.131350347079096,
           -26.92902875822884,
           -26.726707169378585,
           -26.524385580528367,
           -26.322063991678114,
           -26.11974240282786,
           -25.91742081397762,
           -25.71509922512739,
           -25.51277763627713,
           -25.310456047426893,
           -25.108134458576657,
           -24.9058128697264,
           -24.703491280876168,
           -24.50116969202593,
           -24.29884810317568,
           -24.096526514325422,
           -23.894204925475204,
           -23.691883336624947,
           -23.489561747774694,
           -23.287240158924458,
           -23.08491857007422,
           -22.882596981223962,
           -22.68027539237373,
           -22.47795380352349,
           -22.275632214673237,
           -22.073310625822998,
           -21.870989036972766,
           -21.66866744812251,
           -21.466345859272252,
           -21.26402427042202,
           -21.061702681571784,
           -20.90778108294989,
           -20.850659464784698,
           -20.793537846619504,
           -20.736416228454306,
           -20.67929461028911,
           -20.622172992123918,
           -20.56505137395872,
           -20.50792975579352,
           -20.45080813762833,
           -20.39368651946313,
           -20.336564901297933,
           -20.27944328313274,
           -20.222321664967545,
           -20.165200046802347,
           -20.108078428637157,
           -20.05095681047196,
           -19.99383519230676,
           -19.93671357414157,
           -19.879591955976377,
           -19.822470337811176,
           -19.765348719645978,
           -19.708227101480787,
           -19.65110548331559,
           -19.593983865150392,
           -19.536862246985198,
           -19.479740628820007,
           -19.422619010654806,
           -19.365497392489612,
           -19.308375774324418,
           -19.25125415615922,
           -19.194132537994022,
           -19.137010919828832,
           -19.079889301663634,
           -19.022767683498436,
           -18.965646065333242,
           -18.90852444716805,
           -18.851933596007868,
           -18.795970013381186,
           -18.74000643075451,
           -18.684042848127824,
           -18.62807926550115,
           -18.57211568287447,
           -18.516152100247783,
           -18.4601885176211,
           -18.404224934994424,
           -18.348261352367743,
           -18.292297769741058,
           -18.23633418711438,
           -18.180370604487702,
           -18.124407021861018,
           -18.06844343923434,
           -18.012479856607662,
           -17.956516273980977,
           -17.900552691354292,
           -17.844589108727618,
           -17.788625526100937,
           -17.732661943474252,
           -17.676698360847574,
           -17.620734778220893,
           -17.56477119559421,
           -17.50880761296753,
           -17.452844030340852,
           -17.396880447714167,
           -17.34091686508749,
           -17.284953282460812,
           -17.228989699834127,
           -17.173026117207442,
           -17.117062534580768,
           -17.061098951954087,
           -17.0051353693274,
           -16.949171786700724,
           -16.893208204074043,
           -16.83724462144736,
           -16.78128103882068,
           -16.725317456194002,
           -16.669353873567317,
           -16.613390290940636,
           -16.55742670831396,
           -16.501463125687277,
           -16.445499543060592,
           -16.389535960433914,
           -16.333572377807236,
           -16.27760879518055,
           -16.206332944184012,
           -16.05849575133813,
           -15.910658558492242,
           -15.762821365646358,
           -15.6149841728005,
           -15.467146979954615,
           -15.319309787108727,
           -15.171472594262871,
           -15.023635401416984,
           -14.875798208571098,
           -14.727961015725242,
           -14.580123822879356,
           -14.432286630033474,
           -14.28444943718759,
           -14.136612244341729,
           -13.988775051495846,
           -13.840937858649959,
           -13.693100665804101,
           -13.545263472958215,
           -13.39742628011233,
           -13.249589087266472,
           -13.101751894420588,
           -12.953914701574702,
           -12.806077508728844,
           -12.65824031588296,
           -12.516596779885573,
           -12.375092117734459,
           -12.233587455583368,
           -12.092082793432255,
           -11.950578131281139,
           -11.80907346913005,
           -11.667568806978936,
           -11.52606414482782,
           -11.38455948267673,
           -11.243054820525614,
           -11.1015501583745,
           -10.960045496223387,
           -10.818540834072298,
           -10.67703617192118,
           -10.535531509770067,
           -10.394026847618976,
           -10.252522185467862,
           -10.142895145432776,
           -10.056037835480577,
           -9.969180525528362,
           -9.882323215576147,
           -9.795465905623947,
           -9.708608595671732,
           -9.621751285719517,
           -9.534893975767302,
           -9.448036665815103,
           -9.361179355862888,
           -9.274322045910672,
           -9.187464735958473,
           -9.100607426006258,
           -9.013750116054043,
           -8.926892806101844,
           -8.840035496149628,
           -8.753178186197413,
           -8.665241622364459,
           -8.572661769213749,
           -8.480081916063023,
           -8.387502062912297,
           -8.294922209761586,
           -8.20234235661086,
           -8.109762503460132,
           -8.017182650309422,
           -7.924602797158696,
           -7.832022944007968,
           -7.739443090857259,
           -7.6468632377065315,
           -7.554283384555804,
           -7.461703531405077,
           -7.369123678254368,
           -7.276543825103641,
           -7.183963971952913,
           -7.091384118802204,
           -6.998804265651477,
           -6.90622441250075,
           -6.81364455935004,
           -6.721064706199314,
           -6.628484853048587,
           -6.535904999897859,
           -6.443325146747149
          ],
          [
           -40.04727471579146,
           -40.0906095239482,
           -40.13394433210494,
           -40.17727914026168,
           -40.220613948418425,
           -40.263948756575175,
           -40.30728356473191,
           -40.350618372888654,
           -40.3939531810454,
           -40.43728798920214,
           -40.48062279735889,
           -40.523957605515626,
           -40.56729241367237,
           -40.61062722182911,
           -40.653962029985856,
           -40.6972968381426,
           -40.74063164629934,
           -40.783966454456085,
           -40.82730126261282,
           -40.87063607076957,
           -40.91397087892631,
           -40.95730568708306,
           -41.00064049523979,
           -41.043975303396536,
           -41.08731011155328,
           -41.13064491971002,
           -41.173979727866765,
           -41.21731453602351,
           -41.26064934418025,
           -41.303984152336994,
           -41.34731896049374,
           -41.39065376865048,
           -41.433988576807224,
           -41.47732338496397,
           -41.52065819312071,
           -41.56399300127745,
           -41.607327809434196,
           -41.65066261759094,
           -41.69399742574768,
           -41.737332233904425,
           -41.78066704206117,
           -41.82400185021791,
           -41.867336658374654,
           -41.9106714665314,
           -41.95400627468814,
           -41.99734108284488,
           -42.04067589100163,
           -42.08401069915837,
           -42.12734550731511,
           -42.17068031547185,
           -42.2140151236286,
           -42.25734993178534,
           -42.300684739942085,
           -42.34401954809882,
           -42.38735435625557,
           -42.430689164412314,
           -42.47402397256905,
           -42.51735878072579,
           -42.560693588882536,
           -42.60402839703928,
           -42.64736320519602,
           -42.69069801335277,
           -42.734032821509516,
           -42.77736762966625,
           -42.820702437822995,
           -42.864037245979745,
           -42.90737205413648,
           -42.950706862293224,
           -42.994041669012226,
           -43.03613936109284,
           -43.07823705317347,
           -43.12033474525409,
           -43.162432437334715,
           -43.20453012941534,
           -43.246627821495956,
           -43.28872551357658,
           -43.330823205657204,
           -43.37292089773783,
           -43.415018589818445,
           -43.45711628189907,
           -43.49921397397969,
           -43.54131166606032,
           -43.58340935814094,
           -43.62550705022156,
           -43.66427203208434,
           -43.70237047190355,
           -43.74046891172275,
           -43.77856735154195,
           -43.81666579136116,
           -43.85476423118037,
           -43.89286267099957,
           -43.93096111081878,
           -43.96905955063798,
           -44.007157990457195,
           -44.045256430276396,
           -44.0833548700956,
           -44.121453309914806,
           -44.159551749734014,
           -44.19765018955322,
           -44.236017127049834,
           -44.27451831408727,
           -44.313019501124685,
           -44.35152068816211,
           -44.39002187519954,
           -44.428523062236955,
           -44.46702424927439,
           -44.50552543631182,
           -44.54402662334924,
           -44.58252781038667,
           -44.62102899742409,
           -44.65953018446152,
           -44.69803137149894,
           -44.73653255853637,
           -44.7750337455738,
           -44.81353493261122,
           -44.852036119648645,
           -44.89053730668607,
           -44.929038493723496,
           -44.967539680760915,
           -45.00604086779835,
           -45.04454205483577,
           -45.0830432418732,
           -45.12154442891062,
           -45.16004561594805,
           -45.198546802985476,
           -45.237047990022894,
           -45.27554917706033,
           -45.314050364097746,
           -45.35255155113518,
           -45.391052738172604,
           -45.42955392521003,
           -45.468055112247455,
           -45.506556299284874,
           -45.5450574863223,
           -45.583558673359725,
           -45.622059860397144,
           -45.66056104743458,
           -45.699062234472,
           -45.73756342150943,
           -45.776064608546854,
           -45.81456579558427,
           -45.8530669826217,
           -45.89156816965913,
           -45.93006935669655,
           -45.968570543733975,
           -46.0070717307714,
           -46.045572917808826,
           -46.08407410484626,
           -46.12257529188368,
           -46.16107647892111,
           -46.19957766595853,
           -46.238078852995955,
           -46.27658004003339,
           -46.315081227070806,
           -46.35358241410824,
           -46.39208360114566,
           -46.43058478818308,
           -46.46908597522051,
           -46.507587162257934,
           -46.54608834929536,
           -46.584589536332786,
           -46.62309072337021,
           -46.66159191040764,
           -46.700093097445055,
           -46.73859428448249,
           -46.777095471519914,
           -46.81559665855734,
           -46.757241661588004,
           -46.65045857261531,
           -46.5436754836426,
           -46.4368923946699,
           -46.3301093056972,
           -46.22332621672449,
           -46.11654312775178,
           -46.00976003877908,
           -45.90297694980637,
           -45.79619386083367,
           -45.68941077186096,
           -45.582627682888265,
           -45.475844593915554,
           -45.36906150494285,
           -45.26227841597016,
           -45.15549532699745,
           -45.04871223802475,
           -44.94192914905204,
           -44.83514606007933,
           -44.728362971106634,
           -44.62157988213392,
           -44.514796793161224,
           -44.40801370418852,
           -44.301230615215815,
           -44.19444752624311,
           -44.087664437270405,
           -43.9808813482977,
           -43.874098259324995,
           -43.76731517035229,
           -43.660532081379586,
           -43.55374899240688,
           -43.446965903434176,
           -43.34018281446147,
           -43.233399725488766,
           -43.12661663651607,
           -43.01983354754336,
           -42.91305045857065,
           -42.806267369597954,
           -42.69948428062524,
           -42.59270119165254,
           -42.48591810267985,
           -42.379135013707135,
           -42.27235192473443,
           -42.165568835761725,
           -42.05878574678901,
           -41.952002657816315,
           -41.84521956884362,
           -41.738436479870906,
           -41.6316533908982,
           -41.524870301925496,
           -41.41808721295279,
           -41.31130412398009,
           -41.20452103500739,
           -41.097737946034684,
           -40.99095485706198,
           -40.884171768089274,
           -40.77738867911657,
           -40.670605590143865,
           -40.56382250117116,
           -40.457039412198455,
           -40.35025632322575,
           -40.243473234253045,
           -40.13669014528034,
           -40.029907056307636,
           -39.92312396733493,
           -39.81634087836223,
           -39.70955778938952,
           -39.602774700416816,
           -39.49599161144412,
           -39.389208522471414,
           -39.282425433498716,
           -39.175642344526004,
           -39.06885925555329,
           -38.96207616658059,
           -38.8552930776079,
           -38.748509988635185,
           -38.64172689966249,
           -38.53494381068978,
           -38.42816072171708,
           -38.32137763274437,
           -38.23286184872525,
           -38.16565792439248,
           -38.098454000059704,
           -37.96292219467166,
           -37.75906250822834,
           -37.555202821785024,
           -37.351343135341715,
           -37.147483448898384,
           -36.943623762455076,
           -36.73976407601177,
           -36.535904389568444,
           -36.33204470312511,
           -36.128185016681826,
           -35.92432533023849,
           -35.72046564379516,
           -35.51770459867474,
           -35.3153830098245,
           -35.11306142097425,
           -34.91073983212401,
           -34.708418243273776,
           -34.50609665442352,
           -34.303775065573284,
           -34.101453476723044,
           -33.8991318878728,
           -33.69681029902254,
           -33.49448871017232,
           -33.29216712132206,
           -33.08984553247181,
           -32.887523943621574,
           -32.685202354771334,
           -32.48288076592108,
           -32.28055917707084,
           -32.07823758822061,
           -31.875915999370353,
           -31.673594410520096,
           -31.471272821669885,
           -31.268951232819624,
           -31.066629643969367,
           -30.86430805511914,
           -30.661986466268896,
           -30.459664877418643,
           -30.257343288568403,
           -30.055021699718168,
           -29.852700110867918,
           -29.650378522017675,
           -29.448056933167443,
           -29.24573534431719,
           -29.04341375546693,
           -28.84109216661671,
           -28.638770577766458,
           -28.436448988916204,
           -28.23412740006597,
           -28.031805811215726,
           -27.829484222365473,
           -27.62716263351524,
           -27.424841044665005,
           -27.222519455814748,
           -27.020197866964494,
           -26.817876278114273,
           -26.615554689264016,
           -26.413233100413763,
           -26.21091151156353,
           -26.00858992271329,
           -25.806268333863034,
           -25.6039467450128,
           -25.401625156162567,
           -25.19930356731231,
           -24.99698197846207,
           -24.794660389611835,
           -24.59233880076158,
           -24.390017211911324,
           -24.187695623061106,
           -23.985374034210846,
           -23.783052445360596,
           -23.58073085651036,
           -23.378409267660125,
           -23.176087678809868,
           -22.973766089959632,
           -22.771444501109396,
           -22.56912291225914,
           -22.366801323408904,
           -22.16447973455867,
           -21.96215814570841,
           -21.759836556858154,
           -21.557514968007922,
           -21.355193379157686,
           -21.20127178053579,
           -21.1441501623706,
           -21.087028544205406,
           -21.02990692604021,
           -20.972785307875014,
           -20.915663689709824,
           -20.858542071544623,
           -20.80142045337942,
           -20.744298835214234,
           -20.687177217049037,
           -20.630055598883835,
           -20.572933980718645,
           -20.51581236255345,
           -20.458690744388253,
           -20.401569126223055,
           -20.344447508057865,
           -20.287325889892664,
           -20.230204271727473,
           -20.17308265356228,
           -20.11596103539708,
           -20.05883941723188,
           -20.00171779906669,
           -19.944596180901495,
           -19.887474562736298,
           -19.830352944571104,
           -19.77323132640591,
           -19.716109708240708,
           -19.658988090075518,
           -19.601866471910323,
           -19.544744853745126,
           -19.487623235579925,
           -19.430501617414738,
           -19.373379999249536,
           -19.31625838108434,
           -19.259136762919145,
           -19.20201514475395,
           -19.144893526588753,
           -19.08777190842356,
           -19.030650290258365,
           -18.973528672093167,
           -18.916407053927973,
           -18.85928543576278,
           -18.80216381759758,
           -18.74504219943238,
           -18.687920581267186,
           -18.63079896310199,
           -18.573677344936794,
           -18.5165557267716,
           -18.45943410860641,
           -18.402312490441208,
           -18.345190872276014,
           -18.288069254110823,
           -18.230947635945622,
           -18.173826017780424,
           -18.116704399615237,
           -18.05958278145004,
           -18.00246116328484,
           -17.945339545119644,
           -17.88821792695445,
           -17.83109630878925,
           -17.77397469062406,
           -17.716853072458864,
           -17.659731454293663,
           -17.602609836128472,
           -17.54548821796328,
           -17.48836659979808,
           -17.43124498163288,
           -17.374123363467692,
           -17.317001745302495,
           -17.259880127137293,
           -17.20342369319877,
           -17.14746011057209,
           -17.091496527945406,
           -17.035532945318728,
           -16.97956936269205,
           -16.923605780065365,
           -16.86764219743868,
           -16.81167861481201,
           -16.755715032185325,
           -16.69975144955864,
           -16.643787866931962,
           -16.58782428430528,
           -16.5318607016786,
           -16.460584850682057,
           -16.312747657836173,
           -16.16491046499029,
           -16.0170732721444,
           -15.869236079298544,
           -15.72139888645266,
           -15.573561693606774,
           -15.425724500760916,
           -15.27788730791503,
           -15.130050115069146,
           -14.98221292222329,
           -14.834375729377403,
           -14.686538536531518,
           -14.538701343685632,
           -14.390864150839775,
           -14.24302695799389,
           -14.095189765148005,
           -13.947352572302147,
           -13.799515379456261,
           -13.651678186610376,
           -13.503840993764518,
           -13.356003800918634,
           -13.208166608072748,
           -13.060329415226889,
           -12.912492222381005,
           -12.76465502953512,
           -12.616817836689235,
           -12.468980643843379,
           -12.321143450997493,
           -12.173306258151605,
           -12.02546906530575,
           -11.877631872459864,
           -11.729794679613978,
           -11.58195748676812,
           -11.434120293922234,
           -11.28628310107635,
           -11.138445908230466,
           -10.990608715384607,
           -10.842771522538722,
           -10.694934329692838,
           -10.547097136846979,
           -10.401370789444947,
           -10.291743749409862,
           -10.200117655156843,
           -10.107537802006117,
           -10.014957948855391,
           -9.922378095704682,
           -9.829798242553954,
           -9.737218389403225,
           -9.644638536252497,
           -9.552058683101789,
           -9.459478829951061,
           -9.366898976800334,
           -9.274319123649626,
           -9.181739270498898,
           -9.089159417348172,
           -8.99657956419746,
           -8.903999711046735,
           -8.81141985789601,
           -8.718840004745282,
           -8.62626015159457,
           -8.533680298443844,
           -8.441100445293117,
           -8.348520592142407,
           -8.25594073899168,
           -8.163360885840953,
           -8.070781032690244,
           -7.978201179539516,
           -7.885621326388789,
           -7.793041473238079,
           -7.700461620087353,
           -7.607881766936625,
           -7.515301913785898,
           -7.422722060635188,
           -7.330142207484461,
           -7.237562354333734,
           -7.144982501183025,
           -7.052402648032297,
           -6.95982279488157,
           -6.867242941730861,
           -6.774663088580134,
           -6.682083235429407,
           -6.5895033822786795,
           -6.4969235291279706
          ],
          [
           -39.71667582165517,
           -39.76001062981191,
           -39.80334543796865,
           -39.846680246125395,
           -39.89001505428214,
           -39.93334986243888,
           -39.97668467059562,
           -40.02001947875237,
           -40.06335428690911,
           -40.10668909506585,
           -40.150023903222596,
           -40.19335871137933,
           -40.23669351953608,
           -40.280028327692825,
           -40.32336313584957,
           -40.36669794400631,
           -40.41003275216305,
           -40.45336756031979,
           -40.496702368476534,
           -40.540037176633284,
           -40.58337198479002,
           -40.62670679294676,
           -40.670041601103506,
           -40.713376409260256,
           -40.75671121741699,
           -40.800046025573735,
           -40.843380833730485,
           -40.88671564188722,
           -40.930050450043964,
           -40.97338525820071,
           -41.01672006635745,
           -41.060054874514194,
           -41.10338968267094,
           -41.14672449082768,
           -41.19005929898442,
           -41.233394107141166,
           -41.276728915297916,
           -41.320063723454645,
           -41.363398531611395,
           -41.40673333976813,
           -41.45006814792488,
           -41.49340295608162,
           -41.53673776423837,
           -41.58007257239511,
           -41.623407380551846,
           -41.6667421887086,
           -41.71007699686533,
           -41.75341180502208,
           -41.79674661317882,
           -41.84008142133557,
           -41.883416229492305,
           -41.92675103764905,
           -41.969467287004484,
           -42.01156497908511,
           -42.05366267116573,
           -42.09576036324635,
           -42.13785805532698,
           -42.1799557474076,
           -42.22205343948822,
           -42.264151131568845,
           -42.30624882364946,
           -42.34834651573009,
           -42.39044420781071,
           -42.43254189989133,
           -42.47463959197196,
           -42.51673728405258,
           -42.5588349761332,
           -42.60093266821382,
           -42.643030360294446,
           -42.68512805237507,
           -42.727225744455694,
           -42.76932343653631,
           -42.811421128616935,
           -42.85351882069756,
           -42.89561651277818,
           -42.93771420485881,
           -42.979811896939424,
           -43.021909589020055,
           -43.06400728110068,
           -43.1061049731813,
           -43.14820266526192,
           -43.190300357342544,
           -43.23239804942317,
           -43.27449574150379,
           -43.31326072336656,
           -43.35135916318577,
           -43.38945760300497,
           -43.42755604282418,
           -43.46565448264339,
           -43.50375292246259,
           -43.54185136228179,
           -43.579949802101,
           -43.61804824192021,
           -43.656146681739415,
           -43.69424512155862,
           -43.732343561377824,
           -43.77044200119703,
           -43.808540441016234,
           -43.84663888083544,
           -43.88473732065465,
           -43.92283576047385,
           -43.96093420029305,
           -43.99903264011226,
           -44.03713107993147,
           -44.07522951975068,
           -44.11332795956988,
           -44.15142639938908,
           -44.18952483920829,
           -44.227623279027505,
           -44.265721718846706,
           -44.30382015866591,
           -44.34191859848511,
           -44.38001703830432,
           -44.41811547812353,
           -44.45621391794273,
           -44.49437948204983,
           -44.532880669087255,
           -44.57138185612468,
           -44.60988304316211,
           -44.64838423019953,
           -44.68688541723696,
           -44.725386604274384,
           -44.7638877913118,
           -44.802388978349235,
           -44.84089016538666,
           -44.87939135242408,
           -44.91789253946151,
           -44.95639372649893,
           -44.99489491353636,
           -45.03339610057378,
           -45.07189728761121,
           -45.11039847464864,
           -45.14889966168606,
           -45.18740084872349,
           -45.22590203576091,
           -45.264403222798336,
           -45.30290440983576,
           -45.34140559687319,
           -45.37990678391062,
           -45.41840797094804,
           -45.456909157985464,
           -45.49541034502289,
           -45.533911532060316,
           -45.57241271909774,
           -45.61091390613517,
           -45.64941509317259,
           -45.68791628021002,
           -45.726417467247444,
           -45.76491865428487,
           -45.803419841322295,
           -45.84192102835972,
           -45.88042221539715,
           -45.91892340243457,
           -45.957424589472,
           -45.995925776509424,
           -46.03442696354685,
           -46.072928150584275,
           -46.11142933762169,
           -46.14993052465912,
           -46.188431711696545,
           -46.22693289873397,
           -46.265434085771396,
           -46.30393527280882,
           -46.34243645984625,
           -46.38093764688367,
           -46.4194388339211,
           -46.45794002095852,
           -46.39958502398919,
           -46.29280193501649,
           -46.18601884604378,
           -46.07923575707109,
           -45.972452668098384,
           -45.86566957912567,
           -45.758886490152975,
           -45.65210340118027,
           -45.545320312207565,
           -45.43853722323486,
           -45.331754134262155,
           -45.22497104528945,
           -45.118187956316746,
           -45.01140486734404,
           -44.904621778371336,
           -44.79783868939863,
           -44.691055600425926,
           -44.58427251145322,
           -44.47748942248052,
           -44.37070633350781,
           -44.26392324453511,
           -44.1571401555624,
           -44.050357066589704,
           -43.94357397761699,
           -43.836790888644295,
           -43.73000779967158,
           -43.623224710698885,
           -43.51644162172619,
           -43.409658532753475,
           -43.30287544378077,
           -43.196092354808066,
           -43.08930926583536,
           -42.98252617686266,
           -42.87574308788995,
           -42.76895999891725,
           -42.66217690994454,
           -42.55539382097184,
           -42.44861073199914,
           -42.34182764302643,
           -42.23504455405373,
           -42.128261465081025,
           -42.02147837610832,
           -41.914695287135615,
           -41.80791219816291,
           -41.7011291091902,
           -41.5943460202175,
           -41.487562931244796,
           -41.3807798422721,
           -41.273996753299386,
           -41.16721366432668,
           -41.060430575353976,
           -40.95364748638128,
           -40.84686439740857,
           -40.74008130843587,
           -40.63329821946316,
           -40.52651513049046,
           -40.419732041517754,
           -40.31294895254505,
           -40.20616586357234,
           -40.09938277459964,
           -39.992599685626935,
           -39.92235119651438,
           -39.85514727218161,
           -39.78794334784884,
           -39.72073942351608,
           -39.653535499183306,
           -39.58633157485054,
           -39.519127650517774,
           -39.451923726185,
           -39.384719801852235,
           -39.31751587751947,
           -39.2503119531867,
           -39.18310802885393,
           -39.115904104521164,
           -39.0487001801884,
           -38.981496255855625,
           -38.91429233152286,
           -38.847088407190085,
           -38.77988448285733,
           -38.71268055852455,
           -38.64547663419179,
           -38.57827270985902,
           -38.51106878552625,
           -38.37553698013821,
           -38.17167729369488,
           -37.96781760725157,
           -37.76395792080826,
           -37.56009823436493,
           -37.35623854792162,
           -37.15237886147831,
           -36.94851917503498,
           -36.74465948859165,
           -36.54079980214836,
           -36.33694011570503,
           -36.13308042926171,
           -35.9292207428184,
           -35.72536105637509,
           -35.521501369931755,
           -35.317641683488446,
           -35.11378199704514,
           -34.90992231060181,
           -34.706062624158506,
           -34.50220293771519,
           -34.29834325127186,
           -34.094483564828536,
           -33.89062387838524,
           -33.68676419194191,
           -33.48290450549859,
           -33.27904481905527,
           -33.07518513261197,
           -32.87132544616863,
           -32.66746575972533,
           -32.463606073282016,
           -32.25974638683869,
           -32.05588670039536,
           -31.852027013952068,
           -31.648167327508748,
           -31.444307641065414,
           -31.240447954622102,
           -31.036588268178797,
           -30.832728581735466,
           -30.628868895292158,
           -30.42500920884885,
           -30.22114952240552,
           -30.017289835962213,
           -29.8134301495189,
           -29.60957046307557,
           -29.405710776632244,
           -29.201851090188953,
           -28.997991403745623,
           -28.7941317173023,
           -28.590272030858987,
           -28.386412344415675,
           -28.182552657972344,
           -27.978692971529043,
           -27.774833285085727,
           -27.570973598642396,
           -27.367113912199073,
           -27.163254225755786,
           -26.959394539312452,
           -26.755534852869125,
           -26.551675166425817,
           -26.347815479982508,
           -26.143955793539178,
           -25.940096107095865,
           -25.73623642065256,
           -25.53237673420923,
           -25.32851704776592,
           -25.12465736132261,
           -24.92079767487928,
           -24.71693798843595,
           -24.513078301992664,
           -24.309218615549334,
           -24.105358929106004,
           -23.901499242662695,
           -23.697639556219386,
           -23.49377986977606,
           -23.289920183332747,
           -23.08606049688944,
           -22.882200810446115,
           -22.678341124002802,
           -22.474481437559486,
           -22.270621751116163,
           -22.066762064672837,
           -21.861117875814394,
           -21.65243341941177,
           -21.494008436426885,
           -21.43610240027749,
           -21.378196364128108,
           -21.32061110448171,
           -21.263312251888213,
           -21.20601339929471,
           -21.148714546701207,
           -21.091415694107706,
           -21.034116841514212,
           -20.976817988920708,
           -20.919519136327203,
           -20.862220283733706,
           -20.804921431140208,
           -20.7476225785467,
           -20.690323725953203,
           -20.633024873359705,
           -20.5757260207662,
           -20.518427168172703,
           -20.461128315579206,
           -20.403829462985705,
           -20.346530610392197,
           -20.2892317577987,
           -20.231932905205202,
           -20.1746340526117,
           -20.1173352000182,
           -20.0600363474247,
           -20.002737494831194,
           -19.9454386422377,
           -19.8881397896442,
           -19.830840937050695,
           -19.77354208445719,
           -19.7162432318637,
           -19.658944379270196,
           -19.601645526676695,
           -19.544346674083197,
           -19.487047821489693,
           -19.42974896889619,
           -19.372450116302694,
           -19.315151263709197,
           -19.25785241111569,
           -19.20055355852219,
           -19.143254705928694,
           -19.085955853335193,
           -19.02865700074169,
           -18.97135814814819,
           -18.914059295554694,
           -18.85676044296119,
           -18.799461590367688,
           -18.74216273777419,
           -18.684863885180686,
           -18.62756503258719,
           -18.57026617999369,
           -18.512967327400183,
           -18.455668474806682,
           -18.398369622213192,
           -18.341070769619687,
           -18.28377191702618,
           -18.226473064432682,
           -18.169174211839184,
           -18.11187535924568,
           -18.054576506652182,
           -17.997277654058685,
           -17.93997880146518,
           -17.882679948871683,
           -17.825381096278182,
           -17.76808224368468,
           -17.710783391091176,
           -17.653484538497683,
           -17.596185685904178,
           -17.538886833310674,
           -17.481587980717176,
           -17.42428912812368,
           -17.366990275530178,
           -17.309691422936677,
           -17.252392570343176,
           -17.19509371774967,
           -17.13779486515617,
           -17.080496012562676,
           -17.023197159969175,
           -16.96589830737567,
           -16.90859945478217,
           -16.851300602188672,
           -16.794001749595168,
           -16.72044673382622,
           -16.565610902179973,
           -16.41077507053373,
           -16.255939238887482,
           -16.10110340724127,
           -15.946267575595023,
           -15.79143174394878,
           -15.636595912302562,
           -15.481760080656317,
           -15.326924249010073,
           -15.172088417363856,
           -15.021850036153094,
           -14.87320667481677,
           -14.724563313480445,
           -14.575919952144146,
           -14.427276590807821,
           -14.278633229471497,
           -14.129989868135198,
           -13.981346506798873,
           -13.832703145462549,
           -13.684059784126248,
           -13.535416422789925,
           -13.386773061453601,
           -13.238129700117302,
           -13.089486338780977,
           -12.94084297744465,
           -12.792199616108325,
           -12.643556254772028,
           -12.494912893435703,
           -12.34626953209938,
           -12.19762617076308,
           -12.048982809426754,
           -11.900339448090431,
           -11.751696086754132,
           -11.603052725417806,
           -11.454409364081481,
           -11.305766002745155,
           -11.157122641408858,
           -11.008479280072534,
           -10.85983591873621,
           -10.711192557399912,
           -10.562549196063586,
           -10.44609284748137,
           -10.352627222294956,
           -10.259161597108525,
           -10.165695971922094,
           -10.07223034673568,
           -9.978764721549247,
           -9.885299096362814,
           -9.791833471176385,
           -9.69836784598997,
           -9.604902220803538,
           -9.511436595617107,
           -9.417970970430694,
           -9.324505345244262,
           -9.23103972005783,
           -9.137574094871416,
           -9.044108469684984,
           -8.950642844498553,
           -8.857177219312122,
           -8.763711594125708,
           -8.670245968939277,
           -8.576780343752844,
           -8.48331471856643,
           -8.389849093379999,
           -8.296383468193568,
           -8.202917843007153,
           -8.109452217820722,
           -8.015986592634292,
           -7.922520967447876,
           -7.829055342261444,
           -7.735589717075014,
           -7.642124091888582,
           -7.54615616982357,
           -7.446792250170327,
           -7.347428330517086,
           -7.248064410863862,
           -7.148700491210619,
           -7.049336571557378,
           -6.949972651904154,
           -6.850608732250912,
           -6.751244812597669,
           -6.651880892944426,
           -6.552516973291203
          ],
          [
           -39.386076927518886,
           -39.42941173567563,
           -39.47274654383237,
           -39.516081351989115,
           -39.55941616014586,
           -39.6027509683026,
           -39.64608577645934,
           -39.68942058461609,
           -39.73275539277283,
           -39.77609020092957,
           -39.819425009086316,
           -39.86275981724305,
           -39.9060946253998,
           -39.949429433556546,
           -39.99276424171328,
           -40.03609904987003,
           -40.07943385802677,
           -40.12276866618351,
           -40.16610347434026,
           -40.209438282497004,
           -40.25277309065374,
           -40.29610789881049,
           -40.33944270696722,
           -40.38277751512397,
           -40.42611232328071,
           -40.469447131437455,
           -40.5127819395942,
           -40.556116747750934,
           -40.599451555907685,
           -40.64278636406443,
           -40.68612117222117,
           -40.72945598037791,
           -40.77279078853466,
           -40.8161255966914,
           -40.859460404848136,
           -40.90279521291613,
           -40.94489290499676,
           -40.98699059707738,
           -41.029088289158004,
           -41.07118598123863,
           -41.113283673319245,
           -41.155381365399876,
           -41.19747905748049,
           -41.23957674956112,
           -41.28167444164174,
           -41.32377213372236,
           -41.36586982580299,
           -41.407967517883606,
           -41.45006520996422,
           -41.49216290204486,
           -41.53426059412547,
           -41.5763582862061,
           -41.61845597828672,
           -41.660553670367335,
           -41.702651362447966,
           -41.74474905452858,
           -41.786846746609214,
           -41.82894443868983,
           -41.871042130770455,
           -41.91313982285108,
           -41.9552375149317,
           -41.99733520701233,
           -42.039432899092944,
           -42.08153059117357,
           -42.12362828325419,
           -42.16572597533482,
           -42.20782366741544,
           -42.24992135949606,
           -42.29201905157669,
           -42.334116743657304,
           -42.376214435737936,
           -42.41831212781855,
           -42.460409819899176,
           -42.5025075119798,
           -42.54460520406042,
           -42.58670289614105,
           -42.628800588221665,
           -42.67089828030229,
           -42.71299597238291,
           -42.75509366446353,
           -42.79719135654416,
           -42.83928904862478,
           -42.8813867407054,
           -42.923484432786026,
           -42.962249414648795,
           -43.000347854468004,
           -43.038446294287205,
           -43.07654473410641,
           -43.114643173925614,
           -43.15274161374482,
           -43.19084005356403,
           -43.22893849338323,
           -43.26703693320244,
           -43.30513537302165,
           -43.34323381284085,
           -43.38133225266006,
           -43.41943069247927,
           -43.45752913229847,
           -43.49562757211768,
           -43.53372601193688,
           -43.571824451756086,
           -43.609922891575295,
           -43.6480213313945,
           -43.686119771213704,
           -43.724218211032905,
           -43.762316650852114,
           -43.80041509067132,
           -43.83851353049052,
           -43.87661197030973,
           -43.91471041012893,
           -43.95280884994815,
           -43.99090728976735,
           -44.02900572958655,
           -44.06710416940576,
           -44.10520260922497,
           -44.143301049044176,
           -44.18139948886338,
           -44.219497928682586,
           -44.25759636850179,
           -44.295694808320995,
           -44.3337932481402,
           -44.371891687959405,
           -44.40999012777861,
           -44.448088567597814,
           -44.48618700741702,
           -44.52428544723623,
           -44.56238388705543,
           -44.60048232687463,
           -44.63858076669384,
           -44.67667920651305,
           -44.71477764633226,
           -44.75287608615147,
           -44.79124302408725,
           -44.82974421112468,
           -44.8682453981621,
           -44.90674658519953,
           -44.945247772236954,
           -44.98374895927438,
           -45.022250146311805,
           -45.06075133334923,
           -45.099252520386656,
           -45.13775370742408,
           -45.17625489446151,
           -45.21475608149893,
           -45.25325726853636,
           -45.29175845557378,
           -45.33025964261121,
           -45.368760829648636,
           -45.40726201668606,
           -45.44576320372349,
           -45.484264390760906,
           -45.52276557779834,
           -45.561266764835764,
           -45.59976795187318,
           -45.63826913891061,
           -45.676770325948034,
           -45.71527151298546,
           -45.75377270002289,
           -45.79227388706031,
           -45.83077507409774,
           -45.869276261135155,
           -45.90777744817259,
           -45.946278635210014,
           -45.98477982224744,
           -46.02328100928486,
           -46.06178219632229,
           -46.10028338335971,
           -46.04192838639038,
           -45.93514529741768,
           -45.82836220844498,
           -45.721579119472274,
           -45.61479603049957,
           -45.508012941526864,
           -45.40122985255417,
           -45.29444676358146,
           -45.18766367460875,
           -45.08088058563605,
           -44.97409749666334,
           -44.86731440769064,
           -44.76053131871794,
           -44.65374822974523,
           -44.54696514077253,
           -44.44018205179982,
           -44.33339896282712,
           -44.22661587385441,
           -44.11983278488171,
           -44.01304969590901,
           -43.9062666069363,
           -43.799483517963594,
           -43.6927004289909,
           -43.585917340018185,
           -43.47913425104549,
           -43.372351162072775,
           -43.26556807310007,
           -43.15878498412737,
           -43.05200189515466,
           -42.94521880618197,
           -42.83843571720925,
           -42.73165262823655,
           -42.62486953926385,
           -42.51808645029114,
           -42.411303361318446,
           -42.304520272345734,
           -42.197737183373036,
           -42.09095409440033,
           -41.98417100542762,
           -41.87738791645492,
           -41.770604827482224,
           -41.67904446863628,
           -41.61184054430351,
           -41.544636619970746,
           -41.47743269563798,
           -41.4102287713052,
           -41.34302484697243,
           -41.27582092263967,
           -41.2086169983069,
           -41.141413073974135,
           -41.07420914964136,
           -41.007005225308596,
           -40.93980130097583,
           -40.87259737664306,
           -40.8053934523103,
           -40.73818952797753,
           -40.67098560364476,
           -40.603781679311986,
           -40.53657775497922,
           -40.469373830646454,
           -40.40216990631369,
           -40.334965981980915,
           -40.26776205764815,
           -40.20055813331538,
           -40.13335420898262,
           -40.066150284649844,
           -39.99894636031708,
           -39.93174243598431,
           -39.86453851165154,
           -39.79733458731877,
           -39.73013066298601,
           -39.66292673865324,
           -39.59572281432047,
           -39.528518889987694,
           -39.461314965654935,
           -39.39411104132216,
           -39.326907116989396,
           -39.25970319265663,
           -39.19249926832386,
           -39.12529534399109,
           -39.058091419658325,
           -38.99088749532555,
           -38.923683570992786,
           -38.78815176560474,
           -38.584292079161415,
           -38.380432392718106,
           -38.1765727062748,
           -37.97271301983146,
           -37.76885333338815,
           -37.56499364694485,
           -37.36113396050152,
           -37.15727427405819,
           -36.9534145876149,
           -36.74955490117157,
           -36.54569521472824,
           -36.34183552828493,
           -36.13797584184162,
           -35.934116155398286,
           -35.730256468954984,
           -35.526396782511675,
           -35.322537096068345,
           -35.118677409625036,
           -34.91481772318173,
           -34.710958036738404,
           -34.50709835029507,
           -34.30323866385178,
           -34.09937897740845,
           -33.89551929096512,
           -33.69165960452182,
           -33.4877999180785,
           -33.28394023163518,
           -33.08008054519186,
           -32.87622085874855,
           -32.67236117230523,
           -32.46850148586189,
           -32.26464179941861,
           -32.060782112975275,
           -31.856922426531952,
           -31.653062740088643,
           -31.44920305364533,
           -31.245343367202004,
           -31.041483680758695,
           -30.837623994315386,
           -30.633764307872053,
           -30.429904621428747,
           -30.22604493498544,
           -30.022185248542108,
           -29.818325562098778,
           -29.614465875655487,
           -29.41060618921216,
           -29.20674650276883,
           -29.00288681632552,
           -28.799027129882212,
           -28.595167443438882,
           -28.391307756995573,
           -28.187448070552264,
           -27.98358838410894,
           -27.779728697665604,
           -27.57411755732422,
           -27.365433100921575,
           -27.156748644518927,
           -26.948064188116298,
           -26.73937973171367,
           -26.530695275311025,
           -26.322010818908396,
           -26.113326362505767,
           -25.90464190610312,
           -25.69595744970049,
           -25.487272993297864,
           -25.278588536895217,
           -25.06990408049257,
           -24.861219624089955,
           -24.65253516768731,
           -24.44385071128466,
           -24.23516625488204,
           -24.026481798479406,
           -23.81779734207676,
           -23.60911288567413,
           -23.400428429271507,
           -23.191743972868856,
           -22.98305951646623,
           -22.774375060063598,
           -22.56569060366095,
           -22.357006147258303,
           -22.148321690855674,
           -21.939637234453052,
           -21.781212251468162,
           -21.72330621531877,
           -21.665400179169385,
           -21.60749414301999,
           -21.5495881068706,
           -21.491682070721215,
           -21.43377603457182,
           -21.375869998422424,
           -21.317963962273044,
           -21.26005792612365,
           -21.202151889974253,
           -21.144245853824867,
           -21.08633981767548,
           -21.028433781526083,
           -20.970527745376696,
           -20.912621709227306,
           -20.854715673077912,
           -20.796809636928526,
           -20.738903600779135,
           -20.680997564629738,
           -20.623091528480344,
           -20.56518549233096,
           -20.507279456181568,
           -20.449373420032178,
           -20.391467383882787,
           -20.3335613477334,
           -20.275655311584003,
           -20.217749275434613,
           -20.159843239285227,
           -20.101937203135833,
           -20.04403116698644,
           -19.986125130837056,
           -19.928219094687663,
           -19.87031305853827,
           -19.812407022388875,
           -19.754500986239492,
           -19.696594950090095,
           -19.638688913940705,
           -19.580782877791318,
           -19.52331790982148,
           -19.46601905722798,
           -19.408720204634484,
           -19.35142135204098,
           -19.294122499447475,
           -19.236823646853978,
           -19.17952479426048,
           -19.122225941666976,
           -19.064927089073475,
           -19.007628236479977,
           -18.950329383886473,
           -18.893030531292975,
           -18.835731678699478,
           -18.778432826105973,
           -18.72113397351247,
           -18.663835120918975,
           -18.606536268325474,
           -18.54923741573197,
           -18.49193856313847,
           -18.43463971054497,
           -18.377340857951467,
           -18.32004200535797,
           -18.26274315276447,
           -18.205444300170967,
           -18.14814544757747,
           -18.09084659498397,
           -18.033547742390468,
           -17.976248889796963,
           -17.91895003720347,
           -17.861651184609965,
           -17.80435233201646,
           -17.747053479422963,
           -17.689754626829465,
           -17.632455774235964,
           -17.575156921642463,
           -17.517858069048962,
           -17.460559216455458,
           -17.403260363861957,
           -17.345961511268463,
           -17.28866265867496,
           -17.231363806081458,
           -17.174064953487957,
           -17.11676610089446,
           -17.059467248300955,
           -16.98591223253201,
           -16.831076400885763,
           -16.676240569239514,
           -16.521404737593272,
           -16.366568905947055,
           -16.21173307430081,
           -16.056897242654564,
           -15.902061411008347,
           -15.747225579362103,
           -15.59238974771586,
           -15.437553916069643,
           -15.282718084423399,
           -15.127882252777152,
           -14.973046421130906,
           -14.81821058948469,
           -14.663374757838447,
           -14.508538926192202,
           -14.353703094545986,
           -14.198867262899743,
           -14.044031431253494,
           -13.88919559960728,
           -13.734359767961035,
           -13.579523936314791,
           -13.424688104668572,
           -13.269852273022329,
           -13.115016441376083,
           -12.960180609729838,
           -12.805344778083624,
           -12.65355827822718,
           -12.504914916890856,
           -12.356271555554558,
           -12.207628194218234,
           -12.058984832881908,
           -11.910341471545609,
           -11.761698110209284,
           -11.613054748872962,
           -11.464411387536634,
           -11.315768026200338,
           -11.167124664864012,
           -11.018481303527686,
           -10.869837942191388,
           -10.721194580855062,
           -10.604738232272847,
           -10.511272607086433,
           -10.417806981900002,
           -10.324341356713573,
           -10.230875731527156,
           -10.137410106340726,
           -10.043944481154293,
           -9.950478855967862,
           -9.85701323078145,
           -9.763547605595019,
           -9.670081980408584,
           -9.576616355222171,
           -9.483150730035739,
           -9.389685104849308,
           -9.29224260815014,
           -9.192878688496897,
           -9.093514768843654,
           -8.994150849190412,
           -8.894786929537188,
           -8.795423009883947,
           -8.696059090230703,
           -8.59669517057748,
           -8.497331250924237,
           -8.397967331270996,
           -8.298603411617773,
           -8.19923949196453,
           -8.099875572311287,
           -8.000511652658062,
           -7.90114773300482,
           -7.8017838133515784,
           -7.702419893698336,
           -7.6030559740451125,
           -7.50369205439187,
           -7.404328134738629,
           -7.304964215085404,
           -7.205600295432161,
           -7.106236375778918,
           -7.006872456125695,
           -6.907508536472453,
           -6.808144616819211,
           -6.7087806971659685,
           -6.609416777512745
          ],
          [
           -39.0554780333826,
           -39.09881284153934,
           -39.142147649696085,
           -39.18548245785282,
           -39.22881726600957,
           -39.272152074166314,
           -39.31548688232305,
           -39.3588216904798,
           -39.40215649863654,
           -39.445491306793286,
           -39.48882611495002,
           -39.53216092310677,
           -39.57549573126351,
           -39.61883053942025,
           -39.662165347576995,
           -39.705500155733745,
           -39.74883496389048,
           -39.792169772047224,
           -39.835504580203974,
           -39.8782208309084,
           -39.92031852298902,
           -39.96241621506964,
           -40.00451390715027,
           -40.04661159923089,
           -40.08870929131152,
           -40.130806983392134,
           -40.17290467547276,
           -40.21500236755338,
           -40.257100059634006,
           -40.29919775171462,
           -40.34129544379525,
           -40.38339313587587,
           -40.425490827956494,
           -40.46758852003712,
           -40.509686212117735,
           -40.55178390419836,
           -40.59388159627898,
           -40.63597928835961,
           -40.67807698044023,
           -40.720174672520855,
           -40.76227236460147,
           -40.804370056682096,
           -40.84646774876272,
           -40.888565440843344,
           -40.93066313292396,
           -40.972760825004585,
           -41.014858517085216,
           -41.05695620916583,
           -41.09905390124645,
           -41.14115159332708,
           -41.1832492854077,
           -41.22534697748833,
           -41.267444669568945,
           -41.30954236164956,
           -41.35164005373019,
           -41.39373774581081,
           -41.43583543789144,
           -41.47793312997206,
           -41.520030822052675,
           -41.562128514133306,
           -41.60422620621392,
           -41.64632389829455,
           -41.68842159037517,
           -41.73051928245579,
           -41.77261697453642,
           -41.81471466661704,
           -41.85681235869767,
           -41.898910050778284,
           -41.941007742858915,
           -41.98310543493953,
           -42.025203127020156,
           -42.06730081910078,
           -42.109398511181396,
           -42.15149620326203,
           -42.193593895342644,
           -42.23569158742327,
           -42.27778927950389,
           -42.31988697158451,
           -42.36198466366514,
           -42.40408235574576,
           -42.44618004782638,
           -42.488277739907005,
           -42.53037543198762,
           -42.572473124068246,
           -42.61123810593102,
           -42.649336545750224,
           -42.68743498556943,
           -42.72553342538864,
           -42.76363186520784,
           -42.80173030502705,
           -42.83982874484625,
           -42.87792718466545,
           -42.91602562448466,
           -42.95412406430387,
           -42.99222250412308,
           -43.03032094394228,
           -43.068419383761494,
           -43.10651782358069,
           -43.144616263399904,
           -43.182714703219105,
           -43.22081314303831,
           -43.25891158285752,
           -43.29701002267672,
           -43.335108462495924,
           -43.37320690231513,
           -43.41130534213434,
           -43.44940378195355,
           -43.48750222177275,
           -43.52560066159195,
           -43.56369910141116,
           -43.60179754123037,
           -43.63989598104958,
           -43.67799442086878,
           -43.71609286068798,
           -43.75419130050719,
           -43.792289740326396,
           -43.830388180145604,
           -43.868486619964806,
           -43.906585059784014,
           -43.944683499603215,
           -43.98278193942242,
           -44.02088037924163,
           -44.05897881906083,
           -44.09707725888004,
           -44.13517569869924,
           -44.17327413851845,
           -44.21137257833766,
           -44.24947101815686,
           -44.28756945797606,
           -44.32566789779527,
           -44.36376633761448,
           -44.40186477743369,
           -44.439963217252895,
           -44.4780616570721,
           -44.5161600968913,
           -44.554258536710506,
           -44.592356976529715,
           -44.63045541634892,
           -44.668553856168124,
           -44.706652295987325,
           -44.744750735806534,
           -44.78284917562574,
           -44.82094761544495,
           -44.85904605526415,
           -44.89714449508336,
           -44.93524293490257,
           -44.97334137472177,
           -45.01143981454098,
           -45.04960537908725,
           -45.08810656612467,
           -45.1266077531621,
           -45.16510894019952,
           -45.20361012723695,
           -45.24211131427437,
           -45.2806125013118,
           -45.319113688349226,
           -45.357614875386645,
           -45.39611606242407,
           -45.434617249461496,
           -45.47311843649892,
           -45.511619623536355,
           -45.55012081057378,
           -45.5886219976112,
           -45.627123184648624,
           -45.66562437168605,
           -45.704125558723476,
           -45.7426267457609,
           -45.684271748791566,
           -45.57748865981887,
           -45.470705570846164,
           -45.36392248187346,
           -45.257139392900754,
           -45.15035630392805,
           -45.043573214955344,
           -44.93679012598264,
           -44.830007037009935,
           -44.72322394803723,
           -44.616440859064525,
           -44.50965777009183,
           -44.40287468111912,
           -44.29609159214642,
           -44.18930850317371,
           -44.08252541420101,
           -43.9757423252283,
           -43.8689592362556,
           -43.762176147282894,
           -43.65539305831019,
           -43.548609969337484,
           -43.441826880364786,
           -43.36853381642541,
           -43.30132989209264,
           -43.23412596775987,
           -43.16692204342711,
           -43.099718119094334,
           -43.032514194761575,
           -42.9653102704288,
           -42.898106346096036,
           -42.83090242176327,
           -42.7636984974305,
           -42.69649457309773,
           -42.62929064876496,
           -42.56208672443219,
           -42.494882800099425,
           -42.42767887576666,
           -42.36047495143389,
           -42.29327102710112,
           -42.226067102768354,
           -42.15886317843559,
           -42.091659254102815,
           -42.02445532977005,
           -41.957251405437276,
           -41.89004748110452,
           -41.822843556771744,
           -41.75563963243898,
           -41.68843570810621,
           -41.62123178377344,
           -41.55402785944067,
           -41.48682393510791,
           -41.419620010775134,
           -41.352416086442375,
           -41.2852121621096,
           -41.218008237776836,
           -41.15080431344407,
           -41.0836003891113,
           -41.01639646477853,
           -40.94919254044576,
           -40.88198861611299,
           -40.81478469178023,
           -40.74758076744746,
           -40.680376843114686,
           -40.61317291878192,
           -40.545968994449154,
           -40.478765070116395,
           -40.411561145783615,
           -40.34435722145085,
           -40.277153297118076,
           -40.20994937278531,
           -40.142745448452544,
           -40.07554152411977,
           -40.00833759978701,
           -39.94113367545424,
           -39.87392975112147,
           -39.80672582678871,
           -39.739521902455934,
           -39.672317978123175,
           -39.6051140537904,
           -39.53791012945763,
           -39.47070620512487,
           -39.4035022807921,
           -39.33629835645933,
           -39.20076655107128,
           -38.99690686462795,
           -38.79304717818465,
           -38.589187491741335,
           -38.38532780529801,
           -38.181468118854696,
           -37.97760843241139,
           -37.773748745968064,
           -37.569889059524726,
           -37.366029373081446,
           -37.16216968663811,
           -36.958310000194786,
           -36.75445031375148,
           -36.55059062730817,
           -36.34673094086484,
           -36.14287125442153,
           -35.93901156797822,
           -35.73515188153489,
           -35.53129219509158,
           -35.32743250864827,
           -35.123572822204935,
           -34.91971313576161,
           -34.71585344931832,
           -34.511993762874994,
           -34.308134076431664,
           -34.104274389988355,
           -33.900414703545046,
           -33.696555017101716,
           -33.49269533065841,
           -33.287117238834036,
           -33.07843278243139,
           -32.86974832602874,
           -32.66106386962613,
           -32.45237941322348,
           -32.24369495682084,
           -32.0350105004182,
           -31.826326044015584,
           -31.617641587612933,
           -31.408957131210308,
           -31.200272674807678,
           -30.991588218405028,
           -30.7829037620024,
           -30.574219305599772,
           -30.365534849197125,
           -30.156850392794475,
           -29.94816593639187,
           -29.73948147998922,
           -29.530797023586572,
           -29.322112567183943,
           -29.113428110781317,
           -28.904743654378667,
           -28.69605919797604,
           -28.48737474157341,
           -28.278690285170768,
           -28.070005828768117,
           -27.86132137236551,
           -27.65263691596286,
           -27.44395245956021,
           -27.235268003157586,
           -27.026583546754956,
           -26.81789909035231,
           -26.609214633949684,
           -26.40053017754705,
           -26.191845721144404,
           -25.983161264741774,
           -25.774476808339152,
           -25.5657923519365,
           -25.35710789553385,
           -25.148423439131243,
           -24.9397389827286,
           -24.73105452632595,
           -24.52237006992332,
           -24.31368561352069,
           -24.10500115711804,
           -23.89631670071542,
           -23.687632244312788,
           -23.47894778791014,
           -23.27026333150751,
           -23.06157887510489,
           -22.85289441870224,
           -22.64420996229959,
           -22.435525505896962,
           -22.226841049494336,
           -22.068416066509446,
           -22.01051003036006,
           -21.952603994210673,
           -21.89469795806128,
           -21.83679192191189,
           -21.7788858857625,
           -21.720979849613105,
           -21.66307381346371,
           -21.60516777731433,
           -21.547261741164938,
           -21.48935570501554,
           -21.43144966886615,
           -21.373543632716764,
           -21.31563759656737,
           -21.25773156041798,
           -21.199825524268594,
           -21.141919488119196,
           -21.08401345196981,
           -21.02610741582042,
           -20.968201379671026,
           -20.910295343521632,
           -20.852389307372242,
           -20.79448327122286,
           -20.73657723507346,
           -20.678671198924075,
           -20.620765162774685,
           -20.56285912662529,
           -20.5049530904759,
           -20.44704705432651,
           -20.38914101817712,
           -20.331234982027723,
           -20.27332894587834,
           -20.215422909728947,
           -20.157516873579556,
           -20.099610837430163,
           -20.041704801280773,
           -19.983798765131382,
           -19.925892728981992,
           -19.867986692832606,
           -19.810080656683212,
           -19.752174620533822,
           -19.69426858438443,
           -19.63636254823504,
           -19.578456512085644,
           -19.520550475936258,
           -19.46264443978687,
           -19.404738403637474,
           -19.346832367488087,
           -19.2889263313387,
           -19.231020295189303,
           -19.173114259039913,
           -19.11520822289053,
           -19.057302186741133,
           -18.999396150591735,
           -18.941490114442352,
           -18.883584078292962,
           -18.825678042143565,
           -18.76777200599418,
           -18.70986596984479,
           -18.651959933695395,
           -18.594053897546008,
           -18.536147861396618,
           -18.478241825247224,
           -18.420335789097834,
           -18.362429752948447,
           -18.304523716799054,
           -18.24661768064966,
           -18.188711644500277,
           -18.130805608350883,
           -18.072899572201486,
           -18.0149935360521,
           -17.957087499902713,
           -17.899181463753315,
           -17.84127542760393,
           -17.78336939145454,
           -17.726024715161252,
           -17.668725862567747,
           -17.611427009974257,
           -17.554128157380752,
           -17.496829304787248,
           -17.43953045219375,
           -17.382231599600253,
           -17.32493274700675,
           -17.2513777312378,
           -17.096541899591553,
           -16.941706067945304,
           -16.786870236299062,
           -16.632034404652845,
           -16.477198573006604,
           -16.322362741360358,
           -16.167526909714137,
           -16.012691078067895,
           -15.85785524642165,
           -15.703019414775433,
           -15.54818358312919,
           -15.393347751482946,
           -15.2385119198367,
           -15.083676088190483,
           -14.92884025654424,
           -14.774004424897992,
           -14.619168593251779,
           -14.464332761605535,
           -14.309496929959288,
           -14.154661098313074,
           -13.999825266666825,
           -13.84498943502058,
           -13.690153603374366,
           -13.534341206370188,
           -13.37848634223892,
           -13.222631478107656,
           -13.066776613976419,
           -12.910921749845151,
           -12.755066885713887,
           -12.599212021582654,
           -12.443357157451388,
           -12.287502293320122,
           -12.131647429188885,
           -11.975792565057619,
           -11.819937700926355,
           -11.664082836795089,
           -11.508227972663851,
           -11.352373108532587,
           -11.196518244401322,
           -11.040663380270084,
           -10.88480851613882,
           -10.761218784729378,
           -10.660675576692679,
           -10.56013236865596,
           -10.459589160619242,
           -10.359045952582543,
           -10.258502744545822,
           -10.157959536509104,
           -10.057416328472387,
           -9.956873120435688,
           -9.85632991239897,
           -9.75578670436225,
           -9.655243496325552,
           -9.554700288288833,
           -9.454157080252116,
           -9.353613872215416,
           -9.253070664178697,
           -9.152527456141978,
           -9.05198424810526,
           -8.95168673375873,
           -8.85232281410549,
           -8.752958894452247,
           -8.653594974799024,
           -8.554231055145781,
           -8.454867135492538,
           -8.355503215839315,
           -8.256139296186072,
           -8.156775376532831,
           -8.057411456879606,
           -7.9580475372263635,
           -7.858683617573121,
           -7.759319697919878,
           -7.659955778266655,
           -7.560591858613413,
           -7.461227938960171,
           -7.361864019306946,
           -7.262500099653704,
           -7.163136180000462,
           -7.063772260347238,
           -6.964408340693996,
           -6.8650444210407535,
           -6.765680501387512,
           -6.6663165817342875
          ],
          [
           -38.72487913924631,
           -38.76821394740306,
           -38.8115487555598,
           -38.85364644890067,
           -38.89574414098129,
           -38.93784183306191,
           -38.979939525142534,
           -39.02203721722316,
           -39.06413490930378,
           -39.106232601384406,
           -39.14833029346503,
           -39.19042798554565,
           -39.23252567762627,
           -39.274623369706894,
           -39.31672106178752,
           -39.35881875386814,
           -39.400916445948766,
           -39.44301413802938,
           -39.48511183011001,
           -39.52720952219063,
           -39.56930721427125,
           -39.61140490635187,
           -39.653502598432496,
           -39.69560029051312,
           -39.737697982593744,
           -39.77979567467436,
           -39.82189336675499,
           -39.86399105883561,
           -39.90608875091623,
           -39.94818644299686,
           -39.990284135077474,
           -40.032381827158105,
           -40.07447951923872,
           -40.116577211319346,
           -40.15867490339997,
           -40.200772595480586,
           -40.24287028756122,
           -40.284967979641834,
           -40.32706567172246,
           -40.36916336380308,
           -40.4112610558837,
           -40.45335874796433,
           -40.49545644004495,
           -40.53755413212557,
           -40.579651824206195,
           -40.62174951628682,
           -40.66384720836744,
           -40.70594490044806,
           -40.748042592528684,
           -40.79014028460931,
           -40.83223797668993,
           -40.874335668770556,
           -40.91643336085117,
           -40.9585310529318,
           -41.00062874501242,
           -41.042726437093044,
           -41.08482412917367,
           -41.12692182125429,
           -41.169019513334916,
           -41.21111720541554,
           -41.253214897496164,
           -41.29531258957679,
           -41.337410281657405,
           -41.37950797373803,
           -41.421605665818646,
           -41.46370335789928,
           -41.505801049979894,
           -41.54789874206052,
           -41.58999643414114,
           -41.632094126221766,
           -41.67419181830239,
           -41.71628951038301,
           -41.75838720246363,
           -41.800484894544255,
           -41.84258258662488,
           -41.8846802787055,
           -41.92677797078612,
           -41.96887566286674,
           -42.01097335494737,
           -42.05307104702799,
           -42.095168739108615,
           -42.13726643118923,
           -42.179364123269856,
           -42.22146181535048,
           -42.26022679721326,
           -42.298325237032465,
           -42.336423676851666,
           -42.37452211667087,
           -42.41262055649008,
           -42.450718996309284,
           -42.488817436128485,
           -42.526915875947694,
           -42.565014315766895,
           -42.60311275558611,
           -42.64121119540532,
           -42.67930963522451,
           -42.71740807504373,
           -42.75550651486292,
           -42.79360495468214,
           -42.831703394501346,
           -42.86980183432055,
           -42.90790027413975,
           -42.94599871395896,
           -42.984097153778166,
           -43.02219559359737,
           -43.060294033416575,
           -43.098392473235776,
           -43.136490913054985,
           -43.17458935287419,
           -43.2126877926934,
           -43.2507862325126,
           -43.288884672331804,
           -43.32698311215101,
           -43.36508155197022,
           -43.40317999178943,
           -43.44127843160863,
           -43.47937687142783,
           -43.51747531124704,
           -43.55557375106625,
           -43.59367219088546,
           -43.631770630704665,
           -43.66986907052386,
           -43.70796751034307,
           -43.746065950162276,
           -43.784164389981484,
           -43.822262829800685,
           -43.86036126961989,
           -43.898459709439095,
           -43.9365581492583,
           -43.97465658907751,
           -44.01275502889672,
           -44.05085346871593,
           -44.08895190853512,
           -44.12705034835433,
           -44.16514878817354,
           -44.20324722799275,
           -44.24134566781195,
           -44.27944410763116,
           -44.31754254745036,
           -44.35564098726957,
           -44.393739427088775,
           -44.431837866907976,
           -44.469936306727185,
           -44.50803474654639,
           -44.546133186365594,
           -44.5842316261848,
           -44.622330066004004,
           -44.66042850582321,
           -44.69852694564242,
           -44.73662538546162,
           -44.77472382528083,
           -44.81282226510004,
           -44.85092070491924,
           -44.88901914473844,
           -44.92711758455765,
           -44.96521602437686,
           -45.003314464196066,
           -45.04141290401527,
           -45.07951134383447,
           -45.11760978365368,
           -45.155708223472885,
           -45.193806663292094,
           -45.231905103111295,
           -45.270003542930496,
           -45.30810198274971,
           -45.34646892112466,
           -45.384970108162086,
           -45.32661511119276,
           -45.219832022220054,
           -45.125227088547305,
           -45.05802316421454,
           -44.99081923988177,
           -44.923615315549,
           -44.856411391216234,
           -44.78920746688347,
           -44.7220035425507,
           -44.654799618217936,
           -44.58759569388516,
           -44.5203917695524,
           -44.453187845219624,
           -44.38598392088686,
           -44.31877999655409,
           -44.251576072221326,
           -44.18437214788856,
           -44.11716822355579,
           -44.04996429922302,
           -43.982760374890255,
           -43.91555645055748,
           -43.84835252622471,
           -43.78114860189194,
           -43.71394467755918,
           -43.64674075322641,
           -43.579536828893644,
           -43.51233290456088,
           -43.445128980228105,
           -43.37792505589534,
           -43.31072113156257,
           -43.2435172072298,
           -43.176313282897034,
           -43.10910935856427,
           -43.041905434231495,
           -42.97470150989873,
           -42.90749758556596,
           -42.84029366123319,
           -42.77308973690043,
           -42.70588581256766,
           -42.638681888234885,
           -42.571477963902126,
           -42.50427403956935,
           -42.43707011523659,
           -42.36986619090382,
           -42.30266226657105,
           -42.235458342238275,
           -42.16825441790551,
           -42.10105049357274,
           -42.03384656923997,
           -41.96664264490721,
           -41.89943872057444,
           -41.83223479624167,
           -41.765030871908905,
           -41.69782694757613,
           -41.63062302324337,
           -41.5634190989106,
           -41.49621517457783,
           -41.42901125024507,
           -41.361807325912295,
           -41.29460340157953,
           -41.22739947724676,
           -41.16019555291399,
           -41.092991628581224,
           -41.02578770424845,
           -40.958583779915685,
           -40.89137985558292,
           -40.82417593125015,
           -40.75697200691738,
           -40.689768082584614,
           -40.62256415825185,
           -40.55536023391908,
           -40.48815630958631,
           -40.42095238525354,
           -40.35374846092077,
           -40.286544536588,
           -40.219340612255245,
           -40.15213668792247,
           -40.084932763589705,
           -40.01772883925694,
           -39.950524914924166,
           -39.8833209905914,
           -39.81611706625863,
           -39.74891314192586,
           -39.61338133653782,
           -39.40952165009449,
           -39.20566196365118,
           -39.00011692034384,
           -38.7914324639412,
           -38.58274800753857,
           -38.37406355113594,
           -38.16537909473329,
           -37.956694638330646,
           -37.74801018192803,
           -37.53932572552538,
           -37.33064126912274,
           -37.121956812720114,
           -36.913272356317485,
           -36.704587899914834,
           -36.495903443512205,
           -36.28721898710958,
           -36.07853453070693,
           -35.8698500743043,
           -35.66116561790167,
           -35.45248116149902,
           -35.24379670509638,
           -35.03511224869377,
           -34.82642779229113,
           -34.61774333588848,
           -34.40905887948585,
           -34.20037442308322,
           -33.991689966680575,
           -33.783005510277945,
           -33.574321053875316,
           -33.36563659747267,
           -33.15695214107002,
           -32.948267684667414,
           -32.73958322826476,
           -32.53089877186212,
           -32.32221431545949,
           -32.11352985905686,
           -31.904845402654214,
           -31.696160946251588,
           -31.48747648984896,
           -31.278792033446308,
           -31.070107577043682,
           -30.86142312064105,
           -30.6527386642384,
           -30.444054207835755,
           -30.235369751433147,
           -30.02667655973041,
           -29.81797463183969,
           -29.60927270394899,
           -29.400570776058284,
           -29.191868848167566,
           -28.983166920276865,
           -28.77446499238616,
           -28.565763064495442,
           -28.35706113660472,
           -28.148359208714034,
           -27.939657280823315,
           -27.73095535293259,
           -27.52225342504189,
           -27.313551497151188,
           -27.104849569260466,
           -26.89614764136976,
           -26.68744571347906,
           -26.478743785588343,
           -26.27004185769764,
           -26.061339929806934,
           -25.852638001916215,
           -25.643936074025497,
           -25.43523414613481,
           -25.22653221824409,
           -25.01783029035337,
           -24.809128362462666,
           -24.600426434571965,
           -24.391724506681243,
           -24.183022578790542,
           -23.97432065089984,
           -23.765618723009116,
           -23.556916795118415,
           -23.348214867227714,
           -23.139512939336992,
           -22.930811011446266,
           -22.722109083555566,
           -22.513407155664865,
           -22.354918381991936,
           -22.29685591675457,
           -22.238793451517196,
           -22.18073098627982,
           -22.122717861516005,
           -22.064735407527678,
           -22.006752953539348,
           -21.948770499551017,
           -21.890788045562697,
           -21.83280559157437,
           -21.77482313758604,
           -21.716840683597717,
           -21.65885822960939,
           -21.600875775621063,
           -21.54289332163274,
           -21.484910867644412,
           -21.426928413656082,
           -21.36894595966776,
           -21.310963505679435,
           -21.252981051691105,
           -21.194998597702774,
           -21.13701614371445,
           -21.079033689726124,
           -21.021051235737797,
           -20.963068781749474,
           -20.90508632776115,
           -20.847103873772816,
           -20.789121419784493,
           -20.73113896579617,
           -20.673156511807843,
           -20.61517405781951,
           -20.557191603831193,
           -20.49920914984286,
           -20.44122669585453,
           -20.38324424186621,
           -20.32526178787788,
           -20.26727933388955,
           -20.209296879901228,
           -20.151314425912904,
           -20.093331971924577,
           -20.03534951793625,
           -19.977367063947927,
           -19.919384609959597,
           -19.861402155971266,
           -19.803419701982943,
           -19.74543724799462,
           -19.68745479400629,
           -19.629472340017966,
           -19.571489886029642,
           -19.513507432041308,
           -19.455524978052985,
           -19.397542524064665,
           -19.33956007007633,
           -19.281577616088004,
           -19.223595162099684,
           -19.165612708111354,
           -19.107630254123023,
           -19.0496478001347,
           -18.991665346146373,
           -18.933682892158043,
           -18.875700438169723,
           -18.8177179841814,
           -18.75973553019307,
           -18.701753076204742,
           -18.64377062221642,
           -18.58578816822809,
           -18.527805714239758,
           -18.469823260251438,
           -18.41184080626311,
           -18.35385835227478,
           -18.295875898286457,
           -18.23789344429813,
           -18.1799109903098,
           -18.121928536321477,
           -18.063946082333153,
           -18.005963628344823,
           -17.947981174356492,
           -17.889998720368176,
           -17.832016266379846,
           -17.774033812391515,
           -17.71605135840319,
           -17.658068904414865,
           -17.600086450426538,
           -17.52477939149749,
           -17.36284930786479,
           -17.200919224232088,
           -17.038989140599387,
           -16.87705905696672,
           -16.715128973334014,
           -16.553198889701317,
           -16.391268806068645,
           -16.229338722435944,
           -16.067408638803244,
           -15.905478555170573,
           -15.743548471537874,
           -15.581618387905174,
           -15.419688304272475,
           -15.261674638405417,
           -15.105819774274153,
           -14.949964910142889,
           -14.794110046011651,
           -14.638255181880385,
           -14.48240031774912,
           -14.326545453617882,
           -14.170690589486618,
           -14.014835725355354,
           -13.858980861224119,
           -13.703125997092853,
           -13.547271132961587,
           -13.39141626883032,
           -13.235561404699082,
           -13.079706540567816,
           -12.923851676436552,
           -12.767996812305316,
           -12.61214194817405,
           -12.456287084042785,
           -12.30043221991155,
           -12.144577355780283,
           -11.988722491649018,
           -11.832867627517754,
           -11.677012763386516,
           -11.52115789925525,
           -11.365303035123983,
           -11.209448170992747,
           -11.053593306861483,
           -10.930003575452043,
           -10.829460367415344,
           -10.728917159378623,
           -10.628373951341906,
           -10.527830743305206,
           -10.427287535268487,
           -10.32674432723177,
           -10.226201119195052,
           -10.125657911158351,
           -10.025114703121634,
           -9.924571495084914,
           -9.824028287048217,
           -9.723485079011498,
           -9.62294187097478,
           -9.522398662938079,
           -9.421855454901362,
           -9.321312246864643,
           -9.220769038827925,
           -9.120225830791224,
           -9.019682622754507,
           -8.919139414717788,
           -8.81859620668109,
           -8.71805299864437,
           -8.617509790607652,
           -8.516966582570952,
           -8.416423374534235,
           -8.315880166497516,
           -8.215336958460817,
           -8.111652899625573,
           -8.005092875941777,
           -7.898532852257984,
           -7.791972828574206,
           -7.685412804890411,
           -7.578852781206615,
           -7.472292757522837,
           -7.365732733839042,
           -7.259172710155247,
           -7.15261268647147,
           -7.046052662787674,
           -6.939492639103877,
           -6.8329326154200825,
           -6.726372591736306
          ],
          [
           -38.38130006041326,
           -38.421999634473465,
           -38.46269920853367,
           -38.50339878259388,
           -38.54409835665409,
           -38.58479793071429,
           -38.62549750477449,
           -38.6661970788347,
           -38.706896652894905,
           -38.74759622695511,
           -38.788295801015316,
           -38.82899537507553,
           -38.869694949135734,
           -38.91039452319593,
           -38.95109409725614,
           -38.99249273164048,
           -39.034590423721106,
           -39.07668811580172,
           -39.11878580788235,
           -39.16088349996297,
           -39.202981192043595,
           -39.24507888412422,
           -39.28717657620484,
           -39.32927426828547,
           -39.37137196036609,
           -39.41346965244671,
           -39.45556734452733,
           -39.497665036607955,
           -39.53976272868858,
           -39.581860420769196,
           -39.62395811284982,
           -39.666055804930444,
           -39.70815349701107,
           -39.75025118909169,
           -39.792348881172316,
           -39.83444657325293,
           -39.87654426533356,
           -39.91864195741418,
           -39.960739649494805,
           -40.00283734157543,
           -40.044935033656046,
           -40.08703272573667,
           -40.129130417817294,
           -40.17122810989792,
           -40.21332580197854,
           -40.255423494059166,
           -40.29752118613979,
           -40.339618878220406,
           -40.38171657030103,
           -40.423814262381654,
           -40.46591195446227,
           -40.5080096465429,
           -40.55010733862352,
           -40.59220503070414,
           -40.63430272278477,
           -40.676400414865384,
           -40.718498106946015,
           -40.76059579902663,
           -40.802693491107256,
           -40.84479118318788,
           -40.886888875268504,
           -40.92898656734912,
           -40.971084259429745,
           -41.01318195151037,
           -41.05527964359099,
           -41.09737733567162,
           -41.13947502775224,
           -41.18157271983286,
           -41.22367041191348,
           -41.265768103994105,
           -41.30786579607473,
           -41.34996348815535,
           -41.39206118023597,
           -41.434158872316594,
           -41.47625656439722,
           -41.51835425647784,
           -41.560451948558466,
           -41.60254964063908,
           -41.64464733271971,
           -41.68674502480033,
           -41.728842716880955,
           -41.77094040896157,
           -41.813038101042196,
           -41.85513579312282,
           -41.893317712470925,
           -41.930716477272526,
           -41.968115242074134,
           -42.005514006875735,
           -42.04291277167734,
           -42.08031153647894,
           -42.11771030128054,
           -42.15510906608215,
           -42.19250783088375,
           -42.22990659568535,
           -42.26730536048696,
           -42.30470412528855,
           -42.34210289009017,
           -42.37950165489176,
           -42.41713364535677,
           -42.45523208517598,
           -42.49333052499519,
           -42.531428964814395,
           -42.5695274046336,
           -42.6076258444528,
           -42.645724284272006,
           -42.683822724091215,
           -42.72192116391042,
           -42.76001960372963,
           -42.79811804354883,
           -42.836216483368034,
           -42.87431492318724,
           -42.91241336300645,
           -42.95051180282566,
           -42.98861024264486,
           -43.02670868246406,
           -43.06480712228327,
           -43.10290556210248,
           -43.14100400192168,
           -43.17910244174088,
           -43.21720088156009,
           -43.2552993213793,
           -43.293397761198506,
           -43.331496201017714,
           -43.369594640836915,
           -43.40769308065612,
           -43.445791520475325,
           -43.48388996029453,
           -43.52198840011374,
           -43.56008683993294,
           -43.59818527975215,
           -43.63628371957135,
           -43.67438215939056,
           -43.71248059920977,
           -43.75057903902897,
           -43.78867747884818,
           -43.82677591866738,
           -43.86487435848659,
           -43.9029727983058,
           -43.941071238125005,
           -43.979169677944206,
           -44.017268117763415,
           -44.055366557582616,
           -44.093464997401824,
           -44.131563437221025,
           -44.169661877040234,
           -44.207760316859435,
           -44.24585875667864,
           -44.28395719649785,
           -44.32205563631705,
           -44.36015407613627,
           -44.39825251595547,
           -44.43635095577467,
           -44.47444939559388,
           -44.51254783541309,
           -44.550646275232296,
           -44.5887447150515,
           -44.6268431548707,
           -44.66494159468991,
           -44.703040034509115,
           -44.74113847432832,
           -44.779236914147525,
           -44.81733535396673,
           -44.855433793785934,
           -44.89353223360514,
           -44.93163067342435,
           -44.96972911324355,
           -45.00782755306276,
           -44.99857962231761,
           -44.96565850629029,
           -44.93273739026297,
           -44.899816274235654,
           -44.86689515820833,
           -44.83397404218101,
           -44.801052926153695,
           -44.76813181012636,
           -44.73521069409905,
           -44.70228957807173,
           -44.6693684620444,
           -44.636447346017086,
           -44.60352622998977,
           -44.57060511396245,
           -44.537683997935126,
           -44.50476288190781,
           -44.471841765880484,
           -44.41958160666585,
           -44.352377682333085,
           -44.28517375800032,
           -44.217969833667546,
           -44.15076590933477,
           -44.08356198500201,
           -44.01635806066924,
           -43.949154136336475,
           -43.88195021200371,
           -43.814746287670935,
           -43.74754236333817,
           -43.680338439005396,
           -43.61313451467263,
           -43.545930590339864,
           -43.4787266660071,
           -43.41152274167433,
           -43.34431881734156,
           -43.27711489300879,
           -43.20991096867602,
           -43.142707044343254,
           -43.07550312001049,
           -43.00829919567772,
           -42.94109527134495,
           -42.87389134701219,
           -42.80668742267942,
           -42.73948349834665,
           -42.67227957401388,
           -42.60507564968111,
           -42.537871725348346,
           -42.47066780101558,
           -42.40346387668281,
           -42.33625995235004,
           -42.26905602801727,
           -42.2018521036845,
           -42.13464817935174,
           -42.06744425501897,
           -42.000240330686196,
           -41.93303640635343,
           -41.865832482020664,
           -41.7986285576879,
           -41.731424633355125,
           -41.66422070902236,
           -41.597016784689586,
           -41.52981286035682,
           -41.462608936024054,
           -41.39540501169128,
           -41.32820108735852,
           -41.26099716302575,
           -41.19379323869299,
           -41.12658931436022,
           -41.05938539002745,
           -40.99218146569468,
           -40.92497754136191,
           -40.85777361702914,
           -40.79056969269638,
           -40.72336576836361,
           -40.656161844030834,
           -40.588957919698075,
           -40.5217539953653,
           -40.454550071032536,
           -40.38734614669977,
           -40.320142222367,
           -40.25293829803423,
           -40.185734373701465,
           -40.11853044936869,
           -40.051326525035925,
           -39.91326337308382,
           -39.70434099351237,
           -39.495418613940934,
           -39.2864962343695,
           -39.077573854798054,
           -38.86865147522663,
           -38.65972909565519,
           -38.45080671608374,
           -38.241884336512285,
           -38.03296195694088,
           -37.824039577369426,
           -37.61511719779798,
           -37.406194818226545,
           -37.19727243865511,
           -36.98835005908366,
           -36.77942767951223,
           -36.57050529994079,
           -36.361582920369344,
           -36.15266054079791,
           -35.943738161226484,
           -35.73481578165503,
           -35.525893402083575,
           -35.31697102251216,
           -35.108048642940716,
           -34.89912626336927,
           -34.690203883797835,
           -34.48128850279556,
           -34.272586574904835,
           -34.063884647014135,
           -33.855182719123434,
           -33.64648079123271,
           -33.43777886334198,
           -33.22907693545131,
           -33.02037500756058,
           -32.811673079669866,
           -32.602971151779165,
           -32.39426922388846,
           -32.185567295997735,
           -31.976865368107035,
           -31.768163440216334,
           -31.559461512325612,
           -31.350759584434908,
           -31.142057656544207,
           -30.93335572865349,
           -30.72465380076276,
           -30.515951872872083,
           -30.307249944981358,
           -30.098548017090636,
           -29.88984608919993,
           -29.68114416130923,
           -29.472442233418512,
           -29.26374030552781,
           -29.05503837763711,
           -28.84633644974638,
           -28.637634521855666,
           -28.42893259396498,
           -28.220230666074265,
           -28.01152873818354,
           -27.80282681029284,
           -27.594124882402134,
           -27.385422954511412,
           -27.176721026620704,
           -26.968019098730004,
           -26.75931717083929,
           -26.550615242948584,
           -26.341913315057884,
           -26.133211387167158,
           -25.924509459276436,
           -25.715807531385753,
           -25.507105603495035,
           -25.298403675604316,
           -25.08970174771361,
           -24.88099981982291,
           -24.672297891932185,
           -24.463595964041485,
           -24.25489403615078,
           -24.046192108260065,
           -23.837490180369365,
           -23.62878825247866,
           -23.420086324587935,
           -23.211384396697213,
           -23.002682468806512,
           -22.79398054091581,
           -22.635491767242886,
           -22.577429302005513,
           -22.519366836768143,
           -22.461304371530765,
           -22.403241906293395,
           -22.345179441056025,
           -22.287116975818645,
           -22.229054510581268,
           -22.170992045343905,
           -22.112929580106528,
           -22.05486711486915,
           -21.99680464963178,
           -21.938742184394407,
           -21.88067971915703,
           -21.82261725391966,
           -21.76455478868229,
           -21.70649232344491,
           -21.64842985820754,
           -21.59036739297017,
           -21.532304927732792,
           -21.47424246249541,
           -21.41617999725804,
           -21.35811753202067,
           -21.300055066783294,
           -21.241992601545924,
           -21.183930136308554,
           -21.125867671071177,
           -21.067805205833803,
           -21.009742740596433,
           -20.95168027535906,
           -20.893617810121683,
           -20.835555344884316,
           -20.777492879646935,
           -20.719430414409562,
           -20.66136794917219,
           -20.603305483934818,
           -20.545243018697445,
           -20.48718055346007,
           -20.429118088222697,
           -20.371055622985324,
           -20.312993157747947,
           -20.254930692510577,
           -20.196921568278846,
           -20.138939114290515,
           -20.080956660302192,
           -20.02297420631387,
           -19.96499175232554,
           -19.907009298337215,
           -19.84902684434889,
           -19.79104439036056,
           -19.733061936372234,
           -19.67507948238391,
           -19.617097028395584,
           -19.559114574407253,
           -19.501132120418934,
           -19.4431496664306,
           -19.385167212442273,
           -19.32718475845395,
           -19.269202304465622,
           -19.211219850477292,
           -19.15323739648897,
           -19.095254942500645,
           -19.037272488512315,
           -18.97929003452399,
           -18.921307580535668,
           -18.863325126547338,
           -18.805342672559007,
           -18.74736021857069,
           -18.689377764582357,
           -18.63139531059403,
           -18.573412856605707,
           -18.51543040261738,
           -18.457447948629053,
           -18.399465494640722,
           -18.341483040652403,
           -18.283500586664072,
           -18.22551813267574,
           -18.167535678687422,
           -18.10955322469909,
           -18.051570770710764,
           -17.993588316722438,
           -17.935605862734114,
           -17.877623408745784,
           -17.802316349816735,
           -17.640386266184038,
           -17.478456182551334,
           -17.316526098918636,
           -17.154596015285968,
           -16.992665931653264,
           -16.830735848020566,
           -16.668805764387898,
           -16.506875680755194,
           -16.344945597122493,
           -16.18301551348982,
           -16.021085429857123,
           -15.859155346224423,
           -15.697225262591722,
           -15.535295178959053,
           -15.37336509532635,
           -15.211435011693649,
           -15.04950492806098,
           -14.88757484442828,
           -14.725644760795578,
           -14.56371467716291,
           -14.40178459353021,
           -14.239854509897508,
           -14.077924426264836,
           -13.915994342632137,
           -13.754064258999437,
           -13.592134175366736,
           -13.430204091734065,
           -13.268274008101365,
           -13.106343924468664,
           -12.944413840835994,
           -12.782483757203293,
           -12.625071874765453,
           -12.469217010634216,
           -12.31336214650295,
           -12.157507282371686,
           -12.001652418240418,
           -11.845797554109183,
           -11.689942689977919,
           -11.534087825846651,
           -11.378232961715415,
           -11.222378097584151,
           -11.098788366174709,
           -10.99824515813801,
           -10.897701950101292,
           -10.797158742064573,
           -10.696615534027872,
           -10.596072325991155,
           -10.495529117954435,
           -10.394985909917718,
           -10.29444270188102,
           -10.1938994938443,
           -10.090811433219882,
           -9.984251409536105,
           -9.877691385852309,
           -9.771131362168513,
           -9.664571338484738,
           -9.558011314800943,
           -9.451451291117145,
           -9.34489126743335,
           -9.238331243749574,
           -9.131771220065778,
           -9.025211196381981,
           -8.918651172698205,
           -8.81209114901441,
           -8.705531125330614,
           -8.598971101646837,
           -8.492411077963041,
           -8.385851054279245,
           -8.279291030595468,
           -8.172731006911674,
           -8.066170983227877,
           -7.959610959544081,
           -7.853050935860305,
           -7.746490912176509,
           -7.639930888492714,
           -7.533370864808937,
           -7.426810841125141,
           -7.3202508174413445,
           -7.21369079375757,
           -7.107130770073773,
           -7.000570746389977,
           -6.894010722706181,
           -6.787450699022406
          ],
          [
           -38.03593061017217,
           -38.07663018423238,
           -38.117329758292584,
           -38.15802933235279,
           -38.198728906412995,
           -38.2394284804732,
           -38.280128054533414,
           -38.32082762859362,
           -38.361527202653825,
           -38.40222677671403,
           -38.442926350774236,
           -38.48362592483444,
           -38.52432549889464,
           -38.56502507295485,
           -38.60572464701506,
           -38.646424221075264,
           -38.68712379513547,
           -38.727823369195676,
           -38.76852294325588,
           -38.80922251731609,
           -38.8499220913763,
           -38.8906216654365,
           -38.931321239496704,
           -38.97202081355691,
           -39.012720387617115,
           -39.05341996167732,
           -39.094119535737526,
           -39.13481910979773,
           -39.17551868385794,
           -39.21621825791814,
           -39.256917831978356,
           -39.2976174071218,
           -39.339715099202415,
           -39.381812791283046,
           -39.42391048336366,
           -39.46600817544428,
           -39.50810586752491,
           -39.55020355960553,
           -39.59230125168616,
           -39.63439894376678,
           -39.67649663584739,
           -39.718594327928024,
           -39.76069202000864,
           -39.80278971208927,
           -39.844887404169896,
           -39.88698509625051,
           -39.929082788331144,
           -39.97118048041176,
           -40.01327817249238,
           -40.055375864573,
           -40.097473556653625,
           -40.13957124873425,
           -40.18166894081487,
           -40.22376663289549,
           -40.265864324976114,
           -40.30796201705674,
           -40.35005970913736,
           -40.392157401217986,
           -40.43425509329861,
           -40.476352785379234,
           -40.51845047745985,
           -40.56054816954048,
           -40.6026458616211,
           -40.64474355370172,
           -40.68684124578235,
           -40.72893893786297,
           -40.77103662994359,
           -40.81313432202421,
           -40.855232014104836,
           -40.89732970618546,
           -40.93942739826608,
           -40.98152509034671,
           -41.023622782427324,
           -41.06572047450795,
           -41.10781816658857,
           -41.149915858669196,
           -41.19201355074982,
           -41.23411124283044,
           -41.27620893491106,
           -41.318306626991685,
           -41.36040431907231,
           -41.40250201115293,
           -41.44459970323355,
           -41.486697395314174,
           -41.52487931466228,
           -41.56227807946388,
           -41.59967684426548,
           -41.63707560906708,
           -41.67447437386869,
           -41.711873138670285,
           -41.74927190347189,
           -41.786670668273494,
           -41.824069433075096,
           -41.861468197876704,
           -41.89886696267831,
           -41.936265727479906,
           -41.973664492281515,
           -42.01106325708311,
           -42.04846202188472,
           -42.085860786686325,
           -42.12325955148792,
           -42.16065831628953,
           -42.19805708109112,
           -42.23545584589273,
           -42.27285461069433,
           -42.31025337549593,
           -42.34765214029754,
           -42.385050905099135,
           -42.42244966990074,
           -42.459848434702344,
           -42.497247199503946,
           -42.534645964305554,
           -42.57204472910715,
           -42.609443493908756,
           -42.64684225871036,
           -42.684824086568725,
           -42.72292252638793,
           -42.76102096620714,
           -42.799119406026335,
           -42.837217845845544,
           -42.87531628566475,
           -42.91341472548396,
           -42.95151316530317,
           -42.98961160512236,
           -43.02771004494158,
           -43.06580848476078,
           -43.10390692457999,
           -43.142005364399196,
           -43.1801038042184,
           -43.218202244037606,
           -43.25630068385681,
           -43.294399123676016,
           -43.332497563495224,
           -43.370596003314425,
           -43.40869444313363,
           -43.446792882952835,
           -43.48489132277204,
           -43.52298976259125,
           -43.56108820241046,
           -43.59918664222966,
           -43.63728508204886,
           -43.67538352186807,
           -43.71348196168728,
           -43.75158040150648,
           -43.78967884132569,
           -43.82777728114489,
           -43.8658757209641,
           -43.90397416078331,
           -43.942072600602515,
           -43.98017104042172,
           -44.018269480240924,
           -44.056367920060126,
           -44.09446635987933,
           -44.132564799698535,
           -44.17066323951775,
           -44.20876167933695,
           -44.24686011915616,
           -44.28495855897536,
           -44.32305699879457,
           -44.36115543861377,
           -44.39925387843298,
           -44.43735231825219,
           -44.47545075807139,
           -44.5135491978906,
           -44.5516476377098,
           -44.58974607752901,
           -44.62784451734821,
           -44.61859658660307,
           -44.58567547057575,
           -44.552754354548426,
           -44.5198332385211,
           -44.48691212249378,
           -44.45399100646647,
           -44.42106989043914,
           -44.388148774411825,
           -44.3552276583845,
           -44.32230654235718,
           -44.289385426329865,
           -44.25646431030255,
           -44.22354319427522,
           -44.1906220782479,
           -44.15770096222058,
           -44.12477984619326,
           -44.091858730165946,
           -44.05893761413862,
           -44.026016498111304,
           -43.99309538208398,
           -43.960174266056654,
           -43.92725315002934,
           -43.89433203400202,
           -43.861410917974695,
           -43.828489801947384,
           -43.79556868592006,
           -43.762647569892735,
           -43.72972645386542,
           -43.6968053378381,
           -43.663884221810775,
           -43.63096310578345,
           -43.59804198975613,
           -43.56512087372881,
           -43.53219975770149,
           -43.49927864167417,
           -43.46635752564684,
           -43.42992022464321,
           -43.362716300310446,
           -43.29551237597768,
           -43.228308451644914,
           -43.16110452731215,
           -43.093900602979375,
           -43.0266966786466,
           -42.959492754313835,
           -42.89228882998107,
           -42.8250849056483,
           -42.75788098131554,
           -42.690677056982764,
           -42.62347313264999,
           -42.55626920831723,
           -42.489065283984466,
           -42.4218613596517,
           -42.35465743531893,
           -42.287453510986154,
           -42.22024958665339,
           -42.15304566232062,
           -42.085841737987856,
           -42.01863781365509,
           -41.95143388932232,
           -41.88422996498955,
           -41.817026040656785,
           -41.74982211632401,
           -41.682618191991246,
           -41.61541426765847,
           -41.548210343325714,
           -41.48100641899294,
           -41.413802494660175,
           -41.34659857032741,
           -41.279394645994635,
           -41.21219072166187,
           -41.1449867973291,
           -41.07778287299634,
           -41.010578948663564,
           -40.9433750243308,
           -40.87617109999803,
           -40.80896717566526,
           -40.74176325133249,
           -40.67455932699973,
           -40.607355402666954,
           -40.54015147833419,
           -40.47294755400142,
           -40.40574362966865,
           -40.33853970533588,
           -40.20047655338378,
           -39.99155417381233,
           -39.7826317942409,
           -39.573709414669466,
           -39.36478703509802,
           -39.155864655526585,
           -38.94694227595515,
           -38.7380198963837,
           -38.52909751681225,
           -38.32017513724084,
           -38.11125275766939,
           -37.90233037809793,
           -37.693407998526496,
           -37.48448561895508,
           -37.275563239383615,
           -37.06664085981219,
           -36.85771848024076,
           -36.6487961006693,
           -36.439873721097875,
           -36.23095134152644,
           -36.02202896195499,
           -35.81310658238354,
           -35.60418420281212,
           -35.39526182324067,
           -35.186339443669226,
           -34.97741706409779,
           -34.76849468452636,
           -34.55957230495491,
           -34.35064992538348,
           -34.141727545812046,
           -33.9328051662406,
           -33.723882786669144,
           -33.51496040709773,
           -33.306038027526284,
           -33.09711564795483,
           -32.888193268383404,
           -32.67927088881196,
           -32.470348509240516,
           -32.26142612966909,
           -32.05250375009764,
           -31.843581370526195,
           -31.63465899095476,
           -31.425736611383336,
           -31.21681423181188,
           -31.007891852240434,
           -30.79896947266902,
           -30.590047093097567,
           -30.381124713526116,
           -30.172202333954687,
           -29.963279954383253,
           -29.754357574811802,
           -29.545435195240373,
           -29.33651281566894,
           -29.127590436097485,
           -28.918668056526037,
           -28.709745676954626,
           -28.50082329738317,
           -28.292102123434482,
           -28.08340019554378,
           -27.874698267653077,
           -27.66599633976236,
           -27.457294411871658,
           -27.248592483980957,
           -27.03989055609023,
           -26.83118862819953,
           -26.62248670030883,
           -26.41378477241811,
           -26.205082844527386,
           -25.996380916636703,
           -25.78767898874598,
           -25.578977060855262,
           -25.370275132964558,
           -25.161573205073857,
           -24.952871277183135,
           -24.74416934929243,
           -24.53546742140173,
           -24.32676549351101,
           -24.118063565620304,
           -23.909361637729603,
           -23.70065970983888,
           -23.491957781948162,
           -23.283255854057458,
           -23.074553926166754,
           -22.916065152493832,
           -22.85800268725646,
           -22.79994022201909,
           -22.74187775678171,
           -22.68381529154434,
           -22.62575282630697,
           -22.567690361069594,
           -22.509627895832217,
           -22.45156543059485,
           -22.393502965357474,
           -22.335440500120097,
           -22.277378034882723,
           -22.219315569645353,
           -22.161253104407976,
           -22.103190639170606,
           -22.045128173933236,
           -21.98706570869586,
           -21.92900324345849,
           -21.87094077822112,
           -21.812878312983738,
           -21.75481584774636,
           -21.69675338250899,
           -21.638690917271617,
           -21.58062845203424,
           -21.52256598679687,
           -21.4645035215595,
           -21.406441056322123,
           -21.348378591084753,
           -21.290316125847383,
           -21.232253660610006,
           -21.174191195372625,
           -21.11612873013526,
           -21.05806626489788,
           -21.000003799660504,
           -20.941941334423134,
           -20.883878869185764,
           -20.825816403948387,
           -20.767753938711017,
           -20.709691473473647,
           -20.65162900823627,
           -20.593566542998893,
           -20.535504077761523,
           -20.477441612524146,
           -20.41937914728677,
           -20.3613166820494,
           -20.303254216812032,
           -20.245191751574655,
           -20.18712928633728,
           -20.12906682109991,
           -20.071004355862534,
           -20.01294189062516,
           -19.954879425387787,
           -19.896816960150414,
           -19.838754494913037,
           -19.78069202967567,
           -19.722629564438293,
           -19.66456709920092,
           -19.606504633963546,
           -19.548442168726176,
           -19.4903797034888,
           -19.43231723825143,
           -19.374254773014055,
           -19.31619230777668,
           -19.258129842539308,
           -19.200067377301938,
           -19.14200491206456,
           -19.083942446827184,
           -19.025879981589817,
           -18.96781751635244,
           -18.909755051115063,
           -18.851692585877693,
           -18.79363012064032,
           -18.735567655402946,
           -18.677505190165576,
           -18.6194427249282,
           -18.56138025969082,
           -18.503317794453448,
           -18.44525532921608,
           -18.387192863978704,
           -18.329130398741324,
           -18.271125275041687,
           -18.213142821053363,
           -18.155160367065033,
           -18.079853308135988,
           -17.917923224503287,
           -17.755993140870583,
           -17.594063057237886,
           -17.432132973605214,
           -17.270202889972513,
           -17.108272806339812,
           -16.946342722707143,
           -16.783455151078755,
           -16.620282917824277,
           -16.457110684569834,
           -16.293938451315356,
           -16.13076621806088,
           -15.967593984806403,
           -15.804421751551956,
           -15.641249518297483,
           -15.478077285043007,
           -15.31490505178856,
           -15.151732818534088,
           -14.98856058527961,
           -14.825388352025165,
           -14.66221611877069,
           -14.499043885516214,
           -14.335871652261767,
           -14.172699419007293,
           -14.009527185752816,
           -13.846354952498341,
           -13.683182719243895,
           -13.52001048598942,
           -13.356838252734944,
           -13.1936660194805,
           -13.030493786226025,
           -12.867321552971546,
           -12.704149319717102,
           -12.540977086462625,
           -12.37780485320815,
           -12.214632619953676,
           -12.05146038669923,
           -11.888288153444753,
           -11.725115920190277,
           -11.561943686935832,
           -11.398771453681357,
           -11.267750534891686,
           -11.159694840719744,
           -11.051639146547785,
           -10.943583452375822,
           -10.835527758203884,
           -10.727472064031922,
           -10.619416369859962,
           -10.511360675688001,
           -10.40330498151606,
           -10.2952492873441,
           -10.18719359317214,
           -10.079137899000198,
           -9.971082204828237,
           -9.863026510656276,
           -9.754970816484336,
           -9.646915122312375,
           -9.538859428140414,
           -9.430803733968453,
           -9.322748039796513,
           -9.214692345624552,
           -9.106636651452591,
           -8.99858095728065,
           -8.89052526310869,
           -8.782469568936728,
           -8.674413874764788,
           -8.566358180592829,
           -8.458302486420866,
           -8.350246792248926,
           -8.242191098076965,
           -8.134135403905004,
           -8.026079709733043,
           -7.9180240155611035,
           -7.809968321389142,
           -7.701912627217183,
           -7.594448972095035,
           -7.487888948411239,
           -7.381328924727444,
           -7.274768901043669,
           -7.168208877359872,
           -7.0616488536760755,
           -6.95508882999228,
           -6.8485288063085035
          ],
          [
           -37.6905611599311,
           -37.731260733991306,
           -37.771960308051504,
           -37.81265988211172,
           -37.85335945617192,
           -37.89405903023213,
           -37.934758604292334,
           -37.97545817835254,
           -38.01615775241275,
           -38.05685732647295,
           -38.097556900533164,
           -38.13825647459336,
           -38.17895604865357,
           -38.21965562271377,
           -38.260355196773986,
           -38.301054770834185,
           -38.3417543448944,
           -38.382453918954596,
           -38.4231534930148,
           -38.46385306707501,
           -38.50455264113522,
           -38.54525221519542,
           -38.58595178925563,
           -38.62665136331584,
           -38.66735093737604,
           -38.70805051143624,
           -38.748750085496454,
           -38.78944965955666,
           -38.830149233616865,
           -38.87084880767706,
           -38.911548381737276,
           -38.95224795579748,
           -38.99294752985769,
           -39.03364710391789,
           -39.074346677978106,
           -39.11504625203831,
           -39.15574582609851,
           -39.196445400158716,
           -39.23714497421892,
           -39.27784454827913,
           -39.31854412233934,
           -39.359243696399545,
           -39.39994327045975,
           -39.44064284451996,
           -39.481342418580155,
           -39.52204199264036,
           -39.56274156670057,
           -39.60344114076078,
           -39.64483977468374,
           -39.686937466764356,
           -39.72903515884499,
           -39.7711328509256,
           -39.813230543006235,
           -39.85532823508685,
           -39.89742592716747,
           -39.9395236192481,
           -39.981621311328716,
           -40.02371900340935,
           -40.065816695489964,
           -40.10791438757059,
           -40.15001207965121,
           -40.192109771731836,
           -40.23420746381246,
           -40.27630515589308,
           -40.3184028479737,
           -40.360500540054325,
           -40.40259823213494,
           -40.444695924215566,
           -40.4867936162962,
           -40.528891308376814,
           -40.57098900045744,
           -40.61308669253806,
           -40.655184384618686,
           -40.69728207669931,
           -40.739379768779926,
           -40.78147746086055,
           -40.823575152941174,
           -40.8656728450218,
           -40.90777053710242,
           -40.94986822918304,
           -40.99196592126367,
           -41.03406361334429,
           -41.076161305424904,
           -41.118258997505535,
           -41.15644091685364,
           -41.193839681655234,
           -41.23123844645684,
           -41.268637211258444,
           -41.306035976060045,
           -41.343434740861646,
           -41.38083350566325,
           -41.418232270464856,
           -41.45563103526646,
           -41.49302980006806,
           -41.530428564869666,
           -41.56782732967126,
           -41.60522609447287,
           -41.64262485927447,
           -41.68002362407608,
           -41.71742238887768,
           -41.75482115367927,
           -41.79221991848088,
           -41.82961868328249,
           -41.867017448084084,
           -41.90441621288569,
           -41.941814977687294,
           -41.979213742488895,
           -42.0166125072905,
           -42.0540112720921,
           -42.091410036893706,
           -42.12880880169531,
           -42.16620756649691,
           -42.203606331298516,
           -42.24100509610011,
           -42.27840386090172,
           -42.31580262570331,
           -42.35320139050492,
           -42.390600155306515,
           -42.42799892010813,
           -42.46539768490973,
           -42.50279644971134,
           -42.540195214512934,
           -42.577593979314535,
           -42.614992744116144,
           -42.65239150891774,
           -42.68979027371934,
           -42.72718903852095,
           -42.764587803322556,
           -42.80198656812415,
           -42.83938533292576,
           -42.87678409772736,
           -42.914416087961484,
           -42.952514527780686,
           -42.99061296759989,
           -43.028711407419095,
           -43.066809847238304,
           -43.104908287057505,
           -43.14300672687671,
           -43.18110516669592,
           -43.21920360651512,
           -43.25730204633433,
           -43.29540048615353,
           -43.33349892597275,
           -43.37159736579195,
           -43.40969580561116,
           -43.44779424543036,
           -43.48589268524957,
           -43.523991125068775,
           -43.56208956488798,
           -43.60018800470718,
           -43.638286444526386,
           -43.676384884345595,
           -43.714483324164796,
           -43.752581763984004,
           -43.790680203803205,
           -43.828778643622414,
           -43.86687708344162,
           -43.90497552326082,
           -43.94307396308003,
           -43.98117240289924,
           -44.01927084271845,
           -44.05736928253765,
           -44.09546772235685,
           -44.13356616217606,
           -44.17166460199527,
           -44.209763041814476,
           -44.24786148163368,
           -44.23861355088853,
           -44.205692434861206,
           -44.172771318833895,
           -44.13985020280657,
           -44.106929086779246,
           -44.07400797075193,
           -44.04108685472461,
           -44.008165738697286,
           -43.97524462266996,
           -43.94232350664265,
           -43.90940239061533,
           -43.87648127458801,
           -43.843560158560685,
           -43.81063904253337,
           -43.77771792650604,
           -43.74479681047872,
           -43.71187569445141,
           -43.67895457842408,
           -43.64603346239676,
           -43.61311234636944,
           -43.580191230342116,
           -43.5472701143148,
           -43.51434899828748,
           -43.481427882260164,
           -43.44850676623284,
           -43.415585650205514,
           -43.382664534178204,
           -43.34974341815088,
           -43.316822302123555,
           -43.28390118609624,
           -43.25098007006891,
           -43.218058954041595,
           -43.18513783801427,
           -43.152216721986946,
           -43.119295605959636,
           -43.08637448993231,
           -43.05345337390499,
           -43.020532257877676,
           -42.98761114185035,
           -42.95469002582303,
           -42.921768909795716,
           -42.88884779376839,
           -42.85592667774107,
           -42.82300556171375,
           -42.79008444568643,
           -42.75716332965911,
           -42.72424221363178,
           -42.69132109760446,
           -42.65839998157715,
           -42.62547886554982,
           -42.592557749522506,
           -42.55963663349519,
           -42.52671551746786,
           -42.493794401440546,
           -42.46087328541322,
           -42.427952169385904,
           -42.373054918287814,
           -42.30585099395504,
           -42.238647069622274,
           -42.17144314528951,
           -42.10423922095674,
           -42.03703529662397,
           -41.9698313722912,
           -41.90262744795843,
           -41.835423523625664,
           -41.76821959929289,
           -41.70101567496013,
           -41.633811750627366,
           -41.56660782629459,
           -41.49940390196183,
           -41.432199977629054,
           -41.36499605329629,
           -41.29779212896352,
           -41.230588204630756,
           -41.16338428029799,
           -41.09618035596522,
           -41.028976431632444,
           -40.96177250729968,
           -40.89456858296691,
           -40.827364658634146,
           -40.76016073430138,
           -40.69295680996861,
           -40.62575288563584,
           -40.48768973368374,
           -40.27876735411228,
           -40.06984497454085,
           -39.86092259496942,
           -39.65200021539797,
           -39.443077835826536,
           -39.2341554562551,
           -39.025233076683655,
           -38.8163106971122,
           -38.60738831754079,
           -38.39846593796934,
           -38.18954355839789,
           -37.98062117882646,
           -37.77169879925503,
           -37.56277641968357,
           -37.35385404011215,
           -37.14493166054071,
           -36.93600928096926,
           -36.727086901397826,
           -36.51816452182639,
           -36.309242142254945,
           -36.1003197626835,
           -35.89139738311208,
           -35.68247500354063,
           -35.473552623969184,
           -35.26463024439775,
           -35.05570786482632,
           -34.84678548525486,
           -34.63786310568344,
           -34.428940726112,
           -34.22001834654055,
           -34.011095966969094,
           -33.80217358739769,
           -33.593251207826235,
           -33.38432882825478,
           -33.175406448683354,
           -32.96648406911192,
           -32.75756168954047,
           -32.54863930996904,
           -32.33971693039761,
           -32.13079455082615,
           -31.921872171254723,
           -31.712949791683286,
           -31.50402741211184,
           -31.295105032540388,
           -31.086182652968972,
           -30.877260273397525,
           -30.66833789382607,
           -30.45941551425464,
           -30.250493134683207,
           -30.041570755111756,
           -29.832648375540327,
           -29.62372599596889,
           -29.41480361639744,
           -29.20588123682599,
           -28.99695885725458,
           -28.78803647768313,
           -28.579114098111678,
           -28.37019171854024,
           -28.161269338968815,
           -27.95234695939736,
           -27.743424579825927,
           -27.5345022002545,
           -27.325579820683046,
           -27.116657441111613,
           -26.907735061540183,
           -26.698812681968732,
           -26.489890302397278,
           -26.280967922825866,
           -26.07204554325442,
           -25.863123163682964,
           -25.654200784111538,
           -25.4452784045401,
           -25.23635602496865,
           -25.027433645397224,
           -24.81851126582579,
           -24.609588886254336,
           -24.40047706934916,
           -24.19131703353272,
           -23.982156997716256,
           -23.772996961899796,
           -23.563836926083347,
           -23.354676890266905,
           -23.19604477324225,
           -23.13846849380117,
           -23.080892214360087,
           -23.023315934918998,
           -22.96573965547792,
           -22.907930469113474,
           -22.849958526185368,
           -22.791986583257263,
           -22.734014640329168,
           -22.676042697401066,
           -22.61807075447296,
           -22.56009881154486,
           -22.50212686861676,
           -22.444154925688657,
           -22.38618298276056,
           -22.328211039832457,
           -22.27023909690435,
           -22.21226715397625,
           -22.154295211048154,
           -22.09632326812005,
           -22.038351325191947,
           -21.98037938226385,
           -21.922407439335743,
           -21.864435496407637,
           -21.806463553479546,
           -21.74849161055144,
           -21.690519667623338,
           -21.632547724695236,
           -21.574575781767138,
           -21.516603838839035,
           -21.45863189591093,
           -21.400659952982835,
           -21.34268801005473,
           -21.284716067126624,
           -21.226744124198525,
           -21.168772181270423,
           -21.110800238342318,
           -21.052828295414223,
           -20.994856352486124,
           -20.93688440955802,
           -20.878912466629917,
           -20.820940523701818,
           -20.762968580773716,
           -20.70499663784561,
           -20.647024694917512,
           -20.589052751989406,
           -20.531080809061304,
           -20.47310886613321,
           -20.415136923205107,
           -20.357164980277002,
           -20.2991930373489,
           -20.2412210944208,
           -20.1832491514927,
           -20.125277208564594,
           -20.0673052656365,
           -20.009333322708393,
           -19.951361379780288,
           -19.893389436852193,
           -19.83541749392409,
           -19.777445550995985,
           -19.719473608067883,
           -19.661501665139788,
           -19.603529722211682,
           -19.545557779283584,
           -19.487585836355485,
           -19.42961389342738,
           -19.371641950499274,
           -19.31367000757118,
           -19.255698064643077,
           -19.19772612171497,
           -19.139754178786873,
           -19.081782235858775,
           -19.02381029293067,
           -18.965838350002567,
           -18.907866407074472,
           -18.849894464146363,
           -18.79192252121826,
           -18.733950578290163,
           -18.67597863536206,
           -18.61800669243396,
           -18.560034749505856,
           -18.502062806577758,
           -18.444090863649656,
           -18.367592986124563,
           -18.198465435614498,
           -18.02933788510443,
           -17.860210334594363,
           -17.69108278408433,
           -17.52195523357426,
           -17.352827683064195,
           -17.183700132554158,
           -17.014572582044096,
           -16.845445031534027,
           -16.676317481023986,
           -16.507189930513924,
           -16.338062380003855,
           -16.168934829493786,
           -15.999807278983752,
           -15.830679728473683,
           -15.661552177963618,
           -15.49423457896047,
           -15.331062345705993,
           -15.16789011245152,
           -15.004717879197074,
           -14.841545645942595,
           -14.67837341268812,
           -14.515201179433678,
           -14.3520289461792,
           -14.188856712924725,
           -14.025684479670247,
           -13.862512246415802,
           -13.699340013161327,
           -13.53616777990685,
           -13.372995546652406,
           -13.20982331339793,
           -13.046651080143455,
           -12.883478846889007,
           -12.720306613634532,
           -12.557134380380058,
           -12.393962147125581,
           -12.230789913871137,
           -12.067617680616658,
           -11.904445447362184,
           -11.74127321410774,
           -11.578100980853264,
           -11.447080062063593,
           -11.339024367891652,
           -11.230968673719694,
           -11.122912979547731,
           -11.01485728537579,
           -10.90680159120383,
           -10.798745897031868,
           -10.690690202859907,
           -10.582634508687967,
           -10.474578814516008,
           -10.366523120344047,
           -10.258467426172105,
           -10.150411732000144,
           -10.042356037828183,
           -9.934300343656243,
           -9.826244649484282,
           -9.718188955312321,
           -9.61013326114036,
           -9.50207756696842,
           -9.39402187279646,
           -9.285966178624498,
           -9.177910484452559,
           -9.069854790280598,
           -8.961799096108635,
           -8.853743401936693,
           -8.740431503831513,
           -8.626283388920864,
           -8.512135274010237,
           -8.39798715909959,
           -8.283839044188941,
           -8.169690929278293,
           -8.055542814367666,
           -7.9413946994570175,
           -7.827246584546368,
           -7.713098469635742,
           -7.598950354725094,
           -7.484802239814446,
           -7.370654124903819,
           -7.256506009993171,
           -7.1423578950825215,
           -7.028209780171874,
           -6.914061665261247
          ],
          [
           -37.34519170969001,
           -37.38589128375022,
           -37.426590857810424,
           -37.46729043187063,
           -37.507990005930836,
           -37.54868957999104,
           -37.58938915405125,
           -37.63008872811145,
           -37.67078830217166,
           -37.71148787623187,
           -37.75218745029207,
           -37.79288702435228,
           -37.83358659841248,
           -37.874286172472694,
           -37.91498574653289,
           -37.955685320593105,
           -37.9963848946533,
           -38.037084468713516,
           -38.07778404277372,
           -38.11848361683393,
           -38.15918319089413,
           -38.19988276495434,
           -38.24058233901454,
           -38.28128191307475,
           -38.321981487134956,
           -38.36268106119516,
           -38.40338063525537,
           -38.44408020931557,
           -38.48477978337578,
           -38.525479357435984,
           -38.5661789314962,
           -38.606878505556395,
           -38.64757807961661,
           -38.688277653676806,
           -38.72897722773702,
           -38.76967680179722,
           -38.81037637585743,
           -38.85107594991763,
           -38.89177552397784,
           -38.93247509803804,
           -38.97317467209825,
           -39.01387424615845,
           -39.054573820218664,
           -39.09527339427887,
           -39.135972968339075,
           -39.176672542399274,
           -39.21737211645949,
           -39.25807169051969,
           -39.298771264579905,
           -39.33947083864011,
           -39.380170412700316,
           -39.42086998676052,
           -39.46156956082073,
           -39.502269134880926,
           -39.54296870894113,
           -39.58366828300134,
           -39.62436785706154,
           -39.665067431121756,
           -39.70576700518196,
           -39.74646657924217,
           -39.78716615330237,
           -39.82786572736258,
           -39.868565301422784,
           -39.90926487548299,
           -39.94996445016505,
           -39.99206214224567,
           -40.034159834326296,
           -40.07625752640692,
           -40.11835521848754,
           -40.16045291056816,
           -40.202550602648785,
           -40.24464829472941,
           -40.28674598681003,
           -40.32884367889065,
           -40.37094137097127,
           -40.4130390630519,
           -40.45513675513252,
           -40.497234447213145,
           -40.53933213929377,
           -40.581429831374386,
           -40.62352752345501,
           -40.665625215535634,
           -40.70772290761626,
           -40.74982059969688,
           -40.78800251904499,
           -40.82540128384659,
           -40.8628000486482,
           -40.90019881344979,
           -40.9375975782514,
           -40.974996343053,
           -41.0123951078546,
           -41.04979387265621,
           -41.087192637457804,
           -41.12459140225941,
           -41.16199016706101,
           -41.199388931862615,
           -41.23678769666422,
           -41.274186461465824,
           -41.311585226267425,
           -41.34898399106903,
           -41.38638275587063,
           -41.423781520672236,
           -41.461180285473844,
           -41.49857905027544,
           -41.53597781507705,
           -41.57337657987864,
           -41.61077534468025,
           -41.64817410948184,
           -41.68557287428345,
           -41.72297163908506,
           -41.760370403886654,
           -41.79776916868826,
           -41.835167933489856,
           -41.872566698291465,
           -41.90996546309307,
           -41.94736422789467,
           -41.98476299269627,
           -42.02216175749787,
           -42.059560522299485,
           -42.09695928710108,
           -42.13435805190269,
           -42.17175681670429,
           -42.20915558150588,
           -42.2465543463075,
           -42.28395311110909,
           -42.32135187591069,
           -42.3587506407123,
           -42.396149405513896,
           -42.433548170315504,
           -42.47094693511711,
           -42.508345699918706,
           -42.545744464720315,
           -42.58314322952191,
           -42.62054199432352,
           -42.657940759125125,
           -42.69533952392672,
           -42.73273828872833,
           -42.770137053529936,
           -42.80753581833153,
           -42.84493458313314,
           -42.88233334793473,
           -42.91973211273634,
           -42.957130877537935,
           -42.99452964233954,
           -43.03192840714115,
           -43.069327171942746,
           -43.106725936744354,
           -43.14412470154596,
           -43.18210652917343,
           -43.22020496899263,
           -43.25830340881184,
           -43.29640184863105,
           -43.33450028845025,
           -43.37259872826946,
           -43.41069716808866,
           -43.44879560790787,
           -43.48689404772708,
           -43.52499248754628,
           -43.56309092736549,
           -43.601189367184695,
           -43.639287807003896,
           -43.677386246823104,
           -43.715484686642306,
           -43.753583126461514,
           -43.79168156628072,
           -43.82978000609993,
           -43.867878445919125,
           -43.858630515173985,
           -43.82570939914667,
           -43.79278828311934,
           -43.759867167092025,
           -43.7269460510647,
           -43.69402493503739,
           -43.661103819010066,
           -43.62818270298274,
           -43.595261586955424,
           -43.5623404709281,
           -43.52941935490078,
           -43.49649823887346,
           -43.46357712284614,
           -43.430656006818815,
           -43.3977348907915,
           -43.36481377476418,
           -43.33189265873686,
           -43.29897154270954,
           -43.26605042668221,
           -43.2331293106549,
           -43.20020819462758,
           -43.16728707860025,
           -43.134365962572936,
           -43.10144484654561,
           -43.068523730518294,
           -43.03560261449097,
           -43.00268149846365,
           -42.969760382436334,
           -42.93683926640901,
           -42.9039181503817,
           -42.87099703435437,
           -42.83807591832706,
           -42.80515480229973,
           -42.77223368627241,
           -42.73931257024509,
           -42.706391454217766,
           -42.67347033819044,
           -42.64054922216312,
           -42.6076281061358,
           -42.57470699010849,
           -42.541785874081164,
           -42.50886475805384,
           -42.47594364202652,
           -42.443022525999204,
           -42.41010140997188,
           -42.377180293944555,
           -42.34425917791724,
           -42.31133806188992,
           -42.2784169458626,
           -42.24549582983528,
           -42.21257471380795,
           -42.17965359778064,
           -42.14673248175332,
           -42.113811365726,
           -42.080890249698676,
           -42.04796913367135,
           -42.01504801764404,
           -41.98212690161672,
           -41.94920578558939,
           -41.916284669562074,
           -41.88336355353475,
           -41.85044243750743,
           -41.81752132148011,
           -41.78460020545279,
           -41.75167908942547,
           -41.71875797339815,
           -41.68583685737083,
           -41.652915741343506,
           -41.61999462531619,
           -41.58707350928887,
           -41.554152393261546,
           -41.52123127723423,
           -41.48831016120691,
           -41.45538904517958,
           -41.42246792915226,
           -41.38339353626518,
           -41.31618961193241,
           -41.24898568759965,
           -41.18178176326688,
           -41.11457783893411,
           -41.047373914601344,
           -40.98016999026857,
           -40.9129660659358,
           -40.774902913983695,
           -40.56598053441225,
           -40.35705815484081,
           -40.148135775269374,
           -39.93921339569793,
           -39.7302910161265,
           -39.52136863655507,
           -39.31244625698362,
           -39.10352387741216,
           -38.894601497840746,
           -38.6856791182693,
           -38.47675673869785,
           -38.26783435912641,
           -38.058911979554985,
           -37.84998959998353,
           -37.641067220412104,
           -37.43214484084067,
           -37.22322246126922,
           -37.01430008169778,
           -36.80537770212636,
           -36.5964553225549,
           -36.387532942983455,
           -36.17842112613513,
           -35.96926109031867,
           -35.7601010545022,
           -35.55094101868576,
           -35.34178098286932,
           -35.13262094705286,
           -34.92346091123641,
           -34.714300875419966,
           -34.5051408396035,
           -34.29598080378704,
           -34.08682076797061,
           -33.87766073215415,
           -33.66850069633769,
           -33.45934066052124,
           -33.2501806247048,
           -33.04102058888834,
           -32.83186055307189,
           -32.622700517255446,
           -32.413540481438986,
           -32.20438044562254,
           -31.995220409806095,
           -31.786060373989635,
           -31.57690033817317,
           -31.367740302356744,
           -31.158580266540284,
           -30.949420230723824,
           -30.74026019490738,
           -30.531100159090933,
           -30.321940123274473,
           -30.112780087458027,
           -29.90362005164158,
           -29.694460015825122,
           -29.485299980008655,
           -29.27613994419223,
           -29.06697990837577,
           -28.857819872559304,
           -28.648659836742866,
           -28.43949980092642,
           -28.230339765109953,
           -28.02117972929351,
           -27.81201969347707,
           -27.602859657660602,
           -27.39369962184416,
           -27.184539586027718,
           -26.97537955021125,
           -26.76621951439479,
           -26.557059478578367,
           -26.3478994427619,
           -26.13873940694544,
           -25.929579371128995,
           -25.720419335312553,
           -25.511259299496086,
           -25.302099263679644,
           -25.0929392278632,
           -24.883779192046738,
           -24.674619156230293,
           -24.465459120413854,
           -24.256299084597387,
           -24.04713904878092,
           -23.83797901296448,
           -23.628818977148036,
           -23.47018686012338,
           -23.412610580682298,
           -23.35503430124122,
           -23.297458021800132,
           -23.23988174235905,
           -23.182305462917967,
           -23.124729183476884,
           -23.067152904035794,
           -23.00957662459472,
           -22.952000345153635,
           -22.89442406571255,
           -22.83684778627147,
           -22.779271506830383,
           -22.721695227389297,
           -22.664118947948218,
           -22.60654266850714,
           -22.548966389066052,
           -22.49139010962497,
           -22.433813830183887,
           -22.3762375507428,
           -22.318661271301718,
           -22.261084991860635,
           -22.203508712419556,
           -22.145932432978466,
           -22.088356153537386,
           -22.030779874096304,
           -21.97320359465522,
           -21.915627315214138,
           -21.858051035773055,
           -21.800474756331973,
           -21.742898476890883,
           -21.685322197449807,
           -21.62774591800872,
           -21.570169638567634,
           -21.512593359126555,
           -21.45501707968547,
           -21.397440800244386,
           -21.339864520803303,
           -21.282288241362224,
           -21.224711961921138,
           -21.167135682480055,
           -21.109559403038972,
           -21.051983123597886,
           -20.994406844156803,
           -20.93683056471572,
           -20.879168699012723,
           -20.821196756084618,
           -20.763224813156523,
           -20.70525287022842,
           -20.647280927300315,
           -20.589308984372217,
           -20.531337041444118,
           -20.473365098516012,
           -20.415393155587907,
           -20.357421212659816,
           -20.29944926973171,
           -20.241477326803604,
           -20.183505383875506,
           -20.125533440947407,
           -20.067561498019302,
           -20.009589555091203,
           -19.9516176121631,
           -19.893645669235,
           -19.835673726306897,
           -19.7777017833788,
           -19.719729840450693,
           -19.66175789752259,
           -19.603785954594493,
           -19.54581401166639,
           -19.487842068738285,
           -19.429870125810186,
           -19.371898182882084,
           -19.313926239953982,
           -19.255954297025884,
           -19.197982354097785,
           -19.14001041116968,
           -19.08203846824157,
           -19.02406652531348,
           -18.966094582385374,
           -18.908122639457268,
           -18.85015069652917,
           -18.79217875360107,
           -18.73420681067297,
           -18.65770893314788,
           -18.48858138263781,
           -18.319453832127742,
           -18.150326281617676,
           -17.981198731107643,
           -17.812071180597574,
           -17.642943630087508,
           -17.473816079577475,
           -17.304688529067406,
           -17.13556097855734,
           -16.966433428047303,
           -16.797305877537234,
           -16.628178327027168,
           -16.459050776517103,
           -16.289923226007065,
           -16.120795675497,
           -15.951668124986933,
           -15.782540574476897,
           -15.61341302396683,
           -15.444285473456763,
           -15.275157922946725,
           -15.10603037243666,
           -14.936902821926594,
           -14.767775271416555,
           -14.59864772090649,
           -14.429520170396422,
           -14.260392619886355,
           -14.09126506937632,
           -13.922137518866254,
           -13.753009968356189,
           -13.583882417846151,
           -13.414754867336082,
           -13.245627316826015,
           -13.07649976631598,
           -12.907372215805914,
           -12.738244665295845,
           -12.573291674297492,
           -12.410119441043046,
           -12.24694720778857,
           -12.083774974534094,
           -11.92060274127965,
           -11.757430508025173,
           -11.626409589235504,
           -11.518353895063562,
           -11.410298200891603,
           -11.30224250671964,
           -11.1941868125477,
           -11.08613111837574,
           -10.975238266348066,
           -10.861090151437418,
           -10.746942036526791,
           -10.632793921616143,
           -10.518645806705495,
           -10.404497691794866,
           -10.290349576884218,
           -10.176201461973571,
           -10.062053347062944,
           -9.947905232152294,
           -9.833757117241646,
           -9.719609002331,
           -9.605460887420373,
           -9.491312772509723,
           -9.377164657599076,
           -9.263016542688447,
           -9.148868427777801,
           -9.034720312867151,
           -8.920572197956524,
           -8.806424083045876,
           -8.692275968135228,
           -8.578127853224602,
           -8.463979738313952,
           -8.349831623403304,
           -8.235683508492656,
           -8.12153539358203,
           -8.007387278671382,
           -7.893239163760733,
           -7.7790910488501055,
           -7.664942933939457,
           -7.55079481902881,
           -7.436646704118184,
           -7.322498589207535,
           -7.208350474296886,
           -7.094202359386238,
           -6.98005424447561
          ],
          [
           -36.99982225944893,
           -37.04052183350914,
           -37.081221407569345,
           -37.12192098162955,
           -37.162620555689756,
           -37.20332012974997,
           -37.24401970381017,
           -37.28471927787037,
           -37.325418851930586,
           -37.36611842599079,
           -37.406818000051,
           -37.4475175741112,
           -37.48821714817141,
           -37.528916722231614,
           -37.56961629629183,
           -37.610315870352025,
           -37.65101544441223,
           -37.691715018472436,
           -37.73241459253265,
           -37.77311416659285,
           -37.81381374065305,
           -37.85451331471326,
           -37.895212888773464,
           -37.93591246283368,
           -37.976612036893876,
           -38.01731161095408,
           -38.058011185014294,
           -38.09871075907449,
           -38.139410333134705,
           -38.180109907194904,
           -38.22080948125512,
           -38.26150905531533,
           -38.30220862937553,
           -38.34290820343574,
           -38.38360777749594,
           -38.424307351556145,
           -38.46500692561635,
           -38.505706499676556,
           -38.54640607373676,
           -38.587105647796974,
           -38.62780522185717,
           -38.66850479591738,
           -38.709204369977584,
           -38.7499039440378,
           -38.790603518097996,
           -38.8313030921582,
           -38.872002666218414,
           -38.91270224027862,
           -38.953401814338825,
           -38.99410138839903,
           -39.03480096245924,
           -39.07550053651944,
           -39.11620011057965,
           -39.15689968463985,
           -39.19759925870006,
           -39.238298832760265,
           -39.27899840682047,
           -39.319697980880676,
           -39.36039755494088,
           -39.40109712900109,
           -39.44179670306129,
           -39.4824962771215,
           -39.523195851181704,
           -39.56389542524191,
           -39.604594999302115,
           -39.64529457336232,
           -39.68599414742253,
           -39.72669372148273,
           -39.76739329554294,
           -39.80809286960314,
           -39.84879244366335,
           -39.889492017723555,
           -39.93019159178376,
           -39.970891165843966,
           -40.01159073990417,
           -40.05229031396438,
           -40.09298988802458,
           -40.13368946208479,
           -40.174389036144994,
           -40.2150886102052,
           -40.255788184265406,
           -40.29718681772699,
           -40.33928450980761,
           -40.381382201888236,
           -40.41956412123635,
           -40.45696288603795,
           -40.49436165083955,
           -40.53176041564115,
           -40.56915918044276,
           -40.60655794524436,
           -40.64395671004596,
           -40.681355474847564,
           -40.71875423964917,
           -40.75615300445077,
           -40.79355176925238,
           -40.83095053405397,
           -40.868349298855584,
           -40.90574806365718,
           -40.94314682845879,
           -40.980545593260395,
           -41.01794435806199,
           -41.05534312286359,
           -41.0927418876652,
           -41.1301406524668,
           -41.1675394172684,
           -41.20493818207,
           -41.2423369468716,
           -41.27973571167321,
           -41.31713447647481,
           -41.354533241276414,
           -41.391932006078015,
           -41.429330770879616,
           -41.46672953568122,
           -41.504128300482826,
           -41.54152706528443,
           -41.57892583008603,
           -41.61632459488762,
           -41.65372335968923,
           -41.69112212449084,
           -41.72852088929243,
           -41.76591965409405,
           -41.80331841889564,
           -41.840717183697244,
           -41.878115948498845,
           -41.91551471330045,
           -41.952913478102055,
           -41.990312242903656,
           -42.027711007705264,
           -42.06510977250686,
           -42.102508537308466,
           -42.13990730211007,
           -42.17730606691167,
           -42.21470483171328,
           -42.25210359651488,
           -42.28950236131648,
           -42.32690112611808,
           -42.36429989091968,
           -42.40169865572129,
           -42.43909742052289,
           -42.47649618532449,
           -42.513894950126094,
           -42.551293714927695,
           -42.5886924797293,
           -42.626091244530905,
           -42.663490009332506,
           -42.70088877413411,
           -42.73828753893571,
           -42.77568630373732,
           -42.81308506853892,
           -42.85048383334052,
           -42.88788259814213,
           -42.92528136294372,
           -42.96268012774532,
           -43.000078892546924,
           -43.03747765734853,
           -43.07487642215013,
           -43.112275186951734,
           -43.14967395175334,
           -43.187072716554944,
           -43.224471481356545,
           -43.261870246158146,
           -43.299269010959755,
           -43.336667775761356,
           -43.37406654056296,
           -43.411698530566184,
           -43.44979697038539,
           -43.487895410204594,
           -43.478647479459454,
           -43.44572636343213,
           -43.41280524740481,
           -43.37988413137749,
           -43.34696301535016,
           -43.314041899322845,
           -43.28112078329553,
           -43.2481996672682,
           -43.215278551240885,
           -43.18235743521357,
           -43.14943631918624,
           -43.11651520315892,
           -43.0835940871316,
           -43.050672971104284,
           -43.01775185507696,
           -42.98483073904964,
           -42.951909623022324,
           -42.91967231220927,
           -42.89153781124469,
           -42.86340331028011,
           -42.83526880931554,
           -42.807134308350946,
           -42.77899980738637,
           -42.75086530642179,
           -42.7227308054572,
           -42.69459630449263,
           -42.66646180352805,
           -42.63832730256347,
           -42.610192801598885,
           -42.58205830063431,
           -42.553923799669725,
           -42.52578929870514,
           -42.497654797740566,
           -42.46952029677598,
           -42.4413857958114,
           -42.41325129484682,
           -42.38511679388224,
           -42.356982292917664,
           -42.32884779195308,
           -42.3007132909885,
           -42.27257879002392,
           -42.244444289059345,
           -42.21630978809476,
           -42.18817528713018,
           -42.160040786165595,
           -42.13190628520101,
           -42.103771784236436,
           -42.07563728327186,
           -42.04750278230728,
           -42.01936828134269,
           -41.99123378037811,
           -41.96309927941353,
           -41.93496477844895,
           -41.906830277484374,
           -41.87869577651979,
           -41.85056127555521,
           -41.82242677459063,
           -41.79429227362605,
           -41.76615777266147,
           -41.73802327169689,
           -41.709888770732306,
           -41.68175426976774,
           -41.653619768803146,
           -41.62548526783857,
           -41.59735076687399,
           -41.56921626590941,
           -41.54108176494483,
           -41.512947263980244,
           -41.48481276301567,
           -41.456678262051085,
           -41.4285437610865,
           -41.400409260121926,
           -41.37227475915734,
           -41.344140258192766,
           -41.31600575722818,
           -41.2878712562636,
           -41.259736755299016,
           -41.23160225433445,
           -41.20346775336986,
           -41.17533325240528,
           -41.1471987514407,
           -41.119064250476114,
           -41.09092974951154,
           -40.97347523438431,
           -40.76670070509443,
           -40.55992617580458,
           -40.353151646514725,
           -40.146377117224844,
           -39.93960258793499,
           -39.73282805864513,
           -39.52605352935526,
           -39.319279000065386,
           -39.11250447077555,
           -38.90572994148567,
           -38.698955412195794,
           -38.492180882905934,
           -38.285406353616075,
           -38.0786318243262,
           -37.87185729503634,
           -37.66508276574649,
           -37.45830823645662,
           -37.25153370716676,
           -37.0447591778769,
           -36.837984648587025,
           -36.63121011929715,
           -36.424435590007306,
           -36.21766106071743,
           -36.01088653142756,
           -35.8041120021377,
           -35.59733747284785,
           -35.390562943557974,
           -35.18378841426811,
           -34.977013884978255,
           -34.77023935568838,
           -34.5634648263985,
           -34.35669029710867,
           -34.1499157678188,
           -33.94264278321881,
           -33.73348274740237,
           -33.524322711585924,
           -33.31516267576946,
           -33.10600263995302,
           -32.89684260413657,
           -32.68768256832011,
           -32.47852253250367,
           -32.26936249668722,
           -32.06020246087076,
           -31.8510424250543,
           -31.64188238923787,
           -31.432722353421415,
           -31.223562317604948,
           -31.014402281788506,
           -30.805242245972057,
           -30.596082210155597,
           -30.38692217433915,
           -30.17776213852271,
           -29.968602102706242,
           -29.759442066889783,
           -29.55028203107336,
           -29.34112199525689,
           -29.13196195944043,
           -28.922801923623986,
           -28.713641887807544,
           -28.504481851991084,
           -28.29532181617464,
           -28.086161780358196,
           -27.877001744541733,
           -27.667841708725287,
           -27.458681672908842,
           -27.24952163709238,
           -27.04036160127592,
           -26.831201565459494,
           -26.622041529643028,
           -26.412881493826564,
           -26.203721458010122,
           -25.994561422193676,
           -25.785401386377217,
           -25.57624135056077,
           -25.36708131474433,
           -25.157921278927866,
           -24.94876124311142,
           -24.739601207294974,
           -24.530441171478515,
           -24.32128113566205,
           -24.112121099845606,
           -23.902961064029164,
           -23.744328947004504,
           -23.686752667563425,
           -23.629176388122342,
           -23.571600108681253,
           -23.51402382924018,
           -23.456447549799094,
           -23.39887127035801,
           -23.34129499091692,
           -23.28371871147585,
           -23.226142432034763,
           -23.168566152593673,
           -23.110989873152594,
           -23.05341359371151,
           -22.995837314270428,
           -22.938261034829345,
           -22.880684755388263,
           -22.823108475947176,
           -22.765532196506097,
           -22.707955917065014,
           -22.650379637623928,
           -22.59280335818284,
           -22.535227078741762,
           -22.47765079930068,
           -22.420074519859593,
           -22.362498240418514,
           -22.30492196097743,
           -22.247345681536345,
           -22.189769402095266,
           -22.132193122654183,
           -22.074616843213093,
           -22.01704056377201,
           -21.959464284330934,
           -21.901888004889848,
           -21.84431172544876,
           -21.78673544600768,
           -21.729159166566596,
           -21.671582887125513,
           -21.61400660768443,
           -21.55643032824335,
           -21.498854048802265,
           -21.441277769361182,
           -21.3837014899201,
           -21.326125210479013,
           -21.268548931037927,
           -21.210972651596848,
           -21.153396372155765,
           -21.09582009271468,
           -21.038243813273596,
           -20.980667533832516,
           -20.92309125439143,
           -20.865514974950347,
           -20.807938695509264,
           -20.75036241606818,
           -20.6927861366271,
           -20.63520985718602,
           -20.577633577744933,
           -20.520057298303847,
           -20.462481018862764,
           -20.404904739421685,
           -20.3473284599806,
           -20.28975218053952,
           -20.232175901098433,
           -20.174599621657347,
           -20.117023342216267,
           -20.059447062775188,
           -20.001870783334102,
           -19.944294503893016,
           -19.886718224451936,
           -19.82914194501085,
           -19.771565665569767,
           -19.713989386128684,
           -19.6564131066876,
           -19.59883682724652,
           -19.541260547805436,
           -19.483684268364353,
           -19.42610798892327,
           -19.368531709482184,
           -19.3109554300411,
           -19.253494326696103,
           -19.196233530717393,
           -19.138972734738687,
           -19.081711938759984,
           -19.024451142781267,
           -18.94733393473816,
           -18.772680158526523,
           -18.62938871456988,
           -18.486097270613236,
           -18.342805826656615,
           -18.19951438269997,
           -18.05622293874333,
           -17.912931494786708,
           -17.769640050830066,
           -17.626348606873417,
           -17.4830571629168,
           -17.33976571896015,
           -17.19647427500351,
           -17.053182831046865,
           -16.909891387090248,
           -16.7665999431336,
           -16.623308499176957,
           -16.48001705522034,
           -16.33672561126369,
           -16.19343416730705,
           -16.05014272335043,
           -15.906851279393784,
           -15.763559835437139,
           -15.62026839148052,
           -15.476976947523877,
           -15.33368550356723,
           -15.190394059610586,
           -15.04710261565397,
           -14.903811171697322,
           -14.760519727740679,
           -14.61722828378406,
           -14.473936839827413,
           -14.330645395870768,
           -14.187353951914151,
           -14.044062507957506,
           -13.90077106400086,
           -13.757479620044215,
           -13.614188176087598,
           -13.470896732130953,
           -13.327605288174308,
           -13.184313844217689,
           -13.041022400261044,
           -12.8977309563044,
           -12.75443951234778,
           -12.611148068391135,
           -12.46785662443449,
           -12.32456518047787,
           -12.181273736521225,
           -12.037982292564582,
           -11.894690848607937,
           -11.75139940465132,
           -11.608107960694674,
           -11.464816516738027,
           -11.321525072781409,
           -11.178233628824763,
           -11.03494218486812,
           -10.891650740911501,
           -10.748359296954856,
           -10.60506785299821,
           -10.461776409041565,
           -10.318484965084949,
           -10.175193521128303,
           -10.031902077171658,
           -9.888610633215038,
           -9.745319189258392,
           -9.602027745301749,
           -9.45873630134513,
           -9.315444857388485,
           -9.17215341343184,
           -9.028861969475221,
           -8.885570525518578,
           -8.74227908156193,
           -8.598987637605287,
           -8.455696193648668,
           -8.312404749692023,
           -8.169113305735378,
           -8.02582186177876,
           -7.882530417822114,
           -7.73923897386547,
           -7.595947529908852,
           -7.4526560859522055,
           -7.309364641995561,
           -7.168483642011353,
           -7.046346607302554
          ],
          [
           -36.64268170247337,
           -36.68182538213876,
           -36.72096906180415,
           -36.76011274146954,
           -36.799256421134935,
           -36.83840010080033,
           -36.877543780465714,
           -36.91668746013111,
           -36.9558311397965,
           -36.994974819461895,
           -37.03411849912729,
           -37.073262178792675,
           -37.11240585845806,
           -37.15154953812346,
           -37.1909525336999,
           -37.23165210776011,
           -37.272351681820325,
           -37.313051255880524,
           -37.35375082994073,
           -37.394450404000935,
           -37.43514997806115,
           -37.47584955212135,
           -37.51654912618155,
           -37.55724870024176,
           -37.59794827430196,
           -37.63864784836217,
           -37.67934742242238,
           -37.72004699648258,
           -37.76074657054279,
           -37.801446144603,
           -37.842145718663204,
           -37.88284529272341,
           -37.923544866783615,
           -37.96424444084382,
           -38.00494401490403,
           -38.04564358896423,
           -38.08634316302444,
           -38.127042737084636,
           -38.16774231114485,
           -38.20844188520505,
           -38.24914145926526,
           -38.28984103332547,
           -38.33054060738567,
           -38.371240181445884,
           -38.41193975550608,
           -38.45263932956628,
           -38.493338903626494,
           -38.5340384776867,
           -38.574738051746905,
           -38.61543762580711,
           -38.65613719986732,
           -38.69683677392752,
           -38.73753634798773,
           -38.778235922047934,
           -38.818935496108146,
           -38.859635070168345,
           -38.90033464422855,
           -38.94103421828876,
           -38.98173379234896,
           -39.02243336640917,
           -39.06313294046938,
           -39.103832514529586,
           -39.14453208858979,
           -39.18523166265,
           -39.2259312367102,
           -39.26663081077041,
           -39.307330384830614,
           -39.34802995889082,
           -39.388729532951025,
           -39.42942910701123,
           -39.47012868107144,
           -39.51082825513164,
           -39.55152782919185,
           -39.59222740325205,
           -39.632926977312266,
           -39.673626551372465,
           -39.71432612543267,
           -39.75502569949288,
           -39.79572527355308,
           -39.836424847613294,
           -39.87712442167349,
           -39.9178239957337,
           -39.95852356979391,
           -39.99922314385411,
           -40.03717204353215,
           -40.07457080833375,
           -40.111969573135354,
           -40.14936833793696,
           -40.18676710273856,
           -40.22416586754016,
           -40.261564632341766,
           -40.29896339714337,
           -40.336362161944976,
           -40.37376092674657,
           -40.41115969154818,
           -40.44855845634978,
           -40.48595722115139,
           -40.52335598595299,
           -40.5607547507546,
           -40.59815351555619,
           -40.635552280357786,
           -40.6729510451594,
           -40.710349809961,
           -40.7477485747626,
           -40.785147339564205,
           -40.822546104365806,
           -40.85994486916741,
           -40.897343633969015,
           -40.934742398770624,
           -40.97214116357222,
           -41.00953992837382,
           -41.04693869317542,
           -41.08433745797703,
           -41.12173622277863,
           -41.15913498758023,
           -41.19653375238183,
           -41.23393251718343,
           -41.271331281985034,
           -41.30873004678664,
           -41.346128811588244,
           -41.383527576389845,
           -41.420926341191446,
           -41.45832510599305,
           -41.495723870794656,
           -41.53312263559626,
           -41.57052140039786,
           -41.60792016519946,
           -41.64531893000107,
           -41.68271769480266,
           -41.72011645960427,
           -41.75751522440587,
           -41.79491398920747,
           -41.83231275400908,
           -41.86971151881069,
           -41.90711028361228,
           -41.94450904841389,
           -41.981907813215486,
           -42.019306578017094,
           -42.056705342818695,
           -42.094104107620296,
           -42.1315028724219,
           -42.1689016372235,
           -42.20630040202511,
           -42.24369916682671,
           -42.28109793162831,
           -42.31849669642991,
           -42.35589546123151,
           -42.39329422603312,
           -42.43069299083472,
           -42.46809175563632,
           -42.50549052043793,
           -42.542889285239525,
           -42.580288050041126,
           -42.61720978265319,
           -42.65365448285668,
           -42.69009918306016,
           -42.72654388326366,
           -42.76298858346715,
           -42.79943328367064,
           -42.835877983874134,
           -42.87232268407762,
           -42.90876738428111,
           -42.94521208448461,
           -42.98165678468809,
           -43.01810148489158,
           -43.05454618509508,
           -43.09099088529857,
           -43.0995563424627,
           -43.09418217810713,
           -43.08880801375157,
           -43.083433849396,
           -43.078059685040444,
           -43.072685520684885,
           -43.06731135632932,
           -43.061937191973755,
           -43.05656302761819,
           -43.051188863262624,
           -43.045814698907066,
           -43.04044053455151,
           -43.035066370195935,
           -43.02969220584037,
           -43.02431804148481,
           -43.018943877129246,
           -43.01356971277369,
           -43.00819554841812,
           -43.00282138406256,
           -42.997447219707,
           -42.97429153862019,
           -42.9461570376556,
           -42.918022536691026,
           -42.88988803572644,
           -42.86175353476186,
           -42.833619033797284,
           -42.8054845328327,
           -42.777350031868124,
           -42.74921553090354,
           -42.72108102993896,
           -42.69294652897438,
           -42.664812028009806,
           -42.63667752704522,
           -42.60854302608064,
           -42.580408525116056,
           -42.55227402415148,
           -42.524139523186896,
           -42.49600502222231,
           -42.46787052125774,
           -42.439736020293154,
           -42.41160151932857,
           -42.38346701836399,
           -42.35533251739942,
           -42.327198016434835,
           -42.29906351547026,
           -42.27092901450567,
           -42.24279451354109,
           -42.21466001257651,
           -42.18652551161193,
           -42.15839101064735,
           -42.130256509682766,
           -42.10212200871819,
           -42.07398750775361,
           -42.045853006789024,
           -42.01771850582445,
           -41.989584004859864,
           -41.96144950389528,
           -41.93331500293071,
           -41.90518050196613,
           -41.877046001001546,
           -41.84891150003696,
           -41.820776999072386,
           -41.7926424981078,
           -41.76450799714322,
           -41.73637349617864,
           -41.70823899521406,
           -41.68010449424948,
           -41.65196999328491,
           -41.623835492320325,
           -41.59570099135574,
           -41.56756649039116,
           -41.53943198942658,
           -41.51129748846199,
           -41.483162987497415,
           -41.45502848653284,
           -41.426893985568256,
           -41.39875948460367,
           -41.37062498363909,
           -41.34249048267451,
           -41.31435598170994,
           -41.286221480745354,
           -41.25808697978077,
           -41.22995247881619,
           -41.112497963688966,
           -40.905723434399086,
           -40.698948905109226,
           -40.492174375819374,
           -40.2853998465295,
           -40.07862531723964,
           -39.87185078794978,
           -39.66507625865991,
           -39.458301729370035,
           -39.2515272000802,
           -39.044752670790324,
           -38.83797814150045,
           -38.631203612210584,
           -38.42442908292073,
           -38.21765455363086,
           -38.010880024341006,
           -37.80410549505115,
           -37.59733096576127,
           -37.39055643647141,
           -37.183781907181555,
           -36.977007377891674,
           -36.77023284860181,
           -36.56345831931196,
           -36.35668379002209,
           -36.14990926073221,
           -35.943134731442356,
           -35.7363602021525,
           -35.52958567286262,
           -35.322811143572764,
           -35.11603661428291,
           -34.90926208499303,
           -34.70248755570316,
           -34.49571302641332,
           -34.288938497123446,
           -34.08216396783357,
           -33.87538943854371,
           -33.668614909253854,
           -33.46184037996398,
           -33.25506585067413,
           -33.04829132138427,
           -32.841516792094396,
           -32.63474226280454,
           -32.42796773351468,
           -32.221193204224804,
           -32.01441867493493,
           -31.807644145645092,
           -31.60086961635521,
           -31.394095087065338,
           -31.18732055777548,
           -30.980546028485627,
           -30.773771499195746,
           -30.56699696990589,
           -30.360222440616035,
           -30.153447911326154,
           -29.94667338203628,
           -29.739898852746443,
           -29.53312432345657,
           -29.326349794166692,
           -29.119575264876836,
           -28.912800735586984,
           -28.706026206297103,
           -28.49925167700725,
           -28.292477147717392,
           -28.08570261842752,
           -27.87892808913766,
           -27.6721535598478,
           -27.465379030557926,
           -27.258604501268046,
           -27.05182997197821,
           -26.845055442688334,
           -26.63828091339846,
           -26.43150638410861,
           -26.22473185481875,
           -26.017957325528876,
           -25.811182796239017,
           -25.604408266949157,
           -25.397633737659284,
           -25.190859208369424,
           -24.98408467907957,
           -24.779047930278672,
           -24.57663487813846,
           -24.37422182599827,
           -24.17180877385808,
           -24.018045040434057,
           -23.961579944442384,
           -23.90511484845072,
           -23.84864975245904,
           -23.792184656467366,
           -23.735719560475697,
           -23.67891990995204,
           -23.621659113973323,
           -23.564398317994627,
           -23.507137522015917,
           -23.449876726037203,
           -23.392615930058497,
           -23.33535513407979,
           -23.27809433810108,
           -23.22083354212237,
           -23.163572746143668,
           -23.106311950164955,
           -23.04905115418625,
           -22.991790358207545,
           -22.934529562228832,
           -22.877268766250126,
           -22.820007970271416,
           -22.762747174292713,
           -22.705486378314003,
           -22.648225582335293,
           -22.59096478635659,
           -22.53370399037788,
           -22.476443194399167,
           -22.419182398420467,
           -22.361921602441754,
           -22.304660806463044,
           -22.247400010484345,
           -22.190139214505635,
           -22.13287841852692,
           -22.075617622548208,
           -22.01835682656951,
           -21.961096030590795,
           -21.90383523461209,
           -21.846574438633382,
           -21.789313642654676,
           -21.732052846675963,
           -21.674792050697263,
           -21.61753125471855,
           -21.560270458739836,
           -21.503009662761134,
           -21.445748866782427,
           -21.388488070803717,
           -21.33122727482501,
           -21.273966478846305,
           -21.21670568286759,
           -21.159444886888885,
           -21.10218409091018,
           -21.04492329493147,
           -20.98766249895276,
           -20.93040170297406,
           -20.873140906995346,
           -20.815880111016632,
           -20.75861931503793,
           -20.701358519059223,
           -20.64409772308051,
           -20.586836927101807,
           -20.529576131123097,
           -20.472315335144387,
           -20.415054539165684,
           -20.357793743186978,
           -20.300532947208264,
           -20.24327215122955,
           -20.186011355250855,
           -20.12875055927214,
           -20.07148976329343,
           -20.014228967314722,
           -19.95696817133602,
           -19.899707375357305,
           -19.842446579378603,
           -19.785185783399896,
           -19.727924987421186,
           -19.670664191442473,
           -19.613403395463774,
           -19.55614259948506,
           -19.49888180350635,
           -19.441621007527644,
           -19.384360211548938,
           -19.327099415570224,
           -19.24998220752712,
           -19.073582939161952,
           -18.89718367079679,
           -18.720784402431626,
           -18.544385134066495,
           -18.367985865701332,
           -18.19158659733617,
           -18.015187328971034,
           -17.83878806060587,
           -17.66238879224071,
           -17.48598952387558,
           -17.309590255510415,
           -17.13319098714525,
           -16.95679171878009,
           -16.780392450414954,
           -16.603993182049795,
           -16.427593913684632,
           -16.251194645319497,
           -16.074795376954334,
           -15.898396108589173,
           -15.721996840224042,
           -15.568457754487643,
           -15.425166310530996,
           -15.281874866574379,
           -15.138583422617733,
           -14.995291978661086,
           -14.852000534704441,
           -14.708709090747824,
           -14.56541764679118,
           -14.422126202834535,
           -14.278834758877917,
           -14.135543314921271,
           -13.992251870964624,
           -13.848960427008008,
           -13.70566898305136,
           -13.562377539094715,
           -13.419086095138072,
           -13.275794651181453,
           -13.13250320722481,
           -12.989211763268164,
           -12.845920319311546,
           -12.7026288753549,
           -12.559337431398255,
           -12.416045987441636,
           -12.272754543484993,
           -12.129463099528348,
           -11.986171655571727,
           -11.842880211615084,
           -11.699588767658437,
           -11.556297323701793,
           -11.413005879745175,
           -11.269714435788531,
           -11.126422991831884,
           -10.983131547875265,
           -10.839840103918622,
           -10.696548659961977,
           -10.553257216005358,
           -10.409965772048713,
           -10.266674328092067,
           -10.123382884135422,
           -9.980091440178805,
           -9.83679999622216,
           -9.693508552265515,
           -9.56029062492114,
           -9.438153590212321,
           -9.316016555503497,
           -9.193879520794697,
           -9.071742486085876,
           -8.949605451377053,
           -8.827468416668255,
           -8.705331381959432,
           -8.583194347250611,
           -8.46105731254179,
           -8.33892027783299,
           -8.216783243124167,
           -8.094646208415346,
           -7.9725091737065465,
           -7.850372138997725,
           -7.728235104288903,
           -7.606098069580104,
           -7.4839610348712835,
           -7.36182400016246,
           -7.239686965453638,
           -7.117549930744839
          ],
          [
           -36.28327201623185,
           -36.32241569589724,
           -36.36155937556263,
           -36.40070305522802,
           -36.439846734893415,
           -36.47899041455881,
           -36.518134094224195,
           -36.55727777388959,
           -36.59642145355498,
           -36.63556513322037,
           -36.67470881288576,
           -36.713852492551155,
           -36.75299617221654,
           -36.792139851881934,
           -36.83128353154733,
           -36.87042721121272,
           -36.909570890878115,
           -36.9487145705435,
           -36.987858250208895,
           -37.02700192987429,
           -37.066145609539674,
           -37.10528928920507,
           -37.144432968870454,
           -37.183576648535855,
           -37.222720328201234,
           -37.261864007866635,
           -37.30100768753203,
           -37.34015136719741,
           -37.37929504686281,
           -37.418438726528194,
           -37.45758240619359,
           -37.49776334871072,
           -37.53846292277093,
           -37.57916249683113,
           -37.619862070891344,
           -37.66056164495155,
           -37.701261219011755,
           -37.74196079307196,
           -37.782660367132166,
           -37.82335994119238,
           -37.86405951525258,
           -37.90475908931278,
           -37.94545866337299,
           -37.986158237433195,
           -38.0268578114934,
           -38.067557385553606,
           -38.10825695961381,
           -38.148956533674024,
           -38.18965610773422,
           -38.230355681794435,
           -38.271055255854634,
           -38.31175482991485,
           -38.352454403975045,
           -38.39315397803526,
           -38.43385355209546,
           -38.47455312615567,
           -38.51525270021587,
           -38.55595227427608,
           -38.59665184833628,
           -38.63735142239649,
           -38.67805099645669,
           -38.7187505705169,
           -38.75945014457711,
           -38.800149718637314,
           -38.84084929269752,
           -38.881548866757726,
           -38.92224844081793,
           -38.96294801487814,
           -39.00364758893835,
           -39.044347162998555,
           -39.08504673705876,
           -39.12574631111896,
           -39.166445885179165,
           -39.20714545923937,
           -39.247845033299576,
           -39.28854460735978,
           -39.329244181419995,
           -39.3699437554802,
           -39.4106433295404,
           -39.451342903600604,
           -39.49204247766081,
           -39.53274205172102,
           -39.57344162578123,
           -39.614141199841434,
           -39.65209009951947,
           -39.68948886432107,
           -39.72688762912267,
           -39.76428639392428,
           -39.801685158725874,
           -39.83908392352748,
           -39.876482688329084,
           -39.913881453130685,
           -39.951280217932286,
           -39.98867898273389,
           -40.026077747535496,
           -40.06347651233709,
           -40.1008752771387,
           -40.1382740419403,
           -40.17567280674191,
           -40.21307157154351,
           -40.25047033634511,
           -40.28786910114671,
           -40.32526786594832,
           -40.36266663074992,
           -40.40006539555152,
           -40.43746416035313,
           -40.474862925154724,
           -40.51226168995633,
           -40.549660454757934,
           -40.587059219559535,
           -40.624457984361136,
           -40.66185674916274,
           -40.69925551396434,
           -40.73665427876595,
           -40.77405304356755,
           -40.81145180836915,
           -40.84885057317075,
           -40.88624933797235,
           -40.92364810277397,
           -40.96104686757556,
           -40.99844563237717,
           -41.03584439717877,
           -41.07324316198037,
           -41.110641926781966,
           -41.148040691583574,
           -41.185439456385176,
           -41.22283822118678,
           -41.26023698598838,
           -41.297635750789986,
           -41.33503451559159,
           -41.37243328039319,
           -41.4098320451948,
           -41.4472308099964,
           -41.484629574798,
           -41.5220283395996,
           -41.5594271044012,
           -41.5968258691549,
           -41.63327056935839,
           -41.66971526956188,
           -41.70615996976537,
           -41.742604669968856,
           -41.779049370172345,
           -41.81549407037584,
           -41.85193877057933,
           -41.88838347078283,
           -41.924828170986316,
           -41.961272871189806,
           -41.997717571393295,
           -42.034162271596784,
           -42.070606971800274,
           -42.10705167200377,
           -42.14349637220726,
           -42.17994107241075,
           -42.21638577261424,
           -42.25283047281773,
           -42.289275173021224,
           -42.32571987322471,
           -42.3621645734282,
           -42.39860927363169,
           -42.43505397383518,
           -42.47149867403868,
           -42.50794337424217,
           -42.544388074445656,
           -42.580832774649146,
           -42.61727747485264,
           -42.65372217505613,
           -42.69016687525962,
           -42.698732332423745,
           -42.69335816806818,
           -42.68798400371262,
           -42.682609839357056,
           -42.67723567500149,
           -42.671861510645925,
           -42.66648734629037,
           -42.66111318193481,
           -42.655739017579236,
           -42.65036485322368,
           -42.64499068886812,
           -42.63961652451255,
           -42.63424236015699,
           -42.62886819580143,
           -42.623494031445865,
           -42.6181198670903,
           -42.61274570273474,
           -42.60737153837918,
           -42.60199737402361,
           -42.59662320966805,
           -42.59124904531249,
           -42.58587488095692,
           -42.580500716601364,
           -42.5751265522458,
           -42.56975238789023,
           -42.564378223534675,
           -42.55900405917911,
           -42.55362989482355,
           -42.548255730467986,
           -42.54288156611242,
           -42.537507401756855,
           -42.5321332374013,
           -42.52675907304573,
           -42.521384908690166,
           -42.51601074433461,
           -42.51063657997904,
           -42.505262415623484,
           -42.49988825126792,
           -42.49451408691235,
           -42.48913992255679,
           -42.48376575820123,
           -42.47839159384567,
           -42.473017429490106,
           -42.466220745739484,
           -42.4380862447749,
           -42.409951743810325,
           -42.38181724284574,
           -42.35368274188116,
           -42.32554824091658,
           -42.297413739952,
           -42.26927923898742,
           -42.24114473802284,
           -42.21301023705826,
           -42.18487573609368,
           -42.1567412351291,
           -42.12860673416452,
           -42.10047223319994,
           -42.07233773223536,
           -42.04420323127078,
           -42.01606873030619,
           -41.98793422934161,
           -41.959799728377035,
           -41.93166522741245,
           -41.90353072644787,
           -41.87539622548329,
           -41.84726172451872,
           -41.81912722355413,
           -41.79099272258955,
           -41.76285822162497,
           -41.73472372066039,
           -41.706589219695815,
           -41.67845471873123,
           -41.65032021776665,
           -41.62218571680207,
           -41.59405121583749,
           -41.565916714872905,
           -41.53778221390832,
           -41.509647712943746,
           -41.48151321197916,
           -41.45337871101459,
           -41.42524421005001,
           -41.39710970908543,
           -41.368975208120844,
           -41.25152069299361,
           -41.04474616370374,
           -40.83797163441388,
           -40.63119710512403,
           -40.42442257583416,
           -40.2176480465443,
           -40.01087351725443,
           -39.804098987964565,
           -39.59732445867469,
           -39.390549929384854,
           -39.183775400094966,
           -38.9770008708051,
           -38.77022634151523,
           -38.56345181222538,
           -38.35667728293551,
           -38.14990275364565,
           -37.943128224355796,
           -37.736353695065915,
           -37.52957916577606,
           -37.322804636486204,
           -37.11603010719633,
           -36.90925557790646,
           -36.70248104861662,
           -36.49570651932674,
           -36.288931990036865,
           -36.082157460747005,
           -35.87538293145715,
           -35.66860840216727,
           -35.46183387287742,
           -35.25505934358756,
           -35.04828481429769,
           -34.84151028500781,
           -34.63473575571797,
           -34.427961226428096,
           -34.22118669713822,
           -34.01441216784836,
           -33.80763763855851,
           -33.60086310926863,
           -33.39408857997878,
           -33.18731405068892,
           -32.98053952139904,
           -32.77376499210919,
           -32.566990462819334,
           -32.36021593352945,
           -32.15344140423958,
           -31.94666687494974,
           -31.739892345659865,
           -31.533117816369987,
           -31.326343287080135,
           -31.119773205761653,
           -30.917360153621438,
           -30.71494710148125,
           -30.512534049341056,
           -30.310120997200848,
           -30.107707945060632,
           -29.905294892920463,
           -29.70288184078025,
           -29.50046878864004,
           -29.298055736499848,
           -29.095642684359653,
           -28.893229632219445,
           -28.69081658007925,
           -28.488403527939063,
           -28.285990475798847,
           -28.083577423658653,
           -27.881164371518462,
           -27.67875131937825,
           -27.47633826723804,
           -27.27392521509786,
           -27.071512162957653,
           -26.869099110817444,
           -26.66668605867725,
           -26.464273006537056,
           -26.261859954396847,
           -26.059446902256653,
           -25.85703385011646,
           -25.65462079797625,
           -25.452207745836056,
           -25.249794693695865,
           -25.047381641555653,
           -24.844968589415444,
           -24.64255553727525,
           -24.440142485135055,
           -24.28637875171104,
           -24.229913655719365,
           -24.173448559727696,
           -24.116983463736023,
           -24.06051836774435,
           -24.00405327175268,
           -23.947588175761005,
           -23.89112307976933,
           -23.834657983777664,
           -23.778192887785984,
           -23.72172779179431,
           -23.665262695802642,
           -23.60879759981097,
           -23.552332503819294,
           -23.495867407827625,
           -23.439402311835952,
           -23.38293721584428,
           -23.32647211985261,
           -23.270007023860938,
           -23.213541927869258,
           -23.157076831877585,
           -23.100611735885913,
           -23.044146639894244,
           -22.987681543902568,
           -22.9312164479109,
           -22.874751351919226,
           -22.81828625592755,
           -22.761821159935877,
           -22.705356063944212,
           -22.648890967952532,
           -22.592425871960856,
           -22.535960775969194,
           -22.479495679977518,
           -22.42303058398584,
           -22.366565487994173,
           -22.3101003920025,
           -22.253635296010824,
           -22.19717020001915,
           -22.140705104027482,
           -22.084240008035806,
           -22.027774912044134,
           -21.971309816052464,
           -21.91484472006079,
           -21.85837962406911,
           -21.80191452807744,
           -21.74544943208577,
           -21.688984336094094,
           -21.632519240102425,
           -21.576054144110756,
           -21.51935395565654,
           -21.462093159677835,
           -21.40483236369913,
           -21.34757156772042,
           -21.29031077174171,
           -21.23304997576301,
           -21.175789179784296,
           -21.118528383805586,
           -21.061267587826876,
           -21.004006791848173,
           -20.94674599586946,
           -20.889485199890757,
           -20.83222440391205,
           -20.774963607933337,
           -20.71770281195463,
           -20.660442015975924,
           -20.603181219997214,
           -20.5459204240185,
           -20.488659628039805,
           -20.43139883206109,
           -20.37413803608238,
           -20.31687724010368,
           -20.259616444124966,
           -20.202355648146256,
           -20.145094852167553,
           -20.087834056188843,
           -20.030573260210133,
           -19.97331246423142,
           -19.91605166825272,
           -19.85879087227401,
           -19.8015300762953,
           -19.744269280316594,
           -19.687008484337888,
           -19.629747688359174,
           -19.55263048031607,
           -19.376231211950902,
           -19.19983194358574,
           -19.023432675220576,
           -18.847033406855445,
           -18.670634138490282,
           -18.49423487012512,
           -18.317835601759988,
           -18.141436333394825,
           -17.965037065029662,
           -17.788637796664528,
           -17.612238528299365,
           -17.435839259934202,
           -17.25943999156904,
           -17.083040723203908,
           -16.90664145483874,
           -16.730242186473582,
           -16.55384291810845,
           -16.377443649743284,
           -16.20104438137812,
           -16.024645113012994,
           -15.848245844647826,
           -15.671846576282665,
           -15.495447307917534,
           -15.319048039552369,
           -15.142648771187206,
           -14.966249502822041,
           -14.78985023445691,
           -14.613450966091747,
           -14.437051697726584,
           -14.260652429361453,
           -14.08425316099629,
           -13.907853892631126,
           -13.731454624265995,
           -13.55505535590083,
           -13.378656087535669,
           -13.202256819170504,
           -13.025857550805373,
           -12.849458282440212,
           -12.673059014075047,
           -12.507526794405411,
           -12.364235350448764,
           -12.220943906492119,
           -12.077652462535502,
           -11.952097607830904,
           -11.829960573122083,
           -11.707823538413283,
           -11.585686503704462,
           -11.46354946899564,
           -11.341412434286818,
           -11.219275399578018,
           -11.097138364869199,
           -10.975001330160374,
           -10.852864295451575,
           -10.730727260742754,
           -10.608590226033932,
           -10.486453191325134,
           -10.364316156616312,
           -10.242179121907489,
           -10.120042087198668,
           -9.997905052489868,
           -9.875768017781045,
           -9.753630983072224,
           -9.631493948363424,
           -9.509356913654603,
           -9.387219878945782,
           -9.265082844236982,
           -9.142945809528161,
           -9.020808774819336,
           -8.898671740110538,
           -8.776534705401717,
           -8.654397670692894,
           -8.532260635984073,
           -8.410123601275274,
           -8.287986566566452,
           -8.165849531857631,
           -8.043712497148832,
           -7.921575462440009,
           -7.799438427731187,
           -7.677301393022388,
           -7.555164358313565,
           -7.433027323604744,
           -7.310890288895923,
           -7.188753254187123
          ],
          [
           -35.92386232999032,
           -35.963006009655714,
           -36.0021496893211,
           -36.04129336898649,
           -36.08043704865189,
           -36.119580728317274,
           -36.15872440798267,
           -36.19786808764806,
           -36.23701176731345,
           -36.27615544697885,
           -36.315299126644234,
           -36.35444280630962,
           -36.393586485975014,
           -36.43273016564041,
           -36.4718738453058,
           -36.511017524971194,
           -36.55016120463658,
           -36.589304884301974,
           -36.62844856396737,
           -36.667592243632754,
           -36.70673592329814,
           -36.74587960296354,
           -36.78502328262893,
           -36.82416696229433,
           -36.863310641959714,
           -36.9024543216251,
           -36.9415980012905,
           -36.98074168095589,
           -37.01988536062128,
           -37.05902904028667,
           -37.09817271995206,
           -37.137316399617454,
           -37.17646007928285,
           -37.215603758948234,
           -37.25474743861362,
           -37.29389111827902,
           -37.33303479794441,
           -37.37217847760979,
           -37.411322157275194,
           -37.45046583694058,
           -37.489609516605974,
           -37.52875319627137,
           -37.56789687593675,
           -37.60704055560215,
           -37.64618423526754,
           -37.68532791493293,
           -37.72447159459832,
           -37.76387458966133,
           -37.80457416372153,
           -37.84527373778174,
           -37.885973311841944,
           -37.92667288590215,
           -37.96737245996236,
           -38.00807203402256,
           -38.048771608082774,
           -38.08947118214297,
           -38.130170756203185,
           -38.17087033026339,
           -38.211569904323596,
           -38.252269478383795,
           -38.29296905244401,
           -38.33366862650421,
           -38.37436820056442,
           -38.41506777462462,
           -38.45576734868483,
           -38.496466922745036,
           -38.53716649680524,
           -38.57786607086545,
           -38.61856564492565,
           -38.65926521898586,
           -38.699964793046064,
           -38.74066436710627,
           -38.781363941166475,
           -38.82206351522669,
           -38.862763089286894,
           -38.9034626633471,
           -38.9441622374073,
           -38.9848618114675,
           -39.02556138552771,
           -39.066260959587915,
           -39.10696053364813,
           -39.147660107708326,
           -39.18835968176853,
           -39.22905925582874,
           -39.26700815550677,
           -39.30440692030838,
           -39.34180568510998,
           -39.37920444991158,
           -39.416603214713184,
           -39.454001979514786,
           -39.491400744316394,
           -39.528799509117995,
           -39.566198273919596,
           -39.603597038721205,
           -39.640995803522806,
           -39.67839456832441,
           -39.715793333126015,
           -39.75319209792761,
           -39.79059086272922,
           -39.82798962753082,
           -39.86538839233242,
           -39.90278715713403,
           -39.94018592193562,
           -39.97758468673723,
           -40.014983451538825,
           -40.05238221634043,
           -40.089780981142034,
           -40.127179745943636,
           -40.164578510745244,
           -40.201977275546845,
           -40.239376040348446,
           -40.27677480515005,
           -40.31417356995165,
           -40.35157233475326,
           -40.38897109955486,
           -40.42636986435646,
           -40.46376862915806,
           -40.50116739395966,
           -40.53856615876126,
           -40.57596492356287,
           -40.61288665586008,
           -40.64933135606357,
           -40.685776056267066,
           -40.722220756470556,
           -40.758665456674045,
           -40.795110156877534,
           -40.83155485708104,
           -40.86799955728452,
           -40.90444425748801,
           -40.940888957691506,
           -40.977333657894995,
           -41.013778358098484,
           -41.05022305830198,
           -41.08666775850546,
           -41.12311245870896,
           -41.15955715891245,
           -41.19600185911594,
           -41.23244655931943,
           -41.26889125952292,
           -41.30533595972641,
           -41.3417806599299,
           -41.37822536013339,
           -41.41467006033688,
           -41.45111476054038,
           -41.48755946074387,
           -41.52400416094736,
           -41.560448861150846,
           -41.596893561354335,
           -41.63333826155783,
           -41.66978296176132,
           -41.70622766196481,
           -41.74267236216831,
           -41.77911706237179,
           -41.81556176257528,
           -41.852006462778775,
           -41.888451162982264,
           -41.92489586318575,
           -41.96134056338924,
           -41.99778526359273,
           -42.03422996379622,
           -42.07067466399972,
           -42.107119364203214,
           -42.1435640644067,
           -42.180008764610186,
           -42.21645346481368,
           -42.25289816501717,
           -42.28934286522066,
           -42.297908322384785,
           -42.29253415802922,
           -42.287159993673654,
           -42.281785829318096,
           -42.27641166496254,
           -42.27103750060697,
           -42.26566333625141,
           -42.26028917189585,
           -42.25491500754028,
           -42.24954084318472,
           -42.24416667882916,
           -42.238792514473595,
           -42.233418350118036,
           -42.22804418576247,
           -42.222670021406906,
           -42.21729585705135,
           -42.21192169269578,
           -42.206547528340224,
           -42.20117336398466,
           -42.19579919962909,
           -42.190425035273535,
           -42.18505087091797,
           -42.179676706562404,
           -42.174302542206846,
           -42.16892837785128,
           -42.163554213495715,
           -42.15818004914016,
           -42.15280588478459,
           -42.147431720429026,
           -42.14205755607347,
           -42.13668339171791,
           -42.13130922736234,
           -42.12593506300678,
           -42.12056089865122,
           -42.11518673429565,
           -42.10981256994009,
           -42.104438405584524,
           -42.09906424122897,
           -42.0936900768734,
           -42.088315912517835,
           -42.08294174816227,
           -42.07756758380671,
           -42.072193419451146,
           -42.06681925509559,
           -42.06144509074002,
           -42.05607092638446,
           -42.0506967620289,
           -42.045322597673334,
           -42.039948433317775,
           -42.03457426896221,
           -42.02920010460665,
           -42.023825940251086,
           -42.01845177589552,
           -42.013077611539956,
           -42.0077034471844,
           -42.00232928282883,
           -41.99695511847327,
           -41.99158095411771,
           -41.98620678976215,
           -41.980832625406585,
           -41.97545846105102,
           -41.970084296695454,
           -41.9647101323399,
           -41.95933596798434,
           -41.95396180362877,
           -41.94858763927321,
           -41.94321347491765,
           -41.93001545189421,
           -41.90188095092962,
           -41.87374644996504,
           -41.845611949000464,
           -41.81747744803589,
           -41.789342947071304,
           -41.76120844610672,
           -41.73307394514214,
           -41.70493944417756,
           -41.67680494321298,
           -41.6486704422484,
           -41.62053594128382,
           -41.59240144031924,
           -41.56426693935466,
           -41.53613243839008,
           -41.5079979374255,
           -41.390543422298265,
           -41.18376889300839,
           -40.97699436371853,
           -40.77021983442869,
           -40.5634453051388,
           -40.356670775848954,
           -40.14989624655909,
           -39.943121717269214,
           -39.73634718797935,
           -39.52957265868951,
           -39.32279812939962,
           -39.116023600109756,
           -38.90924907081989,
           -38.70247454153004,
           -38.49570001224016,
           -38.28892548295031,
           -38.08215095366045,
           -37.87537642437057,
           -37.66860189508072,
           -37.46182736579086,
           -37.258085429104426,
           -37.05567237696422,
           -36.853259324824045,
           -36.650846272683836,
           -36.44843322054362,
           -36.246020168403426,
           -36.04360711626324,
           -35.84119406412302,
           -35.63878101198283,
           -35.43636795984264,
           -35.233954907702426,
           -35.03154185556222,
           -34.829128803422044,
           -34.62671575128183,
           -34.42430269914162,
           -34.221889647001426,
           -34.01947659486124,
           -33.81706354272102,
           -33.61465049058083,
           -33.41223743844064,
           -33.209824386300426,
           -33.00741133416023,
           -32.804998282020044,
           -32.60258522987983,
           -32.40017217773962,
           -32.19775912559945,
           -31.99534607345924,
           -31.792933021319026,
           -31.590519969178835,
           -31.38810691703864,
           -31.185693864898433,
           -30.983280812758235,
           -30.78086776061804,
           -30.57845470847783,
           -30.37604165633762,
           -30.173628604197447,
           -29.971215552057235,
           -29.768802499917022,
           -29.56638944777683,
           -29.36397639563664,
           -29.16156334349643,
           -28.959150291356238,
           -28.756737239216044,
           -28.554324187075835,
           -28.35191113493564,
           -28.149498082795446,
           -27.947085030655238,
           -27.744671978515026,
           -27.542258926374853,
           -27.33984587423464,
           -27.137432822094432,
           -26.935019769954238,
           -26.732606717814047,
           -26.530193665673835,
           -26.32778061353364,
           -26.12536756139345,
           -25.922954509253238,
           -25.720541457113043,
           -25.518128404972853,
           -25.31571535283264,
           -25.11330230069243,
           -24.910889248552238,
           -24.708476196412043,
           -24.554712462988025,
           -24.498247366996356,
           -24.441782271004687,
           -24.385317175013007,
           -24.328852079021342,
           -24.27238698302967,
           -24.215921887037993,
           -24.159456791046317,
           -24.102991695054648,
           -24.046526599062975,
           -23.9900615030713,
           -23.93359640707963,
           -23.877131311087957,
           -23.820666215096285,
           -23.764201119104612,
           -23.70773602311294,
           -23.651270927121264,
           -23.594805831129595,
           -23.538340735137922,
           -23.481875639146246,
           -23.425410543154573,
           -23.368945447162904,
           -23.31248035117123,
           -23.256015255179555,
           -23.199550159187886,
           -23.143085063196217,
           -23.08661996720454,
           -23.03015487121287,
           -22.9736897752212,
           -22.917224679229523,
           -22.860759583237844,
           -22.80429448724618,
           -22.747829391254502,
           -22.69136429526283,
           -22.63489919927116,
           -22.578434103279488,
           -22.52196900728781,
           -22.465503911296143,
           -22.409038815304466,
           -22.35257371931279,
           -22.29610862332112,
           -22.239643527329452,
           -22.183178431337776,
           -22.1267133353461,
           -22.07024823935443,
           -22.01378314336276,
           -21.957318047371082,
           -21.900852951379413,
           -21.84438785538774,
           -21.787922759396064,
           -21.731457663404395,
           -21.674992567412726,
           -21.61852747142105,
           -21.562062375429374,
           -21.50559727943771,
           -21.449132183446036,
           -21.392667087454353,
           -21.336201991462687,
           -21.27973689547101,
           -21.22327179947934,
           -21.16680670348767,
           -21.110341607495997,
           -21.05387651150432,
           -20.99741141551265,
           -20.940946319520982,
           -20.884481223529306,
           -20.828016127537627,
           -20.771933553147658,
           -20.71604827906488,
           -20.660163004982103,
           -20.60427773089933,
           -20.54839245681655,
           -20.492507182733775,
           -20.436621908651002,
           -20.380736634568226,
           -20.324851360485447,
           -20.26896608640267,
           -20.213080812319898,
           -20.15719553823712,
           -20.101310264154343,
           -20.045424990071567,
           -19.98953971598879,
           -19.93365444190601,
           -19.85647048991657,
           -19.672793148393744,
           -19.48911580687092,
           -19.305438465348097,
           -19.12176112382531,
           -18.96910267061071,
           -18.817882941248477,
           -18.66666321188628,
           -18.515443482524052,
           -18.36422375316182,
           -18.21300402379962,
           -18.06178429443739,
           -17.910564565075163,
           -17.759344835712934,
           -17.608125106350734,
           -17.456905376988505,
           -17.305685647626277,
           -17.154465918264076,
           -17.003246188901848,
           -16.85202645953962,
           -16.70080673017742,
           -16.54958700081519,
           -16.398367271452962,
           -16.247147542090758,
           -16.09592781272853,
           -15.944708083366303,
           -15.793488354004074,
           -15.642268624641872,
           -15.491048895279645,
           -15.339829165917417,
           -15.188609436555216,
           -15.037389707192988,
           -14.88616997783076,
           -14.734950248468559,
           -14.58373051910633,
           -14.432510789744098,
           -14.281291060381871,
           -14.130071331019671,
           -13.978851601657441,
           -13.827631872295216,
           -13.676412142933012,
           -13.525192413570785,
           -13.373972684208557,
           -13.222752954846355,
           -13.071533225484126,
           -12.9203134961219,
           -12.769093766759697,
           -12.617874037397469,
           -12.466654308035238,
           -12.315434578673012,
           -12.164214849310811,
           -12.012995119948583,
           -11.861775390586354,
           -11.710555661224152,
           -11.559335931861922,
           -11.408116202499695,
           -11.256896473137493,
           -11.105676743775264,
           -10.954457014413036,
           -10.803237285050807,
           -10.652017555688607,
           -10.500797826326378,
           -10.34957809696415,
           -10.19835836760195,
           -10.047138638239721,
           -9.895918908877492,
           -9.744699179515292,
           -9.593479450153064,
           -9.442259720790835,
           -9.291039991428633,
           -9.139820262066404,
           -8.988600532704176,
           -8.837380803341947,
           -8.686161073979745,
           -8.534941344617518,
           -8.383721615255288,
           -8.232501885893088,
           -8.08128215653086,
           -7.93006242716863,
           -7.783204202555648,
           -7.652655806901131,
           -7.522107411246611,
           -7.391559015592093,
           -7.261010619937599
          ],
          [
           -35.564452643748794,
           -35.60359632341418,
           -35.64274000307958,
           -35.68188368274497,
           -35.721027362410354,
           -35.760171042075754,
           -35.79931472174114,
           -35.83845840140653,
           -35.87760208107193,
           -35.916745760737314,
           -35.955889440402714,
           -35.9950331200681,
           -36.03417679973349,
           -36.07332047939889,
           -36.112464159064274,
           -36.15160783872966,
           -36.19075151839506,
           -36.22989519806045,
           -36.26903887772583,
           -36.308182557391234,
           -36.34732623705662,
           -36.38646991672201,
           -36.4256135963874,
           -36.464757276052794,
           -36.50390095571818,
           -36.54304463538358,
           -36.582188315048974,
           -36.62133199471435,
           -36.660475674379754,
           -36.69961935404514,
           -36.73876303371053,
           -36.77790671337593,
           -36.81705039304131,
           -36.85619407270671,
           -36.8953377523721,
           -36.93448143203749,
           -36.97362511170289,
           -37.012768791368266,
           -37.05191247103367,
           -37.09105615069905,
           -37.13019983036445,
           -37.16934351002983,
           -37.208487189695234,
           -37.24763086936062,
           -37.286774549026006,
           -37.32591822869141,
           -37.36506190835679,
           -37.40420558802219,
           -37.44334926768758,
           -37.482492947352966,
           -37.52163662701836,
           -37.56078030668375,
           -37.59992398634914,
           -37.63906766601453,
           -37.67821134567993,
           -37.71735502534531,
           -37.75649870501071,
           -37.7956423846761,
           -37.834786064341486,
           -37.87392974400689,
           -37.91307342367227,
           -37.95221710333767,
           -37.99136078300306,
           -38.030504462668446,
           -38.07068540467213,
           -38.111384978732346,
           -38.152084552792545,
           -38.19278412685276,
           -38.23348370091296,
           -38.27418327497317,
           -38.314882849033374,
           -38.35558242309358,
           -38.396281997153785,
           -38.43698157121399,
           -38.4776811452742,
           -38.5183807193344,
           -38.55908029339461,
           -38.599779867454814,
           -38.64047944151502,
           -38.681179015575225,
           -38.72187858963543,
           -38.762578163695636,
           -38.80327773775584,
           -38.84397731181605,
           -38.88192621149408,
           -38.919324976295684,
           -38.95672374109729,
           -38.99412250589889,
           -39.031521270700495,
           -39.0689200355021,
           -39.1063188003037,
           -39.1437175651053,
           -39.1811163299069,
           -39.21851509470851,
           -39.255913859510116,
           -39.29331262431171,
           -39.33071138911332,
           -39.36811015391492,
           -39.40550891871653,
           -39.44290768351813,
           -39.48030644831973,
           -39.51770521312134,
           -39.55510397792294,
           -39.59250274236179,
           -39.62894744256528,
           -39.665392142768766,
           -39.70183684297226,
           -39.738281543175745,
           -39.774726243379234,
           -39.81117094358273,
           -39.84761564378622,
           -39.88406034398971,
           -39.920505044193206,
           -39.956949744396695,
           -39.993394444600185,
           -40.02983914480367,
           -40.06628384500716,
           -40.10272854521065,
           -40.13917324541414,
           -40.17561794561764,
           -40.21206264582113,
           -40.24850734602462,
           -40.28495204622811,
           -40.3213967464316,
           -40.35784144663509,
           -40.39428614683859,
           -40.43073084704208,
           -40.46717554724557,
           -40.50362024744906,
           -40.540064947652546,
           -40.57650964785604,
           -40.61295434805953,
           -40.64939904826302,
           -40.68584374846651,
           -40.72228844867,
           -40.75873314887349,
           -40.79517784907698,
           -40.831622549280475,
           -40.868067249483964,
           -40.90451194968746,
           -40.94095664989095,
           -40.97740135009444,
           -41.01384605029793,
           -41.05029075050142,
           -41.08673545070491,
           -41.1231801509084,
           -41.15962485111189,
           -41.19606955131538,
           -41.23251425151888,
           -41.26895895172237,
           -41.30540365192586,
           -41.34184835212935,
           -41.378293052332836,
           -41.414737752536325,
           -41.451182452739815,
           -41.487627152943304,
           -41.52407185314679,
           -41.56051655335029,
           -41.59696125355378,
           -41.63340595375727,
           -41.669850653960765,
           -41.706295354164254,
           -41.742740054367744,
           -41.77918475457123,
           -41.81562945477472,
           -41.85207415497822,
           -41.88851885518171,
           -41.897084312345825,
           -41.89171014799027,
           -41.88633598363471,
           -41.88096181927914,
           -41.87558765492358,
           -41.87021349056802,
           -41.864839326212454,
           -41.85946516185689,
           -41.85409099750133,
           -41.848716833145765,
           -41.8433426687902,
           -41.83796850443464,
           -41.832594340079076,
           -41.82722017572351,
           -41.82184601136795,
           -41.816471847012394,
           -41.81109768265682,
           -41.805723518301264,
           -41.800349353945705,
           -41.79497518959014,
           -41.78960102523457,
           -41.78422686087901,
           -41.77885269652346,
           -41.77347853216789,
           -41.76810436781233,
           -41.76273020345676,
           -41.7573560391012,
           -41.75198187474564,
           -41.74660771039007,
           -41.74123354603451,
           -41.73585938167895,
           -41.73048521732339,
           -41.72511105296782,
           -41.71973688861226,
           -41.714362724256695,
           -41.70898855990113,
           -41.70361439554557,
           -41.69824023119001,
           -41.69286606683444,
           -41.68749190247888,
           -41.68211773812332,
           -41.67674357376776,
           -41.67136940941219,
           -41.665995245056635,
           -41.66062108070106,
           -41.655246916345504,
           -41.64987275198994,
           -41.64449858763438,
           -41.639124423278815,
           -41.63375025892325,
           -41.62837609456769,
           -41.62300193021213,
           -41.61762776585657,
           -41.612253601501,
           -41.60687943714544,
           -41.60150527278988,
           -41.596131108434314,
           -41.59075694407875,
           -41.58538277972319,
           -41.580008615367625,
           -41.57463445101207,
           -41.5692602866565,
           -41.56388612230094,
           -41.55851195794537,
           -41.55313779358981,
           -41.551254450361036,
           -41.552861910814954,
           -41.55446937126888,
           -41.556076831722805,
           -41.557684292176724,
           -41.55929175263064,
           -41.56089921308457,
           -41.56250667353849,
           -41.56411413399241,
           -41.56572159444633,
           -41.56732905490025,
           -41.56893651535418,
           -41.57054397580809,
           -41.57215143626202,
           -41.573758896715944,
           -41.57536635716987,
           -41.57697381762379,
           -41.578581278077706,
           -41.48356248790332,
           -41.291917447100644,
           -41.100272406297975,
           -40.908627365495306,
           -40.71698232469263,
           -40.52533728388996,
           -40.33369224308729,
           -40.14204720228461,
           -39.950402161481925,
           -39.75069261868826,
           -39.548294905032286,
           -39.345897191376295,
           -39.143499477720326,
           -38.94110176406437,
           -38.73870405040838,
           -38.53630633675242,
           -38.333908623096455,
           -38.131510909440465,
           -37.9291131957845,
           -37.72671548212854,
           -37.52431776847255,
           -37.32192005481657,
           -37.11952234116062,
           -36.91712462750464,
           -36.71472691384865,
           -36.51232920019269,
           -36.30993148653672,
           -36.10753377288074,
           -35.90513605922477,
           -35.70273834556881,
           -35.50034063191282,
           -35.297942918256844,
           -35.095545204600896,
           -34.893147490944905,
           -34.69074977728892,
           -34.48835206363296,
           -34.28595434997699,
           -34.08355663632101,
           -33.88115892266504,
           -33.67876120900908,
           -33.4763634953531,
           -33.27396578169713,
           -33.07156806804116,
           -32.869170354385176,
           -32.6667726407292,
           -32.46437492707325,
           -32.26197721341727,
           -32.059579499761284,
           -31.857181786105315,
           -31.65478407244935,
           -31.45238635879337,
           -31.249988645137403,
           -31.047590931481437,
           -30.84519321782545,
           -30.642795504169467,
           -30.44039779051352,
           -30.23800007685754,
           -30.03560236320155,
           -29.83320464954559,
           -29.63080693588962,
           -29.42840922223364,
           -29.226011508577674,
           -29.023613794921708,
           -28.82121608126572,
           -28.618818367609755,
           -28.416420653953793,
           -28.214022940297806,
           -28.011625226641822,
           -27.809227512985878,
           -27.60682979932989,
           -27.404432085673907,
           -27.20203437201794,
           -26.999636658361975,
           -26.79723894470599,
           -26.594841231050026,
           -26.39244351739406,
           -26.190045803738077,
           -25.98764809008211,
           -25.785250376426145,
           -25.58285266277016,
           -25.380454949114178,
           -25.178057235458212,
           -24.975659521802246,
           -24.822481870820745,
           -24.76774434518818,
           -24.713006819555616,
           -24.658269293923045,
           -24.603531768290477,
           -24.548794242657912,
           -24.49405671702534,
           -24.439225877630776,
           -24.383340603548007,
           -24.327455329465227,
           -24.271570055382448,
           -24.21568478129967,
           -24.159799507216903,
           -24.103914233134123,
           -24.048028959051347,
           -23.99214368496857,
           -23.936258410885795,
           -23.88037313680302,
           -23.824487862720247,
           -23.768602588637467,
           -23.712717314554688,
           -23.65683204047191,
           -23.600946766389143,
           -23.54506149230636,
           -23.489176218223587,
           -23.43329094414082,
           -23.377405670058035,
           -23.321520395975263,
           -23.265635121892487,
           -23.209749847809707,
           -23.153864573726928,
           -23.097979299644162,
           -23.042094025561383,
           -22.986208751478607,
           -22.93032347739583,
           -22.874438203313055,
           -22.818552929230275,
           -22.762667655147503,
           -22.706782381064727,
           -22.650897106981947,
           -22.595011832899175,
           -22.539126558816402,
           -22.48324128473362,
           -22.427356010650847,
           -22.37147073656807,
           -22.315585462485295,
           -22.259700188402512,
           -22.203814914319743,
           -22.147929640236967,
           -22.09204436615419,
           -22.036159092071415,
           -21.980273817988643,
           -21.92438854390586,
           -21.868503269823083,
           -21.812617995740315,
           -21.756732721657535,
           -21.700847447574752,
           -21.644962173491983,
           -21.589076899409207,
           -21.53319162532643,
           -21.477306351243655,
           -21.421421077160883,
           -21.365535803078103,
           -21.309650528995327,
           -21.253765254912555,
           -21.197879980829775,
           -21.141994706747,
           -21.08610943266423,
           -21.030224158581447,
           -20.97433888449867,
           -20.918453610415895,
           -20.862568336333123,
           -20.806683062250343,
           -20.750797788167567,
           -20.6949125140848,
           -20.639027240002015,
           -20.58314196591924,
           -20.527256691836467,
           -20.471371417753687,
           -20.41548614367091,
           -20.359600869588135,
           -20.303715595505363,
           -20.247830321422583,
           -20.170646369433143,
           -19.986969027910312,
           -19.80329168638749,
           -19.619614344864665,
           -19.435937003341877,
           -19.252259661819053,
           -19.06858232029623,
           -18.884904978773438,
           -18.70122763725061,
           -18.517550295727787,
           -18.333872954205,
           -18.150195612682175,
           -17.966518271159348,
           -17.782840929636524,
           -17.599163588113733,
           -17.41548624659091,
           -17.231808905068085,
           -17.048131563545294,
           -16.86445422202247,
           -16.680776880499646,
           -16.497099538976855,
           -16.31342219745403,
           -16.129744855931207,
           -15.946067514408417,
           -15.762390172885592,
           -15.603689113959966,
           -15.452469384597737,
           -15.301249655235537,
           -15.150029925873309,
           -14.99881019651108,
           -14.847590467148878,
           -14.696370737786648,
           -14.545151008424423,
           -14.393931279062222,
           -14.242711549699994,
           -14.091491820337763,
           -13.940272090975535,
           -13.789052361613333,
           -13.637832632251104,
           -13.486612902888876,
           -13.335393173526679,
           -13.184173444164449,
           -13.032953714802222,
           -12.881733985440018,
           -12.73051425607779,
           -12.579294526715561,
           -12.42807479735336,
           -12.276855067991132,
           -12.125635338628904,
           -11.974415609266675,
           -11.823195879904475,
           -11.671976150542246,
           -11.520756421180014,
           -11.369536691817814,
           -11.218316962455587,
           -11.067097233093357,
           -10.915877503731156,
           -10.764657774368928,
           -10.6134380450067,
           -10.470428184792738,
           -10.339879789138243,
           -10.209331393483724,
           -10.078782997829205,
           -9.948234602174711,
           -9.817686206520191,
           -9.687137810865673,
           -9.556589415211178,
           -9.42604101955666,
           -9.295492623902142,
           -9.164944228247649,
           -9.034395832593127,
           -8.903847436938609,
           -8.77329904128409,
           -8.642750645629595,
           -8.512202249975077,
           -8.381653854320557,
           -8.251105458666064,
           -8.120557063011546,
           -7.990008667357026,
           -7.859460271702531,
           -7.728911876048014,
           -7.598363480393494,
           -7.467815084738976,
           -7.337266689084481
          ],
          [
           -35.205042957507274,
           -35.24418663717267,
           -35.283330316838054,
           -35.32247399650344,
           -35.36161767616884,
           -35.40076135583423,
           -35.43990503549961,
           -35.47904871516501,
           -35.5181923948304,
           -35.557336074495794,
           -35.59647975416119,
           -35.635623433826574,
           -35.67476711349196,
           -35.71391079315736,
           -35.75305447282275,
           -35.79219815248814,
           -35.831341832153534,
           -35.87048551181892,
           -35.90962919148431,
           -35.94877287114971,
           -35.98791655081509,
           -36.02706023048049,
           -36.06620391014588,
           -36.105347589811274,
           -36.14449126947667,
           -36.18363494914205,
           -36.22277862880745,
           -36.26192230847284,
           -36.301065988138234,
           -36.34020966780362,
           -36.379353347469014,
           -36.41849702713441,
           -36.4576407067998,
           -36.496784386465194,
           -36.53592806613057,
           -36.57507174579597,
           -36.61421542546137,
           -36.653359105126746,
           -36.69250278479215,
           -36.73164646445753,
           -36.77079014412292,
           -36.80993382378831,
           -36.84907750345371,
           -36.8882211831191,
           -36.927364862784486,
           -36.96650854244988,
           -37.00565222211527,
           -37.04479590178066,
           -37.08393958144605,
           -37.12308326111145,
           -37.16222694077684,
           -37.201370620442226,
           -37.24051430010762,
           -37.27965797977301,
           -37.3188016594384,
           -37.35794533910379,
           -37.39708901876919,
           -37.43623269843457,
           -37.475376378099966,
           -37.51452005776536,
           -37.553663737430746,
           -37.59280741709614,
           -37.63195109676153,
           -37.67109477642692,
           -37.71023845609232,
           -37.749382135757706,
           -37.78852581542309,
           -37.827669495088486,
           -37.86681317475388,
           -37.90595685441927,
           -37.945100534084666,
           -37.98424421375005,
           -38.023387893415446,
           -38.06253157308084,
           -38.101675252746226,
           -38.14081893241162,
           -38.17996261207701,
           -38.2191062917424,
           -38.25824997140779,
           -38.297393651073186,
           -38.33679664562274,
           -38.377496219682946,
           -38.41819579374315,
           -38.45889536780336,
           -38.4968442674814,
           -38.534243032283,
           -38.5716417970846,
           -38.60856352906698,
           -38.64500822927047,
           -38.681452929473956,
           -38.717897629677445,
           -38.75434232988094,
           -38.79078703008443,
           -38.82723173028793,
           -38.86367643049142,
           -38.900121130694906,
           -38.9365658308984,
           -38.97301053110189,
           -39.00945523130538,
           -39.04589993150887,
           -39.08234463171236,
           -39.11878933191585,
           -39.15523403211934,
           -39.191678732322835,
           -39.228123432526324,
           -39.26456813272981,
           -39.3010128329333,
           -39.3374575331368,
           -39.37390223334029,
           -39.41034693354378,
           -39.44679163374727,
           -39.483236333950764,
           -39.519681034154246,
           -39.55612573435774,
           -39.59257043456123,
           -39.62901513476472,
           -39.66545983496822,
           -39.70190453517171,
           -39.738349235375196,
           -39.774793935578685,
           -39.811238635782175,
           -39.847683335985664,
           -39.88412803618915,
           -39.92057273639265,
           -39.95701743659614,
           -39.993462136799636,
           -40.029906837003125,
           -40.066351537206614,
           -40.102796237410104,
           -40.1392409376136,
           -40.17568563781709,
           -40.212130338020586,
           -40.248575038224075,
           -40.28501973842756,
           -40.321464438631054,
           -40.35790913883454,
           -40.39435383903803,
           -40.43079853924152,
           -40.46724323944502,
           -40.50368793964851,
           -40.540132639852,
           -40.576577340055486,
           -40.61302204025898,
           -40.64946674046247,
           -40.68591144066596,
           -40.72235614086945,
           -40.75880084107295,
           -40.79524554127644,
           -40.831690241479926,
           -40.868134941683415,
           -40.90457964188691,
           -40.9410243420904,
           -40.97746904229388,
           -41.01391374249738,
           -41.05035844270087,
           -41.08680314290436,
           -41.123247843107855,
           -41.159692543311344,
           -41.196137243514826,
           -41.23258194371832,
           -41.26902664392181,
           -41.30547134412531,
           -41.3419160443288,
           -41.37836074453229,
           -41.414805444735784,
           -41.451250144939266,
           -41.487694845142755,
           -41.49626030230687,
           -41.49088613795132,
           -41.485511973595756,
           -41.48013780924019,
           -41.47476364488463,
           -41.46938948052907,
           -41.4640153161735,
           -41.458641151817936,
           -41.45326698746238,
           -41.44789282310682,
           -41.442518658751254,
           -41.442131381766686,
           -41.44373884222061,
           -41.44534630267453,
           -41.44695376312845,
           -41.448561223582374,
           -41.45016868403629,
           -41.45177614449021,
           -41.453383604944136,
           -41.45499106539806,
           -41.45659852585199,
           -41.458205986305906,
           -41.459813446759824,
           -41.46142090721374,
           -41.463028367667675,
           -41.464635828121594,
           -41.46624328857551,
           -41.46785074902944,
           -41.469458209483356,
           -41.471065669937275,
           -41.4726731303912,
           -41.47428059084512,
           -41.475888051299044,
           -41.47749551175296,
           -41.47910297220689,
           -41.48071043266081,
           -41.48231789311473,
           -41.48392535356865,
           -41.48553281402258,
           -41.487140274476495,
           -41.48874773493042,
           -41.49035519538434,
           -41.491962655838265,
           -41.49357011629218,
           -41.4951775767461,
           -41.49678503720003,
           -41.49839249765395,
           -41.49999995810787,
           -41.50160741856179,
           -41.503214879015715,
           -41.50482233946964,
           -41.50642979992356,
           -41.50803726037748,
           -41.5096447208314,
           -41.51125218128532,
           -41.51285964173924,
           -41.514467102193166,
           -41.51607456264709,
           -41.51768202310101,
           -41.519289483554935,
           -41.520896944008854,
           -41.52250440446278,
           -41.5241118649167,
           -41.525719325370616,
           -41.52732678582454,
           -41.52893424627847,
           -41.53054170673239,
           -41.532149167186304,
           -41.53375662764023,
           -41.535364088094155,
           -41.536971548548074,
           -41.53857900900199,
           -41.54018646945592,
           -41.541793929909836,
           -41.54340139036376,
           -41.54500885081768,
           -41.5466163112716,
           -41.54822377172553,
           -41.54983123217945,
           -41.55143869263337,
           -41.553046153087294,
           -41.55465361354121,
           -41.55626107399514,
           -41.461242283820745,
           -41.26959724301807,
           -41.07795220221541,
           -40.886307161412745,
           -40.694662120610055,
           -40.503017079807385,
           -40.311372039004716,
           -40.11972699820204,
           -39.92808195739936,
           -39.7364369165967,
           -39.54479187579402,
           -39.353146834991335,
           -39.16150179418867,
           -38.969856753386,
           -38.77821171258332,
           -38.58656667178066,
           -38.39492163097798,
           -38.2032765901753,
           -38.01163154937264,
           -37.81998650856997,
           -37.628341467767285,
           -37.4366964269646,
           -37.245051386161954,
           -37.053406345359264,
           -36.86176130455658,
           -36.67011626375392,
           -36.47847122295125,
           -36.286826182148566,
           -36.095181141345904,
           -35.903536100543235,
           -35.71189105974055,
           -35.52024601893787,
           -35.32860097813521,
           -35.13695593733253,
           -34.94531089652985,
           -34.749409583182825,
           -34.547011869526855,
           -34.34461415587087,
           -34.14221644221491,
           -33.93981872855895,
           -33.737421014902964,
           -33.535023301246994,
           -33.332625587591025,
           -33.13022787393504,
           -32.92783016027906,
           -32.72543244662312,
           -32.52303473296713,
           -32.32063701931115,
           -32.11823930565518,
           -31.915841591999218,
           -31.713443878343234,
           -31.511046164687265,
           -31.308648451031303,
           -31.10625073737532,
           -30.903853023719336,
           -30.701455310063384,
           -30.499057596407404,
           -30.296659882751413,
           -30.09426216909545,
           -29.89186445543949,
           -29.689466741783505,
           -29.48706902812754,
           -29.284671314471574,
           -29.08227360081559,
           -28.87987588715962,
           -28.67747817350366,
           -28.47508045984767,
           -28.27268274619169,
           -28.070285032535743,
           -27.867887318879756,
           -27.665489605223776,
           -27.463091891567807,
           -27.260694177911844,
           -27.05829646425586,
           -26.85589875059989,
           -26.65350103694393,
           -26.451103323287946,
           -26.248705609631976,
           -26.046307895976014,
           -25.84391018232003,
           -25.641512468664047,
           -25.439114755008077,
           -25.236717041352115,
           -25.083539390370614,
           -25.02880186473805,
           -24.97406433910548,
           -24.91932681347291,
           -24.864589287840342,
           -24.809851762207778,
           -24.75511423657521,
           -24.700376710942635,
           -24.645639185310074,
           -24.590901659677503,
           -24.53616413404493,
           -24.481426608412363,
           -24.426689082779795,
           -24.371951557147227,
           -24.31721403151466,
           -24.26247650588209,
           -24.207738980249523,
           -24.153001454616955,
           -24.09826392898439,
           -24.04352640335182,
           -23.988788877719244,
           -23.93405135208668,
           -23.879313826454112,
           -23.82457630082154,
           -23.76983877518898,
           -23.71510124955641,
           -23.660363723923837,
           -23.60562619829127,
           -23.550888672658704,
           -23.496151147026133,
           -23.441413621393565,
           -23.386676095760997,
           -23.331938570128433,
           -23.277201044495857,
           -23.22246351886329,
           -23.16772599323072,
           -23.112988467598157,
           -23.058250941965586,
           -23.00351341633302,
           -22.948775890700446,
           -22.894038365067882,
           -22.839300839435317,
           -22.784563313802746,
           -22.72982578817017,
           -22.675088262537606,
           -22.620350736905046,
           -22.56561321127247,
           -22.510875685639903,
           -22.456138160007335,
           -22.401400634374763,
           -22.346663108742195,
           -22.291925583109634,
           -22.23718805747706,
           -22.18245053184449,
           -22.126793875256876,
           -22.070908601174096,
           -22.015023327091317,
           -21.959138053008544,
           -21.903252778925772,
           -21.847367504842993,
           -21.791482230760217,
           -21.735596956677444,
           -21.679711682594665,
           -21.62382640851189,
           -21.567941134429116,
           -21.51205586034634,
           -21.45617058626356,
           -21.400285312180788,
           -21.34440003809801,
           -21.288514764015233,
           -21.232629489932457,
           -21.176744215849684,
           -21.120858941766905,
           -21.064973667684132,
           -21.009088393601356,
           -20.95320311951858,
           -20.8973178454358,
           -20.84143257135303,
           -20.785547297270256,
           -20.72966202318747,
           -20.673776749104697,
           -20.617891475021924,
           -20.562006200939145,
           -20.4848222489497,
           -20.301144907426874,
           -20.117467565904054,
           -19.93379022438123,
           -19.75011288285844,
           -19.566435541335615,
           -19.38275819981279,
           -19.19908085829,
           -19.015403516767172,
           -18.83172617524435,
           -18.64804883372156,
           -18.464371492198737,
           -18.28069415067591,
           -18.097016809153086,
           -17.913339467630298,
           -17.72966212610747,
           -17.545984784584647,
           -17.362307443061855,
           -17.17863010153903,
           -16.994952760016208,
           -16.811275418493416,
           -16.627598076970592,
           -16.44392073544777,
           -16.26024339392498,
           -16.076566052402153,
           -15.89288871087933,
           -15.709211369356506,
           -15.525534027833714,
           -15.34185668631089,
           -15.158179344788067,
           -14.974502003265275,
           -14.790824661742452,
           -14.607147320219628,
           -14.423469978696836,
           -14.249920680193467,
           -14.090550865182024,
           -13.931181050170583,
           -13.771811235159168,
           -13.612441420147727,
           -13.453071605136284,
           -13.29370179012487,
           -13.134331975113431,
           -12.974962160101988,
           -12.815592345090577,
           -12.656222530079132,
           -12.496852715067691,
           -12.337482900056278,
           -12.178113085044837,
           -12.018743270033394,
           -11.859373455021954,
           -11.721619814830238,
           -11.59107141917572,
           -11.460523023521201,
           -11.329974627866704,
           -11.199426232212186,
           -11.068877836557668,
           -10.938329440903173,
           -10.807781045248653,
           -10.677232649594135,
           -10.546684253939617,
           -10.416135858285124,
           -10.285587462630605,
           -10.155039066976085,
           -10.02449067132159,
           -9.893942275667072,
           -9.763393880012552,
           -9.632845484358057,
           -9.50229708870354,
           -9.371748693049021,
           -9.241200297394528,
           -9.110651901740006,
           -8.980103506085491,
           -8.84955511043097,
           -8.719006714776476,
           -8.58845831912196,
           -8.457909923467438,
           -8.327361527812943,
           -8.196813132158427,
           -8.066264736503907,
           -7.935716340849412,
           -7.805167945194896,
           -7.674619549540374,
           -7.544071153885858,
           -7.413522758231363
          ],
          [
           -34.83487263767347,
           -34.874016317338864,
           -34.91315999700426,
           -34.95230367666964,
           -34.99144735633504,
           -35.03059103600043,
           -35.06973471566582,
           -35.10887839533121,
           -35.148022074996604,
           -35.187165754662,
           -35.22630943432738,
           -35.26545311399278,
           -35.30459679365817,
           -35.34374047332356,
           -35.38288415298895,
           -35.422027832654344,
           -35.46117151231973,
           -35.50031519198512,
           -35.53945887165052,
           -35.57860255131591,
           -35.6177462309813,
           -35.65688991064669,
           -35.696033590312084,
           -35.73517726997747,
           -35.77432094964286,
           -35.81346462930826,
           -35.85260830897364,
           -35.89175198863904,
           -35.93089566830443,
           -35.97003934796982,
           -36.00918302763521,
           -36.0483267073006,
           -36.08747038696599,
           -36.12661406663139,
           -36.16575774629678,
           -36.20490142596217,
           -36.24404510562756,
           -36.28318878529295,
           -36.32233246495835,
           -36.36147614462374,
           -36.40061982428912,
           -36.43976350395452,
           -36.47890718361991,
           -36.518050863285296,
           -36.55719454295069,
           -36.59633822261608,
           -36.63548190228148,
           -36.67462558194686,
           -36.71376926161225,
           -36.75291294127765,
           -36.792056620943036,
           -36.83120030060843,
           -36.87034398027382,
           -36.90948765993921,
           -36.9486313396046,
           -36.987775019269996,
           -37.02691869893539,
           -37.066062378600776,
           -37.10520605826617,
           -37.14434973793156,
           -37.18349341759695,
           -37.22263709726234,
           -37.261780776927736,
           -37.30092445659312,
           -37.340068136258516,
           -37.37921181592391,
           -37.418355495589296,
           -37.45749917525469,
           -37.49664285492008,
           -37.53578653458547,
           -37.57493021304242,
           -37.61237238166664,
           -37.64981455029087,
           -37.687256718915094,
           -37.72469888753931,
           -37.76214105616354,
           -37.79958322478776,
           -37.837025393411984,
           -37.87446756203621,
           -37.91190973066044,
           -37.94935189928466,
           -37.98679406790888,
           -38.024236236533106,
           -38.06167840515733,
           -38.097299915653025,
           -38.13255729452301,
           -38.16781467339299,
           -38.203072052262975,
           -38.23832943113296,
           -38.27358681000294,
           -38.30884418887293,
           -38.34410156774292,
           -38.379358946612896,
           -38.41461632548288,
           -38.44987370435287,
           -38.48513108322285,
           -38.52038846209283,
           -38.556437387675224,
           -38.59288208787871,
           -38.62932678808221,
           -38.6657714882857,
           -38.702216188489196,
           -38.738660888692685,
           -38.775105588896174,
           -38.81155028909967,
           -38.84799498930316,
           -38.88443968950665,
           -38.92088438971014,
           -38.95732908991363,
           -38.99377379011712,
           -39.03021849032061,
           -39.0666631905241,
           -39.10310789072759,
           -39.13955259093109,
           -39.17599729113458,
           -39.21244199133807,
           -39.24888669154156,
           -39.285331391745046,
           -39.321776091948536,
           -39.358220792152025,
           -39.39466549235552,
           -39.43111019255901,
           -39.4675548927625,
           -39.503999592966,
           -39.540444293169486,
           -39.576888993372975,
           -39.613333693576465,
           -39.649778393779954,
           -39.68622309398344,
           -39.72266779418693,
           -39.75911249439042,
           -39.795557194593925,
           -39.83200189479741,
           -39.868446595000904,
           -39.90489129520439,
           -39.94133599540788,
           -39.97778069561137,
           -40.01422539581486,
           -40.05067009601835,
           -40.08711479622185,
           -40.12355949642533,
           -40.160004196628826,
           -40.19644889683232,
           -40.232893597035805,
           -40.2693382972393,
           -40.30578299744279,
           -40.34222769764628,
           -40.378672397849776,
           -40.415117098053265,
           -40.45156179825676,
           -40.48800649846025,
           -40.52445119866374,
           -40.56089589886722,
           -40.59734059907072,
           -40.63378529927421,
           -40.6702299994777,
           -40.70667469968119,
           -40.74311939988468,
           -40.77956410008817,
           -40.81600880029166,
           -40.85245350049515,
           -40.88889820069865,
           -40.92534290090214,
           -40.96178760110563,
           -40.998232301309116,
           -41.034677001512605,
           -41.0711217017161,
           -41.09308641671636,
           -41.107811139114986,
           -41.12253586151362,
           -41.13726058391225,
           -41.15198530631088,
           -41.16671002870951,
           -41.18143475110814,
           -41.196159473506775,
           -41.210884195905415,
           -41.22560891830404,
           -41.24033364070267,
           -41.2550583631013,
           -41.26978308549994,
           -41.28450780789857,
           -41.299232530297196,
           -41.31395725269583,
           -41.32868197509446,
           -41.343406697493094,
           -41.35813141989173,
           -41.37285614229036,
           -41.387580864688985,
           -41.402305587087625,
           -41.41703030948626,
           -41.43175503188489,
           -41.4407081635851,
           -41.44231562403902,
           -41.443923084492944,
           -41.44553054494686,
           -41.44713800540078,
           -41.44874546585471,
           -41.450352926308625,
           -41.45196038676255,
           -41.453567847216476,
           -41.455175307670395,
           -41.45678276812431,
           -41.45839022857824,
           -41.459997689032164,
           -41.46160514948608,
           -41.46321260994,
           -41.46482007039393,
           -41.46642753084785,
           -41.468034991301764,
           -41.46964245175569,
           -41.47124991220961,
           -41.47285737266354,
           -41.47446483311745,
           -41.47607229357137,
           -41.4776797540253,
           -41.479287214479214,
           -41.48089467493314,
           -41.482502135387065,
           -41.484109595840984,
           -41.48571705629491,
           -41.48732451674883,
           -41.48893197720275,
           -41.49053943765668,
           -41.4921468981106,
           -41.493754358564516,
           -41.495361819018434,
           -41.49696927947236,
           -41.498576739926285,
           -41.500184200380204,
           -41.50179166083412,
           -41.503399121288055,
           -41.505006581741966,
           -41.50661404219589,
           -41.50822150264982,
           -41.50982896310373,
           -41.51143642355766,
           -41.51304388401158,
           -41.514651344465506,
           -41.51625880491942,
           -41.51786626537334,
           -41.519473725827275,
           -41.521081186281194,
           -41.522688646735105,
           -41.52429610718903,
           -41.525903567642956,
           -41.527511028096875,
           -41.52911848855081,
           -41.53072594900471,
           -41.532333409458644,
           -41.53394086991256,
           -41.43892207973818,
           -41.2472770389355,
           -41.05563199813283,
           -40.86398695733017,
           -40.67234191652748,
           -40.48069687572481,
           -40.28905183492215,
           -40.09740679411947,
           -39.90576175331678,
           -39.714116712514134,
           -39.52247167171145,
           -39.33082663090876,
           -39.1391815901061,
           -38.947536549303436,
           -38.755891508500746,
           -38.564246467698084,
           -38.372601426895415,
           -38.180956386092724,
           -37.98931134529006,
           -37.7976663044874,
           -37.60602126368472,
           -37.41437622288203,
           -37.22273118207938,
           -37.031086141276695,
           -36.83944110047401,
           -36.64779605967134,
           -36.45615101886868,
           -36.264505978066,
           -36.07286093726333,
           -35.88121589646066,
           -35.689570855657976,
           -35.49792581485529,
           -35.306280774052645,
           -35.11463573324996,
           -34.92299069244728,
           -34.73134565164461,
           -34.53970061084195,
           -34.34805557003926,
           -34.156410529236595,
           -33.964765488433926,
           -33.77312044763124,
           -33.581475406828574,
           -33.38983036602591,
           -33.19818532522323,
           -33.00654028442054,
           -32.8148952436179,
           -32.62325020281521,
           -32.431605162012524,
           -32.23996012120986,
           -32.04831508040719,
           -31.85667003960451,
           -31.665024998801844,
           -31.473379957999175,
           -31.28173491719649,
           -31.090089876393805,
           -30.898444835591157,
           -30.706799794788473,
           -30.51515475398579,
           -30.32350971318312,
           -30.13186467238046,
           -29.940219631577776,
           -29.74812654767741,
           -29.545728834021446,
           -29.343331120365463,
           -29.140933406709493,
           -28.93853569305353,
           -28.736137979397547,
           -28.53374026574156,
           -28.331342552085616,
           -28.128944838429632,
           -27.926547124773645,
           -27.724149411117683,
           -27.521751697461717,
           -27.319353983805733,
           -27.116956270149768,
           -26.9145585564938,
           -26.712160842837818,
           -26.50976312918185,
           -26.307365415525886,
           -26.104967701869903,
           -25.90256998821392,
           -25.700172274557954,
           -25.497774560901984,
           -25.344596909920483,
           -25.289859384287922,
           -25.235121858655354,
           -25.180384333022783,
           -25.125646807390215,
           -25.070909281757647,
           -25.016171756125075,
           -24.961434230492507,
           -24.906696704859947,
           -24.85195917922737,
           -24.7972216535948,
           -24.742484127962236,
           -24.687746602329668,
           -24.6330090766971,
           -24.57827155106453,
           -24.523534025431964,
           -24.468796499799392,
           -24.414058974166828,
           -24.35932144853426,
           -24.304583922901692,
           -24.249846397269117,
           -24.19510887163655,
           -24.14037134600398,
           -24.085633820371413,
           -24.03089629473885,
           -23.97615876910628,
           -23.92142124347371,
           -23.86668371784114,
           -23.811946192208573,
           -23.757208666576,
           -23.702471140943434,
           -23.64773361531087,
           -23.5929960896783,
           -23.538258564045726,
           -23.483521038413166,
           -23.428783512780594,
           -23.374045987148026,
           -23.319308461515458,
           -23.26457093588289,
           -23.20983341025032,
           -23.15509588461775,
           -23.100358358985186,
           -23.045620833352615,
           -22.990883307720043,
           -22.93614578208748,
           -22.88140825645491,
           -22.82667073082234,
           -22.771933205189775,
           -22.717195679557207,
           -22.662458153924636,
           -22.607720628292068,
           -22.552983102659503,
           -22.49824557702693,
           -22.44350805139436,
           -22.3887705257618,
           -22.334033000129228,
           -22.279295474496656,
           -22.22455794886409,
           -22.1702142177775,
           -22.11636272938605,
           -22.062511240994606,
           -22.00865975260316,
           -21.95480826421171,
           -21.900956775820266,
           -21.84710528742882,
           -21.79325379903737,
           -21.73940231064592,
           -21.68555082225448,
           -21.631699333863033,
           -21.577847845471585,
           -21.523996357080136,
           -21.470144868688696,
           -21.41629338029724,
           -21.362441891905803,
           -21.30859040351436,
           -21.254738915122903,
           -21.200887426731455,
           -21.147035938340014,
           -21.093184449948566,
           -21.03933296155712,
           -20.985481473165674,
           -20.93162998477423,
           -20.877778496382778,
           -20.801092058308438,
           -20.610230871819574,
           -20.41936968533071,
           -20.228508498841848,
           -20.037647312353023,
           -19.84678612586416,
           -19.655924939375296,
           -19.465063752886472,
           -19.292572504514347,
           -19.1332026895029,
           -18.973832874491492,
           -18.81446305948005,
           -18.655093244468606,
           -18.495723429457165,
           -18.33635361444575,
           -18.17698379943431,
           -18.017613984422866,
           -17.858244169411456,
           -17.698874354400015,
           -17.53950453938857,
           -17.380134724377157,
           -17.22076490936572,
           -17.061395094354275,
           -16.902025279342862,
           -16.742655464331417,
           -16.583285649319976,
           -16.423915834308534,
           -16.26454601929712,
           -16.105176204285684,
           -15.945806389274237,
           -15.786436574262826,
           -15.627066759251385,
           -15.46769694423994,
           -15.308327129228529,
           -15.148957314217089,
           -14.989587499205644,
           -14.830217684194203,
           -14.67084786918279,
           -14.511478054171349,
           -14.352108239159907,
           -14.192738424148493,
           -14.033368609137053,
           -13.873998794125612,
           -13.714628979114195,
           -13.555259164102756,
           -13.395889349091314,
           -13.2365195340799,
           -13.077149719068458,
           -12.917779904057017,
           -12.758410089045574,
           -12.59904027403416,
           -12.43967045902272,
           -12.280300644011279,
           -12.120930828999864,
           -11.961561013988423,
           -11.802191198976981,
           -11.642821383965568,
           -11.483451568954125,
           -11.324081753942684,
           -11.16471193893124,
           -11.00534212391983,
           -10.845972308908387,
           -10.686602493896945,
           -10.527232678885532,
           -10.36786286387409,
           -10.208493048862648,
           -10.049123233851235,
           -9.889753418839796,
           -9.73038360382835,
           -9.571013788816938,
           -9.411643973805496,
           -9.252274158794053,
           -9.092904343782614,
           -8.9335345287712,
           -8.774164713759758,
           -8.614794898748315,
           -8.46707798039407,
           -8.327684528574537,
           -8.188291076755004,
           -8.048897624935497,
           -7.909504173115964,
           -7.770110721296432,
           -7.630717269476899,
           -7.491323817657393
          ],
          [
           -34.461978107396185,
           -34.50112178706158,
           -34.54026546672697,
           -34.57940914639236,
           -34.61855282605775,
           -34.657696505723145,
           -34.69684018538853,
           -34.735983865053925,
           -34.77512754471932,
           -34.81427122438471,
           -34.8534149040501,
           -34.89255858371549,
           -34.931702263380885,
           -34.97084594304627,
           -35.009989622711664,
           -35.04913330237706,
           -35.088276982042444,
           -35.12742066170784,
           -35.16656434137323,
           -35.20570802103862,
           -35.24485170070401,
           -35.283995380369404,
           -35.32313906003479,
           -35.36228273970019,
           -35.40142641936557,
           -35.440570099030964,
           -35.479713778696365,
           -35.51885745836175,
           -35.558001138027144,
           -35.59714481769254,
           -35.636288497357924,
           -35.67543217702332,
           -35.714575856688704,
           -35.753719536354104,
           -35.79286321601949,
           -35.832006895684884,
           -35.87115057535028,
           -35.910294255015664,
           -35.94943793468106,
           -35.988581614346444,
           -36.02772529401184,
           -36.06686897367723,
           -36.10601265334262,
           -36.14515633300802,
           -36.184300012673404,
           -36.2234436923388,
           -36.26258737200419,
           -36.30173105166958,
           -36.340874731334964,
           -36.380018411000364,
           -36.41916209066575,
           -36.45830577033114,
           -36.49744944999654,
           -36.536593129661924,
           -36.57488605231754,
           -36.61232822094176,
           -36.64977038956599,
           -36.68721255819021,
           -36.724654726814435,
           -36.76209689543866,
           -36.799539064062884,
           -36.83698123268711,
           -36.87442340131133,
           -36.91186556993555,
           -36.94930773855978,
           -36.986749907184,
           -37.02419207580822,
           -37.06163424443245,
           -37.09907641305667,
           -37.136518581680896,
           -37.17396075030512,
           -37.21140291892934,
           -37.24884508755356,
           -37.28628725617779,
           -37.32372942480201,
           -37.361171593426235,
           -37.39861376205046,
           -37.436055930674684,
           -37.47349809929891,
           -37.51094026792314,
           -37.54838243654736,
           -37.58582460517158,
           -37.6232667737958,
           -37.66070894242003,
           -37.69633045291572,
           -37.7315878317857,
           -37.76684521065569,
           -37.80210258952567,
           -37.83735996839566,
           -37.87261734726564,
           -37.907874726135624,
           -37.9431321050056,
           -37.978389483875596,
           -38.013646862745574,
           -38.04890424161556,
           -38.084161620485546,
           -38.11941899935553,
           -38.15467637822552,
           -38.1899337570955,
           -38.22519113596548,
           -38.26044851483547,
           -38.295705893705446,
           -38.33096327257544,
           -38.366220651445424,
           -38.40147803031541,
           -38.43673540918539,
           -38.471992788055374,
           -38.50725016692536,
           -38.54250754579534,
           -38.57776492466533,
           -38.61302230353532,
           -38.648279682405295,
           -38.68353706127528,
           -38.71899232599502,
           -38.755437026198514,
           -38.791881726402,
           -38.82832642660549,
           -38.86477112680898,
           -38.90121582701247,
           -38.93766052721596,
           -38.97410522741945,
           -39.01054992762294,
           -39.046994627826436,
           -39.083439328029925,
           -39.119884028233415,
           -39.156328728436904,
           -39.1927734286404,
           -39.22921812884389,
           -39.26566282904738,
           -39.30210752925087,
           -39.33855222945436,
           -39.374996929657854,
           -39.41144162986134,
           -39.44788633006483,
           -39.48433103026833,
           -39.52077573047181,
           -39.55722043067531,
           -39.5936651308788,
           -39.63010983108229,
           -39.66655453128578,
           -39.70299923148927,
           -39.73944393169276,
           -39.77588863189625,
           -39.81233333209974,
           -39.84877803230323,
           -39.88522273250672,
           -39.921667432710215,
           -39.958112132913705,
           -39.9945568331172,
           -40.03100153332069,
           -40.06744623352418,
           -40.10389093372767,
           -40.14033563393116,
           -40.17678033413465,
           -40.213225034338144,
           -40.24966973454163,
           -40.286114434745116,
           -40.32255913494861,
           -40.3590038351521,
           -40.3954485353556,
           -40.43189323555909,
           -40.46833793576258,
           -40.504782635966066,
           -40.541227336169555,
           -40.577672036373045,
           -40.61411673657654,
           -40.65056143678003,
           -40.67252615178028,
           -40.687250874178915,
           -40.701975596577554,
           -40.71670031897618,
           -40.73142504137481,
           -40.746149763773445,
           -40.76087448617207,
           -40.77559920857071,
           -40.790323930969336,
           -40.80504865336797,
           -40.8197733757666,
           -40.83449809816524,
           -40.84922282056387,
           -40.86394754296251,
           -40.87867226536113,
           -40.893396987759765,
           -40.9081217101584,
           -40.92284643255702,
           -40.93757115495566,
           -40.95229587735429,
           -40.96702059975292,
           -40.98174532215155,
           -40.99647004455019,
           -41.01119476694882,
           -41.02591948934745,
           -41.040644211746084,
           -41.05536893414472,
           -41.07009365654335,
           -41.08481837894198,
           -41.099543101340615,
           -41.11426782373924,
           -41.12899254613787,
           -41.143717268536506,
           -41.15844199093513,
           -41.17316671333377,
           -41.187891435732396,
           -41.202616158131036,
           -41.21734088052966,
           -41.232065602928294,
           -41.24679032532693,
           -41.26151504772556,
           -41.27623977012419,
           -41.290964492522825,
           -41.30568921492146,
           -41.32041393732009,
           -41.335138659718716,
           -41.34986338211735,
           -41.36458810451598,
           -41.379312826914614,
           -41.394037549313246,
           -41.40876227171188,
           -41.42348699411051,
           -41.438211716509144,
           -41.45293643890777,
           -41.46661177312018,
           -41.468219233574104,
           -41.46982669402802,
           -41.47143415448195,
           -41.473041614935866,
           -41.47464907538979,
           -41.4762565358437,
           -41.477863996297636,
           -41.479471456751554,
           -41.48107891720548,
           -41.4826863776594,
           -41.48429383811332,
           -41.485901298567235,
           -41.48750875902117,
           -41.48911621947508,
           -41.490723679929005,
           -41.49233114038293,
           -41.49393860083685,
           -41.49554606129077,
           -41.49715352174469,
           -41.49876098219862,
           -41.50036844265254,
           -41.501975903106455,
           -41.50358336356038,
           -41.505190824014306,
           -41.506798284468225,
           -41.50840574492216,
           -41.51001320537607,
           -41.511620665829994,
           -41.41660187565561,
           -41.224956834852925,
           -41.03331179405026,
           -40.841666753247594,
           -40.65002171244491,
           -40.45837667164224,
           -40.26673163083957,
           -40.075086590036896,
           -39.883441549234206,
           -39.69179650843156,
           -39.500151467628875,
           -39.30850642682619,
           -39.11686138602352,
           -38.92521634522086,
           -38.73357130441818,
           -38.54192626361551,
           -38.35028122281284,
           -38.158636182010156,
           -37.966991141207494,
           -37.775346100404825,
           -37.58370105960214,
           -37.39205601879945,
           -37.20041097799681,
           -37.00876593719413,
           -36.817120896391444,
           -36.625475855588775,
           -36.433830814786106,
           -36.24218577398342,
           -36.05054073318075,
           -35.858895692378084,
           -35.6672506515754,
           -35.475605610772725,
           -35.28396056997007,
           -35.092315529167394,
           -34.9006704883647,
           -34.70902544756204,
           -34.51738040675937,
           -34.32573536595669,
           -34.13409032515402,
           -33.94244528435135,
           -33.75080024354867,
           -33.559155202746005,
           -33.367510161943336,
           -33.17586512114065,
           -32.98422008033798,
           -32.79257503953532,
           -32.60092999873264,
           -32.409284957929955,
           -32.217639917127286,
           -32.02599487632462,
           -31.834349835521934,
           -31.642704794719272,
           -31.451059753916603,
           -31.25941471311392,
           -31.067769672311236,
           -30.87612463150859,
           -30.684479590705905,
           -30.49283454990322,
           -30.301189509100553,
           -30.109544468297884,
           -29.9178994274952,
           -29.72625438669253,
           -29.53460934588987,
           -29.342964305087186,
           -29.151319264284517,
           -28.959674223481848,
           -28.768029182679168,
           -28.576384141876485,
           -28.384739101073837,
           -28.193094060271147,
           -28.00310252001899,
           -27.815123981550403,
           -27.62714544308181,
           -27.43916690461321,
           -27.251188366144618,
           -27.063209827676026,
           -26.87523128920742,
           -26.687252750738832,
           -26.499274212270244,
           -26.311295673801638,
           -26.123317135333025,
           -25.935338596864437,
           -25.74736005839585,
           -25.604576613009296,
           -25.552183353786834,
           -25.499790094564368,
           -25.447396835341895,
           -25.39500357611943,
           -25.34261031689696,
           -25.290217057674486,
           -25.23782379845202,
           -25.185430539229554,
           -25.13226339061577,
           -25.07841190222432,
           -25.024560413832877,
           -24.970708925441432,
           -24.91685743704998,
           -24.86300594865854,
           -24.809154460267095,
           -24.755302971875643,
           -24.7014514834842,
           -24.647599995092754,
           -24.593748506701306,
           -24.53989701830986,
           -24.486045529918407,
           -24.43219404152697,
           -24.378342553135518,
           -24.32449106474407,
           -24.27063957635263,
           -24.216788087961177,
           -24.162936599569733,
           -24.10908511117829,
           -24.055233622786837,
           -24.00138213439539,
           -23.947530646003948,
           -23.893679157612503,
           -23.83982766922105,
           -23.785976180829607,
           -23.73212469243816,
           -23.67827320404671,
           -23.624421715655266,
           -23.570570227263826,
           -23.516718738872374,
           -23.46286725048093,
           -23.409015762089485,
           -23.355164273698037,
           -23.301312785306585,
           -23.24746129691514,
           -23.193609808523696,
           -23.139758320132245,
           -23.0859068317408,
           -23.032055343349356,
           -22.978203854957908,
           -22.924352366566467,
           -22.870500878175022,
           -22.81664938978357,
           -22.76279790139212,
           -22.70894641300068,
           -22.65509492460923,
           -22.601243436217782,
           -22.547391947826338,
           -22.493540459434893,
           -22.439688971043445,
           -22.385837482652,
           -22.331985994260553,
           -22.278134505869104,
           -22.22428301747766,
           -22.170431529086216,
           -22.116580040694764,
           -22.062728552303312,
           -22.008877063911875,
           -21.955025575520423,
           -21.90117408712898,
           -21.847322598737534,
           -21.79347111034609,
           -21.73961962195464,
           -21.685768133563194,
           -21.63191664517175,
           -21.578065156780298,
           -21.52421366838885,
           -21.47036217999741,
           -21.416510691605957,
           -21.362659203214513,
           -21.308807714823068,
           -21.254956226431624,
           -21.201104738040172,
           -21.12441829996583,
           -20.933557113476965,
           -20.742695926988105,
           -20.551834740499245,
           -20.360973554010418,
           -20.170112367521554,
           -19.979251181032687,
           -19.788389994543863,
           -19.597528808055003,
           -19.40666762156614,
           -19.21580643507731,
           -19.024945248588452,
           -18.834084062099585,
           -18.643222875610725,
           -18.452361689121897,
           -18.261500502633034,
           -18.070639316144174,
           -17.879778129655346,
           -17.688916943166483,
           -17.49805575667762,
           -17.307194570188795,
           -17.11633338369993,
           -16.925472197211068,
           -16.734611010722244,
           -16.54374982423338,
           -16.35288863774452,
           -16.162027451255653,
           -15.971166264766826,
           -15.780305078277966,
           -15.605189542309958,
           -15.445819727298542,
           -15.286449912287102,
           -15.127080097275659,
           -14.967710282264246,
           -14.808340467252805,
           -14.648970652241362,
           -14.489600837229919,
           -14.33023102221851,
           -14.170861207207066,
           -14.011491392195625,
           -13.852121577184212,
           -13.692751762172769,
           -13.533381947161327,
           -13.374012132149915,
           -13.214642317138471,
           -13.05527250212703,
           -12.895902687115617,
           -12.736532872104176,
           -12.577163057092733,
           -12.41779324208129,
           -12.258423427069879,
           -12.099053612058436,
           -11.939683797046994,
           -11.780313982035581,
           -11.620944167024138,
           -11.47489194981421,
           -11.335498497994704,
           -11.196105046175173,
           -11.05671159435564,
           -10.917318142536107,
           -10.7779246907166,
           -10.63853123889707,
           -10.499137787077535,
           -10.359744335258029,
           -10.220350883438496,
           -10.080957431618964,
           -9.941563979799456,
           -9.802170527979925,
           -9.66277707616039,
           -9.523383624340886,
           -9.38399017252135,
           -9.244596720701818,
           -9.105203268882288,
           -8.96580981706278,
           -8.826416365243247,
           -8.687022913423716,
           -8.547629461604208,
           -8.408236009784675,
           -8.268842557965144,
           -8.129449106145636,
           -7.990055654326103,
           -7.850662202506571,
           -7.711268750687038,
           -7.571875298867532
          ],
          [
           -34.0890835771189,
           -34.1282272567843,
           -34.167370936449686,
           -34.20651461611508,
           -34.24565829578047,
           -34.28480197544586,
           -34.32394565511125,
           -34.363089334776646,
           -34.40223301444203,
           -34.44137669410743,
           -34.48052037377282,
           -34.519664053438206,
           -34.5588077331036,
           -34.59795141276899,
           -34.63709509243438,
           -34.67623877209978,
           -34.715382451765166,
           -34.75452613143056,
           -34.79366981109595,
           -34.83281349076134,
           -34.871957170426725,
           -34.911100850092126,
           -34.95024452975751,
           -34.9893882094229,
           -35.0285318890883,
           -35.067675568753685,
           -35.10681924841907,
           -35.14596292808447,
           -35.18510660774986,
           -35.22425028741526,
           -35.263393967080646,
           -35.30253764674603,
           -35.341681326411425,
           -35.38082500607682,
           -35.41996868574221,
           -35.4591123654076,
           -35.49825604507299,
           -35.537399722968445,
           -35.57484189159267,
           -35.61228406021689,
           -35.649726228841104,
           -35.68716839746534,
           -35.72461056608956,
           -35.762052734713784,
           -35.79949490333801,
           -35.83693707196223,
           -35.87437924058645,
           -35.91182140921068,
           -35.9492635778349,
           -35.98670574645912,
           -36.02414791508335,
           -36.06159008370757,
           -36.099032252331796,
           -36.13647442095602,
           -36.173916589580244,
           -36.21135875820447,
           -36.24880092682869,
           -36.28624309545292,
           -36.32368526407714,
           -36.36112743270136,
           -36.39856960132558,
           -36.43601176994981,
           -36.47345393857403,
           -36.51089610719825,
           -36.54833827582248,
           -36.585780444446705,
           -36.62322261307093,
           -36.660664781695154,
           -36.69810695031937,
           -36.735549118943595,
           -36.77299128756782,
           -36.810433456192044,
           -36.84787562481627,
           -36.88531779344049,
           -36.92275996206472,
           -36.96020213068894,
           -36.99764429931316,
           -37.03508646793739,
           -37.072528636561614,
           -37.10997080518584,
           -37.14741297381006,
           -37.18485514243429,
           -37.22229731105851,
           -37.259739479682736,
           -37.29536099017842,
           -37.33061836904841,
           -37.36587574791839,
           -37.40113312678837,
           -37.43639050565836,
           -37.47164788452834,
           -37.50690526339832,
           -37.54216264226831,
           -37.577420021138295,
           -37.61267740000828,
           -37.647934778878266,
           -37.683192157748245,
           -37.71844953661824,
           -37.753706915488216,
           -37.7889642943582,
           -37.82422167322819,
           -37.85947905209817,
           -37.89473643096816,
           -37.92999380983814,
           -37.96525118870812,
           -38.00050856757811,
           -38.03576594644809,
           -38.07102332531808,
           -38.106280704188066,
           -38.14153808305805,
           -38.17679546192803,
           -38.212052840798016,
           -38.247310219667995,
           -38.28256759853798,
           -38.31782497740797,
           -38.35308235627795,
           -38.38833973514794,
           -38.42359711401792,
           -38.45885449288791,
           -38.49411187175789,
           -38.52936925062787,
           -38.564626629497866,
           -38.59988400836784,
           -38.63514138723782,
           -38.670398766107816,
           -38.705656144977794,
           -38.74091352384777,
           -38.776170902717766,
           -38.81142828158775,
           -38.84668566045773,
           -38.88194303932772,
           -38.9179919645183,
           -38.9544366647218,
           -38.990881364925286,
           -39.027326065128776,
           -39.063770765332265,
           -39.100215465535754,
           -39.13666016573925,
           -39.17310486594274,
           -39.20954956614623,
           -39.24599426634972,
           -39.282438966553215,
           -39.3188836667567,
           -39.35532836696019,
           -39.39177306716368,
           -39.42821776736717,
           -39.46466246757066,
           -39.50110716777416,
           -39.53755186797764,
           -39.57399656818114,
           -39.61044126838463,
           -39.64688596858812,
           -39.68333066879161,
           -39.7197753689951,
           -39.75622006919859,
           -39.79266476940209,
           -39.82910946960557,
           -39.865554169809066,
           -39.901998870012555,
           -39.938443570216045,
           -39.974888270419534,
           -40.01133297062303,
           -40.04777767082652,
           -40.08422237103001,
           -40.1206670712335,
           -40.15711177143699,
           -40.193556471640484,
           -40.230001171843966,
           -40.251965886844225,
           -40.26669060924286,
           -40.28141533164149,
           -40.29614005404012,
           -40.31086477643875,
           -40.32558949883739,
           -40.340314221236014,
           -40.35503894363465,
           -40.36976366603328,
           -40.38448838843192,
           -40.399213110830544,
           -40.41393783322918,
           -40.42866255562781,
           -40.44338727802644,
           -40.458112000425075,
           -40.47283672282371,
           -40.48756144522234,
           -40.502286167620966,
           -40.517010890019606,
           -40.53173561241823,
           -40.546460334816864,
           -40.561185057215496,
           -40.57590977961413,
           -40.59063450201276,
           -40.60535922441139,
           -40.62008394681002,
           -40.63480866920865,
           -40.64953339160729,
           -40.66425811400592,
           -40.67898283640455,
           -40.69370755880318,
           -40.708432281201816,
           -40.72315700360045,
           -40.737881725999074,
           -40.752606448397714,
           -40.76733117079634,
           -40.78205589319497,
           -40.796780615593605,
           -40.81150533799223,
           -40.82623006039087,
           -40.840954782789495,
           -40.855679505188135,
           -40.87040422758677,
           -40.88512894998539,
           -40.899853672384026,
           -40.91457839478265,
           -40.92930311718129,
           -40.94402783957992,
           -40.95875256197856,
           -40.97347728437719,
           -40.98820200677582,
           -41.002926729174455,
           -41.01765145157308,
           -41.03237617397171,
           -41.04710089637035,
           -41.06182561876898,
           -41.07655034116761,
           -41.09127506356624,
           -41.105999785964876,
           -41.1207245083635,
           -41.13544923076214,
           -41.15017395316077,
           -41.1648986755594,
           -41.17962339795803,
           -41.194348120356665,
           -41.209072842755305,
           -41.22379756515393,
           -41.23852228755256,
           -41.253247009951195,
           -41.26797173234983,
           -41.282696454748454,
           -41.297421177147086,
           -41.31214589954571,
           -41.32687062194436,
           -41.341595344342984,
           -41.35632006674162,
           -41.37104478914025,
           -41.38576951153888,
           -41.40049423393751,
           -41.41521895633614,
           -41.42994367873478,
           -41.448706382595404,
           -41.4699540143756,
           -41.391463622952784,
           -41.213235208326964,
           -41.03500679370116,
           -40.84817531033374,
           -40.660196771865124,
           -40.47221823339653,
           -40.28423969492795,
           -40.09626115645934,
           -39.90828261799073,
           -39.720304079522165,
           -39.53232554105355,
           -39.344347002584946,
           -39.156368464116355,
           -38.96838992564777,
           -38.780411387179164,
           -38.59243284871057,
           -38.40445431024199,
           -38.216475771773375,
           -38.02849723330478,
           -37.84051869483619,
           -37.65254015636759,
           -37.46456161789899,
           -37.27658307943041,
           -37.0886045409618,
           -36.90062600249319,
           -36.712647464024606,
           -36.52466892555602,
           -36.33669038708741,
           -36.14871184861882,
           -35.96073331015023,
           -35.772754771681626,
           -35.58477623321302,
           -35.39679769474444,
           -35.20881915627584,
           -35.02084061780723,
           -34.83286207933864,
           -34.644883540870055,
           -34.45690500240145,
           -34.26892646393286,
           -34.08094792546427,
           -33.89296938699567,
           -33.70499084852707,
           -33.51701231005848,
           -33.32903377158988,
           -33.141055233121264,
           -32.953076694652694,
           -32.76509815618409,
           -32.57711961771548,
           -32.38914107924689,
           -32.201162540778306,
           -32.0131840023097,
           -31.825205463841108,
           -31.63722692537252,
           -31.44924838690391,
           -31.261269848435305,
           -31.07329130996673,
           -30.885312771498125,
           -30.697334233029522,
           -30.50935569456093,
           -30.32137715609234,
           -30.133398617623733,
           -29.945420079155145,
           -29.75744154068655,
           -29.569463002217944,
           -29.38148446374936,
           -29.193505925280768,
           -29.00552738681216,
           -28.817548848343556,
           -28.629570309874985,
           -28.44159177140638,
           -28.253613232937766,
           -28.065634694469182,
           -27.87765615600059,
           -27.689677617531984,
           -27.501699079063393,
           -27.313720540594804,
           -27.125742002126195,
           -26.937763463657607,
           -26.749784925189015,
           -26.561806386720413,
           -26.373827848251803,
           -26.185849309783215,
           -25.997870771314624,
           -25.85508732592807,
           -25.80269406670561,
           -25.750300807483143,
           -25.697907548260673,
           -25.645514289038204,
           -25.593121029815734,
           -25.540727770593264,
           -25.488334511370795,
           -25.435941252148332,
           -25.38354799292586,
           -25.331154733703382,
           -25.27876147448092,
           -25.226368215258454,
           -25.17397495603598,
           -25.121581696813518,
           -25.06918843759105,
           -25.01679517836858,
           -24.96440191914611,
           -24.912008659923643,
           -24.85961540070117,
           -24.807222141478697,
           -24.75482888225623,
           -24.702435623033765,
           -24.650042363811295,
           -24.597649104588825,
           -24.545255845366363,
           -24.492862586143886,
           -24.440469326921416,
           -24.388076067698954,
           -24.33568280847648,
           -24.28328954925401,
           -24.23089629003155,
           -24.178503030809075,
           -24.126109771586602,
           -24.073716512364136,
           -24.021323253141674,
           -23.9689299939192,
           -23.916536734696734,
           -23.864143475474265,
           -23.81175021625179,
           -23.759356957029325,
           -23.70696369780686,
           -23.654570438584386,
           -23.602177179361917,
           -23.54978392013945,
           -23.497390660916984,
           -23.444997401694508,
           -23.392604142472045,
           -23.34021088324958,
           -23.287817624027106,
           -23.235424364804636,
           -23.18303110558217,
           -23.130637846359697,
           -23.078244587137227,
           -23.025851327914765,
           -22.973458068692295,
           -22.921064809469826,
           -22.868671550247356,
           -22.81627829102489,
           -22.763015212700832,
           -22.709163724309388,
           -22.65531223591794,
           -22.60146074752649,
           -22.54760925913505,
           -22.493757770743603,
           -22.439906282352155,
           -22.386054793960703,
           -22.332203305569262,
           -22.278351817177814,
           -22.224500328786366,
           -22.17064884039492,
           -22.116797352003474,
           -22.062945863612022,
           -22.00909437522058,
           -21.955242886829136,
           -21.90139139843769,
           -21.847539910046237,
           -21.7936884216548,
           -21.739836933263348,
           -21.685985444871896,
           -21.632133956480455,
           -21.57828246808901,
           -21.52443097969756,
           -21.447744541623216,
           -21.256883355134356,
           -21.066022168645492,
           -20.875160982156633,
           -20.684299795667805,
           -20.49343860917894,
           -20.302577422690078,
           -20.111716236201254,
           -19.920855049712394,
           -19.729993863223527,
           -19.5391326767347,
           -19.348271490245835,
           -19.157410303756976,
           -18.966549117268112,
           -18.775687930779288,
           -18.584826744290424,
           -18.393965557801565,
           -18.203104371312733,
           -18.012243184823873,
           -17.821381998335006,
           -17.630520811846182,
           -17.43965962535732,
           -17.24879843886846,
           -17.057937252379627,
           -16.889285487777794,
           -16.721599277893482,
           -16.553913068009173,
           -16.386226858124893,
           -16.21854064824058,
           -16.050854438356268,
           -15.883168228471991,
           -15.715482018587679,
           -15.547795808703366,
           -15.380109598819088,
           -15.212423388934777,
           -15.044737179050465,
           -14.877050969166154,
           -14.709364759281875,
           -14.541678549397563,
           -14.373992339513253,
           -14.206306129628972,
           -14.038619919744662,
           -13.87093370986035,
           -13.70324749997607,
           -13.535561290091758,
           -13.36787508020745,
           -13.200188870323167,
           -13.032502660438858,
           -12.864816450554546,
           -12.697130240670235,
           -12.529444030785955,
           -12.361757820901644,
           -12.194071611017332,
           -12.026385401133053,
           -11.858699191248741,
           -11.69101298136443,
           -11.52332677148015,
           -11.355640561595841,
           -11.18795435171153,
           -11.020268141827218,
           -10.858476171926737,
           -10.719082720107206,
           -10.579689268287673,
           -10.440295816468169,
           -10.300902364648634,
           -10.1615089128291,
           -10.022115461009593,
           -9.882722009190061,
           -9.743328557370528,
           -9.603935105551022,
           -9.46454165373149,
           -9.325148201911958,
           -9.185754750092425,
           -9.046361298272917,
           -8.906967846453384,
           -8.767574394633852,
           -8.628180942814346,
           -8.488787490994813,
           -8.34939403917528,
           -8.210000587355774,
           -8.07060713553624,
           -7.931213683716708,
           -7.7918202318971765,
           -7.652426780077668
          ],
          [
           -33.71618904684163,
           -33.75533272650702,
           -33.79447640617241,
           -33.8336200858378,
           -33.872763765503194,
           -33.91190744516858,
           -33.951051124833974,
           -33.99019480449937,
           -34.029338484164754,
           -34.068482163830154,
           -34.10762584349554,
           -34.14676952316093,
           -34.18591320282632,
           -34.225056882491714,
           -34.26420056215711,
           -34.3033442418225,
           -34.34248792148789,
           -34.38163160115328,
           -34.420775280818674,
           -34.45991896048407,
           -34.499062640149454,
           -34.537355562243576,
           -34.57479773086779,
           -34.61223989949202,
           -34.64968206811624,
           -34.68712423674046,
           -34.72456640536468,
           -34.76200857398891,
           -34.79945074261313,
           -34.836892911237356,
           -34.87433507986158,
           -34.911777248485805,
           -34.94921941711003,
           -34.986661585734254,
           -35.02410375435848,
           -35.0615459229827,
           -35.09898809160693,
           -35.13643026023115,
           -35.173872428855375,
           -35.2113145974796,
           -35.24875676610382,
           -35.28619893472805,
           -35.323641103352266,
           -35.36108327197649,
           -35.398525440600714,
           -35.43596760922493,
           -35.47340977784916,
           -35.51085194647339,
           -35.548294115097605,
           -35.58573628372183,
           -35.62317845234605,
           -35.66062062097028,
           -35.6980627895945,
           -35.735504958218726,
           -35.77294712684295,
           -35.810389295467175,
           -35.8478314640914,
           -35.885273632715624,
           -35.92271580133984,
           -35.960157969964065,
           -35.9976001385883,
           -36.035042307212514,
           -36.07248447583674,
           -36.10992664446096,
           -36.14736881308519,
           -36.184810981709404,
           -36.22225315033363,
           -36.25969531895786,
           -36.297137487582084,
           -36.3345796562063,
           -36.372021824830526,
           -36.40946399345475,
           -36.446906162078974,
           -36.4843483307032,
           -36.52179049932742,
           -36.55923266795165,
           -36.596674836575865,
           -36.63411700520009,
           -36.67155917382432,
           -36.709001342448545,
           -36.74644351107277,
           -36.783885679696986,
           -36.82132784832121,
           -36.858770016945435,
           -36.89439152744112,
           -36.92964890631111,
           -36.964906285181094,
           -37.00016366405108,
           -37.03542104292106,
           -37.070678421791044,
           -37.10593580066103,
           -37.141193179531015,
           -37.176450558401,
           -37.21170793727099,
           -37.24696531614097,
           -37.28222269501095,
           -37.317480073880944,
           -37.35273745275092,
           -37.387994831620915,
           -37.423252210490894,
           -37.45850958936087,
           -37.49376696823086,
           -37.529024347100844,
           -37.56428172597083,
           -37.599539104840815,
           -37.6347964837108,
           -37.67005386258079,
           -37.705311241450765,
           -37.74056862032075,
           -37.77582599919073,
           -37.81108337806072,
           -37.8463407569307,
           -37.88159813580069,
           -37.91685551467067,
           -37.95211289354066,
           -37.987370272410644,
           -38.02262765128063,
           -38.05788503015061,
           -38.093142409020594,
           -38.12839978789057,
           -38.163657166760565,
           -38.19891454563055,
           -38.23417192450053,
           -38.269429303370515,
           -38.3046866822405,
           -38.33994406111049,
           -38.37520143998047,
           -38.41045881885045,
           -38.44571619772044,
           -38.48097357659043,
           -38.51623095546041,
           -38.551488334330394,
           -38.58674571320037,
           -38.62200309207036,
           -38.657260470940344,
           -38.69251784981032,
           -38.727775228680315,
           -38.7630326075503,
           -38.79828998642028,
           -38.833547365290265,
           -38.86880474416025,
           -38.90406212303023,
           -38.93931950190022,
           -38.97457688077021,
           -39.009834259640186,
           -39.04509163851017,
           -39.080546902838094,
           -39.11699160304159,
           -39.15343630324507,
           -39.18988100344857,
           -39.22632570365206,
           -39.26277040385555,
           -39.299215104059044,
           -39.335659804262534,
           -39.37210450446602,
           -39.40854920466951,
           -39.444993904873,
           -39.48143860507649,
           -39.51788330527999,
           -39.55432800548348,
           -39.590772705686966,
           -39.62721740589046,
           -39.66366210609395,
           -39.70010680629744,
           -39.73655150650093,
           -39.77299620670442,
           -39.80944090690791,
           -39.83140562190816,
           -39.8461303443068,
           -39.860855066705426,
           -39.875579789104066,
           -39.89030451150269,
           -39.905029233901324,
           -39.91975395629996,
           -39.93447867869859,
           -39.94920340109722,
           -39.963928123495855,
           -39.97865284589449,
           -39.99337756829312,
           -40.008102290691745,
           -40.02282701309038,
           -40.03755173548901,
           -40.05227645788764,
           -40.067001180286276,
           -40.08172590268491,
           -40.09645062508354,
           -40.111175347482174,
           -40.1259000698808,
           -40.14062479227944,
           -40.15534951467807,
           -40.170074237076705,
           -40.18479895947533,
           -40.199523681873956,
           -40.214248404272595,
           -40.22897312667123,
           -40.24369784906986,
           -40.25842257146849,
           -40.27314729386712,
           -40.28787201626576,
           -40.30259673866439,
           -40.31732146106302,
           -40.33204618346164,
           -40.34677090586028,
           -40.361495628258915,
           -40.37622035065755,
           -40.39094507305617,
           -40.40566979545481,
           -40.42039451785344,
           -40.43511924025208,
           -40.44984396265071,
           -40.464568685049336,
           -40.47929340744797,
           -40.498987968977765,
           -40.52023560075796,
           -40.54148323253816,
           -40.562730864318354,
           -40.58397849609855,
           -40.605226127878744,
           -40.62647375965894,
           -40.64772139143914,
           -40.66896902321933,
           -40.69021665499953,
           -40.71146428677973,
           -40.732711918559914,
           -40.75395955034012,
           -40.77520718212032,
           -40.79645481390052,
           -40.81770244568071,
           -40.83895007746089,
           -40.8601977092411,
           -40.88144534102129,
           -40.90269297280149,
           -40.92394060458169,
           -40.945188236361886,
           -40.96643586814208,
           -40.98768349992228,
           -41.00893113170247,
           -41.03017876348267,
           -41.051426395262865,
           -41.07267402704306,
           -41.09392165882325,
           -41.11516929060345,
           -41.136416922383646,
           -41.15766455416384,
           -41.178912185944036,
           -41.20015981772423,
           -41.221407449504426,
           -41.242655081284624,
           -41.26390271306482,
           -41.285150344845015,
           -41.206659953422204,
           -41.02843153879638,
           -40.85020312417058,
           -40.67197470954477,
           -40.49374629491895,
           -40.31551788029315,
           -40.137289465667344,
           -39.95906105104153,
           -39.78083263641571,
           -39.60260422178992,
           -39.4243758071641,
           -39.246147392538276,
           -39.06791897791247,
           -38.88969056328667,
           -38.71146214866085,
           -38.53323373403504,
           -38.355005319409244,
           -38.176776904783424,
           -37.99854849015762,
           -37.82032007553181,
           -37.642091660906,
           -37.46386324628017,
           -37.28563483165439,
           -37.10740641702857,
           -36.92917800240274,
           -36.75094958777694,
           -36.57272117315114,
           -36.39449275852532,
           -36.21626434389951,
           -36.03803592927371,
           -35.85980751464789,
           -35.68157910002207,
           -35.50335068539628,
           -35.325122270770464,
           -35.146893856144644,
           -34.96866544151883,
           -34.79043702689303,
           -34.61220861226722,
           -34.433980197641404,
           -34.255751783015604,
           -34.077523368389784,
           -33.89929495376398,
           -33.72106653913818,
           -33.54283812451235,
           -33.36460970988654,
           -33.18638129526075,
           -33.008152880634924,
           -32.82763033063426,
           -32.63965179216567,
           -32.45167325369708,
           -32.263694715228475,
           -32.07571617675988,
           -31.88773763829129,
           -31.69975909982269,
           -31.51178056135408,
           -31.323802022885506,
           -31.1358234844169,
           -30.947844945948297,
           -30.759866407479706,
           -30.571887869011114,
           -30.38390933054251,
           -30.19593079207392,
           -30.007952253605332,
           -29.819973715136726,
           -29.631995176668134,
           -29.444016638199543,
           -29.256038099730937,
           -29.068059561262327,
           -28.880081022793757,
           -28.69210248432515,
           -28.50412394585654,
           -28.316145407387957,
           -28.128166868919365,
           -27.94018833045076,
           -27.752209791982168,
           -27.564231253513576,
           -27.376252715044973,
           -27.188274176576382,
           -27.000295638107794,
           -26.812317099639188,
           -26.624338561170582,
           -26.43636002270199,
           -26.2483814842334,
           -26.10559803884685,
           -26.053204779624384,
           -26.000811520401918,
           -25.948418261179448,
           -25.89602500195698,
           -25.84363174273451,
           -25.791238483512043,
           -25.738845224289573,
           -25.686451965067107,
           -25.634058705844637,
           -25.58166544662216,
           -25.529272187399695,
           -25.47687892817723,
           -25.424485668954755,
           -25.37209240973229,
           -25.31969915050982,
           -25.26730589128735,
           -25.214912632064888,
           -25.162519372842418,
           -25.11012611361995,
           -25.057732854397475,
           -25.00533959517501,
           -24.95294633595254,
           -24.90055307673007,
           -24.8481598175076,
           -24.795766558285134,
           -24.74337329906266,
           -24.6909800398402,
           -24.63858678061773,
           -24.58619352139526,
           -24.533800262172786,
           -24.481407002950323,
           -24.429013743727854,
           -24.37662048450538,
           -24.324227225282915,
           -24.271833966060445,
           -24.219440706837975,
           -24.16704744761551,
           -24.11465418839304,
           -24.06226092917057,
           -24.0098676699481,
           -23.957474410725638,
           -23.90508115150316,
           -23.85268789228069,
           -23.800294633058225,
           -23.74790137383576,
           -23.69550811461329,
           -23.64311485539082,
           -23.59072159616835,
           -23.53832833694588,
           -23.48593507772341,
           -23.434123988668453,
           -23.38296354832761,
           -23.331803107986772,
           -23.280642667645942,
           -23.229482227305102,
           -23.178321786964258,
           -23.127161346623424,
           -23.076000906282587,
           -23.024840465941747,
           -22.97368002560091,
           -22.922519585260076,
           -22.87135914491924,
           -22.820198704578402,
           -22.769038264237565,
           -22.717877823896725,
           -22.666717383555884,
           -22.615556943215054,
           -22.564396502874214,
           -22.513236062533373,
           -22.462075622192536,
           -22.410915181851706,
           -22.359754741510862,
           -22.30859430117003,
           -22.257433860829188,
           -22.20627342048835,
           -22.155112980147514,
           -22.10395253980668,
           -22.05279209946584,
           -22.001631659125003,
           -21.950471218784163,
           -21.89931077844333,
           -21.848150338102485,
           -21.772558785834526,
           -21.574811673930917,
           -21.377064562027297,
           -21.179317450123687,
           -20.98157033822011,
           -20.783823226316496,
           -20.58607611441288,
           -20.3883290025093,
           -20.19058189060569,
           -19.992834778702075,
           -19.795087666798498,
           -19.59734055489488,
           -19.426566661373865,
           -19.258880451489553,
           -19.091194241605276,
           -18.923508031720964,
           -18.755821821836655,
           -18.58813561195237,
           -18.420449402068062,
           -18.25276319218375,
           -18.08507698229947,
           -17.91739077241516,
           -17.749704562530844,
           -17.582018352646568,
           -17.414332142762255,
           -17.246645932877946,
           -17.07895972299363,
           -16.911273513109354,
           -16.74358730322504,
           -16.575901093340732,
           -16.408214883456452,
           -16.24052867357214,
           -16.07284246368783,
           -15.90515625380355,
           -15.737470043919238,
           -15.56978383403493,
           -15.402097624150615,
           -15.234411414266336,
           -15.066725204382024,
           -14.899038994497715,
           -14.731352784613435,
           -14.563666574729123,
           -14.395980364844814,
           -14.228294154960533,
           -14.060607945076221,
           -13.892921735191912,
           -13.725235525307632,
           -13.557549315423321,
           -13.389863105539009,
           -13.222176895654698,
           -13.054490685770418,
           -12.886804475886105,
           -12.719118266001797,
           -12.551432056117516,
           -12.383745846233204,
           -12.216059636348895,
           -12.048373426464615,
           -11.880687216580302,
           -11.713001006695992,
           -11.545314796811681,
           -11.3776285869274,
           -11.20994237704309,
           -11.04225616715878,
           -10.874569957274499,
           -10.706883747390187,
           -10.539197537505878,
           -10.371511327621597,
           -10.203825117737287,
           -10.036138907852976,
           -9.868452697968696,
           -9.700766488084383,
           -9.533080278200073,
           -9.370519280068578,
           -9.221858958939029,
           -9.073198637809451,
           -8.924538316679874,
           -8.775877995550324,
           -8.627217674420748,
           -8.478557353291169,
           -8.329897032161622,
           -8.181236711032044,
           -8.032576389902466,
           -7.883916068772889,
           -7.73525574764334
          ],
          [
           -33.34329451656434,
           -33.38243819622973,
           -33.42158187589512,
           -33.46072555556051,
           -33.49986923289446,
           -33.537311401518686,
           -33.57475357014291,
           -33.61219573876714,
           -33.64963790739136,
           -33.68708007601558,
           -33.72452224463981,
           -33.76196441326403,
           -33.79940658188825,
           -33.83684875051248,
           -33.8742909191367,
           -33.91173308776092,
           -33.94917525638515,
           -33.98661742500937,
           -34.024059593633595,
           -34.06150176225782,
           -34.098943930882044,
           -34.13638609950627,
           -34.17382826813049,
           -34.21127043675472,
           -34.24871260537894,
           -34.28615477400316,
           -34.32359694262738,
           -34.36103911125161,
           -34.39848127987583,
           -34.435923448500056,
           -34.47336561712428,
           -34.5108077857485,
           -34.54824995437273,
           -34.58569212299695,
           -34.62313429162117,
           -34.660576460245395,
           -34.69801862886962,
           -34.73546079749384,
           -34.77290296611807,
           -34.81034513474229,
           -34.847787303366516,
           -34.88522947199074,
           -34.922671640614965,
           -34.96011380923919,
           -34.997555977863406,
           -35.03499814648763,
           -35.072440315111855,
           -35.10988248373608,
           -35.147324652360304,
           -35.18476682098453,
           -35.222208989608745,
           -35.25965115823298,
           -35.2970933268572,
           -35.33453549548142,
           -35.37197766410564,
           -35.40941983272987,
           -35.44686200135409,
           -35.484304169978316,
           -35.52174633860254,
           -35.559188507226764,
           -35.59663067585099,
           -35.63407284447521,
           -35.67151501309944,
           -35.708957181723655,
           -35.746399350347886,
           -35.7838415189721,
           -35.82128368759633,
           -35.85872585622055,
           -35.896168024844776,
           -35.933610193469,
           -35.971052362093225,
           -36.00849453071745,
           -36.04593669934167,
           -36.0833788679659,
           -36.12082103659012,
           -36.15826320521435,
           -36.19570537383857,
           -36.233147542462795,
           -36.27058971108702,
           -36.308031879711244,
           -36.34547404833547,
           -36.38291621695969,
           -36.4203583855839,
           -36.457800554208134,
           -36.49342206470383,
           -36.52867944357381,
           -36.56393682244379,
           -36.59919420131378,
           -36.63445158018376,
           -36.66970895905374,
           -36.70496633792373,
           -36.740223716793714,
           -36.7754810956637,
           -36.810738474533686,
           -36.845995853403664,
           -36.88125323227366,
           -36.916510611143636,
           -36.95176799001362,
           -36.98702536888361,
           -37.022282747753586,
           -37.05754012662358,
           -37.092797505493564,
           -37.12805488436355,
           -37.16331226323353,
           -37.198569642103514,
           -37.2338270209735,
           -37.26908439984348,
           -37.304341778713464,
           -37.33959915758345,
           -37.374856536453436,
           -37.41011391532342,
           -37.44537129419341,
           -37.48062867306339,
           -37.51588605193337,
           -37.55114343080336,
           -37.58640080967334,
           -37.62165818854332,
           -37.65691556741331,
           -37.69217294628329,
           -37.72743032515328,
           -37.762687704023264,
           -37.79794508289325,
           -37.833202461763236,
           -37.86845984063322,
           -37.90371721950321,
           -37.93897459837318,
           -37.97423197724317,
           -38.00948935611315,
           -38.044746734983136,
           -38.08000411385312,
           -38.11526149272311,
           -38.15051887159309,
           -38.18577625046308,
           -38.221033629333064,
           -38.25629100820304,
           -38.29154838707303,
           -38.326805765943014,
           -38.362063144813,
           -38.39732052368298,
           -38.432577902552964,
           -38.46783528142295,
           -38.503092660292936,
           -38.53835003916292,
           -38.57360741803291,
           -38.60886479690289,
           -38.64412217577287,
           -38.67937955464286,
           -38.71463693351284,
           -38.74989431238282,
           -38.785151691252814,
           -38.82040907012279,
           -38.85566644899278,
           -38.890923827862764,
           -38.92618120673274,
           -38.961438585602735,
           -38.99669596447272,
           -39.0319533433427,
           -39.067210722212685,
           -39.10246810108267,
           -39.13772547995265,
           -39.172982858822635,
           -39.20824023769263,
           -39.24349761656261,
           -39.27954654136138,
           -39.31599124156486,
           -39.352435941768356,
           -39.388880641971845,
           -39.410845356972104,
           -39.42557007937073,
           -39.440294801769355,
           -39.455019524167994,
           -39.46974424656663,
           -39.48446896896525,
           -39.499193691363885,
           -39.51391841376252,
           -39.52864313616115,
           -39.54926955536013,
           -39.57051718714032,
           -39.59176481892051,
           -39.61301245070071,
           -39.63426008248091,
           -39.655507714261105,
           -39.6767553460413,
           -39.698002977821496,
           -39.719250609601694,
           -39.740498241381886,
           -39.761745873162084,
           -39.782993504942276,
           -39.80424113672248,
           -39.825488768502666,
           -39.846736400282865,
           -39.86798403206306,
           -39.889231663843255,
           -39.91047929562346,
           -39.931726927403645,
           -39.95297455918384,
           -39.97422219096404,
           -39.995469822744234,
           -40.01671745452444,
           -40.037965086304624,
           -40.05921271808483,
           -40.08046034986502,
           -40.10170798164521,
           -40.12295561342542,
           -40.14420324520561,
           -40.16545087698581,
           -40.186698508766,
           -40.2079461405462,
           -40.2291937723264,
           -40.25044140410658,
           -40.27168903588679,
           -40.292936667666986,
           -40.31418429944718,
           -40.33543193122737,
           -40.356679563007575,
           -40.377927194787766,
           -40.399174826567965,
           -40.420422458348156,
           -40.44167009012835,
           -40.462917721908546,
           -40.484165353688745,
           -40.50541298546894,
           -40.52666061724914,
           -40.547908249029334,
           -40.56915588080953,
           -40.590403512589724,
           -40.61165114436992,
           -40.63289877615012,
           -40.65414640793031,
           -40.67539403971051,
           -40.6966416714907,
           -40.7178893032709,
           -40.7391369350511,
           -40.76038456683129,
           -40.78163219861149,
           -40.80287983039169,
           -40.82412746217187,
           -40.84537509395208,
           -40.86662272573227,
           -40.88787035751247,
           -40.90911798929267,
           -40.93036562107285,
           -40.95161325285305,
           -40.97286088463325,
           -40.99410851641345,
           -41.015356148193646,
           -41.03660377997384,
           -41.05785141175404,
           -41.07909904353423,
           -41.10034667531443,
           -41.021856283891616,
           -40.843627869265795,
           -40.665399454639996,
           -40.48717104001418,
           -40.30894262538837,
           -40.13071421076256,
           -39.952485796136756,
           -39.774257381510935,
           -39.596028966885115,
           -39.41780055225933,
           -39.239572137633516,
           -39.06134372300769,
           -38.88311530838188,
           -38.70488689375608,
           -38.52665847913026,
           -38.348430064504456,
           -38.170201649878656,
           -37.99197323525283,
           -37.81374482062703,
           -37.63551640600123,
           -37.4572879913754,
           -37.27905957674958,
           -37.1008311621238,
           -36.922602747497976,
           -36.744374332872155,
           -36.566145918246356,
           -36.38791750362054,
           -36.20968908899473,
           -36.03146067436893,
           -35.853232259743116,
           -35.6750038451173,
           -35.49677543049148,
           -35.31854701586569,
           -35.14031860123987,
           -34.96209018661405,
           -34.78386177198825,
           -34.60563335736244,
           -34.42740494273663,
           -34.24917652811082,
           -34.07094811348502,
           -33.892719698859196,
           -33.71449128423339,
           -33.53626286960759,
           -33.35803445498176,
           -33.17980604035594,
           -33.00157762573016,
           -32.82334921110434,
           -32.645120796478516,
           -32.46689238185271,
           -32.28866396722691,
           -32.11043555260109,
           -31.93220713797529,
           -31.753978723349483,
           -31.575750308723656,
           -31.397521894097842,
           -31.219293479472054,
           -31.041065064846237,
           -30.862836650220412,
           -30.68460823559461,
           -30.506379820968803,
           -30.32815140634299,
           -30.14992299171718,
           -29.971694577091377,
           -29.793466162465556,
           -29.615237747839753,
           -29.437009333213954,
           -29.25878091858813,
           -29.08055250396231,
           -28.902324089336517,
           -28.724095674710703,
           -28.545867260084883,
           -28.367638845459076,
           -28.18941043083327,
           -28.01118201620745,
           -27.83295360158165,
           -27.654725186955844,
           -27.477605688045447,
           -27.311574961879078,
           -27.145544235712716,
           -26.979513509546337,
           -26.813482783379953,
           -26.64745205721359,
           -26.48142133104723,
           -26.354249246000187,
           -26.30479444319179,
           -26.255339640383397,
           -26.205884837574995,
           -26.1564300347666,
           -26.106975231958206,
           -26.057520429149807,
           -26.008065626341406,
           -25.958610823533014,
           -25.909156020724613,
           -25.859701217916214,
           -25.80902811026367,
           -25.757867669922835,
           -25.706707229581994,
           -25.65554678924116,
           -25.604386348900324,
           -25.553225908559487,
           -25.502065468218646,
           -25.450905027877813,
           -25.399744587536972,
           -25.34858414719613,
           -25.297423706855295,
           -25.24626326651446,
           -25.195102826173617,
           -25.143942385832787,
           -25.09278194549195,
           -25.041621505151106,
           -24.990461064810273,
           -24.939300624469436,
           -24.888140184128595,
           -24.836979743787754,
           -24.78581930344693,
           -24.734658863106088,
           -24.683498422765247,
           -24.632337982424414,
           -24.581177542083577,
           -24.530017101742736,
           -24.478856661401895,
           -24.427696221061066,
           -24.37653578072022,
           -24.325375340379388,
           -24.274214900038555,
           -24.223054459697714,
           -24.17189401935687,
           -24.120733579016033,
           -24.0695731386752,
           -24.018412698334362,
           -23.967252257993522,
           -23.916091817652692,
           -23.864931377311848,
           -23.81377093697101,
           -23.76261049663018,
           -23.711450056289337,
           -23.6602896159485,
           -23.609129175607666,
           -23.557968735266826,
           -23.506808294925985,
           -23.45564785458515,
           -23.404487414244315,
           -23.353326973903474,
           -23.30216653356264,
           -23.251006093221804,
           -23.199845652880967,
           -23.14868521254013,
           -23.097524772199293,
           -23.046364331858456,
           -22.995203891517615,
           -22.944043451176782,
           -22.89288301083594,
           -22.8417225704951,
           -22.790562130154264,
           -22.73940168981343,
           -22.68824124947259,
           -22.637080809131753,
           -22.58592036879092,
           -22.53475992845008,
           -22.483599488109235,
           -22.43243904776841,
           -22.381278607427568,
           -22.330118167086727,
           -22.27895772674589,
           -22.227797286405057,
           -22.176636846064216,
           -22.101045293796254,
           -21.903298181892644,
           -21.705551069989028,
           -21.507803958085415,
           -21.310056846181833,
           -21.11230973427822,
           -20.914562622374607,
           -20.71681551047103,
           -20.519068398567416,
           -20.321321286663803,
           -20.123574174760225,
           -19.92582706285661,
           -19.728079950952996,
           -19.530332839049382,
           -19.332585727145805,
           -19.134838615242188,
           -18.937091503338575,
           -18.739344391434997,
           -18.541597279531384,
           -18.34385016762777,
           -18.146103055724193,
           -17.948355943820577,
           -17.750608831916963,
           -17.552861720013386,
           -17.355114608109773,
           -17.157367496206156,
           -16.959620384302543,
           -16.761873272398965,
           -16.56412616049535,
           -16.366379048591735,
           -16.168631936688158,
           -15.970884824784546,
           -15.773137712880931,
           -15.575390600977354,
           -15.402694231816877,
           -15.235008021932565,
           -15.067321812048256,
           -14.899635602163976,
           -14.731949392279663,
           -14.564263182395354,
           -14.396576972511074,
           -14.228890762626762,
           -14.061204552742451,
           -13.89351834285817,
           -13.72583213297386,
           -13.55814592308955,
           -13.390459713205269,
           -13.222773503320958,
           -13.05508729343665,
           -12.887401083552335,
           -12.726056842244285,
           -12.577396521114709,
           -12.428736199985131,
           -12.28007587885558,
           -12.131415557726005,
           -11.982755236596427,
           -11.834094915466876,
           -11.6854345943373,
           -11.536774273207724,
           -11.388113952078147,
           -11.239453630948596,
           -11.090793309819018,
           -10.942132988689442,
           -10.793472667559893,
           -10.644812346430314,
           -10.496152025300738,
           -10.347491704171187,
           -10.198831383041611,
           -10.050171061912033,
           -9.901510740782484,
           -9.752850419652907,
           -9.604190098523329,
           -9.455529777393753,
           -9.306869456264202,
           -9.158209135134626,
           -9.009548814005049,
           -8.860888492875498,
           -8.71222817174592,
           -8.563567850616344,
           -8.414907529486795,
           -8.266247208357216,
           -8.117586887227642,
           -7.968926566098062,
           -7.820266244968511
          ],
          [
           -32.96052787196429,
           -32.99612790108227,
           -33.03172793020025,
           -33.06732795931823,
           -33.10292798843621,
           -33.138528017554194,
           -33.174128046672166,
           -33.20972807579015,
           -33.24532810490813,
           -33.28092813402611,
           -33.31652816314409,
           -33.35212819226207,
           -33.38772822138005,
           -33.42424931841422,
           -33.461691487038436,
           -33.49913365566267,
           -33.53657582428689,
           -33.57401799291111,
           -33.611460161535334,
           -33.64890233015956,
           -33.68634449878378,
           -33.72378666740801,
           -33.76122883603223,
           -33.798671004656455,
           -33.83611317328068,
           -33.873555341904904,
           -33.91099751052913,
           -33.94843967915335,
           -33.98588184777758,
           -34.02332401640179,
           -34.060766185026026,
           -34.09820835365025,
           -34.13565052227446,
           -34.1730926908987,
           -34.21053485952291,
           -34.24797702814714,
           -34.285419196771365,
           -34.32286136539558,
           -34.36030353401981,
           -34.39774570264403,
           -34.435187871268255,
           -34.47263003989248,
           -34.5100722085167,
           -34.54751437714093,
           -34.58495654576515,
           -34.62239871438938,
           -34.6598408830136,
           -34.697283051637825,
           -34.73472522026205,
           -34.77216738888627,
           -34.8096095575105,
           -34.847051726134715,
           -34.88449389475895,
           -34.921936063383164,
           -34.95937823200738,
           -34.99682040063161,
           -35.03426256925584,
           -35.07170473788006,
           -35.10914690650428,
           -35.1465890751285,
           -35.18403124375273,
           -35.22147341237695,
           -35.258915581001176,
           -35.2963577496254,
           -35.333799918249625,
           -35.37124208687385,
           -35.40868425549807,
           -35.4461264241223,
           -35.48356859274652,
           -35.521010761370746,
           -35.558452929994964,
           -35.59589509861919,
           -35.63333726724341,
           -35.67077943586764,
           -35.70822160449187,
           -35.74566377311609,
           -35.78310594174031,
           -35.820548110364534,
           -35.85799027898876,
           -35.895432447612976,
           -35.93287461623721,
           -35.97031678486143,
           -36.007758953485656,
           -36.04520112210987,
           -36.08082263260557,
           -36.11608001147555,
           -36.15133739034554,
           -36.18659476921552,
           -36.2218521480855,
           -36.25710952695549,
           -36.29236690582547,
           -36.32762428469546,
           -36.36288166356544,
           -36.398139042435425,
           -36.4333964213054,
           -36.46865380017539,
           -36.503911179045375,
           -36.53916855791536,
           -36.574425936785346,
           -36.60968331565533,
           -36.64494069452532,
           -36.6801980733953,
           -36.71545545226529,
           -36.750712831135274,
           -36.78597021000525,
           -36.82122758887524,
           -36.85648496774522,
           -36.8917423466152,
           -36.92699972548519,
           -36.962257104355174,
           -36.99751448322516,
           -37.032771862095146,
           -37.068029240965124,
           -37.10328661983512,
           -37.1385439987051,
           -37.17380137757508,
           -37.20905875644507,
           -37.244316135315046,
           -37.27957351418504,
           -37.31483089305502,
           -37.350088271925,
           -37.38534565079499,
           -37.42060302966497,
           -37.45586040853496,
           -37.49111778740494,
           -37.526375166274924,
           -37.56163254514491,
           -37.59688992401489,
           -37.632147302884874,
           -37.66740468175486,
           -37.702662060624846,
           -37.73791943949483,
           -37.77317681836482,
           -37.8084341972348,
           -37.84369157610478,
           -37.87894895497477,
           -37.91420633384475,
           -37.94946371271474,
           -37.98472109158472,
           -38.01997847045471,
           -38.05523584932469,
           -38.090493228194674,
           -38.12575060706467,
           -38.161007985934646,
           -38.19626536480463,
           -38.23152274367462,
           -38.266780122544596,
           -38.30203750141458,
           -38.33729488028457,
           -38.37255225915455,
           -38.40780963802453,
           -38.44306701689452,
           -38.4783243957645,
           -38.51358177463448,
           -38.54860660062464,
           -38.5824686705638,
           -38.61633074050295,
           -38.650192810442114,
           -38.68405488038127,
           -38.71791695032043,
           -38.75177902025959,
           -38.785641090198745,
           -38.819503160137906,
           -38.85336523007706,
           -38.88722730001623,
           -38.92108936995538,
           -38.95495143989454,
           -38.98442823135223,
           -39.0117123835692,
           -39.03899653578616,
           -39.066280688003125,
           -39.09356484022008,
           -39.12084899243706,
           -39.14813314465402,
           -39.17541729687098,
           -39.202701449087954,
           -39.22998560130491,
           -39.257269753521875,
           -39.284553905738846,
           -39.3118380579558,
           -39.339122210172775,
           -39.36640636238974,
           -39.393690514606696,
           -39.42097466682366,
           -39.44825881904063,
           -39.47554297125759,
           -39.50282712347455,
           -39.53011127569152,
           -39.55739542790848,
           -39.58467958012545,
           -39.61196373234242,
           -39.63924788455938,
           -39.66653203677634,
           -39.6938161889933,
           -39.72110034121027,
           -39.74838449342724,
           -39.775668645644195,
           -39.80295279786117,
           -39.83023695007813,
           -39.85316141677404,
           -39.874409048554234,
           -39.89565668033443,
           -39.916904312114625,
           -39.93815194389482,
           -39.95939957567502,
           -39.98064720745522,
           -40.00189483923541,
           -40.0231424710156,
           -40.0443901027958,
           -40.065637734576,
           -40.0868853663562,
           -40.1081329981364,
           -40.12938062991658,
           -40.15062826169678,
           -40.17187589347698,
           -40.19312352525718,
           -40.21437115703738,
           -40.23561878881756,
           -40.25686642059776,
           -40.27811405237796,
           -40.29936168415816,
           -40.320609315938356,
           -40.34185694771855,
           -40.36310457949874,
           -40.38435221127894,
           -40.405599843059136,
           -40.426847474839334,
           -40.44809510661953,
           -40.46934273839972,
           -40.49059037017992,
           -40.511838001960115,
           -40.53308563374031,
           -40.55433326552051,
           -40.57558089730071,
           -40.596828529080895,
           -40.618076160861094,
           -40.63932379264129,
           -40.66057142442149,
           -40.68181905620169,
           -40.70306668798189,
           -40.72431431976207,
           -40.74556195154227,
           -40.76680958332247,
           -40.78805721510267,
           -40.80930484688286,
           -40.83055247866305,
           -40.85180011044325,
           -40.87304774222345,
           -40.89429537400365,
           -40.91554300578384,
           -40.83705261436103,
           -40.65882419973521,
           -40.4805957851094,
           -40.302367370483594,
           -40.124138955857774,
           -39.945910541231974,
           -39.767682126606175,
           -39.58945371198035,
           -39.41122529735453,
           -39.23299688272874,
           -39.05476846810292,
           -38.8765400534771,
           -38.698311638851294,
           -38.52008322422549,
           -38.341854809599674,
           -38.163626394973875,
           -37.98539798034807,
           -37.80716956572225,
           -37.62894115109644,
           -37.450712736470635,
           -37.27248432184482,
           -37.094255907218994,
           -36.91602749259321,
           -36.73779907796739,
           -36.559570663341574,
           -36.38134224871576,
           -36.20311383408996,
           -36.02488541946414,
           -35.846657004838335,
           -35.668428590212535,
           -35.49020017558671,
           -35.311971760960894,
           -35.13374334633511,
           -34.95551493170929,
           -34.77728651708346,
           -34.59905810245766,
           -34.420829687831855,
           -34.242601273206034,
           -34.064372858580235,
           -33.88614444395443,
           -33.7079160293286,
           -33.529687614702794,
           -33.35866696423034,
           -33.19263623806396,
           -33.02660551189758,
           -32.86057478573123,
           -32.694544059564855,
           -32.52851333339848,
           -32.36248260723211,
           -32.19645188106575,
           -32.030421154899365,
           -31.864390428733003,
           -31.69835970256664,
           -31.532328976400258,
           -31.366298250233882,
           -31.200267524067534,
           -31.03423679790115,
           -30.86820607173477,
           -30.70217534556841,
           -30.536144619402044,
           -30.37011389323567,
           -30.204083167069303,
           -30.038052440902938,
           -29.87202171473656,
           -29.705990988570196,
           -29.53996026240383,
           -29.373929536237455,
           -29.20789881007107,
           -29.041868083904724,
           -28.875837357738348,
           -28.709806631571965,
           -28.543775905405603,
           -28.377745179239238,
           -28.211714453072858,
           -28.045683726906493,
           -27.87965300074013,
           -27.71362227457375,
           -27.547591548407386,
           -27.381560822241024,
           -27.215530096074644,
           -27.04949936990826,
           -26.883468643741903,
           -26.717437917575538,
           -26.590265832528495,
           -26.540811029720103,
           -26.491356226911705,
           -26.441901424103307,
           -26.39244662129491,
           -26.342991818486517,
           -26.293537015678112,
           -26.244082212869714,
           -26.194627410061326,
           -26.145172607252924,
           -26.095717804444522,
           -26.046263001636127,
           -25.996808198827736,
           -25.94735339601933,
           -25.897898593210936,
           -25.84844379040254,
           -25.798988987594143,
           -25.749534184785748,
           -25.700079381977353,
           -25.650624579168948,
           -25.60116977636055,
           -25.55171497355215,
           -25.50226017074376,
           -25.452805367935362,
           -25.403350565126964,
           -25.353895762318565,
           -25.304440959510167,
           -25.254986156701772,
           -25.205531353893377,
           -25.15607655108498,
           -25.10662174827658,
           -25.057166945468186,
           -25.007712142659784,
           -24.958257339851386,
           -24.90880253704299,
           -24.859347734234596,
           -24.809892931426194,
           -24.7604381286178,
           -24.710983325809405,
           -24.661528523001003,
           -24.612073720192605,
           -24.56261891738421,
           -24.513164114575815,
           -24.463709311767413,
           -24.41425450895902,
           -24.364799706150624,
           -24.31534490334222,
           -24.265890100533824,
           -24.216435297725432,
           -24.16698049491703,
           -24.117525692108636,
           -24.06807088930024,
           -24.018616086491836,
           -23.96916128368344,
           -23.919706480875046,
           -23.87025167806665,
           -23.820796875258253,
           -23.771342072449855,
           -23.721887269641456,
           -23.672432466833058,
           -23.622977664024663,
           -23.57352286121627,
           -23.524068058407867,
           -23.474613255599472,
           -23.425158452791077,
           -23.374850839820184,
           -23.32369039947934,
           -23.27252995913851,
           -23.221369518797665,
           -23.17020907845683,
           -23.11904863811599,
           -23.067888197775158,
           -23.016727757434317,
           -22.96556731709348,
           -22.914406876752647,
           -22.863246436411806,
           -22.812085996070966,
           -22.760925555730132,
           -22.709765115389292,
           -22.65860467504845,
           -22.607444234707618,
           -22.55628379436678,
           -22.505123354025944,
           -22.429531801757985,
           -22.23178468985437,
           -22.034037577950752,
           -21.836290466047142,
           -21.638543354143565,
           -21.440796242239948,
           -21.24304913033633,
           -21.045302018432757,
           -20.84755490652914,
           -20.64980779462553,
           -20.452060682721953,
           -20.254313570818336,
           -20.056566458914723,
           -19.85881934701111,
           -19.661072235107532,
           -19.47599546499986,
           -19.299968838497303,
           -19.12394221199478,
           -18.94791558549223,
           -18.77188895898967,
           -18.595862332487147,
           -18.419835705984596,
           -18.243809079482038,
           -18.067782452979518,
           -17.891755826476963,
           -17.715729199974408,
           -17.539702573471853,
           -17.36367594696933,
           -17.18764932046678,
           -17.011622693964224,
           -16.8355960674617,
           -16.659569440959146,
           -16.48354281445659,
           -16.307516187954068,
           -16.131489561451513,
           -15.955462934948962,
           -15.779436308446403,
           -15.603409681943884,
           -15.427383055441329,
           -15.251356428938774,
           -15.07532980243625,
           -14.899303175933696,
           -14.72327654943114,
           -14.547249922928621,
           -14.371223296426066,
           -14.19519666992351,
           -14.019170043420987,
           -13.843143416918434,
           -13.667116790415879,
           -13.491090163913324,
           -13.315063537410804,
           -13.13903691090825,
           -12.963010284405694,
           -12.786983657903171,
           -12.610957031400616,
           -12.434930404898061,
           -12.258903778395538,
           -12.082877151892983,
           -11.906850525390432,
           -11.730823898887877,
           -11.554797272385354,
           -11.378770645882799,
           -11.202744019380244,
           -11.026717392877721,
           -10.850690766375168,
           -10.674664139872613,
           -10.498637513370092,
           -10.322610886867537,
           -10.146584260364982,
           -9.986521238107658,
           -9.83786091697808,
           -9.689200595848504,
           -9.540540274718925,
           -9.391879953589376,
           -9.243219632459798,
           -9.094559311330222,
           -8.945898990200671,
           -8.797238669071096,
           -8.648578347941518,
           -8.499918026811967,
           -8.35125770568239,
           -8.202597384552814,
           -8.053937063423234,
           -7.905276742293686
          ],
          [
           -32.57460215225112,
           -32.6102021813691,
           -32.645802210487076,
           -32.681402239605056,
           -32.717002268723036,
           -32.75260229784102,
           -32.788202326958995,
           -32.823802356076975,
           -32.859402385194954,
           -32.89500241431294,
           -32.930602443430914,
           -32.96620247254889,
           -33.00180250166687,
           -33.03740253078486,
           -33.07300255990283,
           -33.10860258902082,
           -33.14420261813879,
           -33.17980264725678,
           -33.21540267637475,
           -33.25100270549274,
           -33.28660273461071,
           -33.3222027637287,
           -33.35780279284667,
           -33.393402821964656,
           -33.42900285108263,
           -33.464602880200616,
           -33.500202909318595,
           -33.53580293843657,
           -33.571402967554555,
           -33.607002996672534,
           -33.64444516446419,
           -33.68188733308841,
           -33.71932950171263,
           -33.75677167033686,
           -33.794213838961085,
           -33.83165600758531,
           -33.86909817620953,
           -33.90654034483375,
           -33.94398251345798,
           -33.9814246820822,
           -34.018866850706424,
           -34.056309019330655,
           -34.09375118795487,
           -34.1311933565791,
           -34.16863552520332,
           -34.20607769382754,
           -34.24351986245177,
           -34.28096203107599,
           -34.31840419970021,
           -34.355846368324436,
           -34.39328853694866,
           -34.430730705572884,
           -34.46817287419711,
           -34.505615042821326,
           -34.54305721144556,
           -34.58049938006978,
           -34.617941548694006,
           -34.65538371731822,
           -34.69282588594245,
           -34.73026805456667,
           -34.76771022319089,
           -34.80515239181513,
           -34.842594560439345,
           -34.88003672906356,
           -34.91747889768779,
           -34.95492106631201,
           -34.992363234936235,
           -35.02980540356047,
           -35.067247572184684,
           -35.10468974080891,
           -35.14213190943313,
           -35.17957407805736,
           -35.21701624668158,
           -35.254458415305805,
           -35.29190058393003,
           -35.329342752554254,
           -35.36678492117847,
           -35.4042270898027,
           -35.44166925842693,
           -35.47911142705115,
           -35.51655359567537,
           -35.55399576429959,
           -35.59143793292382,
           -35.62888010154804,
           -35.66450161204373,
           -35.699758990913715,
           -35.7350163697837,
           -35.770273748653686,
           -35.805531127523665,
           -35.84078850639365,
           -35.876045885263636,
           -35.91130326413362,
           -35.94656064300361,
           -35.98181802187359,
           -36.01707540074358,
           -36.052332779613565,
           -36.08759015848355,
           -36.12284753735352,
           -36.15810491622352,
           -36.1933622950935,
           -36.22861967396348,
           -36.26387705283347,
           -36.29913443170345,
           -36.334391810573436,
           -36.36964918944342,
           -36.40490656831341,
           -36.440163947183386,
           -36.47542132605337,
           -36.51067870492336,
           -36.54593608379334,
           -36.58119346266333,
           -36.61645084153331,
           -36.65170822040329,
           -36.68696559927328,
           -36.722222978143265,
           -36.75748035701325,
           -36.79273773588323,
           -36.827995114753215,
           -36.86325249362321,
           -36.898509872493186,
           -36.93376725136317,
           -36.96902463023315,
           -37.004282009103136,
           -37.03953938797313,
           -37.07479676684311,
           -37.110054145713086,
           -37.14531152458308,
           -37.180568903453064,
           -37.21582628232304,
           -37.25108366119303,
           -37.286341040063014,
           -37.32159841893299,
           -37.356855797802986,
           -37.39211317667297,
           -37.42737055554295,
           -37.462627934412936,
           -37.49788531328292,
           -37.5331426921529,
           -37.56746986443839,
           -37.60133193437755,
           -37.6351940043167,
           -37.66905607425586,
           -37.702918144195024,
           -37.73678021413418,
           -37.77064228407334,
           -37.8045043540125,
           -37.838366423951655,
           -37.872228493890816,
           -37.90609056382997,
           -37.93995263376913,
           -37.97381470370829,
           -38.00767677364745,
           -38.04153884358661,
           -38.07540091352576,
           -38.10926298346492,
           -38.143125053404084,
           -38.17698712334324,
           -38.2108491932824,
           -38.24471126322156,
           -38.278573333160715,
           -38.31243540309987,
           -38.34629747303904,
           -38.38015954297819,
           -38.41402161291735,
           -38.447883682856514,
           -38.48174575279567,
           -38.51560782273482,
           -38.54508461419252,
           -38.57236876640948,
           -38.59965291862645,
           -38.62693707084341,
           -38.654221223060375,
           -38.68150537527735,
           -38.708789527494304,
           -38.73607367971127,
           -38.76335783192823,
           -38.790641984145196,
           -38.81792613636216,
           -38.84521028857913,
           -38.87249444079609,
           -38.89977859301306,
           -38.92706274523002,
           -38.95434689744698,
           -38.981631049663946,
           -39.00891520188092,
           -39.03619935409788,
           -39.06348350631484,
           -39.0907676585318,
           -39.11805181074877,
           -39.14533596296573,
           -39.1726201151827,
           -39.19990426739967,
           -39.227188419616624,
           -39.254472571833595,
           -39.28175672405055,
           -39.30904087626752,
           -39.33632502848448,
           -39.363609180701445,
           -39.39089333291841,
           -39.418177485135374,
           -39.44546163735234,
           -39.4727457895693,
           -39.500029941786266,
           -39.52731409400323,
           -39.554598246220195,
           -39.58188239843716,
           -39.60916655065412,
           -39.636450702871095,
           -39.66373485508806,
           -39.69101900730502,
           -39.71830315952199,
           -39.745587311738944,
           -39.772871463955916,
           -39.80015561617287,
           -39.82743976838984,
           -39.8547239206068,
           -39.882008072823766,
           -39.90929222504073,
           -39.9365763772577,
           -39.963860529474665,
           -39.99114468169162,
           -40.018428833908594,
           -40.04571298612555,
           -40.072997138342515,
           -40.10028129055948,
           -40.12756544277645,
           -40.154849594993415,
           -40.18213374721038,
           -40.20941789942734,
           -40.23670205164431,
           -40.263986203861265,
           -40.291270356078236,
           -40.3185545082952,
           -40.34583866051216,
           -40.37312281272912,
           -40.40040696494609,
           -40.42769111716306,
           -40.45497526938002,
           -40.482259421596986,
           -40.50954357381396,
           -40.536827726030914,
           -40.56075828201168,
           -40.58200591379188,
           -40.60325354557208,
           -40.62450117735228,
           -40.64574880913247,
           -40.66699644091266,
           -40.68824407269286,
           -40.70949170447306,
           -40.73073933625326,
           -40.65224894483044,
           -40.47402053020462,
           -40.29579211557882,
           -40.11756370095301,
           -39.93933528632719,
           -39.76110687170139,
           -39.58287845707558,
           -39.40575896658158,
           -39.239728240415204,
           -39.073697514248856,
           -38.90766678808247,
           -38.7416360619161,
           -38.575605335749735,
           -38.409574609583366,
           -38.24354388341699,
           -38.07751315725062,
           -37.91148243108426,
           -37.745451704917876,
           -37.579420978751514,
           -37.41339025258516,
           -37.24735952641878,
           -37.0813288002524,
           -36.91529807408605,
           -36.74926734791967,
           -36.583236621753294,
           -36.41720589558693,
           -36.25117516942056,
           -36.08514444325419,
           -35.91911371708781,
           -35.75308299092145,
           -35.58705226475507,
           -35.42102153858869,
           -35.25499081242234,
           -35.088960086255966,
           -34.92292936008958,
           -34.75689863392322,
           -34.59086790775686,
           -34.424837181590476,
           -34.25880645542411,
           -34.09277572925775,
           -33.92674500309137,
           -33.76071427692501,
           -33.594683550758646,
           -33.42865282459226,
           -33.26262209842589,
           -33.09659137225954,
           -32.930560646093156,
           -32.76452991992678,
           -32.59849919376042,
           -32.43246846759405,
           -32.26643774142767,
           -32.10040701526131,
           -31.934376289094946,
           -31.768345562928566,
           -31.602314836762183,
           -31.43628411059584,
           -31.27025338442946,
           -31.10422265826308,
           -30.938191932096714,
           -30.772161205930352,
           -30.60613047976397,
           -30.440099753597607,
           -30.274069027431246,
           -30.10803830126487,
           -29.9420075750985,
           -29.77597684893214,
           -29.609946122765763,
           -29.443915396599383,
           -29.277884670433032,
           -29.111853944266656,
           -28.945823218100276,
           -28.77979249193391,
           -28.613761765767546,
           -28.44773103960117,
           -28.281700313434804,
           -28.11566958726844,
           -27.94963886110206,
           -27.783608134935697,
           -27.61757740876933,
           -27.451546682602952,
           -27.285515956436573,
           -27.119485230270207,
           -26.953454504103842,
           -26.826282419056803,
           -26.776827616248404,
           -26.72737281344001,
           -26.677918010631608,
           -26.628463207823213,
           -26.579008405014818,
           -26.529553602206416,
           -26.480098799398018,
           -26.43064399658963,
           -26.381189193781232,
           -26.331734390972827,
           -26.28227958816443,
           -26.232824785356037,
           -26.183369982547635,
           -26.13391517973924,
           -26.084460376930846,
           -26.035005574122447,
           -25.98555077131405,
           -25.936095968505654,
           -25.886641165697256,
           -25.837186362888858,
           -25.78773156008046,
           -25.73827675727206,
           -25.688821954463666,
           -25.63936715165527,
           -25.589912348846873,
           -25.540457546038475,
           -25.491002743230077,
           -25.441547940421685,
           -25.39209313761328,
           -25.34263833480488,
           -25.29318353199649,
           -25.24372872918809,
           -25.194273926379694,
           -25.144819123571292,
           -25.095364320762897,
           -25.0459095179545,
           -24.996454715146108,
           -24.94699991233771,
           -24.897545109529307,
           -24.848090306720913,
           -24.79863550391252,
           -24.749180701104116,
           -24.699725898295718,
           -24.65027109548732,
           -24.601168927403755,
           -24.553300954852897,
           -24.505432982302043,
           -24.45756500975119,
           -24.409697037200335,
           -24.36182906464948,
           -24.31396109209863,
           -24.26609311954777,
           -24.21822514699691,
           -24.170357174446064,
           -24.12248920189521,
           -24.074621229344352,
           -24.026753256793494,
           -23.978885284242644,
           -23.93101731169179,
           -23.883149339140935,
           -23.835281366590085,
           -23.787413394039223,
           -23.739545421488373,
           -23.69167744893752,
           -23.64380947638666,
           -23.595941503835807,
           -23.548073531284956,
           -23.500205558734095,
           -23.45233758618324,
           -23.40446961363239,
           -23.356601641081536,
           -23.308733668530678,
           -23.260865695979824,
           -23.21299772342897,
           -23.165129750878116,
           -23.11726177832726,
           -23.06939380577641,
           -23.021525833225553,
           -22.973657860674695,
           -22.925789888123838,
           -22.87792191557299,
           -22.830053943022133,
           -22.756168280707335,
           -22.552194169572807,
           -22.34822005843828,
           -22.144245947303748,
           -21.940271836169256,
           -21.73629772503473,
           -21.5323236139002,
           -21.32834950276571,
           -21.12437539163118,
           -20.920401280496648,
           -20.71642716936216,
           -20.51245305822763,
           -20.308478947093104,
           -20.104504835958572,
           -19.90053072482408,
           -19.696556613689552,
           -19.516383282257404,
           -19.340356655754878,
           -19.164330029252326,
           -18.98830340274977,
           -18.81227677624725,
           -18.636250149744697,
           -18.460223523242142,
           -18.284196896739616,
           -18.10817027023706,
           -17.932143643734506,
           -17.756117017231954,
           -17.58009039072943,
           -17.404063764226876,
           -17.22803713772432,
           -17.052010511221802,
           -16.875983884719247,
           -16.699957258216692,
           -16.52393063171417,
           -16.347904005211614,
           -16.17187737870906,
           -15.995850752206504,
           -15.819824125703985,
           -15.643797499201428,
           -15.467770872698875,
           -15.291744246196352,
           -15.115717619693797,
           -14.939690993191242,
           -14.76366436668872,
           -14.587637740186166,
           -14.41161111368361,
           -14.23558448718109,
           -14.059557860678535,
           -13.88353123417598,
           -13.707504607673425,
           -13.531477981170902,
           -13.355451354668348,
           -13.179424728165795,
           -13.00339810166327,
           -12.827371475160716,
           -12.651344848658162,
           -12.47531822215564,
           -12.299291595653084,
           -12.123264969150531,
           -11.947238342647976,
           -11.771211716145453,
           -11.5951850896429,
           -11.419158463140345,
           -11.243131836637822,
           -11.067105210135267,
           -10.891078583632714,
           -10.715051957130191,
           -10.539025330627638,
           -10.368584022377503,
           -10.210286226095226,
           -10.05198842981292,
           -9.893690633530612,
           -9.735392837248309,
           -9.577095040966032,
           -9.418797244683725,
           -9.26049944840142,
           -9.102201652119142,
           -8.943903855836835,
           -8.78560605955453,
           -8.627308263272251,
           -8.469010466989946,
           -8.310712670707641,
           -8.152414874425334,
           -7.9941170781430575
          ],
          [
           -32.18867643253793,
           -32.22427646165591,
           -32.25987649077389,
           -32.29547651989187,
           -32.33107654900985,
           -32.36667657812783,
           -32.40227660724581,
           -32.43787663636378,
           -32.47347666548177,
           -32.50907669459975,
           -32.54467672371773,
           -32.58027675283571,
           -32.61587678195369,
           -32.65147681107167,
           -32.68707684018965,
           -32.72267686930763,
           -32.758276898425606,
           -32.793876927543586,
           -32.829476956661566,
           -32.865076985779545,
           -32.900677014897525,
           -32.936277044015505,
           -32.971877073133484,
           -33.00747710225147,
           -33.043077131369444,
           -33.07867716048742,
           -33.1142771896054,
           -33.14987721872338,
           -33.18547724784136,
           -33.22107727695934,
           -33.25667730607733,
           -33.29227733519531,
           -33.32787736431328,
           -33.36347739343127,
           -33.39907742254925,
           -33.43467745166723,
           -33.47027748078521,
           -33.505877509903186,
           -33.541477539021166,
           -33.577077568139146,
           -33.612677597257125,
           -33.648277626375105,
           -33.683877655493085,
           -33.719477684611064,
           -33.755077713729044,
           -33.79067774284702,
           -33.827198841889924,
           -33.86464101051415,
           -33.90208317913837,
           -33.9395253477626,
           -33.97696751638682,
           -34.014409685011046,
           -34.05185185363526,
           -34.089294022259494,
           -34.12673619088371,
           -34.16417835950794,
           -34.20162052813216,
           -34.239062696756385,
           -34.27650486538061,
           -34.313947034004826,
           -34.35138920262906,
           -34.388831371253275,
           -34.4262735398775,
           -34.463715708501724,
           -34.50115787712595,
           -34.53860004575018,
           -34.5760422143744,
           -34.61348438299862,
           -34.650926551622845,
           -34.68836872024707,
           -34.725810888871294,
           -34.76325305749552,
           -34.80069522611974,
           -34.83813739474396,
           -34.87557956336819,
           -34.91302173199241,
           -34.95046390061663,
           -34.98790606924086,
           -35.02534823786509,
           -35.062790406489306,
           -35.10023257511353,
           -35.137674743737755,
           -35.17511691236198,
           -35.212559080986196,
           -35.24818059148189,
           -35.283437970351876,
           -35.318695349221855,
           -35.35395272809184,
           -35.389210106961826,
           -35.42446748583181,
           -35.4597248647018,
           -35.49498224357178,
           -35.53023962244177,
           -35.56549700131175,
           -35.60075438018174,
           -35.63601175905171,
           -35.671269137921705,
           -35.70652651679168,
           -35.741783895661676,
           -35.77704127453166,
           -35.81229865340164,
           -35.847556032271626,
           -35.88281341114161,
           -35.9180707900116,
           -35.953328168881576,
           -35.98858554775156,
           -36.02384292662155,
           -36.05910030549153,
           -36.09435768436152,
           -36.1296150632315,
           -36.16487244210148,
           -36.20012982097147,
           -36.235387199841455,
           -36.27064457871144,
           -36.305901957581426,
           -36.34115933645141,
           -36.37641671532139,
           -36.411674094191376,
           -36.44693147306136,
           -36.48218885193134,
           -36.51744623080133,
           -36.552471058312975,
           -36.58633312825213,
           -36.62019519819128,
           -36.65405726813045,
           -36.687919338069605,
           -36.72178140800876,
           -36.75564347794792,
           -36.789505547887074,
           -36.823367617826236,
           -36.8572296877654,
           -36.89109175770456,
           -36.92495382764372,
           -36.958815897582866,
           -36.99267796752203,
           -37.02654003746119,
           -37.06040210740035,
           -37.094264177339504,
           -37.128126247278665,
           -37.161988317217826,
           -37.19585038715698,
           -37.22971245709614,
           -37.263574527035296,
           -37.29743659697446,
           -37.33129866691362,
           -37.36516073685277,
           -37.39902280679193,
           -37.432884876731094,
           -37.46674694667025,
           -37.50060901660941,
           -37.534471086548564,
           -37.568333156487725,
           -37.602195226426886,
           -37.63605729636603,
           -37.669919366305194,
           -37.703781436244356,
           -37.73764350618352,
           -37.77150557612268,
           -37.80536764606183,
           -37.839229716000986,
           -37.87309178594015,
           -37.90695385587931,
           -37.94081592581847,
           -37.974677995757624,
           -38.008540065696785,
           -38.04240213563594,
           -38.0762642055751,
           -38.105740997032804,
           -38.133025149249754,
           -38.160309301466725,
           -38.18759345368369,
           -38.214877605900654,
           -38.24216175811762,
           -38.26944591033458,
           -38.296730062551546,
           -38.32401421476851,
           -38.351298366985475,
           -38.37858251920244,
           -38.40586667141941,
           -38.43315082363637,
           -38.46043497585333,
           -38.487719128070296,
           -38.51500328028726,
           -38.54228743250423,
           -38.56957158472119,
           -38.59685573693815,
           -38.62413988915512,
           -38.65142404137208,
           -38.678708193589046,
           -38.70599234580601,
           -38.73327649802298,
           -38.76056065023994,
           -38.7878448024569,
           -38.815128954673874,
           -38.84241310689083,
           -38.869697259107795,
           -38.89698141132476,
           -38.924265563541724,
           -38.95154971575869,
           -38.97883386797565,
           -39.006118020192616,
           -39.03340217240958,
           -39.06068632462656,
           -39.087970476843516,
           -39.11525462906047,
           -39.14253878127744,
           -39.1698229334944,
           -39.197107085711366,
           -39.22439123792833,
           -39.251675390145294,
           -39.278959542362266,
           -39.30624369457922,
           -39.33352784679619,
           -39.36081199901316,
           -39.388096151230116,
           -39.41538030344708,
           -39.44266445566405,
           -39.46994860788101,
           -39.49723276009797,
           -39.524516912314944,
           -39.55180106453191,
           -39.57908521674887,
           -39.60636936896584,
           -39.6336535211828,
           -39.660937673399765,
           -39.68822182561672,
           -39.71550597783369,
           -39.74279013005065,
           -39.770074282267615,
           -39.80045600362063,
           -39.83168250873343,
           -39.86290901384624,
           -39.89413551895905,
           -39.92536202407186,
           -39.956588529184664,
           -39.98781503429748,
           -40.01904153941028,
           -40.050268044523094,
           -40.0814945496359,
           -40.112721054748704,
           -40.143947559861516,
           -40.17517406497432,
           -40.20640057008713,
           -40.237627075199946,
           -40.26885358031275,
           -40.300080085425556,
           -40.33130659053837,
           -40.36253309565117,
           -40.39375960076398,
           -40.42498610587679,
           -40.36937301229361,
           -40.226920320014436,
           -40.08446762773528,
           -39.942014935456115,
           -39.79956224317695,
           -39.657109550897786,
           -39.51465685861863,
           -39.37220416633946,
           -39.229751474060286,
           -39.08729878178114,
           -38.94484608950198,
           -38.80239339722281,
           -38.659940704943644,
           -38.51748801266449,
           -38.37503532038532,
           -38.23258262810616,
           -38.090129935827,
           -37.94767724354784,
           -37.80276419087187,
           -37.636865320542995,
           -37.47096645021411,
           -37.30506757988522,
           -37.13916870955636,
           -36.97326983922747,
           -36.80737096889858,
           -36.6414720985697,
           -36.475573228240826,
           -36.30967435791194,
           -36.14377548758306,
           -35.97787661725419,
           -35.8119777469253,
           -35.64607887659641,
           -35.48018000626755,
           -35.31428113593866,
           -35.14838226560977,
           -34.982483395280894,
           -34.81658452495202,
           -34.65068565462313,
           -34.48478678429426,
           -34.31888791396538,
           -34.152989043636495,
           -33.98709017330762,
           -33.82119130297875,
           -33.65529243264986,
           -33.48939356232097,
           -33.32349469199211,
           -33.15759582166322,
           -32.99169695133433,
           -32.82579808100546,
           -32.659899210676585,
           -32.4940003403477,
           -32.32810147001882,
           -32.16220259968995,
           -31.99630372936106,
           -31.830404859032164,
           -31.66450598870331,
           -31.49860711837442,
           -31.33270824804553,
           -31.166809377716653,
           -31.000910507387783,
           -30.835011637058894,
           -30.669112766730017,
           -30.503213896401142,
           -30.337315026072254,
           -30.171416155743383,
           -30.005517285414506,
           -29.839618415085617,
           -29.67371954475673,
           -29.507820674427865,
           -29.34192180409898,
           -29.176022933770092,
           -29.010124063441218,
           -28.844225193112347,
           -28.678326322783455,
           -28.512427452454578,
           -28.346528582125703,
           -28.18062971179682,
           -28.01473084146794,
           -27.848831971139067,
           -27.682933100810178,
           -27.517034230481286,
           -27.351135360152416,
           -27.18523648982354,
           -27.059302356333575,
           -27.013297696521423,
           -26.967293036709275,
           -26.92128837689712,
           -26.875283717084965,
           -26.829279057272817,
           -26.783274397460662,
           -26.737269737648507,
           -26.69126507783636,
           -26.6452604180242,
           -26.59925575821205,
           -26.553251098399898,
           -26.507246438587746,
           -26.46020337080597,
           -26.41233539825512,
           -26.364467425704266,
           -26.316599453153415,
           -26.268731480602558,
           -26.220863508051707,
           -26.172995535500846,
           -26.12512756294999,
           -26.07725959039914,
           -26.029391617848283,
           -25.981523645297425,
           -25.933655672746575,
           -25.88578770019572,
           -25.837919727644866,
           -25.790051755094012,
           -25.742183782543158,
           -25.6943158099923,
           -25.646447837441443,
           -25.598579864890596,
           -25.550711892339738,
           -25.50284391978888,
           -25.454975947238026,
           -25.407107974687175,
           -25.359240002136318,
           -25.311372029585467,
           -25.263504057034613,
           -25.215636084483755,
           -25.1677681119329,
           -25.11990013938205,
           -25.072032166831193,
           -25.024164194280335,
           -24.976296221729484,
           -24.92842824917863,
           -24.880560276627776,
           -24.83269230407692,
           -24.784824331526067,
           -24.736956358975213,
           -24.68908838642436,
           -24.641220413873505,
           -24.593352441322647,
           -24.54548446877179,
           -24.497616496220942,
           -24.44974852367008,
           -24.401880551119227,
           -24.354012578568373,
           -24.30614460601752,
           -24.258276633466664,
           -24.21040866091581,
           -24.16254068836496,
           -24.114672715814102,
           -24.066804743263248,
           -24.018936770712394,
           -23.97106879816154,
           -23.92320082561068,
           -23.87533285305983,
           -23.827464880508973,
           -23.779596907958116,
           -23.73172893540726,
           -23.68386096285641,
           -23.635992990305553,
           -23.5881250177547,
           -23.540257045203845,
           -23.49238907265299,
           -23.444521100102133,
           -23.396653127551286,
           -23.348785155000428,
           -23.300917182449567,
           -23.25304920989872,
           -23.205181237347865,
           -23.157313264797008,
           -23.08342760248221,
           -22.879453491347682,
           -22.675479380213154,
           -22.471505269078627,
           -22.267531157944134,
           -22.063557046809606,
           -21.85958293567508,
           -21.655608824540586,
           -21.451634713406055,
           -21.247660602271527,
           -21.043686491137038,
           -20.839712380002503,
           -20.635738268867975,
           -20.431764157733447,
           -20.227790046598955,
           -20.023815935464427,
           -19.8198418243299,
           -19.615867713195406,
           -19.41189360206088,
           -19.207919490926347,
           -19.00394537979186,
           -18.799971268657327,
           -18.5959971575228,
           -18.392023046388303,
           -18.18804893525378,
           -17.98407482411925,
           -17.78010071298472,
           -17.576126601850227,
           -17.3721524907157,
           -17.16817837958117,
           -16.96420426844668,
           -16.76023015731215,
           -16.55625604617762,
           -16.35228193504313,
           -16.148307823908603,
           -15.944333712774071,
           -15.74035960163954,
           -15.536385490505051,
           -15.33241137937052,
           -15.148318639625982,
           -14.97229201312346,
           -14.796265386620904,
           -14.62023876011835,
           -14.444212133615828,
           -14.268185507113273,
           -14.100230523677315,
           -13.941932727395036,
           -13.78363493111273,
           -13.625337134830424,
           -13.467039338548117,
           -13.30874154226584,
           -13.150443745983534,
           -12.992145949701229,
           -12.83384815341895,
           -12.675550357136643,
           -12.51725256085434,
           -12.358954764572063,
           -12.200656968289756,
           -12.04235917200745,
           -11.884061375725144,
           -11.72576357944287,
           -11.56746578316056,
           -11.409167986878256,
           -11.250870190595979,
           -11.092572394313672,
           -10.934274598031367,
           -10.775976801749088,
           -10.617679005466783,
           -10.459381209184478,
           -10.301083412902202,
           -10.142785616619893,
           -9.984487820337588,
           -9.826190024055283,
           -9.667892227773006,
           -9.509594431490699,
           -9.351296635208392,
           -9.192998838926115,
           -9.03470104264381,
           -8.876403246361505,
           -8.718105450079227,
           -8.559807653796922,
           -8.401509857514615,
           -8.24321206123231,
           -8.084914264950031
          ],
          [
           -31.802750712824746,
           -31.838350741942726,
           -31.873950771060706,
           -31.909550800178685,
           -31.945150829296665,
           -31.980750858414645,
           -32.016350887532624,
           -32.051950916650604,
           -32.087550945768584,
           -32.12315097488656,
           -32.15875100400454,
           -32.19435103312252,
           -32.2299510622405,
           -32.26555109135848,
           -32.30115112047646,
           -32.33675114959444,
           -32.37235117871242,
           -32.4079512078304,
           -32.44355123694838,
           -32.47915126606636,
           -32.51475129518434,
           -32.55035132430232,
           -32.5859513534203,
           -32.621551382538286,
           -32.65715141165626,
           -32.69275144077424,
           -32.72835146989222,
           -32.7639514990102,
           -32.79955152812818,
           -32.83515155724616,
           -32.870751586364136,
           -32.90635161548212,
           -32.941951644600096,
           -32.97755167371808,
           -33.01315170283606,
           -33.04875173195404,
           -33.084351761072014,
           -33.11995179019,
           -33.15555181930799,
           -33.19115184842596,
           -33.22675187754394,
           -33.26235190666192,
           -33.2979519357799,
           -33.33355196489788,
           -33.36915199401586,
           -33.40475202313384,
           -33.44035205225182,
           -33.4759520813698,
           -33.51155211048778,
           -33.54715213960576,
           -33.58275216872374,
           -33.618352197841716,
           -33.653952226959696,
           -33.689552256077675,
           -33.725152285195655,
           -33.760752314313635,
           -33.796352343431614,
           -33.8319523725496,
           -33.867552401667574,
           -33.90315243078555,
           -33.93875245990353,
           -33.97435248902152,
           -34.00995251931566,
           -34.047394687939885,
           -34.08483685656411,
           -34.122279025188334,
           -34.15972119381255,
           -34.19716336243678,
           -34.23460553106101,
           -34.272047699685224,
           -34.309489868309456,
           -34.34693203693367,
           -34.3843742055579,
           -34.42181637418212,
           -34.459258542806346,
           -34.49670071143057,
           -34.534142880054794,
           -34.57158504867901,
           -34.609027217303236,
           -34.64646938592746,
           -34.68391155455169,
           -34.72135372317591,
           -34.75879589180014,
           -34.79623806042436,
           -34.83185957092005,
           -34.86711694979003,
           -34.90237432866002,
           -34.93763170753,
           -34.97288908639999,
           -35.008146465269974,
           -35.04340384413995,
           -35.07866122300994,
           -35.113918601879924,
           -35.14917598074991,
           -35.184433359619895,
           -35.219690738489874,
           -35.254948117359866,
           -35.290205496229845,
           -35.32546287509983,
           -35.360720253969816,
           -35.3959776328398,
           -35.43123501170978,
           -35.46649239057977,
           -35.50174976944976,
           -35.53700714831974,
           -35.57133432212672,
           -35.60519639206587,
           -35.63905846200503,
           -35.67292053194419,
           -35.70678260188335,
           -35.74064467182251,
           -35.77450674176166,
           -35.808368811700824,
           -35.84223088163998,
           -35.87609295157914,
           -35.9099550215183,
           -35.943817091457454,
           -35.977679161396615,
           -36.01154123133577,
           -36.04540330127493,
           -36.07926537121409,
           -36.11312744115325,
           -36.14698951109241,
           -36.18085158103156,
           -36.21471365097072,
           -36.248575720909884,
           -36.282437790849045,
           -36.3162998607882,
           -36.35016193072735,
           -36.38402400066652,
           -36.417886070605675,
           -36.45174814054484,
           -36.48561021048399,
           -36.519472280423145,
           -36.55333435036231,
           -36.58719642030147,
           -36.62105849024063,
           -36.65492056017978,
           -36.68878263011894,
           -36.7226447000581,
           -36.75650676999726,
           -36.79036883993642,
           -36.82423090987558,
           -36.85809297981473,
           -36.89195504975389,
           -36.92581711969305,
           -36.95967918963221,
           -36.993541259571366,
           -37.02740332951053,
           -37.06126539944969,
           -37.09512746938884,
           -37.128989539328,
           -37.162851609267165,
           -37.19671367920632,
           -37.23057574914547,
           -37.264437819084634,
           -37.298299889023795,
           -37.332161958962956,
           -37.36602402890211,
           -37.399886098841264,
           -37.433748168780426,
           -37.46761023871959,
           -37.50147230865875,
           -37.5353343785979,
           -37.569196448537056,
           -37.603058518476224,
           -37.63692058841538,
           -37.666397379873075,
           -37.69368153209004,
           -37.720965684307004,
           -37.74824983652396,
           -37.77553398874093,
           -37.802818140957896,
           -37.83010229317486,
           -37.857386445391825,
           -37.88467059760879,
           -37.91195474982575,
           -37.93923890204272,
           -37.96652305425969,
           -37.993807206476646,
           -38.02109135869361,
           -38.048375510910574,
           -38.07565966312754,
           -38.1029438153445,
           -38.13022796756147,
           -38.15751211977843,
           -38.184796271995396,
           -38.21208042421236,
           -38.239364576429324,
           -38.26664872864629,
           -38.29393288086325,
           -38.32121703308022,
           -38.34850118529718,
           -38.375785337514145,
           -38.40306948973111,
           -38.430353641948074,
           -38.45763779416504,
           -38.484921946382,
           -38.512206098598966,
           -38.53949025081593,
           -38.566774403032895,
           -38.59405855524986,
           -38.62486266506771,
           -38.65608917018052,
           -38.68731567529333,
           -38.71854218040613,
           -38.74976868551893,
           -38.78099519063174,
           -38.812221695744554,
           -38.84344820085736,
           -38.87467470597018,
           -38.90590121108298,
           -38.93712771619579,
           -38.9683542213086,
           -38.9995807264214,
           -39.03080723153421,
           -39.062033736647024,
           -39.09326024175983,
           -39.124486746872634,
           -39.155713251985446,
           -39.18693975709826,
           -39.21816626221106,
           -39.24939276732387,
           -39.28061927243668,
           -39.31184577754948,
           -39.34307228266229,
           -39.3742987877751,
           -39.405525292887916,
           -39.436751798000714,
           -39.467978303113526,
           -39.49920480822634,
           -39.53043131333915,
           -39.56165781845195,
           -39.59288432356476,
           -39.62411082867757,
           -39.65533733379037,
           -39.68656383890318,
           -39.717790344015995,
           -39.74901684912881,
           -39.78024335424161,
           -39.81146985935442,
           -39.84269636446723,
           -39.873922869580035,
           -39.90514937469284,
           -39.93637587980565,
           -39.96760238491846,
           -39.99882889003126,
           -40.030055395144075,
           -40.06128190025689,
           -40.092508405369685,
           -40.03689531178651,
           -39.89444261950734,
           -39.75198992722818,
           -39.60953723494902,
           -39.46708454266985,
           -39.324631850390695,
           -39.18217915811154,
           -39.039726465832366,
           -38.897273773553195,
           -38.754821081274045,
           -38.61236838899488,
           -38.4699156967157,
           -38.32746300443655,
           -38.18501031215739,
           -38.042557619878224,
           -37.90010492759907,
           -37.7576522353199,
           -37.61519954304073,
           -37.47274685076158,
           -37.33029415848242,
           -37.18784146620325,
           -37.045388773924074,
           -36.90293608164494,
           -36.76048338936577,
           -36.618030697086596,
           -36.47557800480743,
           -36.333125312528274,
           -36.1906726202491,
           -36.048219927969946,
           -35.90576723569079,
           -35.76331454341162,
           -35.620861851132446,
           -35.4784091588533,
           -35.33595646657413,
           -35.19350377429497,
           -35.0510510820158,
           -34.90859838973664,
           -34.766145697457475,
           -34.62369300517832,
           -34.48124031289916,
           -34.33878762061998,
           -34.19633492834083,
           -34.03796201135074,
           -33.87206314102185,
           -33.70616427069296,
           -33.5402654003641,
           -33.37436653003521,
           -33.20846765970632,
           -33.04256878937745,
           -32.876669919048574,
           -32.710771048719685,
           -32.54487217839081,
           -32.37897330806194,
           -32.21307443773304,
           -32.04717556740415,
           -31.8812766970753,
           -31.715377826746412,
           -31.54947895641752,
           -31.38358008608865,
           -31.217681215759775,
           -31.05178234543088,
           -30.88588347510201,
           -30.71998460477314,
           -30.554085734444243,
           -30.38818686411537,
           -30.222287993786495,
           -30.056389123457606,
           -29.890490253128718,
           -29.724591382799858,
           -29.55869251247097,
           -29.39279364214208,
           -29.226894771813203,
           -29.060995901484336,
           -28.895097031155444,
           -28.729198160826567,
           -28.563299290497696,
           -28.397400420168807,
           -28.231501549839933,
           -28.065602679511056,
           -27.899703809182164,
           -27.73380493885328,
           -27.5679060685244,
           -27.402007198195527,
           -27.27607306470556,
           -27.230068404893412,
           -27.18406374508126,
           -27.138059085269102,
           -27.092054425456958,
           -27.046049765644803,
           -27.00004510583265,
           -26.954040446020496,
           -26.908035786208348,
           -26.862031126396193,
           -26.816026466584038,
           -26.770021806771886,
           -26.724017146959735,
           -26.67801248714758,
           -26.632007827335432,
           -26.58600316752328,
           -26.539998507711125,
           -26.493993847898974,
           -26.447989188086822,
           -26.401984528274667,
           -26.355979868462512,
           -26.30997520865036,
           -26.263970548838213,
           -26.217965889026058,
           -26.171961229213906,
           -26.12595656940175,
           -26.079951909589596,
           -26.03394724977745,
           -25.987942589965296,
           -25.941937930153145,
           -25.89593327034099,
           -25.849928610528842,
           -25.803923950716687,
           -25.757919290904532,
           -25.711914631092377,
           -25.66590997128023,
           -25.619905311468074,
           -25.573900651655922,
           -25.52789599184377,
           -25.481891332031616,
           -25.435886672219468,
           -25.389882012407313,
           -25.34387735259516,
           -25.297872692783006,
           -25.251868032970854,
           -25.205863373158707,
           -25.159858713346548,
           -25.113854053534396,
           -25.06784939372225,
           -25.02184473391009,
           -24.97584007409794,
           -24.92983541428579,
           -24.883830754473635,
           -24.83782609466148,
           -24.791821434849332,
           -24.745816775037177,
           -24.699812115225022,
           -24.653807455412867,
           -24.60780279560072,
           -24.561798135788568,
           -24.515793475976416,
           -24.469788816164264,
           -24.423784156352106,
           -24.377779496539958,
           -24.331774836727806,
           -24.285770176915655,
           -24.2397655171035,
           -24.193760857291352,
           -24.147756197479197,
           -24.10175153766704,
           -24.05574687785489,
           -24.00974221804274,
           -23.96325231208043,
           -23.915384339529577,
           -23.867516366978727,
           -23.819648394427865,
           -23.77178042187701,
           -23.723912449326157,
           -23.676044476775303,
           -23.628176504224445,
           -23.580308531673595,
           -23.53244055912274,
           -23.484572586571886,
           -23.41068692425709,
           -23.20671281312256,
           -23.00273870198803,
           -22.798764590853505,
           -22.59479047971901,
           -22.39081636858448,
           -22.186842257449953,
           -21.98286814631546,
           -21.794192952566764,
           -21.610066173342364,
           -21.425939394117997,
           -21.241812614893597,
           -21.057685835669197,
           -20.873559056444797,
           -20.68943227722043,
           -20.50530549799603,
           -20.321178718771634,
           -20.137051939547266,
           -19.952925160322867,
           -19.768798381098467,
           -19.5846716018741,
           -19.4005448226497,
           -19.2164180434253,
           -19.032291264200932,
           -18.848164484976532,
           -18.664037705752133,
           -18.479910926527737,
           -18.295784147303365,
           -18.111657368078966,
           -17.927530588854566,
           -17.743403809630202,
           -17.559277030405802,
           -17.375150251181402,
           -17.191023471957035,
           -17.006896692732635,
           -16.822769913508235,
           -16.638643134283832,
           -16.45451635505947,
           -16.270389575835072,
           -16.08626279661067,
           -15.902136017386304,
           -15.718009238161905,
           -15.533882458937505,
           -15.349755679713137,
           -15.165628900488738,
           -14.98150212126434,
           -14.797375342039974,
           -14.61324856281557,
           -14.429121783591171,
           -14.244995004366771,
           -14.060868225142405,
           -13.876741445918006,
           -13.692614666693604,
           -13.508487887469238,
           -13.324361108244839,
           -13.14023432902044,
           -12.956107549796073,
           -12.771980770571673,
           -12.587853991347274,
           -12.403727212122874,
           -12.219600432898508,
           -12.035473653674108,
           -11.851346874449707,
           -11.667220095225343,
           -11.483093316000943,
           -11.298966536776543,
           -11.114839757552176,
           -10.930712978327776,
           -10.746586199103376,
           -10.56245941987901,
           -10.378332640654609,
           -10.19420586143021,
           -10.01007908220581,
           -9.825952302981445,
           -9.641825523757044,
           -9.457698744532644,
           -9.283796025733091,
           -9.125498229450784,
           -8.967200433168479,
           -8.808902636886202,
           -8.650604840603895,
           -8.49230704432159,
           -8.334009248039283,
           -8.175711451757007
          ],
          [
           -31.416824993111568,
           -31.452425022229548,
           -31.488025051347524,
           -31.523625080465507,
           -31.559225109583487,
           -31.594825138701466,
           -31.630425167819446,
           -31.666025196937426,
           -31.701625226055405,
           -31.73722525517339,
           -31.77282528429137,
           -31.808425313409344,
           -31.844025342527328,
           -31.879625371645307,
           -31.915225400763287,
           -31.950825429881267,
           -31.986425458999246,
           -32.02202548811722,
           -32.05762551723521,
           -32.09322554635318,
           -32.12882557547117,
           -32.16442560458914,
           -32.20002563370712,
           -32.23562566282511,
           -32.27122569194309,
           -32.30682572106106,
           -32.342425750179046,
           -32.37802577929702,
           -32.413625808415006,
           -32.44922583753298,
           -32.484825866650965,
           -32.520425895768945,
           -32.556025924886924,
           -32.591625954004904,
           -32.627225983122884,
           -32.662826012240856,
           -32.69842604135884,
           -32.73402607047682,
           -32.7696260995948,
           -32.80522612871278,
           -32.84082615783076,
           -32.87642618694874,
           -32.91202621606672,
           -32.94762624518471,
           -32.98322627430268,
           -33.01882630342067,
           -33.05442633253864,
           -33.09002636165662,
           -33.1256263907746,
           -33.161226419892586,
           -33.19682644901056,
           -33.232426478128545,
           -33.26802650724652,
           -33.303626536364504,
           -33.33922656548248,
           -33.374826594600464,
           -33.410426623718436,
           -33.44602665283642,
           -33.481626681954396,
           -33.51722671107238,
           -33.552826740190355,
           -33.58842676930834,
           -33.624026798426314,
           -33.6596268275443,
           -33.69522685666227,
           -33.73082688578026,
           -33.76642691489823,
           -33.80202694401622,
           -33.8376269731342,
           -33.87322700225218,
           -33.90882703137015,
           -33.94442706048814,
           -33.98002708960611,
           -34.0156271187241,
           -34.05122714784207,
           -34.08682717696006,
           -34.12242720607803,
           -34.158027235196016,
           -34.193627264314,
           -34.23014836536563,
           -34.26759053398985,
           -34.30503270261408,
           -34.3424748712383,
           -34.37991703986252,
           -34.415538550358214,
           -34.4507959292282,
           -34.486053308098185,
           -34.521310686968164,
           -34.556335516001305,
           -34.59019758594046,
           -34.62405965587962,
           -34.65792172581878,
           -34.691783795757935,
           -34.725645865697096,
           -34.75950793563626,
           -34.79337000557542,
           -34.82723207551457,
           -34.861094145453734,
           -34.89495621539289,
           -34.92881828533205,
           -34.9626803552712,
           -34.996542425210365,
           -35.030404495149526,
           -35.06426656508869,
           -35.09812863502784,
           -35.131990704966995,
           -35.165852774906156,
           -35.19971484484531,
           -35.23357691478447,
           -35.26743898472363,
           -35.30130105466279,
           -35.33516312460195,
           -35.36902519454111,
           -35.40288726448027,
           -35.436749334419424,
           -35.470611404358586,
           -35.50447347429774,
           -35.5383355442369,
           -35.572197614176055,
           -35.606059684115216,
           -35.63992175405437,
           -35.67378382399353,
           -35.70764589393269,
           -35.741507963871854,
           -35.775370033811015,
           -35.80923210375017,
           -35.84309417368933,
           -35.876956243628484,
           -35.910818313567646,
           -35.94468038350681,
           -35.97854245344596,
           -36.01240452338512,
           -36.046266593324276,
           -36.08012866326343,
           -36.1139907332026,
           -36.14785280314175,
           -36.18171487308091,
           -36.21557694302007,
           -36.24943901295923,
           -36.28330108289839,
           -36.317163152837544,
           -36.3510252227767,
           -36.38488729271586,
           -36.41874936265502,
           -36.45261143259418,
           -36.48647350253334,
           -36.5203355724725,
           -36.55419764241166,
           -36.58805971235081,
           -36.621921782289974,
           -36.655783852229135,
           -36.68964592216829,
           -36.72350799210744,
           -36.7573700620466,
           -36.79123213198576,
           -36.82509420192492,
           -36.85895627186408,
           -36.892818341803235,
           -36.926680411742396,
           -36.96054248168156,
           -36.99440455162071,
           -37.02826662155987,
           -37.06212869149903,
           -37.09599076143819,
           -37.12985283137735,
           -37.1637149013165,
           -37.19757697125566,
           -37.22705376271336,
           -37.254337914930325,
           -37.28162206714729,
           -37.30890621936425,
           -37.336190371581225,
           -37.36347452379819,
           -37.39075867601515,
           -37.41804282823211,
           -37.449269326514795,
           -37.4804958316276,
           -37.51172233674041,
           -37.54294884185322,
           -37.57417534696603,
           -37.60540185207883,
           -37.63662835719164,
           -37.66785486230445,
           -37.69908136741726,
           -37.73030787253006,
           -37.761534377642874,
           -37.79276088275568,
           -37.82398738786849,
           -37.8552138929813,
           -37.88644039809411,
           -37.91766690320692,
           -37.94889340831972,
           -37.98011991343253,
           -38.011346418545344,
           -38.04257292365815,
           -38.073799428770954,
           -38.10502593388376,
           -38.13625243899657,
           -38.167478944109384,
           -38.19870544922219,
           -38.229931954335,
           -38.2611584594478,
           -38.29238496456061,
           -38.323611469673416,
           -38.35483797478623,
           -38.38606447989904,
           -38.417290985011846,
           -38.44851749012465,
           -38.47974399523746,
           -38.51097050035027,
           -38.54219700546308,
           -38.573423510575886,
           -38.6046500156887,
           -38.6358765208015,
           -38.667103025914315,
           -38.69832953102712,
           -38.729556036139925,
           -38.76078254125273,
           -38.79200904636554,
           -38.823235551478355,
           -38.85446205659116,
           -38.88568856170397,
           -38.91691506681678,
           -38.94814157192958,
           -38.979368077042395,
           -39.0105945821552,
           -39.04182108726801,
           -39.07304759238082,
           -39.10427409749363,
           -39.135500602606434,
           -39.16672710771924,
           -39.19795361283205,
           -39.229180117944864,
           -39.26040662305767,
           -39.291633128170474,
           -39.32285963328329,
           -39.35408613839609,
           -39.3853126435089,
           -39.41653914862171,
           -39.447765653734514,
           -39.478992158847326,
           -39.51021866396013,
           -39.541445169072944,
           -39.57267167418575,
           -39.603898179298554,
           -39.635124684411366,
           -39.66635118952418,
           -39.69757769463698,
           -39.72880419974979,
           -39.7600307048626,
           -39.70441761127941,
           -39.561964919000246,
           -39.41951222672108,
           -39.27705953444193,
           -39.13460684216275,
           -38.9921541498836,
           -38.84970145760444,
           -38.707248765325275,
           -38.5647960730461,
           -38.422343380766954,
           -38.27989068848779,
           -38.13743799620861,
           -37.994985303929454,
           -37.8525326116503,
           -37.710079919371125,
           -37.567627227091975,
           -37.42517453481281,
           -37.28272184253364,
           -37.14026915025448,
           -36.997816457975325,
           -36.855363765696154,
           -36.71291107341699,
           -36.57045838113784,
           -36.42800568885867,
           -36.2855529965795,
           -36.14310030430035,
           -36.00064761202118,
           -35.85819491974201,
           -35.715742227462854,
           -35.5732895351837,
           -35.430836842904526,
           -35.288384150625355,
           -35.14593145834621,
           -35.00347876606704,
           -34.86102607378787,
           -34.71857338150871,
           -34.576120689229555,
           -34.43366799695038,
           -34.291215304671226,
           -34.14876261239206,
           -34.00630992011289,
           -33.86385722783373,
           -33.721404535554576,
           -33.578951843275405,
           -33.436499150996234,
           -33.29404645871709,
           -33.15159376643792,
           -33.00914107415875,
           -32.86668838187959,
           -32.724235689600434,
           -32.58178299732126,
           -32.439330305042105,
           -32.29687761276294,
           -32.15442492048378,
           -32.011972228204606,
           -31.869519535925463,
           -31.72706684364629,
           -31.58461415136712,
           -31.442161459087963,
           -31.299708766808802,
           -31.15725607452963,
           -31.014803382250477,
           -30.87235068997132,
           -30.72989799769214,
           -30.587445305412988,
           -30.439058702158484,
           -30.273159831829595,
           -30.107260961500707,
           -29.941362091171847,
           -29.77546322084295,
           -29.60956435051407,
           -29.443665480185192,
           -29.277766609856318,
           -29.111867739527433,
           -28.945968869198555,
           -28.78006999886968,
           -28.614171128540793,
           -28.448272258211915,
           -28.28237338788304,
           -28.11647451755415,
           -27.95057564722526,
           -27.784676776896386,
           -27.618777906567512,
           -27.49284377307755,
           -27.4468391132654,
           -27.400834453453246,
           -27.35482979364109,
           -27.30882513382894,
           -27.26282047401679,
           -27.216815814204633,
           -27.17081115439248,
           -27.124806494580334,
           -27.078801834768182,
           -27.032797174956023,
           -26.986792515143872,
           -26.940787855331724,
           -26.89478319551957,
           -26.848778535707417,
           -26.802773875895266,
           -26.756769216083107,
           -26.71076455627096,
           -26.66475989645881,
           -26.618755236646653,
           -26.572750576834498,
           -26.526745917022346,
           -26.480741257210198,
           -26.43473659739804,
           -26.38873193758589,
           -26.34272727777374,
           -26.296722617961585,
           -26.250717958149433,
           -26.204713298337282,
           -26.158708638525127,
           -26.11270397871297,
           -26.066699318900824,
           -26.02069465908867,
           -25.974689999276514,
           -25.928685339464366,
           -25.882680679652214,
           -25.83667601984006,
           -25.790671360027908,
           -25.744666700215756,
           -25.698662040403605,
           -25.65268267966502,
           -25.608499978782255,
           -25.564317277899484,
           -25.520134577016712,
           -25.475951876133948,
           -25.431769175251183,
           -25.387586474368412,
           -25.343403773485644,
           -25.29922107260288,
           -25.255038371720108,
           -25.21085567083734,
           -25.166672969954575,
           -25.122490269071804,
           -25.07830756818904,
           -25.034124867306275,
           -24.989942166423507,
           -24.945759465540736,
           -24.90157676465797,
           -24.857394063775203,
           -24.81321136289243,
           -24.769028662009667,
           -24.724845961126903,
           -24.68066326024413,
           -24.636480559361363,
           -24.592297858478595,
           -24.548115157595827,
           -24.50393245671306,
           -24.459749755830295,
           -24.415567054947527,
           -24.371384354064755,
           -24.32720165318199,
           -24.283018952299223,
           -24.238836251416455,
           -24.194653550533687,
           -24.15047084965092,
           -24.10628814876815,
           -24.06210544788538,
           -24.01792274700262,
           -23.973740046119847,
           -23.92955734523708,
           -23.885374644354314,
           -23.841191943471543,
           -23.797009242588775,
           -23.725390731783172,
           -23.51659317136334,
           -23.307795610943515,
           -23.098998050523683,
           -22.890200490103897,
           -22.68140292968407,
           -22.472605369264237,
           -22.263807808844447,
           -22.055010248424622,
           -21.84621268800479,
           -21.637415127585,
           -21.428617567165176,
           -21.219820006745344,
           -21.011022446325512,
           -20.802224885905723,
           -20.593427325485898,
           -20.384629765066066,
           -20.175832204646284,
           -19.96703464422645,
           -19.758237083806623,
           -19.559086432241347,
           -19.374959653016944,
           -19.190832873792544,
           -19.006706094568177,
           -18.822579315343777,
           -18.63845253611938,
           -18.45432575689498,
           -18.270198977670614,
           -18.086072198446214,
           -17.901945419221814,
           -17.717818639997446,
           -17.533691860773047,
           -17.349565081548647,
           -17.16543830232428,
           -16.98131152309988,
           -16.79718474387548,
           -16.61305796465108,
           -16.428931185426716,
           -16.244804406202316,
           -16.060677626977917,
           -15.876550847753549,
           -15.69242406852915,
           -15.50829728930475,
           -15.324170510080384,
           -15.140043730855982,
           -14.955916951631584,
           -14.771790172407218,
           -14.587663393182819,
           -14.403536613958419,
           -14.219409834734018,
           -14.035283055509653,
           -13.851156276285252,
           -13.667029497060852,
           -13.482902717836486,
           -13.298775938612087,
           -13.114649159387687,
           -12.930522380163321,
           -12.746395600938921,
           -12.562268821714522,
           -12.37814204249012,
           -12.194015263265754,
           -12.009888484041355,
           -11.825761704816955,
           -11.64163492559259,
           -11.469786194605941,
           -11.30148896585645,
           -11.13319173710699,
           -10.9648945083575,
           -10.796597279608008,
           -10.628300050858547,
           -10.460002822109056,
           -10.291705593359566,
           -10.123408364610075,
           -9.955111135860612,
           -9.786813907111123,
           -9.618516678361633,
           -9.45021944961217,
           -9.28192222086268,
           -9.11362499211319,
           -8.94532776336373,
           -8.777030534614239,
           -8.608733305864746,
           -8.440436077115256,
           -8.272138848365795
          ],
          [
           -31.022072433688976,
           -31.057672462806956,
           -31.093272491924935,
           -31.128872521042915,
           -31.164472550160895,
           -31.200072579278878,
           -31.235672608396854,
           -31.271272637514834,
           -31.306872666632817,
           -31.342472695750796,
           -31.378072724868776,
           -31.413672753986756,
           -31.449272783104735,
           -31.484872812222715,
           -31.5204728413407,
           -31.556072870458678,
           -31.591672899576654,
           -31.627272928694637,
           -31.662872957812617,
           -31.698472986930597,
           -31.734073016048576,
           -31.769673045166556,
           -31.805273074284532,
           -31.84087310340252,
           -31.87647313252049,
           -31.91207316163847,
           -31.947673190756458,
           -31.98327321987443,
           -32.01887324899241,
           -32.05447327811039,
           -32.09007330722837,
           -32.12567333634635,
           -32.16127336546433,
           -32.19687339458231,
           -32.23247342370029,
           -32.26807345281827,
           -32.30367348193626,
           -32.33927351105423,
           -32.37487354017222,
           -32.41047356929019,
           -32.44607359840817,
           -32.48167362752615,
           -32.517273656644136,
           -32.55287368576211,
           -32.58847371488009,
           -32.62407374399807,
           -32.659673773116054,
           -32.69527380223403,
           -32.73087383135201,
           -32.766473860469986,
           -32.802073889587966,
           -32.837673918705946,
           -32.87327394782393,
           -32.90887397694191,
           -32.94447400605989,
           -32.98007403517787,
           -33.01567406429585,
           -33.05127409341383,
           -33.08687412253181,
           -33.12247415164979,
           -33.15807418076777,
           -33.19367420988575,
           -33.22927423900373,
           -33.26487426812171,
           -33.30047429723969,
           -33.33607432635767,
           -33.37167435547565,
           -33.40727438459363,
           -33.442874413711614,
           -33.47847444282959,
           -33.514074471947566,
           -33.549674501065546,
           -33.58395798413572,
           -33.61758319056937,
           -33.65120839700301,
           -33.68483360343666,
           -33.7184588098703,
           -33.75208401630394,
           -33.78570922273759,
           -33.81933442917123,
           -33.852959635604876,
           -33.886584842038516,
           -33.92021004847216,
           -33.953835254905805,
           -33.98633391508986,
           -34.01860726602399,
           -34.05088061695813,
           -34.083153967892265,
           -34.115427318826406,
           -34.14770066976054,
           -34.17997402069468,
           -34.21224737162881,
           -34.24452072256295,
           -34.276794073497086,
           -34.30906742443123,
           -34.34134077730291,
           -34.37520284724207,
           -34.409064917181226,
           -34.44292698712038,
           -34.47678905705954,
           -34.510651126998695,
           -34.54451319693786,
           -34.57837526687702,
           -34.61223733681618,
           -34.64609940675533,
           -34.67996147669449,
           -34.713823546633655,
           -34.74768561657281,
           -34.78154768651197,
           -34.81540975645113,
           -34.849271826390286,
           -34.88313389632945,
           -34.9169959662686,
           -34.95085803620776,
           -34.98472010614692,
           -35.01858217608608,
           -35.05244424602523,
           -35.08630631596439,
           -35.120168385903554,
           -35.15403045584271,
           -35.18789252578187,
           -35.22175459572103,
           -35.255616665660185,
           -35.289478735599346,
           -35.32334080553851,
           -35.35720287547766,
           -35.39106494541682,
           -35.424927015355976,
           -35.45878908529514,
           -35.4926511552343,
           -35.52651322517345,
           -35.560375295112614,
           -35.59423736505177,
           -35.62809943499093,
           -35.66196150493009,
           -35.69582357486925,
           -35.729685644808406,
           -35.76354771474756,
           -35.79740978468672,
           -35.83127185462588,
           -35.86513392456504,
           -35.8989959945042,
           -35.93285806444336,
           -35.96672013438251,
           -36.000582204321674,
           -36.03444427426083,
           -36.068306344199996,
           -36.10216841413915,
           -36.136030484078304,
           -36.169892554017466,
           -36.20375462395663,
           -36.23761669389578,
           -36.27147876383495,
           -36.305340833774096,
           -36.33920290371326,
           -36.37306497365242,
           -36.40692704359157,
           -36.44078911353073,
           -36.47465118346989,
           -36.50851325340905,
           -36.54237532334821,
           -36.576237393287364,
           -36.610099463226526,
           -36.64396153316569,
           -36.67782360310484,
           -36.711685673044,
           -36.745547742983156,
           -36.77885619283058,
           -36.81188783263214,
           -36.84491947243369,
           -36.877951112235245,
           -36.91098275203679,
           -36.944014391838344,
           -36.977046031639894,
           -37.01007767144145,
           -37.043109311243,
           -37.07614095104455,
           -37.10917259084611,
           -37.142204230647664,
           -37.175235870449214,
           -37.208267510250764,
           -37.24129915005231,
           -37.27433078985387,
           -37.30736242965543,
           -37.34039406945698,
           -37.37342570925853,
           -37.406457349060084,
           -37.43948898886163,
           -37.47252062866319,
           -37.50555226846474,
           -37.5385839082663,
           -37.57161554806784,
           -37.60464718786939,
           -37.637678827670946,
           -37.6707104674725,
           -37.70374210727405,
           -37.73677374707561,
           -37.76980538687716,
           -37.802837026678716,
           -37.83586866648026,
           -37.868900306281816,
           -37.901931946083366,
           -37.934963585884915,
           -37.96799522568647,
           -38.00102686548802,
           -38.03405850528958,
           -38.06709014509113,
           -38.10012178489268,
           -38.133153424694235,
           -38.166185064495785,
           -38.19921670429734,
           -38.23224834409889,
           -38.26527998390044,
           -38.29831162370199,
           -38.33134326350355,
           -38.3643749033051,
           -38.397078335632834,
           -38.428304840745646,
           -38.45953134585845,
           -38.490757850971264,
           -38.521984356084076,
           -38.55321086119688,
           -38.58443736630968,
           -38.61566387142249,
           -38.646890376535296,
           -38.67811688164811,
           -38.70934338676092,
           -38.740569891873726,
           -38.77179639698653,
           -38.80302290209934,
           -38.83424940721215,
           -38.86547591232495,
           -38.896702417437766,
           -38.92792892255058,
           -38.95915542766338,
           -38.99038193277619,
           -39.02160843788899,
           -39.052834943001805,
           -39.08406144811462,
           -39.11528795322743,
           -39.146514458340235,
           -39.17774096345304,
           -39.208967468565845,
           -39.24019397367866,
           -39.27142047879147,
           -39.30264698390427,
           -39.33387348901707,
           -39.365099994129885,
           -39.3963264992427,
           -39.4275530043555,
           -39.37193991077232,
           -39.229487218493155,
           -39.087034526214,
           -38.94458183393484,
           -38.80212914165566,
           -38.65967644937651,
           -38.517223757097355,
           -38.37477106481818,
           -38.232318372539005,
           -38.08986568025986,
           -37.94741298798069,
           -37.80496029570153,
           -37.66250760342236,
           -37.520054911143205,
           -37.377602218864034,
           -37.23514952658488,
           -37.09269683430572,
           -36.95024414202655,
           -36.80779144974739,
           -36.665338757468234,
           -36.52288606518906,
           -36.38043337290989,
           -36.23798068063075,
           -36.09552798835158,
           -35.953075296072406,
           -35.81062260379325,
           -35.66816991151409,
           -35.52571721923492,
           -35.38326452695576,
           -35.2408118346766,
           -35.098359142397435,
           -34.95590645011826,
           -34.81345375783912,
           -34.67100106555994,
           -34.52854837328078,
           -34.38609568100161,
           -34.243642988722456,
           -34.10119029644329,
           -33.958737604164135,
           -33.81628491188497,
           -33.6738322196058,
           -33.53137952732665,
           -33.388926835047485,
           -33.24647414276832,
           -33.10402145048914,
           -32.96156875820999,
           -32.81911606593083,
           -32.67666337365166,
           -32.5342106813725,
           -32.39175798909334,
           -32.24930529681417,
           -32.10685260453501,
           -31.96439991225585,
           -31.821947219976682,
           -31.679494527697514,
           -31.537041835418368,
           -31.39624660893056,
           -31.258351961080866,
           -31.12045731323118,
           -30.98256266538149,
           -30.84466801753179,
           -30.706773369682104,
           -30.56887872183242,
           -30.430984073982717,
           -30.293089426133033,
           -30.15519477828334,
           -30.017300130433647,
           -29.87940548258395,
           -29.741510834734274,
           -29.603616186884576,
           -29.465721539034877,
           -29.32782689118519,
           -29.1899322433355,
           -29.052037595485803,
           -28.914142947636115,
           -28.77624829978643,
           -28.638353651936733,
           -28.500459004087045,
           -28.36256435623736,
           -28.22466970838766,
           -28.086775060537963,
           -27.948880412688272,
           -27.810985764838588,
           -27.70494539610398,
           -27.662613585599512,
           -27.620281775095044,
           -27.577949964590577,
           -27.535618154086116,
           -27.493286343581648,
           -27.45095453307718,
           -27.408622722572712,
           -27.36629091206825,
           -27.323959101563783,
           -27.281627291059312,
           -27.239295480554848,
           -27.19696367005038,
           -27.154631859545916,
           -27.11230004904145,
           -27.069968238536983,
           -27.025870631394305,
           -26.98168793051154,
           -26.937505229628773,
           -26.893322528746,
           -26.84913982786323,
           -26.80495712698046,
           -26.760774426097697,
           -26.71659172521493,
           -26.67240902433216,
           -26.628226323449397,
           -26.584043622566625,
           -26.539860921683857,
           -26.495678220801093,
           -26.45149551991833,
           -26.407312819035553,
           -26.363130118152796,
           -26.318947417270024,
           -26.274764716387253,
           -26.23058201550449,
           -26.18639931462172,
           -26.14221661373895,
           -26.09803391285618,
           -26.053851211973416,
           -26.009668511090645,
           -25.96548581020788,
           -25.921303109325116,
           -25.877120408442345,
           -25.832937707559573,
           -25.78875500667681,
           -25.744572305794044,
           -25.70038960491127,
           -25.656206904028505,
           -25.61202420314574,
           -25.567841502262972,
           -25.523658801380208,
           -25.479476100497436,
           -25.435293399614665,
           -25.391110698731897,
           -25.346927997849136,
           -25.302745296966368,
           -25.258562596083596,
           -25.21437989520083,
           -25.17019719431806,
           -25.126014493435292,
           -25.081831792552528,
           -25.037649091669763,
           -24.99346639078699,
           -24.949283689904224,
           -24.90510098902146,
           -24.860918288138688,
           -24.81673558725592,
           -24.772552886373155,
           -24.728370185490384,
           -24.684187484607616,
           -24.640004783724848,
           -24.595822082842083,
           -24.551639381959312,
           -24.507456681076548,
           -24.463273980193783,
           -24.41909127931101,
           -24.37490857842824,
           -24.33072587754548,
           -24.28654317666271,
           -24.24236047577994,
           -24.19817777489717,
           -24.153995074014404,
           -24.109812373131636,
           -24.038193862326033,
           -23.829396301906204,
           -23.620598741486376,
           -23.411801181066547,
           -23.203003620646754,
           -22.994206060226926,
           -22.785408499807097,
           -22.57661093938731,
           -22.367813378967483,
           -22.15901581854765,
           -21.95021825812786,
           -21.741420697708033,
           -21.532623137288205,
           -21.323825576868373,
           -21.115028016448584,
           -20.90623045602876,
           -20.697432895608927,
           -20.48863533518914,
           -20.279837774769312,
           -20.071040214349484,
           -19.862242653929695,
           -19.653445093509866,
           -19.444647533090038,
           -19.235849972670245,
           -19.027052412250416,
           -18.818254851830588,
           -18.60945729141076,
           -18.40065973099097,
           -18.19186217057114,
           -17.983064610151313,
           -17.77426704973152,
           -17.565469489311695,
           -17.356671928891863,
           -17.147874368472074,
           -16.939076808052246,
           -16.730279247632417,
           -16.52148168721259,
           -16.3126841267928,
           -16.11015344293797,
           -15.918658970698367,
           -15.727164498458798,
           -15.535670026219194,
           -15.34417555397959,
           -15.15268108174002,
           -14.961186609500416,
           -14.769692137260812,
           -14.5968594790064,
           -14.428562250256908,
           -14.260265021507417,
           -14.091967792757927,
           -13.923670564008466,
           -13.755373335258975,
           -13.587076106509485,
           -13.418778877760023,
           -13.250481649010531,
           -13.08218442026104,
           -12.91388719151158,
           -12.74558996276209,
           -12.577292734012598,
           -12.408995505263109,
           -12.240698276513648,
           -12.072401047764156,
           -11.904103819014667,
           -11.735806590265204,
           -11.567509361515715,
           -11.399212132766223,
           -11.230914904016764,
           -11.062617675267273,
           -10.89432044651778,
           -10.726023217768322,
           -10.557725989018829,
           -10.389428760269338,
           -10.221131531519847,
           -10.052834302770387,
           -9.884537074020896,
           -9.716239845271405,
           -9.547942616521944,
           -9.379645387772452,
           -9.211348159022961,
           -9.043050930273502,
           -8.87475370152401,
           -8.706456472774521,
           -8.538159244025028,
           -8.369862015275569
          ],
          [
           -30.623838865665483,
           -30.65943889478347,
           -30.695038923901443,
           -30.730638953019422,
           -30.76623898213741,
           -30.801839011255385,
           -30.83743904037336,
           -30.873039069491345,
           -30.908639098609328,
           -30.944239127727304,
           -30.979839156845287,
           -31.015439185963263,
           -31.051039215081243,
           -31.086639244199226,
           -31.122239273317206,
           -31.157839302435185,
           -31.193439331553165,
           -31.229039360671145,
           -31.264639389789124,
           -31.300239418907104,
           -31.335839448025084,
           -31.371439477143063,
           -31.407039506261043,
           -31.442639535379026,
           -31.478239564497002,
           -31.513839593614982,
           -31.549439622732965,
           -31.585039651850938,
           -31.620639680968928,
           -31.656239710086904,
           -31.69183973920488,
           -31.72743976832286,
           -31.763039797440843,
           -31.798639826558823,
           -31.8342398556768,
           -31.869839884794782,
           -31.905439913912762,
           -31.941039943030738,
           -31.976639972148725,
           -32.012240001266704,
           -32.047840030384684,
           -32.08344005950266,
           -32.11904008862064,
           -32.15464011773862,
           -32.1902401468566,
           -32.22584017597458,
           -32.26144020509256,
           -32.29704023421054,
           -32.33264026332852,
           -32.3682402924465,
           -32.40384032156447,
           -32.43944035068246,
           -32.47504037980044,
           -32.51064040891842,
           -32.54624043803639,
           -32.5815113321229,
           -32.61513653855655,
           -32.64876174499019,
           -32.68238695142383,
           -32.71601215785748,
           -32.74963736429112,
           -32.783262570724766,
           -32.816887777158406,
           -32.85051298359205,
           -32.884138190025695,
           -32.917763396459335,
           -32.951388602892976,
           -32.98501380932662,
           -33.018639015760264,
           -33.05226422219391,
           -33.085889428627546,
           -33.11951463506119,
           -33.153139841494834,
           -33.186765047928475,
           -33.22039025436212,
           -33.25401546079576,
           -33.287640667229404,
           -33.32126587366305,
           -33.35489108009669,
           -33.38851628653034,
           -33.42214149296398,
           -33.45576669939762,
           -33.48939190583127,
           -33.52301711226491,
           -33.55551577244896,
           -33.587789123383104,
           -33.62006247431724,
           -33.65233582525137,
           -33.68460917618551,
           -33.716882527119644,
           -33.749155878053784,
           -33.78142922898792,
           -33.81370257992206,
           -33.84597593085619,
           -33.87824928179033,
           -33.910522632724465,
           -33.942795983658606,
           -33.975069334592746,
           -34.00734268552688,
           -34.03961603646102,
           -34.07188938739515,
           -34.10416273832929,
           -34.13643608926343,
           -34.16870944019757,
           -34.2009827911317,
           -34.23325614206584,
           -34.265529492999974,
           -34.29780284393411,
           -34.33007619486825,
           -34.36234954580238,
           -34.39462289673652,
           -34.426896247670655,
           -34.45996395978271,
           -34.49382602972187,
           -34.52768809966103,
           -34.56155016960019,
           -34.59541223953934,
           -34.62927430947851,
           -34.663136379417665,
           -34.696998449356826,
           -34.73086051929598,
           -34.76472258923514,
           -34.798584659174296,
           -34.83244672911346,
           -34.86630879905262,
           -34.90017086899177,
           -34.93403293893093,
           -34.96789500887009,
           -35.00175707880925,
           -35.03561914874841,
           -35.06948121868757,
           -35.10334328862673,
           -35.137205358565886,
           -35.17106742850504,
           -35.2049294984442,
           -35.23879156838336,
           -35.27265363832252,
           -35.30651570826168,
           -35.34037777820083,
           -35.37423984813999,
           -35.40810191807915,
           -35.44196398801831,
           -35.47582605795747,
           -35.509688127896624,
           -35.543550197835785,
           -35.577412267774946,
           -35.61127433771411,
           -35.64513640765326,
           -35.678998477592415,
           -35.71286054753158,
           -35.74672261747074,
           -35.7805846874099,
           -35.81444675734905,
           -35.84830882728821,
           -35.88217089722737,
           -35.91603296716653,
           -35.949895037105684,
           -35.983757107044845,
           -36.017619176984,
           -36.05148124692316,
           -36.08534331686232,
           -36.11920538680148,
           -36.15306745674064,
           -36.18692952667979,
           -36.22079159661895,
           -36.25465366655811,
           -36.288515736497274,
           -36.3218241863447,
           -36.35485582614625,
           -36.3878874659478,
           -36.42091910574935,
           -36.4539507455509,
           -36.486982385352455,
           -36.520014025154005,
           -36.55304566495556,
           -36.58607730475711,
           -36.61910894455866,
           -36.65214058436022,
           -36.68517222416177,
           -36.718203863963325,
           -36.751235503764875,
           -36.784267143566424,
           -36.81729878336798,
           -36.85033042316954,
           -36.88336206297109,
           -36.91639370277264,
           -36.949425342574195,
           -36.98245698237574,
           -37.0154886221773,
           -37.04852026197885,
           -37.0815519017804,
           -37.11458354158195,
           -37.1476151813835,
           -37.180646821185064,
           -37.213678460986614,
           -37.246710100788164,
           -37.279741740589714,
           -37.31277338039126,
           -37.34580502019282,
           -37.37883665999438,
           -37.41186829979593,
           -37.44489993959748,
           -37.477931579399026,
           -37.51096321920058,
           -37.54399485900213,
           -37.57702649880368,
           -37.61005813860524,
           -37.64308977840679,
           -37.676121418208346,
           -37.709153058009896,
           -37.742184697811446,
           -37.775216337613,
           -37.80824797741455,
           -37.84127961721611,
           -37.87431125701766,
           -37.907342896819216,
           -37.940374536620766,
           -37.973406176422316,
           -38.006437816223865,
           -38.03946945602542,
           -38.07250109582697,
           -38.10553273562852,
           -38.138564375430086,
           -38.171596015231636,
           -38.204627655033185,
           -38.237659294834735,
           -38.270690934636285,
           -38.30372257443784,
           -38.33675421423939,
           -38.36978585404094,
           -38.4028174938425,
           -38.43584913364405,
           -38.4688807734456,
           -38.501912413247155,
           -38.534944053048704,
           -38.56797569285026,
           -38.60100733265181,
           -38.63403897245337,
           -38.66707061225492,
           -38.70064695238712,
           -38.73458642508587,
           -38.76852589778462,
           -38.802465370483375,
           -38.83640484318213,
           -38.870344315880885,
           -38.90428378857964,
           -38.938223261278395,
           -38.97216273397715,
           -39.006102206675905,
           -39.04004167937466,
           -38.99660050516322,
           -38.875778684041606,
           -38.754956862920004,
           -38.6341350417984,
           -38.51331322067678,
           -38.39249139955517,
           -38.27166957843357,
           -38.15084775731195,
           -38.03002593619034,
           -37.909204115068746,
           -37.78838229394713,
           -37.667560472825514,
           -37.546738651703905,
           -37.4259168305823,
           -37.305095009460686,
           -37.18427318833908,
           -37.06345136721747,
           -36.94262954609585,
           -36.82180772497425,
           -36.69004604066881,
           -36.55215139281911,
           -36.41425674496942,
           -36.276362097119744,
           -36.138467449270046,
           -36.00057280142034,
           -35.862678153570656,
           -35.72478350572097,
           -35.58688885787127,
           -35.44899421002158,
           -35.3110995621719,
           -35.1732049143222,
           -35.0353102664725,
           -34.89741561862283,
           -34.759520970773124,
           -34.621626322923426,
           -34.48373167507374,
           -34.34583702722406,
           -34.20794237937436,
           -34.07004773152467,
           -33.93215308367498,
           -33.794258435825284,
           -33.6563637879756,
           -33.518469140125916,
           -33.38057449227621,
           -33.24267984442652,
           -33.10478519657684,
           -32.96689054872714,
           -32.828995900877445,
           -32.69110125302776,
           -32.55320660517807,
           -32.41531195732837,
           -32.277417309478686,
           -32.139522661629,
           -32.0016280137793,
           -31.863733365929605,
           -31.72583871807993,
           -31.58794407023023,
           -31.45004942238053,
           -31.312154774530843,
           -31.174260126681155,
           -31.036365478831456,
           -30.898470830981772,
           -30.760576183132088,
           -30.622681535282386,
           -30.484786887432698,
           -30.346892239583013,
           -30.208997591733315,
           -30.071102943883616,
           -29.93320829603394,
           -29.795313648184244,
           -29.657419000334542,
           -29.519524352484858,
           -29.381629704635174,
           -29.243735056785475,
           -29.105840408935787,
           -28.9679457610861,
           -28.8300511132364,
           -28.692156465386713,
           -28.55426181753703,
           -28.41636716968733,
           -28.27847252183763,
           -28.140577873987944,
           -28.002683226138256,
           -27.89664285740365,
           -27.85431104689918,
           -27.811979236394713,
           -27.769647425890245,
           -27.727315615385777,
           -27.684983804881316,
           -27.64265199437685,
           -27.600320183872377,
           -27.557988373367913,
           -27.515656562863448,
           -27.473324752358984,
           -27.430992941854516,
           -27.388661131350048,
           -27.346329320845584,
           -27.30399751034112,
           -27.26166569983665,
           -27.219333889332184,
           -27.17700207882772,
           -27.134670268323255,
           -27.092338457818784,
           -27.050006647314312,
           -27.007674836809848,
           -26.965343026305383,
           -26.923011215800916,
           -26.880679405296455,
           -26.838347594791987,
           -26.796015784287523,
           -26.75368397378306,
           -26.71135216327859,
           -26.66902035277412,
           -26.626688542269655,
           -26.58435673176519,
           -26.542024921260722,
           -26.49969311075625,
           -26.45736130025179,
           -26.415029489747322,
           -26.372697679242854,
           -26.330365868738387,
           -26.288034058233926,
           -26.245702247729458,
           -26.20337043722499,
           -26.16103862672053,
           -26.118706816216058,
           -26.07637500571159,
           -26.034043195207126,
           -25.991711384702658,
           -25.94937957419819,
           -25.907047763693726,
           -25.86471595318926,
           -25.82238414268479,
           -25.78005233218033,
           -25.73772052167586,
           -25.695388711171393,
           -25.653056900666925,
           -25.610725090162465,
           -25.568393279657997,
           -25.526061469153525,
           -25.48372965864906,
           -25.441397848144597,
           -25.399066037640125,
           -25.356734227135664,
           -25.314402416631197,
           -25.272070606126732,
           -25.229738795622268,
           -25.1874069851178,
           -25.145075174613336,
           -25.10274336410886,
           -25.060411553604403,
           -25.018079743099936,
           -24.975747932595464,
           -24.933416122090996,
           -24.891084311586535,
           -24.84875250108206,
           -24.8064206905776,
           -24.764088880073135,
           -24.721757069568667,
           -24.6794252590642,
           -24.63709344855974,
           -24.594761638055267,
           -24.5524298275508,
           -24.510098017046335,
           -24.466798204557275,
           -24.422615503674503,
           -24.3509969928689,
           -24.14219943244907,
           -23.948153826983926,
           -23.75665935474432,
           -23.565164882504753,
           -23.37367041026515,
           -23.182175938025544,
           -22.990681465785975,
           -22.799186993546375,
           -22.607692521306767,
           -22.416198049067198,
           -22.224703576827594,
           -22.03320910458799,
           -21.841714632348385,
           -21.650220160108816,
           -21.458725687869215,
           -21.26723121562961,
           -21.075736743390042,
           -20.884242271150434,
           -20.692747798910833,
           -20.501253326671264,
           -20.30975885443166,
           -20.118264382192056,
           -19.926769909952487,
           -19.735275437712883,
           -19.54378096547328,
           -19.352286493233677,
           -19.16079202099411,
           -18.9692975487545,
           -18.777803076514896,
           -18.586308604275327,
           -18.394814132035727,
           -18.20331965979612,
           -18.01182518755655,
           -17.82033071531695,
           -17.628836243077345,
           -17.43734177083774,
           -17.24584729859817,
           -17.054352826358567,
           -16.862858354118963,
           -16.671363881879394,
           -16.47986940963979,
           -16.288374937400185,
           -16.096880465160616,
           -15.905385992921014,
           -15.71389152068141,
           -15.52239704844184,
           -15.330902576202234,
           -15.139408103962632,
           -14.947913631723027,
           -14.75641915948346,
           -14.564924687243856,
           -14.373430215004252,
           -14.181935742764683,
           -13.990441270525078,
           -13.798946798285476,
           -13.607452326045907,
           -13.415957853806303,
           -13.224463381566698,
           -13.032968909327094,
           -12.841474437087527,
           -12.649979964847923,
           -12.458485492608318,
           -12.26699102036875,
           -12.075496548129145,
           -11.88400207588954,
           -11.692507603649972,
           -11.501013131410367,
           -11.309518659170763,
           -11.118024186931196,
           -10.926529714691592,
           -10.735035242451987,
           -10.543540770212385,
           -10.352046297972816,
           -10.160551825733211,
           -9.969057353493607,
           -9.777562881254038,
           -9.586068409014434,
           -9.394573936774831,
           -9.203079464535262,
           -9.011584992295656,
           -8.820090520056054,
           -8.635882410934803,
           -8.467585182185342
          ],
          [
           -30.22560529764199,
           -30.261205326759974,
           -30.29680535587795,
           -30.33240538499593,
           -30.368005414113913,
           -30.403605443231896,
           -30.43920547234987,
           -30.474805501467852,
           -30.510405530585835,
           -30.546005559703815,
           -30.58160558882179,
           -30.617205617939774,
           -30.652805647057754,
           -30.688405676175734,
           -30.72400570529371,
           -30.759605734411693,
           -30.795205763529673,
           -30.830805792647652,
           -30.866405821765632,
           -30.90200585088361,
           -30.93760588000159,
           -30.97320590911957,
           -31.008805938237547,
           -31.044405967355534,
           -31.08000599647351,
           -31.11560602559149,
           -31.15120605470947,
           -31.18680608382745,
           -31.222406112945432,
           -31.258006142063408,
           -31.293606171181388,
           -31.32920620029937,
           -31.364806229417347,
           -31.400406258535327,
           -31.43600628765331,
           -31.47160631677129,
           -31.50720634588927,
           -31.542806375007245,
           -31.578406404125232,
           -31.612689886543716,
           -31.64631509297736,
           -31.679940299411005,
           -31.713565505844645,
           -31.74719071227829,
           -31.78081591871193,
           -31.81444112514557,
           -31.84806633157922,
           -31.88169153801286,
           -31.9153167444465,
           -31.948941950880148,
           -31.982567157313788,
           -32.016192363747436,
           -32.04981757018108,
           -32.08344277661472,
           -32.117067983048365,
           -32.150693189482006,
           -32.18431839591565,
           -32.217943602349294,
           -32.251568808782935,
           -32.28519401521658,
           -32.31881922165022,
           -32.352444428083864,
           -32.386069634517504,
           -32.41969484095115,
           -32.45332004738479,
           -32.48694525381844,
           -32.52057046025208,
           -32.55419566668572,
           -32.58782087311937,
           -32.62144607955301,
           -32.65507128598665,
           -32.68869649242029,
           -32.72232169885394,
           -32.75594690528759,
           -32.78957211172123,
           -32.82319731815487,
           -32.85682252458851,
           -32.89044773102216,
           -32.9240729374558,
           -32.95769814388944,
           -32.991323350323086,
           -33.024948556756726,
           -33.05857376319037,
           -33.092198969624015,
           -33.12469762980807,
           -33.1569709807422,
           -33.189244331676335,
           -33.221517682610475,
           -33.253791033544616,
           -33.28606438447875,
           -33.31833773541288,
           -33.35061108634702,
           -33.38288443728116,
           -33.415157788215296,
           -33.44743113914943,
           -33.47970449008357,
           -33.51197784101771,
           -33.544251191951844,
           -33.57652454288598,
           -33.60879789382012,
           -33.64107124475426,
           -33.67334459568839,
           -33.70561794662253,
           -33.737891297556665,
           -33.770164648490805,
           -33.80243799942494,
           -33.83471135035908,
           -33.86698470129321,
           -33.89925805222735,
           -33.931531403161486,
           -33.96380475409562,
           -33.99607810502976,
           -34.0283514559639,
           -34.06062480689803,
           -34.092898157832174,
           -34.12517150876631,
           -34.15744485970044,
           -34.18971821063458,
           -34.221991561568714,
           -34.254264912502855,
           -34.286538263436995,
           -34.31881161437113,
           -34.35108496530527,
           -34.3833583162394,
           -34.41563166717354,
           -34.447905018107676,
           -34.480178369041816,
           -34.51245171997595,
           -34.54472507232336,
           -34.57858714226252,
           -34.612449212201675,
           -34.646311282140836,
           -34.68017335207999,
           -34.71403542201915,
           -34.74789749195831,
           -34.781759561897466,
           -34.81562163183663,
           -34.84948370177578,
           -34.88334577171494,
           -34.9172078416541,
           -34.95106991159326,
           -34.98493198153241,
           -35.01879405147158,
           -35.052656121410735,
           -35.086518191349896,
           -35.12038026128905,
           -35.15424233122821,
           -35.188104401167365,
           -35.221966471106526,
           -35.25582854104569,
           -35.28969061098484,
           -35.323552680924,
           -35.357414750863164,
           -35.39127682080232,
           -35.42513889074148,
           -35.45900096068064,
           -35.492863030619795,
           -35.526725100558956,
           -35.56058717049811,
           -35.59444924043727,
           -35.628311310376425,
           -35.662173380315586,
           -35.69603545025475,
           -35.7298975201939,
           -35.76375959013306,
           -35.797621660072224,
           -35.83148373001138,
           -35.8647921798588,
           -35.89782381966036,
           -35.93085545946191,
           -35.96388709926346,
           -35.99691873906501,
           -36.029950378866566,
           -36.062982018668116,
           -36.09601365846967,
           -36.12904529827122,
           -36.16207693807277,
           -36.19510857787433,
           -36.228140217675886,
           -36.261171857477436,
           -36.294203497278986,
           -36.327235137080535,
           -36.360266776882085,
           -36.39329841668364,
           -36.4263300564852,
           -36.45936169628675,
           -36.4923933360883,
           -36.52542497588985,
           -36.558456615691405,
           -36.59148825549296,
           -36.62451989529451,
           -36.65755153509606,
           -36.69058317489761,
           -36.72361481469917,
           -36.756646454500725,
           -36.789678094302275,
           -36.822709734103825,
           -36.855741373905374,
           -36.88877301370694,
           -36.92180465350848,
           -36.95483629331003,
           -36.98786793311159,
           -37.02089957291314,
           -37.0539312127147,
           -37.08696285251625,
           -37.119994492317794,
           -37.15302613211935,
           -37.1860577719209,
           -37.21908941172246,
           -37.25212105152401,
           -37.28515269132556,
           -37.318184331127114,
           -37.35121597092867,
           -37.38424761073021,
           -37.41727925053177,
           -37.45031089033332,
           -37.48334253013488,
           -37.51663355099653,
           -37.550573023695286,
           -37.58451249639404,
           -37.61845196909279,
           -37.65239144179155,
           -37.6863309144903,
           -37.72027038718906,
           -37.75420985988781,
           -37.78814933258657,
           -37.82208880528532,
           -37.85602827798407,
           -37.88996775068283,
           -37.92390722338158,
           -37.95784669608034,
           -37.99178616877909,
           -38.02572564147785,
           -38.0596651141766,
           -38.09360458687536,
           -38.127544059574106,
           -38.16148353227287,
           -38.19542300497162,
           -38.22936247767038,
           -38.26330195036913,
           -38.29724142306788,
           -38.331180895766636,
           -38.36512036846539,
           -38.39905984116414,
           -38.4329993138629,
           -38.466938786561656,
           -38.50087825926041,
           -38.53481773195916,
           -38.56875720465792,
           -38.602696677356676,
           -38.55925550314524,
           -38.43843368202362,
           -38.31761186090202,
           -38.19679003978041,
           -38.075968218658794,
           -37.95514639753719,
           -37.83432457641558,
           -37.71350275529396,
           -37.59268093417235,
           -37.471859113050755,
           -37.35103729192914,
           -37.23021547080752,
           -37.10939364968591,
           -36.98857182856431,
           -36.867750007442694,
           -36.74692818632109,
           -36.626106365199476,
           -36.50528454407787,
           -36.38446272295626,
           -36.263640901834655,
           -36.14281908071304,
           -36.02199725959142,
           -35.90117543846983,
           -35.78035361734821,
           -35.659531796226595,
           -35.53870997510499,
           -35.417888153983384,
           -35.29706633286176,
           -35.176244511740165,
           -35.055422690618556,
           -34.93460086949694,
           -34.813779048375324,
           -34.69295722725373,
           -34.57213540613211,
           -34.451313585010496,
           -34.33049176388889,
           -34.209669942767285,
           -34.08884812164567,
           -33.968026300524066,
           -33.84720447940245,
           -33.72638265828084,
           -33.60556083715923,
           -33.48473901603763,
           -33.36391719491601,
           -33.2430953737944,
           -33.122273552672794,
           -33.001451731551185,
           -32.88062991042956,
           -32.75980808930797,
           -32.63898626818636,
           -32.51816444706474,
           -32.39734262594313,
           -32.27652080482152,
           -32.155698983699914,
           -32.0348771625783,
           -31.9140553414567,
           -31.779641531529897,
           -31.641746883680195,
           -31.503852235830507,
           -31.365957587980823,
           -31.228062940131124,
           -31.09016829228144,
           -30.952273644431752,
           -30.81437899658205,
           -30.676484348732366,
           -30.538589700882678,
           -30.40069505303298,
           -30.262800405183285,
           -30.124905757333607,
           -29.98701110948391,
           -29.84911646163421,
           -29.711221813784523,
           -29.57332716593484,
           -29.435432518085136,
           -29.297537870235455,
           -29.159643222385768,
           -29.02174857453607,
           -28.883853926686385,
           -28.745959278836697,
           -28.608064630986995,
           -28.470169983137296,
           -28.332275335287612,
           -28.194380687437924,
           -28.08834031870331,
           -28.046008508198845,
           -28.00367669769438,
           -27.961344887189913,
           -27.919013076685445,
           -27.876681266180984,
           -27.834349455676513,
           -27.79201764517204,
           -27.749685834667584,
           -27.707354024163113,
           -27.665022213658645,
           -27.622690403154184,
           -27.580358592649716,
           -27.538026782145252,
           -27.495694971640784,
           -27.453363161136323,
           -27.411031350631852,
           -27.368699540127388,
           -27.32636772962292,
           -27.284035919118452,
           -27.24170410861398,
           -27.19937229810952,
           -27.15704048760505,
           -27.114708677100587,
           -27.07237686659612,
           -27.030045056091655,
           -26.98771324558719,
           -26.945381435082723,
           -26.90304962457826,
           -26.860717814073787,
           -26.81838600356932,
           -26.776054193064855,
           -26.733722382560387,
           -26.69139057205592,
           -26.64905876155146,
           -26.60672695104699,
           -26.56451382658007,
           -26.523917896193034,
           -26.483321965806,
           -26.442726035418957,
           -26.402130105031922,
           -26.361534174644888,
           -26.320938244257846,
           -26.28034231387081,
           -26.239746383483773,
           -26.19915045309674,
           -26.158554522709696,
           -26.11795859232266,
           -26.077362661935627,
           -26.03676673154859,
           -25.996170801161554,
           -25.955574870774516,
           -25.914978940387478,
           -25.874383010000436,
           -25.83378707961341,
           -25.793191149226363,
           -25.752595218839325,
           -25.71199928845229,
           -25.671403358065255,
           -25.630807427678214,
           -25.590211497291182,
           -25.549615566904144,
           -25.509019636517106,
           -25.468423706130068,
           -25.427827775743033,
           -25.387231845355995,
           -25.346635914968957,
           -25.306039984581922,
           -25.265444054194884,
           -25.224848123807845,
           -25.184252193420807,
           -25.143656263033776,
           -25.103060332646734,
           -25.062464402259696,
           -25.02186847187266,
           -24.98127254148562,
           -24.940676611098585,
           -24.900080680711554,
           -24.859484750324512,
           -24.81888881993747,
           -24.778292889550436,
           -24.7376969591634,
           -24.697101028776363,
           -24.628118799965467,
           -24.417205079035224,
           -24.206291358104988,
           -23.995377637174748,
           -23.784463916244547,
           -23.573550195314315,
           -23.36263647438407,
           -23.15172275345388,
           -22.940809032523635,
           -22.729895311593403,
           -22.5189815906632,
           -22.308067869732962,
           -22.097154148802726,
           -21.88624042787249,
           -21.67532670694229,
           -21.464412986012054,
           -21.253499265081814,
           -21.042585544151617,
           -20.831671823221377,
           -20.620758102291138,
           -20.40984438136094,
           -20.198930660430705,
           -19.98801693950046,
           -19.777103218570268,
           -19.566189497640025,
           -19.363979450141855,
           -19.17248497790225,
           -18.98099050566268,
           -18.789496033423077,
           -18.598001561183473,
           -18.406507088943904,
           -18.2150126167043,
           -18.023518144464695,
           -17.832023672225127,
           -17.640529199985526,
           -17.44903472774592,
           -17.257540255506317,
           -17.06604578326675,
           -16.874551311027144,
           -16.68305683878754,
           -16.49156236654797,
           -16.30006789430837,
           -16.108573422068766,
           -15.917078949829195,
           -15.72558447758959,
           -15.534090005349986,
           -15.342595533110417,
           -15.151101060870813,
           -14.95960658863121,
           -14.768112116391608,
           -14.576617644152039,
           -14.385123171912435,
           -14.193628699672828,
           -14.00213422743326,
           -13.810639755193655,
           -13.619145282954051,
           -13.427650810714484,
           -13.23615633847488,
           -13.044661866235277,
           -12.862336393302058,
           -12.683603789495358,
           -12.504871185688625,
           -12.326138581881892,
           -12.147405978075192,
           -11.968673374268459,
           -11.789940770461726,
           -11.611208166655027,
           -11.432475562848293,
           -11.253742959041562,
           -11.075010355234863,
           -10.89627775142813,
           -10.717545147621397,
           -10.538812543814663,
           -10.360079940007964,
           -10.181347336201231,
           -10.002614732394498,
           -9.8238821285878,
           -9.645149524781065,
           -9.466416920974334,
           -9.287684317167633,
           -9.108951713360902,
           -8.930219109554168,
           -8.751486505747435,
           -8.572753901940736
          ],
          [
           -29.82737172961851,
           -29.862971758736492,
           -29.89857178785447,
           -29.934171816972448,
           -29.96977184609043,
           -30.00537187520841,
           -30.040971904326387,
           -30.07657193344437,
           -30.11217196256235,
           -30.14777199168033,
           -30.18337202079831,
           -30.21897204991629,
           -30.25457207903427,
           -30.290172108152248,
           -30.325772137270228,
           -30.361372166388207,
           -30.396972195506187,
           -30.43257222462417,
           -30.468172253742146,
           -30.503772282860126,
           -30.53937231197811,
           -30.574972341096085,
           -30.610243234530895,
           -30.64386844096454,
           -30.677493647398183,
           -30.711118853831824,
           -30.744744060265468,
           -30.778369266699112,
           -30.811994473132756,
           -30.845619679566397,
           -30.87924488600004,
           -30.912870092433685,
           -30.94649529886733,
           -30.980120505300974,
           -31.013745711734618,
           -31.047370918168262,
           -31.080996124601903,
           -31.114621331035544,
           -31.14824653746919,
           -31.181871743902832,
           -31.215496950336473,
           -31.249122156770117,
           -31.28274736320376,
           -31.316372569637405,
           -31.349997776071046,
           -31.38362298250469,
           -31.417248188938334,
           -31.450873395371975,
           -31.48449860180562,
           -31.518123808239263,
           -31.551749014672904,
           -31.58537422110655,
           -31.61899942754019,
           -31.65262463397383,
           -31.686249840407477,
           -31.719875046841118,
           -31.753500253274765,
           -31.787125459708406,
           -31.820750666142047,
           -31.854375872575694,
           -31.888001079009335,
           -31.921626285442983,
           -31.95525149187662,
           -31.98887669831026,
           -32.022501904743905,
           -32.05612711117756,
           -32.08975231761119,
           -32.123377524044834,
           -32.15700273047848,
           -32.19062793691212,
           -32.22425314334577,
           -32.25787834977941,
           -32.29150355621305,
           -32.3251287626467,
           -32.35875396908034,
           -32.39237917551399,
           -32.42600438194763,
           -32.45962958838127,
           -32.493254794814916,
           -32.52688000124856,
           -32.5605052076822,
           -32.594130414115845,
           -32.62775562054948,
           -32.661380826983134,
           -32.69387948716718,
           -32.726152838101314,
           -32.75842618903545,
           -32.79069953996959,
           -32.82297289090373,
           -32.85524624183786,
           -32.887519592772,
           -32.91979294370614,
           -32.952066294640275,
           -32.98433964557441,
           -33.01661299650855,
           -33.04888634744268,
           -33.08115969837682,
           -33.113433049310956,
           -33.145706400245096,
           -33.17797975117924,
           -33.21025310211337,
           -33.2425264530475,
           -33.274799803981644,
           -33.307073154915784,
           -33.33934650584992,
           -33.37161985678405,
           -33.40389320771819,
           -33.436166558652324,
           -33.468439909586465,
           -33.5007132605206,
           -33.53298661145474,
           -33.56525996238888,
           -33.59753331332301,
           -33.62980666425715,
           -33.662080015191286,
           -33.694353366125426,
           -33.72662671705956,
           -33.75890006799369,
           -33.79117341892783,
           -33.82344676986197,
           -33.85572012079611,
           -33.88799347173024,
           -33.920266822664374,
           -33.952540173598514,
           -33.984813524532655,
           -34.017086875466795,
           -34.04936022640093,
           -34.08163357733507,
           -34.1139069282692,
           -34.14618027920334,
           -34.178453630137476,
           -34.210726981071616,
           -34.24300033200575,
           -34.27527368293988,
           -34.30754703387402,
           -34.33982038480816,
           -34.3720937357423,
           -34.40436708667643,
           -34.43664043761057,
           -34.468913788544704,
           -34.501187139478844,
           -34.533460490412985,
           -34.56573384134712,
           -34.59800719228125,
           -34.63028054321539,
           -34.663348254803175,
           -34.697210324742336,
           -34.73107239468149,
           -34.764934464620644,
           -34.798796534559806,
           -34.83265860449896,
           -34.86652067443812,
           -34.90038274437728,
           -34.934244814316436,
           -34.9681068842556,
           -35.00196895419476,
           -35.03583102413392,
           -35.069693094073074,
           -35.103555164012235,
           -35.13741723395139,
           -35.17127930389055,
           -35.20514137382971,
           -35.239003443768866,
           -35.27286551370803,
           -35.30672758364719,
           -35.34058965358634,
           -35.374451723525496,
           -35.40776017337292,
           -35.44079181317447,
           -35.47382345297602,
           -35.50685509277758,
           -35.53988673257913,
           -35.572918372380684,
           -35.605950012182234,
           -35.63898165198379,
           -35.67201329178534,
           -35.7050449315869,
           -35.73807657138845,
           -35.771108211190004,
           -35.804139850991554,
           -35.837171490793104,
           -35.87020313059465,
           -35.90323477039621,
           -35.93626641019776,
           -35.96929804999932,
           -36.00232968980087,
           -36.035361329602416,
           -36.06839296940397,
           -36.10142460920552,
           -36.13445624900708,
           -36.16748788880864,
           -36.20051952861018,
           -36.23355116841173,
           -36.266582808213286,
           -36.29961444801484,
           -36.33264608781639,
           -36.366559622304706,
           -36.40049909500346,
           -36.434438567702216,
           -36.46837804040097,
           -36.502317513099726,
           -36.53625698579849,
           -36.570196458497236,
           -36.60413593119599,
           -36.638075403894746,
           -36.672014876593494,
           -36.705954349292256,
           -36.739893821991004,
           -36.77383329468976,
           -36.807772767388514,
           -36.84171224008727,
           -36.87565171278602,
           -36.90959118548478,
           -36.94353065818353,
           -36.97747013088229,
           -37.01140960358104,
           -37.0453490762798,
           -37.07928854897855,
           -37.1132280216773,
           -37.14716749437606,
           -37.18110696707481,
           -37.215046439773566,
           -37.24898591247232,
           -37.282925385171076,
           -37.31686485786983,
           -37.350804330568586,
           -37.38474380326734,
           -37.41868327596609,
           -37.45262274866485,
           -37.4865622213636,
           -37.52050169406236,
           -37.554441166761116,
           -37.588380639459864,
           -37.62232011215862,
           -37.656259584857374,
           -37.690199057556136,
           -37.72413853025488,
           -37.75807800295364,
           -37.7920174756524,
           -37.82595694835115,
           -37.8598964210499,
           -37.89383589374866,
           -37.92777536644741,
           -37.96171483914616,
           -37.995654311844916,
           -38.02959378454367,
           -38.06353325724243,
           -38.09747272994119,
           -38.131412202639936,
           -38.1653516753387,
           -38.12191050112725,
           -38.00108868000564,
           -37.88026685888404,
           -37.75944503776243,
           -37.638623216640816,
           -37.51780139551921,
           -37.396979574397605,
           -37.27615775327599,
           -37.15533593215437,
           -37.03451411103278,
           -36.91369228991116,
           -36.79287046878954,
           -36.672048647667935,
           -36.55122682654633,
           -36.43040500542472,
           -36.30958318430311,
           -36.188761363181506,
           -36.06793954205989,
           -35.94711772093828,
           -35.82629589981668,
           -35.70547407869506,
           -35.584652257573445,
           -35.46383043645185,
           -35.343008615330234,
           -35.22218679420861,
           -35.10136497308701,
           -34.980543151965406,
           -34.85972133084379,
           -34.73889950972218,
           -34.61807768860058,
           -34.497255867478955,
           -34.37643404635734,
           -34.25561222523575,
           -34.13479040411413,
           -34.01396858299252,
           -33.89314676187091,
           -33.77232494074931,
           -33.65150311962769,
           -33.53068129850608,
           -33.40985947738447,
           -33.28903765626286,
           -33.168215835141254,
           -33.04739401401965,
           -32.92657219289803,
           -32.80575037177641,
           -32.68492855065482,
           -32.56410672953321,
           -32.44328490841159,
           -32.32246308728998,
           -32.20164126616837,
           -32.08081944504676,
           -31.959997623925155,
           -31.839175802803553,
           -31.718353981681933,
           -31.597532160560316,
           -31.476710339438718,
           -31.355888518317105,
           -31.235066697195492,
           -31.114244876073883,
           -30.99342305495228,
           -30.872601233830657,
           -30.751779412709055,
           -30.63095759158745,
           -30.510135770465833,
           -30.389313949344228,
           -30.26849212822262,
           -30.147670307101002,
           -30.026848485979386,
           -29.90602666485779,
           -29.785204843736178,
           -29.66438302261456,
           -29.543561201492953,
           -29.422739380371347,
           -29.3140291903129,
           -29.207678467261662,
           -29.101327744210426,
           -28.99497702115918,
           -28.888626298107944,
           -28.782275575056705,
           -28.67592485200546,
           -28.569574128954212,
           -28.463223405902976,
           -28.356872682851737,
           -28.27297263316474,
           -28.233973930206226,
           -28.194975227247713,
           -28.15597652428919,
           -28.11697782133068,
           -28.077979118372163,
           -28.038980415413643,
           -27.999981712455128,
           -27.960983009496616,
           -27.9219843065381,
           -27.88298560357958,
           -27.843986900621065,
           -27.804988197662553,
           -27.765989494704034,
           -27.72699079174552,
           -27.68799208878701,
           -27.64899338582849,
           -27.60999468286997,
           -27.57099597991146,
           -27.530799347334945,
           -27.490203416947907,
           -27.449607486560872,
           -27.409011556173837,
           -27.368415625786795,
           -27.32781969539976,
           -27.287223765012726,
           -27.246627834625684,
           -27.206031904238646,
           -27.165435973851615,
           -27.124840043464573,
           -27.08424411307754,
           -27.043648182690504,
           -27.00305225230346,
           -26.962456321916427,
           -26.921860391529385,
           -26.88126446114235,
           -26.840668530755313,
           -26.80007260036828,
           -26.759476669981243,
           -26.7188807395942,
           -26.678284809207163,
           -26.637688878820136,
           -26.597092948433094,
           -26.556497018046052,
           -26.515901087659014,
           -26.475305157271983,
           -26.43470922688494,
           -26.394113296497906,
           -26.35351736611087,
           -26.31292143572383,
           -26.272325505336795,
           -26.23172957494976,
           -26.19113364456272,
           -26.15053771417568,
           -26.10994178378865,
           -26.069345853401607,
           -26.02874992301457,
           -25.98815399262753,
           -25.947558062240496,
           -25.906962131853458,
           -25.866366201466423,
           -25.82577027107939,
           -25.785174340692347,
           -25.744578410305316,
           -25.703982479918274,
           -25.663386549531236,
           -25.622790619144197,
           -25.582194688757166,
           -25.541598758370125,
           -25.501002827983086,
           -25.460406897596055,
           -25.419810967209017,
           -25.379215036821975,
           -25.33861910643494,
           -25.298023176047902,
           -25.257427245660864,
           -25.216831315273826,
           -25.176235384886798,
           -25.135639454499756,
           -25.095043524112715,
           -25.054447593725676,
           -25.013851663338645,
           -24.973255732951603,
           -24.904273504140704,
           -24.693359783210465,
           -24.48244606228023,
           -24.271532341349992,
           -24.060618620419795,
           -23.849704899489556,
           -23.638791178559316,
           -23.42787745762912,
           -23.21696373669888,
           -23.006050015768643,
           -22.795136294838443,
           -22.584222573908207,
           -22.373308852977967,
           -22.162395132047727,
           -21.951481411117534,
           -21.740567690187294,
           -21.529653969257055,
           -21.318740248326858,
           -21.107826527396618,
           -20.896912806466382,
           -20.685999085536185,
           -20.475085364605945,
           -20.26417164367571,
           -20.05325792274551,
           -19.84234420181527,
           -19.63143048088503,
           -19.420516759954797,
           -19.209603039024596,
           -18.998689318094357,
           -18.78777559716412,
           -18.579325767315964,
           -18.381983595888364,
           -18.18464142446077,
           -17.98729925303321,
           -17.789957081605614,
           -17.592614910178018,
           -17.39527273875042,
           -17.19793056732286,
           -17.000588395895264,
           -16.803246224467667,
           -16.605904053040106,
           -16.40856188161251,
           -16.211219710184913,
           -16.013877538757352,
           -15.816535367329756,
           -15.61919319590216,
           -15.421851024474599,
           -15.224508853047002,
           -15.027166681619406,
           -14.82982451019181,
           -14.632482338764248,
           -14.435140167336652,
           -14.237797995909055,
           -14.040455824481494,
           -13.861446280815924,
           -13.682713677009193,
           -13.503981073202493,
           -13.325248469395756,
           -13.146515865589025,
           -12.967783261782294,
           -12.789050657975595,
           -12.61031805416886,
           -12.431585450362128,
           -12.252852846555427,
           -12.074120242748696,
           -11.895387638941962,
           -11.716655035135265,
           -11.53792243132853,
           -11.359189827521796,
           -11.180457223715099,
           -11.001724619908366,
           -10.822992016101633,
           -10.644259412294899,
           -10.465526808488201,
           -10.286794204681467,
           -10.108061600874734,
           -9.929328997068035,
           -9.750596393261302,
           -9.57186378945457,
           -9.393131185647869,
           -9.214398581841138,
           -9.035665978034404,
           -8.85693337422767,
           -8.678200770420972
          ],
          [
           -29.42913816159502,
           -29.464738190713,
           -29.500338219830976,
           -29.53593824894896,
           -29.57153827806694,
           -29.60713830718492,
           -29.641421788951714,
           -29.675046995385358,
           -29.708672201819002,
           -29.742297408252647,
           -29.77592261468629,
           -29.80954782111993,
           -29.843173027553576,
           -29.876798233987216,
           -29.910423440420857,
           -29.9440486468545,
           -29.977673853288145,
           -30.01129905972179,
           -30.04492426615543,
           -30.078549472589074,
           -30.11217467902272,
           -30.145799885456363,
           -30.179425091890003,
           -30.213050298323648,
           -30.24667550475729,
           -30.280300711190932,
           -30.313925917624577,
           -30.34755112405822,
           -30.38117633049186,
           -30.414801536925502,
           -30.44842674335915,
           -30.48205194979279,
           -30.515677156226438,
           -30.54930236266008,
           -30.58292756909372,
           -30.616552775527367,
           -30.650177981961008,
           -30.68380318839465,
           -30.717428394828293,
           -30.751053601261937,
           -30.784678807695578,
           -30.81830401412922,
           -30.851929220562866,
           -30.88555442699651,
           -30.919179633430154,
           -30.952804839863795,
           -30.986430046297443,
           -31.020055252731076,
           -31.05368045916472,
           -31.087305665598365,
           -31.120930872032005,
           -31.154556078465653,
           -31.188181284899294,
           -31.221806491332934,
           -31.255431697766582,
           -31.289056904200223,
           -31.32268211063387,
           -31.35630731706751,
           -31.38993252350115,
           -31.4235577299348,
           -31.45718293636844,
           -31.490808142802088,
           -31.52443334923572,
           -31.558058555669366,
           -31.59168376210301,
           -31.625308968536658,
           -31.6589341749703,
           -31.69255938140394,
           -31.726184587837587,
           -31.759809794271227,
           -31.793435000704875,
           -31.827060207138516,
           -31.860685413572156,
           -31.894310620005804,
           -31.927935826439445,
           -31.961561032873092,
           -31.995186239306733,
           -32.028811445740374,
           -32.06243665217402,
           -32.09606185860766,
           -32.12968706504131,
           -32.16331227147494,
           -32.196937477908584,
           -32.23056268434223,
           -32.263061344526285,
           -32.295334695460426,
           -32.32760804639456,
           -32.35988139732869,
           -32.39215474826283,
           -32.424428099196966,
           -32.456701450131106,
           -32.48897480106524,
           -32.52124815199938,
           -32.55352150293352,
           -32.585794853867654,
           -32.61806820480179,
           -32.650341555735935,
           -32.68261490667007,
           -32.7148882576042,
           -32.74716160853834,
           -32.779434959472475,
           -32.811708310406615,
           -32.84398166134075,
           -32.87625501227489,
           -32.90852836320902,
           -32.94080171414316,
           -32.973075065077296,
           -33.00534841601143,
           -33.03762176694557,
           -33.0698951178797,
           -33.102168468813844,
           -33.13444181974798,
           -33.16671517068212,
           -33.19898852161626,
           -33.23126187255039,
           -33.26353522348453,
           -33.295808574418665,
           -33.3280819253528,
           -33.36035527628694,
           -33.39262862722107,
           -33.42490197815521,
           -33.45717532908935,
           -33.489448680023486,
           -33.52172203095762,
           -33.55399538189176,
           -33.5862687328259,
           -33.61854208376003,
           -33.650815434694174,
           -33.68308878562831,
           -33.71536213656245,
           -33.74763548749658,
           -33.77990883843072,
           -33.812182189364854,
           -33.844455540298995,
           -33.87672889123313,
           -33.90900224216726,
           -33.9412755931014,
           -33.97354894403554,
           -34.005822294969676,
           -34.03809564590381,
           -34.07036899683795,
           -34.10264234777209,
           -34.13491569870622,
           -34.16718904964036,
           -34.1994624005745,
           -34.23173575150864,
           -34.26400910244277,
           -34.29628245337691,
           -34.328555804311044,
           -34.360829155245185,
           -34.39310250617932,
           -34.42537585711346,
           -34.45764920804759,
           -34.489922558981725,
           -34.522195909915865,
           -34.55446926085,
           -34.58674261178413,
           -34.61901596271827,
           -34.65128931365241,
           -34.683562664586546,
           -34.715836015520686,
           -34.748109367343815,
           -34.78197143728298,
           -34.81583350722213,
           -34.8496955771613,
           -34.88355764710045,
           -34.917419717039614,
           -34.95072816688703,
           -34.983759806688575,
           -35.01679144649014,
           -35.04982308629169,
           -35.082854726093245,
           -35.115886365894795,
           -35.148918005696345,
           -35.182546220914126,
           -35.21648569361288,
           -35.25042516631163,
           -35.284364639010384,
           -35.31830411170914,
           -35.352243584407894,
           -35.38618305710665,
           -35.420122529805404,
           -35.45406200250416,
           -35.48800147520291,
           -35.52194094790167,
           -35.555880420600424,
           -35.58981989329918,
           -35.62375936599793,
           -35.65769883869668,
           -35.69163831139544,
           -35.7255777840942,
           -35.75951725679295,
           -35.7934567294917,
           -35.82739620219046,
           -35.86133567488921,
           -35.89527514758797,
           -35.92921462028672,
           -35.96315409298548,
           -35.99709356568423,
           -36.031033038382986,
           -36.064972511081734,
           -36.098911983780496,
           -36.132851456479244,
           -36.166790929178006,
           -36.200730401876754,
           -36.23466987457551,
           -36.268609347274264,
           -36.30254881997301,
           -36.336488292671774,
           -36.37042776537053,
           -36.404367238069284,
           -36.43830671076804,
           -36.472246183466794,
           -36.50618565616554,
           -36.5401251288643,
           -36.57406460156305,
           -36.608004074261814,
           -36.64194354696056,
           -36.67588301965931,
           -36.70982249235807,
           -36.74376196505683,
           -36.77770143775558,
           -36.81164091045433,
           -36.84558038315309,
           -36.87951985585184,
           -36.9134593285506,
           -36.94739880124935,
           -36.98133827394811,
           -37.01527774664686,
           -37.04921721934562,
           -37.08315669204437,
           -37.117096164743124,
           -37.15103563744188,
           -37.184975110140634,
           -37.21891458283939,
           -37.252854055538144,
           -37.2867935282369,
           -37.320733000935654,
           -37.35467247363441,
           -37.388611946333164,
           -37.42255141903191,
           -37.45649089173067,
           -37.49043036442942,
           -37.52436983712818,
           -37.55830930982693,
           -37.59224878252569,
           -37.62618825522444,
           -37.6601277279232,
           -37.69406720062195,
           -37.72800667332071,
           -37.684565499109276,
           -37.56374367798766,
           -37.44292185686605,
           -37.32210003574444,
           -37.20127821462283,
           -37.08045639350122,
           -36.95963457237962,
           -36.838812751258,
           -36.71799093013639,
           -36.59716910901479,
           -36.47634728789317,
           -36.35552546677156,
           -36.23470364564995,
           -36.11388182452834,
           -35.99306000340673,
           -35.87223818228512,
           -35.751416361163514,
           -35.630594540041905,
           -35.509772718920296,
           -35.38895089779869,
           -35.26812907667707,
           -35.147307255555454,
           -35.026485434433866,
           -34.90566361331224,
           -34.784841792190626,
           -34.664019971069024,
           -34.543198149947415,
           -34.4223763288258,
           -34.301554507704196,
           -34.18073268658259,
           -34.05991086546098,
           -33.94034737066612,
           -33.83399664761489,
           -33.727645924563646,
           -33.621295201512396,
           -33.51494447846115,
           -33.408593755409925,
           -33.302243032358675,
           -33.19589230930743,
           -33.0895415862562,
           -32.98319086320495,
           -32.87684014015372,
           -32.770489417102475,
           -32.66413869405123,
           -32.55778797099998,
           -32.45143724794876,
           -32.34508652489751,
           -32.23873580184626,
           -32.132385078795025,
           -32.02603435574379,
           -31.919683632692543,
           -31.813332909641304,
           -31.706982186590068,
           -31.600631463538818,
           -31.494280740487575,
           -31.387930017436343,
           -31.281579294385097,
           -31.175228571333847,
           -31.068877848282614,
           -30.96252712523138,
           -30.856176402180125,
           -30.749825679128893,
           -30.643474956077657,
           -30.53712423302641,
           -30.43077350997517,
           -30.324422786923936,
           -30.21807206387269,
           -30.11172134082144,
           -30.005370617770215,
           -29.89901989471897,
           -29.79266917166772,
           -29.68631844861648,
           -29.579967725565247,
           -29.473617002513997,
           -29.367266279462758,
           -29.260915556411526,
           -29.154564833360276,
           -29.04821411030904,
           -28.941863387257804,
           -28.835512664206554,
           -28.729161941155304,
           -28.62281121810407,
           -28.516460495052833,
           -28.432560445365834,
           -28.39356174240732,
           -28.354563039448806,
           -28.31556433649029,
           -28.276565633531774,
           -28.23756693057326,
           -28.198568227614743,
           -28.15956952465622,
           -28.12057082169771,
           -28.081572118739196,
           -28.04257341578068,
           -28.003574712822164,
           -27.96457600986365,
           -27.92557730690513,
           -27.886578603946614,
           -27.8475799009881,
           -27.808581198029582,
           -27.76958249507107,
           -27.730583792112558,
           -27.69158508915404,
           -27.652586386195523,
           -27.613587683237007,
           -27.57458898027849,
           -27.535590277319972,
           -27.49659157436146,
           -27.457592871402944,
           -27.418594168444425,
           -27.379595465485913,
           -27.340596762527397,
           -27.30159805956888,
           -27.262599356610362,
           -27.22360065365185,
           -27.18460195069333,
           -27.145603247734815,
           -27.1066045447763,
           -27.067605841817787,
           -27.028607138859268,
           -26.989608435900756,
           -26.95060973294224,
           -26.911611029983725,
           -26.872612327025205,
           -26.833613624066693,
           -26.794614921108174,
           -26.755616218149658,
           -26.716617515191142,
           -26.677618812232627,
           -26.63862010927411,
           -26.599621406315592,
           -26.560622703357083,
           -26.521624000398564,
           -26.482625297440045,
           -26.443626594481533,
           -26.404627891523017,
           -26.365629188564498,
           -26.326630485605993,
           -26.287631782647466,
           -26.248633079688954,
           -26.209634376730442,
           -26.17063567377192,
           -26.131636970813403,
           -26.09263826785489,
           -26.053639564896375,
           -26.01464086193786,
           -25.975642158979344,
           -25.936643456020832,
           -25.897644753062313,
           -25.858646050103793,
           -25.819647347145285,
           -25.780648644186765,
           -25.741649941228246,
           -25.702651238269734,
           -25.663652535311215,
           -25.624653832352703,
           -25.585655129394187,
           -25.54665642643567,
           -25.507657723477152,
           -25.468659020518636,
           -25.429660317560128,
           -25.39106726069697,
           -25.353179679221242,
           -25.315292097745512,
           -25.27740451626979,
           -25.239516934794054,
           -25.173188874070217,
           -24.964658417105788,
           -24.75612796014136,
           -24.54813028896392,
           -24.35078811753636,
           -24.153445946108764,
           -23.956103774681168,
           -23.758761603253607,
           -23.561419431826007,
           -23.364077260398414,
           -23.166735088970853,
           -22.969392917543253,
           -22.77205074611566,
           -22.574708574688064,
           -22.377366403260503,
           -22.180024231832906,
           -21.98268206040531,
           -21.78533988897775,
           -21.587997717550152,
           -21.390655546122552,
           -21.193313374694995,
           -20.9959712032674,
           -20.798629031839802,
           -20.601286860412237,
           -20.403944688984648,
           -20.206602517557048,
           -20.009260346129455,
           -19.811918174701894,
           -19.614576003274294,
           -19.417233831846698,
           -19.219891660419137,
           -19.02254948899154,
           -18.825207317563944,
           -18.627865146136386,
           -18.430522974708786,
           -18.233180803281194,
           -18.035838631853593,
           -17.838496460426036,
           -17.64115428899844,
           -17.44381211757084,
           -17.24646994614328,
           -17.049127774715682,
           -16.851785603288086,
           -16.654443431860525,
           -16.457101260432932,
           -16.259759089005335,
           -16.062416917577774,
           -15.865074746150176,
           -15.66773257472258,
           -15.470390403294981,
           -15.273048231867422,
           -15.075706060439826,
           -14.878363889012231,
           -14.68102171758467,
           -14.483679546157072,
           -14.286337374729476,
           -14.088995203301915,
           -13.891653031874318,
           -13.694310860446722,
           -13.496968689019125,
           -13.299626517591564,
           -13.102284346163966,
           -12.90494217473637,
           -12.70760000330881,
           -12.510257831881212,
           -12.312915660453617,
           -12.11557348902606,
           -11.918231317598462,
           -11.720889146170865,
           -11.523546974743304,
           -11.326204803315708,
           -11.128862631888113,
           -10.931520460460517,
           -10.734178289032956,
           -10.53683611760536,
           -10.339493946177761,
           -10.142151774750202,
           -9.944809603322604,
           -9.747467431895007,
           -9.550125260467448,
           -9.353693779719029,
           -9.164001469068715,
           -8.9743091584184,
           -8.784616847768122
          ],
          [
           -29.023191177763195,
           -29.054751308398842,
           -29.08631143903449,
           -29.11787156967014,
           -29.149431700305787,
           -29.180991830941434,
           -29.21255196157708,
           -29.24411209221273,
           -29.275672222848378,
           -29.307232353484025,
           -29.338792484119672,
           -29.37035261475532,
           -29.403633642704104,
           -29.43725884913775,
           -29.47088405557139,
           -29.504509262005033,
           -29.538134468438678,
           -29.57175967487232,
           -29.605384881305962,
           -29.639010087739607,
           -29.672635294173247,
           -29.706260500606895,
           -29.739885707040536,
           -29.773510913474176,
           -29.80713611990782,
           -29.84076132634146,
           -29.874386532775105,
           -29.90801173920875,
           -29.941636945642394,
           -29.975262152076034,
           -30.00888735850968,
           -30.042512564943323,
           -30.076137771376967,
           -30.10976297781061,
           -30.14338818424425,
           -30.177013390677892,
           -30.21063859711154,
           -30.24426380354518,
           -30.27788900997883,
           -30.31151421641247,
           -30.34513942284611,
           -30.378764629279758,
           -30.412389835713398,
           -30.44601504214704,
           -30.479640248580683,
           -30.513265455014327,
           -30.546890661447968,
           -30.580515867881616,
           -30.614141074315256,
           -30.647766280748897,
           -30.681391487182545,
           -30.715016693616185,
           -30.748641900049826,
           -30.78226710648347,
           -30.815892312917118,
           -30.84951751935076,
           -30.883142725784403,
           -30.916767932218043,
           -30.950393138651688,
           -30.984018345085328,
           -31.01764355151897,
           -31.051268757952617,
           -31.084893964386257,
           -31.118519170819898,
           -31.152144377253546,
           -31.18576958368719,
           -31.21939479012083,
           -31.253019996554475,
           -31.28664520298812,
           -31.320270409421763,
           -31.353895615855407,
           -31.387520822289048,
           -31.421146028722692,
           -31.454771235156336,
           -31.488396441589977,
           -31.52202164802362,
           -31.555646854457265,
           -31.589272060890906,
           -31.622897267324547,
           -31.65652247375819,
           -31.690147680191835,
           -31.723772886625476,
           -31.75739809305912,
           -31.791023299492764,
           -31.823521959676818,
           -31.855795310610958,
           -31.88806866154509,
           -31.920342012479228,
           -31.952615363413365,
           -31.9848887143475,
           -32.01716206528164,
           -32.04943541621577,
           -32.08170876714991,
           -32.113982118084046,
           -32.146255469018186,
           -32.17852881995232,
           -32.21080217088647,
           -32.2430755218206,
           -32.27534887275473,
           -32.307622223688874,
           -32.339895574623014,
           -32.37216892555715,
           -32.40444227649128,
           -32.43671562742542,
           -32.468988978359555,
           -32.501262329293695,
           -32.53353568022783,
           -32.56580903116196,
           -32.5980823820961,
           -32.63035573303024,
           -32.662629083964376,
           -32.69490243489851,
           -32.72717578583265,
           -32.75944913676679,
           -32.79172248770092,
           -32.823995838635064,
           -32.8562691895692,
           -32.88854254050333,
           -32.92081589143747,
           -32.953089242371604,
           -32.98536259330575,
           -33.017635944239885,
           -33.04990929517402,
           -33.08218264610815,
           -33.11445599704229,
           -33.14672934797643,
           -33.179002698910566,
           -33.2112760498447,
           -33.24354940077884,
           -33.27582275171298,
           -33.30809610264711,
           -33.34036945358125,
           -33.37264280451539,
           -33.40491615544953,
           -33.43718950638366,
           -33.469462857317794,
           -33.501736208251934,
           -33.53400955918607,
           -33.56628291012021,
           -33.59855626105434,
           -33.63082961198848,
           -33.663102962922615,
           -33.695376313856755,
           -33.72764966479089,
           -33.75992301572503,
           -33.79219636665916,
           -33.8244697175933,
           -33.856743068527436,
           -33.88901641946157,
           -33.92128977039572,
           -33.95356312132985,
           -33.98583647226399,
           -34.018109823198124,
           -34.05038317413226,
           -34.0826565250664,
           -34.11492987600053,
           -34.14569707747956,
           -34.17616304821181,
           -34.206629018944064,
           -34.23709498967631,
           -34.26756096040856,
           -34.29802693114081,
           -34.328492901873055,
           -34.35895887260531,
           -34.38942484333756,
           -34.41989081406981,
           -34.450356784802054,
           -34.48326554349826,
           -34.51739569617644,
           -34.551525848854624,
           -34.585656001532804,
           -34.619786154210985,
           -34.653916306889165,
           -34.68804645956735,
           -34.722176612245526,
           -34.756306764923714,
           -34.79043691760189,
           -34.824567070280075,
           -34.858697222958256,
           -34.892827375636436,
           -34.92695752831462,
           -34.9610876809928,
           -34.99521783367098,
           -35.029347986349165,
           -35.063478139027346,
           -35.09760829170553,
           -35.13173844438371,
           -35.16586859706189,
           -35.19999874974007,
           -35.23412890241825,
           -35.268259055096436,
           -35.30238920777461,
           -35.3365193604528,
           -35.37064951313098,
           -35.40477966580916,
           -35.43890981848734,
           -35.47303997116553,
           -35.50717012384371,
           -35.54130027652189,
           -35.57543042920007,
           -35.60956058187825,
           -35.64369073455643,
           -35.67782088723462,
           -35.71195103991279,
           -35.74608119259098,
           -35.78021134526915,
           -35.81434149794734,
           -35.84847165062552,
           -35.88260180330369,
           -35.91673195598188,
           -35.95086210866007,
           -35.98499226133824,
           -36.01912241401642,
           -36.0532525666946,
           -36.08738271937278,
           -36.12151287205097,
           -36.15564302472916,
           -36.18977317740733,
           -36.22390333008552,
           -36.25803348276369,
           -36.292163635441874,
           -36.32629378812006,
           -36.36042394079824,
           -36.39455409347642,
           -36.42868424615461,
           -36.46281439883278,
           -36.496944551510964,
           -36.531074704189145,
           -36.565204856867325,
           -36.59933500954551,
           -36.63346516222369,
           -36.667595314901874,
           -36.701725467580054,
           -36.735855620258235,
           -36.769985772936415,
           -36.8041159256146,
           -36.838246078292784,
           -36.872376230970964,
           -36.906506383649145,
           -36.940636536327325,
           -36.974766689005506,
           -37.008896841683686,
           -37.043026994361874,
           -37.077157147040054,
           -37.111287299718235,
           -37.145417452396416,
           -37.17875250339344,
           -37.21190047111765,
           -37.24504843884186,
           -37.27819640656607,
           -37.24536815215477,
           -37.14656367560796,
           -37.04775919906116,
           -36.94895472251437,
           -36.850150245967555,
           -36.75134576942076,
           -36.65254129287396,
           -36.55373681632716,
           -36.454932339780356,
           -36.35612786323356,
           -36.25732338668676,
           -36.158518910139954,
           -36.05971443359316,
           -35.960909957046354,
           -35.86210548049955,
           -35.763301003952755,
           -35.66449652740596,
           -35.56569205085915,
           -35.46688757431235,
           -35.36808309776555,
           -35.269278621218746,
           -35.16344241337962,
           -35.05709169032839,
           -34.95074096727715,
           -34.8443902442259,
           -34.73803952117466,
           -34.63168879812343,
           -34.525338075072185,
           -34.41898735202094,
           -34.312636628969706,
           -34.206285905918456,
           -34.09993518286721,
           -33.993584459815985,
           -33.887233736764735,
           -33.78088301371349,
           -33.67453229066225,
           -33.56818156761102,
           -33.46183084455977,
           -33.35548012150853,
           -33.24912939845729,
           -33.14277867540605,
           -33.03642795235481,
           -32.93007722930358,
           -32.82372650625233,
           -32.71737578320108,
           -32.611025060149856,
           -32.504674337098606,
           -32.39832361404736,
           -32.29197289099612,
           -32.185622167944885,
           -32.079271444893635,
           -31.9729207218424,
           -31.866569998791164,
           -31.760219275739917,
           -31.653868552688667,
           -31.547517829637442,
           -31.441167106586192,
           -31.33481638353495,
           -31.22846566048371,
           -31.122114937432475,
           -31.015764214381228,
           -30.90941349132999,
           -30.803062768278753,
           -30.696712045227503,
           -30.590361322176264,
           -30.48401059912503,
           -30.377659876073785,
           -30.271309153022536,
           -30.16495842997131,
           -30.05860770692006,
           -29.952256983868814,
           -29.845906260817575,
           -29.739555537766343,
           -29.633204814715093,
           -29.526854091663854,
           -29.420503368612618,
           -29.31415264556137,
           -29.207801922510136,
           -29.1014511994589,
           -28.99510047640765,
           -28.888749753356404,
           -28.782399030305164,
           -28.67604830725393,
           -28.59214825756693,
           -28.553149554608417,
           -28.514150851649898,
           -28.475152148691386,
           -28.43615344573287,
           -28.397154742774354,
           -28.35815603981584,
           -28.319157336857316,
           -28.280158633898807,
           -28.24115993094029,
           -28.202161227981776,
           -28.16316252502326,
           -28.124163822064745,
           -28.085165119106225,
           -28.046166416147713,
           -28.007167713189197,
           -27.968169010230678,
           -27.929170307272166,
           -27.89017160431365,
           -27.851172901355135,
           -27.81217419839661,
           -27.773175495438096,
           -27.734176792479587,
           -27.695178089521068,
           -27.656179386562556,
           -27.61718068360404,
           -27.57818198064552,
           -27.53918327768701,
           -27.500184574728493,
           -27.46118587176997,
           -27.42218716881146,
           -27.383188465852943,
           -27.34418976289443,
           -27.30579512345028,
           -27.26790754197455,
           -27.23001996049883,
           -27.192132379023093,
           -27.154244797547367,
           -27.11635721607164,
           -27.07846963459591,
           -27.040582053120183,
           -27.002694471644453,
           -26.964806890168724,
           -26.926919308692995,
           -26.889031727217265,
           -26.85114414574154,
           -26.81325656426581,
           -26.775368982790084,
           -26.737481401314355,
           -26.699593819838622,
           -26.661706238362896,
           -26.623818656887167,
           -26.585931075411438,
           -26.548043493935708,
           -26.510155912459986,
           -26.47226833098425,
           -26.43438074950852,
           -26.39649316803279,
           -26.358605586557065,
           -26.320718005081336,
           -26.28283042360561,
           -26.24494284212988,
           -26.20705526065415,
           -26.169167679178422,
           -26.131280097702696,
           -26.093392516226963,
           -26.055504934751234,
           -26.01761735327551,
           -25.979729771799782,
           -25.941842190324046,
           -25.90395460884832,
           -25.866067027372594,
           -25.828179445896865,
           -25.790291864421135,
           -25.752404282945406,
           -25.714516701469677,
           -25.676629119993947,
           -25.63874153851822,
           -25.600853957042492,
           -25.56296637556676,
           -25.525078794091037,
           -25.487191212615308,
           -25.44930363113958,
           -25.382975570415738,
           -25.174445113451306,
           -24.965914656486884,
           -24.757384199522452,
           -24.548853742558066,
           -24.340323285593634,
           -24.131792828629212,
           -23.92326237166482,
           -23.714731914700394,
           -23.506201457735965,
           -23.297671000771576,
           -23.089140543807147,
           -22.880610086842722,
           -22.672079629878297,
           -22.463549172913904,
           -22.25501871594948,
           -22.046488258985054,
           -21.837957802020664,
           -21.629427345056236,
           -21.420896888091807,
           -21.212366431127418,
           -21.00383597416299,
           -20.795305517198564,
           -20.586775060234174,
           -20.37824460326975,
           -20.16971414630532,
           -19.961183689340892,
           -19.752653232376503,
           -19.544122775412077,
           -19.33559231844765,
           -19.12706186148326,
           -18.929053727930874,
           -18.731711556503278,
           -18.534369385075717,
           -18.33702721364812,
           -18.13968504222052,
           -17.942342870792928,
           -17.745000699365367,
           -17.54765852793777,
           -17.350316356510174,
           -17.152974185082613,
           -16.955632013655016,
           -16.75828984222742,
           -16.56094767079986,
           -16.363605499372262,
           -16.166263327944666,
           -15.968921156517105,
           -15.771578985089509,
           -15.574236813661912,
           -15.376894642234316,
           -15.179552470806755,
           -14.982210299379158,
           -14.784868127951562,
           -14.589256277217261,
           -14.399563966566946,
           -14.209871655916633,
           -14.020179345266357,
           -13.830487034616041,
           -13.64079472396573,
           -13.451102413315414,
           -13.261410102665138,
           -13.071717792014823,
           -12.882025481364511,
           -12.692333170714234,
           -12.50264086006392,
           -12.312948549413608,
           -12.123256238763329,
           -11.933563928113015,
           -11.743871617462702,
           -11.554179306812422,
           -11.364486996162109,
           -11.174794685511795,
           -10.985102374861484,
           -10.795410064211204,
           -10.605717753560892,
           -10.416025442910579,
           -10.2263331322603,
           -10.036640821609986,
           -9.846948510959674,
           -9.657256200309396,
           -9.467563889659083,
           -9.27787157900877,
           -9.088179268358456,
           -8.898486957708178
          ],
          [
           -28.613560173924142,
           -28.64512030455979,
           -28.676680435195436,
           -28.708240565831083,
           -28.73980069646673,
           -28.77136082710238,
           -28.802920957738028,
           -28.834481088373675,
           -28.866041219009325,
           -28.897601349644972,
           -28.92916148028062,
           -28.960721610916266,
           -28.992281741551913,
           -29.02384187218756,
           -29.05540200282321,
           -29.086962133458858,
           -29.1185222640945,
           -29.15008239473015,
           -29.1816425253658,
           -29.21320265600145,
           -29.244762786637093,
           -29.276322917272743,
           -29.307883047908387,
           -29.33944317854404,
           -29.371003309179684,
           -29.402563439815335,
           -29.43412357045098,
           -29.46568370108663,
           -29.49793219079568,
           -29.53155739722932,
           -29.565182603662965,
           -29.59880781009661,
           -29.632433016530253,
           -29.666058222963898,
           -29.699683429397535,
           -29.73330863583118,
           -29.766933842264827,
           -29.800559048698464,
           -29.83418425513211,
           -29.867809461565752,
           -29.901434667999396,
           -29.93505987443304,
           -29.96868508086668,
           -30.002310287300325,
           -30.035935493733966,
           -30.06956070016761,
           -30.103185906601254,
           -30.1368111130349,
           -30.17043631946854,
           -30.204061525902183,
           -30.237686732335828,
           -30.271311938769472,
           -30.304937145203112,
           -30.338562351636753,
           -30.3721875580704,
           -30.40581276450404,
           -30.43943797093769,
           -30.47306317737133,
           -30.50668838380497,
           -30.54031359023862,
           -30.57393879667226,
           -30.6075640031059,
           -30.641189209539544,
           -30.674814415973188,
           -30.70843962240683,
           -30.742064828840476,
           -30.775690035274117,
           -30.809315241707758,
           -30.842940448141405,
           -30.876565654575046,
           -30.91019086100869,
           -30.94381606744233,
           -30.977441273875975,
           -31.01106648030962,
           -31.044691686743263,
           -31.078316893176904,
           -31.11194209961055,
           -31.145567306044192,
           -31.179192512477833,
           -31.212817718911477,
           -31.24644292534512,
           -31.280068131778762,
           -31.313693338212406,
           -31.34731854464605,
           -31.379817204830097,
           -31.412090555764237,
           -31.44436390669837,
           -31.47663725763251,
           -31.508910608566644,
           -31.541183959500785,
           -31.573457310434925,
           -31.60573066136906,
           -31.6380040123032,
           -31.670277363237332,
           -31.702550714171473,
           -31.734824065105606,
           -31.767097416039746,
           -31.79937076697388,
           -31.83164411790802,
           -31.863917468842153,
           -31.896190819776294,
           -31.928464170710427,
           -31.960737521644567,
           -31.9930108725787,
           -32.02528422351284,
           -32.057557574446975,
           -32.089830925381115,
           -32.12210427631525,
           -32.15437762724939,
           -32.18665097818352,
           -32.218924329117655,
           -32.251197680051796,
           -32.283471030985936,
           -32.31574438192007,
           -32.34801773285421,
           -32.38029108378834,
           -32.412564434722476,
           -32.44483778565662,
           -32.47711113659076,
           -32.50938448752489,
           -32.54165783845903,
           -32.573931189393164,
           -32.6062045403273,
           -32.63847789126144,
           -32.67075124219557,
           -32.70302459312971,
           -32.73529794406385,
           -32.767571294997985,
           -32.799844645932126,
           -32.83211799686626,
           -32.86439134780039,
           -32.89666469873453,
           -32.928938049668666,
           -32.961211400602814,
           -32.99348475153695,
           -33.02575810247108,
           -33.05803145340522,
           -33.090304804339354,
           -33.122578155273494,
           -33.15424904655525,
           -33.184715017287495,
           -33.21518098801974,
           -33.24564695875199,
           -33.27611292948424,
           -33.30657890021649,
           -33.337044870948745,
           -33.36751084168099,
           -33.39797681241324,
           -33.428442783145485,
           -33.458908753877736,
           -33.48937472460999,
           -33.51984069534224,
           -33.55030666607449,
           -33.58077263680674,
           -33.611238607538986,
           -33.64170457827124,
           -33.67217054900348,
           -33.702636519735734,
           -33.733102490467985,
           -33.76356846120024,
           -33.79403443193249,
           -33.82450040266473,
           -33.854966373396984,
           -33.88543234412923,
           -33.91589831486149,
           -33.94636428559373,
           -33.97683025632598,
           -34.009739015022184,
           -34.043869167700365,
           -34.077999320378545,
           -34.112129473056726,
           -34.14625962573491,
           -34.180389778413094,
           -34.214519931091274,
           -34.248650083769455,
           -34.282780236447636,
           -34.316910389125816,
           -34.351040541804,
           -34.385170694482184,
           -34.41930084716036,
           -34.453430999838545,
           -34.487561152516726,
           -34.521691305194906,
           -34.555821457873094,
           -34.58995161055127,
           -34.624081763229455,
           -34.65821191590763,
           -34.69234206858581,
           -34.726472221264,
           -34.76060237394218,
           -34.79473252662036,
           -34.82886267929854,
           -34.862992831976726,
           -34.8971229846549,
           -34.93125313733309,
           -34.96538329001127,
           -34.99951344268945,
           -35.03364359536763,
           -35.06777374804581,
           -35.10190390072399,
           -35.13603405340217,
           -35.17016420608035,
           -35.20429435875853,
           -35.23842451143672,
           -35.2725546641149,
           -35.30668481679308,
           -35.34081496947126,
           -35.37494512214944,
           -35.40907527482762,
           -35.4432054275058,
           -35.47733558018399,
           -35.51146573286217,
           -35.54559588554035,
           -35.579726038218524,
           -35.61385619089671,
           -35.64798634357489,
           -35.68211649625308,
           -35.71624664893126,
           -35.750376801609434,
           -35.78450695428762,
           -35.8186371069658,
           -35.85276725964398,
           -35.88689741232217,
           -35.921027565000344,
           -35.95515771767853,
           -35.98928787035671,
           -36.02341802303489,
           -36.05754817571307,
           -36.09081307046446,
           -36.123961038188675,
           -36.15710900591288,
           -36.19025697363709,
           -36.2234049413613,
           -36.25655290908551,
           -36.28970087680972,
           -36.32284884453392,
           -36.35599681225813,
           -36.38914477998234,
           -36.42229274770655,
           -36.455440715430754,
           -36.488588683154966,
           -36.52173665087918,
           -36.55488461860338,
           -36.58803258632759,
           -36.6211805540518,
           -36.65432852177601,
           -36.68747648950021,
           -36.720624457224424,
           -36.75377242494863,
           -36.78692039267284,
           -36.75409213826154,
           -36.65528766171474,
           -36.556483185167934,
           -36.45767870862114,
           -36.35887423207433,
           -36.26006975552754,
           -36.161265278980736,
           -36.062460802433925,
           -35.96365632588712,
           -35.86485184934033,
           -35.76604737279353,
           -35.66724289624672,
           -35.56843841969992,
           -35.46963394315313,
           -35.370829466606324,
           -35.27202499005952,
           -35.173220513512724,
           -35.074416036965914,
           -34.975611560419125,
           -34.87680708387232,
           -34.77800260732552,
           -34.679198130778715,
           -34.580393654231926,
           -34.481589177685116,
           -34.38278470113831,
           -34.28398022459152,
           -34.18517574804471,
           -34.0863712714979,
           -33.98756679495111,
           -33.88876231840431,
           -33.78995784185751,
           -33.6911533653107,
           -33.59234888876391,
           -33.493544412217105,
           -33.3947399356703,
           -33.2959354591235,
           -33.1971309825767,
           -33.0983265060299,
           -32.9995220294831,
           -32.9007175529363,
           -32.801913076389496,
           -32.7031085998427,
           -32.6043041232959,
           -32.50549964674909,
           -32.40669517020228,
           -32.3078906936555,
           -32.2090862171087,
           -32.11028174056189,
           -32.011477264015085,
           -31.91267278746829,
           -31.81386831092148,
           -31.715063834374686,
           -31.616259357827893,
           -31.517454881281086,
           -31.41865040473428,
           -31.319845928187483,
           -31.221041451640684,
           -31.122236975093877,
           -31.02343249854708,
           -30.924628022000277,
           -30.82582354545347,
           -30.727019068906678,
           -30.62821459235988,
           -30.52941011581307,
           -30.430605639266275,
           -30.331801162719476,
           -30.232996686172672,
           -30.134192209625866,
           -30.035387733079077,
           -29.93658325653227,
           -29.837778779985463,
           -29.738974303438667,
           -29.640169826891867,
           -29.54136535034506,
           -29.442560873798264,
           -29.343756397251465,
           -29.250422240330078,
           -29.17591226486773,
           -29.101402289405378,
           -29.026892313943023,
           -28.952382338480668,
           -28.87787236301832,
           -28.80336238755597,
           -28.74142546223147,
           -28.704634637182668,
           -28.667843812133867,
           -28.631052987085063,
           -28.59426216203626,
           -28.557471336987454,
           -28.52068051193865,
           -28.48388968688985,
           -28.44709886184105,
           -28.41030803679224,
           -28.373517211743437,
           -28.336726386694636,
           -28.299935561645835,
           -28.26314473659703,
           -28.22635391154823,
           -28.189563086499422,
           -28.152772261450618,
           -28.115981436401817,
           -28.079190611353017,
           -28.042399786304212,
           -28.005608961255408,
           -27.968818136206604,
           -27.9320273111578,
           -27.89445763455308,
           -27.856570053077355,
           -27.81868247160163,
           -27.780794890125897,
           -27.742907308650167,
           -27.70501972717445,
           -27.667132145698716,
           -27.62924456422298,
           -27.591356982747254,
           -27.553469401271528,
           -27.5155818197958,
           -27.47769423832007,
           -27.43980665684434,
           -27.40191907536861,
           -27.364031493892885,
           -27.32614391241716,
           -27.28825633094143,
           -27.2503687494657,
           -27.21248116798997,
           -27.174593586514238,
           -27.13670600503851,
           -27.098818423562783,
           -27.060930842087053,
           -27.023043260611324,
           -26.985155679135595,
           -26.947268097659865,
           -26.90938051618414,
           -26.871492934708414,
           -26.833605353232684,
           -26.795717771756955,
           -26.757830190281222,
           -26.7199426088055,
           -26.682055027329767,
           -26.644167445854038,
           -26.60627986437831,
           -26.568392282902582,
           -26.53050470142685,
           -26.492617119951127,
           -26.454729538475394,
           -26.416841956999665,
           -26.37895437552394,
           -26.34106679404821,
           -26.30317921257248,
           -26.265291631096748,
           -26.227404049621025,
           -26.189516468145296,
           -26.151628886669563,
           -26.113741305193837,
           -26.07585372371811,
           -26.03796614224238,
           -26.000078560766646,
           -25.962190979290924,
           -25.924303397815194,
           -25.886415816339465,
           -25.848528234863736,
           -25.810640653388006,
           -25.772753071912273,
           -25.734865490436547,
           -25.69697790896082,
           -25.659090327485092,
           -25.59276226676125,
           -25.384231809796827,
           -25.175701352832395,
           -24.96717089586797,
           -24.75864043890358,
           -24.55010998193915,
           -24.341579524974723,
           -24.133049068010337,
           -23.92451861104591,
           -23.715988154081483,
           -23.50745769711709,
           -23.298927240152665,
           -23.090396783188236,
           -22.88186632622381,
           -22.67333586925942,
           -22.464805412294993,
           -22.256274955330568,
           -22.04774449836618,
           -21.83921404140175,
           -21.63068358443732,
           -21.42215312747293,
           -21.213622670508506,
           -21.005092213544078,
           -20.796561756579692,
           -20.595604626315957,
           -20.394976774754493,
           -20.194348923193033,
           -19.993721071631608,
           -19.793093220070144,
           -19.59246536850868,
           -19.39183751694726,
           -19.191209665385795,
           -18.99058181382434,
           -18.78995396226291,
           -18.58932611070145,
           -18.388698259139986,
           -18.188070407578522,
           -17.9874425560171,
           -17.786814704455637,
           -17.586186852894176,
           -17.38555900133275,
           -17.184931149771288,
           -16.984303298209824,
           -16.7836754466484,
           -16.58304759508694,
           -16.382419743525475,
           -16.18179189196405,
           -15.98116404040259,
           -15.780536188841126,
           -15.579908337279663,
           -15.37928048571824,
           -15.178652634156776,
           -14.978024782595314,
           -14.77739693103389,
           -14.576769079472427,
           -14.376141227910965,
           -14.17551337634954,
           -13.974885524788078,
           -13.774257673226614,
           -13.573629821665154,
           -13.375280212605192,
           -13.185587901954875,
           -12.995895591304564,
           -12.806203280654284,
           -12.616510970003972,
           -12.42681865935366,
           -12.23712634870338,
           -12.04743403805307,
           -11.857741727402754,
           -11.668049416752476,
           -11.478357106102163,
           -11.288664795451849,
           -11.098972484801536,
           -10.909280174151258,
           -10.719587863500944,
           -10.529895552850633,
           -10.340203242200353,
           -10.150510931550041,
           -9.960818620899726,
           -9.771126310249448,
           -9.581433999599135,
           -9.391741688948823,
           -9.202049378298508,
           -9.01235706764823
          ],
          [
           -28.203929170085086,
           -28.235489300720737,
           -28.267049431356384,
           -28.29860956199203,
           -28.330169692627678,
           -28.361729823263325,
           -28.39328995389897,
           -28.424850084534622,
           -28.45641021517027,
           -28.48797034580592,
           -28.519530476441567,
           -28.551090607077214,
           -28.58265073771286,
           -28.614210868348508,
           -28.645770998984155,
           -28.6773311296198,
           -28.70889126025545,
           -28.740451390891096,
           -28.772011521526743,
           -28.803571652162397,
           -28.835131782798037,
           -28.86669191343369,
           -28.898252044069334,
           -28.929812174704985,
           -28.96137230534063,
           -28.992932435976282,
           -29.024492566611926,
           -29.056052697247573,
           -29.08761282788322,
           -29.119172958518867,
           -29.150733089154517,
           -29.182293219790164,
           -29.21385335042581,
           -29.24541348106146,
           -29.27697361169711,
           -29.308533742332756,
           -29.340093872968403,
           -29.37165400360405,
           -29.4032141342397,
           -29.434774264875347,
           -29.466334395510994,
           -29.49789452614664,
           -29.52945465678229,
           -29.56101478741794,
           -29.592574918053586,
           -29.625855945320893,
           -29.659481151754537,
           -29.69310635818818,
           -29.726731564621822,
           -29.760356771055466,
           -29.79398197748911,
           -29.827607183922755,
           -29.861232390356395,
           -29.89485759679004,
           -29.928482803223684,
           -29.962108009657328,
           -29.99573321609097,
           -30.029358422524613,
           -30.062983628958257,
           -30.096608835391898,
           -30.13023404182554,
           -30.163859248259186,
           -30.197484454692827,
           -30.231109661126467,
           -30.264734867560115,
           -30.298360073993756,
           -30.3319852804274,
           -30.365610486861044,
           -30.399235693294685,
           -30.432860899728325,
           -30.466486106161973,
           -30.500111312595614,
           -30.533736519029254,
           -30.567361725462902,
           -30.600986931896543,
           -30.63461213833019,
           -30.66823734476383,
           -30.701862551197472,
           -30.735487757631116,
           -30.76911296406476,
           -30.802738170498404,
           -30.836363376932045,
           -30.86998858336569,
           -30.90361378979933,
           -30.936112449983383,
           -30.968385800917524,
           -31.000659151851657,
           -31.032932502785798,
           -31.065205853719934,
           -31.097479204654068,
           -31.129752555588205,
           -31.16202590652234,
           -31.19429925745648,
           -31.226572608390615,
           -31.258845959324756,
           -31.29111931025889,
           -31.32339266119303,
           -31.355666012127166,
           -31.387939363061307,
           -31.42021271399544,
           -31.452486064929573,
           -31.484759415863714,
           -31.517032766797847,
           -31.549306117731987,
           -31.581579468666124,
           -31.61385281960026,
           -31.646126170534398,
           -31.678399521468535,
           -31.71067287240267,
           -31.74294622333681,
           -31.775219574270945,
           -31.807492925205082,
           -31.839766276139216,
           -31.872039627073356,
           -31.90431297800749,
           -31.936586328941626,
           -31.968859679875763,
           -32.001133030809896,
           -32.03340638174404,
           -32.06567973267817,
           -32.09795308361232,
           -32.13022643454645,
           -32.16249978548058,
           -32.19326698636318,
           -32.22373295709543,
           -32.25419892782767,
           -32.284664898559924,
           -32.315130869292176,
           -32.34559684002443,
           -32.37606281075667,
           -32.40652878148892,
           -32.436994752221175,
           -32.46746072295342,
           -32.49792669368567,
           -32.52839266441792,
           -32.55885863515017,
           -32.589324605882425,
           -32.61979057661467,
           -32.65025654734692,
           -32.68072251807917,
           -32.711188488811416,
           -32.74165445954367,
           -32.77212043027592,
           -32.80258640100816,
           -32.83305237174042,
           -32.863518342472666,
           -32.89398431320492,
           -32.92445028393716,
           -32.95491625466941,
           -32.985382225401665,
           -33.01584819613391,
           -33.04631416686616,
           -33.07678013759841,
           -33.107246108330656,
           -33.13771207906291,
           -33.16817804979516,
           -33.19864402052741,
           -33.22910999125966,
           -33.25957596199191,
           -33.29004193272416,
           -33.3205079034564,
           -33.350973874188654,
           -33.381439844920905,
           -33.41190581565316,
           -33.44237178638541,
           -33.47283775711766,
           -33.503303727849904,
           -33.536212486546106,
           -33.57034263922429,
           -33.60447279190247,
           -33.638602944580654,
           -33.67273309725883,
           -33.706863249937015,
           -33.74099340261519,
           -33.77512355529338,
           -33.80925370797156,
           -33.84338386064974,
           -33.877514013327925,
           -33.911644166006106,
           -33.945774318684286,
           -33.979904471362474,
           -34.01403462404065,
           -34.048164776718835,
           -34.08229492939701,
           -34.116425082075196,
           -34.15055523475338,
           -34.18468538743156,
           -34.21881554010973,
           -34.25294569278792,
           -34.287075845466106,
           -34.321205998144286,
           -34.35533615082247,
           -34.38946630350065,
           -34.42359645617883,
           -34.457726608857,
           -34.49185676153519,
           -34.52598691421337,
           -34.56011706689155,
           -34.59424721956974,
           -34.62837737224791,
           -34.6625075249261,
           -34.69663767760428,
           -34.73076783028246,
           -34.76489798296064,
           -34.79902813563882,
           -34.833158288317,
           -34.86728844099518,
           -34.90141859367337,
           -34.93554874635155,
           -34.96967889902973,
           -35.00287363753549,
           -35.0360216052597,
           -35.0691695729839,
           -35.102317540708114,
           -35.135465508432326,
           -35.16861347615653,
           -35.201761443880734,
           -35.234909411604946,
           -35.26805737932915,
           -35.30120534705336,
           -35.334353314777566,
           -35.36750128250178,
           -35.40064925022599,
           -35.433797217950186,
           -35.466945185674405,
           -35.50009315339861,
           -35.53324112112283,
           -35.56638908884703,
           -35.599537056571236,
           -35.63268502429545,
           -35.66583299201965,
           -35.698980959743864,
           -35.732128927468075,
           -35.76527689519228,
           -35.79842486291649,
           -35.831572830640695,
           -35.8647207983649,
           -35.89786876608911,
           -35.93101673381332,
           -35.96416470153753,
           -35.99731266926173,
           -36.03046063698595,
           -36.063608604710154,
           -36.09675657243436,
           -36.12990454015857,
           -36.163052507882774,
           -36.196200475606986,
           -36.22934844333119,
           -36.26249641105541,
           -36.29564437877961,
           -36.262816124368314,
           -36.16401164782151,
           -36.06520717127471,
           -35.966402694727904,
           -35.8675982181811,
           -35.768793741634305,
           -35.66998926508751,
           -35.571184788540705,
           -35.472380311993895,
           -35.373575835447106,
           -35.274771358900296,
           -35.17596688235349,
           -35.0771624058067,
           -34.9783579292599,
           -34.8795534527131,
           -34.780748976166294,
           -34.6819444996195,
           -34.58314002307269,
           -34.4843355465259,
           -34.385531069979095,
           -34.28672659343229,
           -34.18792211688549,
           -34.08911764033869,
           -33.99031316379189,
           -33.89150868724508,
           -33.79270421069828,
           -33.693899734151486,
           -33.59509525760468,
           -33.49629078105788,
           -33.397486304511084,
           -33.29868182796428,
           -33.19987735141747,
           -33.10107287487068,
           -33.00226839832388,
           -32.903463921777075,
           -32.80465944523027,
           -32.705854968683475,
           -32.607050492136665,
           -32.50824601558987,
           -32.40944153904307,
           -32.31063706249627,
           -32.21183258594947,
           -32.11302810940267,
           -32.01422363285587,
           -31.915419156309056,
           -31.81661467976227,
           -31.717810203215464,
           -31.619005726668657,
           -31.520201250121865,
           -31.421396773575065,
           -31.322592297028258,
           -31.232475924897564,
           -31.157965949435216,
           -31.08345597397286,
           -31.008945998510505,
           -30.934436023048164,
           -30.859926047585805,
           -30.785416072123454,
           -30.710906096661102,
           -30.63639612119875,
           -30.561886145736402,
           -30.487376170274047,
           -30.4128661948117,
           -30.338356219349343,
           -30.263846243886995,
           -30.189336268424647,
           -30.114826292962288,
           -30.040316317499936,
           -29.965806342037595,
           -29.891296366575233,
           -29.81678639111288,
           -29.74227641565053,
           -29.66776644018818,
           -29.59325646472583,
           -29.518746489263478,
           -29.44423651380113,
           -29.369726538338774,
           -29.295216562876426,
           -29.220706587414078,
           -29.146196611951723,
           -29.07168663648936,
           -28.997176661027016,
           -28.922666685564664,
           -28.860729760240165,
           -28.823938935191364,
           -28.78714811014256,
           -28.750357285093756,
           -28.71356646004496,
           -28.676775634996154,
           -28.639984809947347,
           -28.603193984898542,
           -28.56640315984974,
           -28.529612334800937,
           -28.492821509752133,
           -28.45603068470333,
           -28.41923985965453,
           -28.382449034605727,
           -28.345658209556923,
           -28.308867384508122,
           -28.272076559459315,
           -28.235285734410517,
           -28.198494909361713,
           -28.16170408431291,
           -28.1249132592641,
           -28.0881224342153,
           -28.051331609166496,
           -28.014540784117692,
           -27.977749959068888,
           -27.94095913402009,
           -27.904168308971286,
           -27.867377483922482,
           -27.83058665887368,
           -27.793795833824873,
           -27.75700500877607,
           -27.720214183727272,
           -27.683423358678468,
           -27.646632533629663,
           -27.60984170858086,
           -27.57305088353206,
           -27.53626005848325,
           -27.49946923343445,
           -27.462678408385646,
           -27.425887583336838,
           -27.389096758288037,
           -27.352305933239236,
           -27.315515108190432,
           -27.278724283141628,
           -27.241933458092827,
           -27.205142633044026,
           -27.168351807995215,
           -27.131560982946418,
           -27.094770157897614,
           -27.05797933284881,
           -27.02118850780001,
           -26.984397682751204,
           -26.947606857702404,
           -26.910816032653596,
           -26.8740252076048,
           -26.83723438255599,
           -26.80044355750718,
           -26.76365273245838,
           -26.72686190740958,
           -26.690071082360777,
           -26.653280257311977,
           -26.616489432263172,
           -26.579698607214368,
           -26.542907782165564,
           -26.506116957116763,
           -26.46932613206796,
           -26.43253530701915,
           -26.395744481970354,
           -26.35895365692155,
           -26.322162831872745,
           -26.285372006823945,
           -26.248581181775137,
           -26.21170590693262,
           -26.174697925179274,
           -26.137689943425933,
           -26.100681961672585,
           -26.063673979919233,
           -26.026665998165896,
           -25.989658016412548,
           -25.9526500346592,
           -25.915642052905852,
           -25.878634071152508,
           -25.841626089399163,
           -25.777526889889472,
           -25.577971601598023,
           -25.37841631330658,
           -25.178861025015134,
           -24.979305736723724,
           -24.779750448432278,
           -24.580195160140832,
           -24.38063987184942,
           -24.180532050351264,
           -23.9799041987898,
           -23.779276347228375,
           -23.57864849566691,
           -23.378020644105447,
           -23.17739279254399,
           -22.976764940982562,
           -22.776137089421102,
           -22.57550923785964,
           -22.374881386298213,
           -22.174253534736753,
           -21.973625683175293,
           -21.772997831613868,
           -21.572369980052404,
           -21.37174212849094,
           -21.171114276929515,
           -20.97048642536805,
           -20.769858573806587,
           -20.569230722245127,
           -20.368602870683706,
           -20.16797501912224,
           -19.96734716756078,
           -19.766719315999353,
           -19.56609146443789,
           -19.365463612876432,
           -19.164835761315004,
           -18.964207909753544,
           -18.76358005819208,
           -18.562952206630616,
           -18.362324355069195,
           -18.161696503507734,
           -17.96106865194627,
           -17.760440800384846,
           -17.55981294882338,
           -17.35918509726192,
           -17.158557245700496,
           -16.957929394139033,
           -16.757301542577572,
           -16.556673691016147,
           -16.356045839454687,
           -16.155417987893223,
           -15.95479013633176,
           -15.754162284770336,
           -15.553534433208874,
           -15.35290658164741,
           -15.152278730085985,
           -14.951650878524521,
           -14.751023026963063,
           -14.550395175401636,
           -14.349767323840172,
           -14.149139472278712,
           -13.948511620717252,
           -13.747883769155823,
           -13.547255917594363,
           -13.346628066032899,
           -13.146000214471476,
           -12.945372362910014,
           -12.744744511348552,
           -12.544116659787125,
           -12.343488808225665,
           -12.142860956664201,
           -11.942233105102776,
           -11.741605253541316,
           -11.540977401979852,
           -11.340349550418392,
           -11.139721698856967,
           -10.939093847295503,
           -10.738465995734042,
           -10.537422677717714,
           -10.336157132898563,
           -10.134891588079414,
           -9.9336260432603,
           -9.732360498441151,
           -9.531094953622,
           -9.32982940880285,
           -9.128563863983738
          ],
          [
           -27.794298166246026,
           -27.825858296881673,
           -27.85741842751732,
           -27.888978558152967,
           -27.920538688788618,
           -27.952098819424265,
           -27.98365895005991,
           -28.01521908069556,
           -28.046779211331206,
           -28.078339341966856,
           -28.109899472602503,
           -28.14145960323815,
           -28.173019733873797,
           -28.204579864509444,
           -28.236139995145095,
           -28.267700125780742,
           -28.29926025641639,
           -28.330820387052036,
           -28.362380517687683,
           -28.39394064832333,
           -28.425500778958977,
           -28.457060909594624,
           -28.488621040230274,
           -28.520181170865925,
           -28.551741301501565,
           -28.58330143213722,
           -28.614861562772866,
           -28.646421693408513,
           -28.67798182404416,
           -28.709541954679807,
           -28.741102085315454,
           -28.7726622159511,
           -28.804222346586748,
           -28.8357824772224,
           -28.867342607858046,
           -28.898902738493696,
           -28.930462869129343,
           -28.96202299976499,
           -28.993583130400637,
           -29.025143261036288,
           -29.05670339167193,
           -29.088263522307578,
           -29.119823652943225,
           -29.15138378357888,
           -29.182943914214523,
           -29.21450404485017,
           -29.24606417548582,
           -29.277624306121467,
           -29.309184436757114,
           -29.34074456739276,
           -29.372304698028408,
           -29.40386482866406,
           -29.435424959299706,
           -29.46698508993535,
           -29.498545220570996,
           -29.53010535120665,
           -29.561665481842297,
           -29.593225612477944,
           -29.624785743113588,
           -29.65634587374924,
           -29.687906004384885,
           -29.720154493412462,
           -29.753779699846106,
           -29.787404906279747,
           -29.82103011271339,
           -29.854655319147035,
           -29.888280525580676,
           -29.92190573201432,
           -29.955530938447964,
           -29.98915614488161,
           -30.02278135131525,
           -30.056406557748893,
           -30.090031764182534,
           -30.123656970616175,
           -30.157282177049822,
           -30.190907383483463,
           -30.224532589917104,
           -30.25815779635075,
           -30.291783002784392,
           -30.32540820921804,
           -30.35903341565168,
           -30.39265862208532,
           -30.426283828518965,
           -30.45990903495261,
           -30.492407695136663,
           -30.5246810460708,
           -30.556954397004937,
           -30.589227747939074,
           -30.62150109887321,
           -30.653774449807344,
           -30.68604780074148,
           -30.718321151675617,
           -30.750594502609754,
           -30.78286785354389,
           -30.81514120447803,
           -30.847414555412165,
           -30.879687906346305,
           -30.91196125728044,
           -30.944234608214582,
           -30.97650795914872,
           -31.008781310082856,
           -31.041054661016993,
           -31.07332801195113,
           -31.105601362885267,
           -31.1378747138194,
           -31.170148064753537,
           -31.201818955438853,
           -31.2322849261711,
           -31.262750896903352,
           -31.2932168676356,
           -31.323682838367855,
           -31.354148809100103,
           -31.384614779832347,
           -31.4150807505646,
           -31.44554672129685,
           -31.4760126920291,
           -31.50647866276135,
           -31.536944633493597,
           -31.56741060422585,
           -31.597876574958097,
           -31.628342545690348,
           -31.658808516422596,
           -31.689274487154844,
           -31.71974045788709,
           -31.750206428619343,
           -31.780672399351594,
           -31.81113837008384,
           -31.84160434081609,
           -31.872070311548338,
           -31.902536282280593,
           -31.933002253012837,
           -31.96346822374509,
           -31.99393419447734,
           -32.024400165209585,
           -32.054866135941836,
           -32.08533210667409,
           -32.11579807740634,
           -32.14626404813858,
           -32.176730018870835,
           -32.207195989603086,
           -32.23766196033533,
           -32.26812793106758,
           -32.29859390179983,
           -32.329059872532085,
           -32.359525843264336,
           -32.38999181399658,
           -32.42045778472883,
           -32.450923755461076,
           -32.48138972619333,
           -32.51185569692558,
           -32.54232166765782,
           -32.572787638390075,
           -32.603253609122326,
           -32.63371957985458,
           -32.66418555058683,
           -32.694651521319074,
           -32.725117492051325,
           -32.75558346278358,
           -32.78604943351583,
           -32.81651540424808,
           -32.84698137498032,
           -32.87744734571257,
           -32.90791331644482,
           -32.93837928717707,
           -32.96884525790932,
           -32.999311228641574,
           -33.02977719937382,
           -33.06268595807002,
           -33.09681611074821,
           -33.13094626342638,
           -33.16507641610457,
           -33.19920656878274,
           -33.23333672146093,
           -33.26746687413911,
           -33.30159702681729,
           -33.33572717949548,
           -33.36985733217366,
           -33.40398748485184,
           -33.43811763753002,
           -33.4722477902082,
           -33.50637794288639,
           -33.54050809556456,
           -33.57463824824275,
           -33.60876840092093,
           -33.64289855359911,
           -33.6770287062773,
           -33.71115885895547,
           -33.74528901163366,
           -33.77941916431184,
           -33.81354931699002,
           -33.8476794696682,
           -33.88178623688229,
           -33.914934204606496,
           -33.94808217233071,
           -33.98123014005492,
           -34.01437810777912,
           -34.047526075503335,
           -34.080674043227546,
           -34.11382201095175,
           -34.14696997867596,
           -34.18011794640016,
           -34.21326591412437,
           -34.24641388184858,
           -34.27956184957279,
           -34.312709817297,
           -34.34585778502121,
           -34.379005752745414,
           -34.412153720469625,
           -34.44530168819383,
           -34.47844965591804,
           -34.51159762364225,
           -34.544745591366464,
           -34.57789355909066,
           -34.61104152681487,
           -34.64418949453909,
           -34.67733746226329,
           -34.7104854299875,
           -34.743633397711704,
           -34.77678136543591,
           -34.80992933316013,
           -34.84307730088433,
           -34.87622526860854,
           -34.909373236332755,
           -34.94252120405696,
           -34.97566917178116,
           -35.008817139505375,
           -35.041965107229586,
           -35.07511307495379,
           -35.108261042677995,
           -35.141409010402214,
           -35.17455697812642,
           -35.20770494585062,
           -35.240852913574834,
           -35.274000881299045,
           -35.30714884902325,
           -35.340296816747454,
           -35.373444784471666,
           -35.40659275219588,
           -35.43974071992008,
           -35.47288868764429,
           -35.506036655368504,
           -35.53918462309271,
           -35.57233259081691,
           -35.605480558541124,
           -35.638628526265336,
           -35.67177649398954,
           -35.704924461713745,
           -35.738072429437956,
           -35.77122039716217,
           -35.80436836488637,
           -35.77154011047507,
           -35.67273563392827,
           -35.573931157381466,
           -35.47512668083467,
           -35.37632220428787,
           -35.27751772774107,
           -35.178713251194274,
           -35.079908774647464,
           -34.98110429810066,
           -34.88229982155387,
           -34.78349534500707,
           -34.68469086846026,
           -34.58588639191346,
           -34.48708191536666,
           -34.388277438819856,
           -34.28947296227305,
           -34.19066848572626,
           -34.09186400917945,
           -33.99305953263266,
           -33.89425505608586,
           -33.79545057953905,
           -33.69664610299225,
           -33.59784162644546,
           -33.49903714989865,
           -33.40023267335184,
           -33.30142819680505,
           -33.214529609465046,
           -33.1400196340027,
           -33.06550965854035,
           -32.990999683078,
           -32.91648970761565,
           -32.841979732153284,
           -32.76746975669094,
           -32.692959781228595,
           -32.61844980576623,
           -32.543939830303884,
           -32.469429854841536,
           -32.39491987937918,
           -32.32040990391683,
           -32.245899928454484,
           -32.17138995299213,
           -32.09687997752978,
           -32.02237000206743,
           -31.947860026605078,
           -31.87335005114272,
           -31.798840075680374,
           -31.724330100218022,
           -31.649820124755664,
           -31.57531014929332,
           -31.500800173830967,
           -31.426290198368612,
           -31.35178022290626,
           -31.277270247443912,
           -31.20276027198156,
           -31.128250296519205,
           -31.053740321056857,
           -30.979230345594505,
           -30.90472037013215,
           -30.830210394669802,
           -30.75570041920745,
           -30.681190443745095,
           -30.606680468282747,
           -30.5321704928204,
           -30.457660517358043,
           -30.383150541895688,
           -30.308640566433343,
           -30.234130590970988,
           -30.159620615508633,
           -30.085110640046288,
           -30.01060066458394,
           -29.936090689121578,
           -29.86158071365923,
           -29.78707073819688,
           -29.712560762734526,
           -29.638050787272174,
           -29.563540811809826,
           -29.48903083634747,
           -29.414520860885123,
           -29.340010885422775,
           -29.265500909960416,
           -29.190990934498064,
           -29.116480959035716,
           -29.041970983573364,
           -28.980034058248865,
           -28.943243233200064,
           -28.906452408151264,
           -28.869661583102456,
           -28.83287075805365,
           -28.79607993300485,
           -28.759289107956043,
           -28.72249828290724,
           -28.68570745785844,
           -28.648916632809637,
           -28.612125807760833,
           -28.575334982712032,
           -28.538544157663228,
           -28.501753332614424,
           -28.46496250756562,
           -28.42817168251682,
           -28.391380857468015,
           -28.354590032419214,
           -28.317799207370413,
           -28.281008382321605,
           -28.2442175572728,
           -28.207426732224,
           -28.170635907175196,
           -28.13384508212639,
           -28.097054257077588,
           -28.060263432028787,
           -28.02347260697998,
           -27.98668178193118,
           -27.949890956882378,
           -27.913100131833577,
           -27.876188664115396,
           -27.839180682362056,
           -27.802172700608704,
           -27.76516471885536,
           -27.728156737102015,
           -27.69114875534867,
           -27.654140773595323,
           -27.61713279184198,
           -27.580124810088634,
           -27.543116828335286,
           -27.50610884658194,
           -27.469100864828597,
           -27.43209288307525,
           -27.3950849013219,
           -27.358076919568557,
           -27.321068937815213,
           -27.284060956061865,
           -27.24705297430852,
           -27.210044992555176,
           -27.173037010801828,
           -27.136029029048483,
           -27.09902104729514,
           -27.06201306554179,
           -27.025005083788443,
           -26.987997102035102,
           -26.950989120281754,
           -26.913981138528406,
           -26.876973156775062,
           -26.839965175021717,
           -26.80295719326837,
           -26.76594921151502,
           -26.728941229761677,
           -26.691933248008333,
           -26.654925266254985,
           -26.61791728450164,
           -26.580909302748296,
           -26.543901320994948,
           -26.506893339241604,
           -26.46988535748826,
           -26.43287737573491,
           -26.395869393981563,
           -26.358861412228222,
           -26.321853430474874,
           -26.28484544872153,
           -26.247837466968186,
           -26.210829485214838,
           -26.17382150346149,
           -26.13681352170815,
           -26.0998055399548,
           -26.062797558201453,
           -26.02578957644811,
           -25.988781594694764,
           -25.95177361294142,
           -25.887674413431725,
           -25.68811912514028,
           -25.488563836848833,
           -25.289008548557383,
           -25.089453260265977,
           -24.88989797197453,
           -24.690342683683085,
           -24.490787395391674,
           -24.291232107100228,
           -24.091676818808782,
           -23.89212153051737,
           -23.692566242225926,
           -23.49301095393448,
           -23.29345566564303,
           -23.093900377351623,
           -22.894345089060177,
           -22.694789800768728,
           -22.49523451247732,
           -22.295679224185875,
           -22.096123935894425,
           -21.896568647603015,
           -21.69701335931157,
           -21.497458071020123,
           -21.297902782728713,
           -21.098347494437267,
           -20.898792206145824,
           -20.699236917854375,
           -20.499681629562964,
           -20.300126341271515,
           -20.10057105298007,
           -19.90101576468866,
           -19.701460476397216,
           -19.501905188105773,
           -19.30234989981436,
           -19.102794611522913,
           -18.903239323231467,
           -18.703684034940018,
           -18.503308071082586,
           -18.302680219521122,
           -18.10205236795966,
           -17.901424516398237,
           -17.700796664836773,
           -17.50016881327531,
           -17.299540961713884,
           -17.09891311015242,
           -16.898285258590963,
           -16.69765740702954,
           -16.49677351324428,
           -16.295507968425127,
           -16.094242423605976,
           -15.892976878786865,
           -15.691711333967714,
           -15.490445789148565,
           -15.289180244329453,
           -15.0879146995103,
           -14.886649154691153,
           -14.685383609872039,
           -14.484118065052888,
           -14.282852520233737,
           -14.081586975414588,
           -13.880321430595476,
           -13.679055885776323,
           -13.477790340957176,
           -13.276524796138062,
           -13.075259251318913,
           -12.873993706499762,
           -12.672728161680649,
           -12.4714626168615,
           -12.27019707204235,
           -12.068931527223237,
           -11.867665982404088,
           -11.666400437584937,
           -11.465134892765787,
           -11.263869347946674,
           -11.062603803127523,
           -10.861338258308374,
           -10.66007271348926,
           -10.45880716867011,
           -10.257541623850962,
           -10.056276079031848,
           -9.855010534212699,
           -9.653744989393548,
           -9.452479444574397,
           -9.251213899755285
          ],
          [
           -27.384667162406966,
           -27.416227293042613,
           -27.44778742367826,
           -27.479347554313907,
           -27.510907684949558,
           -27.542467815585205,
           -27.574027946220852,
           -27.6055880768565,
           -27.637148207492146,
           -27.668708338127793,
           -27.700268468763444,
           -27.731828599399087,
           -27.763388730034734,
           -27.794948860670388,
           -27.826508991306035,
           -27.858069121941682,
           -27.88962925257733,
           -27.921189383212976,
           -27.952749513848623,
           -27.98430964448427,
           -28.015869775119917,
           -28.047429905755564,
           -28.078990036391218,
           -28.110550167026858,
           -28.142110297662512,
           -28.17367042829816,
           -28.205230558933803,
           -28.236790689569453,
           -28.2683508202051,
           -28.299910950840747,
           -28.331471081476394,
           -28.36303121211204,
           -28.39459134274769,
           -28.426151473383335,
           -28.457711604018986,
           -28.489271734654636,
           -28.520831865290283,
           -28.55239199592593,
           -28.583952126561577,
           -28.615512257197224,
           -28.64707238783287,
           -28.67863251846852,
           -28.710192649104165,
           -28.741752779739816,
           -28.773312910375463,
           -28.804873041011113,
           -28.83643317164676,
           -28.867993302282407,
           -28.899553432918054,
           -28.9311135635537,
           -28.96267369418935,
           -28.994233824824995,
           -29.025793955460646,
           -29.05735408609629,
           -29.088914216731936,
           -29.12047434736759,
           -29.152034478003237,
           -29.183594608638884,
           -29.21515473927453,
           -29.24671486991018,
           -29.278275000545825,
           -29.309835131181476,
           -29.341395261817123,
           -29.372955392452766,
           -29.404515523088417,
           -29.436075653724064,
           -29.46763578435971,
           -29.49919591499536,
           -29.53075604563101,
           -29.562316176266656,
           -29.593876306902303,
           -29.62543643753795,
           -29.6569965681736,
           -29.688556698809247,
           -29.720116829444894,
           -29.75167696008054,
           -29.783237090716188,
           -29.814797221351835,
           -29.84807824793767,
           -29.881703454371316,
           -29.91532866080496,
           -29.9489538672386,
           -29.98257907367224,
           -30.01620428010589,
           -30.04870294028994,
           -30.080976291224076,
           -30.113249642158213,
           -30.14552299309235,
           -30.177796344026486,
           -30.21006969496062,
           -30.24083689524678,
           -30.271302865979028,
           -30.30176883671128,
           -30.33223480744353,
           -30.36270077817578,
           -30.393166748908026,
           -30.42363271964028,
           -30.454098690372525,
           -30.484564661104777,
           -30.51503063183703,
           -30.545496602569273,
           -30.575962573301524,
           -30.606428544033776,
           -30.636894514766027,
           -30.667360485498275,
           -30.697826456230523,
           -30.728292426962774,
           -30.758758397695022,
           -30.78922436842727,
           -30.81969033915952,
           -30.850156309891773,
           -30.88062228062402,
           -30.91108825135627,
           -30.94155422208852,
           -30.97202019282077,
           -31.00248616355302,
           -31.032952134285267,
           -31.06341810501751,
           -31.093884075749767,
           -31.124350046482014,
           -31.154816017214266,
           -31.185281987946514,
           -31.21574795867876,
           -31.246213929411017,
           -31.276679900143264,
           -31.307145870875512,
           -31.33761184160776,
           -31.36807781234001,
           -31.398543783072263,
           -31.429009753804507,
           -31.45947572453676,
           -31.48994169526901,
           -31.52040766600126,
           -31.550873636733506,
           -31.581339607465758,
           -31.611805578198005,
           -31.642271548930253,
           -31.67273751966251,
           -31.703203490394756,
           -31.733669461127004,
           -31.764135431859252,
           -31.7946014025915,
           -31.825067373323755,
           -31.855533344056006,
           -31.88599931478825,
           -31.916465285520502,
           -31.946931256252753,
           -31.977397226985,
           -32.00786319771725,
           -32.03832916844949,
           -32.068795139181745,
           -32.099261109913996,
           -32.12972708064625,
           -32.1601930513785,
           -32.19065902211075,
           -32.221124992842995,
           -32.25159096357525,
           -32.28205693430749,
           -32.31252290503974,
           -32.342988875771994,
           -32.373454846504245,
           -32.40392081723649,
           -32.43438678796874,
           -32.46485275870099,
           -32.495318729433244,
           -32.52578470016549,
           -32.55625067089774,
           -32.58915942959394,
           -32.62328958227212,
           -32.6574197349503,
           -32.69154988762849,
           -32.72568004030667,
           -32.75981019298485,
           -32.79384680395331,
           -32.82699477167752,
           -32.860142739401724,
           -32.893290707125935,
           -32.92643867485014,
           -32.95958664257435,
           -32.992734610298555,
           -33.02588257802277,
           -33.05903054574697,
           -33.09217851347118,
           -33.125326481195394,
           -33.1584744489196,
           -33.19162241664381,
           -33.22477038436802,
           -33.257918352092226,
           -33.29106631981644,
           -33.32421428754064,
           -33.35736225526485,
           -33.39051022298906,
           -33.42365819071327,
           -33.45680615843747,
           -33.489954126161685,
           -33.523102093885896,
           -33.5562500616101,
           -33.589398029334305,
           -33.622545997058516,
           -33.65569396478273,
           -33.68884193250693,
           -33.72198990023114,
           -33.755137867955355,
           -33.78828583567956,
           -33.82143380340377,
           -33.854581771127975,
           -33.88772973885218,
           -33.92087770657639,
           -33.954025674300595,
           -33.987173642024814,
           -34.02032160974902,
           -34.05346957747322,
           -34.086617545197434,
           -34.11976551292164,
           -34.15291348064585,
           -34.186061448370054,
           -34.21920941609427,
           -34.25235738381848,
           -34.28550535154268,
           -34.31865331926689,
           -34.3518012869911,
           -34.38494925471531,
           -34.41809722243952,
           -34.451245190163725,
           -34.484393157887936,
           -34.51754112561214,
           -34.55068909333635,
           -34.58383706106056,
           -34.61698502878476,
           -34.65013299650898,
           -34.68328096423318,
           -34.716428931957395,
           -34.7495768996816,
           -34.78272486740581,
           -34.81587283513002,
           -34.84902080285423,
           -34.88216877057843,
           -34.91531673830264,
           -34.948464706026854,
           -34.98161267375106,
           -35.01476064147527,
           -35.047908609199474,
           -35.081056576923686,
           -35.1142045446479,
           -35.147352512372095,
           -35.180500480096306,
           -35.21364844782052,
           -35.24679641554472,
           -35.27994438326893,
           -35.313092350993145,
           -35.280264096581845,
           -35.196583294032536,
           -35.12207331857019,
           -35.04756334310784,
           -34.973053367645484,
           -34.898543392183136,
           -34.82403341672079,
           -34.74952344125843,
           -34.67501346579608,
           -34.600373294013664,
           -34.52566801807743,
           -34.4509627421412,
           -34.376257466204976,
           -34.30155219026876,
           -34.226846914332526,
           -34.152141638396294,
           -34.07743636246008,
           -34.002731086523845,
           -33.92802581058762,
           -33.853320534651395,
           -33.77861525871516,
           -33.70390998277893,
           -33.62920470684272,
           -33.55449943090649,
           -33.47979415497026,
           -33.405088879034025,
           -33.33038360309781,
           -33.25567832716158,
           -33.18097305122535,
           -33.106267775289126,
           -33.0315624993529,
           -32.95685722341667,
           -32.88215194748045,
           -32.80744667154422,
           -32.732741395607995,
           -32.65803611967176,
           -32.58333084373554,
           -32.508625567799314,
           -32.43392029186309,
           -32.359215015926864,
           -32.28450973999063,
           -32.20980446405441,
           -32.13509918811819,
           -32.06039391218196,
           -31.985688636245722,
           -31.91098336030951,
           -31.836278084373276,
           -31.761572808437045,
           -31.686867532500823,
           -31.612162256564595,
           -31.53745698062837,
           -31.462751704692142,
           -31.38804642875592,
           -31.313341152819685,
           -31.238635876883457,
           -31.163930600947243,
           -31.08922532501101,
           -31.014520049074775,
           -30.939814773138554,
           -30.86510949720233,
           -30.7904042212661,
           -30.71569894532988,
           -30.64099366939365,
           -30.56628839345742,
           -30.491583117521195,
           -30.416877841584977,
           -30.342172565648745,
           -30.26746728971251,
           -30.192762013776296,
           -30.118056737840064,
           -30.043351461903836,
           -29.968646185967607,
           -29.893940910031386,
           -29.819235634095154,
           -29.744530358158933,
           -29.669825082222708,
           -29.595119806286476,
           -29.52041453035025,
           -29.445709254414027,
           -29.371003978477802,
           -29.29629870254157,
           -29.22159342660534,
           -29.146888150669117,
           -29.084890068460815,
           -29.048306373708368,
           -29.01172267895592,
           -28.975138984203465,
           -28.938555289451013,
           -28.901971594698566,
           -28.86538789994611,
           -28.82880420519366,
           -28.79222051044121,
           -28.75563681568876,
           -28.719053120936305,
           -28.682469426183854,
           -28.645885731431406,
           -28.609302036678955,
           -28.572718341926503,
           -28.53613464717405,
           -28.4995509524216,
           -28.46296725766915,
           -28.4263835629167,
           -28.389799868164246,
           -28.35321617341179,
           -28.316632478659344,
           -28.280048783906892,
           -28.243465089154437,
           -28.206881394401993,
           -28.170297699649538,
           -28.133714004897087,
           -28.097130310144635,
           -28.060352151164345,
           -28.023344169410997,
           -27.98633618765765,
           -27.9493282059043,
           -27.912320224150957,
           -27.875312242397612,
           -27.83830426064427,
           -27.801296278890923,
           -27.764288297137576,
           -27.727280315384235,
           -27.690272333630887,
           -27.65326435187754,
           -27.616256370124194,
           -27.579248388370846,
           -27.542240406617502,
           -27.50523242486415,
           -27.468224443110806,
           -27.431216461357465,
           -27.394208479604117,
           -27.35720049785077,
           -27.32019251609743,
           -27.28318453434408,
           -27.246176552590732,
           -27.20916857083739,
           -27.172160589084044,
           -27.135152607330696,
           -27.098144625577355,
           -27.061136643824007,
           -27.02412866207066,
           -26.987120680317314,
           -26.95011269856397,
           -26.913104716810622,
           -26.876096735057274,
           -26.839088753303933,
           -26.802080771550585,
           -26.765072789797237,
           -26.728064808043897,
           -26.69105682629055,
           -26.6540488445372,
           -26.61704086278386,
           -26.58003288103051,
           -26.543024899277164,
           -26.50601691752382,
           -26.469008935770475,
           -26.432000954017127,
           -26.394992972263783,
           -26.357984990510438,
           -26.32097700875709,
           -26.283969027003742,
           -26.2469610452504,
           -26.209953063497053,
           -26.172945081743705,
           -26.13593709999036,
           -26.098929118237017,
           -26.061921136483672,
           -25.997821936973978,
           -25.798266648682535,
           -25.598711360391082,
           -25.39915607209964,
           -25.19960078380823,
           -25.000045495516783,
           -24.800490207225334,
           -24.600934918933923,
           -24.401379630642477,
           -24.20182434235103,
           -24.002269054059624,
           -23.80271376576818,
           -23.60315847747673,
           -23.403603189185286,
           -23.204047900893876,
           -23.004492612602427,
           -22.80493732431098,
           -22.60538203601957,
           -22.405254612073108,
           -22.205055041558694,
           -22.00485547104432,
           -21.80465590052991,
           -21.604456330015495,
           -21.40425675950112,
           -21.20405718898671,
           -21.003857618472296,
           -20.80365804795788,
           -20.60345847744351,
           -20.403258906929096,
           -20.203059336414682,
           -20.00285976590031,
           -19.802660195385897,
           -19.602460624871487,
           -19.402261054357112,
           -19.202061483842698,
           -19.001861913328288,
           -18.801662342813874,
           -18.6014627722995,
           -18.401263201785085,
           -18.201063631270674,
           -18.0008640607563,
           -17.800664490241886,
           -17.600464919727475,
           -17.4002653492131,
           -17.200065778698686,
           -16.999866208184276,
           -16.7996666376699,
           -16.59946706715549,
           -16.399267496641077,
           -16.199067926126666,
           -15.99886835561229,
           -15.79866878509788,
           -15.598469214583467,
           -15.39826964406909,
           -15.198070073554678,
           -14.997870503040266,
           -14.797670932525891,
           -14.597471362011477,
           -14.397271791497069,
           -14.197072220982655,
           -13.996872650468282,
           -13.796673079953868,
           -13.596473509439457,
           -13.39627393892508,
           -13.196074368410668,
           -12.995874797896256,
           -12.795378197452195,
           -12.594112652633044,
           -12.392847107813896,
           -12.191581562994783,
           -11.990316018175632,
           -11.789050473356482,
           -11.587784928537332,
           -11.386519383718218,
           -11.185253838899069,
           -10.98398829407992,
           -10.782722749260806,
           -10.581457204441655,
           -10.380191659622508,
           -10.178926114803392,
           -9.977660569984243,
           -9.776395025165094,
           -9.575129480345943,
           -9.37386393552683
          ],
          [
           -26.96835480113431,
           -26.999914931769958,
           -27.031475062405605,
           -27.06303519304125,
           -27.0945953236769,
           -27.126155454312546,
           -27.157715584948193,
           -27.18927571558384,
           -27.22083584621949,
           -27.25239597685514,
           -27.283956107490788,
           -27.315516238126435,
           -27.34707636876208,
           -27.37863649939773,
           -27.410196630033376,
           -27.44175676066903,
           -27.473316891304673,
           -27.50487702194032,
           -27.536437152575967,
           -27.567997283211618,
           -27.59955741384726,
           -27.631117544482912,
           -27.66267767511856,
           -27.69423780575421,
           -27.725797936389853,
           -27.7573580670255,
           -27.78891819766115,
           -27.820478328296794,
           -27.852038458932448,
           -27.88359858956809,
           -27.915158720203742,
           -27.94671885083939,
           -27.978278981475036,
           -28.009839112110683,
           -28.04139924274633,
           -28.072959373381977,
           -28.10451950401763,
           -28.136079634653274,
           -28.167639765288925,
           -28.19919989592457,
           -28.23076002656022,
           -28.262320157195866,
           -28.293880287831513,
           -28.32544041846716,
           -28.357000549102807,
           -28.388560679738458,
           -28.420120810374105,
           -28.451680941009755,
           -28.483241071645402,
           -28.51480120228105,
           -28.546361332916696,
           -28.577921463552343,
           -28.60948159418799,
           -28.641041724823637,
           -28.672601855459284,
           -28.704161986094935,
           -28.73572211673058,
           -28.76728224736623,
           -28.798842378001876,
           -28.830402508637523,
           -28.86196263927317,
           -28.89352276990882,
           -28.925082900544467,
           -28.956643031180114,
           -28.98820316181576,
           -29.019763292451408,
           -29.05132342308706,
           -29.082883553722706,
           -29.114443684358353,
           -29.146003814994,
           -29.177563945629647,
           -29.209124076265297,
           -29.240684206900944,
           -29.271529146477196,
           -29.300943706705244,
           -29.330358266933292,
           -29.35977282716134,
           -29.389187387389388,
           -29.41860194761744,
           -29.448016507845484,
           -29.477431068073532,
           -29.50684562830158,
           -29.53626018852963,
           -29.56567474875768,
           -29.594276638915293,
           -29.622715995058822,
           -29.651155351202352,
           -29.679594707345885,
           -29.70803406348941,
           -29.73647341963294,
           -29.76491277577647,
           -29.79335213192,
           -29.821791488063532,
           -29.850230844207058,
           -29.8793457376745,
           -29.909811708406753,
           -29.940277679139,
           -29.970743649871253,
           -30.001209620603504,
           -30.031675591335755,
           -30.062141562068,
           -30.09260753280025,
           -30.1230735035325,
           -30.153539474264747,
           -30.184005444997,
           -30.21447141572925,
           -30.244937386461498,
           -30.275403357193746,
           -30.305869327925997,
           -30.336335298658245,
           -30.366801269390496,
           -30.397267240122744,
           -30.427733210854992,
           -30.45819918158724,
           -30.48866515231949,
           -30.519131123051743,
           -30.549597093783994,
           -30.58006306451624,
           -30.61052903524849,
           -30.64099500598074,
           -30.67146097671299,
           -30.70192694744524,
           -30.73239291817749,
           -30.76285888890974,
           -30.79332485964199,
           -30.823790830374236,
           -30.854256801106487,
           -30.88472277183873,
           -30.915188742570983,
           -30.945654713303234,
           -30.976120684035482,
           -31.006586654767734,
           -31.037052625499985,
           -31.067518596232233,
           -31.097984566964485,
           -31.128450537696732,
           -31.15891650842898,
           -31.18938247916123,
           -31.219848449893483,
           -31.25031442062573,
           -31.28078039135798,
           -31.311246362090227,
           -31.34171233282248,
           -31.372178303554726,
           -31.402644274286978,
           -31.43311024501923,
           -31.463576215751473,
           -31.494042186483725,
           -31.524508157215976,
           -31.554974127948224,
           -31.585440098680472,
           -31.615906069412723,
           -31.64637204014497,
           -31.676838010877223,
           -31.70730398160947,
           -31.737769952341722,
           -31.76823592307397,
           -31.798701893806218,
           -31.82916786453847,
           -31.85963383527072,
           -31.89009980600297,
           -31.92056577673522,
           -31.951031747467464,
           -31.981497718199716,
           -32.011963688931964,
           -32.042429659664215,
           -32.07289563039647,
           -32.104278005178536,
           -32.13611858198552,
           -32.167959158792506,
           -32.19979973559949,
           -32.231640312406476,
           -32.26348088921346,
           -32.29532146602045,
           -32.32716204282743,
           -32.35900261963442,
           -32.3908431964414,
           -32.42268377324839,
           -32.45452435005537,
           -32.48636492686236,
           -32.51850931077629,
           -32.551565118684564,
           -32.58462092659285,
           -32.61767673450113,
           -32.650732542409415,
           -32.6837883503177,
           -32.71684415822598,
           -32.74989996613426,
           -32.78295577404254,
           -32.81601158195082,
           -32.8490673898591,
           -32.882123197767385,
           -32.91517900567567,
           -32.948234813583944,
           -32.98129062149223,
           -33.01434642940051,
           -33.047402237308795,
           -33.08045804521707,
           -33.113513853125355,
           -33.14656966103364,
           -33.179625468941914,
           -33.2126812768502,
           -33.24573708475848,
           -33.278792892666765,
           -33.31184870057505,
           -33.344904508483324,
           -33.37796031639161,
           -33.41101612429989,
           -33.444071932208175,
           -33.47712774011646,
           -33.51018354802473,
           -33.54323935593302,
           -33.5762951638413,
           -33.60935097174958,
           -33.64240677965786,
           -33.675462587566145,
           -33.70851839547443,
           -33.741574203382704,
           -33.77463001129099,
           -33.80768581919927,
           -33.840741627107555,
           -33.87379743501583,
           -33.906853242924115,
           -33.9399090508324,
           -33.97296485874068,
           -34.00602066664895,
           -34.03907647455725,
           -34.07213228246552,
           -34.1051880903738,
           -34.138243898282084,
           -34.17129970619037,
           -34.20435551409865,
           -34.23741132200693,
           -34.27046712991521,
           -34.303522937823494,
           -34.33657874573177,
           -34.369634553640054,
           -34.40269036154834,
           -34.43574616945662,
           -34.468801977364905,
           -34.50185778527319,
           -34.534913593181464,
           -34.56796940108975,
           -34.601025208998024,
           -34.63408101690631,
           -34.66713682481459,
           -34.700192632722874,
           -34.73324844063116,
           -34.766304248539434,
           -34.79936005644772,
           -34.787853211019375,
           -34.7317837122544,
           -34.675714213489435,
           -34.619644714724465,
           -34.563575215959496,
           -34.50750571719453,
           -34.45143621842956,
           -34.3953667196646,
           -34.339297220899624,
           -34.28322772213467,
           -34.22715822336969,
           -34.17108872460472,
           -34.11501922583976,
           -34.05894972707479,
           -34.00288022830982,
           -33.94681072954486,
           -33.890741230779895,
           -33.834671732014925,
           -33.778602233249956,
           -33.72253273448499,
           -33.66646323572002,
           -33.61039373695505,
           -33.55432423819009,
           -33.49825473942512,
           -33.442185240660145,
           -33.38611574189518,
           -33.33004624313022,
           -33.27397674436524,
           -33.21790724560028,
           -33.16183774683532,
           -33.101455793282746,
           -33.026750517346514,
           -32.952045241410296,
           -32.877339965474064,
           -32.80263468953784,
           -32.727929413601615,
           -32.65322413766538,
           -32.57851886172916,
           -32.50381358579293,
           -32.42910830985671,
           -32.35440303392048,
           -32.27969775798425,
           -32.204992482048034,
           -32.1302872061118,
           -32.05558193017557,
           -31.980876654239353,
           -31.90617137830312,
           -31.83146610236689,
           -31.75676082643067,
           -31.682055550494443,
           -31.607350274558215,
           -31.532644998621986,
           -31.457939722685765,
           -31.383234446749533,
           -31.3085291708133,
           -31.23382389487709,
           -31.15911861894086,
           -31.084413343004627,
           -31.009708067068402,
           -30.935002791132177,
           -30.860297515195946,
           -30.785592239259724,
           -30.7108869633235,
           -30.63618168738727,
           -30.561476411451046,
           -30.48677113551482,
           -30.41206585957859,
           -30.337360583642358,
           -30.262655307706144,
           -30.187950031769912,
           -30.113244755833684,
           -30.038539479897455,
           -29.963834203961234,
           -29.889128928025002,
           -29.814423652088777,
           -29.739718376152556,
           -29.66501310021632,
           -29.590307824280103,
           -29.515602548343878,
           -29.440897272407646,
           -29.366191996471414,
           -29.29148672053519,
           -29.216781444598965,
           -29.154783362390667,
           -29.118199667638216,
           -29.081615972885764,
           -29.04503227813331,
           -29.00844858338086,
           -28.971864888628414,
           -28.93528119387596,
           -28.898697499123507,
           -28.862113804371056,
           -28.825530109618605,
           -28.788946414866153,
           -28.7523627201137,
           -28.71577902536125,
           -28.6791953306088,
           -28.642611635856348,
           -28.6060279411039,
           -28.569444246351445,
           -28.532860551598993,
           -28.49627685684655,
           -28.459693162094094,
           -28.423109467341636,
           -28.386525772589188,
           -28.34994207783674,
           -28.313358383084285,
           -28.276774688331837,
           -28.240190993579382,
           -28.20360729882693,
           -28.16702360407448,
           -28.130439909322035,
           -28.093856214569577,
           -28.057272519817126,
           -28.020688825064678,
           -27.984105130312226,
           -27.94752143555977,
           -27.91093774080732,
           -27.874354046054872,
           -27.837770351302417,
           -27.80118665654997,
           -27.764602961797515,
           -27.728019267045067,
           -27.691435572292615,
           -27.654851877540167,
           -27.61826818278771,
           -27.581684488035258,
           -27.545100793282806,
           -27.508517098530362,
           -27.471933403777903,
           -27.43534970902546,
           -27.398766014273004,
           -27.362182319520553,
           -27.3255986247681,
           -27.289014930015654,
           -27.2524312352632,
           -27.215847540510744,
           -27.1792638457583,
           -27.14268015100584,
           -27.106096456253393,
           -27.06951276150094,
           -27.03292906674849,
           -26.996345371996036,
           -26.959761677243588,
           -26.923177982491136,
           -26.886594287738685,
           -26.850010592986237,
           -26.813426898233786,
           -26.776843203481334,
           -26.74025950872888,
           -26.70253506419263,
           -26.66422223384552,
           -26.625909403498415,
           -26.58759657315131,
           -26.549283742804207,
           -26.5109709124571,
           -26.472658082109994,
           -26.434345251762892,
           -26.396032421415786,
           -26.35771959106868,
           -26.319406760721577,
           -26.28109393037447,
           -26.242781100027358,
           -26.204468269680255,
           -26.166155439333156,
           -26.127842608986047,
           -26.06547579629011,
           -25.882839071849986,
           -25.700202347409864,
           -25.517565622969737,
           -25.334928898529647,
           -25.15229217408953,
           -24.9696554496494,
           -24.787018725209315,
           -24.60438200076919,
           -24.421745276329066,
           -24.239108551888975,
           -24.056471827448853,
           -23.87383510300873,
           -23.684211030884036,
           -23.484011460369658,
           -23.283811889855247,
           -23.083612319340833,
           -22.88341274882646,
           -22.683213178312045,
           -22.483013607797634,
           -22.282814037283263,
           -22.082614466768852,
           -21.88241489625444,
           -21.682215325740064,
           -21.48201575522565,
           -21.28181618471124,
           -21.081616614196825,
           -20.88141704368245,
           -20.68121747316804,
           -20.481017902653626,
           -20.28081833213925,
           -20.08061876162484,
           -19.880419191110427,
           -19.680219620596052,
           -19.480020050081638,
           -19.279820479567228,
           -19.079620909052814,
           -18.879421338538442,
           -18.67922176802403,
           -18.479022197509618,
           -18.278822626995243,
           -18.07862305648083,
           -17.878423485966415,
           -17.678223915452044,
           -17.47802434493763,
           -17.277824774423216,
           -17.077625203908845,
           -16.87742563339443,
           -16.67722606288002,
           -16.477026492365606,
           -16.27682692185123,
           -16.07662735133682,
           -15.876427780822407,
           -15.676228210308032,
           -15.476028639793618,
           -15.275829069279208,
           -15.075629498764833,
           -14.875429928250421,
           -14.675230357736009,
           -14.475030787221598,
           -14.274831216707224,
           -14.07463164619281,
           -13.874432075678397,
           -13.674232505164023,
           -13.474032934649612,
           -13.273833364135196,
           -13.073633793620823,
           -12.873434223106411,
           -12.673234652592,
           -12.473035082077626,
           -12.272835511563214,
           -12.062363179482734,
           -11.848801856145785,
           -11.63524053280888,
           -11.42167920947193,
           -11.208117886134984,
           -10.994556562798076,
           -10.780995239461129,
           -10.567433916124182,
           -10.353872592787274,
           -10.140311269450326,
           -9.926749946113377,
           -9.713188622776432,
           -9.499627299439524
          ],
          [
           -26.54822452165358,
           -26.579784652289227,
           -26.611344782924874,
           -26.64290491356052,
           -26.674465044196168,
           -26.706025174831815,
           -26.737585305467462,
           -26.76914543610311,
           -26.80070556673876,
           -26.832265697374407,
           -26.863825828010057,
           -26.8953859586457,
           -26.926946089281348,
           -26.958506219917,
           -26.990066350552645,
           -27.021626481188292,
           -27.05318661182394,
           -27.08474674245959,
           -27.116306873095237,
           -27.147867003730884,
           -27.17942713436653,
           -27.21098726500218,
           -27.242547395637825,
           -27.274107526273475,
           -27.305667656909122,
           -27.33722778754477,
           -27.36878791818042,
           -27.400348048816063,
           -27.431908179451717,
           -27.463468310087357,
           -27.49502844072301,
           -27.526588571358655,
           -27.558148701994305,
           -27.589708832629952,
           -27.6212689632656,
           -27.652829093901246,
           -27.684389224536897,
           -27.71594935517254,
           -27.747509485808195,
           -27.779069616443838,
           -27.810629747079485,
           -27.84218987771513,
           -27.873750008350783,
           -27.90531013898643,
           -27.936870269622077,
           -27.968430400257724,
           -27.999990530893374,
           -28.031550661529018,
           -28.063110792164668,
           -28.09467092280031,
           -28.126231053435966,
           -28.15779118407161,
           -28.18935131470726,
           -28.220911445342903,
           -28.25247157597855,
           -28.2840317066142,
           -28.31559183724985,
           -28.34536399126828,
           -28.374778551496327,
           -28.40419311172438,
           -28.433607671952426,
           -28.463022232180478,
           -28.49243679240852,
           -28.521851352636567,
           -28.551265912864622,
           -28.580680473092666,
           -28.610095033320714,
           -28.639509593548762,
           -28.668924153776814,
           -28.698338714004862,
           -28.727753274232906,
           -28.757167834460954,
           -28.786582394689006,
           -28.815996954917054,
           -28.845411515145102,
           -28.87482607537315,
           -28.904240635601198,
           -28.933655195829246,
           -28.963069756057294,
           -28.992484316285342,
           -29.02189887651339,
           -29.051313436741438,
           -29.080727996969486,
           -29.110142557197538,
           -29.13874444735515,
           -29.16718380349868,
           -29.19562315964221,
           -29.22406251578574,
           -29.25250187192927,
           -29.2809412280728,
           -29.309380584216328,
           -29.337819940359857,
           -29.366259296503387,
           -29.394698652646916,
           -29.423138008790445,
           -29.451577364933975,
           -29.480016721077504,
           -29.508456077221034,
           -29.536895433364567,
           -29.565334789508096,
           -29.593774145651622,
           -29.62221350179515,
           -29.650652857938685,
           -29.67909221408221,
           -29.707531570225743,
           -29.73597092636927,
           -29.7644102825128,
           -29.792849638656328,
           -29.821288994799858,
           -29.849728350943387,
           -29.87816770708692,
           -29.908295907514333,
           -29.93876187824658,
           -29.96922784897883,
           -29.999693819711077,
           -30.030159790443328,
           -30.06062576117558,
           -30.091091731907827,
           -30.121557702640075,
           -30.152023673372327,
           -30.182489644104574,
           -30.21295561483683,
           -30.243421585569074,
           -30.273887556301325,
           -30.304353527033577,
           -30.33481949776582,
           -30.365285468498072,
           -30.395751439230324,
           -30.426217409962568,
           -30.45668338069482,
           -30.48714935142707,
           -30.51761532215932,
           -30.54808129289157,
           -30.57854726362382,
           -30.60901323435607,
           -30.639479205088318,
           -30.669945175820565,
           -30.700411146552817,
           -30.73087711728507,
           -30.761343088017316,
           -30.791809058749564,
           -30.822275029481812,
           -30.852741000214063,
           -30.88320697094631,
           -30.913672941678563,
           -30.944138912410814,
           -30.97460488314306,
           -31.00507085387531,
           -31.035536824607558,
           -31.066002795339813,
           -31.096468766072057,
           -31.12693473680431,
           -31.157400707536556,
           -31.187866678268808,
           -31.218332649001056,
           -31.248798619733307,
           -31.27926459046556,
           -31.309730561197803,
           -31.340196531930054,
           -31.370662502662306,
           -31.401128473394554,
           -31.431594444126805,
           -31.462060414859053,
           -31.4925263855913,
           -31.522992356323552,
           -31.5534583270558,
           -31.58392429778805,
           -31.615306672570124,
           -31.647147249377106,
           -31.67898782618409,
           -31.710828402991076,
           -31.74266897979806,
           -31.774509556605047,
           -31.806350133412035,
           -31.838190710219017,
           -31.870031287026002,
           -31.901871863832987,
           -31.933712440639976,
           -31.965553017446958,
           -31.997393594253946,
           -32.02923417106093,
           -32.06107474786791,
           -32.0929153246749,
           -32.12475590148188,
           -32.15659647828887,
           -32.18843705509586,
           -32.22027763190283,
           -32.25211820870982,
           -32.28395878551681,
           -32.315799362323794,
           -32.34763993913077,
           -32.379480515937765,
           -32.41132109274474,
           -32.443161669551735,
           -32.47500224635871,
           -32.5068428231657,
           -32.53868339997269,
           -32.57052397677967,
           -32.60236455358666,
           -32.63420513039364,
           -32.666045707200624,
           -32.6980888215999,
           -32.73114462950819,
           -32.76420043741647,
           -32.79725624532475,
           -32.83031205323303,
           -32.86336786114131,
           -32.8964236690496,
           -32.92947947695788,
           -32.962535284866156,
           -32.99559109277444,
           -33.02864690068272,
           -33.061702708591,
           -33.09475851649928,
           -33.12781432440757,
           -33.16087013231585,
           -33.19392594022413,
           -33.22698174813241,
           -33.26003755604069,
           -33.29309336394898,
           -33.32614917185725,
           -33.359204979765536,
           -33.39226078767382,
           -33.4253165955821,
           -33.45837240349038,
           -33.49142821139866,
           -33.524484019306946,
           -33.55753982721522,
           -33.590595635123506,
           -33.62365144303179,
           -33.65670725094007,
           -33.68976305884836,
           -33.72281886675663,
           -33.75587467466492,
           -33.7889304825732,
           -33.821986290481476,
           -33.85504209838976,
           -33.88809790629804,
           -33.921153714206326,
           -33.9542095221146,
           -33.98726533002289,
           -34.02032113793117,
           -34.053376945839446,
           -34.08643275374773,
           -34.11948856165601,
           -34.152544369564296,
           -34.18560017747257,
           -34.21865598538086,
           -34.25171179328914,
           -34.284767601197416,
           -34.27326075576908,
           -34.2171912570041,
           -34.16112175823914,
           -34.105052259474164,
           -34.0489827607092,
           -33.99291326194424,
           -33.93684376317927,
           -33.8807742644143,
           -33.82470476564933,
           -33.768635266884374,
           -33.712565768119404,
           -33.65649626935443,
           -33.600426770589465,
           -33.544357271824495,
           -33.48828777305953,
           -33.43221827429456,
           -33.37614877552959,
           -33.32007927676463,
           -33.26400977799966,
           -33.2079402792347,
           -33.15187078046972,
           -33.09580128170475,
           -33.03973178293979,
           -32.98366228417482,
           -32.92759278540985,
           -32.87152328664489,
           -32.81545378787992,
           -32.759384289114955,
           -32.703314790349985,
           -32.64724529158502,
           -32.59117579282005,
           -32.535106294055076,
           -32.47903679529012,
           -32.422967296525144,
           -32.366897797760174,
           -32.31082829899521,
           -32.25475880023025,
           -32.19868930146528,
           -32.14261980270031,
           -32.08655030393535,
           -32.03048080517038,
           -31.974411306405408,
           -31.918341807640445,
           -31.862272308875472,
           -31.8062028101105,
           -31.750133311345543,
           -31.694063812580573,
           -31.637994313815604,
           -31.581924815050638,
           -31.52585531628567,
           -31.469785817520698,
           -31.413716318755732,
           -31.357646819990766,
           -31.301577321225796,
           -31.245507822460823,
           -31.189438323695867,
           -31.133368824930898,
           -31.077299326165928,
           -31.02122982740096,
           -30.965160328635996,
           -30.90909082987102,
           -30.853021331106056,
           -30.780780257253344,
           -30.706074981317116,
           -30.63136970538089,
           -30.556664429444666,
           -30.481959153508434,
           -30.407253877572202,
           -30.33254860163599,
           -30.25784332569976,
           -30.183138049763528,
           -30.108432773827303,
           -30.033727497891082,
           -29.959022221954847,
           -29.88431694601862,
           -29.809611670082404,
           -29.73490639414617,
           -29.660201118209944,
           -29.585495842273723,
           -29.51079056633749,
           -29.436085290401262,
           -29.361380014465034,
           -29.286674738528816,
           -29.22467665632051,
           -29.188092961568064,
           -29.15150926681561,
           -29.114925572063157,
           -29.078341877310706,
           -29.041758182558258,
           -29.005174487805803,
           -28.96859079305335,
           -28.932007098300907,
           -28.895423403548453,
           -28.858839708795998,
           -28.82225601404355,
           -28.7856723192911,
           -28.749088624538643,
           -28.712504929786196,
           -28.675921235033748,
           -28.63933754028129,
           -28.602753845528845,
           -28.56617015077639,
           -28.52958645602394,
           -28.493002761271484,
           -28.456419066519036,
           -28.41983537176658,
           -28.38325167701413,
           -28.346667982261685,
           -28.310084287509234,
           -28.273500592756783,
           -28.236586682666612,
           -28.19827385231951,
           -28.1599610219724,
           -28.12164819162529,
           -28.083335361278188,
           -28.04502253093108,
           -28.006709700583976,
           -27.968396870236873,
           -27.930084039889767,
           -27.89177120954266,
           -27.85345837919556,
           -27.81514554884845,
           -27.776832718501346,
           -27.738519888154244,
           -27.700207057807134,
           -27.661894227460028,
           -27.623581397112922,
           -27.58526856676582,
           -27.546955736418713,
           -27.508642906071607,
           -27.4703300757245,
           -27.432017245377395,
           -27.393704415030292,
           -27.355391584683183,
           -27.31707875433608,
           -27.278765923988978,
           -27.240453093641865,
           -27.202140263294766,
           -27.16382743294766,
           -27.12551460260055,
           -27.087201772253444,
           -27.04888894190634,
           -27.01057611155923,
           -26.97226328121213,
           -26.933950450865026,
           -26.895637620517924,
           -26.857324790170814,
           -26.819011959823712,
           -26.780699129476602,
           -26.7423862991295,
           -26.704073468782394,
           -26.665760638435287,
           -26.62744780808818,
           -26.589134977741075,
           -26.550822147393973,
           -26.512509317046863,
           -26.47419648669976,
           -26.43588365635265,
           -26.397570826005552,
           -26.35925799565844,
           -26.320945165311343,
           -26.282632334964234,
           -26.244319504617124,
           -26.20600667427002,
           -26.16769384392292,
           -26.12938101357581,
           -26.067014200879875,
           -25.88437747643975,
           -25.701740751999626,
           -25.519104027559504,
           -25.336467303119413,
           -25.15383057867929,
           -24.971193854239168,
           -24.78855712979908,
           -24.605920405358955,
           -24.423283680918832,
           -24.24064695647874,
           -24.05801023203862,
           -23.875373507598496,
           -23.69273678315837,
           -23.51010005871828,
           -23.327463334278157,
           -23.144826609838034,
           -22.962189885397947,
           -22.77955316095782,
           -22.5969164365177,
           -22.414279712077608,
           -22.231642987637485,
           -22.049006263197363,
           -21.86636953875727,
           -21.68373281431715,
           -21.501096089877027,
           -21.318459365436905,
           -21.135822640996814,
           -20.95318591655669,
           -20.770549192116565,
           -20.587912467676475,
           -20.405275743236356,
           -20.222639018796233,
           -20.040002294356142,
           -19.857365569916016,
           -19.674728845475894,
           -19.492092121035768,
           -19.30945539659568,
           -19.126818672155558,
           -18.944181947715432,
           -18.758707092487832,
           -18.56291189407156,
           -18.367116695655287,
           -18.171321497239052,
           -17.958631100935786,
           -17.74506977759884,
           -17.53150845426193,
           -17.317947130924985,
           -17.104385807588038,
           -16.89082448425109,
           -16.677263160914183,
           -16.463701837577236,
           -16.25014051424029,
           -16.03657919090338,
           -15.823017867566433,
           -15.609456544229486,
           -15.395895220892578,
           -15.182333897555631,
           -14.968772574218685,
           -14.755211250881736,
           -14.54164992754483,
           -14.328088604207883,
           -14.114527280870934,
           -13.900965957534027,
           -13.68740463419708,
           -13.473843310860133,
           -13.260281987523225,
           -13.046720664186278,
           -12.83315934084933,
           -12.619598017512422,
           -12.406036694175473,
           -12.192475370838526,
           -11.97891404750158,
           -11.765352724164673,
           -11.551791400827726,
           -11.33823007749078,
           -11.12466875415387,
           -10.911107430816923,
           -10.697546107479976,
           -10.483984784143068,
           -10.270423460806121,
           -10.056862137469174,
           -9.843300814132226,
           -9.629739490795318
          ],
          [
           -26.12809424217285,
           -26.159654372808497,
           -26.191214503444144,
           -26.22277463407979,
           -26.25433476471544,
           -26.285894895351092,
           -26.317455025986735,
           -26.349015156622386,
           -26.380575287258033,
           -26.41213541789368,
           -26.443695548529327,
           -26.475255679164974,
           -26.50681580980062,
           -26.53837594043627,
           -26.56993607107192,
           -26.601496201707565,
           -26.633056332343212,
           -26.664616462978863,
           -26.69617659361451,
           -26.727736724250157,
           -26.759296854885804,
           -26.79085698552145,
           -26.822417116157098,
           -26.85397724679275,
           -26.885537377428392,
           -26.917097508064042,
           -26.94865763869969,
           -26.980217769335336,
           -27.011777899970987,
           -27.043338030606634,
           -27.074898161242277,
           -27.10645829187793,
           -27.13801842251357,
           -27.169578553149226,
           -27.20113868378487,
           -27.23269881442052,
           -27.264258945056167,
           -27.295819075691817,
           -27.327379206327464,
           -27.35893933696311,
           -27.389784275831325,
           -27.41919883605937,
           -27.44861339628742,
           -27.47802795651547,
           -27.507442516743517,
           -27.536857076971565,
           -27.566271637199616,
           -27.59568619742766,
           -27.62510075765571,
           -27.654515317883757,
           -27.683929878111805,
           -27.713344438339856,
           -27.7427589985679,
           -27.77217355879595,
           -27.801588119024,
           -27.831002679252045,
           -27.8604172394801,
           -27.889831799708144,
           -27.919246359936192,
           -27.94866092016424,
           -27.978075480392288,
           -28.00749004062034,
           -28.036904600848388,
           -28.066319161076436,
           -28.095733721304484,
           -28.12514828153253,
           -28.15456284176058,
           -28.183977401988628,
           -28.213391962216676,
           -28.242806522444724,
           -28.272221082672772,
           -28.30163564290082,
           -28.331050203128868,
           -28.360464763356916,
           -28.389879323584964,
           -28.419293883813015,
           -28.448708444041063,
           -28.478123004269108,
           -28.507537564497156,
           -28.536952124725207,
           -28.566366684953255,
           -28.5957812451813,
           -28.62519580540935,
           -28.6546103656374,
           -28.683212255795013,
           -28.711651611938546,
           -28.74009096808207,
           -28.7685303242256,
           -28.79696968036913,
           -28.82540903651266,
           -28.85384839265619,
           -28.88228774879972,
           -28.91072710494325,
           -28.93916646108678,
           -28.967605817230307,
           -28.99604517337384,
           -29.024484529517366,
           -29.0529238856609,
           -29.081363241804425,
           -29.109802597947954,
           -29.138241954091487,
           -29.166681310235013,
           -29.195120666378546,
           -29.22356002252208,
           -29.251999378665605,
           -29.28043873480913,
           -29.308878090952664,
           -29.337317447096193,
           -29.365756803239723,
           -29.39419615938325,
           -29.422635515526782,
           -29.451074871670315,
           -29.479514227813837,
           -29.50795358395737,
           -29.5363929401009,
           -29.564832296244425,
           -29.593271652387962,
           -29.621711008531488,
           -29.650150364675017,
           -29.678589720818547,
           -29.707029076962076,
           -29.735468433105606,
           -29.76390778924913,
           -29.792347145392664,
           -29.820786501536197,
           -29.849225857679723,
           -29.877665213823253,
           -29.906780106621913,
           -29.93724607735416,
           -29.967712048086412,
           -29.99817801881866,
           -30.02864398955091,
           -30.05910996028316,
           -30.08957593101541,
           -30.120041901747662,
           -30.150507872479906,
           -30.180973843212158,
           -30.211439813944406,
           -30.241905784676657,
           -30.27237175540891,
           -30.302837726141156,
           -30.333303696873404,
           -30.363769667605656,
           -30.394235638337904,
           -30.424701609070155,
           -30.455167579802406,
           -30.48563355053465,
           -30.516099521266902,
           -30.54656549199915,
           -30.5770314627314,
           -30.60749743346365,
           -30.6379634041959,
           -30.66842937492815,
           -30.6988953456604,
           -30.729361316392648,
           -30.759827287124896,
           -30.79029325785715,
           -30.820759228589395,
           -30.851225199321647,
           -30.881691170053895,
           -30.912157140786146,
           -30.942623111518397,
           -30.973089082250645,
           -31.003555052982893,
           -31.03402102371514,
           -31.064486994447392,
           -31.09495296517964,
           -31.126335339961717,
           -31.1581759167687,
           -31.190016493575683,
           -31.221857070382672,
           -31.253697647189654,
           -31.28553822399664,
           -31.317378800803624,
           -31.34921937761061,
           -31.381059954417594,
           -31.41290053122458,
           -31.444741108031568,
           -31.47658168483855,
           -31.508422261645535,
           -31.54026283845252,
           -31.572103415259505,
           -31.60394399206649,
           -31.635784568873476,
           -31.66762514568046,
           -31.699465722487446,
           -31.73130629929443,
           -31.76314687610141,
           -31.7949874529084,
           -31.826828029715386,
           -31.85866860652237,
           -31.890509183329357,
           -31.922349760136335,
           -31.954190336943327,
           -31.986030913750312,
           -32.0178714905573,
           -32.04971206736428,
           -32.08155264417126,
           -32.11339322097825,
           -32.14523379778524,
           -32.177074374592216,
           -32.20891495139921,
           -32.240755528206186,
           -32.27259610501317,
           -32.30443668182016,
           -32.33627725862714,
           -32.36811783543413,
           -32.39995841224111,
           -32.4317989890481,
           -32.46363956585508,
           -32.49548014266207,
           -32.52732071946905,
           -32.55916129627604,
           -32.59100187308302,
           -32.62284244989001,
           -32.65468302669699,
           -32.68652360350398,
           -32.718364180310964,
           -32.75020475711794,
           -32.782045333924934,
           -32.81388591073191,
           -32.8457264875389,
           -32.877668332423525,
           -32.91072414033181,
           -32.943779948240085,
           -32.976835756148375,
           -33.00989156405666,
           -33.042947371964935,
           -33.07600317987322,
           -33.1090589877815,
           -33.14211479568978,
           -33.17517060359806,
           -33.20822641150634,
           -33.24128221941463,
           -33.274338027322905,
           -33.30739383523119,
           -33.340449643139465,
           -33.37350545104775,
           -33.40656125895603,
           -33.439617066864315,
           -33.4726728747726,
           -33.50572868268088,
           -33.53878449058916,
           -33.57184029849745,
           -33.604896106405725,
           -33.637951914314,
           -33.671007722222285,
           -33.70406353013057,
           -33.737119338038845,
           -33.770175145947135,
           -33.758668300518785,
           -33.702598801753815,
           -33.64652930298885,
           -33.59045980422389,
           -33.53439030545891,
           -33.47832080669395,
           -33.42225130792898,
           -33.36618180916401,
           -33.31011231039904,
           -33.25404281163408,
           -33.19797331286911,
           -33.14190381410414,
           -33.08583431533918,
           -33.02976481657421,
           -32.97369531780924,
           -32.917625819044275,
           -32.861556320279306,
           -32.805486821514336,
           -32.74941732274937,
           -32.6933478239844,
           -32.637278325219434,
           -32.581208826454464,
           -32.5251393276895,
           -32.46906982892453,
           -32.41300033015956,
           -32.35693083139459,
           -32.30086133262963,
           -32.24479183386466,
           -32.1887223350997,
           -32.13265283633473,
           -32.07658333756976,
           -32.02051383880479,
           -31.96444434003983,
           -31.908374841274856,
           -31.852305342509887,
           -31.79623584374492,
           -31.740166344979954,
           -31.684096846214985,
           -31.628027347450015,
           -31.571957848685052,
           -31.515888349920083,
           -31.45981885115512,
           -31.40374935239015,
           -31.347679853625184,
           -31.29161035486021,
           -31.235540856095255,
           -31.179471357330282,
           -31.12340185856531,
           -31.067332359800343,
           -31.011262861035377,
           -30.955193362270407,
           -30.899123863505444,
           -30.84305436474048,
           -30.786984865975505,
           -30.73091536721054,
           -30.674845868445576,
           -30.618776369680603,
           -30.562706870915633,
           -30.506637372150664,
           -30.4505678733857,
           -30.39449837462073,
           -30.33842887585577,
           -30.282359377090803,
           -30.226289878325833,
           -30.170220379560867,
           -30.114150880795904,
           -30.058081382030934,
           -30.006165692380762,
           -29.960342287108634,
           -29.9145188818365,
           -29.868695476564366,
           -29.822872071292235,
           -29.777048666020107,
           -29.73122526074797,
           -29.685401855475842,
           -29.639578450203707,
           -29.593755044931576,
           -29.54793163965945,
           -29.502108234387315,
           -29.45628482911518,
           -29.410461423843046,
           -29.36463801857092,
           -29.318814613298787,
           -29.275466877144595,
           -29.237070479226276,
           -29.198674081307963,
           -29.160277683389644,
           -29.12188128547133,
           -29.083484887553013,
           -29.045088489634693,
           -29.006692091716378,
           -28.968295693798062,
           -28.929899295879746,
           -28.891502897961423,
           -28.85310650004311,
           -28.8147101021248,
           -28.77631370420648,
           -28.73791730628816,
           -28.69952090836984,
           -28.66112451045153,
           -28.622728112533213,
           -28.584331714614898,
           -28.54593531669658,
           -28.507538918778263,
           -28.469142520859947,
           -28.43074612294163,
           -28.39234972502331,
           -28.353953327104993,
           -28.315556929186677,
           -28.277160531268365,
           -28.238764133350045,
           -28.200367735431733,
           -28.161971337513414,
           -28.123574939595095,
           -28.085178541676783,
           -28.046782143758463,
           -28.008385745840144,
           -27.969989347921832,
           -27.931622444479533,
           -27.893309614132427,
           -27.85499678378532,
           -27.816683953438215,
           -27.778371123091112,
           -27.740058292744006,
           -27.7017454623969,
           -27.66343263204979,
           -27.625119801702688,
           -27.586806971355585,
           -27.54849414100848,
           -27.51018131066137,
           -27.471868480314264,
           -27.43355564996716,
           -27.395242819620055,
           -27.35692998927295,
           -27.318617158925846,
           -27.280304328578737,
           -27.24199149823163,
           -27.20367866788453,
           -27.165365837537422,
           -27.127053007190312,
           -27.08874017684321,
           -27.050427346496107,
           -27.012114516149005,
           -26.973801685801895,
           -26.935488855454793,
           -26.897176025107687,
           -26.85886319476058,
           -26.820550364413478,
           -26.78223753406637,
           -26.74392470371926,
           -26.70561187337216,
           -26.667299043025054,
           -26.628986212677944,
           -26.59067338233084,
           -26.55236055198374,
           -26.51404772163663,
           -26.475734891289527,
           -26.43742206094242,
           -26.399109230595318,
           -26.360796400248205,
           -26.322483569901106,
           -26.284170739554,
           -26.24585790920689,
           -26.207545078859788,
           -26.16923224851268,
           -26.130919418165576,
           -26.068552605469637,
           -25.88591588102951,
           -25.703279156589392,
           -25.520642432149273,
           -25.33800570770918,
           -25.155368983269057,
           -24.97273225882893,
           -24.790095534388847,
           -24.60745880994872,
           -24.424822085508595,
           -24.242185361068504,
           -24.05954863662838,
           -23.875331583726897,
           -23.679536385310627,
           -23.48374118689439,
           -23.287945988478118,
           -23.092150790061844,
           -22.89635559164561,
           -22.70056039322934,
           -22.50476519481306,
           -22.308969996396826,
           -22.113174797980555,
           -21.91737959956428,
           -21.721584401148043,
           -21.525789202731772,
           -21.3299940043155,
           -21.134198805899228,
           -20.938403607482993,
           -20.742608409066715,
           -20.54681321065044,
           -20.351018012234206,
           -20.155222813817936,
           -19.959427615401662,
           -19.763632416985423,
           -19.56783721856915,
           -19.37204202015288,
           -19.17624682173661,
           -18.98045162332037,
           -18.7846564249041,
           -18.588861226487825,
           -18.393066028071587,
           -18.197270829655317,
           -18.001475631239042,
           -17.805680432822804,
           -17.609885234406534,
           -17.414090035990263,
           -17.218294837574025,
           -17.02249963915775,
           -16.82670444074148,
           -16.630909242325206,
           -16.435114043908968,
           -16.239318845492697,
           -16.043523647076423,
           -15.847728448660188,
           -15.651933250243914,
           -15.456138051827642,
           -15.260342853411405,
           -15.064547654995131,
           -14.86875245657886,
           -14.672957258162587,
           -14.477162059746352,
           -14.281366861330078,
           -14.085571662913807,
           -13.889776464497569,
           -13.693981266081295,
           -13.49818606766502,
           -13.302390869248786,
           -13.106595670832512,
           -12.910800472416241,
           -12.715005274000003,
           -12.51921007558373,
           -12.322587562194318,
           -12.109026238857373,
           -11.895464915520467,
           -11.681903592183518,
           -11.468342268846573,
           -11.254780945509662,
           -11.041219622172715,
           -10.827658298835768,
           -10.614096975498862,
           -10.400535652161915,
           -10.186974328824967,
           -9.97341300548802,
           -9.759851682151112
          ],
          [
           -25.707963962692123,
           -25.73952409332777,
           -25.771084223963417,
           -25.802644354599064,
           -25.834204485234714,
           -25.86576461587036,
           -25.89732474650601,
           -25.928884877141655,
           -25.960445007777306,
           -25.992005138412953,
           -26.0235652690486,
           -26.055125399684247,
           -26.086685530319894,
           -26.118245660955544,
           -26.14980579159119,
           -26.18136592222684,
           -26.212926052862482,
           -26.244486183498132,
           -26.27604631413378,
           -26.30760644476943,
           -26.339166575405073,
           -26.370726706040724,
           -26.402286836676367,
           -26.43384696731202,
           -26.463619120622415,
           -26.493033680850466,
           -26.52244824107851,
           -26.55186280130656,
           -26.58127736153461,
           -26.610691921762655,
           -26.640106481990706,
           -26.669521042218754,
           -26.6989356024468,
           -26.72835016267485,
           -26.7577647229029,
           -26.787179283130943,
           -26.816593843358994,
           -26.846008403587042,
           -26.87542296381509,
           -26.90483752404314,
           -26.934252084271183,
           -26.963666644499234,
           -26.993081204727282,
           -27.02249576495533,
           -27.05191032518338,
           -27.081324885411426,
           -27.110739445639478,
           -27.140154005867522,
           -27.16956856609557,
           -27.198983126323625,
           -27.228397686551666,
           -27.25781224677972,
           -27.287226807007766,
           -27.31664136723581,
           -27.346055927463865,
           -27.375470487691906,
           -27.40488504791996,
           -27.434299608148006,
           -27.46371416837605,
           -27.493128728604106,
           -27.52254328883215,
           -27.5519578490602,
           -27.58137240928825,
           -27.610786969516294,
           -27.640201529744346,
           -27.669616089972394,
           -27.69903065020044,
           -27.72844521042849,
           -27.757859770656538,
           -27.787274330884586,
           -27.816688891112634,
           -27.84610345134068,
           -27.87551801156873,
           -27.904932571796778,
           -27.93434713202483,
           -27.963761692252877,
           -27.99317625248092,
           -28.02259081270897,
           -28.05200537293702,
           -28.08141993316507,
           -28.110834493393117,
           -28.14024905362116,
           -28.169663613849217,
           -28.19907817407726,
           -28.227680064234878,
           -28.256119420378408,
           -28.284558776521934,
           -28.312998132665466,
           -28.341437488808992,
           -28.369876844952522,
           -28.39831620109605,
           -28.426755557239584,
           -28.45519491338311,
           -28.483634269526643,
           -28.512073625670176,
           -28.5405129818137,
           -28.56895233795723,
           -28.59739169410076,
           -28.625831050244294,
           -28.654270406387823,
           -28.68270976253135,
           -28.71114911867488,
           -28.73958847481841,
           -28.76802783096194,
           -28.796467187105467,
           -28.824906543248993,
           -28.853345899392526,
           -28.88178525553605,
           -28.91022461167958,
           -28.938663967823118,
           -28.967103323966644,
           -28.995542680110173,
           -29.023982036253702,
           -29.052421392397232,
           -29.08086074854076,
           -29.109300104684294,
           -29.13773946082782,
           -29.16617881697135,
           -29.194618173114876,
           -29.22305752925841,
           -29.25149688540194,
           -29.27993624154547,
           -29.308375597689,
           -29.336814953832526,
           -29.365254309976056,
           -29.39369366611958,
           -29.422133022263118,
           -29.450572378406648,
           -29.479011734550177,
           -29.507451090693703,
           -29.535890446837236,
           -29.564329802980765,
           -29.59276915912429,
           -29.621208515267824,
           -29.649647871411347,
           -29.67808722755488,
           -29.706526583698412,
           -29.73496593984194,
           -29.763405295985468,
           -29.791844652129,
           -29.820284008272527,
           -29.84872336441606,
           -29.87716272055959,
           -29.905602076703115,
           -29.935730276461747,
           -29.96619624719399,
           -29.996662217926243,
           -30.02712818865849,
           -30.057594159390742,
           -30.088060130122994,
           -30.11852610085524,
           -30.148992071587493,
           -30.17945804231974,
           -30.20992401305199,
           -30.24038998378424,
           -30.270855954516488,
           -30.30132192524874,
           -30.331787895980987,
           -30.362253866713235,
           -30.392719837445487,
           -30.423185808177735,
           -30.453651778909986,
           -30.484117749642238,
           -30.514583720374482,
           -30.545049691106733,
           -30.57551566183898,
           -30.605981632571233,
           -30.63736400735331,
           -30.66920458416029,
           -30.701045160967276,
           -30.73288573777426,
           -30.764726314581246,
           -30.79656689138823,
           -30.828407468195216,
           -30.8602480450022,
           -30.892088621809187,
           -30.923929198616168,
           -30.955769775423157,
           -30.987610352230142,
           -31.019450929037127,
           -31.051291505844112,
           -31.083132082651098,
           -31.114972659458083,
           -31.146813236265068,
           -31.178653813072053,
           -31.210494389879035,
           -31.242334966686023,
           -31.27417554349301,
           -31.306016120299994,
           -31.33785669710698,
           -31.369697273913964,
           -31.401537850720945,
           -31.433378427527927,
           -31.465219004334916,
           -31.497059581141897,
           -31.528900157948886,
           -31.560740734755868,
           -31.592581311562853,
           -31.62442188836984,
           -31.656262465176827,
           -31.68810304198381,
           -31.7199436187908,
           -31.75178419559778,
           -31.783624772404764,
           -31.81546534921175,
           -31.847305926018727,
           -31.879146502825723,
           -31.910987079632704,
           -31.94282765643969,
           -31.97466823324667,
           -32.00650881005366,
           -32.038349386860645,
           -32.07018996366763,
           -32.102030540474615,
           -32.1338711172816,
           -32.165711694088586,
           -32.19755227089557,
           -32.229392847702556,
           -32.26123342450954,
           -32.293074001316526,
           -32.32491457812351,
           -32.3567551549305,
           -32.388595731737475,
           -32.42043630854446,
           -32.45227688535145,
           -32.48411746215843,
           -32.515958038965415,
           -32.5477986157724,
           -32.579639192579386,
           -32.61147976938637,
           -32.643320346193356,
           -32.67516092300034,
           -32.707001499807326,
           -32.73884207661431,
           -32.7706826534213,
           -32.80252323022828,
           -32.83436380703527,
           -32.86620438384225,
           -32.89804496064924,
           -32.92988553745622,
           -32.96172611426321,
           -32.99356669107019,
           -33.02540726787718,
           -33.05724784468416,
           -33.09030365115543,
           -33.123359459063714,
           -33.156415266972,
           -33.189471074880274,
           -33.22252688278856,
           -33.25558269069684,
           -33.24407584526849,
           -33.18800634650352,
           -33.13193684773856,
           -33.075867348973595,
           -33.019797850208626,
           -32.963728351443656,
           -32.90765885267869,
           -32.851589353913724,
           -32.79551985514875,
           -32.73945035638379,
           -32.68338085761882,
           -32.627311358853845,
           -32.57124186008888,
           -32.51517236132392,
           -32.45910286255895,
           -32.40303336379398,
           -32.35402538269793,
           -32.308201977425796,
           -32.262378572153665,
           -32.216555166881534,
           -32.170731761609396,
           -32.124908356337265,
           -32.07908495106514,
           -32.03326154579301,
           -31.987438140520876,
           -31.941614735248738,
           -31.89579132997661,
           -31.849967924704476,
           -31.80414451943235,
           -31.758321114160218,
           -31.712497708888083,
           -31.66667430361595,
           -31.620850898343825,
           -31.57502749307169,
           -31.529204087799556,
           -31.483380682527425,
           -31.437557277255294,
           -31.391733871983163,
           -31.345910466711032,
           -31.3000870614389,
           -31.254263656166767,
           -31.20844025089464,
           -31.162616845622505,
           -31.11679344035037,
           -31.070970035078236,
           -31.025146629806112,
           -30.97932322453398,
           -30.933499819261847,
           -30.887676413989713,
           -30.841853008717585,
           -30.796029603445454,
           -30.75020619817332,
           -30.70438279290119,
           -30.658559387629058,
           -30.61273598235692,
           -30.566912577084796,
           -30.521089171812662,
           -30.47526576654053,
           -30.429442361268393,
           -30.38361895599627,
           -30.33779555072413,
           -30.291972145452007,
           -30.246148740179873,
           -30.200325334907742,
           -30.15450192963561,
           -30.108678524363476,
           -30.062855119091346,
           -30.01703171381921,
           -29.97120830854709,
           -29.925384903274953,
           -29.879561498002822,
           -29.833738092730687,
           -29.78791468745856,
           -29.742091282186422,
           -29.69626787691429,
           -29.650444471642164,
           -29.60462106637003,
           -29.5587976610979,
           -29.512974255825768,
           -29.467150850553637,
           -29.4213274452815,
           -29.375504040009368,
           -29.32968063473724,
           -29.286332898583048,
           -29.24793650066473,
           -29.209540102746416,
           -29.171143704828097,
           -29.132747306909785,
           -29.094350908991466,
           -29.055954511073146,
           -29.017558113154827,
           -28.979161715236515,
           -28.940765317318196,
           -28.90236891939988,
           -28.863972521481564,
           -28.82557612356325,
           -28.78717972564493,
           -28.74878332772662,
           -28.7103869298083,
           -28.671990531889982,
           -28.633594133971666,
           -28.59519773605335,
           -28.55680133813503,
           -28.518404940216712,
           -28.4800085422984,
           -28.44161214438008,
           -28.403215746461765,
           -28.36481934854345,
           -28.326422950625133,
           -28.288026552706814,
           -28.2496301547885,
           -28.211233756870186,
           -28.172837358951867,
           -28.134440961033544,
           -28.096044563115235,
           -28.057648165196913,
           -28.019251767278597,
           -27.980855369360278,
           -27.942458971441965,
           -27.904062573523646,
           -27.865666175605334,
           -27.827269777687015,
           -27.788873379768695,
           -27.75047698185038,
           -27.712080583932067,
           -27.673684186013745,
           -27.63528778809543,
           -27.596891390177113,
           -27.558494992258797,
           -27.52009859434048,
           -27.481702196422166,
           -27.44330579850385,
           -27.40490940058553,
           -27.366513002667215,
           -27.3281166047489,
           -27.28972020683058,
           -27.251323808912257,
           -27.21292741099395,
           -27.17453101307563,
           -27.13613461515731,
           -27.097738217238994,
           -27.059341819320682,
           -27.020945421402363,
           -26.982549023484047,
           -26.94415262556573,
           -26.904862126618994,
           -26.863585786358307,
           -26.822309446097627,
           -26.78103310583694,
           -26.739756765576253,
           -26.698480425315573,
           -26.657204085054886,
           -26.615927744794202,
           -26.574651404533522,
           -26.53337506427284,
           -26.492098724012152,
           -26.450822383751465,
           -26.409546043490785,
           -26.368269703230098,
           -26.326993362969414,
           -26.28571702270873,
           -26.244440682448044,
           -26.20316434218736,
           -26.16188800192668,
           -26.120611661665997,
           -26.07933532140531,
           -26.01863327233382,
           -25.860802679208277,
           -25.702972086082735,
           -25.545141492957192,
           -25.38731089983168,
           -25.229480306706137,
           -25.071649713580594,
           -24.91381912045508,
           -24.75598852732954,
           -24.598157934203996,
           -24.440327341078483,
           -24.282496747952944,
           -24.1246661548274,
           -23.96683556170186,
           -23.809004968576343,
           -23.6511743754508,
           -23.493343782325258,
           -23.335513189199744,
           -23.177682596074202,
           -22.99803330984181,
           -22.80223811142557,
           -22.6064429130093,
           -22.41064771459303,
           -22.21485251617679,
           -22.019057317760517,
           -21.823262119344243,
           -21.627466920927972,
           -21.431671722511737,
           -21.235876524095467,
           -21.04008132567919,
           -20.844286127262954,
           -20.64849092884668,
           -20.45269573043041,
           -20.25690053201417,
           -20.061105333597897,
           -19.865310135181623,
           -19.669514936765353,
           -19.473719738349118,
           -19.277924539932844,
           -19.08212934151657,
           -18.886334143100335,
           -18.69053894468406,
           -18.49474374626779,
           -18.298948547851552,
           -18.10315334943528,
           -17.907358151019007,
           -17.71156295260277,
           -17.5157677541865,
           -17.319972555770224,
           -17.12417735735395,
           -16.92838215893772,
           -16.732586960521445,
           -16.53679176210517,
           -16.340996563688932,
           -16.145201365272662,
           -15.949406166856388,
           -15.753610968440153,
           -15.557815770023879,
           -15.362020571607607,
           -15.166225373191335,
           -14.970430174775098,
           -14.774634976358826,
           -14.578839777942552,
           -14.383044579526313,
           -14.187249381110043,
           -13.973179980074715,
           -13.74651386118596,
           -13.519847742297166,
           -13.293181623408373,
           -13.066515504519618,
           -12.839849385630824,
           -12.613183266742027,
           -12.386517147853233,
           -12.15985102896448,
           -11.933184910075685,
           -11.70651879118689,
           -11.479852672298136,
           -11.25318655340934,
           -11.026520434520547,
           -10.799854315631794,
           -10.573188196742999,
           -10.346522077854202,
           -10.119855958965408,
           -9.893189840076655
          ],
          [
           -25.287833683211396,
           -25.319393813847043,
           -25.35095394448269,
           -25.382514075118337,
           -25.414074205753987,
           -25.445634336389634,
           -25.47719446702528,
           -25.508039405185453,
           -25.537453965413505,
           -25.56686852564155,
           -25.5962830858696,
           -25.62569764609765,
           -25.655112206325697,
           -25.684526766553745,
           -25.713941326781793,
           -25.74335588700984,
           -25.77277044723789,
           -25.802185007465937,
           -25.83159956769399,
           -25.861014127922033,
           -25.890428688150084,
           -25.91984324837813,
           -25.94925780860618,
           -25.97867236883423,
           -26.008086929062273,
           -26.037501489290324,
           -26.066916049518372,
           -26.09633060974642,
           -26.125745169974472,
           -26.15515973020252,
           -26.184574290430568,
           -26.213988850658616,
           -26.243403410886664,
           -26.272817971114712,
           -26.30223253134276,
           -26.331647091570808,
           -26.361061651798856,
           -26.390476212026904,
           -26.419890772254952,
           -26.449305332483,
           -26.478719892711048,
           -26.508134452939096,
           -26.537549013167144,
           -26.566963573395196,
           -26.596378133623244,
           -26.625792693851288,
           -26.655207254079343,
           -26.684621814307388,
           -26.714036374535432,
           -26.743450934763487,
           -26.77286549499153,
           -26.802280055219583,
           -26.83169461544763,
           -26.86110917567568,
           -26.890523735903727,
           -26.919938296131775,
           -26.949352856359827,
           -26.97876741658787,
           -27.00818197681592,
           -27.037596537043967,
           -27.067011097272015,
           -27.096425657500067,
           -27.12584021772811,
           -27.15525477795616,
           -27.18466933818421,
           -27.214083898412255,
           -27.243498458640303,
           -27.27291301886836,
           -27.3023275790964,
           -27.33174213932445,
           -27.3611566995525,
           -27.390571259780543,
           -27.4199858200086,
           -27.44940038023664,
           -27.478814940464694,
           -27.50822950069274,
           -27.537644060920783,
           -27.567058621148835,
           -27.596473181376883,
           -27.625887741604934,
           -27.655302301832982,
           -27.684716862061027,
           -27.71413142228908,
           -27.743545982517123,
           -27.772147872674743,
           -27.800587228818273,
           -27.829026584961802,
           -27.857465941105332,
           -27.88590529724886,
           -27.914344653392387,
           -27.94278400953592,
           -27.97122336567945,
           -27.999662721822975,
           -28.02810207796651,
           -28.056541434110038,
           -28.084980790253567,
           -28.113420146397097,
           -28.141859502540626,
           -28.170298858684156,
           -28.198738214827685,
           -28.227177570971214,
           -28.255616927114744,
           -28.284056283258273,
           -28.312495639401803,
           -28.340934995545332,
           -28.36937435168886,
           -28.39781370783239,
           -28.42625306397592,
           -28.45469242011945,
           -28.48313177626298,
           -28.51157113240651,
           -28.54001048855004,
           -28.568449844693568,
           -28.596889200837097,
           -28.625328556980627,
           -28.653767913124156,
           -28.682207269267685,
           -28.710646625411215,
           -28.739085981554744,
           -28.767525337698274,
           -28.795964693841803,
           -28.824404049985333,
           -28.852843406128862,
           -28.88128276227239,
           -28.90972211841592,
           -28.938161474559447,
           -28.96660083070298,
           -28.99504018684651,
           -29.02347954299004,
           -29.051918899133568,
           -29.080358255277098,
           -29.108797611420627,
           -29.137236967564156,
           -29.165676323707686,
           -29.194115679851215,
           -29.222555035994745,
           -29.250994392138274,
           -29.279433748281804,
           -29.307873104425333,
           -29.336312460568863,
           -29.364751816712392,
           -29.39319117285592,
           -29.42163052899945,
           -29.450069885142977,
           -29.47850924128651,
           -29.50694859743004,
           -29.53538795357357,
           -29.563827309717098,
           -29.592266665860627,
           -29.620706022004157,
           -29.649145378147686,
           -29.677584734291216,
           -29.706024090434745,
           -29.73446344657827,
           -29.762902802721804,
           -29.791342158865334,
           -29.819781515008863,
           -29.848220871152392,
           -29.876660227295922,
           -29.905099583439448,
           -29.93421447556933,
           -29.96468044630158,
           -29.99514641703383,
           -30.025612387766078,
           -30.056078358498326,
           -30.086544329230577,
           -30.117010299962825,
           -30.1483926747449,
           -30.180233251551883,
           -30.21207382835887,
           -30.243914405165853,
           -30.275754981972838,
           -30.307595558779823,
           -30.33943613558681,
           -30.371276712393794,
           -30.40311728920078,
           -30.43495786600776,
           -30.46679844281475,
           -30.498639019621738,
           -30.53047959642872,
           -30.562320173235705,
           -30.594160750042686,
           -30.626001326849675,
           -30.657841903656664,
           -30.68968248046364,
           -30.721523057270627,
           -30.753363634077612,
           -30.785204210884597,
           -30.817044787691586,
           -30.848885364498567,
           -30.880725941305553,
           -30.912566518112538,
           -30.94440709491952,
           -30.976247671726508,
           -31.00808824853349,
           -31.03992882534048,
           -31.071769402147464,
           -31.103609976053324,
           -31.134872178896593,
           -31.166134381739866,
           -31.19739658458314,
           -31.22865878742641,
           -31.259920990269688,
           -31.29118319311296,
           -31.32244539595623,
           -31.353707598799506,
           -31.384969801642775,
           -31.41623200448605,
           -31.44749420732932,
           -31.478756410172593,
           -31.510018613015866,
           -31.541280815859142,
           -31.57254301870241,
           -31.603805221545684,
           -31.635067424388957,
           -31.66632962723223,
           -31.697591830075503,
           -31.728854032918775,
           -31.760116235762048,
           -31.79137843860532,
           -31.822640641448594,
           -31.853902844291866,
           -31.885165047135136,
           -31.91642724997841,
           -31.94768945282168,
           -31.978951655664957,
           -32.01021385850823,
           -32.0414760613515,
           -32.072738264194776,
           -32.10400046703805,
           -32.13526266988132,
           -32.166524872724594,
           -32.19778707556787,
           -32.22904927841114,
           -32.26031148125441,
           -32.291573684097685,
           -32.32283588694096,
           -32.35409808978423,
           -32.3853602926275,
           -32.416622495470776,
           -32.44788469831405,
           -32.47914690115732,
           -32.510409104000594,
           -32.54167130684387,
           -32.57293350968714,
           -32.60419571253041,
           -32.63545791537368,
           -32.66672011821696,
           -32.69798232106022,
           -32.7292445239035,
           -32.72640550795202,
           -32.6894652732058,
           -32.652525038459586,
           -32.61558480371336,
           -32.578644568967135,
           -32.54170433422092,
           -32.5047640994747,
           -32.46782386472848,
           -32.430883629982254,
           -32.39394339523604,
           -32.35700316048982,
           -32.3200629257436,
           -32.283122690997374,
           -32.246182456251155,
           -32.20924222150493,
           -32.17230198675871,
           -32.13536175201249,
           -32.09842151726627,
           -32.06148128252005,
           -32.02454104777383,
           -31.987600813027612,
           -31.950660578281386,
           -31.913720343535175,
           -31.87678010878895,
           -31.839839874042728,
           -31.802899639296506,
           -31.765959404550287,
           -31.72901916980406,
           -31.692078935057847,
           -31.65513870031163,
           -31.618198465565406,
           -31.58125823081918,
           -31.544317996072962,
           -31.507377761326744,
           -31.47043752658052,
           -31.4334972918343,
           -31.39655705708808,
           -31.35961682234186,
           -31.322676587595637,
           -31.28573635284942,
           -31.2487961181032,
           -31.21185588335698,
           -31.173482867060958,
           -31.127659461788824,
           -31.081836056516693,
           -31.036012651244565,
           -30.99018924597243,
           -30.944365840700296,
           -30.89854243542817,
           -30.852719030156038,
           -30.806895624883904,
           -30.76107221961177,
           -30.715248814339645,
           -30.66942540906751,
           -30.623602003795376,
           -30.577778598523246,
           -30.531955193251115,
           -30.48613178797898,
           -30.44030838270685,
           -30.394484977434722,
           -30.348661572162587,
           -30.302838166890457,
           -30.257014761618322,
           -30.21119135634619,
           -30.165367951074064,
           -30.119544545801933,
           -30.0737211405298,
           -30.027897735257664,
           -29.982074329985537,
           -29.936250924713406,
           -29.89042751944127,
           -29.844604114169137,
           -29.798780708897013,
           -29.75295730362488,
           -29.707133898352748,
           -29.661310493080613,
           -29.615487087808482,
           -29.569663682536355,
           -29.523840277264224,
           -29.47801687199209,
           -29.432193466719955,
           -29.386370061447824,
           -29.340546656175693,
           -29.297198920021497,
           -29.25880252210318,
           -29.22040612418487,
           -29.18200972626655,
           -29.143613328348234,
           -29.10521693042992,
           -29.066820532511603,
           -29.02842413459328,
           -28.990027736674968,
           -28.951631338756652,
           -28.913234940838333,
           -28.874838542920017,
           -28.836442145001698,
           -28.798045747083382,
           -28.75964934916507,
           -28.721252951246754,
           -28.68285655332843,
           -28.64446015541012,
           -28.606063757491803,
           -28.567667359573488,
           -28.529270961655165,
           -28.490874563736853,
           -28.452478165818537,
           -28.414081767900218,
           -28.375685369981902,
           -28.33580194897782,
           -28.29452560871713,
           -28.25324926845645,
           -28.211972928195767,
           -28.170696587935083,
           -28.129420247674393,
           -28.088143907413716,
           -28.04686756715303,
           -28.005591226892342,
           -27.964314886631662,
           -27.92303854637098,
           -27.881762206110288,
           -27.840485865849608,
           -27.79920952558892,
           -27.75793318532824,
           -27.716656845067554,
           -27.675380504806874,
           -27.634104164546187,
           -27.5928278242855,
           -27.551551484024817,
           -27.510275143764133,
           -27.468998803503446,
           -27.427722463242766,
           -27.38644612298208,
           -27.3451697827214,
           -27.303893442460712,
           -27.262617102200032,
           -27.221340761939345,
           -27.180064421678658,
           -27.138788081417978,
           -27.097511741157295,
           -27.056235400896608,
           -27.014959060635924,
           -26.973682720375244,
           -26.93240638011455,
           -26.89113003985387,
           -26.84985369959319,
           -26.808577359332503,
           -26.76730101907182,
           -26.726024678811136,
           -26.68474833855045,
           -26.643471998289765,
           -26.602195658029085,
           -26.5609193177684,
           -26.519642977507715,
           -26.478366637247035,
           -26.43709029698635,
           -26.39581395672566,
           -26.354537616464977,
           -26.313261276204294,
           -26.27198493594361,
           -26.230708595682923,
           -26.189432255422247,
           -26.148155915161556,
           -26.106879574900873,
           -26.06560323464019,
           -26.02432689437951,
           -25.983050554118822,
           -25.92234850504733,
           -25.76451791192179,
           -25.606687318796244,
           -25.44885672567071,
           -25.29102613254519,
           -25.13319553941965,
           -24.975364946294107,
           -24.817534353168597,
           -24.65970376004305,
           -24.50187316691751,
           -24.344042573791995,
           -24.186211980666453,
           -24.028381387540907,
           -23.87055079441537,
           -23.712720201289855,
           -23.55488960816431,
           -23.39705901503877,
           -23.239228421913257,
           -23.081397828787715,
           -22.923567235662173,
           -22.76573664253666,
           -22.607906049411113,
           -22.450075456285575,
           -22.29224486316006,
           -22.13441427003452,
           -21.976583676908973,
           -21.818753083783434,
           -21.66092249065792,
           -21.503091897532375,
           -21.345261304406833,
           -21.187430711281323,
           -21.029600118155777,
           -20.87176952503024,
           -20.71393893190472,
           -20.543602153373694,
           -20.355756773878852,
           -20.167911394384006,
           -19.980066014889196,
           -19.79222063539435,
           -19.604375255899512,
           -19.416529876404702,
           -19.228684496909857,
           -19.04083911741501,
           -18.852993737920205,
           -18.66514835842536,
           -18.477302978930517,
           -18.289457599435703,
           -18.101612219940865,
           -17.91376684044602,
           -17.725921460951174,
           -17.50896055849319,
           -17.282294439604396,
           -17.0556283207156,
           -16.828962201826844,
           -16.602296082938054,
           -16.37562996404926,
           -16.148963845160505,
           -15.922297726271708,
           -15.695631607382914,
           -15.468965488494117,
           -15.242299369605366,
           -15.01563325071657,
           -14.788967131827777,
           -14.562301012939022,
           -14.335634894050227,
           -14.108968775161433,
           -13.882302656272678,
           -13.655636537383884,
           -13.42897041849509,
           -13.202304299606336,
           -12.975638180717542,
           -12.748972061828745,
           -12.52230594293995,
           -12.295639824051197,
           -12.068973705162403,
           -11.842307586273607,
           -11.615641467384854,
           -11.388975348496057,
           -11.162309229607263,
           -10.935643110718512,
           -10.708976991829715,
           -10.482310872940921,
           -10.255644754052124,
           -10.028978635163373
          ],
          [
           -24.862018192137892,
           -24.889132406639575,
           -24.916246621141255,
           -24.943360835642938,
           -24.970475050144614,
           -24.997589264646297,
           -25.02470347914798,
           -25.05181769364966,
           -25.078931908151343,
           -25.106046122653023,
           -25.133543726194816,
           -25.16295828642286,
           -25.192372846650912,
           -25.22178740687896,
           -25.251201967107008,
           -25.280616527335056,
           -25.310031087563104,
           -25.339445647791152,
           -25.368860208019203,
           -25.398274768247248,
           -25.4276893284753,
           -25.457103888703344,
           -25.486518448931395,
           -25.515933009159443,
           -25.545347569387488,
           -25.57476212961554,
           -25.604176689843587,
           -25.633591250071635,
           -25.663005810299687,
           -25.692420370527735,
           -25.721834930755783,
           -25.75124949098383,
           -25.780664051211875,
           -25.810078611439923,
           -25.839493171667975,
           -25.86890773189602,
           -25.89832229212407,
           -25.927736852352115,
           -25.957151412580167,
           -25.986565972808215,
           -26.015980533036263,
           -26.04539509326431,
           -26.07480965349236,
           -26.104224213720407,
           -26.133638773948455,
           -26.163053334176503,
           -26.19246789440455,
           -26.2218824546326,
           -26.251297014860647,
           -26.280711575088695,
           -26.310126135316743,
           -26.33954069554479,
           -26.36895525577284,
           -26.398369816000887,
           -26.42778437622894,
           -26.457198936456983,
           -26.486613496685038,
           -26.516028056913083,
           -26.545442617141127,
           -26.574857177369182,
           -26.60427173759723,
           -26.633686297825278,
           -26.663100858053323,
           -26.692515418281367,
           -26.721929978509422,
           -26.75134453873747,
           -26.780759098965518,
           -26.810173659193566,
           -26.839588219421614,
           -26.869002779649662,
           -26.89841733987771,
           -26.927831900105758,
           -26.957246460333806,
           -26.986661020561854,
           -27.016075580789902,
           -27.045490141017954,
           -27.074904701246002,
           -27.104319261474046,
           -27.133733821702094,
           -27.163148381930146,
           -27.192562942158194,
           -27.221977502386242,
           -27.251392062614286,
           -27.280806622842338,
           -27.30940851299995,
           -27.337847869143484,
           -27.366287225287014,
           -27.39472658143054,
           -27.42316593757407,
           -27.4516052937176,
           -27.48004464986113,
           -27.508484006004657,
           -27.536923362148187,
           -27.56536271829172,
           -27.593802074435246,
           -27.622241430578775,
           -27.65068078672231,
           -27.679120142865834,
           -27.70755949900937,
           -27.735998855152896,
           -27.764438211296426,
           -27.79287756743995,
           -27.821316923583485,
           -27.849756279727018,
           -27.878195635870544,
           -27.90663499201407,
           -27.935074348157602,
           -27.96351370430113,
           -27.991953060444658,
           -28.020392416588187,
           -28.04883177273172,
           -28.07727112887525,
           -28.105710485018776,
           -28.134149841162305,
           -28.162589197305834,
           -28.191028553449367,
           -28.219467909592893,
           -28.247907265736423,
           -28.276346621879956,
           -28.30478597802348,
           -28.333225334167018,
           -28.36166469031054,
           -28.39010404645407,
           -28.418543402597603,
           -28.446982758741132,
           -28.47542211488466,
           -28.50386147102819,
           -28.53230082717172,
           -28.560740183315254,
           -28.589179539458783,
           -28.617618895602313,
           -28.646058251745842,
           -28.67449760788937,
           -28.702936964032897,
           -28.731376320176427,
           -28.759815676319956,
           -28.78825503246349,
           -28.816694388607015,
           -28.845133744750548,
           -28.873573100894077,
           -28.902012457037607,
           -28.930451813181133,
           -28.958891169324666,
           -28.98733052546819,
           -29.01576988161172,
           -29.04420923775525,
           -29.072648593898784,
           -29.10108795004231,
           -29.12952730618584,
           -29.157966662329372,
           -29.186406018472898,
           -29.214845374616427,
           -29.24328473075996,
           -29.271724086903486,
           -29.300163443047015,
           -29.328602799190545,
           -29.357042155334078,
           -29.38439259360829,
           -29.410654117637854,
           -29.436915641667426,
           -29.46317716569699,
           -29.489438689726562,
           -29.515700213756126,
           -29.541961737785698,
           -29.568223261815263,
           -29.59448478584483,
           -29.6207463098744,
           -29.649595029235577,
           -29.67973734626256,
           -29.70987966328954,
           -29.74002198031652,
           -29.770164297343506,
           -29.800306614370488,
           -29.830448931397473,
           -29.860591248424456,
           -29.890733565451434,
           -29.920875882478416,
           -29.951018199505402,
           -29.981160516532384,
           -30.011302833559366,
           -30.04144515058635,
           -30.07158746761333,
           -30.101807016511078,
           -30.13306921935435,
           -30.164331422197623,
           -30.195593625040896,
           -30.226855827884165,
           -30.25811803072744,
           -30.28938023357071,
           -30.320642436413983,
           -30.351904639257256,
           -30.38316684210053,
           -30.4144290449438,
           -30.445691247787074,
           -30.476953450630347,
           -30.50821565347362,
           -30.539477856316893,
           -30.57074005916017,
           -30.602002262003438,
           -30.63326446484671,
           -30.664526667689984,
           -30.695788870533256,
           -30.72705107337653,
           -30.758313276219805,
           -30.789575479063075,
           -30.82083768190635,
           -30.85209988474962,
           -30.883362087592893,
           -30.914624290436166,
           -30.94588649327944,
           -30.97714869612271,
           -31.008410898965984,
           -31.039673101809253,
           -31.070935304652526,
           -31.102197507495802,
           -31.13345971033907,
           -31.164721913182348,
           -31.19598411602562,
           -31.227246318868893,
           -31.258508521712166,
           -31.28977072455544,
           -31.32103292739871,
           -31.35229513024198,
           -31.38355733308525,
           -31.41481953592853,
           -31.446081738771795,
           -31.477343941615075,
           -31.508606144458348,
           -31.539868347301613,
           -31.571130550144893,
           -31.60239275298816,
           -31.63365495583144,
           -31.66491715867471,
           -31.696179361517984,
           -31.727441564361257,
           -31.75870376720453,
           -31.7899659700478,
           -31.82122817289107,
           -31.852490375734344,
           -31.883752578577617,
           -31.91501478142089,
           -31.946276984264166,
           -31.977539187107432,
           -32.00880138995071,
           -32.04006359279398,
           -32.07132579563726,
           -32.10258799848052,
           -32.1338502013238,
           -32.16511240416707,
           -32.19637460701034,
           -32.19353559105887,
           -32.15659535631264,
           -32.119655121566424,
           -32.082714886820206,
           -32.04577465207399,
           -32.00883441732776,
           -31.971894182581543,
           -31.934953947835325,
           -31.8980137130891,
           -31.86107347834288,
           -31.824133243596663,
           -31.787193008850437,
           -31.75025277410422,
           -31.713312539358,
           -31.676372304611775,
           -31.63943206986556,
           -31.602491835119338,
           -31.565551600373116,
           -31.528611365626894,
           -31.491671130880675,
           -31.454730896134453,
           -31.41779066138823,
           -31.380850426642013,
           -31.34391019189579,
           -31.30696995714957,
           -31.27002972240335,
           -31.233089487657132,
           -31.196149252910907,
           -31.159209018164688,
           -31.122268783418473,
           -31.08532854867225,
           -31.048388313926026,
           -31.01144807917981,
           -30.974507844433585,
           -30.937567609687363,
           -30.900627374941145,
           -30.863687140194923,
           -30.826746905448708,
           -30.789806670702482,
           -30.752866435956264,
           -30.71592620121004,
           -30.678985966463824,
           -30.6420457317176,
           -30.605105496971383,
           -30.568165262225158,
           -30.531225027478943,
           -30.494284792732717,
           -30.457344557986495,
           -30.420404323240277,
           -30.38346408849406,
           -30.346523853747836,
           -30.309583619001614,
           -30.272643384255396,
           -30.23570314950917,
           -30.19876291476295,
           -30.161822680016733,
           -30.12488244527051,
           -30.08794221052429,
           -30.05100197577807,
           -30.014061741031853,
           -29.97712150628563,
           -29.94018127153941,
           -29.90324103679319,
           -29.866300802046965,
           -29.829360567300746,
           -29.792420332554528,
           -29.755480097808302,
           -29.71853986306208,
           -29.681599628315865,
           -29.644659393569643,
           -29.60771915882342,
           -29.570778924077203,
           -29.533838689330985,
           -29.496898454584763,
           -29.47386090035444,
           -29.453578883634478,
           -29.433296866914517,
           -29.41301485019456,
           -29.392732833474604,
           -29.37245081675465,
           -29.35216880003469,
           -29.331886783314733,
           -29.311604766594773,
           -29.284229371463272,
           -29.242667219508697,
           -29.20110506755412,
           -29.159542915599545,
           -29.11798076364497,
           -29.076418611690393,
           -29.03485645973581,
           -28.993294307781234,
           -28.95173215582666,
           -28.910170003872082,
           -28.868607851917503,
           -28.827045699962927,
           -28.78548354800835,
           -28.743921396053775,
           -28.7023592440992,
           -28.660797092144623,
           -28.619234940190044,
           -28.577672788235468,
           -28.536110636280892,
           -28.494548484326312,
           -28.452986332371733,
           -28.411424180417157,
           -28.36986202846258,
           -28.328299876508005,
           -28.286737724553426,
           -28.245175572598853,
           -28.20361342064427,
           -28.162051268689698,
           -28.120489116735122,
           -28.078926964780543,
           -28.037364812825967,
           -27.995802660871394,
           -27.954240508916815,
           -27.912678356962232,
           -27.871116205007656,
           -27.829554053053087,
           -27.787991901098504,
           -27.74642974914393,
           -27.704867597189352,
           -27.663305445234776,
           -27.6217432932802,
           -27.580181141325625,
           -27.53861898937104,
           -27.497056837416466,
           -27.455494685461886,
           -27.41399037647765,
           -27.372714036216962,
           -27.33143769595628,
           -27.290161355695595,
           -27.248885015434908,
           -27.207608675174228,
           -27.166332334913545,
           -27.125055994652858,
           -27.08377965439217,
           -27.042503314131494,
           -27.001226973870807,
           -26.95995063361012,
           -26.918674293349437,
           -26.877397953088753,
           -26.836121612828066,
           -26.794845272567386,
           -26.753568932306706,
           -26.71229259204602,
           -26.671016251785332,
           -26.62973991152465,
           -26.588463571263965,
           -26.547187231003278,
           -26.505910890742598,
           -26.464634550481914,
           -26.423358210221227,
           -26.382081869960544,
           -26.340805529699864,
           -26.299529189439177,
           -26.25825284917849,
           -26.21697650891781,
           -26.17570016865712,
           -26.134423828396436,
           -26.093147488135756,
           -26.051871147875072,
           -26.010594807614385,
           -25.969318467353702,
           -25.92804212709302,
           -25.886765786832335,
           -25.826063737760844,
           -25.668233144635302,
           -25.51040255150976,
           -25.35257195838422,
           -25.194741365258704,
           -25.03691077213316,
           -24.87908017900762,
           -24.721249585882106,
           -24.5402825408489,
           -24.352437161354054,
           -24.164591781859247,
           -23.976746402364398,
           -23.788901022869556,
           -23.601055643374714,
           -23.413210263879904,
           -23.225364884385062,
           -23.037519504890213,
           -22.849674125395403,
           -22.66182874590056,
           -22.47398336640572,
           -22.286137986910912,
           -22.098292607416067,
           -21.910447227921225,
           -21.722601848426415,
           -21.53475646893157,
           -21.346911089436723,
           -21.15906570994188,
           -20.97122033044707,
           -20.78337495095223,
           -20.595529571457387,
           -20.407684191962577,
           -20.219838812467735,
           -20.03199343297289,
           -19.84414805347808,
           -19.656302673983234,
           -19.468457294488392,
           -19.28061191499355,
           -19.09276653549874,
           -18.904921156003894,
           -18.717075776509056,
           -18.529230397014242,
           -18.3413850175194,
           -18.153539638024554,
           -17.965694258529744,
           -17.777848879034902,
           -17.59000349954006,
           -17.40215812004525,
           -17.214312740550405,
           -17.026467361055563,
           -16.83862198156072,
           -16.65077660206591,
           -16.462931222571065,
           -16.27508584307622,
           -16.087240463581413,
           -15.899395084086567,
           -15.711549704591725,
           -15.523704325096915,
           -15.335858945602071,
           -15.148013566107227,
           -14.960168186612385,
           -14.772322807117575,
           -14.584477427622732,
           -14.396632048127888,
           -14.208786668633078,
           -14.020941289138234,
           -13.83309590964339,
           -13.64525053014858,
           -13.457405150653738,
           -13.269559771158894,
           -13.081714391664086,
           -12.89386901216924,
           -12.706023632674398,
           -12.518178253179553,
           -12.330332873684744,
           -12.1424874941899,
           -11.954642114695055,
           -11.751430262471573,
           -11.524764143582777,
           -11.298098024693982,
           -11.071431905805229,
           -10.844765786916433,
           -10.618099668027638,
           -10.391433549138844,
           -10.16476743025009
          ],
          [
           -24.43234832144606,
           -24.459462535947743,
           -24.486576750449423,
           -24.513690964951106,
           -24.540805179452786,
           -24.56791939395447,
           -24.59503360845615,
           -24.622147822957828,
           -24.649262037459515,
           -24.676376251961194,
           -24.703490466462874,
           -24.730604680964554,
           -24.757718895466237,
           -24.78483310996792,
           -24.8119473244696,
           -24.839061538971283,
           -24.866175753472962,
           -24.893289967974646,
           -24.92040418247633,
           -24.94751839697801,
           -24.97463261147969,
           -25.00174682598137,
           -25.028861040483054,
           -25.055975254984737,
           -25.083089469486417,
           -25.1102036839881,
           -25.137317898489776,
           -25.165965676148947,
           -25.19538023637699,
           -25.224794796605043,
           -25.254209356833087,
           -25.283623917061135,
           -25.313038477289183,
           -25.34245303751723,
           -25.37186759774528,
           -25.401282157973327,
           -25.430696718201375,
           -25.460111278429423,
           -25.489525838657475,
           -25.51894039888552,
           -25.54835495911357,
           -25.577769519341615,
           -25.607184079569667,
           -25.636598639797715,
           -25.666013200025763,
           -25.69542776025381,
           -25.72484232048186,
           -25.75425688070991,
           -25.783671440937958,
           -25.813086001166003,
           -25.842500561394054,
           -25.871915121622102,
           -25.90132968185015,
           -25.930744242078198,
           -25.960158802306246,
           -25.989573362534294,
           -26.018987922762342,
           -26.04840248299039,
           -26.077817043218438,
           -26.107231603446486,
           -26.136646163674534,
           -26.166060723902582,
           -26.195475284130634,
           -26.224889844358678,
           -26.254304404586726,
           -26.283718964814778,
           -26.313133525042826,
           -26.342548085270874,
           -26.37196264549892,
           -26.40137720572697,
           -26.43079176595502,
           -26.460206326183066,
           -26.489620886411117,
           -26.519035446639162,
           -26.548450006867213,
           -26.57786456709526,
           -26.60727912732331,
           -26.636693687551357,
           -26.666108247779405,
           -26.695522808007453,
           -26.7249373682355,
           -26.75435192846355,
           -26.783766488691597,
           -26.813181048919645,
           -26.84178293907726,
           -26.87022229522079,
           -26.898661651364314,
           -26.92710100750785,
           -26.955540363651373,
           -26.983979719794903,
           -27.01241907593844,
           -27.040858432081965,
           -27.069297788225498,
           -27.097737144369024,
           -27.126176500512557,
           -27.154615856656086,
           -27.183055212799616,
           -27.211494568943145,
           -27.239933925086675,
           -27.268373281230204,
           -27.296812637373733,
           -27.325251993517263,
           -27.353691349660792,
           -27.38213070580432,
           -27.41057006194785,
           -27.439009418091377,
           -27.46744877423491,
           -27.49588813037844,
           -27.52432748652197,
           -27.552766842665495,
           -27.581206198809028,
           -27.609645554952557,
           -27.638084911096087,
           -27.666524267239616,
           -27.694963623383146,
           -27.72340297952667,
           -27.751842335670204,
           -27.78028169181373,
           -27.808721047957263,
           -27.83716040410079,
           -27.865599760244322,
           -27.89403911638785,
           -27.922478472531374,
           -27.95091782867491,
           -27.97935718481844,
           -28.00779654096197,
           -28.0362358971055,
           -28.064675253249025,
           -28.093114609392558,
           -28.121553965536087,
           -28.149993321679613,
           -28.178432677823146,
           -28.206872033966675,
           -28.2353113901102,
           -28.263750746253734,
           -28.29219010239726,
           -28.32062945854079,
           -28.349068814684323,
           -28.377508170827856,
           -28.405947526971378,
           -28.434386882489967,
           -28.460648406519535,
           -28.486909930549103,
           -28.51317145457867,
           -28.539432978608243,
           -28.565694502637808,
           -28.591956026667376,
           -28.618217550696944,
           -28.64447907472651,
           -28.67074059875608,
           -28.697002122785648,
           -28.723263646815216,
           -28.749525170844784,
           -28.77578669487435,
           -28.802048218903916,
           -28.828309742933484,
           -28.854571266963053,
           -28.88083279099262,
           -28.90709431502219,
           -28.933355839051757,
           -28.959617363081325,
           -28.985878887110896,
           -29.01214041114046,
           -29.03840193517003,
           -29.064663459199597,
           -29.090924983229165,
           -29.117186507258733,
           -29.146035226619908,
           -29.176177543646894,
           -29.206319860673872,
           -29.236462177700854,
           -29.26660449472784,
           -29.296746811754822,
           -29.326889128781808,
           -29.357031445808786,
           -29.38717376283577,
           -29.41731607986275,
           -29.447458396889736,
           -29.477600713916715,
           -29.507743030943697,
           -29.53788534797068,
           -29.568027664997665,
           -29.598169982024643,
           -29.62831229905163,
           -29.658454616078608,
           -29.688596933105593,
           -29.718739250132575,
           -29.74888156715956,
           -29.77902388418654,
           -29.80916620121352,
           -29.839308518240504,
           -29.869450835267486,
           -29.899593152294475,
           -29.92973546932145,
           -29.959877786348436,
           -29.990020103375418,
           -30.0201624204024,
           -30.050304737429382,
           -30.080447054456364,
           -30.11058937148335,
           -30.14073168851033,
           -30.17087400553731,
           -30.201016322564296,
           -30.23115863959128,
           -30.261300956618257,
           -30.29144327364524,
           -30.321585590672225,
           -30.351727907699207,
           -30.38187022472619,
           -30.413016576386283,
           -30.444278779229556,
           -30.47554098207283,
           -30.5068031849161,
           -30.538065387759367,
           -30.569327590602647,
           -30.600589793445916,
           -30.631851996289193,
           -30.663114199132465,
           -30.694376401975735,
           -30.72563860481901,
           -30.756900807662277,
           -30.788163010505556,
           -30.81942521334883,
           -30.850687416192095,
           -30.881949619035375,
           -30.91321182187864,
           -30.94447402472192,
           -30.975736227565186,
           -31.00699843040846,
           -31.038260633251735,
           -31.069522836095008,
           -31.100785038938284,
           -31.132047241781557,
           -31.16330944462483,
           -31.194571647468102,
           -31.225833850311375,
           -31.25709605315464,
           -31.288358255997913,
           -31.319620458841186,
           -31.35088266168446,
           -31.38214486452773,
           -31.413407067371004,
           -31.444669270214277,
           -31.475931473057553,
           -31.507193675900826,
           -31.538455878744095,
           -31.569718081587368,
           -31.60098028443064,
           -31.632242487273913,
           -31.663504690117186,
           -31.66066567416571,
           -31.623725439419488,
           -31.58678520467327,
           -31.54984496992705,
           -31.512904735180825,
           -31.475964500434607,
           -31.43902426568839,
           -31.402084030942163,
           -31.365143796195945,
           -31.32820356144973,
           -31.291263326703508,
           -31.254323091957282,
           -31.217382857211064,
           -31.18044262246484,
           -31.14350238771862,
           -31.1065621529724,
           -31.06962191822618,
           -31.03268168347996,
           -30.99574144873374,
           -30.95880121398752,
           -30.921860979241302,
           -30.884920744495076,
           -30.847980509748858,
           -30.81104027500264,
           -30.774100040256414,
           -30.737159805510196,
           -30.70021957076397,
           -30.66327933601775,
           -30.626339101271533,
           -30.589398866525315,
           -30.55245863177909,
           -30.51551839703287,
           -30.478578162286652,
           -30.44163792754043,
           -30.40469769279421,
           -30.36775745804799,
           -30.330817223301768,
           -30.293876988555546,
           -30.256936753809327,
           -30.21999651906311,
           -30.183056284316883,
           -30.146116049570665,
           -30.109175814824447,
           -30.07223558007822,
           -30.035295345332003,
           -30.004492321374308,
           -29.984210304654347,
           -29.963928287934394,
           -29.943646271214433,
           -29.923364254494473,
           -29.903082237774516,
           -29.88280022105456,
           -29.862518204334602,
           -29.842236187614645,
           -29.821954170894685,
           -29.80167215417473,
           -29.78139013745477,
           -29.76110812073481,
           -29.740826104014857,
           -29.720544087294897,
           -29.700262070574937,
           -29.679980053854983,
           -29.659698037135023,
           -29.639416020415066,
           -29.61913400369511,
           -29.598851986975156,
           -29.57856997025519,
           -29.558287953535235,
           -29.53800593681528,
           -29.51772392009532,
           -29.49744190337536,
           -29.477159886655404,
           -29.456877869935447,
           -29.43659585321549,
           -29.416313836495533,
           -29.396031819775573,
           -29.375749803055616,
           -29.355467786335655,
           -29.3351857696157,
           -29.314903752895745,
           -29.294621736175785,
           -29.274339719455824,
           -29.254057702735867,
           -29.226682307604367,
           -29.18512015564979,
           -29.14355800369522,
           -29.10199585174064,
           -29.06043369978606,
           -29.018871547831488,
           -28.977309395876908,
           -28.93574724392233,
           -28.894185091967756,
           -28.852622940013177,
           -28.811060788058597,
           -28.769498636104025,
           -28.72793648414945,
           -28.686374332194873,
           -28.644812180240294,
           -28.60325002828572,
           -28.561687876331135,
           -28.520125724376562,
           -28.47856357242199,
           -28.43700142046741,
           -28.39543926851283,
           -28.35387711655825,
           -28.312314964603672,
           -28.2707528126491,
           -28.229190660694524,
           -28.18762850873995,
           -28.14606635678537,
           -28.104504204830793,
           -28.062942052876217,
           -28.021379900921637,
           -27.979817748967058,
           -27.938255597012493,
           -27.896693445057913,
           -27.85513129310333,
           -27.813569141148754,
           -27.77200698919418,
           -27.7304448372396,
           -27.688882685285026,
           -27.64732053333045,
           -27.605758381375868,
           -27.564196229421295,
           -27.522634077466716,
           -27.481071925512136,
           -27.43950977355756,
           -27.39794762160298,
           -27.35638546964841,
           -27.31482331769383,
           -27.273261165739257,
           -27.231699013784677,
           -27.1901368618301,
           -27.148574709875525,
           -27.107012557920953,
           -27.06545040596637,
           -27.023888254011787,
           -26.982326102057222,
           -26.940763950102642,
           -26.899201798148063,
           -26.857639646193483,
           -26.814584724513473,
           -26.769663860034747,
           -26.724742995556017,
           -26.679822131077295,
           -26.63490126659857,
           -26.589980402119842,
           -26.545059537641116,
           -26.500138673162382,
           -26.455217808683656,
           -26.410296944204934,
           -26.365376079726204,
           -26.320455215247478,
           -26.27553435076875,
           -26.23061348629003,
           -26.1856926218113,
           -26.140771757332573,
           -26.09585089285385,
           -26.050930028375117,
           -26.006009163896387,
           -25.961088299417668,
           -25.916167434938934,
           -25.871246570460208,
           -25.826325705981482,
           -25.781404841502756,
           -25.736483977024026,
           -25.67802617484925,
           -25.551883684194195,
           -25.42574119353914,
           -25.29959870288408,
           -25.173456212229045,
           -25.047313721573985,
           -24.92117123091893,
           -24.7950287402639,
           -24.66888624960884,
           -24.54274375895378,
           -24.416601268298745,
           -24.29045877764369,
           -24.164316286988633,
           -24.038173796333574,
           -23.91203130567854,
           -23.785888815023483,
           -23.659746324368424,
           -23.533603833713393,
           -23.40746134305833,
           -23.281318852403274,
           -23.15517636174824,
           -23.029033871093183,
           -22.902891380438124,
           -22.77674888978309,
           -22.650606399128034,
           -22.524463908472978,
           -22.34347442059879,
           -22.155629041103982,
           -21.96778366160914,
           -21.779938282114294,
           -21.592092902619484,
           -21.40424752312464,
           -21.216402143629796,
           -21.028556764134986,
           -20.840711384640144,
           -20.6528660051453,
           -20.465020625650457,
           -20.27717524615565,
           -20.089329866660805,
           -19.90148448716596,
           -19.71363910767115,
           -19.525793728176307,
           -19.33794834868146,
           -19.150102969186655,
           -18.96225758969181,
           -18.774412210196964,
           -18.586566830702157,
           -18.398721451207315,
           -18.21087607171247,
           -18.023030692217624,
           -17.835185312722814,
           -17.647339933227972,
           -17.45949455373313,
           -17.27164917423832,
           -17.083803794743474,
           -16.895958415248632,
           -16.708113035753826,
           -16.52026765625898,
           -16.317779071955627,
           -16.077218201539736,
           -15.836657331123895,
           -15.596096460708006,
           -15.355535590292117,
           -15.114974719876276,
           -14.874413849460389,
           -14.633852979044503,
           -14.393292108628659,
           -14.15273123821277,
           -13.912170367796882,
           -13.67160949738104,
           -13.431048626965152,
           -13.190487756549263,
           -12.949926886133376,
           -12.709366015717535,
           -12.468805145301646,
           -12.228244274885759,
           -11.987683404469916,
           -11.747122534054029,
           -11.506561663638141,
           -11.266000793222297,
           -11.02543992280641,
           -10.784879052390522,
           -10.544318181974635,
           -10.30375731155879
          ],
          [
           -24.002678450754228,
           -24.02979266525591,
           -24.05690687975759,
           -24.084021094259274,
           -24.111135308760957,
           -24.138249523262637,
           -24.165363737764316,
           -24.192477952266,
           -24.219592166767683,
           -24.246706381269362,
           -24.273820595771046,
           -24.300934810272725,
           -24.32804902477441,
           -24.355163239276088,
           -24.382277453777768,
           -24.409391668279454,
           -24.43650588278113,
           -24.463620097282814,
           -24.4907343117845,
           -24.51784852628618,
           -24.54496274078786,
           -24.57207695528954,
           -24.599191169791222,
           -24.626305384292905,
           -24.653419598794585,
           -24.680533813296268,
           -24.707648027797948,
           -24.73476224229963,
           -24.761876456801314,
           -24.788990671302994,
           -24.816104885804673,
           -24.843219100306356,
           -24.870333314808036,
           -24.89744752930972,
           -24.924561743811402,
           -24.951675958313082,
           -24.97879017281476,
           -25.005904387316445,
           -25.033018601818124,
           -25.060132816319808,
           -25.087247030821487,
           -25.11436124532317,
           -25.141475459824854,
           -25.168973065875022,
           -25.19838762610307,
           -25.227802186331115,
           -25.257216746559166,
           -25.286631306787214,
           -25.31604586701526,
           -25.34546042724331,
           -25.374874987471358,
           -25.404289547699406,
           -25.433704107927454,
           -25.463118668155502,
           -25.492533228383554,
           -25.521947788611598,
           -25.551362348839646,
           -25.580776909067698,
           -25.610191469295742,
           -25.63960602952379,
           -25.66902058975184,
           -25.69843514997989,
           -25.72784971020794,
           -25.757264270435982,
           -25.786678830664034,
           -25.816093390892085,
           -25.845507951120133,
           -25.87492251134818,
           -25.90433707157623,
           -25.933751631804277,
           -25.963166192032325,
           -25.992580752260373,
           -26.02199531248842,
           -26.05140987271647,
           -26.080824432944517,
           -26.110238993172565,
           -26.139653553400613,
           -26.16906811362866,
           -26.19848267385671,
           -26.227897234084757,
           -26.25731179431281,
           -26.286726354540853,
           -26.3161409147689,
           -26.34555547499695,
           -26.374157365154566,
           -26.402596721298096,
           -26.431036077441625,
           -26.459475433585155,
           -26.487914789728684,
           -26.516354145872214,
           -26.544793502015743,
           -26.573232858159272,
           -26.601672214302802,
           -26.63011157044633,
           -26.65855092658986,
           -26.68699028273339,
           -26.71542963887692,
           -26.74386899502045,
           -26.77230835116398,
           -26.800747707307508,
           -26.829187063451037,
           -26.85762641959457,
           -26.8860657757381,
           -26.914505131881626,
           -26.942944488025155,
           -26.971383844168685,
           -26.999823200312214,
           -27.028262556455743,
           -27.056701912599273,
           -27.085141268742806,
           -27.113580624886332,
           -27.14201998102986,
           -27.17045933717339,
           -27.19889869331692,
           -27.22733804946045,
           -27.255777405603983,
           -27.28421676174751,
           -27.312656117891038,
           -27.341095474034567,
           -27.369534830178097,
           -27.397974186321633,
           -27.426413542465156,
           -27.454852898608685,
           -27.483292254752218,
           -27.510642695401213,
           -27.53690421943078,
           -27.563165743460353,
           -27.589427267489917,
           -27.61568879151948,
           -27.641950315549057,
           -27.66821183957862,
           -27.694473363608193,
           -27.720734887637757,
           -27.746996411667322,
           -27.773257935696897,
           -27.79951945972646,
           -27.825780983756026,
           -27.852042507785594,
           -27.878304031815162,
           -27.904565555844734,
           -27.930827079874298,
           -27.957088603903866,
           -27.983350127933438,
           -28.009611651963002,
           -28.035873175992574,
           -28.06213470002214,
           -28.08839622405171,
           -28.114657748081274,
           -28.140919272110843,
           -28.167180796140414,
           -28.19344232016998,
           -28.21970384419955,
           -28.245965368229115,
           -28.27222689225868,
           -28.29848841628825,
           -28.324749940317815,
           -28.351011464347383,
           -28.377272988376955,
           -28.40353451240652,
           -28.429796036436088,
           -28.45605756046566,
           -28.482319084495227,
           -28.508580608524795,
           -28.53484213255436,
           -28.56110365658393,
           -28.587365180613496,
           -28.613626704643064,
           -28.64247542400424,
           -28.672617741031225,
           -28.70276005805821,
           -28.73290237508519,
           -28.763044692112167,
           -28.793187009139153,
           -28.82332932616614,
           -28.853471643193117,
           -28.883613960220103,
           -28.91375627724708,
           -28.943898594274067,
           -28.97404091130105,
           -29.00418322832803,
           -29.034325545355017,
           -29.064467862381996,
           -29.094610179408974,
           -29.12475249643596,
           -29.154894813462946,
           -29.185037130489924,
           -29.21517944751691,
           -29.245321764543895,
           -29.275464081570874,
           -29.305606398597853,
           -29.335748715624838,
           -29.36589103265182,
           -29.396033349678802,
           -29.426175666705788,
           -29.45631798373277,
           -29.486460300759752,
           -29.51660261778673,
           -29.546744934813717,
           -29.5768872518407,
           -29.60702956886768,
           -29.63717188589466,
           -29.66731420292164,
           -29.69745651994863,
           -29.72759883697561,
           -29.75774115400259,
           -29.787883471029573,
           -29.81802578805656,
           -29.848168105083538,
           -29.878310422110523,
           -29.908452739137505,
           -29.938595056164484,
           -29.968737373191466,
           -29.998879690218452,
           -30.029022007245434,
           -30.05916432427242,
           -30.089306641299395,
           -30.11944895832638,
           -30.149591275353366,
           -30.17973359238034,
           -30.209875909407327,
           -30.24001822643431,
           -30.270160543461294,
           -30.300302860488276,
           -30.33044517751526,
           -30.36058749454224,
           -30.390729811569223,
           -30.420872128596205,
           -30.451014445623187,
           -30.48115676265017,
           -30.51129907967715,
           -30.541441396704137,
           -30.571583713731115,
           -30.601726030758098,
           -30.631868347785083,
           -30.662010664812065,
           -30.692963933418216,
           -30.72422613626149,
           -30.755488339104758,
           -30.78675054194803,
           -30.818012744791304,
           -30.849274947634576,
           -30.88053715047785,
           -30.911799353321122,
           -30.943061556164395,
           -30.974323759007667,
           -31.00558596185094,
           -31.036848164694213,
           -31.068110367537486,
           -31.09937257038076,
           -31.13063477322403,
           -31.127795757272555,
           -31.090855522526333,
           -31.053915287780114,
           -31.016975053033896,
           -30.98003481828767,
           -30.943094583541452,
           -30.906154348795233,
           -30.869214114049008,
           -30.83227387930279,
           -30.79533364455657,
           -30.758393409810346,
           -30.721453175064127,
           -30.684512940317905,
           -30.647572705571687,
           -30.61063247082546,
           -30.573692236079246,
           -30.536752001333024,
           -30.514841725674223,
           -30.49455970895426,
           -30.474277692234306,
           -30.453995675514346,
           -30.43371365879439,
           -30.413431642074436,
           -30.393149625354475,
           -30.372867608634515,
           -30.35258559191456,
           -30.332303575194597,
           -30.312021558474644,
           -30.29173954175469,
           -30.271457525034727,
           -30.251175508314773,
           -30.23089349159481,
           -30.210611474874852,
           -30.1903294581549,
           -30.170047441434935,
           -30.149765424714978,
           -30.129483407995025,
           -30.10920139127506,
           -30.088919374555108,
           -30.06863735783515,
           -30.048355341115187,
           -30.028073324395233,
           -30.007791307675276,
           -29.987509290955316,
           -29.967227274235363,
           -29.946945257515402,
           -29.926663240795442,
           -29.90638122407548,
           -29.886099207355528,
           -29.865817190635575,
           -29.845535173915614,
           -29.825253157195654,
           -29.804971140475697,
           -29.784689123755737,
           -29.76440710703578,
           -29.744125090315826,
           -29.723843073595866,
           -29.703561056875905,
           -29.683279040155952,
           -29.66299702343599,
           -29.64271500671604,
           -29.622432989996078,
           -29.602150973276117,
           -29.581868956556164,
           -29.561586939836204,
           -29.541304923116247,
           -29.52102290639629,
           -29.50074088967633,
           -29.480458872956376,
           -29.460176856236416,
           -29.439894839516455,
           -29.419612822796502,
           -29.399330806076545,
           -29.379048789356585,
           -29.358766772636628,
           -29.338484755916667,
           -29.31820273919671,
           -29.297920722476753,
           -29.2776387057568,
           -29.257356689036836,
           -29.237074672316876,
           -29.21679265559692,
           -29.196510638876966,
           -29.169135243745465,
           -29.127573091790893,
           -29.086010939836317,
           -29.044448787881734,
           -29.00288663592716,
           -28.961324483972586,
           -28.919762332018003,
           -28.878200180063423,
           -28.83663802810885,
           -28.79507587615427,
           -28.753513724199696,
           -28.71195157224512,
           -28.670389420290544,
           -28.628827268335964,
           -28.587265116381392,
           -28.545702964426816,
           -28.504140812472237,
           -28.46257866051766,
           -28.421016508563085,
           -28.379454356608502,
           -28.337892204653926,
           -28.296330052699346,
           -28.254767900744774,
           -28.211246492197695,
           -28.166325627718972,
           -28.121404763240243,
           -28.076483898761516,
           -28.03156303428279,
           -27.986642169804064,
           -27.941721305325338,
           -27.896800440846604,
           -27.851879576367885,
           -27.806958711889155,
           -27.762037847410426,
           -27.717116982931703,
           -27.672196118452973,
           -27.627275253974247,
           -27.58235438949552,
           -27.537433525016798,
           -27.492512660538065,
           -27.447591796059342,
           -27.402670931580616,
           -27.35775006710189,
           -27.312829202623156,
           -27.26790833814443,
           -27.222987473665707,
           -27.178066609186978,
           -27.13314574470825,
           -27.08822488022953,
           -27.0433040157508,
           -26.998383151272073,
           -26.953462286793346,
           -26.908541422314613,
           -26.86362055783589,
           -26.818699693357168,
           -26.77377882887844,
           -26.728857964399708,
           -26.683937099920982,
           -26.639016235442263,
           -26.59409537096353,
           -26.549174506484803,
           -26.504253642006077,
           -26.45933277752735,
           -26.414411913048628,
           -26.3694910485699,
           -26.324570184091165,
           -26.27964931961244,
           -26.23472845513372,
           -26.189807590654993,
           -26.14488672617626,
           -26.099965861697534,
           -26.05504499721881,
           -26.01012413274008,
           -25.965203268261355,
           -25.92028240378263,
           -25.8753615393039,
           -25.830440674825173,
           -25.78551981034645,
           -25.740598945867717,
           -25.69567808138899,
           -25.650757216910268,
           -25.60583635243154,
           -25.560915487952812,
           -25.502457685778033,
           -25.376315195122977,
           -25.25017270446792,
           -25.124030213812865,
           -24.99788772315783,
           -24.871745232502768,
           -24.745602741847712,
           -24.619460251192677,
           -24.49331776053762,
           -24.367175269882566,
           -24.24103277922753,
           -24.11489028857247,
           -23.98874779791742,
           -23.862605307262356,
           -23.73646281660732,
           -23.610320325952266,
           -23.484177835297206,
           -23.358035344642175,
           -23.231892853987112,
           -23.105750363332056,
           -22.979607872677022,
           -22.853465382021966,
           -22.72732289136691,
           -22.601180400711876,
           -22.47503791005682,
           -22.348895419401757,
           -22.2227529287467,
           -22.096610438091666,
           -21.97046794743661,
           -21.795226149977527,
           -21.618198933454163,
           -21.441171716930775,
           -21.26414450040738,
           -21.08711728388402,
           -20.910090067360628,
           -20.733062850837236,
           -20.556035634313844,
           -20.37900841779048,
           -20.201981201267092,
           -20.024953984743696,
           -19.84792676822034,
           -19.670899551696944,
           -19.49387233517355,
           -19.316845118650193,
           -19.139817902126797,
           -18.96279068560341,
           -18.78576346908005,
           -18.608736252556653,
           -18.431709036033265,
           -18.25468181950987,
           -18.077654602986513,
           -17.90062738646312,
           -17.723600169939726,
           -17.546572953416366,
           -17.369545736892974,
           -17.17970033941822,
           -16.939139469002374,
           -16.698578598586487,
           -16.4580177281706,
           -16.217456857754712,
           -15.97689598733887,
           -15.736335116922982,
           -15.495774246507093,
           -15.25521337609125,
           -15.014652505675361,
           -14.774091635259477,
           -14.533530764843633,
           -14.292969894427745,
           -14.052409024011858,
           -13.811848153596014,
           -13.571287283180126,
           -13.330726412764237,
           -13.090165542348352,
           -12.849604671932507,
           -12.60904380151662,
           -12.368482931100733,
           -12.127922060684888,
           -11.887361190269,
           -11.646800319853114,
           -11.40623944943727,
           -11.165678579021383,
           -10.925117708605494,
           -10.684556838189607,
           -10.443995967773766
          ],
          [
           -23.573008580062396,
           -23.600122794564076,
           -23.62723700906576,
           -23.65435122356744,
           -23.68146543806912,
           -23.708579652570805,
           -23.735693867072484,
           -23.762808081574164,
           -23.78992229607585,
           -23.81703651057753,
           -23.84415072507921,
           -23.87126493958089,
           -23.898379154082576,
           -23.925493368584256,
           -23.95260758308594,
           -23.979721797587622,
           -24.006836012089302,
           -24.03395022659098,
           -24.06106444109266,
           -24.088178655594348,
           -24.115292870096027,
           -24.142407084597707,
           -24.16952129909939,
           -24.19663551360107,
           -24.223749728102753,
           -24.250863942604433,
           -24.277978157106116,
           -24.3050923716078,
           -24.33220658610948,
           -24.35932080061116,
           -24.38643501511284,
           -24.413549229614524,
           -24.440663444116204,
           -24.467777658617887,
           -24.49489187311957,
           -24.52200608762125,
           -24.54912030212293,
           -24.57623451662461,
           -24.603348731126296,
           -24.630462945627976,
           -24.657577160129655,
           -24.68469137463134,
           -24.71180558913302,
           -24.7389198036347,
           -24.766034018136384,
           -24.793148232638064,
           -24.820262447139747,
           -24.847376661641427,
           -24.87449087614311,
           -24.901605090644793,
           -24.928719305146473,
           -24.955833519648156,
           -24.982947734149835,
           -25.010061948651515,
           -25.037176163153198,
           -25.064290377654878,
           -25.091404592156564,
           -25.118518806658244,
           -25.145633021159924,
           -25.172747235661607,
           -25.201395015829142,
           -25.23080957605719,
           -25.260224136285238,
           -25.289638696513286,
           -25.319053256741338,
           -25.348467816969386,
           -25.37788237719743,
           -25.40729693742548,
           -25.43671149765353,
           -25.466126057881578,
           -25.495540618109626,
           -25.52495517833767,
           -25.554369738565722,
           -25.58378429879377,
           -25.613198859021818,
           -25.642613419249866,
           -25.672027979477914,
           -25.701442539705965,
           -25.730857099934013,
           -25.760271660162058,
           -25.78968622039011,
           -25.819100780618157,
           -25.848515340846205,
           -25.877929901074253,
           -25.906531791231867,
           -25.934971147375396,
           -25.963410503518926,
           -25.99184985966246,
           -26.020289215805985,
           -26.048728571949514,
           -26.077167928093044,
           -26.10560728423657,
           -26.134046640380102,
           -26.162485996523632,
           -26.190925352667165,
           -26.219364708810687,
           -26.247804064954224,
           -26.27624342109775,
           -26.304682777241283,
           -26.33312213338481,
           -26.36156148952834,
           -26.39000084567187,
           -26.418440201815397,
           -26.44687955795893,
           -26.475318914102456,
           -26.50375827024599,
           -26.532197626389518,
           -26.560636982533044,
           -26.58689850831245,
           -26.613160032342023,
           -26.639421556371587,
           -26.66568308040116,
           -26.691944604430724,
           -26.718206128460295,
           -26.74446765248986,
           -26.770729176519428,
           -26.796990700549,
           -26.823252224578567,
           -26.849513748608132,
           -26.8757752726377,
           -26.902036796667268,
           -26.928298320696836,
           -26.954559844726404,
           -26.980821368755972,
           -27.00708289278554,
           -27.03334441681511,
           -27.05960594084468,
           -27.085867464874244,
           -27.11212898890381,
           -27.138390512933384,
           -27.16465203696295,
           -27.19091356099252,
           -27.217175085022085,
           -27.24343660905165,
           -27.26969813308122,
           -27.295959657110785,
           -27.322221181140353,
           -27.34848270516992,
           -27.374744229199493,
           -27.40100575322906,
           -27.42726727725863,
           -27.453528801288194,
           -27.479790325317765,
           -27.50605184934733,
           -27.5323133733769,
           -27.558574897406466,
           -27.584836421436037,
           -27.611097945465602,
           -27.63735946949517,
           -27.663620993524738,
           -27.689882517554306,
           -27.716144041583874,
           -27.74240556561344,
           -27.76866708964301,
           -27.794928613672575,
           -27.821190137702146,
           -27.84745166173171,
           -27.873713185761282,
           -27.899974709790847,
           -27.92623623382042,
           -27.952497757849983,
           -27.978759281879555,
           -28.00502080590912,
           -28.03128232993869,
           -28.057543853968255,
           -28.083805377997827,
           -28.11006690202739,
           -28.13891562138857,
           -28.169057938415552,
           -28.199200255442534,
           -28.229342572469516,
           -28.2594848894965,
           -28.289627206523484,
           -28.319769523550466,
           -28.349911840577448,
           -28.380054157604434,
           -28.41019647463141,
           -28.440338791658395,
           -28.470481108685377,
           -28.500623425712362,
           -28.53076574273934,
           -28.560908059766323,
           -28.591050376793305,
           -28.62119269382029,
           -28.651335010847273,
           -28.681477327874255,
           -28.71161964490124,
           -28.74176196192822,
           -28.7719042789552,
           -28.802046595982183,
           -28.83218891300917,
           -28.862331230036148,
           -28.892473547063126,
           -28.922615864090115,
           -28.952758181117094,
           -28.982900498144076,
           -29.013042815171058,
           -29.043185132198044,
           -29.073327449225022,
           -29.103469766252008,
           -29.13361208327899,
           -29.163754400305972,
           -29.193896717332954,
           -29.224039034359933,
           -29.25418135138692,
           -29.284323668413904,
           -29.314465985440883,
           -29.34460830246787,
           -29.374750619494854,
           -29.404892936521833,
           -29.43503525354881,
           -29.465177570575797,
           -29.495319887602783,
           -29.52546220462976,
           -29.555604521656747,
           -29.58574683868373,
           -29.615889155710708,
           -29.646031472737693,
           -29.676173789764675,
           -29.706316106791654,
           -29.73645842381864,
           -29.766600740845618,
           -29.796743057872604,
           -29.826885374899586,
           -29.857027691926564,
           -29.88717000895355,
           -29.917312325980536,
           -29.947454643007518,
           -29.977596960034496,
           -30.007739277061482,
           -30.03788159408846,
           -30.067847074401172,
           -30.09698730993162,
           -30.12612754546207,
           -30.15526778099252,
           -30.18440801652297,
           -30.213548252053414,
           -30.242688487583866,
           -30.271828723114314,
           -30.300968958644763,
           -30.330109194175215,
           -30.35924942970566,
           -30.388389665236108,
           -30.41752990076656,
           -30.44667013629701,
           -30.475810371827453,
           -30.504950607357905,
           -30.534090842888354,
           -30.563231078418802,
           -30.59237131394925,
           -30.60440610197366,
           -30.599335442492034,
           -30.594264783010406,
           -30.58919412352878,
           -30.58412346404715,
           -30.57905280456552,
           -30.573982145083896,
           -30.568911485602268,
           -30.56384082612064,
           -30.558770166639015,
           -30.553699507157383,
           -30.54742989313604,
           -30.52720883617896,
           -30.506987779221877,
           -30.486766722264793,
           -30.466545665307713,
           -30.446324608350626,
           -30.426103551393545,
           -30.40588249443646,
           -30.38566143747938,
           -30.365440380522298,
           -30.34521932356521,
           -30.324998266608134,
           -30.304777209651043,
           -30.28455615269396,
           -30.264335095736882,
           -30.244114038779795,
           -30.22389298182271,
           -30.20367192486563,
           -30.183450867908547,
           -30.163229810951464,
           -30.14300875399438,
           -30.1227876970373,
           -30.102566640080216,
           -30.08234558312313,
           -30.062124526166045,
           -30.041903469208965,
           -30.02168241225188,
           -30.001461355294797,
           -29.981240298337717,
           -29.96101924138063,
           -29.94079818442355,
           -29.92057712746647,
           -29.900356070509382,
           -29.880135013552298,
           -29.85991395659522,
           -29.839692899638134,
           -29.81947184268105,
           -29.79925078572397,
           -29.779029728766886,
           -29.758808671809803,
           -29.73858761485272,
           -29.718366557895635,
           -29.69814550093855,
           -29.677924443981468,
           -29.65770338702439,
           -29.6374823300673,
           -29.61726127311022,
           -29.597040216153136,
           -29.576819159196052,
           -29.556598102238972,
           -29.536377045281885,
           -29.516155988324808,
           -29.49593493136772,
           -29.475713874410637,
           -29.455492817453557,
           -29.43527176049647,
           -29.415050703539386,
           -29.394829646582306,
           -29.374608589625222,
           -29.35438753266814,
           -29.334166475711054,
           -29.313945418753974,
           -29.293724361796887,
           -29.273503304839807,
           -29.253282247882723,
           -29.23306119092564,
           -29.21284013396856,
           -29.19261907701147,
           -29.17239802005439,
           -29.152176963097304,
           -29.131955906140224,
           -29.11173484918314,
           -29.083201475237736,
           -29.038043467315703,
           -28.992885459393662,
           -28.947727451471625,
           -28.902569443549588,
           -28.857411435627554,
           -28.81225342770551,
           -28.767095419783473,
           -28.72193741186144,
           -28.676779403939403,
           -28.631621396017366,
           -28.58646338809533,
           -28.54130538017329,
           -28.49614737225125,
           -28.450989364329217,
           -28.40583135640718,
           -28.360673348485143,
           -28.31551534056311,
           -28.270357332641073,
           -28.22519932471903,
           -28.18004131679699,
           -28.134883308874958,
           -28.08972530095292,
           -28.044567293030884,
           -27.999409285108847,
           -27.95425127718681,
           -27.909093269264773,
           -27.863935261342736,
           -27.8187772534207,
           -27.77361924549866,
           -27.728461237576617,
           -27.68330322965459,
           -27.63814522173255,
           -27.59298721381051,
           -27.547829205888476,
           -27.50267119796644,
           -27.4575131900444,
           -27.412355182122365,
           -27.367197174200328,
           -27.322039166278287,
           -27.276881158356254,
           -27.231723150434217,
           -27.18656514251218,
           -27.141407134590136,
           -27.096249126668102,
           -27.051091118746065,
           -27.005933110824028,
           -26.960775102901987,
           -26.915617094979957,
           -26.870459087057917,
           -26.82530107913588,
           -26.780143071213843,
           -26.734985063291806,
           -26.689827055369765,
           -26.644669047447735,
           -26.599511039525694,
           -26.554353031603654,
           -26.509195023681617,
           -26.464037015759587,
           -26.418879007837543,
           -26.37372099991551,
           -26.32868515293486,
           -26.283764288456126,
           -26.238843423977404,
           -26.19392255949868,
           -26.149001695019955,
           -26.10408083054122,
           -26.059159966062502,
           -26.01423910158377,
           -25.969318237105043,
           -25.92439737262632,
           -25.879476508147594,
           -25.83455564366886,
           -25.789634779190134,
           -25.74471391471141,
           -25.69979305023268,
           -25.654872185753952,
           -25.609951321275233,
           -25.5650304567965,
           -25.520109592317773,
           -25.475188727839047,
           -25.43026786336032,
           -25.385346998881595,
           -25.326889196706816,
           -25.20074670605176,
           -25.074604215396704,
           -24.948461724741644,
           -24.774893654949594,
           -24.597866438426202,
           -24.420839221902813,
           -24.24381200537945,
           -24.06678478885606,
           -23.889757572332666,
           -23.712730355809303,
           -23.535703139285914,
           -23.35867592276252,
           -23.181648706239127,
           -23.004621489715767,
           -22.827594273192375,
           -22.650567056668983,
           -22.473539840145623,
           -22.29651262362223,
           -22.11948540709884,
           -21.94245819057548,
           -21.765430974052084,
           -21.588403757528695,
           -21.411376541005332,
           -21.234349324481943,
           -21.057322107958548,
           -20.88029489143516,
           -20.7032676749118,
           -20.526240458388408,
           -20.349213241865012,
           -20.172186025341656,
           -19.99515880881826,
           -19.81813159229487,
           -19.641104375771505,
           -19.464077159248113,
           -19.28704994272472,
           -19.11002272620133,
           -18.932995509677973,
           -18.75596829315458,
           -18.57894107663119,
           -18.401913860107825,
           -18.224886643584433,
           -18.04785942706104,
           -17.87083221053768,
           -17.69380499401429,
           -17.516777777490898,
           -17.339750560967538,
           -17.162723344444146,
           -16.985696127920754,
           -16.808668911397362,
           -16.631641694874,
           -16.454614478350607,
           -16.277587261827215,
           -16.100560045303855,
           -15.923532828780463,
           -15.74650561225707,
           -15.56947839573371,
           -15.392451179210319,
           -15.215423962686927,
           -15.038396746163533,
           -14.861369529640175,
           -14.684342313116781,
           -14.507315096593391,
           -14.33028788007003,
           -14.153260663546636,
           -13.976233447023244,
           -13.799206230499884,
           -13.622179013976492,
           -13.4451517974531,
           -13.26812458092974,
           -13.091097364406348,
           -12.914070147882954,
           -12.737042931359563,
           -12.560015714836203,
           -12.382988498312809,
           -12.205961281789417,
           -12.028934065266057,
           -11.851906848742665,
           -11.674879632219273,
           -11.497852415695913,
           -11.30591723523636,
           -11.06535636482047,
           -10.824795494404583,
           -10.58423462398874
          ],
          [
           -23.143338709370568,
           -23.170452923872247,
           -23.197567138373927,
           -23.224681352875606,
           -23.25179556737729,
           -23.278909781878973,
           -23.306023996380652,
           -23.333138210882336,
           -23.36025242538402,
           -23.3873666398857,
           -23.414480854387378,
           -23.44159506888906,
           -23.468709283390744,
           -23.495823497892424,
           -23.522937712394107,
           -23.55005192689579,
           -23.57716614139747,
           -23.60428035589915,
           -23.631394570400833,
           -23.658508784902516,
           -23.685622999404195,
           -23.712737213905875,
           -23.739851428407555,
           -23.76696564290924,
           -23.79407985741092,
           -23.8211940719126,
           -23.848308286414287,
           -23.875422500915967,
           -23.902536715417646,
           -23.929650929919326,
           -23.95676514442101,
           -23.983879358922692,
           -24.010993573424372,
           -24.038107787926055,
           -24.06522200242774,
           -24.092336216929418,
           -24.119450431431098,
           -24.14656464593278,
           -24.173678860434464,
           -24.200793074936144,
           -24.227907289437823,
           -24.255021503939506,
           -24.28213571844119,
           -24.30924993294287,
           -24.33636414744455,
           -24.363478361946232,
           -24.390592576447915,
           -24.417706790949595,
           -24.444821005451278,
           -24.47193521995296,
           -24.49904943445464,
           -24.526163648956324,
           -24.553277863458003,
           -24.580392077959687,
           -24.60750629246137,
           -24.63462050696305,
           -24.661734721464732,
           -24.688848935966412,
           -24.71596315046809,
           -24.74307736496978,
           -24.770191579471458,
           -24.79730579397314,
           -24.82442000847482,
           -24.8515342229765,
           -24.87864843747818,
           -24.905762651979863,
           -24.932876866481546,
           -24.959991080983226,
           -24.98710529548491,
           -25.01421950998659,
           -25.041333724488272,
           -25.06844793898995,
           -25.095562153491635,
           -25.122676367993318,
           -25.149790582494997,
           -25.17690479699668,
           -25.204402405555218,
           -25.23381696578327,
           -25.263231526011317,
           -25.292646086239362,
           -25.322060646467413,
           -25.35147520669546,
           -25.38088976692351,
           -25.41030432715156,
           -25.43890621730917,
           -25.467345573452704,
           -25.49578492959623,
           -25.524224285739763,
           -25.552663641883292,
           -25.58110299802682,
           -25.609542354170348,
           -25.636892797194132,
           -25.663154321223704,
           -25.68941584525327,
           -25.71567736928284,
           -25.741938893312405,
           -25.768200417341976,
           -25.79446194137154,
           -25.82072346540111,
           -25.846984989430677,
           -25.873246513460245,
           -25.899508037489817,
           -25.92576956151938,
           -25.95203108554895,
           -25.978292609578517,
           -26.004554133608085,
           -26.030815657637653,
           -26.057077181667218,
           -26.08333870569679,
           -26.109600229726357,
           -26.135861753755925,
           -26.162123277785494,
           -26.188384801815058,
           -26.21464632584463,
           -26.240907849874194,
           -26.267169373903762,
           -26.293430897933334,
           -26.3196924219629,
           -26.345953945992463,
           -26.372215470022034,
           -26.3984769940516,
           -26.42473851808117,
           -26.451000042110735,
           -26.477261566140307,
           -26.50352309016987,
           -26.529784614199443,
           -26.55604613822901,
           -26.58230766225858,
           -26.608569186288143,
           -26.634830710317715,
           -26.66109223434728,
           -26.68735375837685,
           -26.71361528240642,
           -26.73987680643598,
           -26.76613833046555,
           -26.792399854495123,
           -26.818661378524688,
           -26.844922902554252,
           -26.871184426583824,
           -26.897445950613392,
           -26.92370747464296,
           -26.949968998672528,
           -26.976230522702096,
           -27.002492046731664,
           -27.028753570761232,
           -27.0550150947908,
           -27.081276618820368,
           -27.107538142849936,
           -27.1337996668795,
           -27.160061190909072,
           -27.186322714938637,
           -27.21258423896821,
           -27.238845762997773,
           -27.26510728702734,
           -27.29136881105691,
           -27.317630335086477,
           -27.343891859116045,
           -27.370153383145613,
           -27.39641490717518,
           -27.42267643120475,
           -27.448937955234317,
           -27.475199479263885,
           -27.501461003293453,
           -27.527722527323018,
           -27.55398405135259,
           -27.580245575382158,
           -27.606507099411726,
           -27.635355818772904,
           -27.665498135799886,
           -27.695640452826865,
           -27.72578276985385,
           -27.755925086880833,
           -27.78606740390782,
           -27.8162097209348,
           -27.846352037961783,
           -27.876494354988765,
           -27.906636672015743,
           -27.93677898904273,
           -27.966921306069707,
           -27.997063623096693,
           -28.027205940123675,
           -28.057348257150657,
           -28.08749057417764,
           -28.117632891204625,
           -28.147775208231607,
           -28.177917525258586,
           -28.20805984228557,
           -28.2373769190821,
           -28.26651715461255,
           -28.295657390142996,
           -28.324797625673447,
           -28.353937861203892,
           -28.383078096734344,
           -28.412218332264793,
           -28.44135856779524,
           -28.47049880332569,
           -28.499639038856138,
           -28.528779274386586,
           -28.55791950991704,
           -28.587059745447483,
           -28.61619998097793,
           -28.64534021650838,
           -28.67448045203883,
           -28.70362068756928,
           -28.732760923099725,
           -28.761901158630177,
           -28.791041394160622,
           -28.82018162969107,
           -28.849321865221523,
           -28.87846210075197,
           -28.907602336282416,
           -28.93674257181287,
           -28.96588280734332,
           -28.995023042873765,
           -29.024163278404217,
           -29.053303513934665,
           -29.082443749465114,
           -29.111583984995562,
           -29.140724220526014,
           -29.16986445605646,
           -29.19900469158691,
           -29.228144927117356,
           -29.257285162647804,
           -29.286425398178253,
           -29.3155656337087,
           -29.344705869239153,
           -29.3738461047696,
           -29.402986340300046,
           -29.432126575830498,
           -29.46126681136095,
           -29.4904070468914,
           -29.519547282421843,
           -29.548687517952295,
           -29.577827753482744,
           -29.606967989013192,
           -29.63610822454364,
           -29.66524846007409,
           -29.694388695604538,
           -29.723528931134986,
           -29.752669166665434,
           -29.781809402195886,
           -29.810949637726335,
           -29.840089873256783,
           -29.86923010878723,
           -29.89837034431768,
           -29.92751057984813,
           -29.956650815378573,
           -29.98579105090903,
           -30.014931286439477,
           -30.044071521969926,
           -30.056106309994334,
           -30.051035650512706,
           -30.045964991031077,
           -30.040894331549453,
           -30.035823672067828,
           -30.030753012586196,
           -30.02568235310457,
           -30.02061169362294,
           -30.01554103414131,
           -30.01047037465969,
           -30.005399715178058,
           -30.00032905569643,
           -29.9952583962148,
           -29.990187736733176,
           -29.985117077251548,
           -29.98004641776992,
           -29.974975758288295,
           -29.969905098806667,
           -29.96483443932504,
           -29.959763779843414,
           -29.954693120361785,
           -29.949622460880157,
           -29.94455180139853,
           -29.9394811419169,
           -29.934410482435275,
           -29.929339822953647,
           -29.92426916347202,
           -29.91919850399039,
           -29.914127844508762,
           -29.909057185027137,
           -29.90398652554551,
           -29.89891586606388,
           -29.893845206582256,
           -29.888774547100628,
           -29.883703887619,
           -29.878633228137375,
           -29.873562568655746,
           -29.868491909174118,
           -29.86342124969249,
           -29.846579057328242,
           -29.826358000371158,
           -29.806136943414078,
           -29.785915886456998,
           -29.765694829499907,
           -29.74547377254283,
           -29.725252715585746,
           -29.705031658628663,
           -29.68481060167158,
           -29.664589544714495,
           -29.644368487757415,
           -29.624147430800328,
           -29.603926373843244,
           -29.583705316886164,
           -29.56348425992908,
           -29.543263202971993,
           -29.523042146014916,
           -29.502821089057832,
           -29.48260003210075,
           -29.462378975143665,
           -29.442157918186584,
           -29.421936861229497,
           -29.401715804272417,
           -29.381494747315333,
           -29.361273690358246,
           -29.341052633401166,
           -29.320831576444085,
           -29.300610519486998,
           -29.280389462529918,
           -29.260168405572834,
           -29.23994734861575,
           -29.219726291658667,
           -29.199505234701583,
           -29.179284177744503,
           -29.159063120787415,
           -29.138842063830335,
           -29.118621006873255,
           -29.09839994991617,
           -29.078178892959084,
           -29.057957836002004,
           -29.03773677904492,
           -29.017515722087836,
           -28.997294665130752,
           -28.97707360817367,
           -28.94854023422826,
           -28.903382226306228,
           -28.858224218384194,
           -28.813066210462154,
           -28.76790820254012,
           -28.722750194618083,
           -28.677592186696046,
           -28.632434178774005,
           -28.587276170851972,
           -28.54211816292993,
           -28.496960155007898,
           -28.451802147085857,
           -28.406644139163824,
           -28.361486131241783,
           -28.316328123319746,
           -28.27117011539771,
           -28.226012107475672,
           -28.180854099553635,
           -28.1356960916316,
           -28.09053808370956,
           -28.04538007578752,
           -28.000222067865487,
           -27.95506405994345,
           -27.909906052021412,
           -27.864748044099372,
           -27.81959003617734,
           -27.7744320282553,
           -27.729274020333264,
           -27.684116012411224,
           -27.63895800448919,
           -27.593799996567153,
           -27.548641988645116,
           -27.503483980723075,
           -27.45832597280104,
           -27.413167964879,
           -27.36800995695696,
           -27.322851949034927,
           -27.277693941112894,
           -27.23253593319086,
           -27.18737792526882,
           -27.142219917346782,
           -27.097061909424745,
           -27.051903901502705,
           -27.00674589358067,
           -26.96158788565863,
           -26.916429877736597,
           -26.871271869814557,
           -26.826113861892523,
           -26.780955853970482,
           -26.735797846048445,
           -26.69063983812641,
           -26.645481830204375,
           -26.600323822282334,
           -26.555165814360294,
           -26.509585905145123,
           -26.46148324679521,
           -26.4133805884453,
           -26.36527793009539,
           -26.317175271745484,
           -26.26907261339557,
           -26.22096995504566,
           -26.172867296695753,
           -26.124764638345837,
           -26.076661979995933,
           -26.028559321646018,
           -25.980456663296106,
           -25.932354004946195,
           -25.88425134659629,
           -25.83614868824638,
           -25.788046029896464,
           -25.739943371546556,
           -25.691840713196648,
           -25.643738054846732,
           -25.595635396496824,
           -25.54753273814692,
           -25.499430079797,
           -25.451327421447093,
           -25.40322476309719,
           -25.355122104747274,
           -25.30701944639736,
           -25.258916788047447,
           -25.21081412969754,
           -25.162711471347627,
           -25.107775880794996,
           -25.018675629228728,
           -24.92957537766246,
           -24.84047512609619,
           -24.751374874529937,
           -24.662274622963665,
           -24.573174371397393,
           -24.484074119831142,
           -24.39497386826487,
           -24.305873616698598,
           -24.216773365132347,
           -24.127673113566075,
           -24.038572861999807,
           -23.94947261043354,
           -23.860372358867284,
           -23.771272107301012,
           -23.68217185573474,
           -23.59307160416849,
           -23.503971352602218,
           -23.414871101035953,
           -23.3257708494697,
           -23.236670597903426,
           -23.14757034633715,
           -23.058470094770904,
           -22.969369843204632,
           -22.880269591638363,
           -22.79116934007209,
           -22.702069088505837,
           -22.612968836939565,
           -22.523868585373297,
           -22.434768333807042,
           -22.345668082240774,
           -22.256567830674506,
           -22.155743796047798,
           -21.978716579524406,
           -21.80168936300101,
           -21.62466214647762,
           -21.447634929954262,
           -21.270607713430866,
           -21.093580496907478,
           -20.916553280384115,
           -20.739526063860723,
           -20.56249884733733,
           -20.38547163081397,
           -20.20844441429058,
           -20.031417197767187,
           -19.854389981243823,
           -19.677362764720435,
           -19.50033554819704,
           -19.323308331673648,
           -19.14368125390859,
           -18.88865320394742,
           -18.63362515398625,
           -18.37859710402513,
           -18.123569054063964,
           -17.868541004102795,
           -17.613512954141676,
           -17.358484904180507,
           -17.10345685421934,
           -16.84842880425817,
           -16.59340075429705,
           -16.33837270433588,
           -16.083344654374716,
           -15.828316604413594,
           -15.573288554452429,
           -15.31826050449126,
           -15.063232454530137,
           -14.808204404568972,
           -14.553176354607803,
           -14.298148304646684,
           -14.043120254685515,
           -13.788092204724347,
           -13.533064154763181,
           -13.278036104802059,
           -13.023008054840894,
           -12.767980004879725,
           -12.512951954918604,
           -12.257923904957435,
           -12.002895854996268,
           -11.747867805035149,
           -11.49283975507398,
           -11.237811705112811,
           -10.982783655151646,
           -10.727755605190524
          ],
          [
           -22.708416038823046,
           -22.733098819354378,
           -22.757781599885707,
           -22.78246438041704,
           -22.807147160948375,
           -22.83182994147971,
           -22.85651272201104,
           -22.881195502542372,
           -22.905878283073708,
           -22.93056106360504,
           -22.95727004275723,
           -22.98438425725891,
           -23.011498471760596,
           -23.038612686262272,
           -23.065726900763956,
           -23.09284111526564,
           -23.11995532976732,
           -23.147069544269,
           -23.17418375877068,
           -23.20129797327236,
           -23.228412187774044,
           -23.255526402275727,
           -23.282640616777407,
           -23.30975483127909,
           -23.336869045780773,
           -23.363983260282453,
           -23.391097474784136,
           -23.418211689285815,
           -23.4453259037875,
           -23.472440118289178,
           -23.499554332790858,
           -23.52666854729254,
           -23.553782761794224,
           -23.580896976295904,
           -23.608011190797587,
           -23.63512540529927,
           -23.66223961980095,
           -23.68935383430263,
           -23.716468048804312,
           -23.743582263305996,
           -23.770696477807675,
           -23.797810692309355,
           -23.82492490681104,
           -23.85203912131272,
           -23.8791533358144,
           -23.90626755031608,
           -23.933381764817764,
           -23.960495979319447,
           -23.987610193821126,
           -24.01472440832281,
           -24.041838622824493,
           -24.068952837326172,
           -24.096067051827852,
           -24.123181266329535,
           -24.15029548083122,
           -24.177409695332898,
           -24.204523909834577,
           -24.23163812433626,
           -24.258752338837944,
           -24.285866553339623,
           -24.312980767841303,
           -24.340094982342986,
           -24.36720919684467,
           -24.394323411346353,
           -24.421437625848036,
           -24.44855184034971,
           -24.475666054851395,
           -24.502780269353075,
           -24.52989448385476,
           -24.557008698356434,
           -24.58412291285812,
           -24.6112371273598,
           -24.638351341861483,
           -24.665465556363166,
           -24.692579770864842,
           -24.719693985366526,
           -24.74680819986821,
           -24.773922414369892,
           -24.80103662887157,
           -24.82815084337326,
           -24.855265057874934,
           -24.882379272376614,
           -24.909493486878297,
           -24.93660770137998,
           -24.961113555809373,
           -24.985097738224308,
           -25.00908192063924,
           -25.033066103054175,
           -25.05705028546911,
           -25.081034467884038,
           -25.105018650298973,
           -25.12900283271391,
           -25.15298701512884,
           -25.178489428701397,
           -25.20475095273096,
           -25.23101247676053,
           -25.2572740007901,
           -25.28353552481967,
           -25.309797048849237,
           -25.3360585728788,
           -25.36232009690837,
           -25.38858162093794,
           -25.414843144967506,
           -25.44110466899707,
           -25.467366193026646,
           -25.49362771705621,
           -25.519889241085778,
           -25.546150765115343,
           -25.57241228914491,
           -25.598673813174486,
           -25.62493533720405,
           -25.65119686123362,
           -25.677458385263183,
           -25.703719909292758,
           -25.729981433322322,
           -25.75624295735189,
           -25.782504481381455,
           -25.808766005411023,
           -25.83502752944059,
           -25.861289053470163,
           -25.88755057749973,
           -25.913812101529295,
           -25.940073625558867,
           -25.96633514958843,
           -25.992596673618003,
           -26.018858197647567,
           -26.04511972167714,
           -26.071381245706704,
           -26.09764276973627,
           -26.12390429376584,
           -26.150165817795404,
           -26.176427341824976,
           -26.20268886585454,
           -26.228950389884112,
           -26.25521191391368,
           -26.281473437943248,
           -26.307734961972812,
           -26.333996486002384,
           -26.36025801003195,
           -26.38651953406152,
           -26.412781058091085,
           -26.439042582120656,
           -26.46530410615022,
           -26.49156563017979,
           -26.517827154209357,
           -26.54408867823893,
           -26.570350202268493,
           -26.596611726298065,
           -26.62287325032763,
           -26.6491347743572,
           -26.675396298386765,
           -26.70165782241633,
           -26.727919346445905,
           -26.754180870475473,
           -26.78044239450504,
           -26.806703918534605,
           -26.832965442564173,
           -26.859226966593738,
           -26.88548849062331,
           -26.911750014652874,
           -26.938011538682446,
           -26.96427306271201,
           -26.990534586741582,
           -27.016796110771146,
           -27.043057634800718,
           -27.069319158830286,
           -27.09558068285985,
           -27.12315303713325,
           -27.151380806528557,
           -27.17960857592387,
           -27.207836345319183,
           -27.236064114714495,
           -27.26429188410981,
           -27.292519653505117,
           -27.320747422900432,
           -27.348975192295743,
           -27.377202961691054,
           -27.405430731086366,
           -27.433658500481677,
           -27.46188626987699,
           -27.490114039272303,
           -27.518341808667614,
           -27.546569578062925,
           -27.57479734745824,
           -27.603025116853548,
           -27.63125288624886,
           -27.659936891572322,
           -27.68907712710277,
           -27.71821736263322,
           -27.747357598163667,
           -27.77649783369412,
           -27.805638069224564,
           -27.834778304755016,
           -27.863918540285464,
           -27.893058775815913,
           -27.92219901134636,
           -27.95133924687681,
           -27.980479482407258,
           -28.00961971793771,
           -28.038759953468155,
           -28.067900188998603,
           -28.097040424529055,
           -28.1261806600595,
           -28.155320895589952,
           -28.1844611311204,
           -28.21360136665085,
           -28.242741602181294,
           -28.271881837711746,
           -28.301022073242194,
           -28.330162308772643,
           -28.35930254430309,
           -28.388442779833547,
           -28.417583015363988,
           -28.446723250894436,
           -28.475863486424885,
           -28.505003721955337,
           -28.53414395748579,
           -28.563284193016237,
           -28.592424428546686,
           -28.621564664077127,
           -28.650704899607582,
           -28.67984513513803,
           -28.70898537066848,
           -28.738125606198924,
           -28.767265841729376,
           -28.79640607725982,
           -28.825546312790273,
           -28.85468654832072,
           -28.88382678385117,
           -28.912967019381618,
           -28.94210725491207,
           -28.97124749044252,
           -29.000387725972963,
           -29.02952796150342,
           -29.05866819703386,
           -29.087808432564316,
           -29.11694866809476,
           -29.14608890362521,
           -29.175229139155658,
           -29.20436937468611,
           -29.233509610216558,
           -29.262649845747003,
           -29.291790081277455,
           -29.320930316807903,
           -29.35007055233835,
           -29.379210787868796,
           -29.40835102339925,
           -29.437491258929693,
           -29.46663149446015,
           -29.4957717299906,
           -29.507806518015006,
           -29.502735858533377,
           -29.49766519905175,
           -29.492594539570124,
           -29.487523880088492,
           -29.482453220606867,
           -29.47738256112524,
           -29.472311901643614,
           -29.467241242161986,
           -29.462170582680358,
           -29.45709992319873,
           -29.452029263717105,
           -29.446958604235476,
           -29.44188794475385,
           -29.436817285272223,
           -29.431746625790595,
           -29.42667596630897,
           -29.421605306827338,
           -29.416534647345713,
           -29.411463987864085,
           -29.406393328382457,
           -29.401322668900832,
           -29.396252009419204,
           -29.391181349937575,
           -29.38611069045595,
           -29.381040030974322,
           -29.375969371492694,
           -29.370898712011066,
           -29.36582805252944,
           -29.360757393047813,
           -29.355686733566184,
           -29.350616074084556,
           -29.34554541460293,
           -29.3404747551213,
           -29.335404095639674,
           -29.330333436158046,
           -29.325262776676418,
           -29.320192117194793,
           -29.315121457713165,
           -29.310050798231536,
           -29.304980138749908,
           -29.299909479268283,
           -29.294838819786655,
           -29.289768160305027,
           -29.2846975008234,
           -29.279626841341774,
           -29.274556181860145,
           -29.269485522378517,
           -29.26441486289689,
           -29.25934420341526,
           -29.254273543933635,
           -29.249202884452007,
           -29.24413222497038,
           -29.239061565488754,
           -29.233990906007126,
           -29.228920246525497,
           -29.22384958704387,
           -29.21877892756224,
           -29.213708268080616,
           -29.20863760859899,
           -29.203566949117363,
           -29.198496289635735,
           -29.19342563015411,
           -29.18835497067248,
           -29.183284311190853,
           -29.178213651709225,
           -29.165949278477527,
           -29.145728221520443,
           -29.12550716456336,
           -29.105286107606283,
           -29.08506505064919,
           -29.06484399369211,
           -29.04462293673503,
           -29.02440187977794,
           -29.004180822820864,
           -28.98395976586378,
           -28.963738708906696,
           -28.943517651949616,
           -28.92329659499253,
           -28.903075538035445,
           -28.88285448107836,
           -28.86263342412128,
           -28.842412367164194,
           -28.81387899321879,
           -28.76872098529676,
           -28.72356297737472,
           -28.678404969452682,
           -28.633246961530645,
           -28.58808895360861,
           -28.54293094568657,
           -28.49777293776453,
           -28.4526149298425,
           -28.40745692192046,
           -28.36229891399842,
           -28.317140906076382,
           -28.27198289815435,
           -28.22682489023231,
           -28.181666882310275,
           -28.136508874388237,
           -28.0913508664662,
           -28.046192858544167,
           -28.00103485062213,
           -27.95587684270009,
           -27.91071883477805,
           -27.864286530882207,
           -27.8161838725323,
           -27.768081214182388,
           -27.71997855583248,
           -27.671875897482572,
           -27.623773239132657,
           -27.575670580782752,
           -27.52756792243284,
           -27.479465264082926,
           -27.431362605733014,
           -27.383259947383113,
           -27.335157289033194,
           -27.287054630683283,
           -27.238951972333375,
           -27.190849313983467,
           -27.14274665563355,
           -27.094643997283647,
           -27.04654133893374,
           -26.998438680583824,
           -26.950336022233913,
           -26.902233363884005,
           -26.85413070553409,
           -26.806028047184178,
           -26.757925388834273,
           -26.709822730484365,
           -26.66172007213445,
           -26.613617413784546,
           -26.565514755434634,
           -26.51741209708472,
           -26.46930943873481,
           -26.421206780384903,
           -26.37310412203499,
           -26.325001463685076,
           -26.276898805335172,
           -26.22879614698526,
           -26.18069348863535,
           -26.132590830285437,
           -26.084488171935533,
           -26.036385513585618,
           -25.98828285523571,
           -25.940180196885798,
           -25.892077538535887,
           -25.84397488018598,
           -25.79587222183607,
           -25.747769563486152,
           -25.69966690513624,
           -25.651564246786336,
           -25.603461588436428,
           -25.555358930086513,
           -25.5072562717366,
           -25.459153613386697,
           -25.41105095503678,
           -25.362948296686874,
           -25.314845638336966,
           -25.26674297998705,
           -25.21864032163714,
           -25.170537663287234,
           -25.12243500493732,
           -25.074332346587408,
           -25.0262296882375,
           -24.978127029887588,
           -24.930024371537677,
           -24.87508878098505,
           -24.78598852941878,
           -24.6968882778525,
           -24.607788026286237,
           -24.518687774719982,
           -24.429587523153714,
           -24.340487271587442,
           -24.25138702002119,
           -24.16228676845492,
           -24.073186516888647,
           -23.984086265322397,
           -23.894986013756125,
           -23.805885762189853,
           -23.71678551062358,
           -23.62768525905733,
           -23.538585007491058,
           -23.449484755924793,
           -23.360384504358535,
           -23.271284252792267,
           -23.182184001226,
           -23.09308374965974,
           -23.003983498093472,
           -22.914883246527204,
           -22.825782994960946,
           -22.664785867686508,
           -22.50066262056597,
           -22.336539373445426,
           -22.17241612632492,
           -22.008292879204376,
           -21.844169632083837,
           -21.680046384963326,
           -21.51592313784279,
           -21.351799890722248,
           -21.187676643601737,
           -21.023553396481198,
           -20.85943014936066,
           -20.69530690224012,
           -20.531183655119605,
           -20.367060407999066,
           -20.202937160878527,
           -20.03881391375802,
           -19.874690666637477,
           -19.710567419516938,
           -19.546444172396427,
           -19.382320925275888,
           -19.21819767815535,
           -19.054074431034834,
           -18.8899511839143,
           -18.72582793679376,
           -18.56170468967322,
           -18.39758144255271,
           -18.233458195432167,
           -18.069334948311628,
           -17.90521170119112,
           -17.741088454070578,
           -17.57696520695004,
           -17.41284195982953,
           -17.24871871270899,
           -17.08459546558845,
           -16.92047221846791,
           -16.73741027482734,
           -16.48238222486617,
           -16.227354174905003,
           -15.972326124943883,
           -15.717298074982716,
           -15.462270025021546,
           -15.207241975060427,
           -14.95221392509926,
           -14.697185875138093,
           -14.442157825176972,
           -14.187129775215805,
           -13.932101725254636,
           -13.67707367529347,
           -13.422045625332348,
           -13.16701757537118,
           -12.911989525410013,
           -12.656961475448892,
           -12.401933425487725,
           -12.146905375526558,
           -11.891877325565437,
           -11.63684927560427,
           -11.381821225643103,
           -11.126793175681934,
           -10.871765125720813
          ],
          [
           -22.269291126749906,
           -22.293973907281238,
           -22.318656687812567,
           -22.3433394683439,
           -22.368022248875235,
           -22.39270502940657,
           -22.4173878099379,
           -22.442070590469232,
           -22.466753371000568,
           -22.4914361515319,
           -22.516118932063236,
           -22.540801712594565,
           -22.565484493125897,
           -22.590167273657233,
           -22.614850054188565,
           -22.6395328347199,
           -22.66421561525123,
           -22.688898395782566,
           -22.713581176313898,
           -22.73826395684523,
           -22.762946737376566,
           -22.787629517907895,
           -22.812312298439227,
           -22.836995078970563,
           -22.861677859501892,
           -22.886360640033228,
           -22.911853901799056,
           -22.938968116300735,
           -22.966082330802422,
           -22.9931965453041,
           -23.02031075980578,
           -23.04742497430746,
           -23.07453918880914,
           -23.101653403310827,
           -23.12876761781251,
           -23.15588183231419,
           -23.182996046815873,
           -23.210110261317553,
           -23.237224475819232,
           -23.264338690320912,
           -23.2914529048226,
           -23.31856711932428,
           -23.345681333825958,
           -23.37279554832764,
           -23.399909762829324,
           -23.427023977331004,
           -23.454138191832687,
           -23.48125240633437,
           -23.508366620836046,
           -23.53548083533773,
           -23.56259504983941,
           -23.589709264341096,
           -23.616823478842775,
           -23.643937693344455,
           -23.671051907846138,
           -23.698166122347818,
           -23.725280336849504,
           -23.752394551351184,
           -23.77950876585286,
           -23.806622980354547,
           -23.833737194856226,
           -23.860851409357913,
           -23.88796562385959,
           -23.915079838361272,
           -23.942194052862952,
           -23.96930826736463,
           -23.996422481866315,
           -24.023536696367998,
           -24.050650910869678,
           -24.07776512537136,
           -24.10487933987304,
           -24.131993554374723,
           -24.159107768876403,
           -24.186221983378086,
           -24.21333619787977,
           -24.24045041238145,
           -24.267564626883132,
           -24.294678841384812,
           -24.321793055886495,
           -24.348907270388178,
           -24.376021484889858,
           -24.40313569939154,
           -24.43024991389322,
           -24.4573641283949,
           -24.481869982824293,
           -24.505854165239228,
           -24.529838347654163,
           -24.553822530069098,
           -24.577806712484033,
           -24.60179089489896,
           -24.625775077313897,
           -24.64975925972883,
           -24.673743442143763,
           -24.6977276245587,
           -24.721711806973637,
           -24.745695989388565,
           -24.769680171803504,
           -24.793664354218436,
           -24.81764853663337,
           -24.841632719048306,
           -24.86561690146324,
           -24.889601083878173,
           -24.913585266293108,
           -24.937569448708043,
           -24.961553631122975,
           -24.98553781353791,
           -25.009521995952845,
           -25.033506178367777,
           -25.05749036078271,
           -25.081854103172184,
           -25.108115627201748,
           -25.13437715123132,
           -25.160638675260884,
           -25.186900199290456,
           -25.213161723320024,
           -25.239423247349592,
           -25.26568477137916,
           -25.291946295408728,
           -25.318207819438296,
           -25.34446934346786,
           -25.370730867497432,
           -25.396992391527,
           -25.423253915556568,
           -25.449515439586133,
           -25.475776963615704,
           -25.50203848764527,
           -25.52830001167484,
           -25.554561535704405,
           -25.580823059733973,
           -25.60708458376354,
           -25.63334610779311,
           -25.659607631822677,
           -25.685869155852245,
           -25.712130679881813,
           -25.73839220391138,
           -25.764653727940946,
           -25.790915251970517,
           -25.817176776000085,
           -25.843438300029653,
           -25.86969982405922,
           -25.89596134808879,
           -25.922222872118354,
           -25.948484396147926,
           -25.97474592017749,
           -26.001007444207062,
           -26.027268968236626,
           -26.053530492266198,
           -26.079792016295766,
           -26.106053540325334,
           -26.1323150643549,
           -26.15857658838447,
           -26.184838112414035,
           -26.211099636443603,
           -26.23736116047317,
           -26.26362268450274,
           -26.289884208532307,
           -26.31614573256187,
           -26.342407256591443,
           -26.368668780621007,
           -26.39493030465058,
           -26.421191828680143,
           -26.447453352709715,
           -26.47371487673928,
           -26.49997640076885,
           -26.526237924798416,
           -26.552499448827987,
           -26.578760972857552,
           -26.606333327130947,
           -26.634561096526262,
           -26.662788865921577,
           -26.691016635316885,
           -26.719244404712196,
           -26.747472174107507,
           -26.775699943502822,
           -26.80392771289813,
           -26.832155482293444,
           -26.86038325168876,
           -26.888611021084067,
           -26.91683879047938,
           -26.94506655987469,
           -26.973294329270004,
           -27.001522098665315,
           -27.029749868060623,
           -27.05797763745594,
           -27.08620540685125,
           -27.114433176246564,
           -27.14266094564187,
           -27.170888715037183,
           -27.199116484432498,
           -27.22734425382781,
           -27.255572023223124,
           -27.28379979261843,
           -27.312027562013743,
           -27.340255331409054,
           -27.368483100804365,
           -27.39671087019968,
           -27.42493863959499,
           -27.4531664089903,
           -27.481394178385614,
           -27.509621947780925,
           -27.537849717176236,
           -27.56607748657155,
           -27.59430525596686,
           -27.622533025362173,
           -27.65076079475748,
           -27.678988564152792,
           -27.707216333548107,
           -27.73544410294342,
           -27.763671872338733,
           -27.79189964173404,
           -27.820127411129352,
           -27.848355180524667,
           -27.876582949919978,
           -27.90481071931529,
           -27.9330384887106,
           -27.961266258105915,
           -27.989494027501223,
           -28.017721796896538,
           -28.045949566291846,
           -28.07417733568716,
           -28.10240510762825,
           -28.1315453431587,
           -28.160685578689154,
           -28.189825814219596,
           -28.21896604975005,
           -28.248106285280493,
           -28.277246520810944,
           -28.306386756341393,
           -28.335526991871845,
           -28.364667227402293,
           -28.39380746293274,
           -28.42294769846319,
           -28.452087933993635,
           -28.481228169524087,
           -28.510368405054535,
           -28.539508640584984,
           -28.568648876115432,
           -28.59778911164588,
           -28.62692934717633,
           -28.65606958270678,
           -28.685209818237226,
           -28.714350053767674,
           -28.743490289298123,
           -28.772630524828575,
           -28.801770760359023,
           -28.83091099588947,
           -28.860051231419924,
           -28.88919146695037,
           -28.918331702480817,
           -28.94747193801127,
           -28.959506726035677,
           -28.95443606655405,
           -28.94936540707242,
           -28.944294747590796,
           -28.939224088109164,
           -28.93415342862754,
           -28.929082769145914,
           -28.924012109664282,
           -28.918941450182658,
           -28.91387079070103,
           -28.9088001312194,
           -28.903729471737776,
           -28.89865881225615,
           -28.893588152774523,
           -28.888517493292895,
           -28.883446833811263,
           -28.878376174329638,
           -28.873305514848013,
           -28.868234855366385,
           -28.863164195884753,
           -28.85809353640313,
           -28.853022876921504,
           -28.847952217439875,
           -28.842881557958247,
           -28.837810898476615,
           -28.832740238994994,
           -28.827669579513366,
           -28.822598920031734,
           -28.817528260550105,
           -28.812457601068488,
           -28.807386941586856,
           -28.802316282105227,
           -28.797245622623606,
           -28.792174963141974,
           -28.78710430366035,
           -28.782033644178718,
           -28.776962984697093,
           -28.771892325215468,
           -28.766821665733836,
           -28.761751006252208,
           -28.75668034677058,
           -28.751609687288955,
           -28.746539027807327,
           -28.741468368325698,
           -28.736397708844073,
           -28.73132704936245,
           -28.72625638988082,
           -28.721185730399192,
           -28.716115070917564,
           -28.711044411435935,
           -28.70597375195431,
           -28.700903092472682,
           -28.695832432991054,
           -28.69076177350943,
           -28.685691114027797,
           -28.68062045454617,
           -28.67554979506454,
           -28.670479135582912,
           -28.668087763506016,
           -28.667857119167536,
           -28.667626474829053,
           -28.66739583049057,
           -28.66716518615209,
           -28.666934541813607,
           -28.666703897475124,
           -28.66647325313664,
           -28.66624260879816,
           -28.666011964459678,
           -28.665781320121194,
           -28.66555067578271,
           -28.66532003144423,
           -28.665089387105745,
           -28.664858742767265,
           -28.664628098428786,
           -28.664397454090302,
           -28.66416680975182,
           -28.663936165413336,
           -28.663705521074856,
           -28.663474876736373,
           -28.66324423239789,
           -28.66301358805941,
           -28.66278294372093,
           -28.662552299382444,
           -28.64634691203968,
           -28.598192038688353,
           -28.55003716533703,
           -28.501882291985705,
           -28.453727418634386,
           -28.40557254528306,
           -28.357417671931735,
           -28.30926279858041,
           -28.261107925229087,
           -28.21295305187776,
           -28.16479817852644,
           -28.116643305175113,
           -28.06848843182379,
           -28.020333558472466,
           -27.97217868512114,
           -27.92402381176982,
           -27.875868938418495,
           -27.827714065067173,
           -27.779559191715848,
           -27.731404318364522,
           -27.683249445013196,
           -27.635094571661874,
           -27.58693969831055,
           -27.538784824959226,
           -27.4906299516079,
           -27.442475078256578,
           -27.394320204905256,
           -27.346165331553934,
           -27.298010458202608,
           -27.249855584851282,
           -27.201700711499953,
           -27.153545838148638,
           -27.10539096479731,
           -27.057236091445983,
           -27.00908121809466,
           -26.960926344743342,
           -26.912771471392013,
           -26.86461659804069,
           -26.81646172468937,
           -26.76830685133804,
           -26.72015197798672,
           -26.671997104635395,
           -26.62384223128407,
           -26.575687357932743,
           -26.52753248458142,
           -26.4793776112301,
           -26.43122273787877,
           -26.383067864527447,
           -26.334912991176125,
           -26.286758117824803,
           -26.23860324447348,
           -26.19044837112216,
           -26.142293497770826,
           -26.094138624419504,
           -26.045983751068185,
           -25.997828877716856,
           -25.949674004365527,
           -25.90151913101421,
           -25.85336425766289,
           -25.80520938431156,
           -25.757054510960238,
           -25.708899637608916,
           -25.66074476425759,
           -25.612589890906268,
           -25.564435017554942,
           -25.516280144203616,
           -25.46812527085229,
           -25.419970397500975,
           -25.371815524149646,
           -25.323660650798317,
           -25.275505777446995,
           -25.227350904095676,
           -25.179196030744347,
           -25.131041157393025,
           -25.082886284041702,
           -25.034731410690377,
           -24.986576537339047,
           -24.938421663987732,
           -24.890266790636407,
           -24.84211191728508,
           -24.79395704393376,
           -24.745802170582433,
           -24.697647297231107,
           -24.648318141271048,
           -24.567578773569455,
           -24.403455526448912,
           -24.239332279328373,
           -24.075209032207862,
           -23.911085785087323,
           -23.74696253796678,
           -23.582839290846273,
           -23.41871604372573,
           -23.25459279660519,
           -23.090469549484684,
           -22.926346302364145,
           -22.762223055243602,
           -22.598099808123067,
           -22.433976561002552,
           -22.269853313882013,
           -22.105730066761474,
           -21.941606819640963,
           -21.77748357252042,
           -21.61336032539988,
           -21.449237078279374,
           -21.28511383115883,
           -21.12099058403829,
           -20.95686733691778,
           -20.792744089797242,
           -20.628620842676703,
           -20.464497595556164,
           -20.300374348435653,
           -20.13625110131511,
           -19.972127854194575,
           -19.808004607074068,
           -19.643881359953525,
           -19.479758112832982,
           -19.315634865712475,
           -19.151511618591936,
           -18.987388371471393,
           -18.823265124350854,
           -18.659141877230343,
           -18.495018630109804,
           -18.33089538298926,
           -18.166772135868754,
           -18.00264888874821,
           -17.838525641627673,
           -17.67440239450716,
           -17.510279147386623,
           -17.346155900266083,
           -17.182032653145573,
           -17.017909406025034,
           -16.853786158904494,
           -16.689662911783955,
           -16.525539664663444,
           -16.361416417542905,
           -16.197293170422363,
           -16.033169923301855,
           -15.869046676181313,
           -15.704923429060774,
           -15.540800181940263,
           -15.376676934819724,
           -15.212553687699184,
           -15.048430440578645,
           -14.884307193458135,
           -14.720183946337595,
           -14.556060699217053,
           -14.391937452096544,
           -14.227814204976005,
           -14.063690957855464,
           -13.899567710734953,
           -13.735444463614414,
           -13.571321216493875,
           -13.407197969373366,
           -13.243074722252825,
           -13.078951475132286,
           -12.914828228011746,
           -12.750704980891236,
           -12.586581733770695,
           -12.422458486650154,
           -12.258335239529645,
           -12.094211992409104,
           -11.930088745288565,
           -11.765965498168056,
           -11.601842251047517,
           -11.437719003926976,
           -11.273595756806435,
           -11.015826868028732
          ],
          [
           -21.830166214676762,
           -21.854848995208094,
           -21.879531775739427,
           -21.90421455627076,
           -21.928897336802095,
           -21.953580117333427,
           -21.97826289786476,
           -22.002945678396088,
           -22.027628458927424,
           -22.05231123945876,
           -22.076994019990092,
           -22.101676800521425,
           -22.126359581052757,
           -22.15104236158409,
           -22.175725142115425,
           -22.200407922646757,
           -22.22509070317809,
           -22.249773483709422,
           -22.274456264240754,
           -22.29913904477209,
           -22.32382182530342,
           -22.348504605834755,
           -22.373187386366084,
           -22.39787016689742,
           -22.422552947428752,
           -22.447235727960084,
           -22.47191850849142,
           -22.49660128902275,
           -22.521284069554085,
           -22.545966850085417,
           -22.570649630616753,
           -22.595332411148085,
           -22.620015191679414,
           -22.64469797221075,
           -22.669380752742082,
           -22.694063533273415,
           -22.71874631380475,
           -22.74342909433608,
           -22.768111874867415,
           -22.792794655398744,
           -22.81747743593008,
           -22.842160216461416,
           -22.866842996992748,
           -22.89355197534256,
           -22.920666189844244,
           -22.947780404345927,
           -22.974894618847607,
           -23.002008833349286,
           -23.02912304785097,
           -23.056237262352653,
           -23.083351476854332,
           -23.110465691356012,
           -23.1375799058577,
           -23.16469412035938,
           -23.191808334861058,
           -23.21892254936274,
           -23.24603676386442,
           -23.273150978366104,
           -23.300265192867784,
           -23.327379407369467,
           -23.35449362187115,
           -23.38160783637283,
           -23.40872205087451,
           -23.435836265376192,
           -23.462950479877875,
           -23.490064694379555,
           -23.517178908881235,
           -23.544293123382914,
           -23.5714073378846,
           -23.598521552386284,
           -23.625635766887964,
           -23.652749981389643,
           -23.679864195891327,
           -23.706978410393006,
           -23.734092624894693,
           -23.761206839396372,
           -23.78832105389805,
           -23.81543526839973,
           -23.842549482901415,
           -23.869663697403098,
           -23.89677791190478,
           -23.923892126406457,
           -23.95100634090814,
           -23.978120555409824,
           -24.002626409839216,
           -24.02661059225415,
           -24.050594774669083,
           -24.074578957084018,
           -24.098563139498953,
           -24.122547321913885,
           -24.14653150432882,
           -24.17051568674375,
           -24.194499869158687,
           -24.21848405157362,
           -24.242468233988554,
           -24.26645241640349,
           -24.290436598818424,
           -24.31442078123336,
           -24.338404963648294,
           -24.362389146063226,
           -24.38637332847816,
           -24.410357510893093,
           -24.434341693308028,
           -24.458325875722963,
           -24.482310058137898,
           -24.50629424055283,
           -24.530278422967765,
           -24.554262605382696,
           -24.57824678779763,
           -24.602230970212567,
           -24.626215152627502,
           -24.650199335042434,
           -24.67418351745737,
           -24.6981676998723,
           -24.722151882287235,
           -24.74613606470217,
           -24.770120247117106,
           -24.794104429532037,
           -24.818088611946973,
           -24.842072794361904,
           -24.86605697677684,
           -24.890041159191775,
           -24.914025341606706,
           -24.938009524021645,
           -24.961993706436573,
           -24.985977888851508,
           -25.011480301672538,
           -25.03774182570211,
           -25.064003349731674,
           -25.090264873761242,
           -25.116526397790807,
           -25.14278792182038,
           -25.169049445849947,
           -25.195310969879515,
           -25.221572493909083,
           -25.24783401793865,
           -25.27409554196822,
           -25.300357065997787,
           -25.32661859002735,
           -25.352880114056923,
           -25.37914163808649,
           -25.40540316211606,
           -25.431664686145623,
           -25.457926210175195,
           -25.48418773420476,
           -25.51044925823433,
           -25.536710782263896,
           -25.562972306293467,
           -25.589233830323032,
           -25.615495354352603,
           -25.641756878382168,
           -25.668018402411732,
           -25.694279926441304,
           -25.720541450470876,
           -25.74680297450044,
           -25.773064498530005,
           -25.799326022559576,
           -25.82558754658914,
           -25.851849070618712,
           -25.878110594648277,
           -25.90437211867785,
           -25.930633642707413,
           -25.956895166736984,
           -25.98315669076655,
           -26.00941821479612,
           -26.035679738825685,
           -26.061941262855257,
           -26.089513617128652,
           -26.11774138652396,
           -26.145969155919275,
           -26.174196925314586,
           -26.202424694709897,
           -26.230652464105212,
           -26.25888023350052,
           -26.287108002895835,
           -26.315335772291142,
           -26.343563541686457,
           -26.371791311081772,
           -26.40001908047708,
           -26.428246849872394,
           -26.456474619267702,
           -26.484702388663017,
           -26.512930158058325,
           -26.54115792745364,
           -26.569385696848954,
           -26.597613466244262,
           -26.625841235639577,
           -26.654069005034884,
           -26.6822967744302,
           -26.71052454382551,
           -26.73875231322082,
           -26.766980082616136,
           -26.795207852011444,
           -26.82343562140676,
           -26.851663390802067,
           -26.87989116019738,
           -26.908118929592693,
           -26.936346698988004,
           -26.964574468383315,
           -26.992802237778626,
           -27.021030007173934,
           -27.049257776569252,
           -27.07748554596456,
           -27.10571331535988,
           -27.133941084755186,
           -27.162168854150494,
           -27.19039662354581,
           -27.21862439294112,
           -27.24685216233643,
           -27.275079931731742,
           -27.303307701127054,
           -27.33153547052237,
           -27.35976323991768,
           -27.38799100931299,
           -27.4162187787083,
           -27.444446548103613,
           -27.472674317498928,
           -27.500902086894236,
           -27.52912985628955,
           -27.55735762568486,
           -27.585585395080173,
           -27.613813164475484,
           -27.642040933870796,
           -27.670268703266107,
           -27.698496472661418,
           -27.726724242056733,
           -27.754952011452044,
           -27.783179780847355,
           -27.811407550242663,
           -27.839635319637974,
           -27.86786308903329,
           -27.896090858428604,
           -27.92431862782391,
           -27.952546397219223,
           -27.980774166614534,
           -28.00900193600985,
           -28.037229705405164,
           -28.065457474800475,
           -28.093685244195783,
           -28.121913013591094,
           -28.150140782986405,
           -28.17836855238172,
           -28.20659632177703,
           -28.23482409117234,
           -28.263051860567654,
           -28.291160187666883,
           -28.317954610959344,
           -28.344749034251805,
           -28.371543457544266,
           -28.398337880836724,
           -28.415222899909878,
           -28.42219851476373,
           -28.42917412961758,
           -28.43614974447143,
           -28.44312535932528,
           -28.45010097417913,
           -28.45707658903298,
           -28.45954826766508,
           -28.459317623326598,
           -28.459086978988115,
           -28.45885633464963,
           -28.458625690311152,
           -28.458395045972665,
           -28.458164401634185,
           -28.457933757295706,
           -28.457703112957223,
           -28.45747246861874,
           -28.457241824280256,
           -28.457011179941777,
           -28.456780535603297,
           -28.45654989126481,
           -28.456319246926327,
           -28.456088602587847,
           -28.455857958249364,
           -28.45562731391088,
           -28.455396669572398,
           -28.45516602523392,
           -28.454935380895435,
           -28.454704736556952,
           -28.454474092218472,
           -28.45424344787999,
           -28.45401280354151,
           -28.453782159203023,
           -28.453551514864543,
           -28.453320870526067,
           -28.453090226187577,
           -28.452859581849097,
           -28.45262893751061,
           -28.45239829317213,
           -28.452167648833647,
           -28.45193700449517,
           -28.451706360156688,
           -28.451475715818205,
           -28.451245071479722,
           -28.45101442714124,
           -28.45078378280276,
           -28.450553138464276,
           -28.450322494125796,
           -28.450091849787313,
           -28.449861205448826,
           -28.44963056111035,
           -28.449399916771867,
           -28.449169272433384,
           -28.4489386280949,
           -28.448707983756417,
           -28.448477339417938,
           -28.448246695079455,
           -28.448016050740975,
           -28.447785406402488,
           -28.44755476206401,
           -28.447324117725525,
           -28.447093473387046,
           -28.446862829048563,
           -28.446632184710083,
           -28.4464015403716,
           -28.446170896033117,
           -28.445940251694637,
           -28.445709607356154,
           -28.44547896301767,
           -28.44524831867919,
           -28.445017674340704,
           -28.444787030002225,
           -28.44455638566374,
           -28.444325741325258,
           -28.44409509698678,
           -28.443864452648295,
           -28.443633808309812,
           -28.44340316397133,
           -28.44317251963285,
           -28.44294187529437,
           -28.442711230955886,
           -28.442480586617403,
           -28.442249942278924,
           -28.426044554936155,
           -28.37788968158483,
           -28.32973480823351,
           -28.281579934882185,
           -28.233425061530863,
           -28.18527018817954,
           -28.13711531482821,
           -28.088960441476885,
           -28.040805568125567,
           -27.99265069477424,
           -27.94449582142291,
           -27.89634094807159,
           -27.848186074720267,
           -27.80003120136894,
           -27.75187632801762,
           -27.703721454666294,
           -27.655566581314968,
           -27.60741170796365,
           -27.559256834612324,
           -27.511101961260998,
           -27.462947087909672,
           -27.41479221455835,
           -27.36663734120703,
           -27.318482467855702,
           -27.270327594504376,
           -27.222172721153054,
           -27.174017847801732,
           -27.125862974450406,
           -27.077708101099084,
           -27.02955322774776,
           -26.981398354396433,
           -26.933243481045114,
           -26.88508860769379,
           -26.83693373434246,
           -26.788778860991137,
           -26.740623987639818,
           -26.692469114288492,
           -26.644314240937163,
           -26.59615936758584,
           -26.54800449423452,
           -26.499849620883197,
           -26.45169474753187,
           -26.403539874180545,
           -26.35538500082922,
           -26.307230127477894,
           -26.25907525412658,
           -26.21092038077525,
           -26.162765507423927,
           -26.114610634072605,
           -26.066455760721272,
           -26.018300887369954,
           -25.969368197466505,
           -25.919566175363602,
           -25.869764153260704,
           -25.819962131157812,
           -25.770160109054913,
           -25.72035808695201,
           -25.67055606484912,
           -25.62075404274622,
           -25.570952020643322,
           -25.52114999854043,
           -25.471347976437528,
           -25.421545954334626,
           -25.371743932231738,
           -25.321941910128835,
           -25.27213988802594,
           -25.222337865923038,
           -25.17253584382015,
           -25.122733821717247,
           -25.072931799614345,
           -25.02312977751145,
           -24.973327755408555,
           -24.923525733305652,
           -24.873723711202757,
           -24.823921689099862,
           -24.774119666996963,
           -24.724317644894064,
           -24.67451562279117,
           -24.62471360068827,
           -24.57491157858537,
           -24.525109556482473,
           -24.475307534379578,
           -24.42550551227668,
           -24.3759247043781,
           -24.32744996750108,
           -24.278975230624063,
           -24.230500493747048,
           -24.182025756870036,
           -24.133551019993018,
           -24.085076283116,
           -24.03660154623899,
           -23.988126809361972,
           -23.939652072484954,
           -23.891177335607942,
           -23.842702598730924,
           -23.794227861853905,
           -23.745753124976886,
           -23.697278388099875,
           -23.648803651222856,
           -23.60032891434584,
           -23.551854177468833,
           -23.503379440591814,
           -23.454904703714796,
           -23.406429966837784,
           -23.357955229960766,
           -23.309480493083747,
           -23.261005756206735,
           -23.21253101932972,
           -23.1640562824527,
           -23.11558154557568,
           -23.06710680869867,
           -23.01863207182165,
           -22.970157334944638,
           -22.921682598067626,
           -22.873207861190604,
           -22.82473312431359,
           -22.776258387436577,
           -22.72778365055956,
           -22.67930891368254,
           -22.63083417680552,
           -22.58235943992851,
           -22.53388470305149,
           -22.485409966174473,
           -22.436935229297465,
           -22.388460492420446,
           -22.21661390268104,
           -21.94699559070682,
           -21.677377278732557,
           -21.407758966758294,
           -21.138140654784074,
           -20.868522342809808,
           -20.59890403083554,
           -20.32928571886127,
           -20.05966740688706,
           -19.790049094912792,
           -19.520430782938526,
           -19.250812470964313,
           -18.981194158990043,
           -18.71157584701578,
           -18.441957535041563,
           -18.172339223067297,
           -17.902720911093027,
           -17.63310259911876,
           -17.363484287144548,
           -17.09386597517028,
           -16.824247663196015,
           -16.5546293512218,
           -16.285011039247532,
           -16.015392727273266,
           -15.74577441529905,
           -15.476156103324783,
           -15.206537791350517,
           -14.9369194793763,
           -14.667301167402034,
           -14.397682855427767,
           -14.128064543453501,
           -13.858446231479286,
           -13.58882791950502,
           -13.319209607530752,
           -13.049591295556537,
           -12.77997298358227,
           -12.510354671608006,
           -12.24073635963379,
           -11.971118047659523,
           -11.701499735685257,
           -11.43188142371099,
           -11.162263111736774
          ],
          [
           -21.391041302603618,
           -21.415724083134954,
           -21.440406863666286,
           -21.46508964419762,
           -21.48977242472895,
           -21.514455205260287,
           -21.539137985791616,
           -21.56382076632295,
           -21.588503546854284,
           -21.613186327385616,
           -21.637869107916952,
           -21.66255188844828,
           -21.687234668979613,
           -21.71191744951095,
           -21.73660023004228,
           -21.761283010573614,
           -21.785965791104946,
           -21.810648571636282,
           -21.835331352167614,
           -21.860014132698947,
           -21.88469691323028,
           -21.909379693761615,
           -21.934062474292944,
           -21.95874525482428,
           -21.983428035355608,
           -22.008110815886944,
           -22.032793596418276,
           -22.05747637694961,
           -22.082159157480945,
           -22.106841938012277,
           -22.13152471854361,
           -22.156207499074945,
           -22.180890279606274,
           -22.20557306013761,
           -22.230255840668942,
           -22.254938621200274,
           -22.27962140173161,
           -22.30430418226294,
           -22.328986962794275,
           -22.353669743325604,
           -22.37835252385694,
           -22.403035304388272,
           -22.427718084919608,
           -22.45240086545094,
           -22.477083645982272,
           -22.501766426513605,
           -22.526449207044937,
           -22.551131987576273,
           -22.575814768107605,
           -22.600497548638938,
           -22.62518032917027,
           -22.649863109701602,
           -22.674545890232935,
           -22.699228670764267,
           -22.7239114512956,
           -22.748594231826935,
           -22.77327701235827,
           -22.797959792889603,
           -22.822642573420936,
           -22.848135834384387,
           -22.87525004888607,
           -22.90236426338775,
           -22.929478477889432,
           -22.956592692391112,
           -22.983706906892795,
           -23.010821121394475,
           -23.037935335896158,
           -23.065049550397838,
           -23.09216376489952,
           -23.119277979401204,
           -23.146392193902884,
           -23.173506408404563,
           -23.20062062290625,
           -23.22773483740793,
           -23.254849051909613,
           -23.281963266411292,
           -23.309077480912972,
           -23.336191695414655,
           -23.36330590991634,
           -23.390420124418018,
           -23.4175343389197,
           -23.444648553421377,
           -23.47176276792306,
           -23.498876982424747,
           -23.52338283685414,
           -23.547367019269075,
           -23.571351201684003,
           -23.595335384098938,
           -23.619319566513873,
           -23.64330374892881,
           -23.667287931343743,
           -23.69127211375867,
           -23.715256296173607,
           -23.739240478588542,
           -23.763224661003477,
           -23.78720884341841,
           -23.811193025833344,
           -23.83517720824828,
           -23.859161390663214,
           -23.883145573078146,
           -23.90712975549308,
           -23.931113937908016,
           -23.95509812032295,
           -23.979082302737886,
           -24.003066485152814,
           -24.02705066756775,
           -24.051034849982685,
           -24.07501903239762,
           -24.099003214812555,
           -24.12298739722749,
           -24.14697157964242,
           -24.170955762057353,
           -24.19493994447229,
           -24.218924126887224,
           -24.24290830930216,
           -24.266892491717094,
           -24.290876674132026,
           -24.314860856546957,
           -24.338845038961892,
           -24.362829221376824,
           -24.386813403791763,
           -24.410797586206694,
           -24.434781768621626,
           -24.458765951036565,
           -24.482750133451496,
           -24.50673431586643,
           -24.530718498281367,
           -24.554702680696302,
           -24.57868686311123,
           -24.602671045526165,
           -24.6266552279411,
           -24.650639410356035,
           -24.67462359277097,
           -24.698607775185906,
           -24.72259195760084,
           -24.74657614001577,
           -24.770560322430704,
           -24.79454450484564,
           -24.818528687260574,
           -24.84251286967551,
           -24.866497052090438,
           -24.89048123450538,
           -24.91484497614333,
           -24.941106500172893,
           -24.967368024202464,
           -24.99362954823203,
           -25.019891072261597,
           -25.046152596291165,
           -25.072414120320733,
           -25.0986756443503,
           -25.124937168379866,
           -25.151198692409437,
           -25.17746021643901,
           -25.203721740468573,
           -25.22998326449814,
           -25.25624478852771,
           -25.282506312557274,
           -25.308767836586846,
           -25.33502936061641,
           -25.36129088464598,
           -25.387552408675546,
           -25.413813932705118,
           -25.440075456734682,
           -25.46633698076425,
           -25.49259850479382,
           -25.518860028823386,
           -25.545121552852954,
           -25.57269390712635,
           -25.600921676521665,
           -25.62914944591698,
           -25.657377215312287,
           -25.6856049847076,
           -25.71383275410291,
           -25.742060523498225,
           -25.770288292893536,
           -25.798516062288847,
           -25.826743831684155,
           -25.854971601079473,
           -25.88319937047478,
           -25.911427139870092,
           -25.939654909265407,
           -25.967882678660715,
           -25.996110448056026,
           -26.02433821745134,
           -26.052565986846652,
           -26.080793756241967,
           -26.109021525637278,
           -26.137249295032586,
           -26.1654770644279,
           -26.19370483382321,
           -26.221932603218523,
           -26.250160372613834,
           -26.278388142009145,
           -26.306615911404457,
           -26.33484368079977,
           -26.363071450195083,
           -26.391299219590394,
           -26.4195269889857,
           -26.447754758381016,
           -26.47598252777633,
           -26.50421029717164,
           -26.53243806656695,
           -26.56066583596226,
           -26.58889360535758,
           -26.617121374752887,
           -26.645349144148195,
           -26.67357691354351,
           -26.70180468293882,
           -26.730032452334136,
           -26.758260221729444,
           -26.78648799112476,
           -26.81471576052007,
           -26.84294352991538,
           -26.871171299310692,
           -26.89838378464234,
           -26.9251782079348,
           -26.951972631227264,
           -26.97876705451972,
           -27.005561477812186,
           -27.032355901104648,
           -27.059150324397105,
           -27.08594474768957,
           -27.112739170982024,
           -27.139533594274482,
           -27.166328017566947,
           -27.193122440859405,
           -27.21991686415187,
           -27.246711287444327,
           -27.273505710736785,
           -27.300300134029246,
           -27.327094557321704,
           -27.353888980614173,
           -27.38068340390663,
           -27.40747782719909,
           -27.434272250491553,
           -27.46106667378401,
           -27.48786109707647,
           -27.514655520368933,
           -27.54144994366139,
           -27.568244366953852,
           -27.59503879024631,
           -27.62183321353877,
           -27.648627636831232,
           -27.67542206012369,
           -27.70221648341615,
           -27.729010906708616,
           -27.755805330001074,
           -27.782599753293535,
           -27.809394176585997,
           -27.836188599878454,
           -27.853073618951612,
           -27.86004923380546,
           -27.867024848659312,
           -27.87400046351316,
           -27.88097607836701,
           -27.887951693220863,
           -27.894927308074713,
           -27.901902922928564,
           -27.908878537782414,
           -27.915854152636264,
           -27.922829767490118,
           -27.929805382343964,
           -27.936780997197815,
           -27.943756612051665,
           -27.950732226905515,
           -27.957707841759365,
           -27.964683456613216,
           -27.971659071467066,
           -27.978634686320916,
           -27.985610301174766,
           -27.99258591602862,
           -27.99956153088247,
           -28.00653714573632,
           -28.013512760590167,
           -28.02048837544402,
           -28.02746399029787,
           -28.034439605151718,
           -28.041415220005575,
           -28.048390834859422,
           -28.055366449713272,
           -28.062342064567122,
           -28.069317679420973,
           -28.076293294274823,
           -28.083268909128673,
           -28.090244523982527,
           -28.097220138836377,
           -28.104195753690224,
           -28.111171368544078,
           -28.118146983397924,
           -28.125122598251778,
           -28.13209821310563,
           -28.13907382795947,
           -28.14604944281333,
           -28.15302505766718,
           -28.16000067252103,
           -28.16697628737488,
           -28.173951902228726,
           -28.180927517082583,
           -28.18790313193643,
           -28.194878746790284,
           -28.20185436164413,
           -28.20882997649798,
           -28.21580559135183,
           -28.22278120620568,
           -28.228405626652894,
           -28.22817498231441,
           -28.22794433797593,
           -28.227713693637448,
           -28.227483049298964,
           -28.22725240496049,
           -28.227021760621998,
           -28.226791116283522,
           -28.226560471945035,
           -28.226329827606556,
           -28.22609918326807,
           -28.225868538929593,
           -28.22563789459111,
           -28.22540725025263,
           -28.225176605914143,
           -28.224945961575663,
           -28.22471531723718,
           -28.2244846728987,
           -28.224254028560217,
           -28.224023384221734,
           -28.223792739883255,
           -28.22356209554477,
           -28.223331451206292,
           -28.223100806867805,
           -28.222870162529325,
           -28.222639518190846,
           -28.22240887385236,
           -28.22217822951388,
           -28.221947585175393,
           -28.205742197832627,
           -28.157587324481305,
           -28.109432451129983,
           -28.061277577778657,
           -28.013122704427335,
           -27.964967831076017,
           -27.916812957724687,
           -27.86865808437336,
           -27.82050321102204,
           -27.772348337670714,
           -27.724193464319388,
           -27.676038590968066,
           -27.627883717616744,
           -27.579728844265418,
           -27.531573970914092,
           -27.483419097562773,
           -27.435264224211448,
           -27.387109350860126,
           -27.338954477508803,
           -27.290639467866278,
           -27.240837445763376,
           -27.191035423660484,
           -27.141233401557585,
           -27.091431379454683,
           -27.041629357351788,
           -26.991827335248892,
           -26.94202531314599,
           -26.892223291043095,
           -26.8424212689402,
           -26.7926192468373,
           -26.742817224734402,
           -26.69301520263151,
           -26.643213180528612,
           -26.59341115842571,
           -26.543609136322814,
           -26.49380711421992,
           -26.444005092117017,
           -26.39420307001412,
           -26.344401047911223,
           -26.294599025808324,
           -26.244797003705433,
           -26.194994981602534,
           -26.14519295949963,
           -26.095390937396733,
           -26.04558891529384,
           -25.99578689319094,
           -25.945984871088044,
           -25.89618284898515,
           -25.846380826882246,
           -25.796578804779347,
           -25.746776782676456,
           -25.69697476057356,
           -25.64717273847066,
           -25.597370716367756,
           -25.547568694264868,
           -25.497766672161962,
           -25.447964650059063,
           -25.398162627956175,
           -25.348360605853276,
           -25.29855858375037,
           -25.24875656164748,
           -25.19895453954458,
           -25.149152517441685,
           -25.09935049533879,
           -25.04954847323589,
           -24.999746451132992,
           -24.94994442903009,
           -24.9001424069272,
           -24.850340384824296,
           -24.800538362721397,
           -24.750736340618506,
           -24.700934318515607,
           -24.651132296412705,
           -24.60133027430981,
           -24.551528252206914,
           -24.501726230104016,
           -24.451924208001117,
           -24.402122185898225,
           -24.352320163795323,
           -24.30251814169242,
           -24.25271611958953,
           -24.202914097486634,
           -24.15311207538373,
           -24.103531267485153,
           -24.055056530608134,
           -24.006581793731115,
           -23.9581070568541,
           -23.909632319977092,
           -23.861157583100074,
           -23.81268284622305,
           -23.764208109346043,
           -23.715733372469025,
           -23.667258635592006,
           -23.618783898714995,
           -23.570309161837976,
           -23.521834424960957,
           -23.47335968808394,
           -23.424884951206927,
           -23.37641021432991,
           -23.32793547745289,
           -23.279460740575885,
           -23.230986003698867,
           -23.134272582412898,
           -22.98449659693498,
           -22.834720611457037,
           -22.684944625979092,
           -22.535168640501176,
           -22.38539265502323,
           -22.235616669545287,
           -22.085840684067346,
           -21.93606469858943,
           -21.786288713111485,
           -21.636512727633544,
           -21.486736742155628,
           -21.336960756677684,
           -21.18718477119974,
           -21.037408785721823,
           -20.88763280024388,
           -20.737856814765934,
           -20.588080829287993,
           -20.438304843810073,
           -20.288528858332132,
           -20.138752872854187,
           -19.98897688737627,
           -19.839200901898327,
           -19.689424916420382,
           -19.53964893094247,
           -19.389872945464525,
           -19.24009695998658,
           -19.090320974508664,
           -18.940544989030723,
           -18.790769003552775,
           -18.640993018074834,
           -18.491217032596914,
           -18.341441047118973,
           -18.19166506164103,
           -18.041889076163116,
           -17.892113090685168,
           -17.742337105207227,
           -17.592561119729307,
           -17.442785134251366,
           -17.29300914877342,
           -17.143233163295477,
           -16.993457177817564,
           -16.84368119233962,
           -16.693905206861675,
           -16.544129221383756,
           -16.394353235905815,
           -16.161828970981308,
           -15.89221065900709,
           -15.622592347032825,
           -15.352974035058558,
           -15.083355723084344,
           -14.813737411110075,
           -14.544119099135807,
           -14.274500787161545,
           -14.004882475187326,
           -13.735264163213062,
           -13.465645851238794,
           -13.196027539264579,
           -12.92640922729031,
           -12.656790915316046,
           -12.387172603341828,
           -12.117554291367563,
           -11.847935979393297,
           -11.57831766741903,
           -11.308699355444814
          ],
          [
           -20.951916390530478,
           -20.976599171061814,
           -21.001281951593143,
           -21.02596473212448,
           -21.05064751265581,
           -21.075330293187143,
           -21.100013073718475,
           -21.12469585424981,
           -21.14937863478114,
           -21.174061415312476,
           -21.198744195843812,
           -21.22342697637514,
           -21.248109756906477,
           -21.27279253743781,
           -21.29747531796914,
           -21.322158098500477,
           -21.346840879031806,
           -21.37152365956314,
           -21.396206440094474,
           -21.420889220625806,
           -21.44557200115714,
           -21.47025478168847,
           -21.494937562219803,
           -21.51962034275114,
           -21.544303123282468,
           -21.568985903813804,
           -21.59366868434514,
           -21.618351464876465,
           -21.643034245407804,
           -21.667717025939137,
           -21.69239980647047,
           -21.717082587001805,
           -21.741765367533134,
           -21.76644814806447,
           -21.791130928595802,
           -21.815813709127134,
           -21.840496489658467,
           -21.865179270189802,
           -21.88986205072113,
           -21.914544831252467,
           -21.9392276117838,
           -21.96391039231513,
           -21.988593172846464,
           -22.013275953377796,
           -22.03795873390913,
           -22.06264151444046,
           -22.087324294971797,
           -22.11200707550313,
           -22.13668985603446,
           -22.161372636565797,
           -22.18605541709713,
           -22.210738197628462,
           -22.235420978159794,
           -22.260103758691127,
           -22.28478653922246,
           -22.309469319753795,
           -22.334152100285127,
           -22.35883488081646,
           -22.383517661347792,
           -22.408200441879124,
           -22.43288322241046,
           -22.457566002941793,
           -22.482248783473125,
           -22.506931564004457,
           -22.53161434453579,
           -22.556297125067125,
           -22.580979905598458,
           -22.605662686129786,
           -22.630345466661122,
           -22.65502824719246,
           -22.679711027723787,
           -22.70439380825512,
           -22.729076588786455,
           -22.753759369317788,
           -22.77844214984912,
           -22.803124930380452,
           -22.829833907927895,
           -22.856948122429575,
           -22.88406233693126,
           -22.91117655143294,
           -22.938290765934624,
           -22.9654049804363,
           -22.992519194937984,
           -23.01963340943967,
           -23.044139263869056,
           -23.06812344628399,
           -23.092107628698926,
           -23.11609181111386,
           -23.140075993528797,
           -23.164060175943725,
           -23.18804435835866,
           -23.212028540773595,
           -23.23601272318853,
           -23.259996905603465,
           -23.2839810880184,
           -23.307965270433332,
           -23.331949452848267,
           -23.3559336352632,
           -23.379917817678137,
           -23.40390200009307,
           -23.427886182508004,
           -23.45187036492294,
           -23.475854547337875,
           -23.499838729752803,
           -23.523822912167738,
           -23.547807094582673,
           -23.571791276997608,
           -23.595775459412543,
           -23.61975964182747,
           -23.643743824242407,
           -23.66772800665734,
           -23.691712189072277,
           -23.715696371487212,
           -23.739680553902147,
           -23.763664736317075,
           -23.78764891873201,
           -23.811633101146946,
           -23.83561728356188,
           -23.859601465976816,
           -23.883585648391747,
           -23.907569830806686,
           -23.931554013221614,
           -23.95553819563655,
           -23.979522378051488,
           -24.003506560466416,
           -24.027490742881348,
           -24.05147492529629,
           -24.075459107711218,
           -24.099443290126153,
           -24.12342747254109,
           -24.147411654956024,
           -24.17139583737096,
           -24.195380019785894,
           -24.219364202200822,
           -24.243348384615757,
           -24.267332567030692,
           -24.291316749445627,
           -24.315300931860563,
           -24.339285114275498,
           -24.363269296690433,
           -24.38725347910536,
           -24.411237661520296,
           -24.43522184393523,
           -24.45920602635016,
           -24.4831902087651,
           -24.50717439118003,
           -24.531158573594965,
           -24.5551427560099,
           -24.579126938424835,
           -24.60311112083977,
           -24.627095303254706,
           -24.651079485669634,
           -24.675063668084576,
           -24.699047850499504,
           -24.72303203291444,
           -24.747016215329374,
           -24.77100039774431,
           -24.794984580159237,
           -24.818968762574173,
           -24.84447117464368,
           -24.870732698673248,
           -24.89699422270282,
           -24.923255746732384,
           -24.94951727076195,
           -24.97577879479152,
           -25.002040318821088,
           -25.028301842850656,
           -25.055874197124055,
           -25.084101966519366,
           -25.112329735914678,
           -25.140557505309992,
           -25.1687852747053,
           -25.197013044100615,
           -25.225240813495926,
           -25.253468582891237,
           -25.281696352286552,
           -25.30992412168186,
           -25.33815189107717,
           -25.366379660472486,
           -25.394607429867797,
           -25.42283519926311,
           -25.45106296865842,
           -25.478812958325342,
           -25.505607381617803,
           -25.532401804910265,
           -25.559196228202723,
           -25.585990651495187,
           -25.61278507478764,
           -25.639579498080106,
           -25.666373921372564,
           -25.693168344665022,
           -25.719962767957487,
           -25.746757191249944,
           -25.773551614542406,
           -25.800346037834863,
           -25.82714046112733,
           -25.85393488441979,
           -25.880729307712247,
           -25.90752373100471,
           -25.93431815429717,
           -25.96111257758963,
           -25.98790700088209,
           -26.01470142417455,
           -26.04149584746701,
           -26.06829027075947,
           -26.095084694051927,
           -26.121879117344392,
           -26.14867354063685,
           -26.17546796392931,
           -26.202262387221772,
           -26.229056810514233,
           -26.255851233806695,
           -26.282645657099152,
           -26.309440080391614,
           -26.336234503684075,
           -26.363028926976533,
           -26.389823350268998,
           -26.416617773561452,
           -26.443412196853913,
           -26.470206620146378,
           -26.497001043438832,
           -26.5237954667313,
           -26.55058989002376,
           -26.577384313316216,
           -26.604178736608677,
           -26.63097315990114,
           -26.6577675831936,
           -26.684562006486058,
           -26.711356429778515,
           -26.73815085307098,
           -26.764945276363434,
           -26.7917396996559,
           -26.818534122948364,
           -26.84532854624082,
           -26.87212296953328,
           -26.89891739282574,
           -26.925711816118202,
           -26.952506239410663,
           -26.97930066270312,
           -27.006095085995582,
           -27.032889509288044,
           -27.059683932580505,
           -27.086478355872963,
           -27.113272779165424,
           -27.140067202457885,
           -27.166861625750343,
           -27.193656049042808,
           -27.220450472335266,
           -27.247244895627723,
           -27.274039318920188,
           -27.29092433799334,
           -27.29789995284719,
           -27.304875567701043,
           -27.31185118255489,
           -27.318826797408743,
           -27.325802412262593,
           -27.33277802711644,
           -27.339753641970297,
           -27.346729256824144,
           -27.353704871677994,
           -27.360680486531844,
           -27.3676561013857,
           -27.37463171623955,
           -27.3816073310934,
           -27.38858294594725,
           -27.3955585608011,
           -27.40253417565495,
           -27.4095097905088,
           -27.41648540536265,
           -27.4234610202165,
           -27.43043663507035,
           -27.437412249924204,
           -27.44438786477805,
           -27.4513634796319,
           -27.45833909448575,
           -27.4653147093396,
           -27.47229032419345,
           -27.479265939047302,
           -27.486241553901156,
           -27.493217168755002,
           -27.500192783608856,
           -27.507168398462703,
           -27.514144013316553,
           -27.521119628170403,
           -27.528095243024254,
           -27.535070857878107,
           -27.542046472731954,
           -27.54902208758581,
           -27.555997702439655,
           -27.562973317293505,
           -27.56994893214736,
           -27.576924547001205,
           -27.583900161855063,
           -27.590875776708906,
           -27.597851391562763,
           -27.60482700641661,
           -27.611802621270463,
           -27.618778236124314,
           -27.625753850978164,
           -27.632729465832014,
           -27.63970508068586,
           -27.646680695539715,
           -27.65365631039356,
           -27.660631925247415,
           -27.667607540101265,
           -27.67458315495511,
           -27.68155876980897,
           -27.688534384662816,
           -27.695509999516666,
           -27.702485614370516,
           -27.709461229224367,
           -27.716436844078217,
           -27.723412458932067,
           -27.730388073785917,
           -27.737363688639764,
           -27.74433930349362,
           -27.751314918347468,
           -27.75829053320132,
           -27.765266148055172,
           -27.77224176290902,
           -27.781186493101167,
           -27.795710415890976,
           -27.81023433868079,
           -27.8247582614706,
           -27.839282184260412,
           -27.853806107050225,
           -27.868330029840035,
           -27.882853952629848,
           -27.89737787541966,
           -27.911901798209474,
           -27.926425720999283,
           -27.940949643789097,
           -27.955473566578913,
           -27.948591222861708,
           -27.898896346130513,
           -27.849201469399315,
           -27.799506592668113,
           -27.74981171593691,
           -27.700116839205716,
           -27.650421962474514,
           -27.60072708574331,
           -27.551032209012114,
           -27.50133733228091,
           -27.45164245554971,
           -27.40194757881851,
           -27.352252702087313,
           -27.30255782535611,
           -27.252862948624912,
           -27.203168071893714,
           -27.153473195162512,
           -27.103778318431313,
           -27.054083441700115,
           -27.00438856496891,
           -26.954693688237708,
           -26.904998811506506,
           -26.85530393477531,
           -26.805609058044105,
           -26.755914181312907,
           -26.706219304581712,
           -26.65652442785051,
           -26.60682955111931,
           -26.55713467438811,
           -26.507439797656907,
           -26.457744920925702,
           -26.40805004419451,
           -26.35835516746331,
           -26.308660290732107,
           -26.258965414000905,
           -26.20927053726971,
           -26.159575660538508,
           -26.109880783807306,
           -26.06018590707611,
           -26.010491030344905,
           -25.960796153613707,
           -25.911101276882512,
           -25.861406400151303,
           -25.811711523420108,
           -25.762016646688906,
           -25.712321769957708,
           -25.662626893226502,
           -25.612932016495307,
           -25.563237139764112,
           -25.513542263032903,
           -25.46384738630171,
           -25.41415250957051,
           -25.364457632839304,
           -25.314762756108102,
           -25.265067879376907,
           -25.215373002645705,
           -25.165678125914503,
           -25.115983249183305,
           -25.066288372452107,
           -25.016593495720905,
           -24.966898618989706,
           -24.917203742258508,
           -24.867508865527306,
           -24.817813988796107,
           -24.76811911206491,
           -24.7184242353337,
           -24.668729358602498,
           -24.61903448187131,
           -24.569339605140105,
           -24.519644728408903,
           -24.469949851677704,
           -24.420254974946502,
           -24.370560098215304,
           -24.320865221484105,
           -24.271170344752907,
           -24.2214754680217,
           -24.171780591290496,
           -24.122085714559308,
           -24.07260714469256,
           -24.02350476276587,
           -23.974402380839187,
           -23.9252999989125,
           -23.876197616985813,
           -23.834249715837093,
           -23.82807421857816,
           -23.821898721319236,
           -23.815723224060307,
           -23.809547726801384,
           -23.803372229542454,
           -23.797196732283524,
           -23.7910212350246,
           -23.731850042257445,
           -23.582074056779504,
           -23.432298071301584,
           -23.282522085823643,
           -23.1327461003457,
           -22.982970114867754,
           -22.833194129389838,
           -22.683418143911894,
           -22.533642158433953,
           -22.383866172956033,
           -22.234090187478092,
           -22.08431420200015,
           -21.934538216522235,
           -21.78476223104429,
           -21.634986245566346,
           -21.48521026008843,
           -21.335434274610485,
           -21.18565828913254,
           -21.035882303654596,
           -20.88610631817668,
           -20.736330332698735,
           -20.586554347220794,
           -20.436778361742878,
           -20.287002376264933,
           -20.13722639078699,
           -19.987450405309072,
           -19.83767441983113,
           -19.687898434353187,
           -19.538122448875242,
           -19.388346463397326,
           -19.23857047791938,
           -19.088794492441437,
           -18.93901850696352,
           -18.78924252148558,
           -18.639466536007635,
           -18.48969055052972,
           -18.339914565051778,
           -18.190138579573834,
           -18.040362594095914,
           -17.890586608617973,
           -17.740810623140028,
           -17.591034637662087,
           -17.441258652184167,
           -17.291482666706223,
           -17.14170668122828,
           -16.991930695750366,
           -16.84215471027242,
           -16.692378724794477,
           -16.54260273931656,
           -16.392826753838616,
           -16.243050768360675,
           -16.09327478288273,
           -15.943498797404814,
           -15.79372281192687,
           -15.643946826448927,
           -15.494170840971009,
           -15.344394855493066,
           -15.19461887001512,
           -15.044842884537207,
           -14.89506689905926,
           -14.745290913581318,
           -14.595514928103404,
           -14.445738942625457,
           -14.295962957147516,
           -14.146186971669573,
           -13.996410986191655,
           -13.84663500071371,
           -13.696859015235768,
           -13.440338069496642,
           -13.156732257670631,
           -12.87312644584462,
           -12.589520634018664,
           -12.305914822192653,
           -12.02230901036664,
           -11.73870319854063,
           -11.455097386714673
          ],
          [
           -20.50705644055887,
           -20.529434537661057,
           -20.551812634763248,
           -20.574190731865436,
           -20.596568828967627,
           -20.618946926069814,
           -20.641325023172005,
           -20.663703120274196,
           -20.686081217376383,
           -20.709611657747306,
           -20.73429443827864,
           -20.75897721880997,
           -20.783659999341303,
           -20.80834277987264,
           -20.83302556040397,
           -20.857708340935304,
           -20.882391121466636,
           -20.90707390199797,
           -20.931756682529304,
           -20.956439463060633,
           -20.98112224359197,
           -21.0058050241233,
           -21.030487804654634,
           -21.05517058518597,
           -21.079853365717298,
           -21.104536146248634,
           -21.129218926779963,
           -21.1539017073113,
           -21.17858448784263,
           -21.203267268373963,
           -21.2279500489053,
           -21.25263282943663,
           -21.277315609967964,
           -21.3019983904993,
           -21.32668117103063,
           -21.351363951561964,
           -21.376046732093293,
           -21.40072951262463,
           -21.425412293155965,
           -21.450095073687294,
           -21.47477785421863,
           -21.49946063474996,
           -21.524143415281294,
           -21.548826195812627,
           -21.57350897634396,
           -21.59819175687529,
           -21.622874537406624,
           -21.64755731793796,
           -21.672240098469292,
           -21.696922879000624,
           -21.72160565953196,
           -21.74628844006329,
           -21.770971220594625,
           -21.795654001125957,
           -21.82033678165729,
           -21.84501956218862,
           -21.869702342719954,
           -21.89438512325129,
           -21.919067903782622,
           -21.943750684313954,
           -21.96843346484529,
           -21.99311624537662,
           -22.017799025907955,
           -22.042481806439287,
           -22.06716458697062,
           -22.091847367501956,
           -22.116530148033284,
           -22.14121292856462,
           -22.165895709095953,
           -22.19057848962729,
           -22.21526127015862,
           -22.239944050689953,
           -22.264626831221285,
           -22.28930961175262,
           -22.31399239228395,
           -22.338675172815286,
           -22.36335795334662,
           -22.38804073387795,
           -22.412723514409286,
           -22.437406294940615,
           -22.46208907547195,
           -22.486771856003283,
           -22.511454636534616,
           -22.536137417065948,
           -22.56023803250028,
           -22.584222214915215,
           -22.60820639733015,
           -22.63219057974508,
           -22.656174762160017,
           -22.680158944574952,
           -22.704143126989884,
           -22.72812730940482,
           -22.752111491819754,
           -22.776095674234686,
           -22.80007985664962,
           -22.824064039064552,
           -22.84804822147949,
           -22.872032403894423,
           -22.896016586309358,
           -22.920000768724293,
           -22.943984951139225,
           -22.96796913355416,
           -22.991953315969095,
           -23.015937498384027,
           -23.03992168079896,
           -23.063905863213897,
           -23.087890045628832,
           -23.111874228043764,
           -23.135858410458695,
           -23.15984259287363,
           -23.183826775288566,
           -23.2078109577035,
           -23.231795140118432,
           -23.255779322533368,
           -23.2797635049483,
           -23.303747687363234,
           -23.32773186977817,
           -23.3517160521931,
           -23.37570023460804,
           -23.399684417022968,
           -23.423668599437907,
           -23.447652781852838,
           -23.471636964267773,
           -23.49562114668271,
           -23.51960532909764,
           -23.54358951151257,
           -23.56757369392751,
           -23.591557876342442,
           -23.615542058757377,
           -23.639526241172312,
           -23.663510423587248,
           -23.687494606002183,
           -23.71147878841711,
           -23.73546297083205,
           -23.75944715324698,
           -23.783431335661916,
           -23.80741551807685,
           -23.831399700491783,
           -23.85538388290672,
           -23.879368065321653,
           -23.903352247736585,
           -23.927336430151524,
           -23.951320612566455,
           -23.975304794981387,
           -23.999288977396326,
           -24.023273159811257,
           -24.04725734222619,
           -24.071241524641128,
           -24.09522570705606,
           -24.119209889470994,
           -24.14319407188593,
           -24.16717825430086,
           -24.191162436715796,
           -24.215146619130728,
           -24.239130801545663,
           -24.263114983960598,
           -24.287099166375533,
           -24.311083348790465,
           -24.33466870463983,
           -24.356259917979223,
           -24.377851131318614,
           -24.399442344658006,
           -24.42103355799739,
           -24.44262477133678,
           -24.46421598467617,
           -24.48580719801556,
           -24.507398411354945,
           -24.532005461928552,
           -24.558120431119253,
           -24.584235400309957,
           -24.610350369500665,
           -24.636465338691373,
           -24.662580307882077,
           -24.68869527707278,
           -24.71481024626349,
           -24.740925215454194,
           -24.7670401846449,
           -24.79315515383561,
           -24.81927012302631,
           -24.84538509221702,
           -24.871500061407726,
           -24.897615030598434,
           -24.92372999978914,
           -24.949844968979843,
           -24.975959938170547,
           -25.002074907361255,
           -25.028189876551963,
           -25.054304845742667,
           -25.08041981493337,
           -25.106534784124076,
           -25.132649753314784,
           -25.158764722505488,
           -25.184879691696196,
           -25.211402333584132,
           -25.23819675687659,
           -25.264991180169055,
           -25.291785603461513,
           -25.318580026753978,
           -25.345374450046435,
           -25.372168873338893,
           -25.398963296631354,
           -25.425757719923816,
           -25.452552143216277,
           -25.479346566508738,
           -25.506140989801196,
           -25.532935413093654,
           -25.55972983638612,
           -25.586524259678576,
           -25.613318682971034,
           -25.6401131062635,
           -25.666907529555957,
           -25.69370195284842,
           -25.72049637614088,
           -25.747290799433337,
           -25.774085222725798,
           -25.80087964601826,
           -25.82767406931072,
           -25.854468492603182,
           -25.88126291589564,
           -25.908057339188105,
           -25.93485176248056,
           -25.961646185773024,
           -25.988440609065485,
           -26.015235032357943,
           -26.0420294556504,
           -26.06882387894286,
           -26.09561830223533,
           -26.122412725527788,
           -26.149207148820246,
           -26.176001572112703,
           -26.20279599540516,
           -26.229590418697626,
           -26.256384841990084,
           -26.28317926528255,
           -26.30997368857501,
           -26.33676811186747,
           -26.36356253515993,
           -26.390356958452386,
           -26.41715138174485,
           -26.443945805037313,
           -26.470740228329767,
           -26.497534651622228,
           -26.52432907491469,
           -26.55112349820715,
           -26.577917921499612,
           -26.60471234479207,
           -26.63150676808453,
           -26.658301191376992,
           -26.685095614669454,
           -26.71189003796191,
           -26.728775057035065,
           -26.73575067188892,
           -26.742726286742766,
           -26.749701901596616,
           -26.75667751645047,
           -26.763653131304316,
           -26.77062874615817,
           -26.77760436101202,
           -26.784579975865874,
           -26.79155559071972,
           -26.79853120557357,
           -26.805506820427425,
           -26.812482435281268,
           -26.819458050135125,
           -26.826433664988976,
           -26.833409279842826,
           -26.840384894696673,
           -26.847360509550526,
           -26.854336124404377,
           -26.861311739258227,
           -26.868287354112077,
           -26.875262968965924,
           -26.882238583819777,
           -26.889214198673624,
           -26.896189813527478,
           -26.90316542838133,
           -26.91014104323518,
           -26.91711665808903,
           -26.92409227294288,
           -26.931067887796733,
           -26.938043502650576,
           -26.94501911750443,
           -26.951994732358283,
           -26.95897034721213,
           -26.965945962065987,
           -26.97292157691983,
           -26.97989719177368,
           -26.98884193517865,
           -27.00336585796846,
           -27.017889780758274,
           -27.032413703548087,
           -27.046937626337893,
           -27.061461549127706,
           -27.07598547191752,
           -27.090509394707333,
           -27.105033317497146,
           -27.11955724028696,
           -27.13408116307677,
           -27.14860508586658,
           -27.163129008656394,
           -27.177652931446207,
           -27.192176854236017,
           -27.20670077702583,
           -27.221224699815643,
           -27.235748622605456,
           -27.250272545395266,
           -27.264796468185075,
           -27.27932039097489,
           -27.293844313764698,
           -27.308368236554514,
           -27.322892159344324,
           -27.337416082134137,
           -27.351940004923947,
           -27.366463927713763,
           -27.380987850503573,
           -27.395511773293386,
           -27.4100356960832,
           -27.424559618873005,
           -27.439083541662818,
           -27.453607464452634,
           -27.468131387242444,
           -27.482655310032257,
           -27.497179232822067,
           -27.51170315561188,
           -27.526227078401693,
           -27.540751001191502,
           -27.555274923981315,
           -27.56979884677113,
           -27.584322769560938,
           -27.59884669235075,
           -27.613370615140564,
           -27.627894537930374,
           -27.642418460720187,
           -27.635536117002985,
           -27.58584124027179,
           -27.53614636354059,
           -27.48645148680939,
           -27.436756610078188,
           -27.387061733346993,
           -27.33736685661579,
           -27.287671979884585,
           -27.23797710315339,
           -27.188282226422185,
           -27.13858734969099,
           -27.088892472959788,
           -27.03919759622859,
           -26.98950271949739,
           -26.93980784276619,
           -26.890112966034987,
           -26.840418089303785,
           -26.790723212572587,
           -26.74102833584139,
           -26.691333459110187,
           -26.641638582378988,
           -26.591943705647783,
           -26.542248828916584,
           -26.492553952185382,
           -26.442859075454187,
           -26.393164198722985,
           -26.343469321991783,
           -26.293774445260585,
           -26.244079568529386,
           -26.194384691798184,
           -26.144689815066982,
           -26.094994938335788,
           -26.045300061604586,
           -25.995605184873384,
           -25.94591030814218,
           -25.896215431410987,
           -25.84652055467978,
           -25.796825677948583,
           -25.747130801217388,
           -25.697435924486182,
           -25.647741047754984,
           -25.59804617102379,
           -25.548351294292587,
           -25.498656417561378,
           -25.448961540830183,
           -25.399266664098988,
           -25.349571787367783,
           -25.299876910636584,
           -25.250468876885357,
           -25.20136649495867,
           -25.15226411303198,
           -25.103161731105295,
           -25.0540593491786,
           -25.004956967251914,
           -24.955854585325234,
           -24.90675220339854,
           -24.857649821471853,
           -24.808547439545173,
           -24.759445057618482,
           -24.71034267569179,
           -24.661240293765104,
           -24.612137911838424,
           -24.563035529911737,
           -24.513933147985046,
           -24.464830766058363,
           -24.41572838413167,
           -24.36662600220498,
           -24.3175236202783,
           -24.268421238351607,
           -24.21931885642492,
           -24.170216474498236,
           -24.12111409257155,
           -24.07201171064486,
           -24.02290932871817,
           -23.973806946791484,
           -23.924704564864797,
           -23.87560218293811,
           -23.826499801011426,
           -23.77739741908474,
           -23.72829503715805,
           -23.67919265523136,
           -23.630090273304674,
           -23.580987891377983,
           -23.539039990229263,
           -23.532864492970337,
           -23.52668899571141,
           -23.520513498452484,
           -23.514338001193558,
           -23.508162503934628,
           -23.501987006675698,
           -23.495811509416775,
           -23.489636012157845,
           -23.48346051489892,
           -23.477285017639993,
           -23.471109520381063,
           -23.464934023122137,
           -23.45875852586321,
           -23.45258302860428,
           -23.446407531345358,
           -23.440232034086428,
           -23.4340565368275,
           -23.427881039568575,
           -23.421705542309645,
           -23.41553004505072,
           -23.409354547791793,
           -23.403179050532863,
           -23.397003553273937,
           -23.39082805601501,
           -23.38465255875608,
           -23.378477061497154,
           -23.372301564238228,
           -23.366126066979298,
           -23.35995056972037,
           -23.353775072461442,
           -23.34759957520252,
           -23.34142407794359,
           -23.335248580684663,
           -23.329073083425737,
           -23.32289758616681,
           -23.31404544711778,
           -23.179390724772045,
           -23.04473600242629,
           -22.910081280080533,
           -22.775426557734797,
           -22.64077183538904,
           -22.50611711304328,
           -22.37146239069755,
           -22.236807668351787,
           -22.102152946006033,
           -21.9674982236603,
           -21.81112145730799,
           -21.527515645481984,
           -21.243909833655973,
           -20.960304021830016,
           -20.676698210004005,
           -20.39309239817799,
           -20.109486586352034,
           -19.82588077452602,
           -19.542274962700013,
           -19.258669150874056,
           -18.97506333904805,
           -18.691457527222035,
           -18.40785171539602,
           -18.124245903570067,
           -17.840640091744056,
           -17.557034279918042,
           -17.273428468092085,
           -16.989822656266078,
           -16.706216844440064,
           -16.422611032614107,
           -16.139005220788096,
           -15.855399408962082,
           -15.571793597136127,
           -15.288187785310114,
           -15.004581973484104,
           -14.720976161658093,
           -14.437370349832138,
           -14.153764538006126,
           -13.870158726180115,
           -13.586552914354156,
           -13.302947102528144,
           -13.019341290702135,
           -12.735735478876176,
           -12.452129667050167,
           -12.168523855224155,
           -11.884918043398145,
           -11.601312231572187
          ],
          [
           -20.056798806864755,
           -20.079176903966946,
           -20.101555001069137,
           -20.123933098171328,
           -20.146311195273515,
           -20.168689292375706,
           -20.191067389477894,
           -20.213445486580085,
           -20.235823583682276,
           -20.258201680784463,
           -20.28057977788665,
           -20.30295787498884,
           -20.325335972091032,
           -20.34771406919322,
           -20.37009216629541,
           -20.392470263397602,
           -20.41484836049979,
           -20.43722645760198,
           -20.459604554704168,
           -20.48198265180636,
           -20.504360748908546,
           -20.526738846010737,
           -20.549116943112928,
           -20.571495040215115,
           -20.593873137317306,
           -20.61625123559338,
           -20.640934016124714,
           -20.66561679665605,
           -20.690299577187382,
           -20.714982357718714,
           -20.739665138250047,
           -20.76434791878138,
           -20.78903069931271,
           -20.813713479844047,
           -20.83839626037538,
           -20.86307904090671,
           -20.887761821438044,
           -20.91244460196938,
           -20.937127382500712,
           -20.961810163032045,
           -20.986492943563377,
           -21.01117572409471,
           -21.03585850462604,
           -21.060541285157377,
           -21.08522406568871,
           -21.109906846220042,
           -21.134589626751378,
           -21.159272407282707,
           -21.183955187814043,
           -21.20863796834537,
           -21.233320748876707,
           -21.25800352940804,
           -21.282686309939375,
           -21.307369090470708,
           -21.332051871002037,
           -21.356734651533372,
           -21.381417432064705,
           -21.406100212596037,
           -21.430782993127373,
           -21.455465773658702,
           -21.480148554190038,
           -21.50483133472137,
           -21.529514115252702,
           -21.554196895784038,
           -21.57887967631537,
           -21.603562456846703,
           -21.62824523737804,
           -21.652928017909367,
           -21.6776107984407,
           -21.702293578972032,
           -21.726976359503368,
           -21.751659140034697,
           -21.776341920566036,
           -21.80102470109737,
           -21.825707481628697,
           -21.850390262160033,
           -21.875073042691366,
           -21.899755823222694,
           -21.924438603754034,
           -21.949121384285363,
           -21.9738041648167,
           -21.99848694534803,
           -22.023169725879363,
           -22.047852506410695,
           -22.071953121845027,
           -22.095937304259966,
           -22.119921486674897,
           -22.143905669089833,
           -22.167889851504768,
           -22.1918740339197,
           -22.21585821633463,
           -22.239842398749566,
           -22.2638265811645,
           -22.287810763579436,
           -22.31179494599437,
           -22.335779128409303,
           -22.35976331082424,
           -22.38374749323917,
           -22.40773167565411,
           -22.43171585806904,
           -22.455700040483975,
           -22.47968422289891,
           -22.503668405313842,
           -22.527652587728777,
           -22.55163677014371,
           -22.575620952558644,
           -22.59960513497358,
           -22.623589317388515,
           -22.64757349980345,
           -22.67155768221838,
           -22.695541864633316,
           -22.719526047048248,
           -22.743510229463183,
           -22.76749441187812,
           -22.79147859429305,
           -22.815462776707985,
           -22.839446959122917,
           -22.863431141537852,
           -22.887415323952787,
           -22.911399506367722,
           -22.935383688782657,
           -22.95936787119759,
           -22.98335205361252,
           -23.00733623602746,
           -23.03132041844239,
           -23.055304600857323,
           -23.07928878327226,
           -23.103272965687193,
           -23.127257148102125,
           -23.15124133051706,
           -23.175225512931995,
           -23.19920969534693,
           -23.223193877761865,
           -23.247178060176797,
           -23.271162242591732,
           -23.295146425006664,
           -23.3191306074216,
           -23.343114789836534,
           -23.36709897225147,
           -23.3910831546664,
           -23.415067337081332,
           -23.43905151949627,
           -23.461440390413028,
           -23.483031603752416,
           -23.504622817091807,
           -23.526214030431195,
           -23.547805243770586,
           -23.569396457109974,
           -23.590987670449366,
           -23.612578883788753,
           -23.63417009712814,
           -23.655761310467533,
           -23.67735252380692,
           -23.69894373714631,
           -23.7205349504857,
           -23.742126163825088,
           -23.76371737716448,
           -23.785308590503867,
           -23.806899803843255,
           -23.828491017182643,
           -23.850082230522034,
           -23.87167344386142,
           -23.893264657200813,
           -23.9148558705402,
           -23.936447083879592,
           -23.958038297218984,
           -23.979629510558368,
           -24.00423656113197,
           -24.030351530322672,
           -24.05646649951338,
           -24.082581468704085,
           -24.108696437894793,
           -24.1348114070855,
           -24.160926376276205,
           -24.18704134546691,
           -24.213156314657617,
           -24.23927128384832,
           -24.26538625303903,
           -24.29150122222973,
           -24.317616191420438,
           -24.343731160611146,
           -24.36984612980185,
           -24.395961098992558,
           -24.42207606818326,
           -24.44819103737397,
           -24.474306006564674,
           -24.500420975755382,
           -24.526535944946083,
           -24.55265091413679,
           -24.5787658833275,
           -24.604880852518207,
           -24.63099582170891,
           -24.657110790899615,
           -24.683225760090323,
           -24.709340729281024,
           -24.735455698471732,
           -24.76157066766244,
           -24.787685636853144,
           -24.81380060604385,
           -24.839915575234556,
           -24.866030544425264,
           -24.892145513615965,
           -24.918260482806673,
           -24.94437545199738,
           -24.97049042118808,
           -24.99660539037879,
           -25.022720359569497,
           -25.0488353287602,
           -25.074950297950906,
           -25.101065267141617,
           -25.12718023633232,
           -25.153295205523026,
           -25.17941017471373,
           -25.20552514390444,
           -25.231640113095146,
           -25.257755082285847,
           -25.283870051476555,
           -25.309985020667263,
           -25.336099989857964,
           -25.362214959048675,
           -25.38832992823938,
           -25.414444897430087,
           -25.440559866620788,
           -25.466674835811496,
           -25.4927898050022,
           -25.518904774192908,
           -25.545019743383612,
           -25.571134712574313,
           -25.59724968176502,
           -25.62336465095573,
           -25.649479620146433,
           -25.675594589337138,
           -25.701709558527845,
           -25.72782452771855,
           -25.753939496909254,
           -25.780054466099962,
           -25.80616943529067,
           -25.832284404481378,
           -25.858399373672082,
           -25.88451434286279,
           -25.91062931205349,
           -25.936744281244202,
           -25.962859250434906,
           -25.98897421962561,
           -26.015768640541342,
           -26.0425630638338,
           -26.069357487126265,
           -26.096151910418723,
           -26.122946333711184,
           -26.14974075700364,
           -26.166625776076796,
           -26.17360139093065,
           -26.180577005784496,
           -26.18755262063835,
           -26.19649737725614,
           -26.21102130004595,
           -26.225545222835763,
           -26.240069145625576,
           -26.25459306841539,
           -26.2691169912052,
           -26.28364091399501,
           -26.298164836784824,
           -26.312688759574634,
           -26.327212682364447,
           -26.34173660515426,
           -26.35626052794407,
           -26.37078445073388,
           -26.385308373523692,
           -26.399832296313505,
           -26.414356219103315,
           -26.42888014189313,
           -26.44340406468294,
           -26.45792798747275,
           -26.472451910262564,
           -26.486975833052377,
           -26.50149975584219,
           -26.516023678632,
           -26.53054760142181,
           -26.54507152421162,
           -26.559595447001435,
           -26.574119369791248,
           -26.58864329258106,
           -26.60316721537087,
           -26.617691138160684,
           -26.632215060950497,
           -26.646738983740306,
           -26.66126290653012,
           -26.67578682931993,
           -26.69031075210974,
           -26.70483467489955,
           -26.719358597689368,
           -26.733882520479177,
           -26.74840644326899,
           -26.762930366058804,
           -26.777454288848617,
           -26.791978211638423,
           -26.806502134428236,
           -26.82102605721805,
           -26.835549980007862,
           -26.850073902797675,
           -26.864597825587484,
           -26.8791217483773,
           -26.893645671167107,
           -26.90816959395692,
           -26.922693516746733,
           -26.93721743953654,
           -26.95174136232636,
           -26.966265285116165,
           -26.980789207905982,
           -26.99531313069579,
           -27.009837053485604,
           -27.024360976275414,
           -27.038884899065224,
           -27.05340882185504,
           -27.06793274464485,
           -27.082456667434663,
           -27.096980590224476,
           -27.11150451301429,
           -27.1260284358041,
           -27.14055235859391,
           -27.15507628138372,
           -27.16960020417353,
           -27.184124126963344,
           -27.198648049753157,
           -27.21317197254297,
           -27.227695895332783,
           -27.242219818122592,
           -27.256743740912405,
           -27.27126766370222,
           -27.285791586492028,
           -27.300315509281837,
           -27.31483943207165,
           -27.329363354861467,
           -27.32248101114427,
           -27.272786134413067,
           -27.223091257681872,
           -27.173396380950667,
           -27.12370150421947,
           -27.074006627488274,
           -27.024311750757064,
           -26.974616874025866,
           -26.924921997294668,
           -26.875227120563466,
           -26.825532243832267,
           -26.775837367101065,
           -26.726142490369867,
           -26.676447613638665,
           -26.626752736907466,
           -26.57705786017627,
           -26.527362983445066,
           -26.477668106713868,
           -26.428330609078152,
           -26.379228227151465,
           -26.33012584522477,
           -26.281023463298084,
           -26.2319210813714,
           -26.18281869944471,
           -26.133716317518022,
           -26.08461393559134,
           -26.035511553664648,
           -25.986409171737964,
           -25.93730678981128,
           -25.888204407884587,
           -25.8391020259579,
           -25.789999644031216,
           -25.74089726210453,
           -25.691794880177838,
           -25.64269249825115,
           -25.593590116324467,
           -25.544487734397777,
           -25.49538535247109,
           -25.446282970544402,
           -25.397180588617715,
           -25.348078206691028,
           -25.298975824764348,
           -25.249873442837654,
           -25.200771060910967,
           -25.15166867898428,
           -25.102566297057592,
           -25.0534639151309,
           -25.00436153320422,
           -24.95525915127753,
           -24.906156769350844,
           -24.857054387424157,
           -24.80795200549747,
           -24.758849623570786,
           -24.709747241644088,
           -24.660644859717408,
           -24.611542477790724,
           -24.56244009586403,
           -24.513337713937347,
           -24.46423533201066,
           -24.415132950083965,
           -24.366030568157285,
           -24.316928186230598,
           -24.26782580430391,
           -24.218723422377224,
           -24.169621040450536,
           -24.120518658523846,
           -24.07141627659716,
           -24.02231389467048,
           -23.973211512743784,
           -23.924109130817097,
           -23.87500674889041,
           -23.825904366963726,
           -23.776801985037036,
           -23.72769960311035,
           -23.678597221183665,
           -23.629494839256974,
           -23.580392457330284,
           -23.531290075403604,
           -23.482187693476916,
           -23.433085311550222,
           -23.383982929623535,
           -23.334880547696855,
           -23.28577816577016,
           -23.24383026462144,
           -23.237654767362514,
           -23.231479270103584,
           -23.22530377284466,
           -23.21912827558573,
           -23.212952778326805,
           -23.206777281067875,
           -23.200601783808953,
           -23.194426286550023,
           -23.188250789291097,
           -23.182075292032167,
           -23.17589979477324,
           -23.16972429751431,
           -23.163548800255384,
           -23.157373302996458,
           -23.076251634465276,
           -22.94159691211952,
           -22.806942189773785,
           -22.672287467428028,
           -22.53763274508227,
           -22.402978022736537,
           -22.268323300390776,
           -22.133668578045018,
           -21.999013855699285,
           -21.864359133353528,
           -21.72970441100777,
           -21.595049688662012,
           -21.460394966316276,
           -21.32574024397052,
           -21.191085521624764,
           -21.05643079927903,
           -20.921776076933273,
           -20.787121354587512,
           -20.65246663224178,
           -20.51781190989602,
           -20.383157187550264,
           -20.248502465204506,
           -20.113847742858773,
           -19.979193020513016,
           -19.844538298167258,
           -19.70988357582153,
           -19.575228853475767,
           -19.44057413113001,
           -19.305919408784277,
           -19.17126468643852,
           -19.03660996409276,
           -18.901955241747025,
           -18.767300519401267,
           -18.63264579705551,
           -18.497991074709752,
           -18.36333635236402,
           -18.228681630018265,
           -18.094026907672504,
           -17.95937218532677,
           -17.824717462981013,
           -17.690062740635256,
           -17.555408018289523,
           -17.42075329594376,
           -17.286098573598004,
           -17.151443851252246,
           -17.016789128906513,
           -16.882134406560755,
           -16.747479684214998,
           -16.612824961869265,
           -16.478170239523507,
           -16.34351551717775,
           -16.208860794832017,
           -16.07420607248626,
           -15.939551350140501,
           -15.718008441993637,
           -15.434402630167629,
           -15.150796818341616,
           -14.867191006515608,
           -14.583585194689649,
           -14.299979382863638,
           -14.016373571037628,
           -13.732767759211669,
           -13.449161947385658,
           -13.165556135559648,
           -12.881950323733689,
           -12.59834451190768,
           -12.31473870008167,
           -12.031132888255657,
           -11.747527076429698
          ],
          [
           -19.606541173170648,
           -19.62891927027284,
           -19.651297367375026,
           -19.673675464477217,
           -19.696053561579404,
           -19.718431658681595,
           -19.740809755783783,
           -19.763187852885974,
           -19.78556594998816,
           -19.807944047090352,
           -19.830322144192543,
           -19.85270024129473,
           -19.87507833839692,
           -19.89745643549911,
           -19.9198345326013,
           -19.94221262970349,
           -19.964590726805678,
           -19.98696882390787,
           -20.00934692101006,
           -20.031725018112247,
           -20.05410311521444,
           -20.076481212316626,
           -20.098859309418817,
           -20.121237406521004,
           -20.143615503623195,
           -20.165993600725383,
           -20.188371697827574,
           -20.21074979492976,
           -20.233127892031955,
           -20.255505989134143,
           -20.277884086236334,
           -20.30026218333852,
           -20.322640280440712,
           -20.345018377542903,
           -20.36739647464509,
           -20.38977457174728,
           -20.41215266884947,
           -20.43453076595166,
           -20.45690886305385,
           -20.47928696015604,
           -20.50166505725823,
           -20.52404315436042,
           -20.54757359397079,
           -20.572256374502125,
           -20.59693915503346,
           -20.62162193556479,
           -20.646304716096125,
           -20.670987496627458,
           -20.69567027715879,
           -20.720353057690126,
           -20.745035838221455,
           -20.76971861875279,
           -20.79440139928412,
           -20.819084179815455,
           -20.843766960346787,
           -20.86844974087812,
           -20.893132521409456,
           -20.917815301940784,
           -20.942498082472117,
           -20.967180863003456,
           -20.991863643534785,
           -21.01654642406612,
           -21.041229204597453,
           -21.065911985128785,
           -21.090594765660118,
           -21.11527754619145,
           -21.139960326722782,
           -21.164643107254115,
           -21.18932588778545,
           -21.214008668316787,
           -21.238691448848115,
           -21.263374229379448,
           -21.288057009910784,
           -21.312739790442112,
           -21.33742257097345,
           -21.36210535150478,
           -21.38678813203611,
           -21.41147091256745,
           -21.43615369309878,
           -21.460836473630113,
           -21.48551925416145,
           -21.510202034692778,
           -21.53488481522411,
           -21.55956759575545,
           -21.583668211189778,
           -21.607652393604713,
           -21.631636576019645,
           -21.65562075843458,
           -21.679604940849515,
           -21.703589123264447,
           -21.727573305679382,
           -21.751557488094313,
           -21.77554167050925,
           -21.799525852924184,
           -21.82351003533912,
           -21.847494217754054,
           -21.87147840016899,
           -21.89546258258392,
           -21.919446764998856,
           -21.94343094741379,
           -21.967415129828723,
           -21.991399312243658,
           -22.015383494658593,
           -22.03936767707353,
           -22.063351859488456,
           -22.087336041903395,
           -22.111320224318327,
           -22.13530440673326,
           -22.159288589148193,
           -22.18327277156313,
           -22.207256953978064,
           -22.231241136393,
           -22.25522531880793,
           -22.279209501222866,
           -22.303193683637797,
           -22.327177866052732,
           -22.351162048467668,
           -22.375146230882603,
           -22.399130413297538,
           -22.42311459571247,
           -22.447098778127405,
           -22.471082960542333,
           -22.495067142957268,
           -22.51905132537221,
           -22.54303550778714,
           -22.56662086284683,
           -22.58821207618622,
           -22.60980328952561,
           -22.631394502864996,
           -22.652985716204388,
           -22.674576929543775,
           -22.69616814288317,
           -22.717759356222555,
           -22.739350569561942,
           -22.760941782901334,
           -22.78253299624072,
           -22.80412420958011,
           -22.8257154229195,
           -22.84730663625889,
           -22.86889784959828,
           -22.890489062937668,
           -22.912080276277056,
           -22.933671489616447,
           -22.955262702955835,
           -22.976853916295227,
           -22.998445129634614,
           -23.020036342974002,
           -23.041627556313394,
           -23.063218769652785,
           -23.084809982992173,
           -23.10640119633156,
           -23.127992409670952,
           -23.149583623010336,
           -23.171174836349728,
           -23.19276604968912,
           -23.214357263028507,
           -23.235948476367895,
           -23.257539689707286,
           -23.27913090304667,
           -23.300722116386062,
           -23.322313329725453,
           -23.343904543064845,
           -23.36549575640423,
           -23.38708696974362,
           -23.408678183083012,
           -23.4302693964224,
           -23.451860609761788,
           -23.47646766033539,
           -23.5025826295261,
           -23.5286975987168,
           -23.554812567907508,
           -23.580927537098212,
           -23.60704250628892,
           -23.633157475479624,
           -23.659272444670332,
           -23.685387413861037,
           -23.711502383051744,
           -23.73761735224245,
           -23.763732321433153,
           -23.78984729062386,
           -23.81596225981457,
           -23.84207722900527,
           -23.868192198195977,
           -23.89430716738668,
           -23.920422136577386,
           -23.946537105768094,
           -23.972652074958802,
           -23.998767044149503,
           -24.02488201334021,
           -24.05099698253092,
           -24.077111951721626,
           -24.103226920912327,
           -24.129341890103035,
           -24.155456859293743,
           -24.181571828484444,
           -24.20768679767515,
           -24.233801766865856,
           -24.259916736056567,
           -24.286031705247268,
           -24.312146674437976,
           -24.338261643628684,
           -24.364376612819388,
           -24.390491582010092,
           -24.4166065512008,
           -24.442721520391505,
           -24.46883648958221,
           -24.494951458772917,
           -24.52106642796362,
           -24.547181397154326,
           -24.573296366345033,
           -24.59941133553574,
           -24.62552630472645,
           -24.65164127391715,
           -24.677756243107858,
           -24.703871212298562,
           -24.729986181489267,
           -24.756101150679974,
           -24.782216119870682,
           -24.80833108906139,
           -24.83444605825209,
           -24.860561027442802,
           -24.886675996633503,
           -24.912790965824207,
           -24.938905935014915,
           -24.96502090420562,
           -24.991135873396328,
           -25.017250842587032,
           -25.04336581177774,
           -25.069480780968444,
           -25.093983904536422,
           -25.11817706114587,
           -25.142370217755325,
           -25.166563374364774,
           -25.190756530974227,
           -25.21494968758368,
           -25.239142844193132,
           -25.263336000802582,
           -25.28752915741203,
           -25.311722314021488,
           -25.335915470630937,
           -25.360108627240386,
           -25.38430178384984,
           -25.40849494045929,
           -25.432688097068745,
           -25.456881253678194,
           -25.481074410287647,
           -25.505267566897096,
           -25.52946072350655,
           -25.553653880116,
           -25.57784703672545,
           -25.600878832498683,
           -25.6227492674357,
           -25.64461970237271,
           -25.666490137309722,
           -25.688360572246737,
           -25.71023100718375,
           -25.73210144212076,
           -25.753971877057776,
           -25.775842311994793,
           -25.7977127469318,
           -25.819583181868815,
           -25.84145361680583,
           -25.863324051742843,
           -25.885194486679858,
           -25.90706492161687,
           -25.92893535655388,
           -25.950805791490893,
           -25.972676226427907,
           -25.99454666136492,
           -26.016417096301932,
           -26.038287531238943,
           -26.057208978885654,
           -26.072270695553634,
           -26.087332412221613,
           -26.102394128889596,
           -26.117455845557572,
           -26.13251756222556,
           -26.147579278893538,
           -26.16264099556152,
           -26.177702712229504,
           -26.192764428897483,
           -26.207826145565463,
           -26.222887862233446,
           -26.23794957890143,
           -26.253011295569408,
           -26.268073012237387,
           -26.283134728905374,
           -26.29819644557335,
           -26.313258162241333,
           -26.328319878909312,
           -26.3433815955773,
           -26.358443312245274,
           -26.373505028913254,
           -26.388566745581237,
           -26.403628462249223,
           -26.418690178917203,
           -26.43375189558518,
           -26.448813612253165,
           -26.46387532892114,
           -26.47893704558912,
           -26.493998762257103,
           -26.509060478925086,
           -26.52412219559307,
           -26.53918391226105,
           -26.55424562892903,
           -26.56930734559701,
           -26.584369062264997,
           -26.599430778932977,
           -26.614492495600956,
           -26.629554212268935,
           -26.64461592893692,
           -26.659677645604898,
           -26.67473936227288,
           -26.68980107894086,
           -26.704862795608843,
           -26.719924512276823,
           -26.734986228944802,
           -26.75004794561279,
           -26.765109662280764,
           -26.78017137894875,
           -26.79523309561673,
           -26.81029481228471,
           -26.825356528952693,
           -26.840418245620672,
           -26.855479962288655,
           -26.870541678956634,
           -26.885603395624614,
           -26.900665112292597,
           -26.915726828960576,
           -26.930788545628555,
           -26.945850262296542,
           -26.96091197896452,
           -26.975973695632504,
           -26.96968779492686,
           -26.920706659473986,
           -26.871725524021116,
           -26.822744388568243,
           -26.77376325311537,
           -26.724782117662503,
           -26.67580098220963,
           -26.626819846756753,
           -26.577838711303887,
           -26.528857575851013,
           -26.479876440398137,
           -26.430895304945267,
           -26.381914169492397,
           -26.33293303403952,
           -26.283951898586654,
           -26.23497076313378,
           -26.185989627680904,
           -26.137008492228038,
           -26.088027356775164,
           -26.039046221322295,
           -25.990065085869418,
           -25.941083950416548,
           -25.892102814963675,
           -25.8431216795108,
           -25.79414054405793,
           -25.74515940860506,
           -25.696178273152185,
           -25.647197137699315,
           -25.598216002246442,
           -25.54923486679357,
           -25.500253731340695,
           -25.45127259588783,
           -25.402291460434952,
           -25.35331032498208,
           -25.304329189529213,
           -25.255348054076336,
           -25.206366918623463,
           -25.157385783170596,
           -25.108404647717723,
           -25.059423512264846,
           -25.010442376811977,
           -24.96146124135911,
           -24.912480105906234,
           -24.863498970453357,
           -24.81451783500049,
           -24.765536699547617,
           -24.71655556409474,
           -24.667574428641874,
           -24.618593293189004,
           -24.569612157736124,
           -24.520631022283258,
           -24.471649886830384,
           -24.422668751377515,
           -24.373687615924638,
           -24.324706480471768,
           -24.2757253450189,
           -24.22674420956602,
           -24.17776307411315,
           -24.128781938660282,
           -24.079800803207405,
           -24.030819667754535,
           -23.98183853230167,
           -23.93285739684879,
           -23.88387626139592,
           -23.834895125943053,
           -23.785913990490172,
           -23.736932855037303,
           -23.687951719584436,
           -23.638970584131556,
           -23.589989448678686,
           -23.541008313225817,
           -23.492027177772943,
           -23.44304604232007,
           -23.3940649068672,
           -23.346894592957337,
           -23.301748142157898,
           -23.256601691358448,
           -23.211455240559015,
           -23.16630878975957,
           -23.12116233896012,
           -23.076015888160683,
           -23.03086943736124,
           -22.985722986561797,
           -22.953995918331742,
           -22.98936576294858,
           -23.024735607565425,
           -23.060105452182267,
           -23.0954752967991,
           -23.130845141415943,
           -23.166214986032784,
           -23.20158483064962,
           -23.236954675266464,
           -23.272324519883302,
           -23.307694364500136,
           -23.343064209116978,
           -23.37843405373382,
           -23.413803898350665,
           -23.449173742967496,
           -23.48454358758434,
           -23.519167390048263,
           -23.38451266770253,
           -23.249857945356773,
           -23.115203223011015,
           -22.980548500665282,
           -22.845893778319525,
           -22.711239055973767,
           -22.57658433362803,
           -22.441929611282276,
           -22.30727488893652,
           -22.17262016659076,
           -22.037965444245028,
           -21.90331072189927,
           -21.76865599955351,
           -21.63400127720778,
           -21.49934655486202,
           -21.36469183251626,
           -21.230037110170528,
           -21.09538238782477,
           -20.960727665479013,
           -20.826072943133255,
           -20.69141822078752,
           -20.556763498441764,
           -20.422108776096007,
           -20.287454053750274,
           -20.152799331404516,
           -20.01814460905876,
           -19.883489886713022,
           -19.748835164367264,
           -19.614180442021507,
           -19.479525719675774,
           -19.344870997330016,
           -19.21021627498426,
           -19.0755615526385,
           -18.940906830292768,
           -18.80625210794701,
           -18.671597385601252,
           -18.53694266325552,
           -18.40228794090976,
           -18.267633218564,
           -18.132978496218268,
           -17.998323773872514,
           -17.863669051526752,
           -17.729014329180995,
           -17.594359606835262,
           -17.459704884489504,
           -17.325050162143746,
           -17.19039543979801,
           -17.055740717452256,
           -16.921085995106495,
           -16.786431272760765,
           -16.625620402949295,
           -16.329785386914153,
           -16.03395037087906,
           -15.738115354843917,
           -15.442280338808771,
           -15.146445322773626,
           -14.850610306738536,
           -14.554775290703391,
           -14.258940274668248,
           -13.963105258633156,
           -13.667270242598011,
           -13.371435226562866,
           -13.075600210527776,
           -12.779765194492631,
           -12.483930178457484,
           -12.18809516242234,
           -11.892260146387251
          ],
          [
           -19.156283539476533,
           -19.178661636578724,
           -19.20103973368091,
           -19.2234178307831,
           -19.245795927885293,
           -19.26817402498748,
           -19.29055212208967,
           -19.31293021919186,
           -19.33530831629405,
           -19.357686413396237,
           -19.38006451049843,
           -19.40244260760062,
           -19.424820704702807,
           -19.447198801804998,
           -19.469576898907185,
           -19.491954996009376,
           -19.514333093111567,
           -19.536711190213754,
           -19.559089287315945,
           -19.581467384418136,
           -19.603845481520324,
           -19.626223578622515,
           -19.648601675724706,
           -19.670979772826893,
           -19.69335786992908,
           -19.71573596703127,
           -19.738114064133462,
           -19.76049216123565,
           -19.78287025833784,
           -19.80524835544003,
           -19.82762645254222,
           -19.85000454964441,
           -19.8723826467466,
           -19.89476074384879,
           -19.917138840950976,
           -19.939516938053167,
           -19.961895035155354,
           -19.98427313225755,
           -20.006651229359736,
           -20.029029326461924,
           -20.051407423564115,
           -20.073785520666306,
           -20.096163617768493,
           -20.118541714870684,
           -20.140919811972875,
           -20.163297909075062,
           -20.18567600617725,
           -20.208054103279444,
           -20.23043220038163,
           -20.25281029748382,
           -20.27518839458601,
           -20.2975664916882,
           -20.31994458879039,
           -20.34232268589258,
           -20.364700782994767,
           -20.387078880096958,
           -20.40945697719915,
           -20.431835074301336,
           -20.454213171816868,
           -20.478895952348203,
           -20.503578732879536,
           -20.528261513410868,
           -20.5529442939422,
           -20.577627074473533,
           -20.602309855004865,
           -20.626992635536197,
           -20.651675416067533,
           -20.676358196598866,
           -20.701040977130198,
           -20.725723757661534,
           -20.750406538192863,
           -20.775089318724195,
           -20.79977209925553,
           -20.824454879786863,
           -20.849137660318195,
           -20.87382044084953,
           -20.898503221380864,
           -20.923186001912192,
           -20.94786878244353,
           -20.97255156297486,
           -20.997234343506197,
           -21.02191712403753,
           -21.046599904568858,
           -21.071282685100194,
           -21.095383300534525,
           -21.119367482949464,
           -21.143351665364392,
           -21.167335847779327,
           -21.191320030194262,
           -21.215304212609198,
           -21.239288395024133,
           -21.263272577439064,
           -21.287256759854,
           -21.31124094226893,
           -21.33522512468387,
           -21.3592093070988,
           -21.383193489513737,
           -21.40717767192867,
           -21.431161854343607,
           -21.45514603675854,
           -21.47913021917347,
           -21.503114401588405,
           -21.52709858400334,
           -21.551082766418276,
           -21.575066948833207,
           -21.599051131248142,
           -21.623035313663074,
           -21.64701949607801,
           -21.671003678492944,
           -21.69339254862002,
           -21.714983761959413,
           -21.7365749752988,
           -21.75816618863819,
           -21.77975740197758,
           -21.801348615316968,
           -21.82293982865636,
           -21.844531041995747,
           -21.866122255335135,
           -21.887713468674526,
           -21.909304682013918,
           -21.930895895353302,
           -21.95248710869269,
           -21.97407832203208,
           -21.995669535371473,
           -22.01726074871086,
           -22.03885196205025,
           -22.060443175389636,
           -22.08203438872903,
           -22.10362560206842,
           -22.125216815407807,
           -22.146808028747195,
           -22.168399242086586,
           -22.189990455425978,
           -22.211581668765362,
           -22.233172882104753,
           -22.25476409544414,
           -22.27635530878353,
           -22.29794652212292,
           -22.319537735462312,
           -22.341128948801703,
           -22.362720162141088,
           -22.38431137548048,
           -22.405902588819867,
           -22.427493802159255,
           -22.449085015498646,
           -22.470676228838034,
           -22.492267442177425,
           -22.513858655516813,
           -22.535449868856205,
           -22.557041082195592,
           -22.57863229553498,
           -22.60022350887437,
           -22.621814722213756,
           -22.643405935553147,
           -22.66499714889254,
           -22.686588362231923,
           -22.708179575571318,
           -22.729770788910706,
           -22.75136200225009,
           -22.772953215589485,
           -22.794544428928873,
           -22.816135642268264,
           -22.83772685560765,
           -22.85931806894704,
           -22.88090928228643,
           -22.90250049562582,
           -22.924091708965207,
           -22.94869875953881,
           -22.974813728729515,
           -23.00092869792022,
           -23.027043667110927,
           -23.05315863630163,
           -23.07927360549234,
           -23.105388574683044,
           -23.13150354387375,
           -23.157618513064456,
           -23.18373348225516,
           -23.20984845144587,
           -23.235963420636573,
           -23.26207838982728,
           -23.288193359017985,
           -23.314308328208693,
           -23.340423297399397,
           -23.3665382665901,
           -23.39265323578081,
           -23.418768204971517,
           -23.44488317416222,
           -23.470998143352926,
           -23.49711311254363,
           -23.523228081734338,
           -23.549343050925042,
           -23.57545802011575,
           -23.601572989306455,
           -23.627687958497162,
           -23.653802927687867,
           -23.67991789687857,
           -23.70603286606928,
           -23.732147835259987,
           -23.758262804450688,
           -23.784377773641395,
           -23.810492742832103,
           -23.836607712022808,
           -23.862722681213512,
           -23.88883765040422,
           -23.914332678272075,
           -23.93852583488153,
           -23.96271899149098,
           -23.986912148100433,
           -24.011105304709886,
           -24.03529846131934,
           -24.059491617928792,
           -24.08368477453824,
           -24.10787793114769,
           -24.13207108775714,
           -24.156264244366593,
           -24.180457400976046,
           -24.2046505575855,
           -24.22884371419495,
           -24.2530368708044,
           -24.277230027413854,
           -24.301423184023307,
           -24.325616340632756,
           -24.349809497242205,
           -24.374002653851655,
           -24.39819581046111,
           -24.42238896707056,
           -24.44658212368001,
           -24.470775280289462,
           -24.494968436898915,
           -24.51916159350837,
           -24.54335475011782,
           -24.56754790672727,
           -24.591741063336723,
           -24.615934219946173,
           -24.640127376555625,
           -24.664320533165075,
           -24.68851368977453,
           -24.71270684638398,
           -24.736900002993433,
           -24.761093159602886,
           -24.785286316212336,
           -24.809479472821785,
           -24.833672629431234,
           -24.857865786040687,
           -24.88205894265014,
           -24.90625209925959,
           -24.930445255869046,
           -24.954638412478495,
           -24.978831569087948,
           -25.003024725697397,
           -25.02605652147063,
           -25.047926956407643,
           -25.069797391344657,
           -25.09166782628167,
           -25.113538261218686,
           -25.135408696155693,
           -25.157279131092707,
           -25.17914956602972,
           -25.20102000096674,
           -25.222890435903746,
           -25.24476087084076,
           -25.266631305777775,
           -25.28850174071479,
           -25.3103721756518,
           -25.332242610588814,
           -25.354113045525825,
           -25.37598348046284,
           -25.397853915399853,
           -25.419724350336868,
           -25.441594785273878,
           -25.463465220210892,
           -25.485335655147907,
           -25.507206090084917,
           -25.529076525021935,
           -25.550946959958942,
           -25.572817394895957,
           -25.59468782983297,
           -25.616558264769985,
           -25.638428699707,
           -25.66029913464401,
           -25.68216956958102,
           -25.704040004518042,
           -25.72591043945505,
           -25.747780874392063,
           -25.769651309329078,
           -25.791521744266092,
           -25.813392179203102,
           -25.835262614140117,
           -25.857133049077127,
           -25.879003484014138,
           -25.900873918951152,
           -25.922744353888167,
           -25.944614788825177,
           -25.96648522376219,
           -25.988355658699206,
           -26.008448030950063,
           -26.023509747618043,
           -26.038571464286026,
           -26.05363318095401,
           -26.068694897621988,
           -26.083756614289968,
           -26.098818330957947,
           -26.113880047625933,
           -26.128941764293913,
           -26.144003480961892,
           -26.15906519762987,
           -26.174126914297858,
           -26.189188630965837,
           -26.204250347633817,
           -26.219312064301796,
           -26.234373780969783,
           -26.249435497637762,
           -26.26449721430574,
           -26.279558930973725,
           -26.294620647641704,
           -26.309682364309687,
           -26.324744080977666,
           -26.33980579764565,
           -26.35486751431363,
           -26.36992923098161,
           -26.384990947649595,
           -26.400052664317574,
           -26.415114380985557,
           -26.430176097653536,
           -26.445237814321516,
           -26.460299530989495,
           -26.475361247657478,
           -26.49042296432546,
           -26.50548468099344,
           -26.52054639766142,
           -26.535608114329403,
           -26.550669830997382,
           -26.56573154766536,
           -26.559445646959723,
           -26.510464511506854,
           -26.46148337605398,
           -26.412502240601107,
           -26.363521105148237,
           -26.314539969695367,
           -26.26555883424249,
           -26.216577698789617,
           -26.16759656333675,
           -26.118615427883874,
           -26.069634292431,
           -26.02065315697813,
           -25.971672021525258,
           -25.922690886072388,
           -25.87370975061952,
           -25.824728615166645,
           -25.775747479713772,
           -25.726766344260902,
           -25.677785208808032,
           -25.628804073355155,
           -25.57982293790228,
           -25.53084180244941,
           -25.48186066699654,
           -25.432879531543662,
           -25.383898396090792,
           -25.334917260637923,
           -25.285936125185046,
           -25.23695498973218,
           -25.187973854279306,
           -25.13899271882643,
           -25.090011583373556,
           -25.041030447920694,
           -24.99204931246782,
           -24.943068177014943,
           -24.894087041562074,
           -24.845105906109204,
           -24.796124770656327,
           -24.747143635203457,
           -24.698162499750588,
           -24.64918136429771,
           -24.60020022884484,
           -24.55121909339197,
           -24.502237957939094,
           -24.453256822486225,
           -24.40427568703335,
           -24.356146704716313,
           -24.31100025391687,
           -24.265853803117427,
           -24.220707352317987,
           -24.175560901518544,
           -24.1304144507191,
           -24.08526799991966,
           -24.040121549120215,
           -23.994975098320772,
           -23.949828647521333,
           -23.904682196721886,
           -23.859535745922443,
           -23.814389295123004,
           -23.769242844323564,
           -23.724096393524118,
           -23.678949942724678,
           -23.633803491925235,
           -23.588657041125792,
           -23.54351059032635,
           -23.49836413952691,
           -23.453217688727467,
           -23.40807123792802,
           -23.36292478712858,
           -23.317778336329138,
           -23.272631885529695,
           -23.227485434730255,
           -23.182338983930812,
           -23.137192533131365,
           -23.09204608233193,
           -23.046899631532487,
           -23.00175318073304,
           -22.956606729933597,
           -22.91146027913416,
           -22.86631382833471,
           -22.821167377535268,
           -22.776020926735825,
           -22.730874475936385,
           -22.68572802513694,
           -22.654000956906888,
           -22.68937080152373,
           -22.724740646140567,
           -22.760110490757413,
           -22.79548033537425,
           -22.83085017999109,
           -22.86622002460793,
           -22.901589869224765,
           -22.93695971384161,
           -22.97232955845845,
           -23.007699403075282,
           -23.043069247692124,
           -23.078439092308965,
           -23.113808936925807,
           -23.149178781542645,
           -23.184548626159486,
           -23.219918470776328,
           -23.255288315393162,
           -23.290658160010004,
           -23.32602800462685,
           -23.36139784924368,
           -23.39676769386052,
           -23.432137538477363,
           -23.4675073830942,
           -23.502877227711043,
           -23.538247072327884,
           -23.573616916944722,
           -23.608986761561557,
           -23.644356606178402,
           -23.679726450795243,
           -23.715096295412078,
           -23.75046614002892,
           -23.676117978627545,
           -23.556591617671405,
           -23.437065256715243,
           -23.317538895759082,
           -23.19801253480292,
           -23.078486173846784,
           -22.958959812890622,
           -22.83943345193446,
           -22.71990709097832,
           -22.60038073002216,
           -22.480854369065995,
           -22.361328008109858,
           -22.241801647153697,
           -22.12227528619754,
           -22.002748925241395,
           -21.883222564285234,
           -21.763696203329076,
           -21.644169842372914,
           -21.524643481416774,
           -21.405117120460613,
           -21.20478246703317,
           -20.90894745099808,
           -20.613112434962936,
           -20.317277418927787,
           -20.0214424028927,
           -19.725607386857554,
           -19.429772370822413,
           -19.133937354787264,
           -18.838102338752176,
           -18.54226732271703,
           -18.246432306681886,
           -17.950597290646794,
           -17.654762274611652,
           -17.358927258576504,
           -17.063092242541416,
           -16.76725722650627,
           -16.471422210471125,
           -16.175587194436034,
           -15.87975217840089,
           -15.583917162365745,
           -15.288082146330598,
           -14.99224713029551,
           -14.696412114260365,
           -14.40057709822522,
           -14.104742082190128,
           -13.808907066154985,
           -13.51307205011984,
           -13.21723703408475,
           -12.921402018049605,
           -12.62556700201446,
           -12.329731985979315,
           -12.033896969944223
          ],
          [
           -18.706025905782425,
           -18.728404002884613,
           -18.750782099986804,
           -18.77316019708899,
           -18.795538294191182,
           -18.817916391293373,
           -18.84029448839556,
           -18.86267258549775,
           -18.88505068259994,
           -18.90742877970213,
           -18.92980687680432,
           -18.95218497390651,
           -18.974563071008696,
           -18.996941168110887,
           -19.019319265213078,
           -19.04169736231527,
           -19.064075459417456,
           -19.086453556519647,
           -19.108831653621834,
           -19.131209750724025,
           -19.153587847826213,
           -19.175965944928404,
           -19.19834404203059,
           -19.220722139132782,
           -19.243100236234973,
           -19.265478333337164,
           -19.287856430439355,
           -19.31023452754154,
           -19.33261262464373,
           -19.35499072174592,
           -19.37736881884811,
           -19.3997469159503,
           -19.422125013052487,
           -19.444503110154677,
           -19.46688120725687,
           -19.48925930435906,
           -19.511637401461243,
           -19.534015498563438,
           -19.556393595665625,
           -19.578771692767816,
           -19.601149789870007,
           -19.623527886972195,
           -19.645905984074382,
           -19.668284081176576,
           -19.690662178278764,
           -19.71304027538095,
           -19.735418372483142,
           -19.757796469585333,
           -19.78017456668752,
           -19.80255266378971,
           -19.8249307608919,
           -19.84730885799409,
           -19.86968695509628,
           -19.89206505219847,
           -19.914443149300656,
           -19.93682124640285,
           -19.959199343505038,
           -19.981577440607225,
           -20.003955537709416,
           -20.026333634811607,
           -20.048711731913794,
           -20.071089829015985,
           -20.093467926118176,
           -20.115846023220364,
           -20.138224120322555,
           -20.160602217424742,
           -20.182980314526933,
           -20.205358411629124,
           -20.22773650873131,
           -20.250114605833502,
           -20.272492702935693,
           -20.29487080003788,
           -20.317248897140068,
           -20.339626994242263,
           -20.36200509134445,
           -20.38553553019428,
           -20.41021831072561,
           -20.43490109125694,
           -20.459583871788276,
           -20.484266652319608,
           -20.508949432850944,
           -20.533632213382276,
           -20.558314993913612,
           -20.58299777444494,
           -20.607098389879276,
           -20.63108257229421,
           -20.655066754709143,
           -20.679050937124074,
           -20.703035119539013,
           -20.727019301953945,
           -20.75100348436888,
           -20.774987666783815,
           -20.798573021053823,
           -20.82016423439321,
           -20.8417554477326,
           -20.86334666107199,
           -20.88493787441138,
           -20.90652908775077,
           -20.928120301090157,
           -20.94971151442955,
           -20.971302727768936,
           -20.992893941108328,
           -21.014485154447716,
           -21.036076367787107,
           -21.057667581126495,
           -21.079258794465883,
           -21.100850007805274,
           -21.122441221144662,
           -21.144032434484053,
           -21.16562364782344,
           -21.18721486116283,
           -21.20880607450222,
           -21.230397287841612,
           -21.251988501181,
           -21.273579714520388,
           -21.29517092785978,
           -21.316762141199163,
           -21.338353354538555,
           -21.359944567877946,
           -21.381535781217337,
           -21.40312699455672,
           -21.424718207896113,
           -21.446309421235505,
           -21.467900634574892,
           -21.48949184791428,
           -21.511083061253668,
           -21.532674274593063,
           -21.554265487932447,
           -21.57585670127184,
           -21.597447914611227,
           -21.619039127950614,
           -21.640630341290006,
           -21.662221554629397,
           -21.68381276796878,
           -21.705403981308173,
           -21.726995194647564,
           -21.748586407986956,
           -21.77017762132634,
           -21.79176883466573,
           -21.813360048005123,
           -21.83495126134451,
           -21.8565424746839,
           -21.87813368802329,
           -21.899724901362674,
           -21.92131611470207,
           -21.942907328041457,
           -21.964498541380845,
           -21.986089754720236,
           -22.007680968059624,
           -22.029272181399016,
           -22.050863394738403,
           -22.072454608077795,
           -22.09404582141718,
           -22.11563703475657,
           -22.13722824809596,
           -22.158819461435346,
           -22.180410674774738,
           -22.202001888114125,
           -22.223593101453517,
           -22.245184314792905,
           -22.266775528132296,
           -22.288366741471684,
           -22.309957954811075,
           -22.33154916815046,
           -22.35314038148985,
           -22.374731594829242,
           -22.39632280816863,
           -22.420929858742234,
           -22.447044827932935,
           -22.47315979712364,
           -22.499274766314347,
           -22.52538973550505,
           -22.551504704695763,
           -22.577619673886463,
           -22.603734643077168,
           -22.629849612267876,
           -22.655964581458583,
           -22.682079550649288,
           -22.708194519839992,
           -22.7343094890307,
           -22.758874608617187,
           -22.78306776522664,
           -22.80726092183609,
           -22.831454078445542,
           -22.855647235054995,
           -22.879840391664448,
           -22.9040335482739,
           -22.92822670488335,
           -22.9524198614928,
           -22.976613018102253,
           -23.000806174711705,
           -23.024999331321155,
           -23.04919248793061,
           -23.07338564454006,
           -23.09757880114951,
           -23.121771957758963,
           -23.145965114368416,
           -23.170158270977865,
           -23.194351427587318,
           -23.218544584196767,
           -23.242737740806223,
           -23.26693089741567,
           -23.291124054025122,
           -23.31531721063457,
           -23.339510367244024,
           -23.363703523853474,
           -23.38789668046293,
           -23.412089837072383,
           -23.436282993681832,
           -23.460476150291285,
           -23.484669306900738,
           -23.508862463510187,
           -23.53305562011964,
           -23.55724877672909,
           -23.581441933338542,
           -23.605635089947995,
           -23.629828246557445,
           -23.654021403166897,
           -23.67821455977635,
           -23.7024077163858,
           -23.726600872995252,
           -23.7507940296047,
           -23.774987186214155,
           -23.799180342823604,
           -23.823373499433057,
           -23.847566656042506,
           -23.87175981265196,
           -23.89595296926141,
           -23.920146125870865,
           -23.944339282480314,
           -23.968532439089767,
           -23.992725595699216,
           -24.01691875230867,
           -24.041111908918122,
           -24.06530506552757,
           -24.089498222137024,
           -24.113691378746474,
           -24.137884535355926,
           -24.16207769196538,
           -24.186270848574832,
           -24.210464005184285,
           -24.23465716179373,
           -24.258850318403184,
           -24.283043475012636,
           -24.30723663162209,
           -24.33142978823154,
           -24.35562294484099,
           -24.379816101450444,
           -24.404009258059894,
           -24.428202414669343,
           -24.45123421044258,
           -24.473104645379593,
           -24.494975080316603,
           -24.516845515253618,
           -24.53871595019063,
           -24.560586385127642,
           -24.582456820064657,
           -24.60432725500167,
           -24.62619768993868,
           -24.648068124875696,
           -24.669938559812707,
           -24.691808994749724,
           -24.713679429686735,
           -24.73554986462375,
           -24.75742029956076,
           -24.77929073449777,
           -24.801161169434785,
           -24.8230316043718,
           -24.844902039308813,
           -24.866772474245828,
           -24.888642909182842,
           -24.910513344119853,
           -24.932383779056863,
           -24.954254213993877,
           -24.97612464893089,
           -24.997995083867906,
           -25.01986551880492,
           -25.041735953741934,
           -25.063606388678945,
           -25.085476823615956,
           -25.10734725855297,
           -25.129217693489984,
           -25.15108812842699,
           -25.17295856336401,
           -25.194828998301023,
           -25.216699433238038,
           -25.23856986817505,
           -25.260440303112063,
           -25.282310738049073,
           -25.304181172986087,
           -25.326051607923098,
           -25.347922042860112,
           -25.369792477797127,
           -25.39166291273414,
           -25.41353334767115,
           -25.435403782608166,
           -25.457274217545176,
           -25.47914465248219,
           -25.501015087419205,
           -25.522885522356216,
           -25.544755957293233,
           -25.566626392230244,
           -25.588496827167255,
           -25.61036726210427,
           -25.632237697041283,
           -25.65410813197829,
           -25.675978566915308,
           -25.697849001852326,
           -25.719719436789337,
           -25.741589871726347,
           -25.76346030666336,
           -25.785330741600376,
           -25.80720117653739,
           -25.8290716114744,
           -25.850942046411415,
           -25.872812481348426,
           -25.89468291628544,
           -25.916553351222454,
           -25.938423786159465,
           -25.959687083014472,
           -25.974748799682455,
           -25.989810516350435,
           -26.004872233018418,
           -26.019933949686397,
           -26.03499566635438,
           -26.05005738302236,
           -26.065119099690342,
           -26.08018081635832,
           -26.0952425330263,
           -26.110304249694284,
           -26.125365966362267,
           -26.140427683030246,
           -26.155489399698226,
           -26.149203498992584,
           -26.100222363539714,
           -26.051241228086845,
           -26.00226009263397,
           -25.9532789571811,
           -25.904297821728232,
           -25.85531668627535,
           -25.80633555082248,
           -25.757354415369615,
           -25.70837327991674,
           -25.65939214446387,
           -25.610411009010996,
           -25.561429873558122,
           -25.51244873810525,
           -25.46346760265238,
           -25.41448646719951,
           -25.365505331746633,
           -25.32025236567585,
           -25.275105914876406,
           -25.22995946407696,
           -25.184813013277516,
           -25.139666562478077,
           -25.094520111678634,
           -25.04937366087919,
           -25.004227210079748,
           -24.959080759280305,
           -24.91393430848086,
           -24.868787857681422,
           -24.823641406881986,
           -24.77849495608254,
           -24.73334850528309,
           -24.688202054483657,
           -24.64305560368421,
           -24.59790915288476,
           -24.552762702085325,
           -24.507616251285885,
           -24.46246980048644,
           -24.417323349686995,
           -24.37217689888756,
           -24.327030448088117,
           -24.281883997288674,
           -24.23673754648923,
           -24.191591095689787,
           -24.146444644890344,
           -24.1012981940909,
           -24.05615174329146,
           -24.011005292492015,
           -23.965858841692572,
           -23.920712390893137,
           -23.875565940093686,
           -23.830419489294243,
           -23.785273038494807,
           -23.74012658769536,
           -23.694980136895918,
           -23.64983368609648,
           -23.604687235297032,
           -23.55954078449759,
           -23.51439433369815,
           -23.469247882898706,
           -23.424101432099263,
           -23.37895498129982,
           -23.33380853050038,
           -23.288662079700934,
           -23.243515628901495,
           -23.198369178102055,
           -23.153222727302612,
           -23.108076276503166,
           -23.06292982570373,
           -23.017783374904283,
           -22.972636924104837,
           -22.9274904733054,
           -22.882344022505958,
           -22.83719757170651,
           -22.79205112090707,
           -22.746904670107632,
           -22.701758219308186,
           -22.656611768508743,
           -22.611465317709303,
           -22.56631886690986,
           -22.521172416110417,
           -22.476025965310974,
           -22.43087951451153,
           -22.385733063712085,
           -22.354005995482034,
           -22.38937584009887,
           -22.424745684715713,
           -22.460115529332562,
           -22.495485373949393,
           -22.53085521856623,
           -22.566225063183076,
           -22.601594907799914,
           -22.636964752416755,
           -22.672334597033593,
           -22.707704441650428,
           -22.691442256635373,
           -22.57191589567921,
           -22.452389534723046,
           -22.33286317376691,
           -22.213336812810745,
           -22.093810451854583,
           -21.974284090898443,
           -21.854757729942282,
           -21.73523136898612,
           -21.615705008029984,
           -21.496178647073823,
           -21.37665228611766,
           -21.25712592516152,
           -21.13759956420536,
           -21.018073203249198,
           -20.89854684229304,
           -20.7790204813369,
           -20.65949412038074,
           -20.539967759424577,
           -20.420441398468437,
           -20.300915037512276,
           -20.181388676556114,
           -20.061862315599974,
           -19.942335954643813,
           -19.82280959368765,
           -19.703283232731494,
           -19.583756871775353,
           -19.464230510819192,
           -19.344704149863034,
           -19.22517778890689,
           -19.105651427950733,
           -18.986125066994568,
           -18.86659870603843,
           -18.74707234508227,
           -18.627545984126108,
           -18.508019623169968,
           -18.388493262213807,
           -18.268966901257645,
           -18.149440540301484,
           -18.029914179345347,
           -17.910387818389182,
           -17.790861457433024,
           -17.671335096476884,
           -17.551808735520723,
           -17.43228237456456,
           -17.31275601360842,
           -17.193229652652263,
           -17.0737032916961,
           -16.954176930739937,
           -16.8346505697838,
           -16.71512420882764,
           -16.595597847871478,
           -16.476071486915338,
           -16.356545125959176,
           -16.237018765003015,
           -16.117492404046875,
           -15.997966043090715,
           -15.878439682134553,
           -15.758913321178415,
           -15.639386960222254,
           -15.519860599266092,
           -15.40033423830993,
           -15.133883953852484,
           -14.838048937817339,
           -14.542213921782194,
           -14.246378905747104,
           -13.950543889711959,
           -13.654708873676814,
           -13.358873857641724,
           -13.063038841606577,
           -12.767203825571436,
           -12.471368809536289,
           -12.175533793501199
          ],
          [
           -18.250341314415053,
           -18.27271941151724,
           -18.295097508619435,
           -18.31747560572162,
           -18.339853702823813,
           -18.362231799926,
           -18.384609897028188,
           -18.40698799413038,
           -18.42936609123257,
           -18.451744188334757,
           -18.47412228543695,
           -18.49650038253914,
           -18.518878479641327,
           -18.541256576743518,
           -18.563634673845705,
           -18.586012770947896,
           -18.608390868050083,
           -18.630768965152274,
           -18.653147062254465,
           -18.675525159356656,
           -18.697903256458844,
           -18.72028135356103,
           -18.74265945066322,
           -18.765037547765413,
           -18.7874156448676,
           -18.80979374196979,
           -18.832171839071982,
           -18.854549936174173,
           -18.87692803327636,
           -18.899306130378548,
           -18.92168422748074,
           -18.94406232458293,
           -18.96644042168512,
           -18.98881851878731,
           -19.011196615889496,
           -19.033574712991687,
           -19.055952810093874,
           -19.07833090719607,
           -19.100709004298256,
           -19.123087101400444,
           -19.145465198502635,
           -19.167843295604825,
           -19.190221392707013,
           -19.212599489809204,
           -19.23497758691139,
           -19.257355684013582,
           -19.27973378111577,
           -19.30211187821796,
           -19.324489975320148,
           -19.34686807242234,
           -19.36924616952453,
           -19.39162426662672,
           -19.41400236372891,
           -19.436380460831096,
           -19.458758557933287,
           -19.481136655035478,
           -19.50351475213767,
           -19.525892849239856,
           -19.548270946342043,
           -19.570649043444234,
           -19.593027140546425,
           -19.615405237648613,
           -19.637783334750804,
           -19.66016143185299,
           -19.682539528955182,
           -19.704917626057373,
           -19.72729572315956,
           -19.74967382026175,
           -19.77205191736394,
           -19.79443001446613,
           -19.81680811156832,
           -19.839186208670508,
           -19.861564305772696,
           -19.88394240287489,
           -19.906320499977078,
           -19.92869859707927,
           -19.949718224513305,
           -19.970058617573738,
           -19.99039901063417,
           -20.010739403694608,
           -20.03107979675504,
           -20.051420189815474,
           -20.07176058287591,
           -20.092100975936344,
           -20.111381698986655,
           -20.130450488034935,
           -20.14951927708322,
           -20.1685880661315,
           -20.18765685517978,
           -20.206725644228065,
           -20.225794433276345,
           -20.244863222324625,
           -20.26645443528401,
           -20.288045648623395,
           -20.309636861962787,
           -20.331228075302178,
           -20.352819288641566,
           -20.374410501980954,
           -20.396001715320345,
           -20.417592928659733,
           -20.439184141999124,
           -20.460775355338512,
           -20.4823665686779,
           -20.503957782017288,
           -20.52554899535668,
           -20.54714020869607,
           -20.568731422035455,
           -20.590322635374847,
           -20.611913848714238,
           -20.633505062053622,
           -20.655096275393014,
           -20.676687488732405,
           -20.698278702071793,
           -20.719869915411184,
           -20.741461128750572,
           -20.76305234208996,
           -20.784643555429348,
           -20.80623476876874,
           -20.827825982108127,
           -20.84941719544752,
           -20.871008408786906,
           -20.892599622126294,
           -20.914190835465682,
           -20.935782048805073,
           -20.957373262144465,
           -20.97896447548385,
           -21.00055568882324,
           -21.022146902162632,
           -21.043738115502023,
           -21.065329328841408,
           -21.0869205421808,
           -21.10851175552019,
           -21.13010296885958,
           -21.151694182198966,
           -21.173285395538358,
           -21.194876608877745,
           -21.216467822217133,
           -21.238059035556525,
           -21.259650248895916,
           -21.281241462235304,
           -21.30283267557469,
           -21.324423888914083,
           -21.34601510225347,
           -21.36760631559286,
           -21.38919752893225,
           -21.410788742271638,
           -21.432379955611026,
           -21.453971168950417,
           -21.475562382289805,
           -21.497153595629197,
           -21.518744808968584,
           -21.540336022307972,
           -21.561927235647364,
           -21.58351844898675,
           -21.605109662326143,
           -21.626700875665534,
           -21.64829208900492,
           -21.66988330234431,
           -21.691474515683698,
           -21.71306572902309,
           -21.734656942362477,
           -21.756248155701865,
           -21.777839369041256,
           -21.799430582380648,
           -21.821021795720032,
           -21.842613009059423,
           -21.86420422239881,
           -21.887263810337767,
           -21.911057585576504,
           -21.934851360815237,
           -21.95864513605397,
           -21.982438911292707,
           -22.006232686531444,
           -22.03002646177018,
           -22.053820237008914,
           -22.077614012247647,
           -22.10140778748638,
           -22.12520156272512,
           -22.148995337963854,
           -22.172789113202587,
           -22.196582888441323,
           -22.22037666368006,
           -22.244170438918793,
           -22.26796421415753,
           -22.29175798939626,
           -22.315551764635,
           -22.339345539873737,
           -22.36313931511247,
           -22.386933090351206,
           -22.410726865589943,
           -22.434520640828676,
           -22.45831441606741,
           -22.482108191306146,
           -22.505901966544883,
           -22.52969574178362,
           -22.55348951702235,
           -22.577283292261086,
           -22.601077067499823,
           -22.62487084273856,
           -22.648664617977293,
           -22.67245839321603,
           -22.696252168454762,
           -22.7200459436935,
           -22.743839718932236,
           -22.76763349417097,
           -22.791427269409706,
           -22.81522104464844,
           -22.839014819887172,
           -22.862808595125912,
           -22.886602370364646,
           -22.91039614560338,
           -22.934189920842115,
           -22.958233309091586,
           -22.982426465701035,
           -23.006619622310488,
           -23.03081277891994,
           -23.055005935529394,
           -23.079199092138843,
           -23.103392248748296,
           -23.127585405357745,
           -23.1517785619672,
           -23.175971718576648,
           -23.2001648751861,
           -23.224358031795553,
           -23.248551188405003,
           -23.272744345014452,
           -23.296937501623905,
           -23.321130658233358,
           -23.34532381484281,
           -23.369516971452256,
           -23.393710128061713,
           -23.417903284671162,
           -23.442096441280615,
           -23.466289597890068,
           -23.490482754499517,
           -23.51467591110897,
           -23.538869067718423,
           -23.563062224327872,
           -23.58725538093732,
           -23.611448537546778,
           -23.635641694156227,
           -23.659834850765677,
           -23.684028007375133,
           -23.708221163984582,
           -23.732414320594035,
           -23.756607477203485,
           -23.780800633812937,
           -23.804993790422387,
           -23.82918694703184,
           -23.853380103641292,
           -23.876411899414524,
           -23.89828233435154,
           -23.920152769288553,
           -23.942023204225563,
           -23.963893639162578,
           -23.98576407409959,
           -24.007634509036603,
           -24.029504943973617,
           -24.051375378910627,
           -24.07324581384764,
           -24.095116248784652,
           -24.11698668372167,
           -24.13885711865868,
           -24.160727553595695,
           -24.182597988532706,
           -24.204468423469716,
           -24.22633885840673,
           -24.24820929334375,
           -24.27007972828076,
           -24.291950163217773,
           -24.313820598154784,
           -24.3356910330918,
           -24.35756146802881,
           -24.379431902965823,
           -24.40130233790284,
           -24.42317277283985,
           -24.445043207776866,
           -24.46691364271388,
           -24.48878407765089,
           -24.5106545125879,
           -24.53252494752492,
           -24.554395382461934,
           -24.57626581739894,
           -24.59813625233596,
           -24.620006687272973,
           -24.641877122209983,
           -24.663747557146994,
           -24.685617992084012,
           -24.70748842702102,
           -24.729358861958037,
           -24.751493373846227,
           -24.774080583237055,
           -24.79666779262788,
           -24.819255002018703,
           -24.84184221140953,
           -24.86442942080036,
           -24.887016630191184,
           -24.90960383958201,
           -24.932191048972832,
           -24.95477825836366,
           -24.97736546775449,
           -24.999952677145316,
           -25.022539886536137,
           -25.04512709592697,
           -25.067714305317793,
           -25.09030151470862,
           -25.112888724099445,
           -25.135475933490277,
           -25.158063142881094,
           -25.180650352271922,
           -25.203237561662753,
           -25.225824771053578,
           -25.2484119804444,
           -25.27099918983523,
           -25.293586399226054,
           -25.31617360861688,
           -25.338760818007707,
           -25.361348027398535,
           -25.383935236789355,
           -25.406522446180187,
           -25.42910965557101,
           -25.451696864961836,
           -25.474284074352664,
           -25.496871283743488,
           -25.519458493134316,
           -25.54204570252514,
           -25.564632911915965,
           -25.587220121306792,
           -25.60980733069762,
           -25.632394540088445,
           -25.654981749479276,
           -25.677568958870097,
           -25.700156168260925,
           -25.702506235672825,
           -25.664382019126887,
           -25.626257802580955,
           -25.588133586035017,
           -25.55000936948908,
           -25.511885152943144,
           -25.473760936397206,
           -25.43563671985127,
           -25.39751250330534,
           -25.359388286759398,
           -25.32126407021346,
           -25.283139853667524,
           -25.24501563712159,
           -25.202979430097066,
           -25.157835549959852,
           -25.11269166982264,
           -25.067547789685424,
           -25.02240390954821,
           -24.977260029411,
           -24.93211614927378,
           -24.886972269136564,
           -24.84182838899935,
           -24.796684508862135,
           -24.751540628724914,
           -24.706396748587707,
           -24.661252868450493,
           -24.61610898831328,
           -24.570965108176065,
           -24.52582122803885,
           -24.480677347901633,
           -24.43553346776442,
           -24.390389587627205,
           -24.345245707489987,
           -24.30010182735277,
           -24.254957947215555,
           -24.209814067078348,
           -24.16467018694113,
           -24.119526306803913,
           -24.074382426666702,
           -24.029238546529484,
           -23.984094666392267,
           -23.938950786255056,
           -23.89380690611784,
           -23.84866302598062,
           -23.80351914584341,
           -23.758375265706192,
           -23.713231385568978,
           -23.668087505431767,
           -23.622943625294553,
           -23.577799745157336,
           -23.532655865020125,
           -23.487511984882907,
           -23.44236810474569,
           -23.39722422460848,
           -23.35208034447126,
           -23.30693646433405,
           -23.261792584196833,
           -23.21664870405962,
           -23.171504823922405,
           -23.126360943785187,
           -23.081217063647976,
           -23.036073183510762,
           -22.990929303373544,
           -22.945785423236334,
           -22.90064154309912,
           -22.855497662961902,
           -22.810353782824684,
           -22.765209902687474,
           -22.72006602255026,
           -22.67492214241304,
           -22.629778262275828,
           -22.584634382138614,
           -22.539490502001396,
           -22.494346621864185,
           -22.449202741726968,
           -22.404058861589753,
           -22.358914981452536,
           -22.31377110131533,
           -22.26862722117811,
           -22.223483341040893,
           -22.17833946090368,
           -22.133195580766465,
           -22.088051700629247,
           -22.062621626561636,
           -22.135760582841986,
           -22.20889953912234,
           -22.28203849540269,
           -22.355177451683033,
           -22.428316407963386,
           -22.50145536424374,
           -22.574594320524078,
           -22.64773327680443,
           -22.720872233084783,
           -22.794011189365122,
           -22.867150145645475,
           -22.940289101925828,
           -23.013428058206184,
           -23.086567014486523,
           -23.159705970766872,
           -23.232844927047225,
           -23.305983883327567,
           -23.37912283960792,
           -23.45226179588827,
           -23.525400752168615,
           -23.598539708448968,
           -23.67167866472932,
           -23.74481762100966,
           -23.81795657729001,
           -23.891095533570365,
           -23.964234489850714,
           -23.90798615619728,
           -23.788459795241117,
           -23.668933434284956,
           -23.54940707332882,
           -23.429880712372658,
           -23.310354351416496,
           -23.190827990460356,
           -23.071301629504195,
           -22.951775268548033,
           -22.83224890759187,
           -22.71272254663573,
           -22.593196185679574,
           -22.473669824723412,
           -22.354143463767272,
           -22.23461710281111,
           -22.11509074185495,
           -21.995564380898813,
           -21.876038019942648,
           -21.756511658986486,
           -21.636985298030346,
           -21.51745893707419,
           -21.397932576118027,
           -21.278406215161866,
           -21.158879854205725,
           -21.039353493249564,
           -20.919827132293403,
           -20.800300771337263,
           -20.6807744103811,
           -20.56124804942494,
           -20.441721688468803,
           -20.230591232136227,
           -19.926044081586646,
           -19.62149693103707,
           -19.316949780487548,
           -19.012402629937966,
           -18.70785547938839,
           -18.403308328838868,
           -18.09876117828929,
           -17.794214027739713,
           -17.48966687719019,
           -17.185119726640615,
           -16.880572576091033,
           -16.576025425541513,
           -16.271478274991935,
           -15.966931124442354,
           -15.66238397389278,
           -15.357836823343257,
           -15.053289672793678,
           -14.748742522244099,
           -14.444195371694576,
           -14.139648221145,
           -13.835101070595421,
           -13.530553920045898,
           -13.22600676949632,
           -12.921459618946743,
           -12.616912468397164,
           -12.312365317847643
          ],
          [
           -17.788652429557274,
           -17.811030526659465,
           -17.833408623761652,
           -17.855786720863843,
           -17.87816481796603,
           -17.900542915068222,
           -17.922921012170413,
           -17.945299109272604,
           -17.96767720637479,
           -17.99005530347698,
           -18.01243340057917,
           -18.03481149768136,
           -18.057189594783548,
           -18.07956769188574,
           -18.10194578898793,
           -18.124323886090117,
           -18.146701983192308,
           -18.1690800802945,
           -18.191458177396687,
           -18.213836274498878,
           -18.236214371601065,
           -18.258592468703256,
           -18.280970565805443,
           -18.303348662907634,
           -18.32572676000982,
           -18.348104857112013,
           -18.370482954214204,
           -18.39286105131639,
           -18.415239148418582,
           -18.43761724552077,
           -18.45999534262296,
           -18.48237343972515,
           -18.50475153682734,
           -18.52712963392953,
           -18.549507731031717,
           -18.571885828133908,
           -18.5942639252361,
           -18.616642022338286,
           -18.639020119440477,
           -18.66139821654267,
           -18.683776313644856,
           -18.706154410747047,
           -18.728532507849234,
           -18.750910604951425,
           -18.773288702053613,
           -18.795666799155804,
           -18.818044896257994,
           -18.840422993360185,
           -18.862801090462373,
           -18.88517918756456,
           -18.90755728466675,
           -18.929935381768942,
           -18.952313478871133,
           -18.97469157597332,
           -18.997069673075508,
           -19.0194477701777,
           -19.04182586727989,
           -19.06420396438208,
           -19.086582061484265,
           -19.10862054060296,
           -19.128960933663393,
           -19.14930132672383,
           -19.169641719784266,
           -19.1899821128447,
           -19.210322505905133,
           -19.230662898965566,
           -19.251003292026,
           -19.271343685086435,
           -19.291684078146872,
           -19.312024471207305,
           -19.33236486426774,
           -19.35270525732817,
           -19.373045650388608,
           -19.39338604344904,
           -19.413726436509474,
           -19.43406682956991,
           -19.454407222630344,
           -19.474747615690777,
           -19.495088008751214,
           -19.515428401811647,
           -19.535768794872084,
           -19.556109187932517,
           -19.576449580992954,
           -19.596789974053387,
           -19.616070697103694,
           -19.635139486151974,
           -19.654208275200258,
           -19.673277064248538,
           -19.69234585329682,
           -19.711414642345105,
           -19.730483431393385,
           -19.749552220441668,
           -19.768621009489948,
           -19.78768979853823,
           -19.806758587586515,
           -19.825827376634795,
           -19.844896165683075,
           -19.863964954731358,
           -19.88303374377964,
           -19.902102532827925,
           -19.921171321876205,
           -19.940240110924485,
           -19.959308899972772,
           -19.978377689021052,
           -19.99744647806933,
           -20.016515267117615,
           -20.0355840561659,
           -20.05465284521418,
           -20.074982845611807,
           -20.096574058951195,
           -20.118165272290586,
           -20.139756485629977,
           -20.161347698969365,
           -20.182938912308753,
           -20.204530125648144,
           -20.226121338987532,
           -20.24771255232692,
           -20.269303765666308,
           -20.2908949790057,
           -20.31248619234509,
           -20.33407740568448,
           -20.355668619023866,
           -20.377259832363258,
           -20.39885104570265,
           -20.420442259042034,
           -20.44203347238142,
           -20.463624685720816,
           -20.485215899060204,
           -20.506807112399592,
           -20.52839832573898,
           -20.54998953907837,
           -20.571580752417763,
           -20.59317196575715,
           -20.61476317909654,
           -20.636354392435926,
           -20.657945605775318,
           -20.67953681911471,
           -20.701128032454097,
           -20.722719245793485,
           -20.744310459132876,
           -20.765901672472264,
           -20.787492885811652,
           -20.809084099151043,
           -20.83067531249043,
           -20.852266525829823,
           -20.87385773916921,
           -20.8954489525086,
           -20.91704016584799,
           -20.938631379187377,
           -20.96022259252677,
           -20.98181380586616,
           -21.003405019205545,
           -21.024996232544936,
           -21.046587445884324,
           -21.06817865922371,
           -21.089769872563103,
           -21.11136108590249,
           -21.13295229924188,
           -21.15454351258127,
           -21.176134725920658,
           -21.19772593926005,
           -21.219317152599437,
           -21.24090836593883,
           -21.262499579278217,
           -21.284090792617604,
           -21.305682005956996,
           -21.327273219296384,
           -21.35033280723534,
           -21.374126582474073,
           -21.397920357712806,
           -21.421714132951546,
           -21.445507908190276,
           -21.469301683429013,
           -21.49309545866775,
           -21.516889233906483,
           -21.540683009145216,
           -21.564476784383952,
           -21.588270559622693,
           -21.612064334861422,
           -21.63585811010016,
           -21.659651885338896,
           -21.68344566057763,
           -21.707239435816366,
           -21.731033211055102,
           -21.754826986293835,
           -21.778620761532572,
           -21.80241453677131,
           -21.826208312010042,
           -21.850002087248775,
           -21.873795862487512,
           -21.89758963772625,
           -21.92138341296498,
           -21.945177188203715,
           -21.96897096344245,
           -21.992764738681185,
           -22.016558513919925,
           -22.04035228915866,
           -22.06414606439739,
           -22.087939839636128,
           -22.111733614874865,
           -22.1355273901136,
           -22.159321165352335,
           -22.183114940591068,
           -22.206908715829805,
           -22.23070249106854,
           -22.25449626630727,
           -22.27829004154601,
           -22.302083816784744,
           -22.325877592023478,
           -22.349671367262218,
           -22.37346514250095,
           -22.397258917739684,
           -22.42105269297842,
           -22.444846468217158,
           -22.46864024345589,
           -22.492434018694624,
           -22.51622779393336,
           -22.540021569172097,
           -22.56381534441083,
           -22.587609119649567,
           -22.611402894888304,
           -22.635196670127037,
           -22.658990445365774,
           -22.68278422060451,
           -22.70657799584324,
           -22.730371771081977,
           -22.754165546320714,
           -22.77795932155945,
           -22.801753096798187,
           -22.82554687203692,
           -22.849340647275653,
           -22.87313442251439,
           -22.896928197753127,
           -22.92072197299186,
           -22.9445157482306,
           -22.96830952346933,
           -22.992103298708066,
           -23.015897073946803,
           -23.038584104806166,
           -23.059903982956946,
           -23.08122386110773,
           -23.102543739258515,
           -23.123863617409295,
           -23.145183495560076,
           -23.166503373710864,
           -23.187823251861644,
           -23.20914313001243,
           -23.23046300816321,
           -23.251782886313993,
           -23.273102764464777,
           -23.29612933286415,
           -23.32086259151212,
           -23.34559585016009,
           -23.370329108808054,
           -23.395062367456024,
           -23.419795626103994,
           -23.444528884751964,
           -23.469262143399934,
           -23.493995402047904,
           -23.51872866069587,
           -23.54346191934384,
           -23.568195177991807,
           -23.59292843663978,
           -23.617661695287744,
           -23.642394953935714,
           -23.667128212583684,
           -23.69186147123165,
           -23.716594729879624,
           -23.741327988527587,
           -23.766061247175557,
           -23.790794505823527,
           -23.815527764471497,
           -23.840261023119464,
           -23.864271633113276,
           -23.8868588425041,
           -23.90944605189493,
           -23.93203326128575,
           -23.95462047067658,
           -23.977207680067405,
           -23.99979488945823,
           -24.022382098849057,
           -24.044969308239885,
           -24.06755651763071,
           -24.090143727021538,
           -24.112730936412362,
           -24.135318145803186,
           -24.157905355194014,
           -24.18049256458484,
           -24.203079773975666,
           -24.22566698336649,
           -24.24825419275732,
           -24.270841402148143,
           -24.29342861153897,
           -24.3160158209298,
           -24.338603030320623,
           -24.361190239711448,
           -24.383777449102276,
           -24.406364658493104,
           -24.428951867883928,
           -24.451539077274752,
           -24.47412628666558,
           -24.496713496056408,
           -24.519300705447233,
           -24.541887914838057,
           -24.56447512422888,
           -24.58706233361971,
           -24.609649543010537,
           -24.63223675240136,
           -24.654823961792186,
           -24.677411171183014,
           -24.699998380573838,
           -24.722585589964666,
           -24.74517279935549,
           -24.767760008746322,
           -24.790347218137143,
           -24.81293442752797,
           -24.8355216369188,
           -24.858108846309626,
           -24.88069605570045,
           -24.903283265091275,
           -24.925870474482103,
           -24.94845768387293,
           -24.971044893263752,
           -24.99363210265458,
           -25.016219312045408,
           -25.038806521436236,
           -25.061393730827056,
           -25.083980940217884,
           -25.106568149608712,
           -25.129155358999537,
           -25.151742568390365,
           -25.17432977778119,
           -25.196916987172013,
           -25.199267054583913,
           -25.161142838037982,
           -25.123018621492047,
           -25.084894404946105,
           -25.046770188400174,
           -25.008645971854236,
           -24.970521755308297,
           -24.93239753876236,
           -24.894273322216428,
           -24.85614910567049,
           -24.81802488912455,
           -24.779900672578616,
           -24.74177645603268,
           -24.703652239486743,
           -24.665528022940812,
           -24.627403806394874,
           -24.589279589848935,
           -24.551155373303,
           -24.513031156757066,
           -24.474906940211127,
           -24.43678272366519,
           -24.39865850711925,
           -24.36053429057332,
           -24.32241007402738,
           -24.284285857481443,
           -24.24616164093551,
           -24.208037424389573,
           -24.169913207843635,
           -24.131788991297704,
           -24.093664774751765,
           -24.055540558205827,
           -24.017416341659896,
           -23.979292125113957,
           -23.94116790856802,
           -23.903043692022084,
           -23.86491947547615,
           -23.82679525893021,
           -23.788671042384276,
           -23.75054682583834,
           -23.7124226092924,
           -23.674298392746465,
           -23.636174176200534,
           -23.598049959654592,
           -23.553545901010594,
           -23.50840202087338,
           -23.463258140736166,
           -23.418114260598948,
           -23.372970380461737,
           -23.327826500324523,
           -23.282682620187305,
           -23.23753874005009,
           -23.19239485991288,
           -23.147250979775663,
           -23.102107099638445,
           -23.056963219501235,
           -23.011819339364017,
           -22.9666754592268,
           -22.92153157908959,
           -22.876387698952374,
           -22.831243818815157,
           -22.786099938677946,
           -22.74095605854073,
           -22.695812178403514,
           -22.6506682982663,
           -22.605524418129086,
           -22.560380537991872,
           -22.51523665785465,
           -22.470092777717444,
           -22.424948897580226,
           -22.379805017443008,
           -22.334661137305797,
           -22.289517257168587,
           -22.24437337703137,
           -22.19922949689415,
           -22.15408561675694,
           -22.10894173661972,
           -22.063797856482502,
           -22.01865397634529,
           -21.973510096208077,
           -21.92836621607086,
           -21.883222335933645,
           -21.838078455796435,
           -21.79293457565922,
           -21.767504501591606,
           -21.84064345787196,
           -21.91378241415231,
           -21.986921370432665,
           -22.060060326713003,
           -22.133199282993356,
           -22.20633823927371,
           -22.279477195554048,
           -22.3526161518344,
           -22.42575510811475,
           -22.49889406439509,
           -22.57203302067545,
           -22.645171976955798,
           -22.718310933236154,
           -22.791449889516493,
           -22.864588845796845,
           -22.937727802077198,
           -23.010866758357537,
           -23.08400571463789,
           -23.157144670918242,
           -23.23028362719858,
           -23.303422583478934,
           -23.376561539759287,
           -23.449700496039625,
           -23.522839452319978,
           -23.59597840860033,
           -23.669117364880684,
           -23.741328706546778,
           -23.636416885433995,
           -23.53150506432121,
           -23.42659324320845,
           -23.321681422095665,
           -23.216769600982886,
           -23.11185777987012,
           -23.00694595875734,
           -22.902034137644556,
           -22.797122316531777,
           -22.692210495419015,
           -22.58729867430623,
           -22.482386853193447,
           -22.377475032080685,
           -22.272563210967903,
           -22.167651389855124,
           -22.062739568742362,
           -21.95782774762958,
           -21.852915926516797,
           -21.748004105404036,
           -21.643092284291253,
           -21.53818046317847,
           -21.433268642065684,
           -21.328356820952923,
           -21.22344499984014,
           -21.118533178727358,
           -21.013621357614596,
           -20.908709536501817,
           -20.803797715389035,
           -20.66665340587149,
           -20.362106255321912,
           -20.057559104772327,
           -19.753011954222757,
           -19.44846480367323,
           -19.143917653123655,
           -18.839370502574074,
           -18.534823352024553,
           -18.23027620147498,
           -17.925729050925398,
           -17.621181900375873,
           -17.316634749826296,
           -17.012087599276718,
           -16.707540448727194,
           -16.402993298177616,
           -16.09844614762804,
           -15.793898997078461,
           -15.489351846528939,
           -15.18480469597936,
           -14.880257545429782,
           -14.57571039488026,
           -14.271163244330682,
           -13.966616093781106,
           -13.662068943231581,
           -13.357521792682004,
           -13.052974642132424,
           -12.748427491582847,
           -12.443880341033324
          ],
          [
           -17.326963544699492,
           -17.349341641801683,
           -17.37171973890387,
           -17.39409783600606,
           -17.416475933108252,
           -17.438854030210443,
           -17.46123212731263,
           -17.483610224414818,
           -17.50598832151701,
           -17.5283664186192,
           -17.55074451572139,
           -17.573122612823575,
           -17.595500709925766,
           -17.617878807027957,
           -17.640256904130148,
           -17.66263500123234,
           -17.685013098334522,
           -17.707391195436713,
           -17.729769292538904,
           -17.752147389641095,
           -17.774525486743283,
           -17.79690358384547,
           -17.81928168094766,
           -17.841659778049852,
           -17.86403787515204,
           -17.88641597225423,
           -17.90879406935642,
           -17.93117216645861,
           -17.9535502635608,
           -17.97592836066299,
           -17.99830645776518,
           -18.02068455486737,
           -18.043062651969556,
           -18.065440749071747,
           -18.08781884617394,
           -18.110196943276126,
           -18.132575040378317,
           -18.154953137480504,
           -18.177331234582695,
           -18.199709331684883,
           -18.222087428787074,
           -18.244465525889265,
           -18.266843622991452,
           -18.287863249753045,
           -18.30820364281348,
           -18.328544035873914,
           -18.348884428934348,
           -18.369224821994784,
           -18.389565215055217,
           -18.40990560811565,
           -18.430246001176087,
           -18.450586394236524,
           -18.470926787296953,
           -18.49126718035739,
           -18.511607573417827,
           -18.53194796647826,
           -18.552288359538693,
           -18.57262875259913,
           -18.592969145659563,
           -18.613309538719996,
           -18.633649931780432,
           -18.653990324840866,
           -18.6743307179013,
           -18.694671110961735,
           -18.71501150402217,
           -18.7353518970826,
           -18.75569229014304,
           -18.77603268320347,
           -18.796373076263905,
           -18.81671346932434,
           -18.837053862384778,
           -18.857394255445207,
           -18.877734648505644,
           -18.898075041566077,
           -18.918415434626514,
           -18.938755827686947,
           -18.959096220747384,
           -18.979436613807817,
           -18.99977700686825,
           -19.020117399928687,
           -19.04045779298912,
           -19.060798186049553,
           -19.08113857910999,
           -19.101478972170423,
           -19.12075969522073,
           -19.13982848426901,
           -19.158897273317294,
           -19.177966062365577,
           -19.19703485141386,
           -19.216103640462137,
           -19.23517242951042,
           -19.254241218558704,
           -19.273310007606987,
           -19.292378796655267,
           -19.31144758570355,
           -19.33051637475183,
           -19.349585163800114,
           -19.368653952848398,
           -19.387722741896678,
           -19.406791530944957,
           -19.42586031999324,
           -19.444929109041524,
           -19.463997898089808,
           -19.483066687138088,
           -19.502135476186368,
           -19.52120426523465,
           -19.540273054282935,
           -19.559341843331215,
           -19.578410632379498,
           -19.597479421427778,
           -19.61654821047606,
           -19.635616999524345,
           -19.654685788572625,
           -19.673754577620908,
           -19.692823366669188,
           -19.71189215571747,
           -19.73096094476575,
           -19.750029733814035,
           -19.769098522862315,
           -19.7881673119106,
           -19.80723610095888,
           -19.826304890007165,
           -19.84537367905544,
           -19.864442468103725,
           -19.883511257152012,
           -19.90510246927899,
           -19.926693682618378,
           -19.94828489595777,
           -19.969876109297157,
           -19.991467322636545,
           -20.013058535975937,
           -20.034649749315328,
           -20.056240962654716,
           -20.077832175994104,
           -20.09942338933349,
           -20.121014602672883,
           -20.14260581601227,
           -20.164197029351662,
           -20.18578824269105,
           -20.207379456030438,
           -20.22897066936983,
           -20.25056188270922,
           -20.27215309604861,
           -20.293744309387996,
           -20.315335522727388,
           -20.336926736066776,
           -20.358517949406163,
           -20.380109162745555,
           -20.401700376084943,
           -20.423291589424334,
           -20.444882802763722,
           -20.46647401610311,
           -20.4880652294425,
           -20.50965644278189,
           -20.53124765612128,
           -20.55283886946067,
           -20.574430082800056,
           -20.596021296139448,
           -20.61761250947884,
           -20.639203722818223,
           -20.660794936157615,
           -20.682386149497002,
           -20.70397736283639,
           -20.72556857617578,
           -20.747159789515173,
           -20.76875100285456,
           -20.79034221619395,
           -20.813401804132905,
           -20.837195579371638,
           -20.860989354610375,
           -20.884783129849108,
           -20.90857690508784,
           -20.932370680326578,
           -20.956164455565318,
           -20.979958230804048,
           -21.003752006042784,
           -21.027545781281518,
           -21.051339556520258,
           -21.07513333175899,
           -21.098927106997728,
           -21.122720882236464,
           -21.146514657475194,
           -21.170308432713934,
           -21.194102207952668,
           -21.2178959831914,
           -21.241689758430137,
           -21.26548353366887,
           -21.289277308907607,
           -21.313071084146344,
           -21.336864859385074,
           -21.360658634623817,
           -21.384452409862547,
           -21.408246185101284,
           -21.43203996034002,
           -21.45583373557875,
           -21.479627510817487,
           -21.503421286056223,
           -21.52721506129496,
           -21.551008836533693,
           -21.57480261177243,
           -21.598596387011163,
           -21.6223901622499,
           -21.646183937488637,
           -21.669977712727373,
           -21.693771487966103,
           -21.71756526320484,
           -21.741359038443576,
           -21.76515281368231,
           -21.78894658892105,
           -21.812740364159783,
           -21.836534139398516,
           -21.860327914637253,
           -21.88412168987599,
           -21.907915465114723,
           -21.931709240353456,
           -21.955503015592193,
           -21.97929679083093,
           -22.003090566069666,
           -22.02584269898984,
           -22.047162577140625,
           -22.06848245529141,
           -22.089802333442194,
           -22.111122211592978,
           -22.13244208974376,
           -22.15376196789454,
           -22.17508184604532,
           -22.196401724196107,
           -22.21772160234689,
           -22.23904148049767,
           -22.260361358648456,
           -22.281681236799237,
           -22.30300111495002,
           -22.3243209931008,
           -22.345640871251586,
           -22.366960749402367,
           -22.388280627553154,
           -22.409600505703935,
           -22.430920383854716,
           -22.452240262005503,
           -22.473560140156284,
           -22.494880018307068,
           -22.51619989645785,
           -22.53751977460863,
           -22.558839652759413,
           -22.580159530910198,
           -22.60147940906098,
           -22.622799287211762,
           -22.644119165362547,
           -22.665439043513327,
           -22.68675892166411,
           -22.709785490063485,
           -22.734518748711455,
           -22.759252007359425,
           -22.78398526600739,
           -22.80871852465536,
           -22.83345178330333,
           -22.858185041951298,
           -22.88291830059927,
           -22.90765155924724,
           -22.932384817895205,
           -22.957118076543175,
           -22.981851335191145,
           -23.00658459383911,
           -23.03131785248708,
           -23.05605111113505,
           -23.080784369783018,
           -23.105517628430988,
           -23.130250887078954,
           -23.154984145726928,
           -23.17971740437489,
           -23.20445066302286,
           -23.22918392167083,
           -23.253917180318798,
           -23.278650438966768,
           -23.303383697614734,
           -23.328116956262704,
           -23.352850214910674,
           -23.377583473558644,
           -23.40231673220661,
           -23.42704999085458,
           -23.451783249502547,
           -23.47651650815052,
           -23.501249766798487,
           -23.525983025446454,
           -23.550716284094428,
           -23.575449542742394,
           -23.60018280139036,
           -23.62491606003833,
           -23.649649318686297,
           -23.674382577334267,
           -23.69911583598224,
           -23.723849094630204,
           -23.74858235327817,
           -23.77331561192614,
           -23.79804887057411,
           -23.822782129222077,
           -23.847515387870047,
           -23.872248646518017,
           -23.896981905165987,
           -23.921715163813957,
           -23.946448422461923,
           -23.971181681109893,
           -23.99591493975786,
           -24.02064819840583,
           -24.0453814570538,
           -24.070114715701767,
           -24.094847974349737,
           -24.119581232997707,
           -24.144314491645673,
           -24.16904775029364,
           -24.19378100894161,
           -24.21851426758958,
           -24.24193361826658,
           -24.264520827657407,
           -24.28710803704823,
           -24.30969524643906,
           -24.332282455829887,
           -24.35486966522071,
           -24.377456874611532,
           -24.400044084002364,
           -24.422631293393188,
           -24.445218502784016,
           -24.467805712174844,
           -24.490392921565668,
           -24.512980130956493,
           -24.535567340347317,
           -24.55815454973815,
           -24.580741759128976,
           -24.603328968519794,
           -24.625916177910625,
           -24.64850338730145,
           -24.671090596692277,
           -24.693677806083105,
           -24.696027873495,
           -24.657903656949067,
           -24.619779440403132,
           -24.581655223857194,
           -24.54353100731126,
           -24.50540679076532,
           -24.46728257421939,
           -24.429158357673447,
           -24.391034141127516,
           -24.352909924581578,
           -24.314785708035643,
           -24.276661491489705,
           -24.23853727494377,
           -24.20041305839783,
           -24.162288841851893,
           -24.12416462530596,
           -24.086040408760024,
           -24.04791619221409,
           -24.00979197566815,
           -23.971667759122212,
           -23.933543542576274,
           -23.895419326030343,
           -23.857295109484408,
           -23.81917089293847,
           -23.78104667639253,
           -23.742922459846596,
           -23.704798243300658,
           -23.666674026754727,
           -23.62854981020879,
           -23.59042559366285,
           -23.552301377116912,
           -23.514177160570984,
           -23.476052944025042,
           -23.437928727479104,
           -23.399804510933173,
           -23.361680294387234,
           -23.323556077841296,
           -23.28543186129536,
           -23.24730764474943,
           -23.209183428203488,
           -23.17105921165755,
           -23.13293499511162,
           -23.094810778565677,
           -23.056686562019742,
           -23.018562345473804,
           -22.980438128927872,
           -22.942313912381934,
           -22.904189695836,
           -22.86606547929006,
           -22.827941262744122,
           -22.789817046198188,
           -22.751692829652256,
           -22.713568613106315,
           -22.675444396560376,
           -22.637320180014445,
           -22.59919596346851,
           -22.561071746922572,
           -22.522947530376634,
           -22.4848233138307,
           -22.44669909728476,
           -22.408574880738826,
           -22.37045066419289,
           -22.332326447646956,
           -22.294202231101018,
           -22.25607801455508,
           -22.217953798009148,
           -22.179829581463206,
           -22.141705364917275,
           -22.103581148371337,
           -22.0654569318254,
           -22.027332715279464,
           -21.98920849873353,
           -21.949256252061332,
           -21.90411237192412,
           -21.85896849178691,
           -21.813824611649686,
           -21.768680731512475,
           -21.72353685137526,
           -21.678392971238043,
           -21.633249091100826,
           -21.588105210963615,
           -21.5429613308264,
           -21.497817450689183,
           -21.47238737662157,
           -21.54552633290192,
           -21.618665289182275,
           -21.691804245462627,
           -21.76494320174297,
           -21.83808215802332,
           -21.911221114303675,
           -21.984360070584014,
           -21.92025139578611,
           -21.815339574673335,
           -21.71042775356057,
           -21.605515932447787,
           -21.500604111335008,
           -21.39569229022222,
           -21.29078046910946,
           -21.185868647996678,
           -21.080956826883895,
           -20.976045005771134,
           -20.87113318465835,
           -20.766221363545565,
           -20.661309542432804,
           -20.556397721320025,
           -20.451485900207242,
           -20.34657407909448,
           -20.241662257981698,
           -20.136750436868915,
           -20.031838615756133,
           -19.926926794643368,
           -19.82201497353059,
           -19.717103152417806,
           -19.612191331305045,
           -19.507279510192262,
           -19.402367689079483,
           -19.29745586796672,
           -19.192544046853936,
           -19.087632225741153,
           -18.982720404628367,
           -18.87780858351561,
           -18.772896762402823,
           -18.66798494129004,
           -18.563073120177283,
           -18.4581612990645,
           -18.353249477951717,
           -18.248337656838956,
           -18.143425835726177,
           -18.03851401461339,
           -17.93360219350063,
           -17.828690372387847,
           -17.723778551275064,
           -17.61886673016228,
           -17.51395490904952,
           -17.409043087936737,
           -17.304131266823955,
           -17.199219445711194,
           -17.09430762459841,
           -16.98939580348563,
           -16.884483982372867,
           -16.779572161260084,
           -16.6746603401473,
           -16.56974851903452,
           -16.464836697921758,
           -16.359924876808975,
           -16.255013055696196,
           -16.15010123458343,
           -16.045189413470652,
           -15.940277592357866,
           -15.835365771245105,
           -15.730453950132322,
           -15.62554212901954,
           -15.520630307906778,
           -15.415718486793995,
           -15.310806665681215,
           -15.20589484456843,
           -15.100983023455669,
           -14.996071202342886,
           -14.891159381230107,
           -14.707225418065946,
           -14.402678267516368,
           -14.09813111696679,
           -13.793583966417268,
           -13.48903681586769,
           -13.184489665318111,
           -12.879942514768532,
           -12.57539536421901
          ],
          [
           -16.865274659841713,
           -16.8876527569439,
           -16.91003085404609,
           -16.932408951148282,
           -16.95478704825047,
           -16.97716514535266,
           -16.99954324245485,
           -17.02192133955704,
           -17.04429943665923,
           -17.066677533761418,
           -17.08905563086361,
           -17.111433727965796,
           -17.133811825067987,
           -17.156189922170178,
           -17.17856801927237,
           -17.200946116374556,
           -17.223324213476744,
           -17.245702310578935,
           -17.268080407681126,
           -17.290458504783317,
           -17.312836601885504,
           -17.33521469898769,
           -17.357592796089882,
           -17.379970893192073,
           -17.40234899029426,
           -17.42472708739645,
           -17.446765565842703,
           -17.467105958903133,
           -17.48744635196357,
           -17.507786745024006,
           -17.52812713808444,
           -17.548467531144873,
           -17.56880792420531,
           -17.589148317265742,
           -17.609488710326175,
           -17.629829103386612,
           -17.650169496447045,
           -17.67050988950748,
           -17.690850282567915,
           -17.711190675628348,
           -17.73153106868878,
           -17.751871461749218,
           -17.77221185480965,
           -17.792552247870084,
           -17.81289264093052,
           -17.833233033990954,
           -17.853573427051387,
           -17.873913820111824,
           -17.894254213172257,
           -17.91459460623269,
           -17.934934999293127,
           -17.955275392353563,
           -17.975615785413996,
           -17.99595617847443,
           -18.016296571534866,
           -18.0366369645953,
           -18.056977357655732,
           -18.07731775071617,
           -18.097658143776602,
           -18.117998536837035,
           -18.138338929897472,
           -18.158679322957905,
           -18.17901971601834,
           -18.199360109078775,
           -18.219700502139208,
           -18.24004089519964,
           -18.260381288260078,
           -18.28072168132051,
           -18.301062074380944,
           -18.32140246744138,
           -18.341742860501814,
           -18.36208325356225,
           -18.382423646622684,
           -18.40276403968312,
           -18.423104432743553,
           -18.443444825803986,
           -18.463785218864423,
           -18.484125611924856,
           -18.50446600498529,
           -18.524806398045726,
           -18.54514679110616,
           -18.565487184166592,
           -18.585827577227032,
           -18.606167970287462,
           -18.62544869333777,
           -18.644517482386053,
           -18.663586271434333,
           -18.682655060482617,
           -18.7017238495309,
           -18.72079263857918,
           -18.739861427627464,
           -18.758930216675743,
           -18.777999005724027,
           -18.79706779477231,
           -18.81613658382059,
           -18.835205372868874,
           -18.854274161917154,
           -18.873342950965437,
           -18.89241174001372,
           -18.911480529062,
           -18.93054931811028,
           -18.949618107158564,
           -18.968686896206847,
           -18.98775568525513,
           -19.00682447430341,
           -19.025893263351694,
           -19.044962052399974,
           -19.064030841448258,
           -19.08309963049654,
           -19.10216841954482,
           -19.121237208593104,
           -19.140305997641384,
           -19.159374786689668,
           -19.17844357573795,
           -19.197512364786228,
           -19.216581153834515,
           -19.235649942882795,
           -19.254718731931074,
           -19.273787520979354,
           -19.29285631002764,
           -19.31192509907592,
           -19.330993888124205,
           -19.350062677172485,
           -19.369131466220768,
           -19.38820025526905,
           -19.40726904431733,
           -19.426337833365615,
           -19.4454066224139,
           -19.46447541146218,
           -19.483544200510458,
           -19.50261298955874,
           -19.521681778607025,
           -19.540750567655305,
           -19.55981935670359,
           -19.57888814575187,
           -19.597956934800152,
           -19.617025723848435,
           -19.636094512896715,
           -19.655163301945,
           -19.67423209099328,
           -19.69330088004156,
           -19.71363087960679,
           -19.735222092946177,
           -19.75681330628557,
           -19.77840451962496,
           -19.799995732964344,
           -19.821586946303736,
           -19.843178159643127,
           -19.864769372982515,
           -19.886360586321903,
           -19.90795179966129,
           -19.929543013000682,
           -19.951134226340073,
           -19.972725439679458,
           -19.99431665301885,
           -20.01590786635824,
           -20.03749907969763,
           -20.059090293037016,
           -20.080681506376408,
           -20.102272719715796,
           -20.123863933055187,
           -20.145455146394575,
           -20.167046359733963,
           -20.18863757307335,
           -20.210228786412742,
           -20.231819999752133,
           -20.25341121309152,
           -20.276470801030474,
           -20.30026457626921,
           -20.324058351507944,
           -20.34785212674668,
           -20.371645901985413,
           -20.39543967722415,
           -20.419233452462887,
           -20.44302722770162,
           -20.466821002940357,
           -20.49061477817909,
           -20.514408553417827,
           -20.53820232865656,
           -20.561996103895297,
           -20.585789879134033,
           -20.609583654372766,
           -20.6333774296115,
           -20.657171204850236,
           -20.680964980088973,
           -20.70475875532771,
           -20.728552530566443,
           -20.75234630580518,
           -20.776140081043913,
           -20.799933856282646,
           -20.823727631521386,
           -20.84752140676012,
           -20.871315181998852,
           -20.89510895723759,
           -20.918902732476326,
           -20.942696507715063,
           -20.966490282953796,
           -20.99028405819253,
           -21.013101293173527,
           -21.03442117132431,
           -21.05574104947509,
           -21.077060927625876,
           -21.09838080577666,
           -21.119700683927444,
           -21.141020562078225,
           -21.16234044022901,
           -21.183660318379793,
           -21.204980196530574,
           -21.226300074681355,
           -21.24761995283214,
           -21.26893983098292,
           -21.290259709133707,
           -21.311579587284488,
           -21.33289946543527,
           -21.354219343586053,
           -21.375539221736837,
           -21.396859099887617,
           -21.4181789780384,
           -21.439498856189182,
           -21.460818734339966,
           -21.482138612490747,
           -21.503458490641535,
           -21.52477836879232,
           -21.546098246943096,
           -21.567418125093884,
           -21.588738003244664,
           -21.61005788139545,
           -21.63137775954623,
           -21.65269763769701,
           -21.674017515847794,
           -21.695337393998578,
           -21.716657272149362,
           -21.737977150300143,
           -21.75929702845093,
           -21.78061690660171,
           -21.801936784752492,
           -21.823256662903276,
           -21.84457654105406,
           -21.86589641920484,
           -21.887216297355625,
           -21.908536175506406,
           -21.92985605365719,
           -21.951175931807974,
           -21.972495809958758,
           -21.993815688109535,
           -22.01513556626032,
           -22.036455444411104,
           -22.057775322561888,
           -22.079095200712672,
           -22.100415078863453,
           -22.123441647262826,
           -22.148174905910796,
           -22.172908164558766,
           -22.197641423206733,
           -22.222374681854703,
           -22.247107940502673,
           -22.27184119915064,
           -22.296574457798613,
           -22.321307716446583,
           -22.346040975094546,
           -22.370774233742516,
           -22.395507492390486,
           -22.420240751038452,
           -22.44497400968642,
           -22.46970726833439,
           -22.49444052698236,
           -22.519173785630326,
           -22.543907044278292,
           -22.568640302926266,
           -22.593373561574232,
           -22.618106820222202,
           -22.642840078870172,
           -22.66757333751814,
           -22.69230659616611,
           -22.717039854814075,
           -22.741773113462045,
           -22.766506372110015,
           -22.791239630757985,
           -22.815972889405952,
           -22.840706148053922,
           -22.86543940670189,
           -22.890172665349862,
           -22.914905923997825,
           -22.939639182645795,
           -22.964372441293765,
           -22.98910569994173,
           -23.0138389585897,
           -23.03857221723767,
           -23.063305475885638,
           -23.088038734533608,
           -23.11277199318158,
           -23.137505251829545,
           -23.16223851047751,
           -23.18697176912548,
           -23.21170502777345,
           -23.236438286421418,
           -23.261171545069388,
           -23.285904803717358,
           -23.310638062365328,
           -23.335371321013294,
           -23.360104579661268,
           -23.384837838309235,
           -23.4095710969572,
           -23.43430435560517,
           -23.45903761425314,
           -23.483770872901108,
           -23.508504131549078,
           -23.533237390197048,
           -23.557970648845014,
           -23.582703907492984,
           -23.60743716614095,
           -23.632170424788917,
           -23.656903683436887,
           -23.681636942084857,
           -23.706370200732827,
           -23.73110345938079,
           -23.756095421879532,
           -23.781098511624414,
           -23.806101601369285,
           -23.831104691114163,
           -23.85610778085904,
           -23.881110870603923,
           -23.9061139603488,
           -23.93111705009368,
           -23.956120139838557,
           -23.981123229583435,
           -24.006126319328317,
           -24.03112940907319,
           -24.056132498818066,
           -24.081135588562947,
           -24.10613867830783,
           -24.131141768052704,
           -24.15614485779758,
           -24.16315406657717,
           -24.13417551342619,
           -24.10519696027521,
           -24.076218407124234,
           -24.047239853973252,
           -24.018261300822275,
           -23.989282747671293,
           -23.96030419452031,
           -23.931325641369334,
           -23.902347088218352,
           -23.873368535067367,
           -23.84438998191639,
           -23.81541142876541,
           -23.78643287561443,
           -23.754664744232805,
           -23.716959815564795,
           -23.67925488689678,
           -23.641549958228765,
           -23.603845029560755,
           -23.56614010089274,
           -23.528435172224725,
           -23.490730243556712,
           -23.453025314888702,
           -23.415320386220685,
           -23.377615457552672,
           -23.339910528884662,
           -23.302205600216645,
           -23.26450067154863,
           -23.22679574288062,
           -23.1890908142126,
           -23.151385885544585,
           -23.11368095687658,
           -23.075976028208565,
           -23.038271099540545,
           -23.00056617087253,
           -22.96286124220452,
           -22.925156313536505,
           -22.88745138486849,
           -22.84974645620048,
           -22.812041527532465,
           -22.77433659886445,
           -22.736631670196438,
           -22.698926741528425,
           -22.66122181286041,
           -22.623516884192398,
           -22.585811955524385,
           -22.54810702685637,
           -22.510402098188358,
           -22.472697169520345,
           -22.43499224085233,
           -22.397287312184318,
           -22.359582383516305,
           -22.32187745484829,
           -22.284172526180274,
           -22.246467597512265,
           -22.20876266884425,
           -22.171057740176234,
           -22.133352811508225,
           -22.09564788284021,
           -22.057942954172194,
           -22.020238025504185,
           -21.98253309683617,
           -21.944828168168154,
           -21.90712323950014,
           -21.86941831083213,
           -21.831713382164114,
           -21.794008453496097,
           -21.75630352482809,
           -21.71859859616007,
           -21.680893667492057,
           -21.643188738824044,
           -21.60548381015603,
           -21.567778881488017,
           -21.530073952820004,
           -21.49236902415199,
           -21.454664095483977,
           -21.416959166815964,
           -21.37925423814795,
           -21.341549309479937,
           -21.303844380811917,
           -21.26613945214391,
           -21.228434523475897,
           -21.190729594807877,
           -21.176564496785446,
           -21.280098551990857,
           -21.383632607196276,
           -21.487166662401684,
           -21.590700717607085,
           -21.6942347728125,
           -21.797768828017915,
           -21.90130288322331,
           -22.004836938428724,
           -22.10837099363414,
           -22.211905048839537,
           -22.31543910404495,
           -22.418973159250367,
           -22.52250721445578,
           -22.62604126966118,
           -22.729575324866595,
           -22.833109380072006,
           -22.936643435277404,
           -23.04017749048282,
           -23.143711545688234,
           -23.247245600893628,
           -23.350779656099043,
           -23.45431371130446,
           -23.557847766509855,
           -23.661381821715274,
           -23.764915876920686,
           -23.868449932126097,
           -23.971983987331495,
           -24.075518042536913,
           -24.17905209774232,
           -24.282586152947722,
           -24.386120208153137,
           -24.489654263358553,
           -24.593188318563946,
           -24.69672237376936,
           -24.800256428974777,
           -24.903790484180192,
           -25.00732453938559,
           -25.110858594591004,
           -25.21439264979642,
           -25.196333793053057,
           -25.091421971940278,
           -24.986510150827495,
           -24.881598329714734,
           -24.658974679803197,
           -24.35227200834799,
           -24.04556933689284,
           -23.73886666543763,
           -23.432163993982424,
           -23.12546132252722,
           -22.818758651072066,
           -22.51205597961686,
           -22.205353308161648,
           -21.898650636706503,
           -21.591947965251293,
           -21.285245293796084,
           -20.978542622340935,
           -20.67183995088573,
           -20.36513727943052,
           -20.05843460797531,
           -19.751731936520162,
           -19.445029265064953,
           -19.138326593609747,
           -18.831623922154595,
           -18.52492125069939,
           -18.21821857924418,
           -17.91151590778903,
           -17.604813236333825,
           -17.298110564878616,
           -16.991407893423464,
           -16.684705221968258,
           -16.37800255051305,
           -16.071299879057843,
           -15.76459720760269,
           -15.457894536147485,
           -15.151191864692278,
           -14.844489193237127,
           -14.537786521781918,
           -14.231083850326712,
           -13.924381178871561,
           -13.617678507416354,
           -13.310975835961145,
           -13.004273164505939,
           -12.697570493050787
          ],
          [
           -16.403585774983934,
           -16.425963872086125,
           -16.448341969188313,
           -16.470720066290504,
           -16.493098163392695,
           -16.515476260494882,
           -16.537854357597073,
           -16.56023245469926,
           -16.58261055180145,
           -16.604988648903642,
           -16.62600827499279,
           -16.646348668053225,
           -16.666689061113658,
           -16.687029454174095,
           -16.70736984723453,
           -16.727710240294964,
           -16.748050633355398,
           -16.768391026415834,
           -16.788731419476267,
           -16.8090718125367,
           -16.829412205597137,
           -16.84975259865757,
           -16.870092991718003,
           -16.89043338477844,
           -16.910773777838873,
           -16.931114170899306,
           -16.951454563959743,
           -16.971794957020176,
           -16.992135350080613,
           -17.012475743141046,
           -17.032816136201482,
           -17.053156529261916,
           -17.07349692232235,
           -17.093837315382785,
           -17.11417770844322,
           -17.13451810150365,
           -17.15485849456409,
           -17.17519888762452,
           -17.195539280684955,
           -17.21587967374539,
           -17.236220066805824,
           -17.256560459866257,
           -17.276900852926694,
           -17.29724124598713,
           -17.31758163904756,
           -17.337922032107997,
           -17.358262425168434,
           -17.378602818228867,
           -17.3989432112893,
           -17.419283604349737,
           -17.43962399741017,
           -17.459964390470606,
           -17.48030478353104,
           -17.500645176591473,
           -17.520985569651906,
           -17.541325962712342,
           -17.561666355772775,
           -17.58200674883321,
           -17.602347141893645,
           -17.62268753495408,
           -17.643027928014515,
           -17.663368321074948,
           -17.683708714135385,
           -17.704049107195818,
           -17.72438950025625,
           -17.744729893316688,
           -17.76507028637712,
           -17.785410679437554,
           -17.80575107249799,
           -17.826091465558424,
           -17.84643185861886,
           -17.866772251679294,
           -17.887112644739727,
           -17.907453037800163,
           -17.927793430860596,
           -17.948133823921033,
           -17.968474216981466,
           -17.9888146100419,
           -18.009155003102336,
           -18.02949539616277,
           -18.049835789223202,
           -18.070176182283635,
           -18.090516575344072,
           -18.11085696840451,
           -18.130137691454813,
           -18.149206480503096,
           -18.168275269551376,
           -18.187344058599656,
           -18.20641284764794,
           -18.225481636696223,
           -18.244550425744503,
           -18.263619214792786,
           -18.282688003841066,
           -18.30175679288935,
           -18.320825581937633,
           -18.339894370985913,
           -18.358963160034197,
           -18.378031949082477,
           -18.39710073813076,
           -18.416169527179044,
           -18.435238316227327,
           -18.454307105275607,
           -18.47337589432389,
           -18.49244468337217,
           -18.51151347242045,
           -18.530582261468734,
           -18.549651050517014,
           -18.568719839565297,
           -18.58778862861358,
           -18.60685741766186,
           -18.625926206710144,
           -18.644994995758424,
           -18.664063784806707,
           -18.68313257385499,
           -18.70220136290327,
           -18.721270151951554,
           -18.740338940999834,
           -18.759407730048117,
           -18.7784765190964,
           -18.79754530814468,
           -18.816614097192964,
           -18.835682886241244,
           -18.854751675289528,
           -18.873820464337808,
           -18.89288925338609,
           -18.91195804243437,
           -18.931026831482654,
           -18.950095620530938,
           -18.969164409579218,
           -18.9882331986275,
           -19.00730198767578,
           -19.026370776724065,
           -19.045439565772348,
           -19.064508354820628,
           -19.08357714386891,
           -19.10264593291719,
           -19.121714721965475,
           -19.14078351101376,
           -19.159852300062038,
           -19.17892108911032,
           -19.1979898781586,
           -19.217058667206885,
           -19.23612745625517,
           -19.255196245303445,
           -19.274265034351732,
           -19.293333823400012,
           -19.312402612448295,
           -19.33147140149658,
           -19.35054019054486,
           -19.369608979593142,
           -19.388677768641426,
           -19.407746557689705,
           -19.426815346737985,
           -19.44588413578627,
           -19.46495292483455,
           -19.484021713882832,
           -19.503090502931112,
           -19.5221592919794,
           -19.543750503273976,
           -19.565341716613364,
           -19.586932929952756,
           -19.608524143292147,
           -19.630115356631535,
           -19.651706569970923,
           -19.673297783310314,
           -19.694888996649702,
           -19.71648020998909,
           -19.739539797928046,
           -19.76333357316678,
           -19.787127348405516,
           -19.810921123644253,
           -19.834714898882982,
           -19.858508674121722,
           -19.882302449360456,
           -19.90609622459919,
           -19.92988999983793,
           -19.95368377507666,
           -19.977477550315395,
           -20.000359887357213,
           -20.021679765507997,
           -20.042999643658774,
           -20.06431952180956,
           -20.085639399960343,
           -20.106959278111127,
           -20.12827915626191,
           -20.149599034412695,
           -20.170918912563476,
           -20.192238790714256,
           -20.21355866886504,
           -20.234878547015825,
           -20.256198425166605,
           -20.27751830331739,
           -20.29883818146817,
           -20.320158059618954,
           -20.341477937769735,
           -20.362797815920523,
           -20.3841176940713,
           -20.405437572222084,
           -20.426757450372868,
           -20.448077328523652,
           -20.469397206674433,
           -20.490717084825217,
           -20.512036962976,
           -20.533356841126782,
           -20.554676719277566,
           -20.57599659742835,
           -20.59731647557913,
           -20.61863635372991,
           -20.639956231880696,
           -20.66127611003148,
           -20.682595988182264,
           -20.70391586633305,
           -20.725235744483825,
           -20.74655562263461,
           -20.767875500785394,
           -20.789195378936178,
           -20.810515257086962,
           -20.831835135237743,
           -20.853155013388523,
           -20.874474891539307,
           -20.89579476969009,
           -20.917114647840876,
           -20.93843452599166,
           -20.959754404142437,
           -20.98107428229322,
           -21.002394160444002,
           -21.02371403859479,
           -21.04503391674557,
           -21.06635379489635,
           -21.08767367304714,
           -21.10899355119792,
           -21.130313429348703,
           -21.151633307499488,
           -21.172953185650268,
           -21.194273063801052,
           -21.215592941951833,
           -21.236912820102617,
           -21.2582326982534,
           -21.279552576404182,
           -21.300872454554966,
           -21.322192332705747,
           -21.34351221085653,
           -21.364832089007315,
           -21.3861519671581,
           -21.40747184530888,
           -21.42879172345966,
           -21.45011160161044,
           -21.47143147976123,
           -21.492751357912013,
           -21.514071236062794,
           -21.537097804462167,
           -21.561831063110137,
           -21.586564321758104,
           -21.611297580406074,
           -21.636030839054044,
           -21.660764097702014,
           -21.68549735634998,
           -21.710230614997954,
           -21.73496387364592,
           -21.759697132293887,
           -21.784430390941857,
           -21.809163649589827,
           -21.833896908237794,
           -21.85863016688576,
           -21.883363425533734,
           -21.9080966841817,
           -21.93282994282967,
           -21.95756320147764,
           -21.982296460125603,
           -22.007029718773573,
           -22.031762977421543,
           -22.056496236069513,
           -22.08122949471748,
           -22.105962753365446,
           -22.13069601201342,
           -22.155429270661386,
           -22.180184783012177,
           -22.20518787275705,
           -22.23019096250193,
           -22.255194052246807,
           -22.28019714199169,
           -22.30520023173657,
           -22.33020332148144,
           -22.355206411226323,
           -22.3802095009712,
           -22.40521259071608,
           -22.430215680460954,
           -22.45521877020584,
           -22.480221859950717,
           -22.505224949695595,
           -22.53022803944047,
           -22.555231129185348,
           -22.580234218930226,
           -22.605237308675107,
           -22.630240398419986,
           -22.655243488164864,
           -22.68024657790974,
           -22.70524966765462,
           -22.730252757399498,
           -22.755255847144376,
           -22.780258936889254,
           -22.805262026634132,
           -22.83026511637901,
           -22.85526820612389,
           -22.880271295868766,
           -22.905274385613644,
           -22.930277475358526,
           -22.9552805651034,
           -22.98028365484828,
           -23.00528674459316,
           -23.03028983433804,
           -23.055292924082913,
           -23.08029601382779,
           -23.105299103572673,
           -23.13030219331755,
           -23.155305283062425,
           -23.180308372807303,
           -23.20531146255219,
           -23.23031455229706,
           -23.255317642041938,
           -23.28032073178682,
           -23.305323821531697,
           -23.33032691127658,
           -23.355330001021457,
           -23.380333090766335,
           -23.405336180511206,
           -23.43033927025609,
           -23.455342360000966,
           -23.48034544974584,
           -23.505348539490726,
           -23.530351629235607,
           -23.555354718980478,
           -23.58035780872536,
           -23.587367017504945,
           -23.558388464353968,
           -23.52940991120299,
           -23.500431358052005,
           -23.471452804901027,
           -23.44247425175005,
           -23.413495698599068,
           -23.384517145448086,
           -23.35553859229711,
           -23.326560039146127,
           -23.297581485995146,
           -23.268602932844168,
           -23.23962437969319,
           -23.21064582654221,
           -23.181667273391227,
           -23.15268872024025,
           -23.123710167089268,
           -23.094731613938286,
           -23.065753060787312,
           -23.036774507636327,
           -23.007795954485346,
           -22.978817401334368,
           -22.949838848183386,
           -22.920860295032405,
           -22.891881741881427,
           -22.86290318873045,
           -22.833924635579468,
           -22.804946082428486,
           -22.77596752927751,
           -22.746988976126527,
           -22.718010422975546,
           -22.68903186982457,
           -22.66005331667359,
           -22.631074763522605,
           -22.602096210371624,
           -22.57311765722065,
           -22.544139104069668,
           -22.515160550918687,
           -22.48618199776771,
           -22.45720344461673,
           -22.428224891465746,
           -22.399246338314768,
           -22.37026778516379,
           -22.341289232012805,
           -22.312310678861827,
           -22.28147241428638,
           -22.243767485618363,
           -22.20606255695035,
           -22.168357628282337,
           -22.130652699614323,
           -22.09294777094631,
           -22.0552428422783,
           -22.017537913610283,
           -21.979832984942266,
           -21.94212805627426,
           -21.904423127606243,
           -21.86671819893823,
           -21.829013270270213,
           -21.791308341602203,
           -21.753603412934186,
           -21.715898484266177,
           -21.678193555598163,
           -21.640488626930146,
           -21.602783698262137,
           -21.565078769594123,
           -21.527373840926106,
           -21.489668912258093,
           -21.451963983590083,
           -21.41425905492207,
           -21.37655412625405,
           -21.338849197586036,
           -21.30114426891803,
           -21.26343934025001,
           -21.225734411582,
           -21.18802948291399,
           -21.15032455424597,
           -21.112619625577956,
           -21.074914696909943,
           -21.03720976824193,
           -20.999504839573916,
           -20.961799910905903,
           -20.92409498223789,
           -20.886390053569873,
           -20.872224955547438,
           -20.975759010752853,
           -21.079293065958268,
           -21.182827121163683,
           -21.286361176369077,
           -21.389895231574496,
           -21.493429286779907,
           -21.596963341985305,
           -21.700497397190716,
           -21.80403145239613,
           -21.90756550760153,
           -22.011099562806947,
           -22.11463361801236,
           -22.218167673217778,
           -22.32170172842317,
           -22.425235783628587,
           -22.528769838834002,
           -22.632303894039396,
           -22.73583794924481,
           -22.839372004450226,
           -22.94290605965562,
           -23.04644011486104,
           -23.14997417006645,
           -23.253508225271844,
           -23.171099890115674,
           -23.0806072919504,
           -22.990114693785124,
           -22.899622095619865,
           -22.809129497454588,
           -22.718636899289308,
           -22.62814430112405,
           -22.537651702958772,
           -22.447159104793496,
           -22.356666506628237,
           -22.26617390846296,
           -22.17568131029768,
           -22.085188712132403,
           -21.994696113967144,
           -21.904203515801868,
           -21.81371091763659,
           -21.723218319471332,
           -21.632725721306056,
           -21.542233123140775,
           -21.451740524975516,
           -21.36124792681024,
           -21.270755328644967,
           -21.180262730479704,
           -21.089770132314428,
           -20.99927753414915,
           -20.908784935983874,
           -20.81829233781861,
           -20.727799739653335,
           -20.63730714148806,
           -20.5468145433228,
           -20.456321945157523,
           -20.365829346992246,
           -20.275336748826984,
           -20.184844150661707,
           -20.09435155249643,
           -20.003858954331154,
           -19.86832279245899,
           -19.561620121003784,
           -19.254917449548575,
           -18.948214778093423,
           -18.641512106638217,
           -18.33480943518301,
           -18.02810676372786,
           -17.721404092272653,
           -17.414701420817444,
           -17.10799874936229,
           -16.801296077907086,
           -16.494593406451877,
           -16.18789073499667,
           -15.881188063541519,
           -15.574485392086313,
           -15.267782720631107,
           -14.961080049175955,
           -14.654377377720746,
           -14.34767470626554,
           -14.040972034810387,
           -13.734269363355182,
           -13.427566691899973,
           -13.120864020444767,
           -12.814161348989614
          ],
          [
           -15.938760175692611,
           -15.957026055046649,
           -15.975291934400687,
           -15.993557813754725,
           -16.011823693108767,
           -16.030089572462803,
           -16.04835545181684,
           -16.06662133117088,
           -16.08661596992291,
           -16.106956362983343,
           -16.12729675604378,
           -16.147637149104213,
           -16.167977542164646,
           -16.188317935225083,
           -16.208658328285516,
           -16.228998721345953,
           -16.249339114406386,
           -16.26967950746682,
           -16.290019900527255,
           -16.31036029358769,
           -16.33070068664812,
           -16.35104107970856,
           -16.37138147276899,
           -16.391721865829425,
           -16.41206225888986,
           -16.432402651950294,
           -16.45274304501073,
           -16.473083438071164,
           -16.4934238311316,
           -16.51376422419203,
           -16.534104617252467,
           -16.554445010312904,
           -16.574785403373337,
           -16.59512579643377,
           -16.615466189494203,
           -16.63580658255464,
           -16.656146975615073,
           -16.67648736867551,
           -16.696827761735946,
           -16.717168154796376,
           -16.737508547856812,
           -16.757848940917242,
           -16.778189333977682,
           -16.798529727038115,
           -16.81887012009855,
           -16.839210513158985,
           -16.859550906219418,
           -16.879891299279855,
           -16.900231692340288,
           -16.92057208540072,
           -16.940912478461158,
           -16.96125287152159,
           -16.981593264582024,
           -17.00193365764246,
           -17.022274050702894,
           -17.042614443763327,
           -17.062954836823764,
           -17.083295229884197,
           -17.10363562294463,
           -17.123976016005066,
           -17.1443164090655,
           -17.164656802125936,
           -17.18499719518637,
           -17.205337588246802,
           -17.225677981307236,
           -17.246018374367672,
           -17.266358767428105,
           -17.286699160488542,
           -17.307039553548975,
           -17.327379946609412,
           -17.347720339669845,
           -17.368060732730278,
           -17.388401125790715,
           -17.408741518851148,
           -17.42908191191158,
           -17.449422304972018,
           -17.46976269803245,
           -17.490103091092884,
           -17.510443484153324,
           -17.530783877213757,
           -17.55112427027419,
           -17.571464663334623,
           -17.59180505639506,
           -17.612145449455497,
           -17.6314261725058,
           -17.650494961554084,
           -17.669563750602364,
           -17.688632539650644,
           -17.707701328698928,
           -17.72677011774721,
           -17.74583890679549,
           -17.764907695843775,
           -17.783976484892055,
           -17.803045273940338,
           -17.822114062988618,
           -17.8411828520369,
           -17.860251641085185,
           -17.879320430133465,
           -17.898389219181748,
           -17.917458008230028,
           -17.93652679727831,
           -17.95559558632659,
           -17.97466437537488,
           -17.993733164423155,
           -18.01280195347144,
           -18.03187074251972,
           -18.050939531568,
           -18.07000832061628,
           -18.089077109664565,
           -18.10814589871285,
           -18.127214687761132,
           -18.146283476809412,
           -18.165352265857692,
           -18.184421054905975,
           -18.20348984395426,
           -18.222558633002542,
           -18.24162742205082,
           -18.260696211099102,
           -18.279765000147385,
           -18.29883378919567,
           -18.317902578243952,
           -18.336971367292232,
           -18.356040156340512,
           -18.375108945388796,
           -18.39417773443708,
           -18.41324652348536,
           -18.432315312533643,
           -18.451384101581926,
           -18.470452890630206,
           -18.48952167967849,
           -18.50859046872677,
           -18.527659257775053,
           -18.546728046823333,
           -18.565796835871616,
           -18.5848656249199,
           -18.60393441396818,
           -18.62300320301646,
           -18.642071992064743,
           -18.661140781113026,
           -18.68020957016131,
           -18.69927835920959,
           -18.71834714825787,
           -18.737415937306153,
           -18.756484726354437,
           -18.775553515402716,
           -18.794622304451,
           -18.813691093499283,
           -18.832759882547563,
           -18.851828671595843,
           -18.870897460644127,
           -18.88996624969241,
           -18.909035038740694,
           -18.928103827788977,
           -18.947172616837257,
           -18.966241405885537,
           -18.98531019493382,
           -19.004378983982104,
           -19.023447773030387,
           -19.042516562078667,
           -19.061585351126947,
           -19.078469801918708,
           -19.09491738812802,
           -19.111364974337338,
           -19.12781256054665,
           -19.144260146755965,
           -19.16070773296528,
           -19.177155319174595,
           -19.195091569165033,
           -19.213772151046033,
           -19.23245273292704,
           -19.25113331480804,
           -19.269813896689044,
           -19.288494478570044,
           -19.307175060451044,
           -19.325855642332048,
           -19.345663737999292,
           -19.366997300498852,
           -19.388330862998405,
           -19.40966442549797,
           -19.43099798799753,
           -19.452331550497085,
           -19.473665112996642,
           -19.494998675496202,
           -19.51633223799576,
           -19.537665800495315,
           -19.558999362994875,
           -19.58033292549443,
           -19.60166648799399,
           -19.62300005049355,
           -19.64433361299311,
           -19.66566717549267,
           -19.68700073799222,
           -19.70833430049178,
           -19.72966786299134,
           -19.751001425490898,
           -19.772334987990458,
           -19.793668550490015,
           -19.815002112989575,
           -19.83633567548913,
           -19.857669237988688,
           -19.879002800488248,
           -19.900336362987808,
           -19.921669925487365,
           -19.943003487986925,
           -19.96433705048648,
           -19.98567061298604,
           -20.007004175485598,
           -20.028337737985154,
           -20.049671300484714,
           -20.071004862984275,
           -20.09233842548383,
           -20.113671987983388,
           -20.13500555048295,
           -20.156339112982504,
           -20.177672675482064,
           -20.19900623798162,
           -20.22033980048118,
           -20.24167336298074,
           -20.263006925480298,
           -20.284340487979854,
           -20.30567405047941,
           -20.327007612978974,
           -20.34834117547853,
           -20.36967473797809,
           -20.391008300477647,
           -20.412341862977208,
           -20.433675425476764,
           -20.45500898797632,
           -20.476342550475877,
           -20.497676112975434,
           -20.519009675474997,
           -20.540343237974554,
           -20.561676800474114,
           -20.583010362973674,
           -20.60434392547323,
           -20.625677487972787,
           -20.647011050472347,
           -20.668344612971907,
           -20.689678175471464,
           -20.711011737971024,
           -20.732345300470577,
           -20.753678862970137,
           -20.775012425469697,
           -20.796345987969254,
           -20.817679550468814,
           -20.83901311296837,
           -20.86034667546793,
           -20.881680237967487,
           -20.903013800467047,
           -20.924347362966603,
           -20.947623302393055,
           -20.972841618746394,
           -20.998059935099732,
           -21.023278251453068,
           -21.04849656780641,
           -21.07371488415975,
           -21.098933200513084,
           -21.124151516866426,
           -21.149369833219765,
           -21.1745881495731,
           -21.19980646592644,
           -21.22502478227978,
           -21.250243098633117,
           -21.275461414986456,
           -21.300679731339798,
           -21.325898047693137,
           -21.351116364046476,
           -21.376334680399815,
           -21.401552996753153,
           -21.426771313106492,
           -21.45198962945983,
           -21.47720794581317,
           -21.50242626216651,
           -21.527644578519848,
           -21.552862894873186,
           -21.578081211226525,
           -21.603299527579864,
           -21.628517843933203,
           -21.65373616028654,
           -21.67895447663988,
           -21.70417279299322,
           -21.72939110934656,
           -21.75441627240922,
           -21.779419362154098,
           -21.80442245189898,
           -21.829425541643854,
           -21.85442863138873,
           -21.879431721133614,
           -21.90443481087849,
           -21.92943790062337,
           -21.954440990368248,
           -21.979444080113126,
           -22.004447169858,
           -22.029450259602882,
           -22.05445334934776,
           -22.079456439092638,
           -22.104459528837516,
           -22.129462618582394,
           -22.154465708327272,
           -22.17946879807215,
           -22.204471887817032,
           -22.22947497756191,
           -22.254478067306785,
           -22.279481157051666,
           -22.304484246796545,
           -22.32948733654142,
           -22.354490426286297,
           -22.37949351603118,
           -22.404496605776057,
           -22.429499695520935,
           -22.454502785265813,
           -22.479505875010688,
           -22.504508964755566,
           -22.529512054500447,
           -22.554515144245325,
           -22.579518233990203,
           -22.60452132373508,
           -22.629524413479963,
           -22.654527503224838,
           -22.679530592969716,
           -22.704533682714597,
           -22.729536772459475,
           -22.754539862204354,
           -22.77954295194923,
           -22.804546041694106,
           -22.829549131438984,
           -22.854552221183866,
           -22.87955531092874,
           -22.904558400673622,
           -22.929561490418504,
           -22.95456458016338,
           -22.979567669908256,
           -23.004570759653134,
           -23.01157996843272,
           -22.982601415281742,
           -22.95362286213076,
           -22.92464430897978,
           -22.895665755828805,
           -22.866687202677824,
           -22.837708649526842,
           -22.80873009637586,
           -22.779751543224886,
           -22.7507729900739,
           -22.721794436922924,
           -22.692815883771942,
           -22.663837330620964,
           -22.63485877746998,
           -22.605880224319005,
           -22.576901671168024,
           -22.547923118017042,
           -22.518944564866064,
           -22.489966011715087,
           -22.460987458564105,
           -22.43200890541312,
           -22.403030352262142,
           -22.374051799111164,
           -22.345073245960183,
           -22.3160946928092,
           -22.287116139658224,
           -22.258137586507246,
           -22.229159033356268,
           -22.200180480205287,
           -22.171201927054305,
           -22.14222337390332,
           -22.113244820752346,
           -22.084266267601365,
           -22.05528771445038,
           -22.0263091612994,
           -21.997330608148424,
           -21.968352054997442,
           -21.939373501846468,
           -21.910394948695483,
           -21.881416395544505,
           -21.85243784239352,
           -21.823459289242546,
           -21.794480736091565,
           -21.76550218294058,
           -21.736523629789602,
           -21.707545076638624,
           -21.678566523487643,
           -21.64958797033666,
           -21.620609417185683,
           -21.591630864034705,
           -21.562652310883724,
           -21.533673757732746,
           -21.504695204581765,
           -21.475716651430783,
           -21.44673809827981,
           -21.417759545128824,
           -21.388780991977846,
           -21.359802438826865,
           -21.330823885675887,
           -21.301845332524902,
           -21.272866779373924,
           -21.243888226222946,
           -21.21490967307196,
           -21.185931119920987,
           -21.156952566770006,
           -21.127974013619028,
           -21.09899546046804,
           -21.070016907317072,
           -21.041038354166083,
           -21.012059801015102,
           -20.983081247864128,
           -20.954102694713146,
           -20.925124141562165,
           -20.896145588411184,
           -20.867167035260206,
           -20.838188482109224,
           -20.80828008433995,
           -20.77057515567194,
           -20.732870227003925,
           -20.695165298335912,
           -20.6574603696679,
           -20.619755440999885,
           -20.582050512331868,
           -20.567885414309433,
           -20.671419469514845,
           -20.77495352472026,
           -20.878487579925675,
           -20.982021635131073,
           -20.9044639294926,
           -20.813971331327323,
           -20.72347873316206,
           -20.632986134996784,
           -20.54249353683151,
           -20.45200093866625,
           -20.361508340500972,
           -20.271015742335695,
           -20.180523144170422,
           -20.09003054600516,
           -19.999537947839883,
           -19.909045349674606,
           -19.818552751509344,
           -19.728060153344067,
           -19.63756755517879,
           -19.54707495701353,
           -19.45658235884825,
           -19.36608976068298,
           -19.275597162517716,
           -19.18510456435244,
           -19.094611966187163,
           -19.004119368021886,
           -18.913626769856627,
           -18.82313417169135,
           -18.732641573526074,
           -18.64214897536081,
           -18.551656377195535,
           -18.461163779030258,
           -18.370671180865,
           -18.28017858269972,
           -18.189685984534446,
           -18.099193386369166,
           -18.008700788203907,
           -17.91820819003863,
           -17.827715591873353,
           -17.737222993708095,
           -17.646730395542818,
           -17.55623779737754,
           -17.46574519921228,
           -17.375252601047002,
           -17.284760002881725,
           -17.194267404716467,
           -17.103774806551186,
           -17.013282208385913,
           -16.922789610220633,
           -16.83229701205537,
           -16.741804413890097,
           -16.651311815724817,
           -16.56081921755956,
           -16.470326619394285,
           -16.37983402122901,
           -16.289341423063746,
           -16.19884882489847,
           -16.108356226733193,
           -16.017863628567916,
           -15.927371030402657,
           -15.836878432237379,
           -15.746385834072104,
           -15.655893235906841,
           -15.565400637741565,
           -15.474908039576288,
           -15.384415441411027,
           -15.29392284324575,
           -15.203430245080472,
           -15.112937646915213,
           -15.022445048749937,
           -14.93195245058466,
           -14.841459852419383,
           -14.750967254254121,
           -14.660474656088846,
           -14.569982057923568,
           -14.479489459758309,
           -14.388996861593032,
           -14.298504263427755,
           -14.157562890749219,
           -13.85086021929401,
           -13.544157547838802,
           -13.237454876383595,
           -12.930752204928444
          ],
          [
           -15.469849553863886,
           -15.488115433217924,
           -15.50638131257196,
           -15.524647191925999,
           -15.542913071280038,
           -15.561178950634076,
           -15.579444829988113,
           -15.59771070934215,
           -15.61597658869619,
           -15.634242468050228,
           -15.652508347404266,
           -15.670774226758304,
           -15.689040106112342,
           -15.70730598546638,
           -15.725571864820418,
           -15.743837744174456,
           -15.762103623528494,
           -15.780369502882532,
           -15.798635382236569,
           -15.816901261590608,
           -15.835167140944645,
           -15.853433020298684,
           -15.87169889965272,
           -15.88996477900676,
           -15.908922160563298,
           -15.92926255362373,
           -15.949602946684166,
           -15.969943339744601,
           -15.990283732805032,
           -16.01062412586547,
           -16.030964518925902,
           -16.051304911986335,
           -16.071645305046772,
           -16.091985698107205,
           -16.112326091167642,
           -16.132666484228075,
           -16.153006877288508,
           -16.17334727034895,
           -16.193687663409378,
           -16.214028056469814,
           -16.234368449530248,
           -16.25470884259068,
           -16.275049235651117,
           -16.295389628711554,
           -16.315730021771984,
           -16.33607041483242,
           -16.356410807892853,
           -16.37675120095329,
           -16.397091594013723,
           -16.41743198707416,
           -16.437772380134593,
           -16.458112773195026,
           -16.478453166255463,
           -16.498793559315896,
           -16.51913395237633,
           -16.539474345436766,
           -16.5598147384972,
           -16.580155131557632,
           -16.60049552461807,
           -16.6208359176785,
           -16.641176310738935,
           -16.66151670379937,
           -16.681857096859808,
           -16.70219748992024,
           -16.722537882980674,
           -16.742878276041107,
           -16.76321866910154,
           -16.783559062161977,
           -16.803899455222414,
           -16.824239848282847,
           -16.84458024134328,
           -16.864920634403713,
           -16.88526102746415,
           -16.905601420524583,
           -16.92594181358502,
           -16.946282206645453,
           -16.966622599705886,
           -16.986962992766323,
           -17.007303385826756,
           -17.027643778887192,
           -17.047984171947625,
           -17.06832456500806,
           -17.088664958068495,
           -17.10900535112893,
           -17.128286074179236,
           -17.14735486322752,
           -17.1664236522758,
           -17.18549244132408,
           -17.204561230372363,
           -17.223630019420646,
           -17.242698808468926,
           -17.26176759751721,
           -17.28083638656549,
           -17.299905175613773,
           -17.318973964662057,
           -17.338042753710337,
           -17.35711154275862,
           -17.3761803318069,
           -17.395249120855183,
           -17.414317909903467,
           -17.433386698951747,
           -17.45245548800003,
           -17.47152427704831,
           -17.490593066096594,
           -17.509661855144877,
           -17.528730644193157,
           -17.547799433241437,
           -17.56686822228972,
           -17.585937011338004,
           -17.605005800386287,
           -17.624074589434567,
           -17.643143378482847,
           -17.66221216753113,
           -17.681280956579414,
           -17.700349745627694,
           -17.719418534675977,
           -17.738487323724257,
           -17.75755611277254,
           -17.776624901820824,
           -17.795693690869104,
           -17.814762479917388,
           -17.833831268965668,
           -17.85290005801395,
           -17.871968847062234,
           -17.891037636110514,
           -17.910106425158798,
           -17.929175214207078,
           -17.94824400325536,
           -17.967312792303645,
           -17.986381581351925,
           -18.005450370400208,
           -18.024519159448488,
           -18.043587948496768,
           -18.062656737545055,
           -18.081725526593335,
           -18.10079431564162,
           -18.119863104689898,
           -18.138931893738178,
           -18.158000682786465,
           -18.177069471834745,
           -18.196138260883025,
           -18.21520704993131,
           -18.23427583897959,
           -18.252470890758335,
           -18.26891847696765,
           -18.285366063176966,
           -18.30181364938628,
           -18.318261235595592,
           -18.33470882180491,
           -18.351156408014226,
           -18.367603994223536,
           -18.384051580432853,
           -18.400499166642167,
           -18.41694675285148,
           -18.433394339060797,
           -18.44984192527011,
           -18.466289511479424,
           -18.48273709768874,
           -18.499184683898054,
           -18.515632270107368,
           -18.532079856316685,
           -18.548527442525998,
           -18.56497502873531,
           -18.58142261494463,
           -18.597870201153942,
           -18.614317787363255,
           -18.630765373572572,
           -18.648701623563014,
           -18.667382205444014,
           -18.686062787325014,
           -18.704743369206017,
           -18.723423951087018,
           -18.74210453296802,
           -18.76078511484902,
           -18.779465696730025,
           -18.798146278611025,
           -18.81682686049203,
           -18.83550744237303,
           -18.854188024254032,
           -18.872868606135036,
           -18.891549188016036,
           -18.910229769897033,
           -18.92891035177804,
           -18.947590933659043,
           -18.966271515540043,
           -18.984952097421044,
           -19.003632679302044,
           -19.02231326118305,
           -19.04099384306405,
           -19.05967442494505,
           -19.07835500682605,
           -19.097035588707055,
           -19.115716170588055,
           -19.13439675246906,
           -19.154271172148363,
           -19.175604734647923,
           -19.19693829714748,
           -19.21827185964704,
           -19.2396054221466,
           -19.260938984646153,
           -19.282272547145713,
           -19.303606109645273,
           -19.324939672144833,
           -19.34627323464439,
           -19.36760679714395,
           -19.388940359643506,
           -19.410273922143062,
           -19.431607484642623,
           -19.45294104714218,
           -19.474274609641736,
           -19.495608172141296,
           -19.516941734640856,
           -19.538275297140416,
           -19.55960885963997,
           -19.58094242213953,
           -19.602275984639093,
           -19.623609547138646,
           -19.644943109638206,
           -19.666276672137766,
           -19.68761023463732,
           -19.70894379713688,
           -19.73027735963644,
           -19.751610922135995,
           -19.772944484635556,
           -19.79427804713511,
           -19.815611609634672,
           -19.83694517213423,
           -19.858278734633785,
           -19.879612297133345,
           -19.900945859632905,
           -19.922279422132462,
           -19.94361298463202,
           -19.96494654713158,
           -19.98628010963114,
           -20.007613672130695,
           -20.02894723463025,
           -20.050280797129812,
           -20.071614359629372,
           -20.09294792212893,
           -20.114281484628485,
           -20.135615047128045,
           -20.1569486096276,
           -20.17828217212716,
           -20.199615734626718,
           -20.22094929712628,
           -20.242282859625835,
           -20.263616422125395,
           -20.284949984624955,
           -20.30628354712451,
           -20.327617109624068,
           -20.350893049050516,
           -20.376111365403858,
           -20.401329681757197,
           -20.426547998110536,
           -20.45176631446387,
           -20.476984630817213,
           -20.50220294717055,
           -20.52742126352389,
           -20.55263957987723,
           -20.577857896230565,
           -20.603076212583908,
           -20.628294528937246,
           -20.653512845290585,
           -20.678731161643924,
           -20.703949477997263,
           -20.7291677943506,
           -20.75438611070394,
           -20.77960442705728,
           -20.804822743410618,
           -20.830041059763957,
           -20.855259376117296,
           -20.880477692470638,
           -20.905696008823973,
           -20.930914325177312,
           -20.95613264153065,
           -20.98135095788399,
           -21.00656927423733,
           -21.031787590590667,
           -21.057005906944006,
           -21.082224223297345,
           -21.107442539650684,
           -21.132660856004026,
           -21.15787917235736,
           -21.1830974887107,
           -21.208315805064043,
           -21.233534121417378,
           -21.258752437770717,
           -21.283970754124056,
           -21.309189070477395,
           -21.334407386830733,
           -21.359625703184072,
           -21.38484401953741,
           -21.41006233589075,
           -21.43528065224409,
           -21.460498968597427,
           -21.485717284950766,
           -21.51093560130411,
           -21.536153917657447,
           -21.561372234010786,
           -21.58659055036412,
           -21.611808866717464,
           -21.6370271830708,
           -21.662245499424138,
           -21.687463815777477,
           -21.71268213213082,
           -21.737900448484158,
           -21.763118764837497,
           -21.78833708119084,
           -21.813555397544174,
           -21.838773713897513,
           -21.863992030250852,
           -21.88921034660419,
           -21.91442866295753,
           -21.939646979310865,
           -21.964865295664204,
           -21.990083612017543,
           -22.01530192837088,
           -22.040520244724224,
           -22.065738561077563,
           -22.090956877430905,
           -22.116175193784244,
           -22.14139351013758,
           -22.165703397466416,
           -22.189740754476578,
           -22.213778111486736,
           -22.237815468496894,
           -22.261852825507056,
           -22.285890182517214,
           -22.309927539527376,
           -22.333964896537537,
           -22.358002253547696,
           -22.382039610557857,
           -22.406076967568016,
           -22.415727577404635,
           -22.39660469289418,
           -22.377481808383724,
           -22.35835892387327,
           -22.339236039362817,
           -22.32011315485236,
           -22.300990270341906,
           -22.281867385831454,
           -22.262744501321002,
           -22.243621616810547,
           -22.22449873230009,
           -22.20537584778964,
           -22.186252963279184,
           -22.167130078768732,
           -22.148007194258273,
           -22.12888430974782,
           -22.10121546831654,
           -22.073134784896673,
           -22.045054101476808,
           -22.016973418056946,
           -21.98889273463708,
           -21.960812051217218,
           -21.932731367797356,
           -21.904650684377486,
           -21.87657000095762,
           -21.84848931753776,
           -21.820408634117893,
           -21.792327950698027,
           -21.764247267278165,
           -21.7361665838583,
           -21.708085900438434,
           -21.68000521701857,
           -21.651924533598706,
           -21.623843850178844,
           -21.595763166758978,
           -21.567682483339112,
           -21.539601799919247,
           -21.51152111649938,
           -21.48344043307952,
           -21.455359749659657,
           -21.42727906623979,
           -21.399198382819925,
           -21.37111769940006,
           -21.343037015980194,
           -21.314956332560328,
           -21.286875649140466,
           -21.2587949657206,
           -21.230714282300738,
           -21.202633598880873,
           -21.174552915461007,
           -21.14647223204114,
           -21.11839154862128,
           -21.090310865201413,
           -21.06223018178155,
           -21.034149498361685,
           -21.00606881494182,
           -20.977988131521954,
           -20.94990744810209,
           -20.92182676468223,
           -20.89374608126236,
           -20.8656653978425,
           -20.837584714422633,
           -20.809504031002767,
           -20.781423347582905,
           -20.753342664163043,
           -20.725261980743177,
           -20.69718129732331,
           -20.669100613903446,
           -20.641019930483584,
           -20.612939247063714,
           -20.584858563643852,
           -20.55677788022399,
           -20.528697196804124,
           -20.50061651338426,
           -20.472535829964393,
           -20.44445514654453,
           -20.416374463124665,
           -20.388293779704803,
           -20.360213096284937,
           -20.33213241286507,
           -20.304051729445206,
           -20.27597104602534,
           -20.247890362605474,
           -20.244917943815924,
           -20.367486848177915,
           -20.490055752539906,
           -20.6126246569019,
           -20.735193561263866,
           -20.857762465625857,
           -20.980331369987844,
           -21.102900274349814,
           -21.22546917871181,
           -21.3480380830738,
           -21.47060698743577,
           -21.59317589179776,
           -21.715744796159747,
           -21.838313700521738,
           -21.960882604883707,
           -22.083451509245698,
           -22.20602041360769,
           -22.32858931796966,
           -22.45115822233165,
           -22.57372712669364,
           -22.696296031055606,
           -22.8188649354176,
           -22.94143383977959,
           -23.064002744141558,
           -23.186571648503552,
           -23.309140552865536,
           -23.43170945722753,
           -23.554278361589503,
           -23.67684726595149,
           -23.799416170313478,
           -23.921985074675447,
           -24.044553979037442,
           -24.167122883399433,
           -24.2896917877614,
           -24.41226069212339,
           -24.53482959648538,
           -24.65739850084737,
           -24.779967405209337,
           -24.90343179748949,
           -25.028473200682598,
           -25.153514603875692,
           -25.278556007068804,
           -25.16923900868295,
           -24.892523152026534,
           -24.615807295370065,
           -24.33909143871359,
           -24.045500579162535,
           -23.747808627936283,
           -23.450116676710028,
           -23.152424725483773,
           -22.85473277425757,
           -22.557040823031315,
           -22.259348871805063,
           -21.96165692057886,
           -21.663964969352605,
           -21.36627301812635,
           -21.068581066900148,
           -20.770889115673896,
           -20.47319716444764,
           -20.175505213221385,
           -19.877813261995183,
           -19.580121310768927,
           -19.28242935954267,
           -18.98473740831647,
           -18.687045457090214,
           -18.38935350586396,
           -18.09166155463776,
           -17.793969603411504,
           -17.49627765218525,
           -17.19858570095905,
           -16.900893749732795,
           -16.60320179850654,
           -16.305509847280284,
           -16.007817896054085,
           -15.71012594482783,
           -15.41243399360157,
           -15.114742042375372,
           -14.817050091149117,
           -14.519358139922863,
           -14.221666188696663,
           -13.923974237470407,
           -13.626282286244148,
           -13.328590335017894,
           -13.030898383791694
          ],
          [
           -15.000938932035158,
           -15.019204811389198,
           -15.037470690743234,
           -15.055736570097274,
           -15.07400244945131,
           -15.09226832880535,
           -15.110534208159386,
           -15.128800087513426,
           -15.147065966867462,
           -15.165331846221502,
           -15.183597725575538,
           -15.201863604929576,
           -15.220129484283614,
           -15.238395363637654,
           -15.256661242991692,
           -15.274927122345728,
           -15.293193001699766,
           -15.311458881053804,
           -15.329724760407842,
           -15.34799063976188,
           -15.366256519115918,
           -15.384522398469956,
           -15.402788277823994,
           -15.421054157178032,
           -15.43932003653207,
           -15.457585915886108,
           -15.475851795240146,
           -15.494117674594182,
           -15.512383553948222,
           -15.530649433302258,
           -15.548915312656298,
           -15.567181192010334,
           -15.585447071364374,
           -15.60371295071841,
           -15.62197883007245,
           -15.640244709426486,
           -15.658510588780526,
           -15.676776468134562,
           -15.6950423474886,
           -15.713308226842639,
           -15.731574106196678,
           -15.75156874426412,
           -15.771909137324554,
           -15.79224953038499,
           -15.812589923445422,
           -15.832930316505855,
           -15.853270709566292,
           -15.873611102626725,
           -15.893951495687158,
           -15.914291888747595,
           -15.934632281808028,
           -15.954972674868465,
           -15.975313067928898,
           -15.995653460989331,
           -16.015993854049768,
           -16.0363342471102,
           -16.056674640170638,
           -16.07701503323107,
           -16.097355426291504,
           -16.117695819351937,
           -16.138036212412374,
           -16.15837660547281,
           -16.178716998533243,
           -16.199057391593676,
           -16.21939778465411,
           -16.239738177714546,
           -16.26007857077498,
           -16.280418963835416,
           -16.30075935689585,
           -16.321099749956282,
           -16.34144014301672,
           -16.361780536077152,
           -16.38212092913759,
           -16.40246132219802,
           -16.422801715258455,
           -16.44314210831889,
           -16.463482501379325,
           -16.48382289443976,
           -16.504163287500194,
           -16.524503680560628,
           -16.544844073621064,
           -16.565184466681494,
           -16.58552485974193,
           -16.605865252802367,
           -16.62514597585267,
           -16.644214764900955,
           -16.663283553949235,
           -16.68235234299752,
           -16.7014211320458,
           -16.72048992109408,
           -16.739558710142365,
           -16.758627499190645,
           -16.77769628823893,
           -16.796765077287212,
           -16.815833866335492,
           -16.83490265538377,
           -16.85397144443206,
           -16.87304023348034,
           -16.892109022528622,
           -16.911177811576902,
           -16.930246600625185,
           -16.94931538967347,
           -16.96838417872175,
           -16.987452967770032,
           -17.006521756818312,
           -17.025590545866592,
           -17.044659334914876,
           -17.06372812396316,
           -17.08279691301144,
           -17.101865702059722,
           -17.120934491108002,
           -17.140003280156286,
           -17.15907206920457,
           -17.17814085825285,
           -17.197209647301133,
           -17.216278436349416,
           -17.235347225397696,
           -17.254416014445976,
           -17.27348480349426,
           -17.29255359254254,
           -17.311622381590826,
           -17.330691170639106,
           -17.349759959687386,
           -17.368828748735673,
           -17.38789753778395,
           -17.406966326832233,
           -17.426035115880513,
           -17.44291956580728,
           -17.45936715201659,
           -17.47581473822591,
           -17.492262324435224,
           -17.508709910644537,
           -17.525157496853854,
           -17.541605083063168,
           -17.55805266927248,
           -17.574500255481798,
           -17.59094784169111,
           -17.607395427900425,
           -17.623843014109738,
           -17.64029060031905,
           -17.65673818652837,
           -17.673185772737682,
           -17.689633358947,
           -17.706080945156312,
           -17.722528531365626,
           -17.738976117574943,
           -17.755423703784256,
           -17.77187128999357,
           -17.788318876202887,
           -17.804766462412204,
           -17.821214048621513,
           -17.83766163483083,
           -17.85410922104014,
           -17.870556807249457,
           -17.88700439345877,
           -17.903451979668084,
           -17.9198995658774,
           -17.936347152086718,
           -17.952794738296028,
           -17.969242324505345,
           -17.98568991071466,
           -18.002137496923975,
           -18.01858508313329,
           -18.035032669342602,
           -18.05148025555192,
           -18.067927841761232,
           -18.084375427970546,
           -18.102311677960987,
           -18.120992259841987,
           -18.13967284172299,
           -18.15835342360399,
           -18.17703400548499,
           -18.195714587365995,
           -18.214395169247,
           -18.233075751128,
           -18.251756333009002,
           -18.270436914890002,
           -18.289117496771006,
           -18.307798078652006,
           -18.32647866053301,
           -18.34515924241401,
           -18.363839824295013,
           -18.382520406176013,
           -18.401200988057013,
           -18.419881569938017,
           -18.43856215181902,
           -18.45724273370002,
           -18.47592331558102,
           -18.494603897462024,
           -18.513284479343024,
           -18.53196506122403,
           -18.55064564310503,
           -18.569326224986032,
           -18.588006806867035,
           -18.606687388748036,
           -18.62536797062904,
           -18.64404855251004,
           -18.662729134391043,
           -18.681409716272046,
           -18.700090298153047,
           -18.718770880034047,
           -18.737451461915047,
           -18.75613204379605,
           -18.77481262567705,
           -18.793493207558054,
           -18.81217378943906,
           -18.830854371320058,
           -18.849534953201058,
           -18.868215535082065,
           -18.886896116963065,
           -18.90557669884407,
           -18.92425728072507,
           -18.94293786260607,
           -18.96287860629744,
           -18.984212168796994,
           -19.005545731296554,
           -19.026879293796114,
           -19.04821285629567,
           -19.069546418795227,
           -19.090879981294787,
           -19.112213543794343,
           -19.133547106293904,
           -19.15488066879346,
           -19.176214231293017,
           -19.197547793792577,
           -19.218881356292137,
           -19.240214918791693,
           -19.261548481291253,
           -19.28288204379081,
           -19.30421560629037,
           -19.325549168789927,
           -19.346882731289487,
           -19.368216293789043,
           -19.389549856288603,
           -19.41088341878816,
           -19.43221698128772,
           -19.45355054378728,
           -19.474884106286837,
           -19.496217668786393,
           -19.517551231285953,
           -19.53888479378551,
           -19.56021835628507,
           -19.581551918784626,
           -19.602885481284186,
           -19.624219043783743,
           -19.645552606283303,
           -19.66688616878286,
           -19.68821973128242,
           -19.709553293781976,
           -19.730886856281536,
           -19.754162795707984,
           -19.779381112061323,
           -19.80459942841466,
           -19.829817744768,
           -19.85503606112134,
           -19.880254377474678,
           -19.905472693828017,
           -19.930691010181356,
           -19.955909326534695,
           -19.98112764288803,
           -20.006345959241372,
           -20.03156427559471,
           -20.05678259194805,
           -20.08200090830139,
           -20.107219224654727,
           -20.132437541008066,
           -20.157655857361405,
           -20.182874173714744,
           -20.208092490068083,
           -20.23331080642142,
           -20.25852912277476,
           -20.283747439128103,
           -20.308965755481438,
           -20.334184071834777,
           -20.35940238818812,
           -20.384620704541454,
           -20.409839020894793,
           -20.435057337248132,
           -20.46027565360147,
           -20.485493969954813,
           -20.510712286308152,
           -20.53593060266149,
           -20.561148919014826,
           -20.58636723536817,
           -20.611585551721507,
           -20.636803868074846,
           -20.66202218442818,
           -20.687240500781524,
           -20.712458817134863,
           -20.7376771334882,
           -20.762895449841537,
           -20.788113766194876,
           -20.813332082548214,
           -20.838550398901557,
           -20.863768715254896,
           -20.88898703160823,
           -20.91420534796157,
           -20.939310110390192,
           -20.96334746740035,
           -20.987384824410512,
           -21.01142218142067,
           -21.03545953843083,
           -21.059496895440986,
           -21.083534252451148,
           -21.10757160946131,
           -21.131608966471468,
           -21.155646323481626,
           -21.17968368049179,
           -21.203721037501946,
           -21.227758394512108,
           -21.25179575152227,
           -21.275833108532428,
           -21.299870465542583,
           -21.323907822552748,
           -21.347945179562906,
           -21.371982536573064,
           -21.396019893583222,
           -21.420057250593388,
           -21.444094607603546,
           -21.468131964613704,
           -21.492169321623866,
           -21.516206678634024,
           -21.540244035644186,
           -21.564281392654344,
           -21.588318749664502,
           -21.61235610667466,
           -21.636393463684826,
           -21.660430820694984,
           -21.684468177705142,
           -21.708505534715304,
           -21.732542891725465,
           -21.756580248735624,
           -21.780617605745782,
           -21.7902682155824,
           -21.77114533107195,
           -21.752022446561494,
           -21.73289956205104,
           -21.713776677540586,
           -21.69465379303013,
           -21.675530908519676,
           -21.65640802400922,
           -21.637285139498772,
           -21.618162254988313,
           -21.599039370477858,
           -21.579916485967406,
           -21.56079360145695,
           -21.541670716946495,
           -21.522547832436043,
           -21.50342494792559,
           -21.484302063415136,
           -21.46517917890468,
           -21.44605629439423,
           -21.426933409883773,
           -21.407810525373318,
           -21.388687640862866,
           -21.369564756352407,
           -21.35044187184195,
           -21.3313189873315,
           -21.312196102821048,
           -21.293073218310592,
           -21.273950333800137,
           -21.254827449289685,
           -21.235704564779226,
           -21.216581680268774,
           -21.197458795758322,
           -21.178335911247867,
           -21.15921302673741,
           -21.140090142226956,
           -21.120967257716504,
           -21.10184437320605,
           -21.082721488695594,
           -21.06359860418514,
           -21.044475719674686,
           -21.025352835164234,
           -21.006229950653783,
           -20.987107066143327,
           -20.96798418163287,
           -20.948861297122416,
           -20.929738412611965,
           -20.910615528101506,
           -20.891492643591054,
           -20.870233279661498,
           -20.842152596241633,
           -20.814071912821767,
           -20.785991229401905,
           -20.75791054598204,
           -20.729829862562173,
           -20.70174917914231,
           -20.673668495722445,
           -20.64558781230258,
           -20.617507128882714,
           -20.589426445462852,
           -20.561345762042986,
           -20.533265078623124,
           -20.50518439520326,
           -20.477103711783393,
           -20.44902302836353,
           -20.420942344943665,
           -20.392861661523803,
           -20.364780978103934,
           -20.33670029468407,
           -20.30861961126421,
           -20.28053892784434,
           -20.252458244424478,
           -20.224377561004616,
           -20.19629687758475,
           -20.16821619416488,
           -20.14013551074502,
           -20.112054827325156,
           -20.083974143905287,
           -20.05589346048543,
           -20.027812777065563,
           -19.999732093645694,
           -19.971651410225828,
           -19.943570726805966,
           -19.915490043386104,
           -19.91251762459655,
           -20.03508652895854,
           -20.15765543332053,
           -20.280224337682522,
           -20.40279324204449,
           -20.525362146406483,
           -20.647931050768474,
           -20.770499955130443,
           -20.89306885949243,
           -21.01563776385442,
           -21.13820666821639,
           -21.260775572578382,
           -21.383344476940373,
           -21.505913381302364,
           -21.628482285664333,
           -21.751051190026324,
           -21.873620094388315,
           -21.996188998750284,
           -22.118757903112275,
           -22.241326807474266,
           -22.365397439617364,
           -22.49043884281048,
           -22.615480246003596,
           -22.740521649196687,
           -22.865563052389795,
           -22.990604455582908,
           -23.11564585877602,
           -23.240687261969107,
           -23.365728665162216,
           -23.49077006835533,
           -23.615811471548422,
           -23.740852874741538,
           -23.86589427793465,
           -23.99093568112774,
           -24.115977084320853,
           -24.241018487513962,
           -24.366059890707074,
           -24.491101293900165,
           -24.61614269709328,
           -24.74118410028639,
           -24.86622550347948,
           -24.991266906672593,
           -24.881949908286746,
           -24.605234051630326,
           -24.328518194973853,
           -24.05180233831738,
           -23.775086481660963,
           -23.49837062500449,
           -23.221654768348017,
           -22.94493891169155,
           -22.66822305503513,
           -22.391507198378655,
           -22.114791341722185,
           -21.838075485065765,
           -21.561359628409292,
           -21.28464377175282,
           -21.007927915096403,
           -20.731212058439933,
           -20.45449620178346,
           -20.17778034512699,
           -19.901064488470567,
           -19.624348631814097,
           -19.347632775157628,
           -19.070916918501208,
           -18.782469254383695,
           -18.48477730315744,
           -18.18708535193124,
           -17.889393400704982,
           -17.591701449478727,
           -17.294009498252528,
           -16.996317547026273,
           -16.698625595800017,
           -16.40093364457376,
           -16.103241693347563,
           -15.805549742121308,
           -15.50785779089505,
           -15.210165839668852,
           -14.912473888442594,
           -14.614781937216339,
           -14.31708998599014,
           -14.019398034763885,
           -13.72170608353763,
           -13.424014132311374,
           -13.126322181085174
          ],
          [
           -14.532028310206432,
           -14.550294189560471,
           -14.568560068914508,
           -14.586825948268547,
           -14.605091827622584,
           -14.623357706976623,
           -14.64162358633066,
           -14.6598894656847,
           -14.678155345038736,
           -14.696421224392775,
           -14.714687103746812,
           -14.732952983100851,
           -14.751218862454888,
           -14.769484741808927,
           -14.787750621162964,
           -14.806016500517003,
           -14.82428237987104,
           -14.84254825922508,
           -14.860814138579116,
           -14.879080017933155,
           -14.897345897287192,
           -14.915611776641232,
           -14.933877655995266,
           -14.952143535349308,
           -14.970409414703342,
           -14.98867529405738,
           -15.00694117341142,
           -15.025207052765456,
           -15.043472932119496,
           -15.061738811473532,
           -15.080004690827572,
           -15.09827057018161,
           -15.116536449535646,
           -15.134802328889686,
           -15.153068208243724,
           -15.17133408759776,
           -15.1895999669518,
           -15.207865846305836,
           -15.226131725659876,
           -15.244397605013912,
           -15.262663484367952,
           -15.280929363721988,
           -15.299195243076028,
           -15.317461122430064,
           -15.335727001784104,
           -15.35399288113814,
           -15.372258760492176,
           -15.390524639846216,
           -15.408790519200252,
           -15.427056398554292,
           -15.445322277908328,
           -15.463588157262368,
           -15.481854036616408,
           -15.500119915970444,
           -15.51838579532448,
           -15.53665167467852,
           -15.55491755403256,
           -15.573874934904508,
           -15.594215327964942,
           -15.614555721025376,
           -15.63489611408581,
           -15.655236507146245,
           -15.67557690020668,
           -15.695917293267113,
           -15.716257686327548,
           -15.736598079387983,
           -15.756938472448415,
           -15.777278865508851,
           -15.797619258569286,
           -15.817959651629721,
           -15.838300044690154,
           -15.858640437750587,
           -15.878980830811024,
           -15.899321223871459,
           -15.919661616931892,
           -15.940002009992327,
           -15.96034240305276,
           -15.980682796113195,
           -16.00102318917363,
           -16.021363582234066,
           -16.0417039752945,
           -16.062044368354933,
           -16.08238476141537,
           -16.102725154475802,
           -16.12200587752611,
           -16.14107466657439,
           -16.160143455622674,
           -16.179212244670957,
           -16.198281033719237,
           -16.217349822767517,
           -16.2364186118158,
           -16.255487400864084,
           -16.274556189912364,
           -16.293624978960647,
           -16.312693768008927,
           -16.33176255705721,
           -16.350831346105494,
           -16.369900135153774,
           -16.38896892420206,
           -16.408037713250337,
           -16.42710650229862,
           -16.446175291346904,
           -16.465244080395184,
           -16.484312869443468,
           -16.50338165849175,
           -16.52245044754003,
           -16.541519236588314,
           -16.560588025636594,
           -16.579656814684878,
           -16.59872560373316,
           -16.616920654646904,
           -16.63336824085622,
           -16.649815827065538,
           -16.66626341327485,
           -16.682710999484165,
           -16.69915858569348,
           -16.715606171902795,
           -16.73205375811211,
           -16.748501344321422,
           -16.76494893053074,
           -16.781396516740053,
           -16.79784410294937,
           -16.814291689158683,
           -16.830739275367996,
           -16.847186861577313,
           -16.863634447786627,
           -16.88008203399594,
           -16.896529620205257,
           -16.912977206414567,
           -16.929424792623884,
           -16.9458723788332,
           -16.962319965042514,
           -16.978767551251828,
           -16.99521513746114,
           -17.011662723670458,
           -17.02811030987977,
           -17.044557896089085,
           -17.0610054822984,
           -17.077453068507715,
           -17.093900654717032,
           -17.110348240926342,
           -17.12679582713566,
           -17.143243413344972,
           -17.159690999554286,
           -17.176138585763603,
           -17.192586171972916,
           -17.209033758182233,
           -17.225481344391547,
           -17.24192893060086,
           -17.258376516810173,
           -17.27482410301949,
           -17.291271689228807,
           -17.307719275438117,
           -17.324166861647434,
           -17.340614447856748,
           -17.35706203406606,
           -17.373509620275378,
           -17.38995720648469,
           -17.406404792694005,
           -17.422852378903322,
           -17.439299965112635,
           -17.45574755132195,
           -17.472195137531266,
           -17.48864272374058,
           -17.505090309949892,
           -17.52153789615921,
           -17.53798548236852,
           -17.55592173235896,
           -17.57460231423996,
           -17.593282896120968,
           -17.611963478001968,
           -17.630644059882968,
           -17.64932464176397,
           -17.668005223644972,
           -17.686685805525975,
           -17.70536638740698,
           -17.72404696928798,
           -17.742727551168983,
           -17.761408133049983,
           -17.780088714930983,
           -17.798769296811987,
           -17.81744987869299,
           -17.83613046057399,
           -17.854811042454994,
           -17.873491624335994,
           -17.892172206216998,
           -17.910852788097998,
           -17.929533369978998,
           -17.94821395186,
           -17.966894533741005,
           -17.985575115622005,
           -18.004255697503005,
           -18.02293627938401,
           -18.04161686126501,
           -18.06029744314601,
           -18.078978025027013,
           -18.097658606908016,
           -18.11633918878902,
           -18.13501977067002,
           -18.15370035255102,
           -18.172380934432024,
           -18.191061516313024,
           -18.209742098194027,
           -18.22842268007503,
           -18.24710326195603,
           -18.265783843837035,
           -18.284464425718035,
           -18.303145007599035,
           -18.32182558948004,
           -18.340506171361042,
           -18.359186753242042,
           -18.377867335123042,
           -18.396547917004046,
           -18.415228498885046,
           -18.43390908076605,
           -18.45258966264705,
           -18.471270244528057,
           -18.489950826409057,
           -18.508631408290057,
           -18.527311990171057,
           -18.54599257205206,
           -18.564673153933064,
           -18.583353735814065,
           -18.602034317695068,
           -18.62071489957607,
           -18.639395481457072,
           -18.658076063338072,
           -18.676756645219072,
           -18.695437227100076,
           -18.71411780898108,
           -18.73279839086208,
           -18.75147897274308,
           -18.77148604044651,
           -18.792819602946064,
           -18.814153165445628,
           -18.835486727945185,
           -18.85682029044474,
           -18.8781538529443,
           -18.899487415443858,
           -18.920820977943418,
           -18.942154540442974,
           -18.96348810294253,
           -18.98482166544209,
           -19.00615522794165,
           -19.027488790441208,
           -19.048822352940764,
           -19.070155915440324,
           -19.091489477939884,
           -19.11282304043944,
           -19.134156602939,
           -19.15743254236545,
           -19.182650858718787,
           -19.207869175072126,
           -19.233087491425465,
           -19.258305807778804,
           -19.283524124132143,
           -19.308742440485478,
           -19.33396075683882,
           -19.359179073192163,
           -19.384397389545494,
           -19.409615705898837,
           -19.43483402225218,
           -19.460052338605514,
           -19.485270654958853,
           -19.510488971312192,
           -19.53570728766553,
           -19.560925604018866,
           -19.58614392037221,
           -19.611362236725547,
           -19.63658055307889,
           -19.661798869432225,
           -19.687017185785564,
           -19.712235502138903,
           -19.73695418032412,
           -19.76099153733428,
           -19.78502889434444,
           -19.8090662513546,
           -19.833103608364762,
           -19.85714096537492,
           -19.88117832238508,
           -19.905215679395237,
           -19.929253036405402,
           -19.953290393415557,
           -19.97732775042572,
           -20.00136510743588,
           -20.025402464446042,
           -20.049439821456197,
           -20.07347717846636,
           -20.09751453547652,
           -20.121551892486675,
           -20.145589249496837,
           -20.169626606507,
           -20.193663963517153,
           -20.21770132052732,
           -20.24173867753748,
           -20.265776034547635,
           -20.289813391557797,
           -20.31385074856796,
           -20.337888105578116,
           -20.361925462588275,
           -20.385962819598436,
           -20.410000176608598,
           -20.434037533618756,
           -20.458074890628914,
           -20.482112247639076,
           -20.506149604649234,
           -20.530186961659396,
           -20.554224318669554,
           -20.578261675679713,
           -20.602299032689878,
           -20.626336389700036,
           -20.650373746710194,
           -20.674411103720352,
           -20.698448460730518,
           -20.722485817740672,
           -20.746523174750834,
           -20.770560531760992,
           -20.794597888771154,
           -20.81863524578131,
           -20.84267260279147,
           -20.866709959801632,
           -20.89074731681179,
           -20.914784673821952,
           -20.93882203083211,
           -20.962859387842272,
           -20.98689674485243,
           -21.01093410186259,
           -21.03497145887275,
           -21.05900881588291,
           -21.08304617289307,
           -21.107083529903232,
           -21.131120886913386,
           -21.155158243923548,
           -21.164808853760167,
           -21.145685969249712,
           -21.12656308473926,
           -21.107440200228808,
           -21.08831731571835,
           -21.069194431207897,
           -21.050071546697442,
           -21.030948662186987,
           -21.011825777676535,
           -20.992702893166083,
           -20.973580008655627,
           -20.954457124145172,
           -20.93533423963472,
           -20.91621135512426,
           -20.89708847061381,
           -20.877965586103358,
           -20.8588427015929,
           -20.839719817082447,
           -20.820596932571995,
           -20.801474048061536,
           -20.78235116355108,
           -20.76322827904063,
           -20.744105394530177,
           -20.72498251001972,
           -20.70585962550927,
           -20.68673674099881,
           -20.66761385648836,
           -20.648490971977907,
           -20.629368087467448,
           -20.610245202956996,
           -20.59112231844654,
           -20.571999433936092,
           -20.552876549425633,
           -20.53375366491518,
           -20.514630780404723,
           -20.49550789589427,
           -20.47638501138382,
           -20.457262126873363,
           -20.438139242362908,
           -20.419016357852456,
           -20.399893473342,
           -20.38077058883155,
           -20.361647704321093,
           -20.342524819810635,
           -20.323401935300183,
           -20.30427905078973,
           -20.285156166279275,
           -20.26603328176882,
           -20.246910397258368,
           -20.22778751274791,
           -20.20866462823746,
           -20.189541743727005,
           -20.17041885921655,
           -20.151295974706095,
           -20.132173090195643,
           -20.11305020568519,
           -20.093927321174732,
           -20.07480443666428,
           -20.055681552153825,
           -20.03655866764337,
           -20.017435783132917,
           -19.998312898622466,
           -19.979190014112007,
           -19.960067129601555,
           -19.9409442450911,
           -19.921821360580648,
           -19.90269847607019,
           -19.88357559155974,
           -19.864452707049285,
           -19.845329822538826,
           -19.826206938028374,
           -19.807084053517922,
           -19.787961169007467,
           -19.768838284497008,
           -19.749715399986556,
           -19.730592515476104,
           -19.71146963096565,
           -19.692346746455197,
           -19.67322386194474,
           -19.654100977434286,
           -19.63497809292383,
           -19.61117040758659,
           -19.583089724166726,
           -19.580117305377172,
           -19.702686209739163,
           -19.82736308174527,
           -19.95240448493838,
           -20.07744588813147,
           -20.202487291324584,
           -20.327528694517696,
           -20.452570097710783,
           -20.577611500903895,
           -20.70265290409701,
           -20.827694307290102,
           -20.952735710483214,
           -21.077777113676326,
           -21.20281851686944,
           -21.32785992006253,
           -21.45290132325564,
           -21.577942726448754,
           -21.702984129641845,
           -21.828025532834957,
           -21.953066936028065,
           -22.078108339221156,
           -22.20314974241427,
           -22.328191145607384,
           -22.45323254880047,
           -22.578273951993587,
           -22.703315355186696,
           -22.82835675837981,
           -22.9533981615729,
           -23.07843956476601,
           -23.203480967959123,
           -23.328522371152214,
           -23.453563774345326,
           -23.578605177538442,
           -23.70364658073153,
           -23.82868798392464,
           -23.953729387117757,
           -24.07877079031087,
           -24.203812193503957,
           -24.32885359669707,
           -24.45389499989018,
           -24.578936403083272,
           -24.703977806276384,
           -24.594660807890534,
           -24.317944951234118,
           -24.041229094577645,
           -23.764513237921175,
           -23.48779738126475,
           -23.21108152460828,
           -22.93436566795181,
           -22.657649811295336,
           -22.38093395463892,
           -22.10421809798245,
           -21.82750224132598,
           -21.550786384669557,
           -21.274070528013084,
           -20.99735467135661,
           -20.720638814700195,
           -20.44392295804372,
           -20.167207101387252,
           -19.890491244730782,
           -19.61377538807436,
           -19.33705953141789,
           -19.06034367476142,
           -18.783627818104996,
           -18.506911961448523,
           -18.230196104792054,
           -17.953480248135634,
           -17.67676439147916,
           -17.40004853482269,
           -17.12333267816627,
           -16.846616821509798,
           -16.56990096485333,
           -16.29318510819686,
           -16.016469251540435,
           -15.739753394883968,
           -15.463037538227494,
           -15.186321681571075,
           -14.909605824914603,
           -14.632889968258132,
           -14.356174111601712,
           -14.07945825494524,
           -13.80274239828877,
           -13.519437929604852,
           -13.22174597837865
          ],
          [
           -14.063117688377702,
           -14.081383567731741,
           -14.099649447085778,
           -14.117915326439816,
           -14.136181205793854,
           -14.154447085147892,
           -14.172712964501928,
           -14.190978843855968,
           -14.209244723210006,
           -14.227510602564044,
           -14.245776481918083,
           -14.26404236127212,
           -14.282308240626158,
           -14.300574119980196,
           -14.318839999334234,
           -14.337105878688272,
           -14.35537175804231,
           -14.373637637396348,
           -14.391903516750386,
           -14.410169396104422,
           -14.428435275458462,
           -14.446701154812498,
           -14.464967034166536,
           -14.483232913520574,
           -14.501498792874614,
           -14.51976467222865,
           -14.53803055158269,
           -14.556296430936726,
           -14.574562310290766,
           -14.592828189644802,
           -14.611094068998842,
           -14.629359948352878,
           -14.647625827706914,
           -14.665891707060954,
           -14.684157586414992,
           -14.70242346576903,
           -14.720689345123068,
           -14.738955224477104,
           -14.757221103831142,
           -14.77548698318518,
           -14.79375286253922,
           -14.812018741893258,
           -14.830284621247294,
           -14.848550500601334,
           -14.86681637995537,
           -14.88508225930941,
           -14.903348138663446,
           -14.921614018017486,
           -14.939879897371522,
           -14.958145776725562,
           -14.976411656079598,
           -14.994677535433638,
           -15.012943414787676,
           -15.031209294141714,
           -15.04947517349575,
           -15.067741052849788,
           -15.086006932203826,
           -15.104272811557864,
           -15.122538690911902,
           -15.14080457026594,
           -15.159070449619978,
           -15.177336328974016,
           -15.195602208328054,
           -15.213868087682092,
           -15.23213396703613,
           -15.250399846390167,
           -15.268665725744205,
           -15.286931605098243,
           -15.305197484452282,
           -15.323463363806319,
           -15.341729243160358,
           -15.359995122514395,
           -15.378261001868434,
           -15.39652688122247,
           -15.416521518605322,
           -15.436861911665758,
           -15.457202304726191,
           -15.477542697786625,
           -15.497883090847061,
           -15.518223483907496,
           -15.53856387696793,
           -15.558904270028364,
           -15.579244663088797,
           -15.599585056149234,
           -15.61886577919954,
           -15.637934568247822,
           -15.657003357296103,
           -15.676072146344387,
           -15.695140935392669,
           -15.714209724440948,
           -15.733278513489232,
           -15.752347302537514,
           -15.771416091585795,
           -15.790484880634077,
           -15.807369329695844,
           -15.823816915905157,
           -15.840264502114476,
           -15.856712088323789,
           -15.873159674533104,
           -15.889607260742416,
           -15.906054846951733,
           -15.922502433161048,
           -15.93895001937036,
           -15.955397605579673,
           -15.97184519178899,
           -15.988292777998304,
           -16.004740364207617,
           -16.021187950416934,
           -16.03763553662625,
           -16.05408312283556,
           -16.070530709044874,
           -16.08697829525419,
           -16.103425881463505,
           -16.11987346767282,
           -16.136321053882135,
           -16.15276864009145,
           -16.169216226300765,
           -16.18566381251008,
           -16.202111398719392,
           -16.218558984928706,
           -16.235006571138022,
           -16.25145415734734,
           -16.26790174355665,
           -16.284349329765966,
           -16.30079691597528,
           -16.317244502184597,
           -16.33369208839391,
           -16.350139674603227,
           -16.366587260812537,
           -16.383034847021854,
           -16.39948243323117,
           -16.415930019440484,
           -16.432377605649798,
           -16.44882519185911,
           -16.465272778068424,
           -16.48172036427774,
           -16.49816795048706,
           -16.514615536696372,
           -16.531063122905685,
           -16.547510709115002,
           -16.563958295324312,
           -16.58040588153363,
           -16.596853467742942,
           -16.613301053952256,
           -16.629748640161573,
           -16.646196226370886,
           -16.662643812580203,
           -16.679091398789517,
           -16.69553898499883,
           -16.711986571208147,
           -16.72843415741746,
           -16.744881743626777,
           -16.761329329836087,
           -16.777776916045404,
           -16.794224502254718,
           -16.81067208846403,
           -16.827119674673348,
           -16.84356726088266,
           -16.860014847091975,
           -16.876462433301292,
           -16.892910019510605,
           -16.90935760571992,
           -16.925805191929236,
           -16.94225277813855,
           -16.958700364347866,
           -16.97514795055718,
           -16.991595536766493,
           -17.00953178675693,
           -17.028212368637934,
           -17.046892950518934,
           -17.065573532399938,
           -17.084254114280938,
           -17.10293469616194,
           -17.121615278042945,
           -17.140295859923945,
           -17.158976441804946,
           -17.17765702368595,
           -17.196337605566953,
           -17.215018187447953,
           -17.233698769328953,
           -17.252379351209957,
           -17.271059933090957,
           -17.28974051497196,
           -17.308421096852964,
           -17.327101678733964,
           -17.345782260614968,
           -17.364462842495968,
           -17.38314342437697,
           -17.40182400625797,
           -17.420504588138975,
           -17.439185170019975,
           -17.45786575190098,
           -17.476546333781975,
           -17.49522691566298,
           -17.513907497543983,
           -17.532588079424983,
           -17.551268661305983,
           -17.56994924318699,
           -17.58862982506799,
           -17.60731040694899,
           -17.62599098882999,
           -17.644671570710997,
           -17.663352152591997,
           -17.682032734472998,
           -17.700713316354,
           -17.719393898235005,
           -17.738074480116005,
           -17.756755061997005,
           -17.77543564387801,
           -17.794116225759012,
           -17.812796807640012,
           -17.831477389521016,
           -17.85015797140202,
           -17.86883855328302,
           -17.88751913516402,
           -17.906199717045023,
           -17.924880298926023,
           -17.943560880807027,
           -17.962241462688027,
           -17.980922044569027,
           -17.99960262645003,
           -18.018283208331034,
           -18.036963790212035,
           -18.055644372093038,
           -18.074324953974042,
           -18.093005535855042,
           -18.111686117736042,
           -18.130366699617046,
           -18.149047281498046,
           -18.16772786337905,
           -18.18640844526005,
           -18.205089027141053,
           -18.223769609022053,
           -18.242450190903057,
           -18.261130772784057,
           -18.27981135466506,
           -18.29849193654606,
           -18.317172518427064,
           -18.335853100308064,
           -18.354533682189068,
           -18.373214264070068,
           -18.39189484595107,
           -18.410575427832075,
           -18.42925600380865,
           -18.447465738439547,
           -18.465675473070448,
           -18.483885207701352,
           -18.50209494233225,
           -18.52030467696315,
           -18.538514411594047,
           -18.558825740025124,
           -18.581238662256382,
           -18.60485810754862,
           -18.628744263669326,
           -18.652630419790032,
           -18.676516575910735,
           -18.700402732031442,
           -18.72428888815215,
           -18.748175044272852,
           -18.772061200393555,
           -18.795947356514265,
           -18.81983351263497,
           -18.843719668755675,
           -18.86760582487638,
           -18.891491980997085,
           -18.915378137117788,
           -18.939264293238494,
           -18.9631504493592,
           -18.987036605479908,
           -19.01092276160061,
           -19.034808917721314,
           -19.058695073842024,
           -19.082581229962724,
           -19.10646738608343,
           -19.130353542204137,
           -19.154239698324844,
           -19.178125854445547,
           -19.202012010566257,
           -19.22589816668696,
           -19.249784322807663,
           -19.27367047892837,
           -19.297556635049077,
           -19.32144279116978,
           -19.345328947290486,
           -19.369215103411193,
           -19.3931012595319,
           -19.4169874156526,
           -19.44087357177331,
           -19.464759727894013,
           -19.488645884014716,
           -19.512532040135426,
           -19.53641819625613,
           -19.560304352376832,
           -19.584190508497542,
           -19.608076664618245,
           -19.63196282073895,
           -19.65584897685966,
           -19.679735132980362,
           -19.70362128910107,
           -19.727507445221775,
           -19.751393601342482,
           -19.775279757463185,
           -19.799165913583888,
           -19.823052069704595,
           -19.8469382258253,
           -19.870824381946004,
           -19.89471053806671,
           -19.918596694187418,
           -19.94248285030812,
           -19.966369006428828,
           -19.990255162549534,
           -20.014141318670237,
           -20.03802747479094,
           -20.06191363091165,
           -20.085799787032354,
           -20.109685943153057,
           -20.133572099273767,
           -20.15745825539447,
           -20.181344411515173,
           -20.20523056763588,
           -20.229116723756587,
           -20.25300287987729,
           -20.276889035997996,
           -20.300775192118703,
           -20.324661348239406,
           -20.348547504360113,
           -20.37243366048082,
           -20.396319816601522,
           -20.420205972722226,
           -20.444092128842936,
           -20.46797828496364,
           -20.491864441084346,
           -20.51575059720505,
           -20.528380677316818,
           -20.518498605410727,
           -20.508616533504636,
           -20.49873446159854,
           -20.488852389692454,
           -20.47897031778636,
           -20.469088245880272,
           -20.459206173974177,
           -20.449324102068083,
           -20.43944203016199,
           -20.429559958255897,
           -20.41967788634981,
           -20.409795814443715,
           -20.399913742537624,
           -20.39003167063153,
           -20.380149598725442,
           -20.370267526819347,
           -20.356893567507928,
           -20.33906440715088,
           -20.32123524679383,
           -20.303406086436777,
           -20.285576926079727,
           -20.267747765722678,
           -20.24991860536563,
           -20.232089445008576,
           -20.214260284651527,
           -20.196431124294474,
           -20.178601963937425,
           -20.160772803580375,
           -20.142943643223326,
           -20.125114482866273,
           -20.107285322509224,
           -20.089456162152175,
           -20.07162700179512,
           -20.053797841438072,
           -20.035968681081023,
           -20.01813952072397,
           -20.00031036036692,
           -19.98248120000987,
           -19.964652039652822,
           -19.94682287929577,
           -19.92899371893872,
           -19.911164558581667,
           -19.893335398224615,
           -19.87550623786757,
           -19.857677077510516,
           -19.839847917153467,
           -19.822018756796417,
           -19.804189596439368,
           -19.78636043608232,
           -19.768531275725266,
           -19.750702115368217,
           -19.732872955011167,
           -19.715043794654115,
           -19.697214634297065,
           -19.679385473940016,
           -19.661556313582963,
           -19.643727153225917,
           -19.625897992868865,
           -19.60806883251181,
           -19.590239672154762,
           -19.572410511797713,
           -19.55458135144066,
           -19.53675219108361,
           -19.51892303072656,
           -19.501093870369512,
           -19.48326471001246,
           -19.46543554965541,
           -19.44760638929836,
           -19.429777228941308,
           -19.41194806858426,
           -19.39411890822721,
           -19.37628974787016,
           -19.358460587513107,
           -19.340631427156058,
           -19.32280226679901,
           -19.304973106441956,
           -19.287143946084907,
           -19.269314785727857,
           -19.251485625370805,
           -19.233656465013755,
           -19.215827304656706,
           -19.197998144299653,
           -19.204159848173532,
           -19.33027587320204,
           -19.45639189823055,
           -19.582507923259058,
           -19.708623948287546,
           -19.834739973316054,
           -19.960855998344563,
           -20.08697202337305,
           -20.21308804840156,
           -20.33920407343007,
           -20.465320098458555,
           -20.591436123487064,
           -20.717552148515573,
           -20.84366817354408,
           -20.969784198572565,
           -21.095900223601078,
           -21.222016248629586,
           -21.34813227365807,
           -21.474248298686582,
           -21.60036432371509,
           -21.72648034874358,
           -21.852596373772087,
           -21.978712398800596,
           -22.10482842382908,
           -22.230944448857592,
           -22.357060473886097,
           -22.48317649891461,
           -22.609292523943097,
           -22.735408548971606,
           -22.861524574000114,
           -22.987640599028598,
           -23.11375662405711,
           -23.23987264908562,
           -23.365988674114107,
           -23.48669655104757,
           -23.599832975435696,
           -23.712969399823827,
           -23.826105824211936,
           -23.939242248600067,
           -24.05237867298819,
           -24.1655150973763,
           -24.27865152176443,
           -24.18911641278277,
           -23.954815922822785,
           -23.720515432862758,
           -23.486214942902734,
           -23.25191445294275,
           -23.017613962982722,
           -22.783313473022694,
           -22.549012983062667,
           -22.285967419485353,
           -22.01334023887147,
           -21.740713058257587,
           -21.468085877643748,
           -21.195458697029867,
           -20.922831516415982,
           -20.650204335802147,
           -20.377577155188263,
           -20.104949974574378,
           -19.832322793960493,
           -19.55969561334666,
           -19.287068432732774,
           -19.014441252118885,
           -18.741814071505054,
           -18.46918689089117,
           -18.196559710277285,
           -17.92393252966345,
           -17.651305349049565,
           -17.378678168435677,
           -17.106050987821845,
           -16.833423807207957,
           -16.560796626594076,
           -16.288169445980188,
           -16.015542265366356,
           -15.742915084752468,
           -15.470287904138585,
           -15.19766072352475,
           -14.925033542910864,
           -14.65240636229698,
           -14.379779181683146,
           -14.107152001069261,
           -13.834524820455375,
           -13.561897639841488,
           -13.289270459227657
          ],
          [
           -13.592992867262007,
           -13.611258746616047,
           -13.629524625970085,
           -13.647790505324123,
           -13.666056384678159,
           -13.684322264032199,
           -13.702588143386237,
           -13.720854022740275,
           -13.73911990209431,
           -13.757385781448349,
           -13.775651660802389,
           -13.793917540156427,
           -13.812183419510465,
           -13.830449298864501,
           -13.848715178218539,
           -13.866981057572577,
           -13.885246936926617,
           -13.903512816280653,
           -13.921778695634691,
           -13.940044574988729,
           -13.958310454342767,
           -13.976576333696803,
           -13.994842213050843,
           -14.01310809240488,
           -14.03137397175892,
           -14.049639851112955,
           -14.067905730466995,
           -14.086171609821033,
           -14.104437489175071,
           -14.122703368529107,
           -14.140969247883147,
           -14.159235127237183,
           -14.177501006591223,
           -14.19576688594526,
           -14.214032765299297,
           -14.232298644653335,
           -14.250564524007373,
           -14.268830403361413,
           -14.28709628271545,
           -14.305362162069489,
           -14.323628041423525,
           -14.341893920777563,
           -14.3601598001316,
           -14.37842567948564,
           -14.396691558839676,
           -14.414957438193715,
           -14.433223317547752,
           -14.451489196901791,
           -14.469755076255828,
           -14.488020955609867,
           -14.506286834963904,
           -14.524552714317943,
           -14.542818593671981,
           -14.56108447302602,
           -14.579350352380056,
           -14.597616231734094,
           -14.615882111088133,
           -14.63414799044217,
           -14.652413869796208,
           -14.670679749150246,
           -14.688945628504284,
           -14.707211507858322,
           -14.72547738721236,
           -14.743743266566398,
           -14.762009145920436,
           -14.780275025274474,
           -14.79854090462851,
           -14.81680678398255,
           -14.835072663336588,
           -14.853338542690624,
           -14.871604422044664,
           -14.8898703013987,
           -14.90813618075274,
           -14.926402060106776,
           -14.944667939460816,
           -14.962933818814854,
           -14.981199698168892,
           -14.998659320004434,
           -15.014506437838845,
           -15.030353555673257,
           -15.04620067350767,
           -15.06204779134208,
           -15.077894909176493,
           -15.093742027010904,
           -15.107852060756331,
           -15.121614677683962,
           -15.13537729461159,
           -15.149139911539221,
           -15.16290252846685,
           -15.17666514539448,
           -15.191322747999184,
           -15.207770334208497,
           -15.224217920417814,
           -15.240665506627128,
           -15.257113092836441,
           -15.273560679045758,
           -15.290008265255072,
           -15.306455851464388,
           -15.322903437673702,
           -15.339351023883015,
           -15.355798610092332,
           -15.372246196301646,
           -15.388693782510959,
           -15.405141368720273,
           -15.42158895492959,
           -15.438036541138903,
           -15.454484127348216,
           -15.47093171355753,
           -15.487379299766847,
           -15.50382688597616,
           -15.520274472185477,
           -15.53672205839479,
           -15.553169644604107,
           -15.56961723081342,
           -15.586064817022734,
           -15.602512403232048,
           -15.618959989441365,
           -15.635407575650678,
           -15.651855161859991,
           -15.668302748069305,
           -15.684750334278622,
           -15.701197920487935,
           -15.717645506697252,
           -15.734093092906566,
           -15.750540679115879,
           -15.766988265325196,
           -15.78343585153451,
           -15.799883437743825,
           -15.816331023953136,
           -15.832778610162453,
           -15.849226196371767,
           -15.865673782581082,
           -15.882121368790397,
           -15.89856895499971,
           -15.915016541209027,
           -15.93146412741834,
           -15.947911713627654,
           -15.964359299836968,
           -15.980806886046285,
           -15.997254472255598,
           -16.01370205846491,
           -16.03014964467423,
           -16.046597230883542,
           -16.063044817092855,
           -16.079492403302172,
           -16.095939989511486,
           -16.112387575720803,
           -16.128835161930116,
           -16.14528274813943,
           -16.161730334348746,
           -16.17817792055806,
           -16.194625506767373,
           -16.211073092976687,
           -16.227520679186,
           -16.243968265395317,
           -16.26041585160463,
           -16.276863437813944,
           -16.29331102402326,
           -16.309758610232574,
           -16.326206196441888,
           -16.342653782651205,
           -16.359101368860518,
           -16.37554895506983,
           -16.391996541279145,
           -16.408444127488462,
           -16.424891713697775,
           -16.44133929990709,
           -16.457519687971494,
           -16.47356647696344,
           -16.48961326595539,
           -16.505660054947338,
           -16.521706843939285,
           -16.53775363293124,
           -16.553800421923185,
           -16.569847210915132,
           -16.585893999907082,
           -16.603251660202783,
           -16.621461394833684,
           -16.63967112946458,
           -16.657880864095482,
           -16.676090598726383,
           -16.69430033335728,
           -16.71251006798818,
           -16.730719802619078,
           -16.74892953724998,
           -16.767139271880882,
           -16.78534900651178,
           -16.80355874114268,
           -16.821768475773574,
           -16.839978210404475,
           -16.85818794503538,
           -16.876397679666276,
           -16.894607414297177,
           -16.912817148928074,
           -16.93102688355897,
           -16.949236618189875,
           -16.967446352820772,
           -16.985656087451673,
           -17.003865822082574,
           -17.02207555671347,
           -17.04028529134437,
           -17.05849502597527,
           -17.07670476060617,
           -17.09491449523707,
           -17.11312422986797,
           -17.131333964498868,
           -17.149543699129765,
           -17.167753433760666,
           -17.185963168391567,
           -17.204172903022467,
           -17.222382637653368,
           -17.240592372284265,
           -17.258802106915166,
           -17.277011841546067,
           -17.295221576176964,
           -17.313431310807864,
           -17.331641045438765,
           -17.349850780069662,
           -17.36806051470056,
           -17.386270249331464,
           -17.40447998396236,
           -17.42268971859326,
           -17.44089945322416,
           -17.459109187855056,
           -17.477318922485956,
           -17.495528657116857,
           -17.513738391747758,
           -17.53194812637866,
           -17.550157861009556,
           -17.568367595640456,
           -17.586577330271357,
           -17.604787064902254,
           -17.622996799533155,
           -17.641206534164056,
           -17.659416268794953,
           -17.677626003425853,
           -17.69583573805675,
           -17.71404547268765,
           -17.732255207318552,
           -17.75046494194945,
           -17.76867467658035,
           -17.786884411211247,
           -17.805094145842148,
           -17.82330388047305,
           -17.84151361510395,
           -17.859723349734846,
           -17.877933084365747,
           -17.896142818996648,
           -17.914352553627545,
           -17.932562288258445,
           -17.952873616689523,
           -17.975286538920777,
           -17.99769946115203,
           -18.020112383383285,
           -18.042525305614543,
           -18.064938227845794,
           -18.087351150077048,
           -18.109764072308305,
           -18.132176994539563,
           -18.154589916770817,
           -18.17700283900207,
           -18.199415761233325,
           -18.22182868346458,
           -18.244241605695834,
           -18.26665452792709,
           -18.289067450158345,
           -18.3114803723896,
           -18.333893294620854,
           -18.35630621685211,
           -18.378719139083362,
           -18.40113206131462,
           -18.423544983545877,
           -18.445957905777128,
           -18.468370828008382,
           -18.49078375023964,
           -18.513196672470894,
           -18.535609594702148,
           -18.558022516933402,
           -18.58043543916466,
           -18.602848361395914,
           -18.625261283627168,
           -18.647674205858422,
           -18.670087128089676,
           -18.692500050320934,
           -18.715065372528077,
           -18.738951528648784,
           -18.762837684769487,
           -18.786723840890197,
           -18.810609997010896,
           -18.834496153131603,
           -18.858382309252306,
           -18.882268465373016,
           -18.90615462149372,
           -18.930040777614426,
           -18.953926933735133,
           -18.977813089855836,
           -19.00169924597654,
           -19.025585402097246,
           -19.049471558217952,
           -19.073357714338655,
           -19.097243870459366,
           -19.12113002658007,
           -19.145016182700772,
           -19.16890233882148,
           -19.192788494942185,
           -19.21667465106289,
           -19.240560807183595,
           -19.2644469633043,
           -19.288333119425005,
           -19.31221927554571,
           -19.336105431666418,
           -19.35999158778712,
           -19.383877743907824,
           -19.407763900028534,
           -19.431650056149238,
           -19.455536212269944,
           -19.47942236839065,
           -19.503308524511354,
           -19.527194680632057,
           -19.551080836752767,
           -19.57496699287347,
           -19.598853148994177,
           -19.62273930511488,
           -19.646625461235587,
           -19.67051161735629,
           -19.694397773476997,
           -19.718283929597703,
           -19.742170085718406,
           -19.76605624183911,
           -19.78994239795982,
           -19.813828554080523,
           -19.837714710201226,
           -19.861600866321936,
           -19.874230946433705,
           -19.86434887452761,
           -19.854466802621523,
           -19.84458473071543,
           -19.834702658809338,
           -19.824820586903243,
           -19.814938514997152,
           -19.80505644309106,
           -19.79517437118497,
           -19.785292299278876,
           -19.77541022737278,
           -19.76552815546669,
           -19.7556460835606,
           -19.745764011654508,
           -19.735881939748417,
           -19.725999867842326,
           -19.716117795936235,
           -19.70623572403014,
           -19.696353652124046,
           -19.686471580217955,
           -19.676589508311864,
           -19.666707436405773,
           -19.65682536449968,
           -19.646943292593587,
           -19.637061220687492,
           -19.627179148781405,
           -19.61729707687531,
           -19.60741500496922,
           -19.59753293306313,
           -19.587650861157034,
           -19.577768789250943,
           -19.567886717344848,
           -19.558004645438757,
           -19.548122573532666,
           -19.538240501626575,
           -19.528358429720484,
           -19.518476357814386,
           -19.5085942859083,
           -19.498712214002207,
           -19.488830142096113,
           -19.47894807019002,
           -19.46906599828393,
           -19.459183926377836,
           -19.44930185447174,
           -19.43941978256565,
           -19.42953771065956,
           -19.41965563875347,
           -19.409773566847377,
           -19.399891494941283,
           -19.390009423035192,
           -19.380127351129097,
           -19.370245279223006,
           -19.352897753752146,
           -19.335068593395096,
           -19.317239433038047,
           -19.299410272680998,
           -19.281581112323945,
           -19.263751951966896,
           -19.245922791609846,
           -19.228093631252797,
           -19.210264470895744,
           -19.192435310538695,
           -19.174606150181646,
           -19.156776989824593,
           -19.138947829467547,
           -19.121118669110494,
           -19.10328950875344,
           -19.085460348396396,
           -19.067631188039343,
           -19.04980202768229,
           -19.03197286732524,
           -19.01414370696819,
           -18.996314546611142,
           -18.97848538625409,
           -18.96065622589704,
           -18.94282706553999,
           -18.924997905182938,
           -18.90716874482589,
           -18.88933958446884,
           -18.871510424111786,
           -18.853681263754737,
           -18.835852103397688,
           -18.818022943040635,
           -18.824184646914517,
           -18.950300671943022,
           -19.07641669697153,
           -19.20253272200004,
           -19.328648747028524,
           -19.454764772057036,
           -19.580880797085545,
           -19.706996822114032,
           -19.83311284714254,
           -19.95922887217105,
           -20.085344897199537,
           -20.211460922228046,
           -20.337576947256554,
           -20.463692972285063,
           -20.589808997313547,
           -20.715925022342056,
           -20.842041047370568,
           -20.95535776472861,
           -21.06849418911674,
           -21.181630613504872,
           -21.294767037892974,
           -21.407903462281105,
           -21.521039886669236,
           -21.634176311057338,
           -21.747312735445476,
           -21.8604491598336,
           -21.97358558422173,
           -22.08672200860984,
           -22.199858432997967,
           -22.312994857386094,
           -22.426131281774204,
           -22.539267706162335,
           -22.65240413055046,
           -22.76554055493857,
           -22.8786769793267,
           -22.99181340371483,
           -23.10494982810296,
           -23.21808625249107,
           -23.331222676879197,
           -23.444359101267324,
           -23.557495525655433,
           -23.670631950043564,
           -23.5810968410619,
           -23.346796351101915,
           -23.112495861141888,
           -22.878195371181867,
           -22.643894881221883,
           -22.409594391261855,
           -22.175293901301828,
           -21.9409934113418,
           -21.706692921381816,
           -21.472392431421788,
           -21.23809194146176,
           -21.003791451501776,
           -20.76949096154175,
           -20.53519047158172,
           -20.30088998162174,
           -20.066589491661716,
           -19.832289001701685,
           -19.59798851174166,
           -19.363688021781677,
           -19.12938753182165,
           -18.895087041861622,
           -18.660786551901637,
           -18.42648606194161,
           -18.192185571981582,
           -17.957885082021598,
           -17.71666443389954,
           -17.44403725328565,
           -17.171410072671815,
           -16.89878289205793,
           -16.626155711444042,
           -16.35352853083016,
           -16.080901350216326,
           -15.808274169602441,
           -15.535646988988555,
           -15.263019808374722,
           -14.990392627760837,
           -14.71776544714695,
           -14.445138266533116,
           -14.17251108591923,
           -13.899883905305346,
           -13.62725672469146,
           -13.354629544077627
          ],
          [
           -13.121000048066309,
           -13.139265927420347,
           -13.157531806774386,
           -13.175797686128423,
           -13.19406356548246,
           -13.212329444836499,
           -13.230595324190535,
           -13.248861203544575,
           -13.267127082898613,
           -13.28539296225265,
           -13.303658841606689,
           -13.321924720960725,
           -13.340190600314765,
           -13.358456479668803,
           -13.37672235902284,
           -13.394988238376879,
           -13.413254117730915,
           -13.431519997084953,
           -13.449785876438993,
           -13.46805175579303,
           -13.486317635147069,
           -13.504583514501105,
           -13.522849393855147,
           -13.541115273209181,
           -13.559381152563223,
           -13.577647031917257,
           -13.595912911271295,
           -13.614178790625335,
           -13.632444669979373,
           -13.650710549333409,
           -13.668976428687447,
           -13.687242308041485,
           -13.705508187395523,
           -13.723774066749561,
           -13.7420399461036,
           -13.760305825457637,
           -13.778571704811675,
           -13.796837584165715,
           -13.81510346351975,
           -13.833369342873791,
           -13.851635222227827,
           -13.869901101581865,
           -13.888166980935901,
           -13.906432860289941,
           -13.924698739643977,
           -13.942964618998017,
           -13.961230498352053,
           -13.979496377706093,
           -13.99776225706013,
           -14.01602813641417,
           -14.034294015768205,
           -14.052559895122243,
           -14.070825774476283,
           -14.08909165383032,
           -14.107357533184357,
           -14.125623412538395,
           -14.143889291892433,
           -14.162155171246471,
           -14.180421050600508,
           -14.198686929954548,
           -14.216952809308586,
           -14.233203051703066,
           -14.249050169537478,
           -14.264897287371891,
           -14.280744405206303,
           -14.296591523040714,
           -14.312438640875126,
           -14.328285758709537,
           -14.34413287654395,
           -14.359979994378362,
           -14.375827112212773,
           -14.391674230047187,
           -14.407521347881596,
           -14.423368465716008,
           -14.439215583550421,
           -14.455062701384833,
           -14.470909819219246,
           -14.486756937053658,
           -14.502604054888069,
           -14.518451172722482,
           -14.534298290556894,
           -14.550145408391304,
           -14.565992526225717,
           -14.581839644060128,
           -14.595949677805555,
           -14.609712294733187,
           -14.623474911660814,
           -14.637237528588445,
           -14.651000145516075,
           -14.664762762443704,
           -14.678525379371335,
           -14.692287996298964,
           -14.706050613226594,
           -14.719813230154223,
           -14.733575847081854,
           -14.747338464009484,
           -14.761101080937113,
           -14.774863697864744,
           -14.788626314792374,
           -14.802388931720003,
           -14.816151548647632,
           -14.82991416557526,
           -14.843676782502893,
           -14.857439399430522,
           -14.87120201635815,
           -14.884964633285781,
           -14.89872725021341,
           -14.914727338922846,
           -14.931174925132163,
           -14.947622511341477,
           -14.964070097550792,
           -14.980517683760105,
           -14.99696526996942,
           -15.013412856178736,
           -15.029860442388049,
           -15.046308028597364,
           -15.06275561480668,
           -15.079203201015993,
           -15.095650787225308,
           -15.112098373434621,
           -15.128545959643938,
           -15.144993545853252,
           -15.161441132062565,
           -15.17788871827188,
           -15.194336304481196,
           -15.21078389069051,
           -15.227231476899828,
           -15.243679063109141,
           -15.260126649318453,
           -15.27657423552777,
           -15.293021821737083,
           -15.309469407946398,
           -15.325916994155712,
           -15.342364580365027,
           -15.35881216657434,
           -15.375259752783654,
           -15.391707338992969,
           -15.408154925202284,
           -15.4246025114116,
           -15.441050097620915,
           -15.457497683830228,
           -15.473945270039541,
           -15.490392856248857,
           -15.506840442458172,
           -15.523288028667487,
           -15.5397356148768,
           -15.556183201086116,
           -15.57263078729543,
           -15.589078373504744,
           -15.60552595971406,
           -15.621973545923373,
           -15.63842113213269,
           -15.654868718342001,
           -15.671316304551317,
           -15.687763890760632,
           -15.704211476969945,
           -15.720659063179259,
           -15.737106649388576,
           -15.753554235597889,
           -15.770001821807204,
           -15.786449408016518,
           -15.802896994225833,
           -15.819344580435148,
           -15.835792166644461,
           -15.852239752853778,
           -15.868687339063092,
           -15.885134925272405,
           -15.90131531333681,
           -15.91736210232876,
           -15.933408891320706,
           -15.949455680312656,
           -15.965502469304603,
           -15.981549258296553,
           -15.997596047288502,
           -16.01364283628045,
           -16.0296896252724,
           -16.045736414264347,
           -16.061783203256297,
           -16.077829992248244,
           -16.09387678124019,
           -16.10992357023214,
           -16.12597035922409,
           -16.142017148216038,
           -16.158063937207988,
           -16.174110726199935,
           -16.190157515191885,
           -16.20620430418383,
           -16.222251093175778,
           -16.23829788216773,
           -16.254344671159675,
           -16.270391460151625,
           -16.286438249143572,
           -16.302485038135522,
           -16.318531827127472,
           -16.33457861611942,
           -16.350625405111366,
           -16.366672194103316,
           -16.382718983095266,
           -16.398765772087213,
           -16.41612343337787,
           -16.43433316800877,
           -16.452542902639667,
           -16.47075263727057,
           -16.488962371901465,
           -16.507172106532366,
           -16.525381841163266,
           -16.543591575794167,
           -16.561801310425064,
           -16.58001104505597,
           -16.598220779686866,
           -16.616430514317763,
           -16.634640248948664,
           -16.652849983579564,
           -16.67105971821046,
           -16.68926945284136,
           -16.70747918747226,
           -16.72568892210316,
           -16.74389865673406,
           -16.762108391364958,
           -16.78031812599586,
           -16.79852786062676,
           -16.81673759525766,
           -16.834947329888557,
           -16.853157064519454,
           -16.87136679915036,
           -16.889576533781256,
           -16.907786268412156,
           -16.925996003043053,
           -16.944205737673954,
           -16.962415472304855,
           -16.980625206935752,
           -16.998834941566653,
           -17.017044676197553,
           -17.03525441082845,
           -17.05346414545935,
           -17.07167388009025,
           -17.08988361472115,
           -17.10809334935205,
           -17.126303083982947,
           -17.144512818613848,
           -17.16272255324475,
           -17.180932287875645,
           -17.199142022506546,
           -17.217351757137447,
           -17.235561491768348,
           -17.253771226399245,
           -17.271980961030145,
           -17.290190695661046,
           -17.308400430291947,
           -17.326610164922844,
           -17.34692149335392,
           -17.36933441558518,
           -17.39174733781643,
           -17.414160260047684,
           -17.43657318227894,
           -17.458986104510196,
           -17.48139902674145,
           -17.503811948972704,
           -17.526224871203958,
           -17.548637793435212,
           -17.571050715666466,
           -17.593463637897727,
           -17.61587656012898,
           -17.638289482360232,
           -17.66070240459149,
           -17.683115326822744,
           -17.705528249053998,
           -17.727941171285252,
           -17.750354093516506,
           -17.77276701574776,
           -17.795179937979015,
           -17.817592860210276,
           -17.840005782441526,
           -17.86241870467278,
           -17.884831626904038,
           -17.907244549135292,
           -17.929657471366546,
           -17.9520703935978,
           -17.974483315829055,
           -17.996896238060312,
           -18.019309160291566,
           -18.04172208252282,
           -18.064135004754075,
           -18.086547926985332,
           -18.108960849216587,
           -18.13137377144784,
           -18.153786693679095,
           -18.176199615910352,
           -18.198612538141603,
           -18.221025460372857,
           -18.243438382604115,
           -18.265851304835365,
           -18.28826422706662,
           -18.310677149297877,
           -18.333090071529135,
           -18.355502993760386,
           -18.377915915991643,
           -18.400328838222897,
           -18.42274176045415,
           -18.445154682685406,
           -18.467567604916663,
           -18.489980527147914,
           -18.51239344937917,
           -18.534806371610426,
           -18.55721929384168,
           -18.579632216072934,
           -18.60204513830419,
           -18.624458060535446,
           -18.6468709827667,
           -18.669283904997954,
           -18.69169682722921,
           -18.714109749460462,
           -18.736522671691716,
           -18.758935593922974,
           -18.781348516154228,
           -18.803761438385482,
           -18.82617436061674,
           -18.849158793628238,
           -18.873044949748945,
           -18.89693110586965,
           -18.920817261990354,
           -18.94470341811106,
           -18.968589574231768,
           -18.99247573035247,
           -19.016361886473177,
           -19.04024804259388,
           -19.06413419871459,
           -19.08802035483529,
           -19.111906510955997,
           -19.135792667076704,
           -19.15967882319741,
           -19.183564979318113,
           -19.207451135438816,
           -19.22008121555059,
           -19.210199143644495,
           -19.200317071738407,
           -19.190434999832313,
           -19.18055292792622,
           -19.17067085602013,
           -19.160788784114036,
           -19.150906712207945,
           -19.141024640301854,
           -19.13114256839576,
           -19.121260496489665,
           -19.111378424583577,
           -19.101496352677486,
           -19.09161428077139,
           -19.0817322088653,
           -19.07185013695921,
           -19.061968065053115,
           -19.052085993147028,
           -19.042203921240933,
           -19.03232184933484,
           -19.02243977742875,
           -19.012557705522656,
           -19.002675633616562,
           -18.992793561710474,
           -18.982911489804376,
           -18.97302941789829,
           -18.963147345992194,
           -18.953265274086107,
           -18.943383202180012,
           -18.93350113027392,
           -18.923619058367827,
           -18.913736986461736,
           -18.90385491455564,
           -18.893972842649553,
           -18.88409077074346,
           -18.874208698837368,
           -18.864326626931273,
           -18.854444555025182,
           -18.844562483119095,
           -18.834680411212997,
           -18.82479833930691,
           -18.814916267400815,
           -18.805034195494724,
           -18.79515212358863,
           -18.785270051682538,
           -18.775387979776447,
           -18.765505907870352,
           -18.755623835964258,
           -18.745741764058167,
           -18.735859692152076,
           -18.725977620245985,
           -18.716095548339894,
           -18.7062134764338,
           -18.696331404527708,
           -18.686449332621617,
           -18.676567260715522,
           -18.666685188809428,
           -18.65680311690334,
           -18.646921044997246,
           -18.63703897309115,
           -18.62715690118506,
           -18.617274829278973,
           -18.607392757372878,
           -18.597510685466784,
           -18.587628613560696,
           -18.5777465416546,
           -18.567864469748507,
           -18.557982397842416,
           -18.548100325936325,
           -18.538218254030234,
           -18.528336182124143,
           -18.51845411021805,
           -18.50960052518271,
           -18.501177058740787,
           -18.492753592298865,
           -18.484330125856935,
           -18.475906659415013,
           -18.467483192973088,
           -18.459059726531166,
           -18.45063626008924,
           -18.442212793647318,
           -18.43378932720539,
           -18.425365860763463,
           -18.436938707961936,
           -18.548493123362384,
           -18.660047538762832,
           -18.77160195416328,
           -18.883156369563707,
           -18.994710784964155,
           -19.106265200364607,
           -19.217819615765034,
           -19.329374031165482,
           -19.442246797902772,
           -19.55538322229088,
           -19.66851964667901,
           -19.78165607106714,
           -19.894792495455267,
           -20.007928919843373,
           -20.121065344231507,
           -20.23420176861963,
           -20.34733819300774,
           -20.46047461739587,
           -20.573611041783998,
           -20.686747466172108,
           -20.79988389056024,
           -20.913020314948366,
           -21.026156739336475,
           -21.139293163724602,
           -21.252429588112733,
           -21.365566012500864,
           -21.47870243688897,
           -21.5918388612771,
           -21.704975285665228,
           -21.818111710053337,
           -21.931248134441464,
           -22.044384558829595,
           -22.1575209832177,
           -22.27065740760583,
           -22.383793831993962,
           -22.496930256382093,
           -22.610066680770196,
           -22.72320310515833,
           -22.836339529546457,
           -22.949475953934567,
           -23.062612378322697,
           -22.973077269341033,
           -22.73877677938105,
           -22.50447628942102,
           -22.270175799461,
           -22.035875309501012,
           -21.801574819540985,
           -21.567274329580957,
           -21.33297383962093,
           -21.09867334966095,
           -20.86437285970092,
           -20.630072369740894,
           -20.39577187978091,
           -20.161471389820882,
           -19.927170899860855,
           -19.692870409900873,
           -19.458569919940846,
           -19.22426942998082,
           -18.98996894002079,
           -18.75566845006081,
           -18.521367960100783,
           -18.28706747014075,
           -18.05276698018077,
           -17.818466490220743,
           -17.584166000260716,
           -17.34986551030073,
           -17.115565020340703,
           -16.88126453038068,
           -16.646964040420695,
           -16.412663550460664,
           -16.17836306050064,
           -15.944062570540613,
           -15.709762080580628,
           -15.475461590620602,
           -15.243127564393987,
           -15.01472658325575,
           -14.786325602117474,
           -14.557924620979197,
           -14.329523639840964,
           -14.101122658702687,
           -13.872721677564408,
           -13.644320696426131,
           -13.415919715287897
          ],
          [
           -12.649007228870609,
           -12.667273108224649,
           -12.685538987578685,
           -12.703804866932725,
           -12.72207074628676,
           -12.7403366256408,
           -12.758602504994839,
           -12.776868384348877,
           -12.795134263702913,
           -12.813400143056953,
           -12.831666022410989,
           -12.849931901765027,
           -12.868197781119065,
           -12.886463660473105,
           -12.904729539827143,
           -12.922995419181179,
           -12.941261298535217,
           -12.959527177889255,
           -12.977793057243293,
           -12.996058936597331,
           -13.014324815951369,
           -13.032590695305407,
           -13.050856574659445,
           -13.069122454013485,
           -13.087388333367521,
           -13.105654212721559,
           -13.123920092075597,
           -13.142185971429633,
           -13.160451850783673,
           -13.17871773013771,
           -13.196983609491749,
           -13.215249488845785,
           -13.233515368199825,
           -13.251781247553863,
           -13.270047126907901,
           -13.288313006261937,
           -13.306578885615977,
           -13.324844764970013,
           -13.343110644324053,
           -13.36137652367809,
           -13.379642403032127,
           -13.397908282386165,
           -13.416174161740203,
           -13.434440041094241,
           -13.451899665567286,
           -13.467746783401697,
           -13.483593901236109,
           -13.499441019070524,
           -13.515288136904934,
           -13.531135254739345,
           -13.546982372573758,
           -13.56282949040817,
           -13.578676608242581,
           -13.594523726076993,
           -13.610370843911406,
           -13.626217961745818,
           -13.64206507958023,
           -13.657912197414642,
           -13.673759315249054,
           -13.689606433083465,
           -13.705453550917877,
           -13.721300668752288,
           -13.737147786586702,
           -13.752994904421113,
           -13.768842022255527,
           -13.784689140089938,
           -13.800536257924348,
           -13.816383375758761,
           -13.832230493593173,
           -13.848077611427584,
           -13.863924729261997,
           -13.879771847096407,
           -13.895618964930819,
           -13.911466082765232,
           -13.927313200599645,
           -13.943160318434057,
           -13.959007436268468,
           -13.974854554102881,
           -13.990701671937293,
           -14.006548789771704,
           -14.022395907606116,
           -14.038243025440527,
           -14.05409014327494,
           -14.069937261109352,
           -14.084047294854777,
           -14.09780991178241,
           -14.111572528710038,
           -14.125335145637667,
           -14.139097762565298,
           -14.152860379492928,
           -14.166622996420557,
           -14.180385613348188,
           -14.194148230275818,
           -14.207910847203447,
           -14.221673464131076,
           -14.235436081058706,
           -14.249198697986337,
           -14.262961314913966,
           -14.276723931841596,
           -14.290486548769227,
           -14.304249165696856,
           -14.318011782624485,
           -14.331774399552113,
           -14.345537016479746,
           -14.359299633407375,
           -14.373062250335003,
           -14.386824867262632,
           -14.400587484190263,
           -14.414350101117893,
           -14.428112718045522,
           -14.441875334973153,
           -14.455637951900783,
           -14.469400568828412,
           -14.483163185756043,
           -14.496925802683673,
           -14.510688419611302,
           -14.524451036538933,
           -14.53821365346656,
           -14.551976270394192,
           -14.565738887321821,
           -14.57950150424945,
           -14.593264121177082,
           -14.60702673810471,
           -14.621684343637197,
           -14.63813192984651,
           -14.654579516055826,
           -14.671027102265143,
           -14.687474688474456,
           -14.70392227468377,
           -14.720369860893086,
           -14.7368174471024,
           -14.753265033311713,
           -14.769712619521027,
           -14.786160205730344,
           -14.802607791939657,
           -14.81905537814897,
           -14.835502964358286,
           -14.8519505505676,
           -14.868398136776916,
           -14.88484572298623,
           -14.901293309195545,
           -14.917740895404858,
           -14.934188481614173,
           -14.950636067823488,
           -14.967083654032804,
           -14.983531240242117,
           -14.999978826451432,
           -15.016426412660747,
           -15.03287399887006,
           -15.049321585079376,
           -15.06576917128869,
           -15.082216757498006,
           -15.09866434370732,
           -15.115111929916633,
           -15.13155951612595,
           -15.148007102335264,
           -15.164454688544577,
           -15.18090227475389,
           -15.197349860963204,
           -15.21379744717252,
           -15.230245033381834,
           -15.24669261959115,
           -15.263140205800465,
           -15.279587792009778,
           -15.296035378219093,
           -15.312482964428408,
           -15.328930550637722,
           -15.345110938702126,
           -15.361157727694074,
           -15.377204516686023,
           -15.393251305677971,
           -15.409298094669918,
           -15.42534488366187,
           -15.441391672653818,
           -15.457438461645769,
           -15.473485250637715,
           -15.489532039629665,
           -15.505578828621612,
           -15.521625617613562,
           -15.537672406605509,
           -15.553719195597457,
           -15.569765984589406,
           -15.585812773581353,
           -15.601859562573303,
           -15.617906351565251,
           -15.6339531405572,
           -15.649999929549146,
           -15.666046718541095,
           -15.682093507533047,
           -15.698140296524993,
           -15.714187085516942,
           -15.73023387450889,
           -15.746280663500837,
           -15.762327452492787,
           -15.778374241484734,
           -15.794421030476682,
           -15.81046781946863,
           -15.826514608460581,
           -15.842561397452531,
           -15.858608186444478,
           -15.874654975436425,
           -15.890701764428373,
           -15.906748553420323,
           -15.922795342412272,
           -15.938842131404218,
           -15.954888920396167,
           -15.970935709388117,
           -15.986982498380065,
           -16.003029287372012,
           -16.019076076363962,
           -16.035122865355913,
           -16.05116965434786,
           -16.06721644333981,
           -16.083263232331756,
           -16.099310021323703,
           -16.115356810315653,
           -16.1314035993076,
           -16.14745038829955,
           -16.163497177291497,
           -16.179543966283447,
           -16.195590755275393,
           -16.21163754426734,
           -16.228995206552955,
           -16.247204941183853,
           -16.265414675814753,
           -16.283624410445654,
           -16.301834145076555,
           -16.320043879707452,
           -16.338253614338353,
           -16.356463348969253,
           -16.37467308360015,
           -16.392882818231048,
           -16.41109255286195,
           -16.42930228749285,
           -16.44751202212375,
           -16.465721756754647,
           -16.483931491385547,
           -16.502141226016448,
           -16.520350960647345,
           -16.538560695278246,
           -16.556770429909147,
           -16.574980164540044,
           -16.593189899170945,
           -16.611399633801845,
           -16.629609368432746,
           -16.647819103063643,
           -16.66602883769454,
           -16.68423857232544,
           -16.70244830695634,
           -16.72065804158724,
           -16.740969370018316,
           -16.763382292249574,
           -16.785795214480828,
           -16.808208136712082,
           -16.83062105894334,
           -16.85303398117459,
           -16.875446903405845,
           -16.897859825637102,
           -16.92027274786836,
           -16.94268567009961,
           -16.965098592330865,
           -16.987511514562122,
           -17.009924436793376,
           -17.03233735902463,
           -17.054750281255888,
           -17.07716320348714,
           -17.099576125718396,
           -17.12198904794965,
           -17.144401970180905,
           -17.16681489241216,
           -17.189227814643417,
           -17.211640736874674,
           -17.234053659105925,
           -17.25646658133718,
           -17.278879503568437,
           -17.30129242579969,
           -17.323705348030945,
           -17.3461182702622,
           -17.368531192493453,
           -17.39094411472471,
           -17.413357036955965,
           -17.43576995918722,
           -17.458182881418473,
           -17.480595803649727,
           -17.503008725880985,
           -17.525421648112236,
           -17.547834570343493,
           -17.570247492574747,
           -17.592660414806,
           -17.615073337037256,
           -17.637486259268513,
           -17.659899181499767,
           -17.682312103731018,
           -17.704725025962276,
           -17.727137948193533,
           -17.749550870424784,
           -17.77196379265604,
           -17.794376714887296,
           -17.81678963711855,
           -17.8392025593498,
           -17.861615481581058,
           -17.884028403812312,
           -17.906441326043566,
           -17.928854248274824,
           -17.95126717050608,
           -17.973680092737332,
           -17.99609301496859,
           -18.018505937199844,
           -18.040918859431102,
           -18.06225715602689,
           -18.083322534745854,
           -18.10438791346482,
           -18.12545329218378,
           -18.146518670902744,
           -18.167584049621702,
           -18.188649428340664,
           -18.20971480705963,
           -18.230780185778592,
           -18.251845564497554,
           -18.272910943216516,
           -18.293976321935478,
           -18.31504170065444,
           -18.336107079373402,
           -18.357172458092368,
           -18.378237836811326,
           -18.39930321553029,
           -18.420368594249254,
           -18.441433972968213,
           -18.462499351687175,
           -18.48356473040614,
           -18.504630109125102,
           -18.525695487844065,
           -18.546760866563027,
           -18.560092488401885,
           -18.55795659648054,
           -18.5558207045592,
           -18.553684812637854,
           -18.55154892071651,
           -18.54941302879517,
           -18.547277136873824,
           -18.545141244952482,
           -18.543005353031138,
           -18.540869461109793,
           -18.53873356918845,
           -18.536597677267107,
           -18.534461785345766,
           -18.53232589342442,
           -18.530190001503076,
           -18.52805410958173,
           -18.52591821766039,
           -18.523782325739045,
           -18.521646433817704,
           -18.514794864048447,
           -18.50637139760652,
           -18.497947931164596,
           -18.48952446472267,
           -18.481100998280745,
           -18.47267753183882,
           -18.464254065396897,
           -18.45583059895497,
           -18.44740713251305,
           -18.438983666071124,
           -18.4305601996292,
           -18.422136733187273,
           -18.41371326674535,
           -18.405289800303425,
           -18.3968663338615,
           -18.388442867419574,
           -18.380019400977652,
           -18.371595934535726,
           -18.3631724680938,
           -18.35474900165188,
           -18.346325535209953,
           -18.33790206876803,
           -18.329478602326105,
           -18.32105513588418,
           -18.312631669442254,
           -18.30420820300033,
           -18.295784736558407,
           -18.28736127011648,
           -18.27893780367456,
           -18.270514337232633,
           -18.262090870790708,
           -18.253667404348782,
           -18.24524393790686,
           -18.236820471464934,
           -18.22839700502301,
           -18.219973538581087,
           -18.21155007213916,
           -18.203126605697236,
           -18.19470313925531,
           -18.186279672813384,
           -18.177856206371462,
           -18.16943273992954,
           -18.161009273487615,
           -18.15258580704569,
           -18.144162340603764,
           -18.135738874161838,
           -18.127315407719912,
           -18.118891941277987,
           -18.11046847483607,
           -18.102045008394143,
           -18.093621541952217,
           -18.08519807551029,
           -18.07677460906837,
           -18.068351142626444,
           -18.059927676184518,
           -18.051504209742596,
           -18.04308074330067,
           -18.034657276858745,
           -18.02623381041682,
           -18.017810343974894,
           -18.009386877532968,
           -18.000963411091046,
           -17.992539944649124,
           -17.9841164782072,
           -17.99568932540567,
           -18.107243740806116,
           -18.218798156206564,
           -18.330352571607012,
           -18.441906987007442,
           -18.553461402407887,
           -18.665015817808335,
           -18.776570233208766,
           -18.888124648609214,
           -18.999679064009662,
           -19.11123347941009,
           -19.22278789481054,
           -19.334342310210985,
           -19.445896725611433,
           -19.557451141011864,
           -19.66900555641231,
           -19.78055997181276,
           -19.892114387213187,
           -20.003668802613635,
           -20.115223218014084,
           -20.22677763341451,
           -20.33833204881496,
           -20.449886464215407,
           -20.561440879615834,
           -20.672995295016282,
           -20.784549710416734,
           -20.896104125817182,
           -21.00765854121761,
           -21.119212956618057,
           -21.230767372018505,
           -21.33770037207567,
           -21.423799211310254,
           -21.50989805054484,
           -21.595996889779407,
           -21.682095729013994,
           -21.768194568248582,
           -21.854293407483162,
           -21.94039224671773,
           -22.026491085952316,
           -22.1125899251869,
           -22.19868876442147,
           -22.284787603656053,
           -22.217948233763558,
           -22.041867285923228,
           -21.865786338082863,
           -21.689705390242498,
           -21.513624442402165,
           -21.3375434945618,
           -21.161462546721435,
           -20.985381598881073,
           -20.80930065104074,
           -20.63321970320038,
           -20.45713875536001,
           -20.281057807519677,
           -20.05343543139422,
           -19.825034450255945,
           -19.596633469117712,
           -19.368232487979434,
           -19.139831506841155,
           -18.91143052570288,
           -18.683029544564647,
           -18.45462856342637,
           -18.226227582288093,
           -17.997826601149857,
           -17.76942562001158,
           -17.541024638873303,
           -17.312623657735067,
           -17.08422267659679,
           -16.855821695458513,
           -16.62742071432028,
           -16.399019733182,
           -16.170618752043723,
           -15.94221777090545,
           -15.713816789767215,
           -15.485415808628936,
           -15.25701482749066,
           -15.028613846352426,
           -14.80021286521415,
           -14.571811884075872,
           -14.343410902937638,
           -14.11500992179936,
           -13.886608940661084,
           -13.658207959522805,
           -13.42980697838457
          ],
          [
           -12.17701440967491,
           -12.19528028902895,
           -12.213546168382987,
           -12.231812047737025,
           -12.250077927091063,
           -12.268343806445102,
           -12.286609685799139,
           -12.304875565153177,
           -12.323141444507215,
           -12.341407323861254,
           -12.35967320321529,
           -12.377939082569329,
           -12.396204961923367,
           -12.414470841277405,
           -12.432736720631443,
           -12.45100259998548,
           -12.469268479339519,
           -12.487534358693557,
           -12.505800238047595,
           -12.524066117401633,
           -12.54233199675567,
           -12.560597876109707,
           -12.578863755463745,
           -12.597129634817785,
           -12.615395514171823,
           -12.633661393525859,
           -12.651927272879899,
           -12.670193152233935,
           -12.686443397265919,
           -12.70229051510033,
           -12.718137632934742,
           -12.733984750769155,
           -12.749831868603565,
           -12.765678986437978,
           -12.78152610427239,
           -12.797373222106803,
           -12.813220339941214,
           -12.829067457775626,
           -12.844914575610037,
           -12.860761693444449,
           -12.87660881127886,
           -12.892455929113273,
           -12.908303046947685,
           -12.924150164782098,
           -12.93999728261651,
           -12.955844400450921,
           -12.971691518285333,
           -12.987538636119744,
           -13.003385753954156,
           -13.019232871788569,
           -13.03507998962298,
           -13.05092710745739,
           -13.066774225291805,
           -13.082621343126217,
           -13.098468460960628,
           -13.11431557879504,
           -13.130162696629453,
           -13.146009814463865,
           -13.161856932298274,
           -13.17770405013269,
           -13.1935511679671,
           -13.20939828580151,
           -13.225245403635924,
           -13.241092521470337,
           -13.256939639304747,
           -13.27278675713916,
           -13.288633874973572,
           -13.304480992807983,
           -13.320328110642395,
           -13.336175228476808,
           -13.35202234631122,
           -13.367869464145631,
           -13.383716581980043,
           -13.399563699814456,
           -13.415410817648866,
           -13.431257935483279,
           -13.447105053317692,
           -13.462952171152104,
           -13.478799288986515,
           -13.494646406820927,
           -13.51049352465534,
           -13.52634064248975,
           -13.542187760324163,
           -13.558034878158574,
           -13.572144911904001,
           -13.585907528831632,
           -13.59967014575926,
           -13.613432762686891,
           -13.62719537961452,
           -13.64095799654215,
           -13.654720613469781,
           -13.66848323039741,
           -13.682245847325039,
           -13.696008464252671,
           -13.7097710811803,
           -13.723533698107929,
           -13.73729631503556,
           -13.75105893196319,
           -13.764821548890819,
           -13.778584165818447,
           -13.79234678274608,
           -13.806109399673709,
           -13.819872016601337,
           -13.833634633528966,
           -13.847397250456595,
           -13.861159867384227,
           -13.874922484311856,
           -13.888685101239485,
           -13.902447718167117,
           -13.916210335094746,
           -13.929972952022375,
           -13.943735568950006,
           -13.957498185877636,
           -13.971260802805265,
           -13.985023419732894,
           -13.998786036660523,
           -14.012548653588155,
           -14.026311270515784,
           -14.040073887443413,
           -14.053836504371045,
           -14.067599121298674,
           -14.081361738226303,
           -14.095124355153931,
           -14.108886972081562,
           -14.122649589009193,
           -14.136412205936821,
           -14.150174822864452,
           -14.16393743979208,
           -14.177700056719711,
           -14.19146267364734,
           -14.205225290574969,
           -14.218987907502601,
           -14.23275052443023,
           -14.246513141357863,
           -14.260275758285491,
           -14.274038375213118,
           -14.287800992140749,
           -14.301563609068378,
           -14.315326225996008,
           -14.329088842923639,
           -14.34508893456086,
           -14.361536520770176,
           -14.37798410697949,
           -14.394431693188803,
           -14.41087927939812,
           -14.427326865607434,
           -14.443774451816747,
           -14.460222038026062,
           -14.476669624235377,
           -14.493117210444693,
           -14.509564796654006,
           -14.526012382863323,
           -14.542459969072635,
           -14.558907555281948,
           -14.575355141491263,
           -14.591802727700577,
           -14.608250313909892,
           -14.624697900119207,
           -14.641145486328522,
           -14.657593072537837,
           -14.674040658747153,
           -14.690488244956466,
           -14.70693583116578,
           -14.723383417375096,
           -14.73983100358441,
           -14.756278589793725,
           -14.772726176003038,
           -14.788906564067442,
           -14.804953353059393,
           -14.82100014205134,
           -14.837046931043288,
           -14.853093720035236,
           -14.869140509027186,
           -14.885187298019135,
           -14.901234087011082,
           -14.91728087600303,
           -14.933327664994978,
           -14.949374453986927,
           -14.965421242978877,
           -14.981468031970826,
           -14.997514820962774,
           -15.013561609954722,
           -15.029608398946671,
           -15.04565518793862,
           -15.061701976930568,
           -15.077748765922514,
           -15.093795554914461,
           -15.109842343906411,
           -15.12588913289836,
           -15.141935921890308,
           -15.157982710882258,
           -15.174029499874205,
           -15.190076288866155,
           -15.206123077858104,
           -15.222169866850049,
           -15.238216655841999,
           -15.254263444833947,
           -15.270310233825898,
           -15.286357022817846,
           -15.302403811809793,
           -15.31845060080174,
           -15.334497389793691,
           -15.35054417878564,
           -15.366590967777586,
           -15.382637756769537,
           -15.398684545761483,
           -15.414731334753434,
           -15.43077812374538,
           -15.44682491273733,
           -15.462871701729277,
           -15.478918490721226,
           -15.494965279713174,
           -15.511012068705123,
           -15.527058857697071,
           -15.54310564668902,
           -15.559152435680968,
           -15.575199224672918,
           -15.591246013664867,
           -15.607292802656813,
           -15.623339591648763,
           -15.639386380640712,
           -15.655433169632659,
           -15.671479958624607,
           -15.687526747616557,
           -15.703573536608506,
           -15.719620325600452,
           -15.7356671145924,
           -15.75171390358435,
           -15.767760692576298,
           -15.783807481568246,
           -15.799854270560196,
           -15.815901059552143,
           -15.83194784854409,
           -15.847994637536042,
           -15.86404142652799,
           -15.880088215519937,
           -15.896135004511887,
           -15.912181793503834,
           -15.928228582495784,
           -15.94427537148773,
           -15.960322160479679,
           -15.976368949471627,
           -15.992415738463576,
           -16.008462527455524,
           -16.024509316447475,
           -16.04186697972804,
           -16.06007671435894,
           -16.07828644898984,
           -16.09649618362074,
           -16.11470591825164,
           -16.135017246682715,
           -16.157430168913972,
           -16.179843091145226,
           -16.20225601337648,
           -16.224668935607735,
           -16.24708185783899,
           -16.269494780070243,
           -16.291907702301504,
           -16.314320624532755,
           -16.336733546764005,
           -16.359146468995267,
           -16.3804335932165,
           -16.40149897193546,
           -16.422564350654426,
           -16.443629729373388,
           -16.46469510809235,
           -16.48576048681131,
           -16.506825865530274,
           -16.527891244249233,
           -16.5489566229682,
           -16.57002200168716,
           -16.591087380406123,
           -16.612152759125085,
           -16.633218137844047,
           -16.65428351656301,
           -16.67534889528197,
           -16.696414274000933,
           -16.7174796527199,
           -16.73854503143886,
           -16.759610410157823,
           -16.780675788876785,
           -16.801741167595747,
           -16.82280654631471,
           -16.84387192503367,
           -16.864937303752633,
           -16.8860026824716,
           -16.907068061190557,
           -16.92813343990952,
           -16.94919881862848,
           -16.970264197347444,
           -16.99132957606641,
           -17.012394954785368,
           -17.03346033350433,
           -17.054525712223295,
           -17.075591090942257,
           -17.09665646966122,
           -17.11772184838018,
           -17.138787227099147,
           -17.15985260581811,
           -17.180917984537068,
           -17.201983363256033,
           -17.223048741974996,
           -17.244114120693958,
           -17.26517949941292,
           -17.286244878131882,
           -17.307310256850844,
           -17.328375635569806,
           -17.34944101428877,
           -17.37050639300773,
           -17.391571771726692,
           -17.412637150445654,
           -17.433702529164616,
           -17.45476790788358,
           -17.475833286602544,
           -17.496898665321503,
           -17.51796404404047,
           -17.53902942275943,
           -17.560094801478392,
           -17.581160180197354,
           -17.602225558916317,
           -17.623290937635282,
           -17.64435631635424,
           -17.665421695073206,
           -17.686487073792165,
           -17.707552452511127,
           -17.72861783123009,
           -17.74968320994905,
           -17.770748588668013,
           -17.791813967386975,
           -17.812879346105937,
           -17.833944724824903,
           -17.855010103543865,
           -17.876075482262827,
           -17.889407104101686,
           -17.887271212180345,
           -17.885135320259,
           -17.882999428337655,
           -17.88086353641631,
           -17.87872764449497,
           -17.876591752573624,
           -17.874455860652283,
           -17.87231996873094,
           -17.870184076809597,
           -17.868048184888252,
           -17.86591229296691,
           -17.863776401045566,
           -17.86164050912422,
           -17.859504617202877,
           -17.857368725281532,
           -17.85523283336019,
           -17.85309694143885,
           -17.850961049517505,
           -17.84882515759616,
           -17.84668926567482,
           -17.844553373753474,
           -17.842417481832133,
           -17.840281589910788,
           -17.838145697989443,
           -17.8360098060681,
           -17.833873914146757,
           -17.831738022225412,
           -17.82960213030407,
           -17.827466238382726,
           -17.82533034646138,
           -17.82319445454004,
           -17.821058562618695,
           -17.818922670697354,
           -17.81678677877601,
           -17.814650886854665,
           -17.812514994933323,
           -17.810379103011982,
           -17.808243211090634,
           -17.806107319169293,
           -17.80397142724795,
           -17.801835535326607,
           -17.79969964340526,
           -17.797563751483917,
           -17.795427859562572,
           -17.79329196764123,
           -17.791156075719886,
           -17.789020183798545,
           -17.7868842918772,
           -17.784748399955856,
           -17.782612508034518,
           -17.780476616113173,
           -17.77834072419183,
           -17.776204832270484,
           -17.774068940349142,
           -17.770300689582893,
           -17.761877223140967,
           -17.75345375669904,
           -17.74503029025712,
           -17.736606823815194,
           -17.72818335737327,
           -17.719759890931346,
           -17.71133642448942,
           -17.702912958047495,
           -17.694489491605573,
           -17.686066025163647,
           -17.677642558721722,
           -17.669219092279796,
           -17.66079562583787,
           -17.652372159395945,
           -17.643948692954023,
           -17.6355252265121,
           -17.627101760070175,
           -17.61867829362825,
           -17.610254827186324,
           -17.6018313607444,
           -17.593407894302473,
           -17.58498442786055,
           -17.576560961418625,
           -17.5681374949767,
           -17.559714028534778,
           -17.551290562092852,
           -17.54286709565093,
           -17.5544399428494,
           -17.665994358249847,
           -17.777548773650295,
           -17.889103189050743,
           -18.00065760445117,
           -18.11221201985162,
           -18.223766435252067,
           -18.335320850652494,
           -18.446875266052945,
           -18.558429681453394,
           -18.669984096853824,
           -18.781538512254272,
           -18.89309292765472,
           -19.001503286441338,
           -19.087602125675907,
           -19.173700964910488,
           -19.259799804145075,
           -19.345898643379645,
           -19.43199748261423,
           -19.518096321848816,
           -19.604195161083382,
           -19.690294000317966,
           -19.77639283955255,
           -19.86249167878712,
           -19.948590518021703,
           -20.034689357256287,
           -20.120788196490874,
           -20.20688703572544,
           -20.292985874960024,
           -20.37908471419461,
           -20.465183553429178,
           -20.55128239266376,
           -20.63738123189835,
           -20.72348007113292,
           -20.809578910367502,
           -20.895677749602086,
           -20.98177658883667,
           -21.06787542807124,
           -21.153974267305827,
           -21.24007310654041,
           -21.326171945774977,
           -21.412270785009564,
           -21.34543141511707,
           -21.16935046727674,
           -20.99326951943637,
           -20.817188571596006,
           -20.641107623755676,
           -20.46502667591531,
           -20.288945728074946,
           -20.11286478023458,
           -19.936783832394248,
           -19.760702884553883,
           -19.584621936713518,
           -19.408540988873185,
           -19.23246004103282,
           -19.056379093192454,
           -18.880298145352125,
           -18.70421719751176,
           -18.528136249671395,
           -18.35205530183103,
           -18.175974353990696,
           -17.99989340615033,
           -17.823812458309966,
           -17.647731510469637,
           -17.47165056262927,
           -17.295569614788906,
           -17.119488666948573,
           -16.943407719108208,
           -16.767326771267847,
           -16.59124582342751,
           -16.41290699627868,
           -16.1845060151404,
           -15.956105034002123,
           -15.727704052863887,
           -15.49930307172561,
           -15.270902090587336,
           -15.042501109449098,
           -14.814100128310823,
           -14.585699147172546,
           -14.35729816603431,
           -14.128897184896037,
           -13.900496203757754,
           -13.672095222619479,
           -13.443694241481243
          ],
          [
           -11.705021590479213,
           -11.723287469833252,
           -11.741553349187289,
           -11.759819228541327,
           -11.778085107895365,
           -11.796350987249404,
           -11.814616866603439,
           -11.832882745957477,
           -11.851148625311517,
           -11.869414504665555,
           -11.887680384019593,
           -11.905140011130136,
           -11.92098712896455,
           -11.93683424679896,
           -11.952681364633372,
           -11.968528482467784,
           -11.984375600302197,
           -12.000222718136609,
           -12.01606983597102,
           -12.031916953805434,
           -12.047764071639845,
           -12.063611189474257,
           -12.079458307308668,
           -12.095305425143081,
           -12.111152542977493,
           -12.126999660811904,
           -12.142846778646316,
           -12.158693896480727,
           -12.174541014315139,
           -12.19038813214955,
           -12.206235249983964,
           -12.222082367818377,
           -12.237929485652788,
           -12.2537766034872,
           -12.269623721321611,
           -12.285470839156023,
           -12.301317956990436,
           -12.317165074824848,
           -12.33301219265926,
           -12.34885931049367,
           -12.364706428328084,
           -12.380553546162496,
           -12.396400663996907,
           -12.412247781831319,
           -12.42809489966573,
           -12.443942017500142,
           -12.459789135334555,
           -12.475636253168968,
           -12.49148337100338,
           -12.507330488837791,
           -12.523177606672203,
           -12.539024724506614,
           -12.55487184234103,
           -12.570718960175437,
           -12.586566078009849,
           -12.602413195844262,
           -12.618260313678675,
           -12.634107431513087,
           -12.649954549347498,
           -12.665801667181912,
           -12.681648785016321,
           -12.697495902850736,
           -12.713343020685146,
           -12.72919013851956,
           -12.745037256353971,
           -12.760884374188384,
           -12.776731492022794,
           -12.792578609857205,
           -12.808425727691619,
           -12.82427284552603,
           -12.840119963360443,
           -12.855967081194855,
           -12.871814199029266,
           -12.887661316863678,
           -12.903508434698091,
           -12.919355552532503,
           -12.935202670366914,
           -12.951049788201326,
           -12.966896906035737,
           -12.98274402387015,
           -12.998591141704562,
           -13.014438259538975,
           -13.030285377373385,
           -13.046132495207797,
           -13.060242528953225,
           -13.074005145880854,
           -13.087767762808483,
           -13.101530379736113,
           -13.115292996663744,
           -13.129055613591373,
           -13.142818230519001,
           -13.156580847446634,
           -13.170343464374263,
           -13.184106081301895,
           -13.197868698229522,
           -13.211631315157152,
           -13.22539393208478,
           -13.23915654901241,
           -13.25291916594004,
           -13.26668178286767,
           -13.2804443997953,
           -13.29420701672293,
           -13.307969633650561,
           -13.321732250578192,
           -13.33549486750582,
           -13.34925748443345,
           -13.36302010136108,
           -13.376782718288709,
           -13.39054533521634,
           -13.404307952143967,
           -13.418070569071599,
           -13.431833185999228,
           -13.445595802926857,
           -13.459358419854489,
           -13.473121036782118,
           -13.486883653709747,
           -13.500646270637379,
           -13.514408887565008,
           -13.528171504492637,
           -13.541934121420267,
           -13.555696738347894,
           -13.569459355275526,
           -13.583221972203155,
           -13.596984589130784,
           -13.610747206058416,
           -13.624509822986045,
           -13.638272439913676,
           -13.652035056841306,
           -13.665797673768934,
           -13.679560290696564,
           -13.693322907624193,
           -13.707085524551825,
           -13.720848141479454,
           -13.734610758407083,
           -13.748373375334712,
           -13.76213599226234,
           -13.775898609189971,
           -13.789661226117602,
           -13.80342384304523,
           -13.817186459972861,
           -13.830949076900488,
           -13.84471169382812,
           -13.85847431075575,
           -13.872236927683378,
           -13.885999544611009,
           -13.89976216153864,
           -13.913524778466272,
           -13.927287395393899,
           -13.94105001232153,
           -13.954812629249158,
           -13.968575246176789,
           -13.982337863104421,
           -13.996100480032048,
           -14.009863096959677,
           -14.02362571388731,
           -14.037388330814936,
           -14.052045939275208,
           -14.068493525484524,
           -14.084941111693837,
           -14.101388697903152,
           -14.117836284112467,
           -14.134283870321783,
           -14.150731456531098,
           -14.167179042740411,
           -14.183626628949725,
           -14.20007421515904,
           -14.216521801368355,
           -14.232702189432759,
           -14.248748978424707,
           -14.264795767416656,
           -14.280842556408604,
           -14.296889345400551,
           -14.312936134392501,
           -14.32898292338445,
           -14.345029712376398,
           -14.361076501368348,
           -14.377123290360295,
           -14.393170079352243,
           -14.409216868344192,
           -14.42526365733614,
           -14.441310446328089,
           -14.457357235320037,
           -14.473404024311986,
           -14.489450813303934,
           -14.505497602295883,
           -14.521544391287833,
           -14.53759118027978,
           -14.55363796927173,
           -14.569684758263676,
           -14.585731547255627,
           -14.601778336247577,
           -14.617825125239522,
           -14.63387191423147,
           -14.649918703223417,
           -14.665965492215367,
           -14.682012281207315,
           -14.698059070199264,
           -14.71410585919121,
           -14.73015264818316,
           -14.746199437175111,
           -14.762246226167058,
           -14.778293015159006,
           -14.794339804150955,
           -14.810386593142903,
           -14.826433382134853,
           -14.841567736178273,
           -14.85662605281339,
           -14.871684369448506,
           -14.886742686083622,
           -14.901801002718738,
           -14.916859319353854,
           -14.93191763598897,
           -14.946975952624086,
           -14.962034269259203,
           -14.977092585894317,
           -14.992150902529435,
           -15.007209219164551,
           -15.022267535799667,
           -15.037325852434783,
           -15.0523841690699,
           -15.067442485705014,
           -15.082500802340128,
           -15.097559118975246,
           -15.112617435610362,
           -15.12767575224548,
           -15.142734068880594,
           -15.157792385515709,
           -15.172850702150825,
           -15.187909018785941,
           -15.202967335421059,
           -15.218025652056173,
           -15.23308396869129,
           -15.248142285326406,
           -15.263200601961522,
           -15.278258918596638,
           -15.293317235231754,
           -15.30837555186687,
           -15.323433868501986,
           -15.338492185137103,
           -15.353550501772219,
           -15.368608818407333,
           -15.383667135042451,
           -15.398725451677565,
           -15.413783768312681,
           -15.4288420849478,
           -15.443900401582916,
           -15.45895871821803,
           -15.474017034853148,
           -15.489075351488262,
           -15.504133668123377,
           -15.521769184056334,
           -15.54198189928713,
           -15.562194614517924,
           -15.582407329748717,
           -15.602620044979513,
           -15.622832760210308,
           -15.643045475441104,
           -15.6632581906719,
           -15.683470905902695,
           -15.70368362113349,
           -15.723896336364286,
           -15.744109051595082,
           -15.764321766825875,
           -15.784534482056669,
           -15.804747197287465,
           -15.82495991251826,
           -15.845172627749053,
           -15.865385342979849,
           -15.885598058210645,
           -15.905810773441438,
           -15.926023488672236,
           -15.94623620390303,
           -15.966448919133823,
           -15.98666163436462,
           -16.006874349595414,
           -16.027087064826212,
           -16.047299780057006,
           -16.0675124952878,
           -16.087725210518595,
           -16.10793792574939,
           -16.128150640980188,
           -16.148363356210986,
           -16.168576071441777,
           -16.18878878667257,
           -16.209001501903366,
           -16.22921421713416,
           -16.249426932364955,
           -16.269639647595753,
           -16.289852362826547,
           -16.31006507805734,
           -16.33027779328814,
           -16.35049050851893,
           -16.370703223749725,
           -16.390915938980523,
           -16.411128654211318,
           -16.43134136944211,
           -16.451554084672907,
           -16.471766799903705,
           -16.4919795151345,
           -16.51219223036529,
           -16.532404945596088,
           -16.552617660826883,
           -16.57342873639376,
           -16.594494115112717,
           -16.615559493831682,
           -16.63662487255064,
           -16.657690251269607,
           -16.678755629988572,
           -16.69982100870753,
           -16.720886387426493,
           -16.741951766145455,
           -16.76301714486442,
           -16.78408252358338,
           -16.805147902302345,
           -16.826213281021303,
           -16.847278659740265,
           -16.868344038459227,
           -16.889409417178193,
           -16.91047479589715,
           -16.931540174616117,
           -16.95260555333508,
           -16.97367093205404,
           -16.994736310773003,
           -17.015801689491965,
           -17.03686706821093,
           -17.05793244692989,
           -17.078997825648855,
           -17.100063204367814,
           -17.121128583086776,
           -17.142193961805738,
           -17.163259340524704,
           -17.184324719243666,
           -17.205390097962628,
           -17.218721719801486,
           -17.21658582788014,
           -17.214449935958797,
           -17.212314044037456,
           -17.210178152116114,
           -17.20804226019477,
           -17.205906368273425,
           -17.20377047635208,
           -17.20163458443074,
           -17.199498692509394,
           -17.197362800588053,
           -17.19522690866671,
           -17.193091016745363,
           -17.190955124824022,
           -17.18881923290268,
           -17.186683340981332,
           -17.18454744905999,
           -17.182411557138646,
           -17.1802756652173,
           -17.17813977329596,
           -17.17600388137462,
           -17.173867989453274,
           -17.17173209753193,
           -17.169596205610585,
           -17.16746031368924,
           -17.1653244217679,
           -17.163188529846558,
           -17.161052637925213,
           -17.15891674600387,
           -17.156780854082527,
           -17.154644962161182,
           -17.152509070239837,
           -17.150373178318493,
           -17.14823728639715,
           -17.146101394475807,
           -17.143965502554465,
           -17.141829610633124,
           -17.139693718711776,
           -17.137557826790434,
           -17.135421934869093,
           -17.13328604294775,
           -17.131150151026407,
           -17.129014259105062,
           -17.12687836718372,
           -17.124742475262373,
           -17.12260658334103,
           -17.120470691419687,
           -17.118334799498342,
           -17.116198907577,
           -17.114063015655656,
           -17.11192712373431,
           -17.109791231812974,
           -17.10765533989163,
           -17.105519447970284,
           -17.10338355604894,
           -17.101247664127598,
           -17.099746281977936,
           -17.098994794208625,
           -17.098243306439315,
           -17.097491818670004,
           -17.096740330900694,
           -17.095988843131387,
           -17.095237355362073,
           -17.094485867592763,
           -17.093734379823456,
           -17.092982892054145,
           -17.092231404284835,
           -17.091479916515524,
           -17.090728428746214,
           -17.0899769409769,
           -17.089225453207593,
           -17.088473965438283,
           -17.08772247766897,
           -17.086970989899662,
           -17.08621950213035,
           -17.08546801436104,
           -17.08471652659173,
           -17.08396503882242,
           -17.08321355105311,
           -17.0824620632838,
           -17.081710575514485,
           -17.08095908774518,
           -17.080207599975868,
           -17.093481084821914,
           -17.17687943274473,
           -17.26027778066755,
           -17.34367612859037,
           -17.427074476513173,
           -17.510472824435993,
           -17.593871172358813,
           -17.677269520281616,
           -17.760667868204436,
           -17.844066216127256,
           -17.92746456405006,
           -18.01086291197288,
           -18.094261259895696,
           -18.177659607818516,
           -18.26105795574132,
           -18.34445630366414,
           -18.42785465158696,
           -18.511252999509765,
           -18.594651347432585,
           -18.6780496953554,
           -18.761448043278207,
           -18.844846391201024,
           -18.928244739123844,
           -19.01164308704665,
           -19.095041434969467,
           -19.178439782892287,
           -19.261838130815107,
           -19.34523647873791,
           -19.428634826660726,
           -19.512033174583546,
           -19.595431522506352,
           -19.678829870429173,
           -19.764864413251857,
           -19.850963252486427,
           -19.93706209172101,
           -20.023160930955598,
           -20.109259770190178,
           -20.19535860942475,
           -20.281457448659335,
           -20.36755628789392,
           -20.453655127128485,
           -20.539753966363072,
           -20.472914596470577,
           -20.296833648630248,
           -20.12075270078988,
           -19.944671752949517,
           -19.768590805109184,
           -19.59250985726882,
           -19.416428909428454,
           -19.24034796158809,
           -19.06426701374776,
           -18.88818606590739,
           -18.71321681081947,
           -18.542972261279218,
           -18.37272771173893,
           -18.202483162198643,
           -18.032238612658382,
           -17.861994063118097,
           -17.69174951357781,
           -17.52150496403752,
           -17.351260414497265,
           -17.181015864956976,
           -17.010771315416687,
           -16.840526765876433,
           -16.670282216336144,
           -16.500037666795855,
           -16.329793117255598,
           -16.159548567715312,
           -15.989304018175023,
           -15.819059468634766,
           -15.648814919094477,
           -15.478570369554191,
           -15.308325820013902,
           -15.138081270473647,
           -14.96783672093336,
           -14.797592171393072,
           -14.627347621852813,
           -14.457103072312526,
           -14.286858522772238,
           -14.116613973231981,
           -13.946369423691696,
           -13.776124874151405,
           -13.605880324611118,
           -13.43563577507086
          ],
          [
           -11.232187631477961,
           -11.245289159005898,
           -11.258390686533833,
           -11.27149221406177,
           -11.284593741589708,
           -11.297695269117646,
           -11.311254397649646,
           -11.327101515484058,
           -11.342948633318471,
           -11.358795751152883,
           -11.374642868987294,
           -11.390489986821708,
           -11.406337104656119,
           -11.422184222490529,
           -11.438031340324942,
           -11.453878458159354,
           -11.469725575993767,
           -11.485572693828177,
           -11.50141981166259,
           -11.517266929497001,
           -11.533114047331413,
           -11.548961165165826,
           -11.564808283000238,
           -11.580655400834651,
           -11.596502518669062,
           -11.612349636503472,
           -11.628196754337885,
           -11.644043872172297,
           -11.659890990006708,
           -11.675738107841122,
           -11.691585225675531,
           -11.707432343509947,
           -11.723279461344358,
           -11.73912657917877,
           -11.754973697013181,
           -11.770820814847593,
           -11.786667932682004,
           -11.802515050516417,
           -11.818362168350829,
           -11.834209286185242,
           -11.850056404019652,
           -11.865903521854065,
           -11.881750639688475,
           -11.897597757522888,
           -11.9134448753573,
           -11.929291993191711,
           -11.945139111026126,
           -11.960986228860534,
           -11.976833346694947,
           -11.99268046452936,
           -12.008527582363772,
           -12.024374700198184,
           -12.040221818032595,
           -12.056068935867007,
           -12.07191605370142,
           -12.087763171535832,
           -12.103610289370243,
           -12.119457407204656,
           -12.135304525039066,
           -12.151151642873478,
           -12.16699876070789,
           -12.182845878542302,
           -12.198692996376716,
           -12.214540114211125,
           -12.230387232045537,
           -12.24623434987995,
           -12.262081467714362,
           -12.277928585548775,
           -12.293775703383186,
           -12.309622821217598,
           -12.325469939052011,
           -12.341317056886421,
           -12.357164174720833,
           -12.373011292555246,
           -12.388858410389657,
           -12.40470552822407,
           -12.42055264605848,
           -12.436399763892892,
           -12.452246881727307,
           -12.468093999561718,
           -12.48394111739613,
           -12.499788235230541,
           -12.515635353064953,
           -12.531482470899366,
           -12.545592504644791,
           -12.559355121572423,
           -12.573117738500052,
           -12.586880355427681,
           -12.600642972355311,
           -12.61440558928294,
           -12.628168206210571,
           -12.641930823138201,
           -12.65569344006583,
           -12.669456056993461,
           -12.68321867392109,
           -12.69698129084872,
           -12.71074390777635,
           -12.72450652470398,
           -12.73826914163161,
           -12.752031758559237,
           -12.76579437548687,
           -12.779556992414498,
           -12.793319609342129,
           -12.80708222626976,
           -12.820844843197388,
           -12.834607460125017,
           -12.848370077052646,
           -12.862132693980277,
           -12.875895310907907,
           -12.889657927835536,
           -12.903420544763167,
           -12.917183161690796,
           -12.930945778618426,
           -12.944708395546055,
           -12.958471012473685,
           -12.972233629401316,
           -12.985996246328945,
           -12.999758863256574,
           -13.013521480184203,
           -13.027284097111835,
           -13.041046714039464,
           -13.054809330967093,
           -13.068571947894723,
           -13.082334564822354,
           -13.096097181749982,
           -13.109859798677611,
           -13.123622415605244,
           -13.137385032532872,
           -13.151147649460501,
           -13.164910266388132,
           -13.17867288331576,
           -13.192435500243391,
           -13.20619811717102,
           -13.219960734098652,
           -13.233723351026281,
           -13.24748596795391,
           -13.261248584881539,
           -13.27501120180917,
           -13.2887738187368,
           -13.30253643566443,
           -13.316299052592061,
           -13.33006166951969,
           -13.34382428644732,
           -13.357586903374951,
           -13.37134952030258,
           -13.38511213723021,
           -13.39887475415784,
           -13.41263737108547,
           -13.426399988013099,
           -13.440162604940728,
           -13.453925221868358,
           -13.467687838795989,
           -13.481450455723618,
           -13.495213072651246,
           -13.508975689578879,
           -13.522738306506506,
           -13.536500923434136,
           -13.550263540361767,
           -13.564026157289396,
           -13.577788774217026,
           -13.591551391144655,
           -13.603946545581596,
           -13.614974232308889,
           -13.626001919036183,
           -13.637029605763473,
           -13.648057292490767,
           -13.65908497921806,
           -13.671678102826524,
           -13.685053944875573,
           -13.698429786924626,
           -13.711805628973677,
           -13.725181471022726,
           -13.738557313071777,
           -13.751933155120827,
           -13.765308997169878,
           -13.778684839218927,
           -13.792060681267978,
           -13.8060189212062,
           -13.821077237841314,
           -13.83613555447643,
           -13.851193871111544,
           -13.866252187746662,
           -13.881310504381776,
           -13.896368821016894,
           -13.911427137652009,
           -13.926485454287125,
           -13.941543770922245,
           -13.956602087557357,
           -13.971660404192473,
           -13.98671872082759,
           -14.001777037462706,
           -14.016835354097823,
           -14.031893670732938,
           -14.046951987368054,
           -14.062010304003168,
           -14.077068620638286,
           -14.092126937273402,
           -14.107185253908517,
           -14.122243570543633,
           -14.13730188717875,
           -14.152360203813867,
           -14.167418520448983,
           -14.1824768370841,
           -14.197535153719215,
           -14.21259347035433,
           -14.227651786989446,
           -14.242710103624564,
           -14.257768420259676,
           -14.272826736894793,
           -14.287885053529909,
           -14.302943370165025,
           -14.318001686800143,
           -14.333060003435257,
           -14.348118320070375,
           -14.36317663670549,
           -14.378234953340606,
           -14.393293269975722,
           -14.408351586610838,
           -14.423409903245954,
           -14.43846821988107,
           -14.453526536516186,
           -14.468584853151302,
           -14.483643169786419,
           -14.498701486421535,
           -14.513759803056649,
           -14.528818119691767,
           -14.543876436326883,
           -14.558934752962,
           -14.573993069597115,
           -14.589051386232232,
           -14.604109702867348,
           -14.61916801950246,
           -14.634226336137578,
           -14.649284652772693,
           -14.664342969407812,
           -14.679401286042927,
           -14.694459602678043,
           -14.709517919313157,
           -14.724576235948273,
           -14.739634552583391,
           -14.754692869218506,
           -14.76975118585362,
           -14.784809502488738,
           -14.799867819123854,
           -14.81492613575897,
           -14.829984452394086,
           -14.845042769029202,
           -14.860101085664317,
           -14.875159402299435,
           -14.89021771893455,
           -14.907853234867506,
           -14.9280659500983,
           -14.948278665329095,
           -14.968491380559891,
           -14.988704095790686,
           -15.008916811021482,
           -15.029129526252275,
           -15.049342241483071,
           -15.069554956713867,
           -15.08976767194466,
           -15.109980387175456,
           -15.130193102406253,
           -15.150405817637047,
           -15.170618532867842,
           -15.190831248098638,
           -15.211043963329432,
           -15.231256678560227,
           -15.251469393791021,
           -15.271682109021816,
           -15.291894824252612,
           -15.312107539483407,
           -15.332320254714205,
           -15.352532969944997,
           -15.372745685175794,
           -15.392958400406588,
           -15.413171115637384,
           -15.433383830868175,
           -15.453596546098973,
           -15.473809261329766,
           -15.494021976560562,
           -15.514234691791357,
           -15.534447407022155,
           -15.554660122252947,
           -15.574872837483746,
           -15.59508555271454,
           -15.615298267945334,
           -15.635510983176129,
           -15.655723698406923,
           -15.675936413637718,
           -15.696149128868512,
           -15.716361844099309,
           -15.736574559330103,
           -15.7567872745609,
           -15.776999989791694,
           -15.79721270502249,
           -15.817425420253283,
           -15.83763813548408,
           -15.857850850714875,
           -15.878063565945668,
           -15.898276281176464,
           -15.91848899640726,
           -15.938701711638055,
           -15.95891442686885,
           -15.979127142099646,
           -15.999339857330442,
           -16.019552572561235,
           -16.03976528779203,
           -16.059978003022827,
           -16.08019071825362,
           -16.100403433484416,
           -16.12061614871521,
           -16.140828863946005,
           -16.1610415791768,
           -16.181254294407594,
           -16.20146700963839,
           -16.221679724869183,
           -16.241892440099978,
           -16.26210515533078,
           -16.28231787056157,
           -16.30034692874024,
           -16.318069190406277,
           -16.33579145207231,
           -16.353513713738348,
           -16.371235975404385,
           -16.38895823707042,
           -16.406680498736456,
           -16.424402760402494,
           -16.44212502206853,
           -16.459847283734565,
           -16.477569545400602,
           -16.495291807066643,
           -16.513014068732673,
           -16.53073633039871,
           -16.543814788335528,
           -16.54760563881391,
           -16.55139648929229,
           -16.555187339770672,
           -16.558978190249054,
           -16.562769040727435,
           -16.566559891205817,
           -16.5703507416842,
           -16.57414159216258,
           -16.57793244264096,
           -16.581723293119342,
           -16.585514143597727,
           -16.589304994076105,
           -16.593095844554487,
           -16.596886695032868,
           -16.600677545511253,
           -16.60446839598963,
           -16.608259246468016,
           -16.612050096946398,
           -16.615840947424775,
           -16.61963179790316,
           -16.619544661309334,
           -16.61879317354002,
           -16.618041685770713,
           -16.6172901980014,
           -16.616538710232092,
           -16.615787222462778,
           -16.61503573469347,
           -16.61428424692416,
           -16.61353275915485,
           -16.612781271385536,
           -16.61202978361623,
           -16.611278295846923,
           -16.61052680807761,
           -16.609775320308298,
           -16.609023832538988,
           -16.608272344769677,
           -16.607520857000367,
           -16.60676936923106,
           -16.606017881461746,
           -16.60526639369244,
           -16.604514905923125,
           -16.603763418153818,
           -16.603011930384504,
           -16.602260442615197,
           -16.601508954845887,
           -16.600757467076576,
           -16.600005979307262,
           -16.599254491537955,
           -16.59850300376864,
           -16.597751515999335,
           -16.597000028230024,
           -16.596248540460714,
           -16.595497052691403,
           -16.59474556492209,
           -16.59399407715278,
           -16.593242589383472,
           -16.592491101614158,
           -16.59173961384485,
           -16.590988126075537,
           -16.590236638306227,
           -16.589485150536916,
           -16.58873366276761,
           -16.587982174998295,
           -16.58723068722899,
           -16.586479199459678,
           -16.585727711690367,
           -16.584976223921057,
           -16.584224736151747,
           -16.583473248382436,
           -16.582721760613126,
           -16.581970272843815,
           -16.581218785074505,
           -16.580467297305194,
           -16.579715809535884,
           -16.578964321766573,
           -16.578212833997263,
           -16.577461346227953,
           -16.576709858458642,
           -16.57595837068933,
           -16.57520688292002,
           -16.57445539515071,
           -16.573703907381404,
           -16.586977392227446,
           -16.670375740150263,
           -16.753774088073083,
           -16.837172435995903,
           -16.92057078391871,
           -17.00396913184153,
           -17.087367479764346,
           -17.170765827687152,
           -17.254164175609972,
           -17.33756252353279,
           -17.42096087145559,
           -17.504359219378415,
           -17.587757567301228,
           -17.671155915224052,
           -17.754554263146854,
           -17.837952611069674,
           -17.92135095899249,
           -18.004749306915297,
           -18.088147654838117,
           -18.171546002760937,
           -18.25494435068374,
           -18.338342698606557,
           -18.421741046529377,
           -18.505139394452183,
           -18.588537742375,
           -18.671936090297823,
           -18.75533443822064,
           -18.81835927066419,
           -18.87209241432042,
           -18.92582555797665,
           -18.979558701632875,
           -19.033291845289106,
           -19.08702498894534,
           -19.14075813260156,
           -19.194491276257796,
           -19.248224419914024,
           -19.301957563570255,
           -19.355690707226483,
           -19.409423850882714,
           -19.463156994538945,
           -19.516890138195166,
           -19.570623281851397,
           -19.526164362213322,
           -19.411568254507923,
           -19.296972146802503,
           -19.182376039097086,
           -19.06777993139169,
           -18.953183823686274,
           -18.838587715980854,
           -18.72399160827544,
           -18.60939550057004,
           -18.494799392864625,
           -18.380203285159205,
           -18.26560717745381,
           -18.151011069748392,
           -18.036414962042972,
           -17.921818854337577,
           -17.78051788859033,
           -17.610273339050046,
           -17.440028789509753,
           -17.269784239969496,
           -17.09953969042921,
           -16.92929514088892,
           -16.759050591348668,
           -16.58880604180838,
           -16.41856149226809,
           -16.248316942727833,
           -16.078072393187544,
           -15.907827843647256,
           -15.737583294107,
           -15.567338744566714,
           -15.397094195026424,
           -15.226849645486137,
           -15.05660509594588,
           -14.886360546405593,
           -14.716115996865305,
           -14.545871447325048,
           -14.375626897784759,
           -14.20538234824447,
           -14.035137798704216,
           -13.864893249163927,
           -13.694648699623638,
           -13.524404150083353,
           -13.354159600543095
          ],
          [
           -10.757815587847881,
           -10.770917115375818,
           -10.784018642903753,
           -10.79712017043169,
           -10.81022169795963,
           -10.823323225487567,
           -10.836424753015502,
           -10.849526280543438,
           -10.862627808071377,
           -10.875729335599313,
           -10.888830863127252,
           -10.901932390655189,
           -10.915033918183125,
           -10.928135445711062,
           -10.941236973239,
           -10.954338500766937,
           -10.967440028294874,
           -10.98054155582281,
           -10.993643083350747,
           -11.006744610878684,
           -11.01984613840662,
           -11.032947665934559,
           -11.046049193462494,
           -11.06098111669471,
           -11.076828234529124,
           -11.092675352363536,
           -11.108522470197947,
           -11.124369588032359,
           -11.14021670586677,
           -11.156063823701182,
           -11.171910941535595,
           -11.187758059370005,
           -11.20360517720442,
           -11.219452295038831,
           -11.235299412873243,
           -11.251146530707654,
           -11.266993648542066,
           -11.282840766376479,
           -11.298687884210889,
           -11.314535002045304,
           -11.330382119879713,
           -11.346229237714127,
           -11.362076355548538,
           -11.37792347338295,
           -11.393770591217361,
           -11.409617709051773,
           -11.425464826886186,
           -11.4413119447206,
           -11.457159062555009,
           -11.473006180389422,
           -11.488853298223834,
           -11.504700416058245,
           -11.520547533892657,
           -11.536394651727068,
           -11.552241769561482,
           -11.568088887395893,
           -11.583936005230306,
           -11.599783123064718,
           -11.61563024089913,
           -11.631477358733541,
           -11.647324476567952,
           -11.663171594402364,
           -11.679018712236777,
           -11.694865830071189,
           -11.710712947905602,
           -11.726560065740014,
           -11.742407183574423,
           -11.758254301408837,
           -11.774101419243248,
           -11.789948537077661,
           -11.805795654912073,
           -11.821642772746483,
           -11.837489890580896,
           -11.853337008415307,
           -11.86918412624972,
           -11.885031244084132,
           -11.900878361918545,
           -11.916725479752957,
           -11.932572597587368,
           -11.948419715421782,
           -11.964266833256193,
           -11.980113951090603,
           -11.995961068925016,
           -12.011808186759428,
           -12.025918220504852,
           -12.039680837432485,
           -12.053443454360112,
           -12.067206071287742,
           -12.080968688215371,
           -12.094731305143002,
           -12.108493922070632,
           -12.122256538998261,
           -12.136019155925892,
           -12.14978177285352,
           -12.163544389781151,
           -12.177307006708782,
           -12.19106962363641,
           -12.204832240564041,
           -12.218594857491672,
           -12.232357474419299,
           -12.246120091346928,
           -12.25988270827456,
           -12.273645325202189,
           -12.287407942129821,
           -12.30117055905745,
           -12.314933175985079,
           -12.328695792912708,
           -12.342458409840338,
           -12.356221026767969,
           -12.369983643695598,
           -12.383746260623226,
           -12.397508877550857,
           -12.411271494478488,
           -12.425034111406116,
           -12.438796728333747,
           -12.452559345261378,
           -12.466321962189006,
           -12.480084579116635,
           -12.493847196044264,
           -12.507609812971896,
           -12.521372429899525,
           -12.535135046827154,
           -12.548897663754786,
           -12.562660280682415,
           -12.576422897610044,
           -12.590185514537673,
           -12.603948131465303,
           -12.617710748392932,
           -12.631473365320565,
           -12.645235982248192,
           -12.658998599175824,
           -12.672761216103456,
           -12.686523833031085,
           -12.700286449958714,
           -12.714049066886343,
           -12.727811683813972,
           -12.741574300741602,
           -12.755336917669233,
           -12.769099534596862,
           -12.78286215152449,
           -12.796624768452121,
           -12.810387385379752,
           -12.82415000230738,
           -12.837912619235011,
           -12.851675236162642,
           -12.86270292504815,
           -12.873730611775443,
           -12.884758298502735,
           -12.895785985230027,
           -12.90681367195732,
           -12.917841358684614,
           -12.928869045411908,
           -12.939896732139196,
           -12.950924418866489,
           -12.961952105593781,
           -12.972979792321073,
           -12.984007479048369,
           -12.99503516577566,
           -13.006062852502952,
           -13.017090539230246,
           -13.028118225957538,
           -13.039145912684832,
           -13.050173599412124,
           -13.061201286139415,
           -13.072228972866709,
           -13.083256659594001,
           -13.094284346321293,
           -13.10687746992976,
           -13.120253311978809,
           -13.13362915402786,
           -13.147004996076909,
           -13.16038083812596,
           -13.17375668017501,
           -13.187132522224061,
           -13.200508364273112,
           -13.213884206322161,
           -13.227260048371212,
           -13.240635890420265,
           -13.254011732469314,
           -13.267387574518365,
           -13.280763416567414,
           -13.294139258616465,
           -13.307515100665515,
           -13.320890942714566,
           -13.334266784763617,
           -13.347642626812666,
           -13.361018468861715,
           -13.374394310910766,
           -13.387770152959819,
           -13.401145995008868,
           -13.414521837057919,
           -13.42789767910697,
           -13.441273521156017,
           -13.454649363205071,
           -13.46802520525412,
           -13.481401047303173,
           -13.494776889352222,
           -13.50815273140127,
           -13.521528573450322,
           -13.534904415499373,
           -13.548280257548422,
           -13.561656099597474,
           -13.575031941646522,
           -13.588407783695576,
           -13.601783625744623,
           -13.61515946779367,
           -13.628794154435727,
           -13.643852471070844,
           -13.65891078770596,
           -13.673969104341076,
           -13.689027420976192,
           -13.704085737611308,
           -13.719144054246424,
           -13.734202370881539,
           -13.749260687516657,
           -13.764319004151773,
           -13.779377320786889,
           -13.794435637422005,
           -13.80949395405712,
           -13.824552270692235,
           -13.839610587327352,
           -13.854668903962468,
           -13.869727220597584,
           -13.884785537232698,
           -13.899843853867816,
           -13.914902170502932,
           -13.929960487138048,
           -13.945018803773163,
           -13.960077120408279,
           -13.975135437043395,
           -13.990193753678511,
           -14.005252070313627,
           -14.020310386948745,
           -14.03536870358386,
           -14.050427020218978,
           -14.065485336854092,
           -14.080543653489208,
           -14.095601970124322,
           -14.11066028675944,
           -14.125718603394557,
           -14.140776920029673,
           -14.155835236664787,
           -14.170893553299905,
           -14.18595186993502,
           -14.201010186570135,
           -14.216068503205253,
           -14.231126819840368,
           -14.246185136475486,
           -14.2612434531106,
           -14.276301769745718,
           -14.293937285678672,
           -14.314150000909468,
           -14.334362716140262,
           -14.354575431371057,
           -14.374788146601853,
           -14.395000861832646,
           -14.41521357706344,
           -14.435426292294238,
           -14.455639007525033,
           -14.475851722755827,
           -14.496064437986625,
           -14.51627715321742,
           -14.536489868448212,
           -14.556702583679005,
           -14.576915298909805,
           -14.5971280141406,
           -14.617340729371392,
           -14.637553444602188,
           -14.657766159832983,
           -14.677978875063776,
           -14.698191590294574,
           -14.718404305525368,
           -14.738617020756163,
           -14.758829735986959,
           -14.779042451217755,
           -14.79925516644855,
           -14.819467881679344,
           -14.839680596910139,
           -14.859893312140933,
           -14.880106027371728,
           -14.900318742602526,
           -14.92053145783332,
           -14.940744173064113,
           -14.960956888294909,
           -14.981169603525705,
           -15.001382318756498,
           -15.021595033987294,
           -15.04180774921809,
           -15.062020464448885,
           -15.08223317967968,
           -15.102445894910474,
           -15.121720180169294,
           -15.139442441835332,
           -15.157164703501369,
           -15.174886965167403,
           -15.19260922683344,
           -15.210331488499477,
           -15.228053750165511,
           -15.245776011831548,
           -15.263498273497582,
           -15.281220535163621,
           -15.298942796829657,
           -15.31666505849569,
           -15.33438732016173,
           -15.352109581827765,
           -15.369831843493799,
           -15.38755410515984,
           -15.405276366825875,
           -15.42299862849191,
           -15.440720890157946,
           -15.458443151823984,
           -15.476165413490019,
           -15.493887675156056,
           -15.51160993682209,
           -15.529332198488127,
           -15.547054460154165,
           -15.564776721820198,
           -15.582498983486238,
           -15.600221245152271,
           -15.61794350681831,
           -15.635665768484346,
           -15.653388030150381,
           -15.671110291816417,
           -15.688832553482456,
           -15.70655481514849,
           -15.724277076814527,
           -15.741999338480564,
           -15.759721600146596,
           -15.777443861812635,
           -15.79516612347867,
           -15.812888385144706,
           -15.830610646810745,
           -15.84833290847678,
           -15.861411366413595,
           -15.86520221689198,
           -15.868993067370358,
           -15.872783917848743,
           -15.876574768327124,
           -15.880365618805504,
           -15.884156469283887,
           -15.887947319762269,
           -15.89173817024065,
           -15.89552902071903,
           -15.899319871197413,
           -15.903110721675795,
           -15.906901572154176,
           -15.910692422632557,
           -15.914483273110939,
           -15.91827412358932,
           -15.922064974067702,
           -15.925855824546083,
           -15.929646675024465,
           -15.933437525502846,
           -15.937228375981228,
           -15.94101922645961,
           -15.94481007693799,
           -15.948600927416372,
           -15.952391777894753,
           -15.956182628373135,
           -15.959973478851518,
           -15.963764329329898,
           -15.96755517980828,
           -15.97134603028666,
           -15.975136880765044,
           -15.978927731243424,
           -15.982718581721805,
           -15.986509432200188,
           -15.99030028267857,
           -15.994091133156951,
           -15.997881983635331,
           -16.001672834113712,
           -16.005463684592094,
           -16.009254535070475,
           -16.013045385548857,
           -16.01683623602724,
           -16.02062708650562,
           -16.024417936984005,
           -16.028208787462383,
           -16.031999637940764,
           -16.035790488419146,
           -16.039581338897527,
           -16.04337218937591,
           -16.047163039854293,
           -16.050953890332675,
           -16.054744740811053,
           -16.058535591289434,
           -16.06232644176782,
           -16.066117292246197,
           -16.069908142724582,
           -16.073698993202964,
           -16.077489843681345,
           -16.081280694159727,
           -16.08448443348107,
           -16.08373294571176,
           -16.082981457942445,
           -16.082229970173138,
           -16.081478482403828,
           -16.080726994634517,
           -16.079975506865207,
           -16.079224019095896,
           -16.078472531326586,
           -16.077721043557275,
           -16.076969555787965,
           -16.076218068018655,
           -16.075466580249344,
           -16.074715092480034,
           -16.073963604710723,
           -16.073212116941413,
           -16.072460629172102,
           -16.071709141402792,
           -16.07095765363348,
           -16.070206165864175,
           -16.069454678094864,
           -16.06870319032555,
           -16.067951702556243,
           -16.067200214786933,
           -16.080473699632975,
           -16.163872047555795,
           -16.247270395478616,
           -16.330668743401436,
           -16.414067091324238,
           -16.497465439247055,
           -16.580863787169875,
           -16.66426213509268,
           -16.7476604830155,
           -16.831058830938318,
           -16.913135896800643,
           -16.96686904045687,
           -17.020602184113105,
           -17.074335327769337,
           -17.128068471425557,
           -17.181801615081792,
           -17.235534758738023,
           -17.289267902394243,
           -17.343001046050478,
           -17.396734189706713,
           -17.45046733336293,
           -17.504200477019165,
           -17.557933620675396,
           -17.61166676433162,
           -17.665399907987855,
           -17.719133051644082,
           -17.772866195300313,
           -17.82659933895654,
           -17.880332482612772,
           -17.934065626269,
           -17.987798769925227,
           -18.041531913581455,
           -18.09526505723769,
           -18.14899820089391,
           -18.20273134455014,
           -18.256464488206372,
           -18.310197631862607,
           -18.363930775518828,
           -18.41766391917506,
           -18.471397062831294,
           -18.525130206487514,
           -18.57886335014375,
           -18.534404430505667,
           -18.41980832280027,
           -18.30521221509485,
           -18.190616107389438,
           -18.07601999968404,
           -17.961423891978622,
           -17.846827784273202,
           -17.732231676567785,
           -17.61763556886239,
           -17.50303946115697,
           -17.388443353451553,
           -17.273847245746158,
           -17.159251138040737,
           -17.04465503033532,
           -16.930058922629925,
           -16.81546281492451,
           -16.700866707219088,
           -16.58627059951367,
           -16.471674491808276,
           -16.357078384102856,
           -16.24248227639744,
           -16.127886168692044,
           -16.013290060986623,
           -15.898693953281207,
           -15.784097845575811,
           -15.669501737870391,
           -15.554905630164974,
           -15.440309522459579,
           -15.325713414754158,
           -15.211117307048745,
           -15.096521199343325,
           -14.975128921418113,
           -14.804884371877826,
           -14.634639822337537,
           -14.464395272797281,
           -14.294150723256994,
           -14.123906173716705,
           -13.953661624176448,
           -13.783417074636159,
           -13.613172525095873,
           -13.442927975555584,
           -13.272683426015329
          ],
          [
           -10.283443544217807,
           -10.296545071745744,
           -10.30964659927368,
           -10.322748126801617,
           -10.335849654329554,
           -10.348951181857492,
           -10.362052709385427,
           -10.375154236913366,
           -10.388255764441302,
           -10.40135729196924,
           -10.414458819497177,
           -10.427560347025114,
           -10.44066187455305,
           -10.453763402080988,
           -10.466864929608924,
           -10.479966457136861,
           -10.493067984664798,
           -10.506169512192734,
           -10.519271039720673,
           -10.532372567248611,
           -10.545474094776548,
           -10.558575622304485,
           -10.571677149832421,
           -10.584778677360358,
           -10.597880204888295,
           -10.610981732416231,
           -10.624083259944168,
           -10.637184787472105,
           -10.650286315000043,
           -10.663387842527982,
           -10.676489370055918,
           -10.689590897583855,
           -10.70269242511179,
           -10.715793952639729,
           -10.728895480167665,
           -10.741997007695602,
           -10.755098535223539,
           -10.768200062751475,
           -10.781301590279412,
           -10.794860717905369,
           -10.81070783573978,
           -10.826554953574195,
           -10.842402071408603,
           -10.858249189243018,
           -10.87409630707743,
           -10.889943424911841,
           -10.905790542746255,
           -10.921637660580664,
           -10.937484778415076,
           -10.95333189624949,
           -10.9691790140839,
           -10.985026131918314,
           -11.000873249752726,
           -11.016720367587137,
           -11.032567485421549,
           -11.04841460325596,
           -11.064261721090373,
           -11.080108838924783,
           -11.095955956759195,
           -11.11180307459361,
           -11.12765019242802,
           -11.143497310262434,
           -11.159344428096844,
           -11.175191545931256,
           -11.191038663765669,
           -11.206885781600079,
           -11.222732899434492,
           -11.238580017268905,
           -11.254427135103315,
           -11.270274252937728,
           -11.286121370772142,
           -11.30196848860655,
           -11.317815606440965,
           -11.333662724275376,
           -11.34950984210979,
           -11.365356959944199,
           -11.38120407777861,
           -11.397051195613024,
           -11.412898313447437,
           -11.428745431281847,
           -11.44459254911626,
           -11.460439666950672,
           -11.476286784785085,
           -11.492133902619496,
           -11.506243936364921,
           -11.520006553292552,
           -11.53376917022018,
           -11.547531787147811,
           -11.56129440407544,
           -11.57505702100307,
           -11.588819637930701,
           -11.60258225485833,
           -11.61634487178596,
           -11.630107488713591,
           -11.643870105641218,
           -11.657632722568847,
           -11.67139533949648,
           -11.685157956424108,
           -11.698920573351737,
           -11.712683190279368,
           -11.726445807206998,
           -11.740208424134627,
           -11.753971041062258,
           -11.767733657989886,
           -11.781496274917517,
           -11.795258891845148,
           -11.809021508772776,
           -11.822784125700405,
           -11.836546742628036,
           -11.850309359555666,
           -11.864071976483295,
           -11.877834593410924,
           -11.891597210338556,
           -11.905359827266185,
           -11.919122444193814,
           -11.932885061121445,
           -11.946647678049075,
           -11.960410294976704,
           -11.974172911904333,
           -11.987935528831963,
           -12.001698145759594,
           -12.015460762687223,
           -12.029223379614852,
           -12.042985996542482,
           -12.056748613470113,
           -12.070511230397742,
           -12.084273847325372,
           -12.098036464253001,
           -12.110431617787416,
           -12.12145930451471,
           -12.132486991242002,
           -12.143514677969296,
           -12.154542364696589,
           -12.165570051423881,
           -12.17659773815117,
           -12.187625424878462,
           -12.198653111605758,
           -12.209680798333048,
           -12.220708485060342,
           -12.231736171787635,
           -12.242763858514927,
           -12.253791545242219,
           -12.264819231969511,
           -12.275846918696804,
           -12.286874605424096,
           -12.297902292151388,
           -12.308929978878684,
           -12.319957665605976,
           -12.330985352333268,
           -12.34201303906056,
           -12.353040725787853,
           -12.364068412515145,
           -12.375096099242437,
           -12.38612378596973,
           -12.397151472697024,
           -12.408179159424318,
           -12.419206846151607,
           -12.430234532878899,
           -12.441262219606191,
           -12.452289906333485,
           -12.463317593060777,
           -12.47434527978807,
           -12.485372966515364,
           -12.496400653242656,
           -12.507428339969948,
           -12.518456026697242,
           -12.529483713424533,
           -12.542076837032997,
           -12.555452679082048,
           -12.568828521131097,
           -12.58220436318015,
           -12.595580205229199,
           -12.608956047278252,
           -12.6223318893273,
           -12.635707731376352,
           -12.6490835734254,
           -12.662459415474451,
           -12.675835257523502,
           -12.689211099572553,
           -12.702586941621604,
           -12.715962783670655,
           -12.729338625719702,
           -12.742714467768755,
           -12.756090309817806,
           -12.769466151866855,
           -12.782841993915905,
           -12.796217835964956,
           -12.809593678014005,
           -12.822969520063058,
           -12.836345362112107,
           -12.849721204161158,
           -12.863097046210209,
           -12.876472888259258,
           -12.889848730308309,
           -12.90322457235736,
           -12.91660041440641,
           -12.929976256455461,
           -12.943352098504509,
           -12.956727940553561,
           -12.97010378260261,
           -12.983479624651661,
           -12.996855466700714,
           -13.010231308749763,
           -13.023607150798814,
           -13.036982992847864,
           -13.050358834896912,
           -13.063734676945964,
           -13.077110518995013,
           -13.090486361044064,
           -13.103862203093115,
           -13.117238045142166,
           -13.130613887191217,
           -13.143989729240268,
           -13.157365571289315,
           -13.170741413338368,
           -13.184117255387417,
           -13.197493097436467,
           -13.210868939485518,
           -13.22424478153457,
           -13.23762062358362,
           -13.25099646563267,
           -13.26437230768172,
           -13.277748149730773,
           -13.29112399177982,
           -13.304499833828872,
           -13.317875675877922,
           -13.331251517926972,
           -13.344627359976023,
           -13.358003202025072,
           -13.371379044074125,
           -13.384754886123174,
           -13.398130728172223,
           -13.411506570221274,
           -13.424882412270327,
           -13.438258254319376,
           -13.451634096368426,
           -13.466627704300379,
           -13.481686020935497,
           -13.496744337570611,
           -13.511802654205729,
           -13.526860970840843,
           -13.54191928747596,
           -13.556977604111076,
           -13.572035920746192,
           -13.587094237381308,
           -13.602152554016424,
           -13.61721087065154,
           -13.632269187286656,
           -13.647327503921774,
           -13.662385820556889,
           -13.680021336489844,
           -13.70023405172064,
           -13.720446766951435,
           -13.74065948218223,
           -13.760872197413024,
           -13.781084912643818,
           -13.801297627874613,
           -13.821510343105409,
           -13.841723058336203,
           -13.861935773566998,
           -13.882148488797794,
           -13.90236120402859,
           -13.922573919259385,
           -13.94278663449018,
           -13.960815693264392,
           -13.978537954930427,
           -13.996260216596465,
           -14.0139824782625,
           -14.031704739928536,
           -14.049427001594571,
           -14.067149263260607,
           -14.084871524926648,
           -14.10259378659268,
           -14.120316048258719,
           -14.138038309924754,
           -14.155760571590791,
           -14.173482833256827,
           -14.191205094922863,
           -14.208927356588898,
           -14.226649618254935,
           -14.244371879920973,
           -14.26209414158701,
           -14.279816403253042,
           -14.29753866491908,
           -14.315260926585117,
           -14.332983188251152,
           -14.350705449917188,
           -14.368427711583227,
           -14.38614997324926,
           -14.403872234915296,
           -14.421594496581333,
           -14.439316758247369,
           -14.457039019913406,
           -14.474761281579442,
           -14.49248354324548,
           -14.510205804911514,
           -14.527928066577552,
           -14.545650328243587,
           -14.563372589909623,
           -14.58109485157566,
           -14.598817113241697,
           -14.616539374907731,
           -14.634261636573768,
           -14.651983898239806,
           -14.669706159905841,
           -14.687428421571877,
           -14.705150683237914,
           -14.72287294490395,
           -14.740595206569985,
           -14.758317468236022,
           -14.77603972990206,
           -14.793761991568093,
           -14.811484253234129,
           -14.829206514900166,
           -14.846928776566203,
           -14.864651038232237,
           -14.882373299898276,
           -14.900095561564314,
           -14.917817823230347,
           -14.935540084896383,
           -14.95326234656242,
           -14.970984608228457,
           -14.988706869894491,
           -15.00642913156053,
           -15.024151393226564,
           -15.041873654892601,
           -15.059595916558637,
           -15.077318178224674,
           -15.09504043989071,
           -15.112762701556747,
           -15.130484963222784,
           -15.148207224888818,
           -15.165929486554855,
           -15.179007944491671,
           -15.182798794970054,
           -15.186589645448436,
           -15.190380495926817,
           -15.194171346405199,
           -15.197962196883578,
           -15.201753047361962,
           -15.205543897840343,
           -15.209334748318724,
           -15.213125598797106,
           -15.216916449275487,
           -15.220707299753869,
           -15.22449815023225,
           -15.228289000710632,
           -15.232079851189015,
           -15.235870701667395,
           -15.239661552145776,
           -15.24345240262416,
           -15.24724325310254,
           -15.25103410358092,
           -15.254824954059304,
           -15.258615804537687,
           -15.262406655016067,
           -15.266197505494448,
           -15.269988355972831,
           -15.273779206451213,
           -15.27757005692959,
           -15.281360907407976,
           -15.285151757886355,
           -15.288942608364737,
           -15.292733458843118,
           -15.2965243093215,
           -15.300315159799883,
           -15.304106010278264,
           -15.307896860756644,
           -15.311687711235026,
           -15.315478561713409,
           -15.31926941219179,
           -15.32306026267017,
           -15.326851113148551,
           -15.330641963626933,
           -15.334432814105314,
           -15.338223664583698,
           -15.342014515062077,
           -15.34580536554046,
           -15.349855666208136,
           -15.354741999689423,
           -15.359628333170711,
           -15.364514666651996,
           -15.369401000133283,
           -15.374287333614571,
           -15.379173667095856,
           -15.384060000577144,
           -15.38894633405843,
           -15.393832667539716,
           -15.398719001021004,
           -15.40360533450229,
           -15.408491667983577,
           -15.413378001464864,
           -15.418264334946151,
           -15.423150668427438,
           -15.428037001908722,
           -15.43292333539001,
           -15.437809668871296,
           -15.442696002352584,
           -15.44758233583387,
           -15.452468669315156,
           -15.457355002796444,
           -15.462241336277732,
           -15.467127669759016,
           -15.472014003240304,
           -15.476900336721592,
           -15.481786670202876,
           -15.486673003684166,
           -15.49155933716545,
           -15.496445670646736,
           -15.501332004128026,
           -15.50621833760931,
           -15.511104671090598,
           -15.515991004571886,
           -15.520877338053172,
           -15.525763671534458,
           -15.530650005015744,
           -15.543309655644077,
           -15.594835892007652,
           -15.646362128371226,
           -15.697888364734803,
           -15.749414601098367,
           -15.800940837461942,
           -15.852467073825515,
           -15.903993310189083,
           -15.955519546552656,
           -16.00704578291623,
           -16.058572019279794,
           -16.11009825564337,
           -16.161624492006943,
           -16.213150728370515,
           -16.264676964734083,
           -16.316203201097657,
           -16.367729437461232,
           -16.4192556738248,
           -16.47078191018837,
           -16.522308146551946,
           -16.57383438291551,
           -16.625360619279085,
           -16.676886855642657,
           -16.728413092006225,
           -16.7799393283698,
           -16.831465564733374,
           -16.88299180109695,
           -16.934518037460514,
           -16.98604427382409,
           -17.037570510187663,
           -17.089096746551228,
           -17.140622982914802,
           -17.192149219278377,
           -17.24367545564194,
           -17.295201692005516,
           -17.34672792836909,
           -17.398254164732666,
           -17.44978040109623,
           -17.501306637459805,
           -17.548997767075026,
           -17.574226020733484,
           -17.599454274391945,
           -17.573377489076954,
           -17.510654247352388,
           -17.446933718203297,
           -17.336342054404618,
           -17.22575039060596,
           -17.11515872680728,
           -17.0045670630086,
           -16.89397539920992,
           -16.78338373541127,
           -16.67279207161259,
           -16.56220040781391,
           -16.451608744015257,
           -16.341017080216577,
           -16.230425416417898,
           -16.11983375261924,
           -16.009242088820564,
           -15.898650425021884,
           -15.788058761223207,
           -15.677467097424547,
           -15.56687543362587,
           -15.456283769827191,
           -15.345692106028533,
           -15.235100442229857,
           -15.12450877843118,
           -15.013917114632521,
           -14.903325450833844,
           -14.792733787035164,
           -14.682142123236506,
           -14.571550459437827,
           -14.46095879563915,
           -14.350367131840473,
           -14.239775468041815,
           -14.129183804243137,
           -14.01859214044446,
           -13.908000476645801,
           -13.797408812847122,
           -13.686817149048444,
           -13.576225485249788,
           -13.46563382145111,
           -13.35504215765243,
           -13.244450493853753,
           -13.133858830055097
          ],
          [
           -9.809071500587732,
           -9.82217302811567,
           -9.835274555643606,
           -9.848376083171543,
           -9.86147761069948,
           -9.874579138227418,
           -9.887680665755353,
           -9.900782193283291,
           -9.913883720811228,
           -9.926985248339165,
           -9.940086775867103,
           -9.953188303395038,
           -9.966289830922976,
           -9.979391358450913,
           -9.99249288597885,
           -10.005594413506788,
           -10.018695941034723,
           -10.031797468562662,
           -10.044898996090598,
           -10.058000523618535,
           -10.071102051146472,
           -10.08420357867441,
           -10.097305106202345,
           -10.110406633730284,
           -10.123508161258219,
           -10.136609688786157,
           -10.149711216314095,
           -10.162812743842032,
           -10.175914271369969,
           -10.189015798897906,
           -10.202117326425842,
           -10.21521885395378,
           -10.228320381481716,
           -10.241421909009654,
           -10.25452343653759,
           -10.267624964065527,
           -10.280726491593466,
           -10.293828019121403,
           -10.30692954664934,
           -10.320031074177276,
           -10.333132601705213,
           -10.34623412923315,
           -10.359335656761086,
           -10.372437184289025,
           -10.385538711816961,
           -10.398640239344898,
           -10.411741766872835,
           -10.424843294400771,
           -10.437944821928708,
           -10.451046349456647,
           -10.464147876984583,
           -10.47724940451252,
           -10.490350932040458,
           -10.503452459568393,
           -10.516553987096332,
           -10.529655514624269,
           -10.54458743695044,
           -10.560434554784852,
           -10.576281672619263,
           -10.592128790453675,
           -10.607975908288088,
           -10.6238230261225,
           -10.639670143956911,
           -10.655517261791323,
           -10.671364379625736,
           -10.687211497460147,
           -10.703058615294559,
           -10.71890573312897,
           -10.734752850963384,
           -10.750599968797795,
           -10.766447086632207,
           -10.78229420446662,
           -10.79814132230103,
           -10.813988440135441,
           -10.829835557969854,
           -10.845682675804266,
           -10.86152979363868,
           -10.87737691147309,
           -10.893224029307502,
           -10.909071147141916,
           -10.924918264976327,
           -10.940765382810737,
           -10.95661250064515,
           -10.972459618479563,
           -10.986569652224988,
           -11.000332269152619,
           -11.014094886080247,
           -11.027857503007876,
           -11.041620119935507,
           -11.055382736863136,
           -11.069145353790766,
           -11.082907970718397,
           -11.096670587646027,
           -11.110433204573656,
           -11.124195821501287,
           -11.137958438428917,
           -11.151721055356546,
           -11.165483672284177,
           -11.179246289211807,
           -11.193008906139436,
           -11.206771523067065,
           -11.220534139994694,
           -11.234296756922326,
           -11.248059373849955,
           -11.261821990777584,
           -11.275584607705214,
           -11.289347224632843,
           -11.303109841560474,
           -11.316872458488104,
           -11.330635075415733,
           -11.344397692343364,
           -11.358160309270993,
           -11.369187997253974,
           -11.380215683981268,
           -11.39124337070856,
           -11.402271057435852,
           -11.413298744163146,
           -11.424326430890437,
           -11.435354117617731,
           -11.446381804345023,
           -11.457409491072315,
           -11.468437177799608,
           -11.4794648645269,
           -11.490492551254192,
           -11.501520237981484,
           -11.512547924708777,
           -11.523575611436069,
           -11.534603298163361,
           -11.545630984890657,
           -11.556658671617948,
           -11.56768635834524,
           -11.578714045072534,
           -11.589741731799826,
           -11.600769418527118,
           -11.61179710525441,
           -11.622824791981703,
           -11.633852478708995,
           -11.64488016543629,
           -11.655907852163581,
           -11.666935538890874,
           -11.677963225618166,
           -11.68899091234546,
           -11.700018599072752,
           -11.711046285800045,
           -11.722073972527337,
           -11.73310165925463,
           -11.744129345981921,
           -11.755157032709215,
           -11.766184719436506,
           -11.7772124061638,
           -11.788240092891092,
           -11.799267779618383,
           -11.810295466345679,
           -11.82132315307297,
           -11.832350839800263,
           -11.843378526527555,
           -11.854406213254848,
           -11.86543389998214,
           -11.876461586709432,
           -11.887489273436724,
           -11.898516960164017,
           -11.909544646891309,
           -11.920572333618603,
           -11.931600020345895,
           -11.942627707073187,
           -11.953655393800481,
           -11.964683080527774,
           -11.977276204136238,
           -11.990652046185287,
           -12.004027888234338,
           -12.01740373028339,
           -12.030779572332438,
           -12.044155414381489,
           -12.05753125643054,
           -12.07090709847959,
           -12.084282940528642,
           -12.097658782577692,
           -12.111034624626743,
           -12.124410466675792,
           -12.137786308724843,
           -12.151162150773892,
           -12.164537992822943,
           -12.177913834871994,
           -12.191289676921045,
           -12.204665518970096,
           -12.218041361019145,
           -12.231417203068197,
           -12.244793045117245,
           -12.258168887166297,
           -12.271544729215346,
           -12.284920571264397,
           -12.298296413313448,
           -12.311672255362495,
           -12.32504809741155,
           -12.338423939460599,
           -12.351799781509651,
           -12.365175623558702,
           -12.37855146560775,
           -12.3919273076568,
           -12.405303149705851,
           -12.418678991754899,
           -12.432054833803953,
           -12.445430675853002,
           -12.458806517902053,
           -12.472182359951102,
           -12.485558202000151,
           -12.498934044049204,
           -12.512309886098253,
           -12.525685728147304,
           -12.539061570196356,
           -12.552437412245405,
           -12.565813254294456,
           -12.579189096343507,
           -12.592564938392556,
           -12.605940780441607,
           -12.619316622490658,
           -12.632692464539707,
           -12.646068306588758,
           -12.659444148637808,
           -12.67281999068686,
           -12.68619583273591,
           -12.69957167478496,
           -12.71294751683401,
           -12.726323358883059,
           -12.739699200932112,
           -12.753075042981163,
           -12.766450885030212,
           -12.779826727079262,
           -12.793202569128312,
           -12.806578411177364,
           -12.819954253226413,
           -12.832373851585139,
           -12.844278547105178,
           -12.85618324262522,
           -12.868087938145258,
           -12.879992633665301,
           -12.89189732918534,
           -12.903802024705382,
           -12.915706720225423,
           -12.92761141574546,
           -12.939516111265501,
           -12.951420806785542,
           -12.963325502305583,
           -12.975230197825624,
           -12.987134893345663,
           -12.999039588865703,
           -13.010944284385744,
           -13.022848979905785,
           -13.034753675425826,
           -13.046658370945865,
           -13.060241548831689,
           -13.075503209083298,
           -13.090764869334905,
           -13.106026529586511,
           -13.12128818983812,
           -13.136549850089727,
           -13.151811510341336,
           -13.167073170592943,
           -13.182334830844551,
           -13.197596491096157,
           -13.212858151347767,
           -13.228119811599376,
           -13.243381471850983,
           -13.25864313210259,
           -13.274418090125678,
           -13.292136242555562,
           -13.309854394985448,
           -13.327572547415336,
           -13.345290699845219,
           -13.363008852275104,
           -13.38072700470499,
           -13.398445157134876,
           -13.41616330956476,
           -13.433881461994648,
           -13.451599614424534,
           -13.469317766854418,
           -13.487035919284304,
           -13.504754071714189,
           -13.522472224144074,
           -13.54019037657396,
           -13.557908529003848,
           -13.575626681433734,
           -13.593344833863615,
           -13.6110629862935,
           -13.628781138723387,
           -13.646499291153273,
           -13.664217443583158,
           -13.681935596013046,
           -13.69965374844293,
           -13.717371900872813,
           -13.735090053302699,
           -13.752808205732586,
           -13.77052635816247,
           -13.788244510592357,
           -13.805962663022246,
           -13.823680815452125,
           -13.841398967882013,
           -13.859117120311899,
           -13.876835272741786,
           -13.894553425171669,
           -13.912271577601558,
           -13.92998973003144,
           -13.947707882461327,
           -13.96542603489121,
           -13.983144187321098,
           -14.000862339750984,
           -14.018580492180869,
           -14.036298644610756,
           -14.05401679704064,
           -14.071734949470523,
           -14.089453101900412,
           -14.107171254330297,
           -14.12488940676018,
           -14.142607559190068,
           -14.16032571161995,
           -14.178043864049837,
           -14.195762016479723,
           -14.21348016890961,
           -14.231198321339495,
           -14.24891647376938,
           -14.266634626199266,
           -14.284352778629152,
           -14.302070931059035,
           -14.319789083488923,
           -14.337507235918808,
           -14.355225388348693,
           -14.372943540778577,
           -14.390661693208463,
           -14.408379845638347,
           -14.426097998068236,
           -14.44381615049812,
           -14.461534302928007,
           -14.47925245535789,
           -14.49364041709083,
           -14.501367997429874,
           -14.50909557776892,
           -14.516823158107965,
           -14.524550738447012,
           -14.532278318786057,
           -14.540005899125099,
           -14.547733479464146,
           -14.555461059803191,
           -14.563188640142236,
           -14.570916220481282,
           -14.578643800820325,
           -14.58637138115937,
           -14.594098961498416,
           -14.601826541837463,
           -14.609554122176506,
           -14.61728170251555,
           -14.625009282854597,
           -14.632736863193642,
           -14.640464443532686,
           -14.648192023871733,
           -14.655919604210776,
           -14.663647184549824,
           -14.669357060881548,
           -14.674243394362833,
           -14.679129727844119,
           -14.684016061325405,
           -14.688902394806693,
           -14.69378872828798,
           -14.698675061769265,
           -14.703561395250553,
           -14.70844772873184,
           -14.713334062213129,
           -14.718220395694416,
           -14.723106729175703,
           -14.727993062656985,
           -14.732879396138273,
           -14.737765729619559,
           -14.742652063100847,
           -14.747538396582135,
           -14.75242473006342,
           -14.757311063544705,
           -14.762197397025993,
           -14.76708373050728,
           -14.771970063988569,
           -14.776856397469855,
           -14.78174273095114,
           -14.786629064432429,
           -14.791515397913713,
           -14.796401731395001,
           -14.801288064876287,
           -14.806174398357573,
           -14.811060731838861,
           -14.815947065320149,
           -14.820833398801433,
           -14.825719732282721,
           -14.830606065764009,
           -14.835492399245293,
           -14.840378732726581,
           -14.845265066207865,
           -14.850151399689157,
           -14.855037733170441,
           -14.859924066651729,
           -14.864810400133013,
           -14.869696733614301,
           -14.874583067095587,
           -14.879469400576877,
           -14.884355734058161,
           -14.889242067539449,
           -14.894128401020737,
           -14.899014734502021,
           -14.903901067983309,
           -14.908787401464597,
           -14.913673734945881,
           -14.918560068427167,
           -14.923446401908455,
           -14.928332735389743,
           -14.933219068871027,
           -14.938105402352313,
           -14.942991735833601,
           -14.94787806931489,
           -14.952764402796173,
           -14.957650736277461,
           -14.970310386905798,
           -15.02183662326937,
           -15.073362859632944,
           -15.124889095996519,
           -15.176415332360087,
           -15.227941568723658,
           -15.279467805087233,
           -15.3309940414508,
           -15.382520277814375,
           -15.434046514177949,
           -15.485572750541511,
           -15.537098986905086,
           -15.58862522326866,
           -15.640151459632236,
           -15.6916776959958,
           -15.743203932359375,
           -15.79473016872295,
           -15.846256405086516,
           -15.89778264145009,
           -15.949308877813664,
           -16.000835114177228,
           -16.052361350540803,
           -16.103887586904378,
           -16.155413823267942,
           -16.181737837776897,
           -16.20696609143536,
           -16.23219434509382,
           -16.257422598752278,
           -16.282650852410736,
           -16.307879106069194,
           -16.333107359727656,
           -16.358335613386117,
           -16.38356386704458,
           -16.408792120703033,
           -16.434020374361495,
           -16.459248628019957,
           -16.484476881678418,
           -16.509705135336873,
           -16.534933388995334,
           -16.560161642653796,
           -16.585389896312254,
           -16.610618149970712,
           -16.584541364655728,
           -16.52181812293116,
           -16.45909488120658,
           -16.396371639482,
           -16.333648397757432,
           -16.27092515603285,
           -16.208201914308273,
           -16.14547867258369,
           -16.08275543085912,
           -16.02003218913454,
           -15.957308947409963,
           -15.894585705685394,
           -15.831862463960814,
           -15.769139222236234,
           -15.706415980511668,
           -15.643692738787085,
           -15.580969497062505,
           -15.518246255337925,
           -15.445550404619146,
           -15.334958740820468,
           -15.224367077021792,
           -15.11377541322313,
           -15.003183749424455,
           -14.892592085625775,
           -14.782000421827119,
           -14.67140875802844,
           -14.560817094229762,
           -14.450225430431104,
           -14.339633766632424,
           -14.229042102833748,
           -14.11845043903507,
           -14.00785877523641,
           -13.897267111437735,
           -13.786675447639057,
           -13.676083783840397,
           -13.565492120041721,
           -13.454900456243042,
           -13.344308792444386,
           -13.233717128645708,
           -13.123125464847028,
           -13.01253380104835,
           -12.901942137249694
          ],
          [
           -9.334699456957658,
           -9.347800984485595,
           -9.360902512013531,
           -9.374004039541468,
           -9.387105567069407,
           -9.400207094597343,
           -9.41330862212528,
           -9.426410149653217,
           -9.439511677181153,
           -9.452613204709092,
           -9.465714732237029,
           -9.478816259764965,
           -9.491917787292902,
           -9.505019314820839,
           -9.518120842348777,
           -9.531222369876714,
           -9.54432389740465,
           -9.557425424932587,
           -9.570526952460524,
           -9.583628479988462,
           -9.596730007516399,
           -9.609831535044336,
           -9.62293306257227,
           -9.63603459010021,
           -9.649136117628146,
           -9.662237645156084,
           -9.67533917268402,
           -9.688440700211956,
           -9.701542227739894,
           -9.714643755267833,
           -9.727745282795768,
           -9.740846810323706,
           -9.753948337851641,
           -9.767049865379581,
           -9.780151392907518,
           -9.793252920435455,
           -9.806354447963392,
           -9.819455975491326,
           -9.832557503019265,
           -9.8456590305472,
           -9.858760558075138,
           -9.871862085603077,
           -9.884963613131013,
           -9.89806514065895,
           -9.911166668186887,
           -9.924268195714825,
           -9.937369723242762,
           -9.950471250770699,
           -9.963572778298635,
           -9.976674305826572,
           -9.989775833354509,
           -10.002877360882446,
           -10.015978888410384,
           -10.02908041593832,
           -10.042181943466257,
           -10.055283470994194,
           -10.068384998522133,
           -10.08148652605007,
           -10.094588053578006,
           -10.107689581105943,
           -10.12079110863388,
           -10.133892636161818,
           -10.146994163689754,
           -10.16009569121769,
           -10.173197218745628,
           -10.186298746273565,
           -10.199400273801501,
           -10.212501801329438,
           -10.225603328857375,
           -10.238704856385313,
           -10.25180638391325,
           -10.264907911441187,
           -10.278467038161097,
           -10.294314155995508,
           -10.310161273829921,
           -10.326008391664333,
           -10.341855509498746,
           -10.357702627333158,
           -10.37354974516757,
           -10.389396863001982,
           -10.405243980836394,
           -10.421091098670804,
           -10.436938216505217,
           -10.452785334339628,
           -10.466895368085055,
           -10.480657985012687,
           -10.494420601940314,
           -10.508183218867945,
           -10.521945835795574,
           -10.535708452723204,
           -10.549471069650835,
           -10.563233686578464,
           -10.576996303506094,
           -10.590758920433723,
           -10.604521537361354,
           -10.616916689993241,
           -10.627944376720535,
           -10.638972063447827,
           -10.64999975017512,
           -10.661027436902412,
           -10.672055123629706,
           -10.683082810356998,
           -10.69411049708429,
           -10.705138183811583,
           -10.716165870538875,
           -10.727193557266167,
           -10.73822124399346,
           -10.749248930720753,
           -10.760276617448046,
           -10.771304304175338,
           -10.78233199090263,
           -10.793359677629923,
           -10.804387364357215,
           -10.815415051084509,
           -10.826442737811801,
           -10.837470424539093,
           -10.848498111266386,
           -10.859525797993678,
           -10.870553484720972,
           -10.881581171448264,
           -10.892608858175556,
           -10.903636544902849,
           -10.914664231630141,
           -10.925691918357433,
           -10.936719605084726,
           -10.947747291812018,
           -10.958774978539312,
           -10.969802665266602,
           -10.980830351993895,
           -10.991858038721189,
           -11.002885725448483,
           -11.013913412175775,
           -11.024941098903067,
           -11.035968785630358,
           -11.046996472357652,
           -11.058024159084944,
           -11.069051845812236,
           -11.08007953253953,
           -11.091107219266823,
           -11.102134905994115,
           -11.113162592721407,
           -11.1241902794487,
           -11.135217966175993,
           -11.146245652903284,
           -11.157273339630578,
           -11.16830102635787,
           -11.17932871308516,
           -11.190356399812453,
           -11.201384086539745,
           -11.21241177326704,
           -11.223439459994331,
           -11.234467146721625,
           -11.245494833448918,
           -11.256522520176208,
           -11.267550206903502,
           -11.278577893630795,
           -11.289605580358089,
           -11.30063326708538,
           -11.311660953812673,
           -11.322688640539965,
           -11.333716327267258,
           -11.34474401399455,
           -11.355771700721842,
           -11.366799387449136,
           -11.377827074176428,
           -11.38885476090372,
           -11.399882447631015,
           -11.412475571239478,
           -11.425851413288528,
           -11.43922725533758,
           -11.452603097386628,
           -11.46597893943568,
           -11.47935478148473,
           -11.49273062353378,
           -11.506106465582832,
           -11.51948230763188,
           -11.53285814968093,
           -11.546233991729983,
           -11.559609833779032,
           -11.572985675828082,
           -11.586361517877133,
           -11.599737359926182,
           -11.613113201975233,
           -11.626489044024286,
           -11.639864886073333,
           -11.653240728122386,
           -11.666616570171437,
           -11.679992412220484,
           -11.693368254269537,
           -11.706744096318587,
           -11.720119938367638,
           -11.733495780416689,
           -11.746871622465736,
           -11.759364777592614,
           -11.771269473112651,
           -11.783174168632696,
           -11.795078864152734,
           -11.806983559672775,
           -11.818888255192816,
           -11.830792950712855,
           -11.842697646232896,
           -11.854602341752937,
           -11.866507037272976,
           -11.878411732793015,
           -11.890316428313056,
           -11.902221123833097,
           -11.914125819353137,
           -11.926030514873178,
           -11.937935210393217,
           -11.949839905913258,
           -11.961744601433297,
           -11.973649296953338,
           -11.98555399247338,
           -11.997458687993419,
           -12.009363383513461,
           -12.0212680790335,
           -12.033172774553542,
           -12.045077470073583,
           -12.05698216559362,
           -12.068886861113663,
           -12.080791556633702,
           -12.092696252153743,
           -12.104600947673784,
           -12.116505643193822,
           -12.128410338713863,
           -12.140315034233904,
           -12.152219729753945,
           -12.164124425273984,
           -12.176029120794023,
           -12.187933816314066,
           -12.199838511834106,
           -12.211743207354147,
           -12.223647902874186,
           -12.235552598394227,
           -12.247457293914266,
           -12.259361989434307,
           -12.271266684954348,
           -12.28317138047439,
           -12.295076075994428,
           -12.30698077151447,
           -12.318885467034509,
           -12.330790162554548,
           -12.34269485807459,
           -12.354599553594632,
           -12.366504249114671,
           -12.37840894463471,
           -12.390313640154751,
           -12.402218335674792,
           -12.414123031194833,
           -12.426027726714873,
           -12.439610904600697,
           -12.454872564852305,
           -12.470134225103912,
           -12.48539588535552,
           -12.500657545607128,
           -12.515919205858737,
           -12.531180866110343,
           -12.54644252636195,
           -12.56170418661356,
           -12.576965846865164,
           -12.592227507116775,
           -12.607489167368382,
           -12.622750827619988,
           -12.638012487871599,
           -12.653274148123206,
           -12.668535808374813,
           -12.68379746862642,
           -12.699059128878028,
           -12.714320789129635,
           -12.729582449381242,
           -12.74484410963285,
           -12.76010576988446,
           -12.775367430136066,
           -12.790629090387675,
           -12.805890750639284,
           -12.82115241089089,
           -12.836414071142498,
           -12.851675731394106,
           -12.866937391645713,
           -12.882199051897322,
           -12.897460712148929,
           -12.912722372400538,
           -12.927984032652144,
           -12.943245692903753,
           -12.95850735315536,
           -12.97376901340697,
           -12.989030673658576,
           -13.004292333910184,
           -13.019553994161791,
           -13.034815654413396,
           -13.050077314665007,
           -13.065338974916614,
           -13.08060063516822,
           -13.098043805277147,
           -13.115761957707033,
           -13.133480110136915,
           -13.151198262566803,
           -13.168916414996689,
           -13.186634567426573,
           -13.204352719856459,
           -13.222070872286345,
           -13.23978902471623,
           -13.257507177146115,
           -13.275225329576003,
           -13.292943482005889,
           -13.310661634435771,
           -13.328379786865657,
           -13.346097939295545,
           -13.363816091725429,
           -13.381534244155313,
           -13.3992523965852,
           -13.416970549015085,
           -13.43468870144497,
           -13.452406853874857,
           -13.470125006304741,
           -13.487843158734627,
           -13.505561311164513,
           -13.523279463594399,
           -13.540997616024283,
           -13.558715768454169,
           -13.576433920884055,
           -13.594152073313941,
           -13.611870225743825,
           -13.629588378173711,
           -13.647306530603597,
           -13.665024683033483,
           -13.682742835463369,
           -13.700460987893253,
           -13.718179140323137,
           -13.735897292753023,
           -13.753615445182911,
           -13.771333597612795,
           -13.78905175004268,
           -13.803439711775619,
           -13.811167292114664,
           -13.818894872453708,
           -13.826622452792755,
           -13.8343500331318,
           -13.842077613470845,
           -13.849805193809889,
           -13.857532774148936,
           -13.86526035448798,
           -13.872987934827027,
           -13.88071551516607,
           -13.888443095505117,
           -13.89617067584416,
           -13.903898256183204,
           -13.911625836522251,
           -13.919353416861297,
           -13.927080997200342,
           -13.934808577539386,
           -13.94253615787843,
           -13.950263738217476,
           -13.957991318556521,
           -13.965718898895567,
           -13.97344647923461,
           -13.981174059573657,
           -13.9889016399127,
           -13.996629220251748,
           -14.004356800590793,
           -14.012084380929837,
           -14.019811961268882,
           -14.027539541607927,
           -14.035267121946973,
           -14.042994702286018,
           -14.050722282625063,
           -14.058449862964109,
           -14.066177443303152,
           -14.073905023642197,
           -14.081632603981245,
           -14.089360184320288,
           -14.097087764659335,
           -14.104815344998379,
           -14.112542925337424,
           -14.12027050567647,
           -14.127998086015513,
           -14.13572566635456,
           -14.143453246693605,
           -14.15118082703265,
           -14.158908407371696,
           -14.16663598771074,
           -14.174363568049786,
           -14.18209114838883,
           -14.189818728727875,
           -14.197546309066922,
           -14.205273889405964,
           -14.213001469745011,
           -14.220729050084055,
           -14.228456630423102,
           -14.236184210762145,
           -14.243911791101192,
           -14.251639371440236,
           -14.259366951779281,
           -14.267094532118325,
           -14.274822112457372,
           -14.282549692796415,
           -14.29027727313546,
           -14.296697464876017,
           -14.301583798357305,
           -14.306470131838594,
           -14.311356465319879,
           -14.316242798801166,
           -14.32112913228245,
           -14.326015465763739,
           -14.330901799245026,
           -14.335788132726313,
           -14.3406744662076,
           -14.345560799688887,
           -14.350447133170173,
           -14.35533346665146,
           -14.360219800132747,
           -14.365106133614033,
           -14.36999246709532,
           -14.374878800576605,
           -14.379765134057893,
           -14.384651467539179,
           -14.397311118167515,
           -14.44883735453109,
           -14.500363590894663,
           -14.551889827258238,
           -14.603416063621802,
           -14.654942299985377,
           -14.706468536348952,
           -14.757994772712516,
           -14.789249654820312,
           -14.814477908478771,
           -14.839706162137228,
           -14.86493441579569,
           -14.890162669454151,
           -14.915390923112612,
           -14.940619176771069,
           -14.96584743042953,
           -14.991075684087992,
           -15.016303937746448,
           -15.041532191404908,
           -15.06676044506337,
           -15.091988698721828,
           -15.11721695238029,
           -15.14244520603875,
           -15.167673459697209,
           -15.192901713355669,
           -15.218129967014129,
           -15.24335822067259,
           -15.268586474331045,
           -15.293814727989506,
           -15.319042981647968,
           -15.344271235306426,
           -15.369499488964884,
           -15.394727742623349,
           -15.419955996281805,
           -15.445184249940265,
           -15.470412503598727,
           -15.495640757257188,
           -15.520869010915646,
           -15.546097264574106,
           -15.571325518232566,
           -15.596553771891022,
           -15.621782025549486,
           -15.595705240234498,
           -15.532981998509928,
           -15.470258756785347,
           -15.407535515060768,
           -15.344812273336201,
           -15.282089031611621,
           -15.219365789887041,
           -15.156642548162461,
           -15.093919306437892,
           -15.031196064713312,
           -14.968472822988733,
           -14.905749581264164,
           -14.843026339539586,
           -14.780303097815004,
           -14.717579856090438,
           -14.654856614365855,
           -14.592133372641278,
           -14.529410130916697,
           -14.466686889192129,
           -14.403963647467545,
           -14.341240405742969,
           -14.278517164018398,
           -14.21579392229382,
           -14.15307068056924,
           -14.09034743884467,
           -14.02762419712009,
           -13.964900955395509,
           -13.902177713670943,
           -13.839454471946363,
           -13.776731230221783,
           -13.714007988497201,
           -13.651284746772635,
           -13.588561505048055,
           -13.525838263323473,
           -13.444167091034995,
           -13.333575427236315,
           -13.22298376343764,
           -13.112392099638981,
           -13.001800435840305,
           -12.891208772041626,
           -12.780617108242947,
           -12.67002544444429
          ],
          [
           -8.859564718184101,
           -8.869694788534172,
           -8.879824858884241,
           -8.88995492923431,
           -8.90008499958438,
           -8.91021506993445,
           -8.922821354983114,
           -8.93592288251105,
           -8.949024410038987,
           -8.962125937566926,
           -8.975227465094862,
           -8.9883289926228,
           -9.001430520150736,
           -9.014532047678674,
           -9.027633575206611,
           -9.040735102734548,
           -9.053836630262484,
           -9.066938157790421,
           -9.080039685318358,
           -9.093141212846296,
           -9.106242740374231,
           -9.11934426790217,
           -9.132445795430106,
           -9.145547322958043,
           -9.158648850485982,
           -9.171750378013918,
           -9.184851905541853,
           -9.197953433069792,
           -9.211054960597728,
           -9.224156488125665,
           -9.237258015653602,
           -9.250359543181538,
           -9.263461070709477,
           -9.276562598237414,
           -9.28966412576535,
           -9.302765653293287,
           -9.315867180821224,
           -9.328968708349162,
           -9.342070235877099,
           -9.355171763405036,
           -9.368273290932972,
           -9.381374818460909,
           -9.394476345988846,
           -9.407577873516784,
           -9.42067940104472,
           -9.43378092857266,
           -9.446882456100596,
           -9.459983983628533,
           -9.47308551115647,
           -9.486187038684406,
           -9.499288566212343,
           -9.51239009374028,
           -9.525491621268218,
           -9.538593148796153,
           -9.55169467632409,
           -9.564796203852028,
           -9.577897731379966,
           -9.590999258907903,
           -9.60410078643584,
           -9.617202313963777,
           -9.630303841491713,
           -9.64340536901965,
           -9.656506896547587,
           -9.669608424075523,
           -9.682709951603462,
           -9.695811479131399,
           -9.708913006659335,
           -9.722014534187272,
           -9.735116061715209,
           -9.748217589243147,
           -9.761319116771082,
           -9.77442064429902,
           -9.787522171826957,
           -9.800623699354894,
           -9.813725226882832,
           -9.826826754410769,
           -9.839928281938706,
           -9.853029809466642,
           -9.86613133699458,
           -9.879232864522516,
           -9.892334392050454,
           -9.905435919578391,
           -9.918537447106328,
           -9.931638974634264,
           -9.940696906412864,
           -9.948946119041596,
           -9.957195331670327,
           -9.965444544299059,
           -9.97369375692779,
           -9.983795285981014,
           -9.994822972708306,
           -10.0058506594356,
           -10.016878346162892,
           -10.027906032890185,
           -10.038933719617477,
           -10.049961406344769,
           -10.060989093072063,
           -10.072016779799355,
           -10.083044466526648,
           -10.09407215325394,
           -10.105099839981232,
           -10.116127526708526,
           -10.127155213435818,
           -10.13818290016311,
           -10.149210586890401,
           -10.160238273617695,
           -10.171265960344988,
           -10.18229364707228,
           -10.193321333799574,
           -10.204349020526866,
           -10.215376707254158,
           -10.22640439398145,
           -10.237432080708743,
           -10.248459767436035,
           -10.259487454163327,
           -10.27051514089062,
           -10.281542827617914,
           -10.292570514345206,
           -10.303598201072498,
           -10.314625887799792,
           -10.325653574527085,
           -10.336681261254377,
           -10.347708947981669,
           -10.358736634708961,
           -10.369764321436254,
           -10.380792008163546,
           -10.39181969489084,
           -10.40284738161813,
           -10.413875068345424,
           -10.424902755072717,
           -10.435930441800007,
           -10.446958128527301,
           -10.457985815254595,
           -10.469013501981888,
           -10.48004118870918,
           -10.491068875436472,
           -10.502096562163764,
           -10.513124248891057,
           -10.524151935618349,
           -10.535179622345643,
           -10.546207309072933,
           -10.557234995800227,
           -10.568262682527521,
           -10.579290369254812,
           -10.590318055982106,
           -10.601345742709398,
           -10.61237342943669,
           -10.623401116163983,
           -10.634428802891275,
           -10.645456489618569,
           -10.65648417634586,
           -10.667511863073154,
           -10.678539549800446,
           -10.68956723652774,
           -10.700594923255032,
           -10.711622609982324,
           -10.722650296709615,
           -10.733677983436907,
           -10.744705670164201,
           -10.755733356891493,
           -10.766761043618786,
           -10.777788730346078,
           -10.78881641707337,
           -10.799844103800664,
           -10.810871790527957,
           -10.821899477255249,
           -10.832927163982541,
           -10.84372263118501,
           -10.854401988625062,
           -10.865081346065114,
           -10.875760703505168,
           -10.886440060945223,
           -10.897119418385277,
           -10.907798775825327,
           -10.918478133265383,
           -10.929157490705437,
           -10.93983684814549,
           -10.950516205585544,
           -10.961195563025598,
           -10.972068396081058,
           -10.983973091601095,
           -10.995877787121136,
           -11.007782482641177,
           -11.019687178161218,
           -11.031591873681258,
           -11.043496569201299,
           -11.05540126472134,
           -11.067305960241379,
           -11.079210655761418,
           -11.091115351281458,
           -11.1030200468015,
           -11.11492474232154,
           -11.12682943784158,
           -11.138734133361622,
           -11.15063882888166,
           -11.162543524401704,
           -11.174448219921741,
           -11.18635291544178,
           -11.198257610961821,
           -11.210162306481863,
           -11.222067002001904,
           -11.233971697521945,
           -11.245876393041984,
           -11.257781088562023,
           -11.269685784082064,
           -11.281590479602105,
           -11.293495175122144,
           -11.305399870642185,
           -11.317304566162225,
           -11.329209261682266,
           -11.341113957202307,
           -11.353018652722348,
           -11.364923348242387,
           -11.376828043762426,
           -11.388732739282469,
           -11.400637434802508,
           -11.41254213032255,
           -11.424446825842589,
           -11.436351521362628,
           -11.448256216882669,
           -11.46016091240271,
           -11.472065607922751,
           -11.483970303442792,
           -11.49587499896283,
           -11.507779694482872,
           -11.519684390002912,
           -11.531589085522953,
           -11.543493781042994,
           -11.555398476563031,
           -11.567303172083074,
           -11.579207867603113,
           -11.591112563123154,
           -11.603017258643195,
           -11.614921954163234,
           -11.626826649683274,
           -11.638731345203317,
           -11.650636040723356,
           -11.662540736243397,
           -11.674445431763436,
           -11.686350127283477,
           -11.698254822803516,
           -11.710159518323557,
           -11.722064213843598,
           -11.733968909363636,
           -11.745873604883677,
           -11.757778300403718,
           -11.769682995923759,
           -11.7815876914438,
           -11.793492386963841,
           -11.80539708248388,
           -11.818980260369703,
           -11.834241920621313,
           -11.84950358087292,
           -11.864765241124527,
           -11.880026901376137,
           -11.895288561627744,
           -11.910550221879351,
           -11.92581188213096,
           -11.941073542382568,
           -11.956335202634174,
           -11.971596862885782,
           -11.986858523137391,
           -12.002120183389,
           -12.017381843640607,
           -12.032643503892213,
           -12.047905164143822,
           -12.063166824395427,
           -12.078428484647038,
           -12.093690144898645,
           -12.108951805150252,
           -12.124213465401859,
           -12.139475125653467,
           -12.154736785905074,
           -12.169998446156683,
           -12.185260106408293,
           -12.2005217666599,
           -12.215783426911507,
           -12.231045087163114,
           -12.246306747414721,
           -12.26156840766633,
           -12.276830067917938,
           -12.292091728169545,
           -12.307353388421154,
           -12.322615048672763,
           -12.33787670892437,
           -12.353138369175976,
           -12.368400029427583,
           -12.383661689679194,
           -12.398923349930799,
           -12.414185010182406,
           -12.429446670434015,
           -12.444708330685621,
           -12.459969990937228,
           -12.475231651188839,
           -12.490493311440446,
           -12.505754971692053,
           -12.521016631943661,
           -12.53627829219527,
           -12.551539952446877,
           -12.566801612698484,
           -12.582063272950093,
           -12.597324933201701,
           -12.612586593453308,
           -12.627848253704917,
           -12.643109913956526,
           -12.65837157420813,
           -12.673633234459741,
           -12.688894894711348,
           -12.704156554962955,
           -12.719418215214562,
           -12.734679875466172,
           -12.749941535717777,
           -12.765203195969386,
           -12.780464856220995,
           -12.795726516472602,
           -12.81098817672421,
           -12.826249836975817,
           -12.841511497227426,
           -12.856773157479031,
           -12.872034817730642,
           -12.88729647798225,
           -12.90395136799873,
           -12.921669520428614,
           -12.939387672858501,
           -12.957105825288386,
           -12.974823977718271,
           -12.992542130148157,
           -13.010260282578042,
           -13.027978435007926,
           -13.045696587437813,
           -13.063414739867701,
           -13.081132892297584,
           -13.09885104472747,
           -13.113239006460407,
           -13.120966586799453,
           -13.128694167138498,
           -13.136421747477542,
           -13.144149327816587,
           -13.151876908155634,
           -13.15960448849468,
           -13.167332068833725,
           -13.175059649172768,
           -13.182787229511813,
           -13.190514809850859,
           -13.198242390189904,
           -13.205969970528951,
           -13.213697550867995,
           -13.22142513120704,
           -13.229152711546085,
           -13.23688029188513,
           -13.244607872224176,
           -13.25233545256322,
           -13.260063032902265,
           -13.26779061324131,
           -13.275518193580357,
           -13.2832457739194,
           -13.290973354258448,
           -13.298700934597491,
           -13.306428514936535,
           -13.314156095275582,
           -13.321883675614629,
           -13.329611255953669,
           -13.337338836292716,
           -13.345066416631761,
           -13.352793996970806,
           -13.360521577309852,
           -13.368249157648899,
           -13.375976737987944,
           -13.383704318326986,
           -13.391431898666033,
           -13.399205368627358,
           -13.407538664341715,
           -13.41587196005607,
           -13.424205255770426,
           -13.432538551484782,
           -13.440871847199137,
           -13.449205142913494,
           -13.45753843862785,
           -13.465871734342207,
           -13.474205030056561,
           -13.482538325770918,
           -13.490871621485272,
           -13.499204917199629,
           -13.507538212913984,
           -13.51587150862834,
           -13.524204804342697,
           -13.532538100057053,
           -13.54087139577141,
           -13.549204691485762,
           -13.557537987200119,
           -13.565871282914475,
           -13.57420457862883,
           -13.582537874343188,
           -13.590871170057543,
           -13.5992044657719,
           -13.607537761486256,
           -13.61587105720061,
           -13.624204352914965,
           -13.632537648629322,
           -13.640870944343678,
           -13.649204240058033,
           -13.65753753577239,
           -13.665870831486746,
           -13.6742041272011,
           -13.682537422915455,
           -13.690870718629812,
           -13.699204014344168,
           -13.707537310058523,
           -13.71587060577288,
           -13.724203901487236,
           -13.73253719720159,
           -13.740870492915947,
           -13.749203788630304,
           -13.757537084344658,
           -13.765870380059013,
           -13.774203675773371,
           -13.785167881551653,
           -13.80928663764957,
           -13.833405393747489,
           -13.857524149845407,
           -13.88164290594332,
           -13.905761662041238,
           -13.929880418139156,
           -13.953999174237069,
           -13.978117930334989,
           -14.002236686432905,
           -14.02635544253082,
           -14.050474198628736,
           -14.074592954726656,
           -14.098711710824572,
           -14.122830466922487,
           -14.146949223020403,
           -14.171067979118323,
           -14.195186735216236,
           -14.219305491314152,
           -14.243424247412072,
           -14.267543003509985,
           -14.291661759607903,
           -14.315780515705823,
           -14.339899271803732,
           -14.364018027901652,
           -14.38813678399957,
           -14.412255540097487,
           -14.436374296195401,
           -14.46049305229332,
           -14.484611808391238,
           -14.508730564489149,
           -14.532849320587069,
           -14.556968076684985,
           -14.5810868327829,
           -14.605205588880818,
           -14.629324344978736,
           -14.640648445204693,
           -14.646907462834934,
           -14.653166480465178,
           -14.659425498095418,
           -14.66568451572566,
           -14.671943533355904,
           -14.657234746885752,
           -14.627548957486763,
           -14.597863168087768,
           -14.568177378688773,
           -14.538491589289785,
           -14.508805799890789,
           -14.465036169674251,
           -14.404071728229402,
           -14.343107286784564,
           -14.282142845339715,
           -14.221178403894864,
           -14.160213962450026,
           -14.099249521005177,
           -14.038285079560328,
           -13.97732063811549,
           -13.91635619667064,
           -13.85539175522579,
           -13.79442731378094,
           -13.733462872336105,
           -13.672498430891252,
           -13.611533989446404,
           -13.550569548001565,
           -13.489605106556716,
           -13.428640665111867,
           -13.367676223667027,
           -13.30671178222218,
           -13.24574734077733,
           -13.184782899332491,
           -13.12381845788764,
           -13.062854016442792,
           -13.001889574997943,
           -12.940925133553105,
           -12.879960692108254,
           -12.818996250663407,
           -12.758031809218568,
           -12.697067367773718,
           -12.636102926328869,
           -12.57513848488403,
           -12.514174043439183,
           -12.453209601994331,
           -12.392245160549482,
           -12.331280719104644
          ],
          [
           -8.382756970623477,
           -8.392887040973546,
           -8.403017111323615,
           -8.413147181673684,
           -8.423277252023754,
           -8.433407322373824,
           -8.443537392723893,
           -8.453667463073963,
           -8.463797533424033,
           -8.473927603774102,
           -8.484057674124172,
           -8.49418774447424,
           -8.50431781482431,
           -8.51444788517438,
           -8.52457795552445,
           -8.534708025874519,
           -8.544838096224588,
           -8.554968166574659,
           -8.565098236924728,
           -8.575228307274797,
           -8.585358377624866,
           -8.595488447974937,
           -8.606609003944376,
           -8.619710531472315,
           -8.632812059000251,
           -8.645913586528188,
           -8.659015114056125,
           -8.672116641584061,
           -8.685218169112,
           -8.698319696639935,
           -8.711421224167873,
           -8.72452275169581,
           -8.737624279223747,
           -8.750725806751685,
           -8.76382733427962,
           -8.776928861807558,
           -8.790030389335495,
           -8.803131916863432,
           -8.816233444391369,
           -8.829334971919305,
           -8.842436499447242,
           -8.855538026975179,
           -8.868639554503119,
           -8.881741082031054,
           -8.89484260955899,
           -8.907944137086929,
           -8.921045664614866,
           -8.934147192142802,
           -8.947248719670739,
           -8.960350247198676,
           -8.973451774726614,
           -8.98655330225455,
           -8.999654829782488,
           -9.012756357310424,
           -9.025857884838361,
           -9.038959412366298,
           -9.052060939894234,
           -9.065162467422173,
           -9.07826399495011,
           -9.091365522478046,
           -9.104467050005983,
           -9.11756857753392,
           -9.130670105061858,
           -9.143771632589795,
           -9.156873160117732,
           -9.169974687645668,
           -9.183076215173605,
           -9.196177742701542,
           -9.20927927022948,
           -9.222380797757417,
           -9.235482325285354,
           -9.24858385281329,
           -9.261685380341229,
           -9.274786907869165,
           -9.2878884353971,
           -9.30098996292504,
           -9.314091490452975,
           -9.327193017980914,
           -9.34029454550885,
           -9.353396073036787,
           -9.366497600564724,
           -9.37959912809266,
           -9.3927006556206,
           -9.405802183148536,
           -9.414860114927134,
           -9.423109327555865,
           -9.431358540184597,
           -9.439607752813329,
           -9.44785696544206,
           -9.45610617807079,
           -9.464355390699524,
           -9.472604603328254,
           -9.480853815956987,
           -9.489103028585717,
           -9.49735224121445,
           -9.50560145384318,
           -9.513850666471914,
           -9.522099879100644,
           -9.530349091729377,
           -9.538598304358107,
           -9.546847516986839,
           -9.55509672961557,
           -9.563345942244302,
           -9.571595154873034,
           -9.579844367501764,
           -9.588556659047258,
           -9.59958434577455,
           -9.610612032501844,
           -9.621639719229139,
           -9.632667405956429,
           -9.643695092683721,
           -9.654722779411014,
           -9.665750466138308,
           -9.6767781528656,
           -9.687805839592892,
           -9.698833526320184,
           -9.709861213047478,
           -9.72088889977477,
           -9.731916586502063,
           -9.742944273229355,
           -9.753971959956647,
           -9.764999646683941,
           -9.776027333411234,
           -9.787055020138526,
           -9.798082706865818,
           -9.80911039359311,
           -9.820138080320405,
           -9.831165767047695,
           -9.842193453774989,
           -9.853221140502281,
           -9.864248827229574,
           -9.875276513956866,
           -9.886304200684158,
           -9.89733188741145,
           -9.908359574138744,
           -9.919387260866037,
           -9.930414947593329,
           -9.941442634320621,
           -9.952470321047915,
           -9.963498007775208,
           -9.9745256945025,
           -9.985553381229792,
           -9.996581067957084,
           -10.007608754684377,
           -10.018636441411669,
           -10.029664128138961,
           -10.040691814866255,
           -10.05171950159355,
           -10.06274718832084,
           -10.073774875048134,
           -10.084802561775426,
           -10.095830248502718,
           -10.10685793523001,
           -10.117885621957303,
           -10.128913308684595,
           -10.139940995411887,
           -10.15096868213918,
           -10.161996368866472,
           -10.173024055593764,
           -10.184051742321058,
           -10.19507942904835,
           -10.206107115775643,
           -10.217134802502937,
           -10.228162489230227,
           -10.239190175957521,
           -10.250217862684813,
           -10.261245549412106,
           -10.272041016614573,
           -10.282720374054627,
           -10.29339973149468,
           -10.304079088934733,
           -10.314758446374787,
           -10.325437803814841,
           -10.336117161254894,
           -10.346796518694948,
           -10.357475876135004,
           -10.368155233575054,
           -10.37883459101511,
           -10.389513948455162,
           -10.400193305895217,
           -10.41087266333527,
           -10.421552020775323,
           -10.432231378215377,
           -10.442910735655431,
           -10.453590093095485,
           -10.464269450535538,
           -10.474948807975592,
           -10.485628165415644,
           -10.4963075228557,
           -10.506986880295752,
           -10.517666237735806,
           -10.52834559517586,
           -10.539024952615913,
           -10.549704310055967,
           -10.560383667496021,
           -10.571063024936075,
           -10.581742382376127,
           -10.592421739816182,
           -10.603101097256236,
           -10.61378045469629,
           -10.624459812136342,
           -10.635139169576398,
           -10.645818527016448,
           -10.656497884456503,
           -10.667177241896557,
           -10.67785659933661,
           -10.688535956776665,
           -10.699215314216719,
           -10.70989467165677,
           -10.720574029096825,
           -10.731253386536878,
           -10.741932743976932,
           -10.752612101416986,
           -10.76329145885704,
           -10.773970816297094,
           -10.784650173737148,
           -10.795329531177202,
           -10.806008888617255,
           -10.816688246057307,
           -10.827625572651671,
           -10.83953026817171,
           -10.851434963691752,
           -10.863339659211793,
           -10.875244354731834,
           -10.887149050251873,
           -10.899053745771914,
           -10.910958441291955,
           -10.922863136811994,
           -10.934767832332033,
           -10.946672527852076,
           -10.958577223372115,
           -10.970481918892157,
           -10.982386614412196,
           -10.994291309932237,
           -11.006196005452278,
           -11.018100700972317,
           -11.030005396492358,
           -11.041910092012397,
           -11.053814787532437,
           -11.06571948305248,
           -11.07762417857252,
           -11.089528874092558,
           -11.101433569612599,
           -11.11333826513264,
           -11.12524296065268,
           -11.137147656172719,
           -11.149052351692761,
           -11.1609570472128,
           -11.172861742732842,
           -11.184766438252883,
           -11.198349616138705,
           -11.213611276390315,
           -11.228872936641922,
           -11.244134596893527,
           -11.259396257145138,
           -11.274657917396746,
           -11.289919577648352,
           -11.30518123789996,
           -11.320442898151569,
           -11.335704558403176,
           -11.350966218654783,
           -11.366227878906393,
           -11.381489539158,
           -11.396751199409607,
           -11.412012859661214,
           -11.427274519912823,
           -11.442536180164431,
           -11.457797840416038,
           -11.473059500667645,
           -11.488321160919254,
           -11.503582821170863,
           -11.51884448142247,
           -11.534106141674076,
           -11.549367801925685,
           -11.564629462177294,
           -11.5798911224289,
           -11.595152782680508,
           -11.610414442932116,
           -11.625676103183725,
           -11.640937763435332,
           -11.656199423686939,
           -11.67146108393855,
           -11.686722744190154,
           -11.701984404441763,
           -11.717246064693374,
           -11.732507724944977,
           -11.747769385196586,
           -11.763031045448194,
           -11.778292705699801,
           -11.793554365951408,
           -11.808816026203017,
           -11.824077686454626,
           -11.839339346706232,
           -11.85460100695784,
           -11.86986266720945,
           -11.885124327461053,
           -11.900385987712664,
           -11.915647647964272,
           -11.930105299729924,
           -11.944170752897048,
           -11.958236206064171,
           -11.972301659231295,
           -11.98636711239842,
           -12.000432565565545,
           -12.01449801873267,
           -12.02856347189979,
           -12.042628925066914,
           -12.056694378234038,
           -12.070759831401164,
           -12.08482528456829,
           -12.098890737735411,
           -12.112956190902535,
           -12.127021644069659,
           -12.141087097236783,
           -12.155152550403908,
           -12.169218003571032,
           -12.183283456738156,
           -12.197348909905282,
           -12.211414363072404,
           -12.225479816239528,
           -12.239545269406651,
           -12.253610722573775,
           -12.267676175740899,
           -12.281741628908023,
           -12.295807082075147,
           -12.309872535242269,
           -12.323937988409396,
           -12.338003441576518,
           -12.352068894743642,
           -12.366134347910766,
           -12.380199801077891,
           -12.394265254245013,
           -12.408330707412137,
           -12.420916707866601,
           -12.43054380289574,
           -12.440170897924876,
           -12.449797992954014,
           -12.459425087983153,
           -12.469052183012293,
           -12.478679278041431,
           -12.48830637307057,
           -12.497933468099708,
           -12.507560563128846,
           -12.517187658157985,
           -12.526814753187123,
           -12.536441848216262,
           -12.546068943245402,
           -12.555696038274537,
           -12.565323133303679,
           -12.574950228332817,
           -12.584577323361955,
           -12.594204418391092,
           -12.603831513420232,
           -12.61345860844937,
           -12.62308570347851,
           -12.632712798507647,
           -12.642339893536786,
           -12.651966988565926,
           -12.661248071084714,
           -12.669581366799068,
           -12.677914662513427,
           -12.686247958227781,
           -12.694581253942138,
           -12.702914549656494,
           -12.711247845370849,
           -12.719581141085206,
           -12.727914436799562,
           -12.736247732513917,
           -12.744581028228273,
           -12.75291432394263,
           -12.761247619656984,
           -12.76958091537134,
           -12.777914211085697,
           -12.786247506800052,
           -12.794580802514407,
           -12.802914098228763,
           -12.81124739394312,
           -12.819580689657478,
           -12.827913985371833,
           -12.836247281086187,
           -12.844580576800544,
           -12.852913872514899,
           -12.861247168229255,
           -12.86958046394361,
           -12.877913759657966,
           -12.886247055372323,
           -12.894580351086681,
           -12.902913646801034,
           -12.91124694251539,
           -12.919580238229749,
           -12.927913533944103,
           -12.936246829658458,
           -12.944580125372815,
           -12.952913421087171,
           -12.961246716801526,
           -12.96958001251588,
           -12.977913308230237,
           -12.986246603944593,
           -12.994579899658948,
           -13.002913195373306,
           -13.01124649108766,
           -13.019579786802016,
           -13.027913082516372,
           -13.036246378230729,
           -13.044579673945083,
           -13.05291296965944,
           -13.061246265373796,
           -13.069579561088151,
           -13.077912856802506,
           -13.086246152516864,
           -13.094579448231219,
           -13.102912743945573,
           -13.111246039659932,
           -13.119579335374286,
           -13.127912631088641,
           -13.136245926802998,
           -13.14721013258128,
           -13.171328888679199,
           -13.195447644777115,
           -13.219566400875035,
           -13.243685156972948,
           -13.267803913070864,
           -13.291922669168782,
           -13.316041425266697,
           -13.340160181364617,
           -13.364278937462533,
           -13.388397693560446,
           -13.412516449658364,
           -13.43663520575628,
           -13.460753961854198,
           -13.484872717952115,
           -13.508991474050031,
           -13.53311023014795,
           -13.55722898624586,
           -13.58134774234378,
           -13.605466498441697,
           -13.629249195089493,
           -13.635508212719735,
           -13.641767230349975,
           -13.648026247980217,
           -13.654285265610461,
           -13.660544283240704,
           -13.666803300870946,
           -13.673062318501188,
           -13.67932133613143,
           -13.685580353761672,
           -13.691839371391913,
           -13.698098389022157,
           -13.704357406652399,
           -13.710616424282641,
           -13.716875441912881,
           -13.723134459543125,
           -13.729393477173367,
           -13.73565249480361,
           -13.741911512433852,
           -13.748170530064092,
           -13.754429547694334,
           -13.760688565324577,
           -13.745979778854428,
           -13.716293989455439,
           -13.686608200056446,
           -13.65692241065745,
           -13.627236621258458,
           -13.597550831859465,
           -13.56786504246047,
           -13.538179253061474,
           -13.508493463662486,
           -13.47880767426349,
           -13.449121884864493,
           -13.419436095465505,
           -13.389750306066512,
           -13.360064516667515,
           -13.330378727268526,
           -13.30069293786953,
           -13.271007148470535,
           -13.24132135907154,
           -13.21163556967255,
           -13.181949780273555,
           -13.15226399087456,
           -13.117953650501928,
           -13.056989209057079,
           -12.996024767612228,
           -12.935060326167392,
           -12.87409588472254,
           -12.81313144327769,
           -12.752167001832852,
           -12.691202560388003,
           -12.630238118943154,
           -12.569273677498304,
           -12.508309236053467,
           -12.447344794608618,
           -12.38638035316377,
           -12.32541591171893,
           -12.264451470274079,
           -12.20348702882923,
           -12.142522587384391,
           -12.081558145939542,
           -12.020593704494694,
           -11.959629263049845,
           -11.898664821605005
          ],
          [
           -7.905949223062861,
           -7.916079293412931,
           -7.926209363763,
           -7.936339434113069,
           -7.946469504463139,
           -7.956599574813209,
           -7.966729645163278,
           -7.976859715513348,
           -7.9869897858634165,
           -7.997119856213487,
           -8.007249926563556,
           -8.017379996913625,
           -8.027510067263695,
           -8.037640137613765,
           -8.047770207963834,
           -8.057900278313904,
           -8.068030348663973,
           -8.078160419014043,
           -8.088290489364113,
           -8.098420559714182,
           -8.10855063006425,
           -8.118680700414322,
           -8.12881077076439,
           -8.13894084111446,
           -8.149070911464529,
           -8.1592009818146,
           -8.169331052164669,
           -8.179461122514738,
           -8.189591192864807,
           -8.199721263214878,
           -8.209851333564945,
           -8.219981403915016,
           -8.230111474265085,
           -8.240241544615156,
           -8.250371614965225,
           -8.260501685315294,
           -8.270631755665365,
           -8.280761826015432,
           -8.290891896365503,
           -8.303498180433586,
           -8.316599707961524,
           -8.329701235489459,
           -8.3428027630174,
           -8.355904290545334,
           -8.369005818073271,
           -8.38210734560121,
           -8.395208873129146,
           -8.408310400657083,
           -8.42141192818502,
           -8.434513455712956,
           -8.447614983240895,
           -8.46071651076883,
           -8.473818038296768,
           -8.486919565824705,
           -8.500021093352641,
           -8.51312262088058,
           -8.526224148408515,
           -8.539325675936453,
           -8.55242720346439,
           -8.565528730992327,
           -8.578630258520263,
           -8.5917317860482,
           -8.604833313576139,
           -8.617934841104075,
           -8.63103636863201,
           -8.644137896159949,
           -8.657239423687887,
           -8.670340951215824,
           -8.68344247874376,
           -8.696544006271697,
           -8.709645533799634,
           -8.722747061327572,
           -8.735848588855509,
           -8.748950116383446,
           -8.76205164391138,
           -8.775153171439321,
           -8.788254698967258,
           -8.801356226495193,
           -8.814457754023131,
           -8.82755928155107,
           -8.840660809079004,
           -8.853762336606941,
           -8.86686386413488,
           -8.879965391662816,
           -8.889023323441414,
           -8.897272536070146,
           -8.905521748698877,
           -8.913770961327609,
           -8.92202017395634,
           -8.930269386585072,
           -8.938518599213804,
           -8.946767811842536,
           -8.955017024471267,
           -8.963266237099997,
           -8.97151544972873,
           -8.97976466235746,
           -8.988013874986194,
           -8.996263087614924,
           -9.004512300243658,
           -9.012761512872387,
           -9.02101072550112,
           -9.02925993812985,
           -9.037509150758583,
           -9.045758363387314,
           -9.054007576016044,
           -9.062256788644776,
           -9.070506001273507,
           -9.07875521390224,
           -9.08700442653097,
           -9.095253639159703,
           -9.103502851788434,
           -9.111752064417166,
           -9.120001277045898,
           -9.128250489674627,
           -9.136499702303361,
           -9.14474891493209,
           -9.152998127560824,
           -9.161247340189554,
           -9.169496552818288,
           -9.177745765447018,
           -9.185994978075751,
           -9.194244190704481,
           -9.204345718840809,
           -9.215373405568101,
           -9.226401092295394,
           -9.237428779022688,
           -9.24845646574998,
           -9.259484152477272,
           -9.270511839204564,
           -9.281539525931857,
           -9.292567212659149,
           -9.303594899386443,
           -9.314622586113734,
           -9.325650272841026,
           -9.33667795956832,
           -9.347705646295612,
           -9.358733333022904,
           -9.369761019750197,
           -9.38078870647749,
           -9.391816393204783,
           -9.402844079932073,
           -9.413871766659367,
           -9.424899453386661,
           -9.435927140113952,
           -9.446954826841246,
           -9.457982513568538,
           -9.46901020029583,
           -9.480037887023123,
           -9.491065573750415,
           -9.502093260477707,
           -9.513120947205001,
           -9.524148633932292,
           -9.535176320659584,
           -9.546204007386876,
           -9.55723169411417,
           -9.568259380841464,
           -9.579287067568757,
           -9.590314754296049,
           -9.601342441023341,
           -9.612370127750633,
           -9.623397814477926,
           -9.634425501205218,
           -9.64545318793251,
           -9.656480874659803,
           -9.667508561387097,
           -9.678536248114389,
           -9.689563934841681,
           -9.700359402044148,
           -9.711038759484202,
           -9.721718116924256,
           -9.732397474364308,
           -9.743076831804363,
           -9.753756189244417,
           -9.76443554668447,
           -9.775114904124523,
           -9.785794261564579,
           -9.79647361900463,
           -9.807152976444684,
           -9.817832333884738,
           -9.828511691324792,
           -9.839191048764846,
           -9.8498704062049,
           -9.860549763644954,
           -9.871229121085006,
           -9.88190847852506,
           -9.892587835965115,
           -9.903267193405167,
           -9.913946550845221,
           -9.924625908285275,
           -9.935305265725328,
           -9.945984623165382,
           -9.956663980605436,
           -9.967343338045488,
           -9.978022695485542,
           -9.988702052925596,
           -9.99938141036565,
           -10.010060767805705,
           -10.020740125245757,
           -10.031419482685813,
           -10.042098840125865,
           -10.052778197565917,
           -10.063457555005971,
           -10.074136912446026,
           -10.08481626988608,
           -10.095495627326134,
           -10.106174984766188,
           -10.116854342206242,
           -10.127533699646294,
           -10.138213057086347,
           -10.1488924145264,
           -10.159571771966455,
           -10.170251129406509,
           -10.180930486846563,
           -10.191609844286614,
           -10.20228920172667,
           -10.212968559166724,
           -10.223647916606778,
           -10.23432727404683,
           -10.245006631486884,
           -10.255685988926938,
           -10.26636534636699,
           -10.277044703807046,
           -10.287724061247097,
           -10.298403418687153,
           -10.309082776127205,
           -10.31976213356726,
           -10.330441491007313,
           -10.341120848447368,
           -10.35180020588742,
           -10.362479563327474,
           -10.373158920767528,
           -10.38383827820758,
           -10.394517635647635,
           -10.405196993087689,
           -10.415876350527743,
           -10.426555707967797,
           -10.43723506540785,
           -10.447914422847903,
           -10.458593780287956,
           -10.469273137728011,
           -10.479952495168064,
           -10.490631852608118,
           -10.50131121004817,
           -10.511990567488224,
           -10.520732218112357,
           -10.529473863952493,
           -10.53821550979263,
           -10.546957155632764,
           -10.555698801472902,
           -10.56444044731304,
           -10.575163190944274,
           -10.587867032366605,
           -10.600570873788937,
           -10.613274715211269,
           -10.625978556633601,
           -10.63868239805593,
           -10.651386239478263,
           -10.664090080900596,
           -10.676793922322927,
           -10.689497763745258,
           -10.70220160516759,
           -10.714905446589922,
           -10.728698582991786,
           -10.74276403615891,
           -10.756829489326035,
           -10.770894942493157,
           -10.784960395660281,
           -10.799025848827407,
           -10.813091301994529,
           -10.827156755161653,
           -10.841222208328778,
           -10.855287661495902,
           -10.869353114663024,
           -10.883418567830148,
           -10.897484020997274,
           -10.911549474164396,
           -10.92561492733152,
           -10.939680380498647,
           -10.953745833665769,
           -10.967811286832893,
           -10.981876740000017,
           -10.995942193167142,
           -11.010007646334262,
           -11.02407309950139,
           -11.038138552668514,
           -11.052204005835637,
           -11.066269459002761,
           -11.080334912169885,
           -11.094400365337009,
           -11.108465818504133,
           -11.122531271671255,
           -11.13659672483838,
           -11.150662178005502,
           -11.164727631172628,
           -11.178793084339754,
           -11.192858537506876,
           -11.206923990674,
           -11.220989443841125,
           -11.235054897008247,
           -11.249120350175371,
           -11.263185803342495,
           -11.277251256509619,
           -11.291316709676742,
           -11.305382162843866,
           -11.319447616010992,
           -11.333513069178114,
           -11.347578522345238,
           -11.361643975512365,
           -11.375709428679487,
           -11.389774881846611,
           -11.403840335013737,
           -11.41790578818086,
           -11.431971241347982,
           -11.446036694515108,
           -11.460102147682232,
           -11.474167600849354,
           -11.48823305401648,
           -11.502298507183603,
           -11.516363960350725,
           -11.53042941351785,
           -11.544494866684975,
           -11.558560319852097,
           -11.57262577301922,
           -11.586691226186346,
           -11.600756679353472,
           -11.614822132520592,
           -11.62888758568772,
           -11.642953038854841,
           -11.657018492021965,
           -11.671083945189089,
           -11.685149398356215,
           -11.699214851523337,
           -11.713280304690462,
           -11.725866305144924,
           -11.735493400174063,
           -11.745120495203198,
           -11.75474759023234,
           -11.764374685261478,
           -11.774001780290616,
           -11.783628875319755,
           -11.793255970348895,
           -11.80288306537803,
           -11.812510160407168,
           -11.822137255436308,
           -11.831764350465447,
           -11.841391445494583,
           -11.851018540523725,
           -11.860645635552862,
           -11.870272730582,
           -11.87989982561114,
           -11.889526920640279,
           -11.899154015669415,
           -11.908781110698555,
           -11.918408205727694,
           -11.928035300756832,
           -11.93766239578597,
           -11.947289490815109,
           -11.956916585844247,
           -11.966543680873388,
           -11.976170775902524,
           -11.985797870931666,
           -11.995424965960801,
           -12.00505206098994,
           -12.014679156019081,
           -12.024306251048216,
           -12.033933346077355,
           -12.043560441106493,
           -12.053187536135635,
           -12.062814631164773,
           -12.072441726193912,
           -12.08206882122305,
           -12.091695916252188,
           -12.101323011281327,
           -12.110950106310465,
           -12.120577201339604,
           -12.130204296368742,
           -12.13983139139788,
           -12.149458486427019,
           -12.159085581456157,
           -12.168712676485296,
           -12.178339771514436,
           -12.187966866543576,
           -12.197593961572714,
           -12.20722105660185,
           -12.21684815163099,
           -12.22647524666013,
           -12.236102341689268,
           -12.245729436718403,
           -12.255356531747545,
           -12.264983626776683,
           -12.274610721805821,
           -12.28423781683496,
           -12.293864911864098,
           -12.303492006893237,
           -12.313119101922375,
           -12.322746196951513,
           -12.332373291980653,
           -12.342000387009788,
           -12.351627482038928,
           -12.361254577068069,
           -12.370881672097205,
           -12.380508767126345,
           -12.38995533354601,
           -12.398288629260366,
           -12.406621924974722,
           -12.414955220689079,
           -12.423288516403433,
           -12.43162181211779,
           -12.439955107832144,
           -12.448288403546501,
           -12.456621699260856,
           -12.464954994975212,
           -12.473288290689569,
           -12.481621586403925,
           -12.48995488211828,
           -12.498288177832636,
           -12.509252383610917,
           -12.533371139708835,
           -12.557489895806754,
           -12.581608651904672,
           -12.605727408002586,
           -12.624108962604552,
           -12.630367980234794,
           -12.636626997865037,
           -12.642886015495279,
           -12.64914503312552,
           -12.655404050755763,
           -12.661663068386003,
           -12.667922086016247,
           -12.67418110364649,
           -12.680440121276732,
           -12.686699138906974,
           -12.692958156537216,
           -12.699217174167458,
           -12.7054761917977,
           -12.711735209427943,
           -12.717994227058185,
           -12.724253244688427,
           -12.730512262318669,
           -12.736771279948911,
           -12.743030297579153,
           -12.749289315209396,
           -12.755548332839638,
           -12.76180735046988,
           -12.768066368100122,
           -12.774325385730364,
           -12.780584403360606,
           -12.786843420990849,
           -12.793102438621093,
           -12.799361456251331,
           -12.805620473881575,
           -12.811879491511817,
           -12.81813850914206,
           -12.824397526772302,
           -12.830656544402544,
           -12.836915562032786,
           -12.843174579663028,
           -12.849433597293272,
           -12.83472481082312,
           -12.805039021424129,
           -12.775353232025136,
           -12.745667442626141,
           -12.715981653227152,
           -12.686295863828157,
           -12.656610074429162,
           -12.626924285030167,
           -12.597238495631176,
           -12.567552706232181,
           -12.537866916833188,
           -12.508181127434197,
           -12.478495338035202,
           -12.448809548636207,
           -12.419123759237218,
           -12.389437969838223,
           -12.359752180439228,
           -12.330066391040233,
           -12.300380601641244,
           -12.27069481224225,
           -12.24100902284325,
           -12.211323233444263,
           -12.181637444045268,
           -12.151951654646275,
           -12.122265865247284,
           -12.09258007584829,
           -12.062894286449295,
           -12.033208497050305,
           -12.00352270765131,
           -11.973836918252314,
           -11.94415112885332,
           -11.91446533945433,
           -11.884779550055335,
           -11.85509376065634,
           -11.825407971257352,
           -11.795722181858356,
           -11.76603639245936,
           -11.709906689884761,
           -11.648942248439912,
           -11.587977806995063,
           -11.527013365550212,
           -11.466048924105374
          ],
          [
           -7.429141475502236,
           -7.439271545852305,
           -7.449401616202374,
           -7.459531686552444,
           -7.469661756902514,
           -7.479791827252583,
           -7.4899218976026525,
           -7.5000519679527216,
           -7.510182038302792,
           -7.5203121086528615,
           -7.5304421790029314,
           -7.540572249353,
           -7.5507023197030705,
           -7.56083239005314,
           -7.5709624604032095,
           -7.5810925307532795,
           -7.591222601103349,
           -7.601352671453418,
           -7.611482741803487,
           -7.621612812153557,
           -7.631742882503626,
           -7.641872952853696,
           -7.652003023203765,
           -7.662133093553834,
           -7.672263163903905,
           -7.682393234253973,
           -7.692523304604043,
           -7.702653374954113,
           -7.712783445304182,
           -7.722913515654252,
           -7.733043586004321,
           -7.74317365635439,
           -7.75330372670446,
           -7.76343379705453,
           -7.773563867404599,
           -7.783693937754669,
           -7.793824008104737,
           -7.803954078454808,
           -7.814084148804877,
           -7.824214219154946,
           -7.834344289505016,
           -7.844474359855085,
           -7.854604430205155,
           -7.864734500555224,
           -7.874864570905293,
           -7.884994641255363,
           -7.895124711605433,
           -7.905254781955502,
           -7.915384852305572,
           -7.9255149226556405,
           -7.935644993005711,
           -7.945775063355781,
           -7.9559051337058495,
           -7.966035204055919,
           -7.9761652744059885,
           -7.98728582939485,
           -8.000387356922786,
           -8.013488884450723,
           -8.02659041197866,
           -8.039691939506596,
           -8.052793467034535,
           -8.065894994562472,
           -8.07899652209041,
           -8.092098049618345,
           -8.105199577146283,
           -8.11830110467422,
           -8.131402632202155,
           -8.144504159730094,
           -8.15760568725803,
           -8.170707214785967,
           -8.183808742313905,
           -8.19691026984184,
           -8.210011797369779,
           -8.223113324897716,
           -8.236214852425652,
           -8.249316379953589,
           -8.262417907481527,
           -8.275519435009464,
           -8.2886209625374,
           -8.301722490065337,
           -8.314824017593276,
           -8.32792554512121,
           -8.341027072649148,
           -8.354128600177086,
           -8.363186531955686,
           -8.371435744584417,
           -8.379684957213147,
           -8.387934169841879,
           -8.39618338247061,
           -8.404432595099342,
           -8.412681807728074,
           -8.420931020356806,
           -8.429180232985537,
           -8.437429445614269,
           -8.445678658243,
           -8.45392787087173,
           -8.462177083500464,
           -8.470426296129194,
           -8.478675508757927,
           -8.486924721386657,
           -8.495173934015389,
           -8.50342314664412,
           -8.511672359272852,
           -8.519921571901584,
           -8.528170784530316,
           -8.536419997159047,
           -8.544669209787779,
           -8.55291842241651,
           -8.561167635045242,
           -8.569416847673972,
           -8.577666060302706,
           -8.585915272931436,
           -8.594164485560167,
           -8.602413698188899,
           -8.61066291081763,
           -8.618912123446362,
           -8.627161336075094,
           -8.635410548703824,
           -8.643659761332557,
           -8.651908973961287,
           -8.66015818659002,
           -8.66840739921875,
           -8.676656611847482,
           -8.684905824476214,
           -8.693155037104946,
           -8.701404249733677,
           -8.70965346236241,
           -8.71790267499114,
           -8.726151887619872,
           -8.734401100248604,
           -8.742650312877334,
           -8.750899525506066,
           -8.759148738134797,
           -8.76739795076353,
           -8.77564716339226,
           -8.783896376020992,
           -8.792145588649724,
           -8.800394801278456,
           -8.809107091907055,
           -8.820134778634348,
           -8.83116246536164,
           -8.842190152088932,
           -8.853217838816226,
           -8.864245525543518,
           -8.87527321227081,
           -8.886300898998103,
           -8.897328585725395,
           -8.90835627245269,
           -8.91938395917998,
           -8.930411645907274,
           -8.941439332634566,
           -8.952467019361858,
           -8.96349470608915,
           -8.974522392816443,
           -8.985550079543737,
           -8.99657776627103,
           -9.007605452998321,
           -9.018633139725614,
           -9.029660826452906,
           -9.040688513180198,
           -9.05171619990749,
           -9.062743886634783,
           -9.073771573362077,
           -9.084799260089369,
           -9.095826946816661,
           -9.106854633543954,
           -9.117882320271246,
           -9.128677787473713,
           -9.139357144913767,
           -9.15003650235382,
           -9.160715859793873,
           -9.171395217233925,
           -9.182074574673981,
           -9.192753932114034,
           -9.20343328955409,
           -9.214112646994144,
           -9.224792004434196,
           -9.23547136187425,
           -9.246150719314302,
           -9.256830076754357,
           -9.26750943419441,
           -9.278188791634465,
           -9.288868149074517,
           -9.299547506514571,
           -9.310226863954625,
           -9.32090622139468,
           -9.331585578834732,
           -9.342264936274786,
           -9.35294429371484,
           -9.363623651154894,
           -9.374303008594946,
           -9.384982366035,
           -9.395661723475055,
           -9.406341080915109,
           -9.417020438355161,
           -9.427699795795215,
           -9.43837915323527,
           -9.449058510675322,
           -9.459737868115377,
           -9.47041722555543,
           -9.481096582995484,
           -9.491775940435536,
           -9.502455297875592,
           -9.513134655315644,
           -9.523814012755697,
           -9.53449337019575,
           -9.545172727635805,
           -9.555852085075859,
           -9.566531442515911,
           -9.577210799955967,
           -9.58789015739602,
           -9.598569514836072,
           -9.609248872276128,
           -9.61992822971618,
           -9.630607587156234,
           -9.641071645549413,
           -9.649813291389549,
           -9.658554937229686,
           -9.66729658306982,
           -9.67603822890996,
           -9.684779874750095,
           -9.693521520590233,
           -9.702263166430367,
           -9.711004812270502,
           -9.719746458110642,
           -9.728488103950777,
           -9.737229749790915,
           -9.745971395631049,
           -9.754713041471188,
           -9.763454687311324,
           -9.77219633315146,
           -9.780937978991595,
           -9.789679624831733,
           -9.798421270671868,
           -9.807162916512006,
           -9.815904562352141,
           -9.824646208192277,
           -9.833387854032416,
           -9.842129499872552,
           -9.850871145712688,
           -9.859612791552824,
           -9.868354437392961,
           -9.877096083233097,
           -9.885837729073234,
           -9.89457937491337,
           -9.903321020753506,
           -9.912062666593641,
           -9.920804312433779,
           -9.929545958273916,
           -9.938287604114052,
           -9.949010347745286,
           -9.961714189167619,
           -9.97441803058995,
           -9.987121872012281,
           -9.999825713434614,
           -10.012529554856943,
           -10.025233396279276,
           -10.037937237701609,
           -10.05064107912394,
           -10.063344920546271,
           -10.076048761968604,
           -10.088752603390935,
           -10.101456444813266,
           -10.114160286235599,
           -10.12686412765793,
           -10.139567969080261,
           -10.152271810502594,
           -10.164975651924925,
           -10.177679493347256,
           -10.190383334769589,
           -10.203087176191922,
           -10.215791017614253,
           -10.228494859036582,
           -10.241198700458916,
           -10.25390254188125,
           -10.266606383303579,
           -10.27931022472591,
           -10.292014066148242,
           -10.304717907570573,
           -10.317421748992905,
           -10.330125590415237,
           -10.34282943183757,
           -10.3555332732599,
           -10.36823711468223,
           -10.380940956104563,
           -10.393644797526896,
           -10.406348638949227,
           -10.419052480371558,
           -10.431756321793891,
           -10.44446016321622,
           -10.457164004638553,
           -10.469867846060886,
           -10.482571687483217,
           -10.495275528905548,
           -10.507979370327881,
           -10.52068321175021,
           -10.533387053172543,
           -10.546090894594876,
           -10.558794736017207,
           -10.571498577439538,
           -10.58420241886187,
           -10.596906260284202,
           -10.609610101706533,
           -10.622313943128866,
           -10.635017784551199,
           -10.647721625973528,
           -10.660425467395859,
           -10.673129308818192,
           -10.685833150240525,
           -10.698536991662854,
           -10.711240833085188,
           -10.723944674507518,
           -10.73692083862629,
           -10.750986291793417,
           -10.76505174496054,
           -10.779117198127663,
           -10.793182651294789,
           -10.807248104461912,
           -10.821313557629034,
           -10.83537901079616,
           -10.849444463963284,
           -10.863509917130408,
           -10.877575370297532,
           -10.891640823464657,
           -10.90570627663178,
           -10.919771729798903,
           -10.933837182966029,
           -10.94790263613315,
           -10.961968089300274,
           -10.9760335424674,
           -10.990098995634524,
           -11.004164448801648,
           -11.01822990196877,
           -11.030815902423234,
           -11.040442997452372,
           -11.05007009248151,
           -11.059697187510649,
           -11.069324282539787,
           -11.078951377568925,
           -11.088578472598064,
           -11.098205567627202,
           -11.10783266265634,
           -11.117459757685479,
           -11.127086852714617,
           -11.136713947743758,
           -11.146341042772896,
           -11.155968137802034,
           -11.165595232831173,
           -11.175222327860311,
           -11.18484942288945,
           -11.194476517918588,
           -11.204103612947726,
           -11.213730707976865,
           -11.223357803006005,
           -11.232984898035143,
           -11.24261199306428,
           -11.252239088093418,
           -11.261866183122558,
           -11.271493278151695,
           -11.281120373180835,
           -11.290747468209974,
           -11.300374563239112,
           -11.310001658268252,
           -11.31962875329739,
           -11.329255801474993,
           -11.338881491029039,
           -11.348507180583084,
           -11.35813287013713,
           -11.367758559691175,
           -11.377384249245221,
           -11.387009938799268,
           -11.396635628353312,
           -11.40626131790736,
           -11.415887007461405,
           -11.42551269701545,
           -11.435138386569498,
           -11.444764076123544,
           -11.45438976567759,
           -11.464015455231635,
           -11.473641144785681,
           -11.483266834339727,
           -11.49289252389377,
           -11.50251821344782,
           -11.512143903001864,
           -11.52176959255591,
           -11.531395282109955,
           -11.541020971664002,
           -11.550646661218046,
           -11.560272350772095,
           -11.569898040326139,
           -11.579523729880183,
           -11.589149419434232,
           -11.598775108988278,
           -11.608400798542323,
           -11.618026488096369,
           -11.627652177650415,
           -11.63727786720446,
           -11.646903556758506,
           -11.656529246312552,
           -11.666154935866599,
           -11.675780625420643,
           -11.685406314974689,
           -11.695032004528736,
           -11.704657694082782,
           -11.714283383636827,
           -11.723909073190875,
           -11.73353476274492,
           -11.743160452298964,
           -11.752786141853012,
           -11.762411831407057,
           -11.772037520961103,
           -11.781663210515148,
           -11.791288900069194,
           -11.80091458962324,
           -11.810540279177285,
           -11.820165968731331,
           -11.829192584475738,
           -11.835223831171962,
           -11.841255077868183,
           -11.847286324564408,
           -11.85331757126063,
           -11.859348817956853,
           -11.865380064653076,
           -11.871411311349299,
           -11.877442558045521,
           -11.883473804741744,
           -11.889505051437965,
           -11.895536298134187,
           -11.90156754483041,
           -11.907598791526633,
           -11.913630038222855,
           -11.919661284919076,
           -11.9256925316153,
           -11.931723778311524,
           -11.937755025007746,
           -11.943786271703969,
           -11.94981751840019,
           -11.955848765096412,
           -11.961880011792637,
           -11.967911258488858,
           -11.97394250518508,
           -11.979973751881303,
           -11.986004998577526,
           -11.992036245273749,
           -11.99806749196997,
           -12.004098738666194,
           -12.010129985362417,
           -12.016161232058638,
           -12.021584496569757,
           -12.018086676361278,
           -12.014588856152798,
           -12.011091035944318,
           -12.007593215735834,
           -12.004095395527356,
           -12.000597575318876,
           -11.997099755110392,
           -11.993601934901912,
           -11.990104114693434,
           -11.979638680742102,
           -11.964196379831598,
           -11.948754078921091,
           -11.933311778010587,
           -11.917869477100083,
           -11.902427176189576,
           -11.886984875279074,
           -11.871542574368565,
           -11.856100273458063,
           -11.839223363372861,
           -11.809834370234162,
           -11.780445377095468,
           -11.75105638395677,
           -11.721667390818071,
           -11.692278397679377,
           -11.66288940454068,
           -11.63350041140198,
           -11.604111418263281,
           -11.57472242512459,
           -11.545333431985888,
           -11.515944438847193,
           -11.486555445708497,
           -11.457166452569798,
           -11.4277774594311,
           -11.398388466292406,
           -11.368999473153707,
           -11.339610480015008,
           -11.310221486876316,
           -11.280832493737616,
           -11.251443500598917,
           -11.22205450746022,
           -11.192665514321526,
           -11.163276521182826,
           -11.133887528044129,
           -11.104498534905435,
           -11.075109541766736,
           -11.045720548628038,
           -11.016331555489344,
           -10.986942562350647,
           -10.957553569211946,
           -10.928164576073248,
           -10.898775582934555
          ],
          [
           -6.952333727941621,
           -6.96246379829169,
           -6.972593868641759,
           -6.982723938991829,
           -6.992854009341899,
           -7.002984079691968,
           -7.013114150042037,
           -7.023244220392108,
           -7.033374290742176,
           -7.043504361092246,
           -7.053634431442316,
           -7.0637645017923845,
           -7.073894572142455,
           -7.084024642492524,
           -7.094154712842594,
           -7.104284783192663,
           -7.1144148535427325,
           -7.1245449238928025,
           -7.1346749942428715,
           -7.144805064592942,
           -7.1549351349430115,
           -7.1650652052930806,
           -7.17519527564315,
           -7.185325345993219,
           -7.19545541634329,
           -7.205585486693359,
           -7.215715557043428,
           -7.225845627393498,
           -7.235975697743566,
           -7.246105768093637,
           -7.256235838443706,
           -7.266365908793775,
           -7.276495979143844,
           -7.286626049493915,
           -7.296756119843984,
           -7.306886190194054,
           -7.317016260544124,
           -7.327146330894193,
           -7.337276401244262,
           -7.347406471594331,
           -7.3575365419444,
           -7.36766661229447,
           -7.37779668264454,
           -7.387926752994609,
           -7.398056823344678,
           -7.408186893694749,
           -7.418316964044818,
           -7.428447034394887,
           -7.438577104744957,
           -7.448707175095026,
           -7.458837245445096,
           -7.468967315795166,
           -7.479097386145235,
           -7.489227456495304,
           -7.499357526845374,
           -7.509487597195443,
           -7.519617667545513,
           -7.529747737895582,
           -7.539877808245652,
           -7.550007878595721,
           -7.560137948945791,
           -7.5702680192958605,
           -7.58039808964593,
           -7.5905281599959995,
           -7.600658230346069,
           -7.610788300696139,
           -7.620918371046208,
           -7.631048441396278,
           -7.6411785117463475,
           -7.651308582096417,
           -7.661438652446487,
           -7.671568722796556,
           -7.684175005884059,
           -7.697276533411996,
           -7.7103780609399335,
           -7.723479588467871,
           -7.736581115995807,
           -7.7496826435237445,
           -7.762784171051681,
           -7.775885698579619,
           -7.788987226107556,
           -7.802088753635492,
           -7.815190281163429,
           -7.828291808691366,
           -7.837349740469966,
           -7.845598953098698,
           -7.8538481657274275,
           -7.862097378356159,
           -7.870346590984891,
           -7.8785958036136226,
           -7.886845016242354,
           -7.895094228871086,
           -7.903343441499818,
           -7.911592654128549,
           -7.919841866757281,
           -7.928091079386011,
           -7.936340292014744,
           -7.944589504643474,
           -7.952838717272208,
           -7.961087929900938,
           -7.969337142529669,
           -7.977586355158401,
           -7.985835567787133,
           -7.994084780415864,
           -8.002333993044596,
           -8.010583205673328,
           -8.01883241830206,
           -8.02708163093079,
           -8.035330843559521,
           -8.043580056188253,
           -8.051829268816984,
           -8.060078481445716,
           -8.068327694074448,
           -8.07657690670318,
           -8.084826119331911,
           -8.093075331960643,
           -8.101324544589374,
           -8.109573757218104,
           -8.117822969846838,
           -8.126072182475568,
           -8.134321395104301,
           -8.142570607733031,
           -8.150819820361763,
           -8.159069032990496,
           -8.167318245619226,
           -8.175567458247958,
           -8.18381667087669,
           -8.192065883505421,
           -8.200315096134153,
           -8.208564308762885,
           -8.216813521391614,
           -8.225062734020346,
           -8.233311946649078,
           -8.24156115927781,
           -8.249810371906541,
           -8.258059584535273,
           -8.266308797164005,
           -8.274558009792736,
           -8.282807222421468,
           -8.2910564350502,
           -8.29930564767893,
           -8.307554860307661,
           -8.315804072936395,
           -8.324053285565126,
           -8.332302498193858,
           -8.340551710822588,
           -8.34880092345132,
           -8.357050136080051,
           -8.365299348708783,
           -8.373548561337515,
           -8.381797773966246,
           -8.390046986594978,
           -8.39829619922371,
           -8.406545411852441,
           -8.414794624481173,
           -8.424896151700604,
           -8.435923838427899,
           -8.44695152515519,
           -8.457979211882481,
           -8.469006898609775,
           -8.480034585337068,
           -8.49106227206436,
           -8.502089958791652,
           -8.513117645518944,
           -8.524145332246238,
           -8.53517301897353,
           -8.546200705700823,
           -8.55699617290329,
           -8.567675530343342,
           -8.578354887783396,
           -8.589034245223448,
           -8.599713602663503,
           -8.610392960103557,
           -8.62107231754361,
           -8.631751674983665,
           -8.642431032423717,
           -8.653110389863771,
           -8.663789747303825,
           -8.67446910474388,
           -8.685148462183932,
           -8.695827819623986,
           -8.70650717706404,
           -8.717186534504094,
           -8.727865891944148,
           -8.7385452493842,
           -8.749224606824255,
           -8.759903964264307,
           -8.770152718826616,
           -8.778894364666753,
           -8.787636010506889,
           -8.796377656347026,
           -8.805119302187162,
           -8.8138609480273,
           -8.822602593867437,
           -8.831344239707573,
           -8.840085885547708,
           -8.848827531387844,
           -8.857569177227981,
           -8.866310823068117,
           -8.875052468908255,
           -8.88379411474839,
           -8.892535760588528,
           -8.901277406428663,
           -8.910019052268801,
           -8.918760698108937,
           -8.927502343949072,
           -8.93624398978921,
           -8.944985635629346,
           -8.953727281469481,
           -8.962468927309619,
           -8.971210573149754,
           -8.979952218989892,
           -8.98869386483003,
           -8.997435510670165,
           -9.0061771565103,
           -9.014918802350437,
           -9.023660448190574,
           -9.032402094030711,
           -9.041143739870847,
           -9.049885385710983,
           -9.05862703155112,
           -9.067368677391256,
           -9.076110323231394,
           -9.08485196907153,
           -9.093593614911665,
           -9.102335260751802,
           -9.11107690659194,
           -9.119818552432076,
           -9.128560198272211,
           -9.137301844112347,
           -9.146043489952486,
           -9.154785135792622,
           -9.163526781632758,
           -9.172268427472893,
           -9.181010073313029,
           -9.189751719153167,
           -9.198493364993304,
           -9.20723501083344,
           -9.215976656673575,
           -9.224718302513711,
           -9.23345994835385,
           -9.242201594193986,
           -9.250943240034122,
           -9.25968488587426,
           -9.268426531714395,
           -9.27716817755453,
           -9.285909823394668,
           -9.294651469234804,
           -9.30339311507494,
           -9.312134760915077,
           -9.32285750454631,
           -9.335561345968642,
           -9.348265187390975,
           -9.360969028813305,
           -9.373672870235637,
           -9.38637671165797,
           -9.399080553080301,
           -9.411784394502632,
           -9.424488235924965,
           -9.437192077347294,
           -9.449895918769627,
           -9.46259976019196,
           -9.475303601614293,
           -9.488007443036622,
           -9.500711284458955,
           -9.513415125881286,
           -9.526118967303617,
           -9.53882280872595,
           -9.551526650148281,
           -9.564230491570614,
           -9.576934332992945,
           -9.589638174415278,
           -9.602342015837609,
           -9.61504585725994,
           -9.627749698682273,
           -9.640453540104605,
           -9.653157381526935,
           -9.665861222949268,
           -9.678565064371599,
           -9.69126890579393,
           -9.703972747216262,
           -9.716676588638595,
           -9.729380430060925,
           -9.742084271483257,
           -9.75478811290559,
           -9.767491954327921,
           -9.780195795750252,
           -9.792899637172585,
           -9.805603478594916,
           -9.818307320017245,
           -9.831011161439578,
           -9.84371500286191,
           -9.856418844284242,
           -9.869122685706575,
           -9.881826527128906,
           -9.894530368551235,
           -9.907234209973568,
           -9.9199380513959,
           -9.932641892818232,
           -9.945345734240563,
           -9.958049575662894,
           -9.970753417085227,
           -9.983457258507558,
           -9.99616109992989,
           -10.008864941352224,
           -10.021568782774553,
           -10.034272624196886,
           -10.046976465619217,
           -10.05968030704155,
           -10.072384148463879,
           -10.085087989886212,
           -10.097791831308545,
           -10.110495672730874,
           -10.123199514153207,
           -10.135903355575538,
           -10.14649674724806,
           -10.156898282407976,
           -10.167299817567892,
           -10.177701352727807,
           -10.188102887887723,
           -10.19850442304764,
           -10.208905958207556,
           -10.21930749336747,
           -10.229709028527385,
           -10.240110563687303,
           -10.250512098847217,
           -10.260913634007132,
           -10.271315169167048,
           -10.281716704326964,
           -10.29211823948688,
           -10.302519774646797,
           -10.312921309806711,
           -10.323322844966626,
           -10.333492510299418,
           -10.343198435977957,
           -10.352904361656496,
           -10.362610287335034,
           -10.372316213013573,
           -10.382022138692111,
           -10.391728064370653,
           -10.40143399004919,
           -10.411139915727729,
           -10.420845841406267,
           -10.430551767084808,
           -10.440257692763346,
           -10.449963618441885,
           -10.459669544120423,
           -10.469375469798964,
           -10.479081395477502,
           -10.48878732115604,
           -10.49849324683458,
           -10.50819917251312,
           -10.517905098191658,
           -10.527611023870199,
           -10.537316949548735,
           -10.547022875227274,
           -10.556728800905814,
           -10.566434726584353,
           -10.576140652262891,
           -10.58584657794143,
           -10.595552503619968,
           -10.605221654530576,
           -10.614847344084623,
           -10.624473033638667,
           -10.634098723192713,
           -10.643724412746758,
           -10.653350102300804,
           -10.662975791854851,
           -10.672601481408897,
           -10.68222717096294,
           -10.69185286051699,
           -10.701478550071034,
           -10.71110423962508,
           -10.720729929179125,
           -10.730355618733173,
           -10.739981308287218,
           -10.749606997841266,
           -10.75923268739531,
           -10.768858376949353,
           -10.778484066503403,
           -10.788109756057446,
           -10.797735445611494,
           -10.80736113516554,
           -10.816986824719585,
           -10.82661251427363,
           -10.836238203827676,
           -10.845863893381722,
           -10.855489582935768,
           -10.865115272489815,
           -10.87474096204386,
           -10.884366651597905,
           -10.893992341151952,
           -10.903618030705998,
           -10.913243720260043,
           -10.922869409814089,
           -10.932495099368136,
           -10.942120788922182,
           -10.951746478476226,
           -10.961372168030273,
           -10.970997857584319,
           -10.980623547138364,
           -10.99024923669241,
           -10.999874926246456,
           -11.009500615800501,
           -11.019126305354547,
           -11.028751994908594,
           -11.03837768446264,
           -11.048003374016684,
           -11.05762906357073,
           -11.067254753124777,
           -11.07688044267882,
           -11.086506132232868,
           -11.096131821786916,
           -11.105757511340961,
           -11.115383200895007,
           -11.125008890449053,
           -11.13403550619346,
           -11.140066752889682,
           -11.146097999585905,
           -11.15212924628213,
           -11.15816049297835,
           -11.164191739674573,
           -11.170222986370796,
           -11.176254233067018,
           -11.182285479763243,
           -11.188316726459464,
           -11.194347973155685,
           -11.200379219851909,
           -11.20641046654813,
           -11.212441713244353,
           -11.218472959940575,
           -11.2245042066368,
           -11.23053545333302,
           -11.236566700029243,
           -11.234135929700024,
           -11.230638109491544,
           -11.227140289283064,
           -11.223642469074582,
           -11.220144648866103,
           -11.216646828657623,
           -11.21314900844914,
           -11.20965118824066,
           -11.206153368032178,
           -11.2026555478237,
           -11.199157727615216,
           -11.195659907406736,
           -11.192162087198257,
           -11.188664266989775,
           -11.185166446781295,
           -11.181668626572815,
           -11.178170806364335,
           -11.174672986155853,
           -11.171175165947371,
           -11.167677345738891,
           -11.164179525530411,
           -11.160681705321931,
           -11.157183885113449,
           -11.153686064904969,
           -11.143220630953639,
           -11.127778330043135,
           -11.112336029132631,
           -11.096893728222124,
           -11.081451427311622,
           -11.066009126401115,
           -11.050566825490609,
           -11.035124524580104,
           -11.019682223669601,
           -11.004239922759094,
           -10.988797621848589,
           -10.973355320938087,
           -10.957913020027581,
           -10.942470719117074,
           -10.927028418206572,
           -10.911586117296066,
           -10.896143816385559,
           -10.880701515475053,
           -10.865259214564551,
           -10.849816913654044,
           -10.834374612743536,
           -10.818932311833034,
           -10.80349001092253,
           -10.788047710012023,
           -10.768719231802928,
           -10.739330238664229,
           -10.70994124552553,
           -10.680552252386837,
           -10.651163259248138,
           -10.621774266109439,
           -10.592385272970741,
           -10.562996279832047,
           -10.533607286693348,
           -10.50421829355465,
           -10.474829300415955,
           -10.445440307277257,
           -10.416051314138558,
           -10.386662320999866,
           -10.357273327861165,
           -10.32788433472247,
           -10.29849534158377,
           -10.269106348445074
          ],
          [
           -6.474933148283943,
           -6.4850632186340125,
           -6.4951932889840815,
           -6.5053233593341515,
           -6.5154534296842215,
           -6.5255835000342906,
           -6.53571357038436,
           -6.54584364073443,
           -6.5559737110844996,
           -6.5661037814345695,
           -6.576233851784639,
           -6.586363922134708,
           -6.596493992484777,
           -6.606624062834847,
           -6.616754133184917,
           -6.626884203534987,
           -6.637014273885055,
           -6.647144344235125,
           -6.657274414585194,
           -6.667404484935265,
           -6.677534555285334,
           -6.687664625635403,
           -6.697794695985472,
           -6.707924766335542,
           -6.718054836685612,
           -6.728184907035681,
           -6.738314977385751,
           -6.748445047735819,
           -6.75857511808589,
           -6.768705188435959,
           -6.778835258786028,
           -6.788965329136098,
           -6.799095399486166,
           -6.809225469836237,
           -6.819355540186306,
           -6.829485610536376,
           -6.839615680886446,
           -6.849745751236514,
           -6.859875821586584,
           -6.870005891936653,
           -6.880135962286723,
           -6.890266032636793,
           -6.900396102986862,
           -6.910526173336931,
           -6.9206562436870005,
           -6.930786314037071,
           -6.94091638438714,
           -6.9510464547372095,
           -6.961176525087279,
           -6.9713065954373485,
           -6.9814366657874185,
           -6.9915667361374885,
           -7.0016968064875575,
           -7.011826876837626,
           -7.021956947187697,
           -7.032087017537766,
           -7.042217087887836,
           -7.052347158237905,
           -7.062477228587975,
           -7.072607298938044,
           -7.082737369288113,
           -7.092867439638183,
           -7.102997509988253,
           -7.113127580338322,
           -7.123257650688391,
           -7.133387721038462,
           -7.14351779138853,
           -7.153647861738599,
           -7.16377793208867,
           -7.173908002438739,
           -7.184038072788809,
           -7.194168143138878,
           -7.204298213488947,
           -7.214428283839017,
           -7.224558354189086,
           -7.234688424539156,
           -7.244818494889225,
           -7.254948565239294,
           -7.265078635589364,
           -7.2741712424476574,
           -7.281188928819834,
           -7.288206615192009,
           -7.295224301564186,
           -7.3022419879363625,
           -7.310285946189001,
           -7.318535158817733,
           -7.326784371446465,
           -7.3350335840751955,
           -7.343282796703927,
           -7.351532009332659,
           -7.35978122196139,
           -7.368030434590121,
           -7.376279647218853,
           -7.384528859847585,
           -7.392778072476316,
           -7.401027285105048,
           -7.409276497733781,
           -7.417525710362511,
           -7.425774922991243,
           -7.434024135619975,
           -7.4422733482487065,
           -7.450522560877437,
           -7.458771773506169,
           -7.467020986134901,
           -7.475270198763631,
           -7.483519411392363,
           -7.491768624021095,
           -7.5000178366498265,
           -7.508267049278558,
           -7.51651626190729,
           -7.5247654745360215,
           -7.533014687164753,
           -7.541263899793484,
           -7.549513112422216,
           -7.557762325050948,
           -7.566011537679678,
           -7.57426075030841,
           -7.5825099629371415,
           -7.590759175565873,
           -7.599008388194605,
           -7.607257600823337,
           -7.615506813452068,
           -7.623756026080799,
           -7.632005238709532,
           -7.640254451338262,
           -7.648503663966994,
           -7.656752876595726,
           -7.665002089224457,
           -7.673251301853188,
           -7.68150051448192,
           -7.689749727110652,
           -7.697998939739383,
           -7.706248152368115,
           -7.714497364996846,
           -7.722746577625578,
           -7.73099579025431,
           -7.739245002883041,
           -7.7474942155117725,
           -7.755743428140503,
           -7.763992640769235,
           -7.772241853397967,
           -7.780491066026698,
           -7.78874027865543,
           -7.796989491284162,
           -7.805238703912893,
           -7.813487916541625,
           -7.821737129170356,
           -7.829986341799088,
           -7.838235554427818,
           -7.84648476705655,
           -7.854733979685282,
           -7.862983192314014,
           -7.871232404942746,
           -7.879481617571477,
           -7.8877308302002085,
           -7.89598004282894,
           -7.904229255457671,
           -7.912478468086403,
           -7.920727680715134,
           -7.928976893343865,
           -7.937226105972598,
           -7.945475318601329,
           -7.953254961858869,
           -7.9586867700237205,
           -7.964118578188573,
           -7.969550386353424,
           -7.974982194518276,
           -7.982100615230786,
           -7.990062342217126,
           -7.998024069203467,
           -8.005985796189806,
           -8.013947523176148,
           -8.021909250162489,
           -8.029870977148828,
           -8.037832704135168,
           -8.045794431121509,
           -8.053756158107849,
           -8.06171788509419,
           -8.06967961208053,
           -8.07764133906687,
           -8.08560306605321,
           -8.093564793039551,
           -8.10152652002589,
           -8.10948824701223,
           -8.117774938107221,
           -8.126516583947357,
           -8.135258229787492,
           -8.14399987562763,
           -8.152741521467766,
           -8.161483167307903,
           -8.17022481314804,
           -8.178966458988175,
           -8.18770810482831,
           -8.196449750668448,
           -8.205191396508585,
           -8.213933042348723,
           -8.222674688188858,
           -8.231416334028994,
           -8.24015797986913,
           -8.248899625709267,
           -8.257641271549405,
           -8.26638291738954,
           -8.275124563229676,
           -8.283866209069814,
           -8.29260785490995,
           -8.301349500750085,
           -8.310091146590223,
           -8.318832792430358,
           -8.327574438270494,
           -8.336316084110631,
           -8.345057729950767,
           -8.353799375790905,
           -8.362541021631042,
           -8.371282667471178,
           -8.380024313311313,
           -8.38876595915145,
           -8.397507604991587,
           -8.406249250831722,
           -8.41499089667186,
           -8.423732542511996,
           -8.432474188352133,
           -8.441215834192269,
           -8.449957480032406,
           -8.458699125872542,
           -8.46744077171268,
           -8.476182417552815,
           -8.484924063392953,
           -8.493665709233088,
           -8.502407355073224,
           -8.511149000913361,
           -8.519890646753497,
           -8.528632292593633,
           -8.53737393843377,
           -8.546115584273906,
           -8.554857230114044,
           -8.56359887595418,
           -8.572340521794317,
           -8.581082167634452,
           -8.58982381347459,
           -8.598565459314724,
           -8.607307105154861,
           -8.616048750994999,
           -8.624790396835134,
           -8.633532042675272,
           -8.642273688515408,
           -8.651015334355543,
           -8.65975698019568,
           -8.668498626035817,
           -8.677240271875954,
           -8.68598191771609,
           -8.696704661347324,
           -8.709408502769657,
           -8.722112344191988,
           -8.734816185614319,
           -8.74752002703665,
           -8.760223868458983,
           -8.772927709881314,
           -8.785631551303647,
           -8.798335392725978,
           -8.811039234148309,
           -8.823743075570642,
           -8.836446916992974,
           -8.849150758415306,
           -8.861854599837637,
           -8.874558441259968,
           -8.8872622826823,
           -8.899966124104632,
           -8.912669965526963,
           -8.925373806949294,
           -8.938077648371626,
           -8.950781489793957,
           -8.96348533121629,
           -8.97618917263862,
           -8.988893014060952,
           -9.001596855483285,
           -9.014300696905618,
           -9.02700453832795,
           -9.03970837975028,
           -9.052412221172611,
           -9.065116062594944,
           -9.077819904017275,
           -9.090523745439606,
           -9.103227586861937,
           -9.114684342654758,
           -9.125085877814676,
           -9.13548741297459,
           -9.145888948134509,
           -9.156290483294423,
           -9.16669201845434,
           -9.177093553614252,
           -9.18749508877417,
           -9.197896623934085,
           -9.208298159094001,
           -9.218699694253917,
           -9.229101229413834,
           -9.239502764573746,
           -9.249904299733664,
           -9.260305834893582,
           -9.270707370053497,
           -9.281108905213411,
           -9.291510440373326,
           -9.301911975533244,
           -9.312313510693158,
           -9.322715045853077,
           -9.333116581012991,
           -9.343518116172906,
           -9.353919651332824,
           -9.364321186492738,
           -9.374722721652653,
           -9.385124256812569,
           -9.395525791972485,
           -9.4059273271324,
           -9.416328862292316,
           -9.426730397452232,
           -9.437131932612147,
           -9.447533467772063,
           -9.457935002931979,
           -9.468336538091895,
           -9.478738073251812,
           -9.489139608411726,
           -9.499541143571644,
           -9.509942678731559,
           -9.520344213891473,
           -9.53074574905139,
           -9.541147284211304,
           -9.55154881937122,
           -9.561950354531138,
           -9.572351889691053,
           -9.582753424850967,
           -9.593154960010885,
           -9.6035564951708,
           -9.613958030330714,
           -9.62435956549063,
           -9.634529230823421,
           -9.64423515650196,
           -9.653941082180499,
           -9.663647007859037,
           -9.673352933537576,
           -9.683058859216114,
           -9.692764784894655,
           -9.702470710573195,
           -9.712176636251732,
           -9.721882561930272,
           -9.73158848760881,
           -9.74129441328735,
           -9.751000338965888,
           -9.760706264644428,
           -9.770412190322967,
           -9.780118116001507,
           -9.789824041680045,
           -9.799529967358584,
           -9.809235893037123,
           -9.818941818715661,
           -9.828647744394202,
           -9.83835367007274,
           -9.848059595751279,
           -9.857765521429819,
           -9.867471447108358,
           -9.877177372786896,
           -9.886883298465435,
           -9.896589224143973,
           -9.906295149822512,
           -9.916001075501052,
           -9.92570700117959,
           -9.935412926858127,
           -9.945118852536668,
           -9.954824778215208,
           -9.964530703893747,
           -9.974236629572285,
           -9.983942555250824,
           -9.993648480929362,
           -10.003354406607901,
           -10.01306033228644,
           -10.022766257964978,
           -10.032472183643517,
           -10.042178109322055,
           -10.051884035000597,
           -10.061589960679136,
           -10.071295886357674,
           -10.081001812036213,
           -10.090707737714752,
           -10.10041366339329,
           -10.110119589071829,
           -10.119825514750369,
           -10.129531440428908,
           -10.139237366107446,
           -10.148943291785987,
           -10.158649217464525,
           -10.168355143143064,
           -10.178061068821602,
           -10.18776699450014,
           -10.197472920178681,
           -10.20717884585722,
           -10.216884771535758,
           -10.226590697214297,
           -10.236296622892837,
           -10.246002548571376,
           -10.255708474249914,
           -10.265414399928453,
           -10.275120325606991,
           -10.28482625128553,
           -10.29453217696407,
           -10.304238102642607,
           -10.313944028321147,
           -10.323649953999688,
           -10.333355879678226,
           -10.343061805356767,
           -10.352767731035303,
           -10.362471985288437,
           -10.372097674842484,
           -10.38172336439653,
           -10.391349053950576,
           -10.400974743504623,
           -10.410600433058667,
           -10.420226122612712,
           -10.42985181216676,
           -10.438878427911167,
           -10.44490967460739,
           -10.450940921303612,
           -10.450185183038755,
           -10.446687362830275,
           -10.443189542621795,
           -10.439691722413315,
           -10.436193902204833,
           -10.432696081996353,
           -10.429198261787871,
           -10.42570044157939,
           -10.422202621370909,
           -10.41870480116243,
           -10.415206980953949,
           -10.411709160745469,
           -10.408211340536987,
           -10.404713520328507,
           -10.401215700120026,
           -10.397717879911546,
           -10.394220059703065,
           -10.390722239494584,
           -10.387224419286103,
           -10.383726599077622,
           -10.380228778869144,
           -10.376730958660662,
           -10.37323313845218,
           -10.3697353182437,
           -10.36623749803522,
           -10.362739677826738,
           -10.359241857618258,
           -10.355744037409778,
           -10.352246217201298,
           -10.348748396992816,
           -10.345250576784336,
           -10.341752756575856,
           -10.338254936367374,
           -10.334757116158894,
           -10.331259295950414,
           -10.327761475741934,
           -10.324263655533452,
           -10.320765835324972,
           -10.31726801511649,
           -10.30680258116516,
           -10.291360280254656,
           -10.27591797934415,
           -10.260475678433645,
           -10.245033377523145,
           -10.229591076612635,
           -10.214148775702128,
           -10.198706474791624,
           -10.183264173881122,
           -10.167821872970617,
           -10.15237957206011,
           -10.136937271149606,
           -10.121494970239102,
           -10.106052669328594,
           -10.09061036841809,
           -10.075168067507585,
           -10.05972576659708,
           -10.044283465686576,
           -10.02884116477607,
           -10.013398863865564,
           -9.997956562955059,
           -9.982514262044557,
           -9.96707196113405,
           -9.951629660223544,
           -9.93618735931304,
           -9.920745058402535,
           -9.905302757492029,
           -9.889860456581527,
           -9.87441815567102,
           -9.858975854760514,
           -9.843533553850008,
           -9.828091252939506,
           -9.812648952028999,
           -9.797206651118493,
           -9.781764350207991,
           -9.766322049297484,
           -9.750879748386978,
           -9.735437447476475,
           -9.719995146565969,
           -9.698215100232977,
           -9.668826107094278,
           -9.639437113955584
          ],
          [
           -5.995951683348538,
           -6.006081753698607,
           -6.016211824048676,
           -6.026341894398746,
           -6.036471964748816,
           -6.046602035098886,
           -6.056732105448954,
           -6.066862175799024,
           -6.076992246149093,
           -6.087122316499164,
           -6.097252386849233,
           -6.107382457199302,
           -6.117512527549372,
           -6.127642597899442,
           -6.137772668249511,
           -6.14790273859958,
           -6.158032808949649,
           -6.168162879299719,
           -6.178292949649789,
           -6.188423019999858,
           -6.198553090349927,
           -6.208683160699997,
           -6.218813231050066,
           -6.228943301400136,
           -6.239073371750206,
           -6.249203442100275,
           -6.259333512450344,
           -6.269463582800414,
           -6.279593653150483,
           -6.289723723500553,
           -6.299853793850623,
           -6.309983864200692,
           -6.320113934550761,
           -6.330244004900831,
           -6.340374075250901,
           -6.35050414560097,
           -6.360634215951039,
           -6.3707642863011085,
           -6.380894356651179,
           -6.391024427001248,
           -6.4011544973513175,
           -6.4112845677013865,
           -6.4214146380514565,
           -6.4315447084015265,
           -6.4416747787515956,
           -6.451804849101665,
           -6.461934919451735,
           -6.472064989801804,
           -6.482195060151874,
           -6.492325130501943,
           -6.502455200852012,
           -6.512585271202083,
           -6.522715341552152,
           -6.532845411902221,
           -6.542975482252291,
           -6.553105552602361,
           -6.56323562295243,
           -6.573365693302499,
           -6.583495763652569,
           -6.593625834002638,
           -6.603755904352708,
           -6.613885974702777,
           -6.624016045052847,
           -6.631552459408649,
           -6.638570145780826,
           -6.6455878321530015,
           -6.652605518525179,
           -6.659623204897355,
           -6.666640891269531,
           -6.673658577641708,
           -6.680676264013885,
           -6.687693950386061,
           -6.694711636758237,
           -6.701729323130414,
           -6.7087470095025905,
           -6.715764695874767,
           -6.722782382246944,
           -6.729800068619119,
           -6.736817754991296,
           -6.743835441363474,
           -6.75085312773565,
           -6.757870814107826,
           -6.764888500480002,
           -6.771906186852179,
           -6.779950145104817,
           -6.788199357733549,
           -6.79644857036228,
           -6.804697782991012,
           -6.812946995619743,
           -6.821196208248474,
           -6.829445420877206,
           -6.837694633505937,
           -6.84594384613467,
           -6.854193058763402,
           -6.862442271392133,
           -6.870691484020863,
           -6.878940696649597,
           -6.887189909278327,
           -6.895439121907059,
           -6.903688334535791,
           -6.911937547164522,
           -6.920186759793253,
           -6.928435972421985,
           -6.936685185050717,
           -6.9449343976794475,
           -6.953183610308179,
           -6.961432822936911,
           -6.969682035565642,
           -6.977931248194374,
           -6.986180460823105,
           -6.994429673451837,
           -7.002678886080568,
           -7.0109280987093,
           -7.019177311338032,
           -7.0274265239667635,
           -7.035675736595495,
           -7.043924949224227,
           -7.0521741618529585,
           -7.060423374481688,
           -7.068672587110422,
           -7.076921799739152,
           -7.0851710123678835,
           -7.093420224996615,
           -7.101669437625347,
           -7.1099186502540785,
           -7.11816786288281,
           -7.126417075511542,
           -7.134666288140274,
           -7.142915500769004,
           -7.151164713397736,
           -7.159413926026467,
           -7.167663138655199,
           -7.17591235128393,
           -7.184161563912662,
           -7.1924107765413945,
           -7.200659989170125,
           -7.208909201798857,
           -7.217158414427589,
           -7.22540762705632,
           -7.233656839685051,
           -7.241906052313783,
           -7.250155264942514,
           -7.258404477571246,
           -7.266653690199978,
           -7.2749029028287095,
           -7.28315211545744,
           -7.289523056018169,
           -7.29495486418302,
           -7.300386672347872,
           -7.305818480512724,
           -7.311250288677575,
           -7.3166820968424275,
           -7.32211390500728,
           -7.327545713172131,
           -7.332977521336983,
           -7.338409329501834,
           -7.343841137666686,
           -7.349272945831538,
           -7.35470475399639,
           -7.360136562161242,
           -7.365568370326093,
           -7.371000178490945,
           -7.376431986655798,
           -7.3818637948206485,
           -7.387295602985501,
           -7.392727411150353,
           -7.398159219315204,
           -7.405277640027714,
           -7.4132393670140555,
           -7.421201094000395,
           -7.429162820986736,
           -7.437124547973076,
           -7.445086274959417,
           -7.453048001945757,
           -7.461009728932098,
           -7.468971455918437,
           -7.476933182904777,
           -7.484894909891118,
           -7.492856636877459,
           -7.500818363863798,
           -7.508780090850139,
           -7.516741817836479,
           -7.5247035448228194,
           -7.53266527180916,
           -7.540626998795501,
           -7.5485887257818405,
           -7.556550452768182,
           -7.56451217975452,
           -7.5724739067408615,
           -7.580435633727202,
           -7.588397360713542,
           -7.5963590876998826,
           -7.604320814686222,
           -7.612282541672564,
           -7.620244268658903,
           -7.628205995645244,
           -7.636167722631584,
           -7.644129449617925,
           -7.652091176604266,
           -7.660052903590605,
           -7.668014630576946,
           -7.675976357563285,
           -7.683938084549626,
           -7.691899811535966,
           -7.699861538522307,
           -7.7078232655086465,
           -7.715784992494989,
           -7.723746719481328,
           -7.731708446467668,
           -7.739670173454008,
           -7.747631900440348,
           -7.7555936274266895,
           -7.76355535441303,
           -7.771517081399369,
           -7.779478808385709,
           -7.78744053537205,
           -7.795402262358391,
           -7.8033639893447315,
           -7.811325716331071,
           -7.819287443317412,
           -7.827249170303752,
           -7.835210897290093,
           -7.843172624276432,
           -7.851134351262772,
           -7.859096078249113,
           -7.867057805235453,
           -7.875019532221795,
           -7.882981259208134,
           -7.890942986194474,
           -7.898904713180816,
           -7.906866440167155,
           -7.914828167153495,
           -7.922789894139836,
           -7.930751621126176,
           -7.9387133481125165,
           -7.946675075098857,
           -7.954636802085198,
           -7.9625985290715375,
           -7.970560256057877,
           -7.978521983044218,
           -7.986483710030559,
           -7.994445437016898,
           -8.00240716400324,
           -8.010368890989579,
           -8.01833061797592,
           -8.026292344962261,
           -8.0342540719486,
           -8.042345782836842,
           -8.051087428676977,
           -8.059829074517115,
           -8.070551818148349,
           -8.082871938061475,
           -8.09327347322139,
           -8.103675008381304,
           -8.114076543541222,
           -8.124478078701136,
           -8.134879613861052,
           -8.145281149020969,
           -8.155682684180885,
           -8.1660842193408,
           -8.176485754500714,
           -8.186887289660632,
           -8.197288824820548,
           -8.207690359980463,
           -8.218091895140379,
           -8.228493430300295,
           -8.23889496546021,
           -8.249296500620126,
           -8.25969803578004,
           -8.270099570939955,
           -8.280501106099873,
           -8.29090264125979,
           -8.301304176419704,
           -8.31170571157962,
           -8.322107246739536,
           -8.33250878189945,
           -8.342910317059365,
           -8.353311852219282,
           -8.3637133873792,
           -8.374114922539114,
           -8.38451645769903,
           -8.394917992858947,
           -8.405319528018861,
           -8.415721063178777,
           -8.426122598338694,
           -8.436524133498608,
           -8.446925668658524,
           -8.45732720381844,
           -8.467728738978355,
           -8.478130274138271,
           -8.488531809298188,
           -8.498933344458104,
           -8.509334879618017,
           -8.519736414777935,
           -8.530137949937853,
           -8.540539485097765,
           -8.550941020257682,
           -8.561342555417598,
           -8.571744090577514,
           -8.582145625737427,
           -8.592547160897345,
           -8.602948696057261,
           -8.613350231217176,
           -8.623751766377092,
           -8.634153301537008,
           -8.644554836696923,
           -8.654956371856839,
           -8.665357907016755,
           -8.67575944217667,
           -8.686160977336586,
           -8.696562512496502,
           -8.706964047656417,
           -8.717365582816333,
           -8.72776711797625,
           -8.738168653136164,
           -8.74857018829608,
           -8.758971723455996,
           -8.769373258615913,
           -8.779774793775827,
           -8.790176328935743,
           -8.80057786409566,
           -8.810979399255574,
           -8.82138093441549,
           -8.831782469575407,
           -8.842184004735321,
           -8.852585539895237,
           -8.862987075055154,
           -8.873388610215068,
           -8.883790145374984,
           -8.8941916805349,
           -8.904593215694817,
           -8.914994750854733,
           -8.925396286014648,
           -8.935565951347439,
           -8.945271877025977,
           -8.954977802704516,
           -8.964683728383054,
           -8.974389654061593,
           -8.984095579740131,
           -8.993801505418674,
           -9.003507431097212,
           -9.013213356775749,
           -9.02291928245429,
           -9.03262520813283,
           -9.042331133811368,
           -9.052037059489905,
           -9.061742985168445,
           -9.071448910846984,
           -9.081154836525522,
           -9.090860762204063,
           -9.100566687882601,
           -9.11027261356114,
           -9.119978539239678,
           -9.129684464918219,
           -9.139390390596756,
           -9.149096316275296,
           -9.158802241953834,
           -9.168508167632373,
           -9.178214093310912,
           -9.18792001898945,
           -9.197191371796064,
           -9.206288895059533,
           -9.215386418323,
           -9.224483941586469,
           -9.233581464849935,
           -9.242678988113404,
           -9.251776511376871,
           -9.26087403464034,
           -9.269971557903805,
           -9.279069081167275,
           -9.288166604430742,
           -9.29726412769421,
           -9.306361650957676,
           -9.315459174221145,
           -9.324556697484613,
           -9.33365422074808,
           -9.342751744011549,
           -9.351849267275018,
           -9.360946790538483,
           -9.370044313801952,
           -9.379141837065418,
           -9.388239360328887,
           -9.397336883592354,
           -9.406434406855823,
           -9.41553193011929,
           -9.424629453382758,
           -9.433726976646227,
           -9.442824499909692,
           -9.45192202317316,
           -9.46101954643663,
           -9.470117069700098,
           -9.479214592963565,
           -9.488312116227032,
           -9.497409639490499,
           -9.506507162753968,
           -9.515604686017436,
           -9.524702209280903,
           -9.53379973254437,
           -9.542897255807839,
           -9.551994779071308,
           -9.561092302334774,
           -9.570189825598241,
           -9.57928734886171,
           -9.588384872125177,
           -9.597482395388644,
           -9.606579918652113,
           -9.615677441915581,
           -9.62477496517905,
           -9.633872488442515,
           -9.642970011705984,
           -9.65206753496945,
           -9.66116505823292,
           -9.670262581496386,
           -9.679360104759853,
           -9.688457628023322,
           -9.69755515128679,
           -9.703916694965628,
           -9.696598340721325,
           -9.68927998647702,
           -9.681961632232715,
           -9.67464327798841,
           -9.667324923744108,
           -9.660006569499803,
           -9.652688215255498,
           -9.645369861011195,
           -9.63805150676689,
           -9.630733152522588,
           -9.623414798278283,
           -9.616096444033978,
           -9.610313669940265,
           -9.606855018966993,
           -9.603396367993719,
           -9.599937717020447,
           -9.596479066047177,
           -9.593020415073903,
           -9.589561764100631,
           -9.58610311312736,
           -9.58264446215409,
           -9.579185811180816,
           -9.575727160207544,
           -9.57226850923427,
           -9.568809858260998,
           -9.565351207287726,
           -9.561892556314454,
           -9.558433905341182,
           -9.55497525436791,
           -9.551516603394637,
           -9.548057952421367,
           -9.544599301448095,
           -9.541140650474821,
           -9.53768199950155,
           -9.534223348528277,
           -9.530764697555004,
           -9.527306046581732,
           -9.52384739560846,
           -9.520388744635188,
           -9.516930093661916,
           -9.513471442688644,
           -9.502999480531447,
           -9.487518010385735,
           -9.472036540240019,
           -9.456555070094305,
           -9.441073599948595,
           -9.42559212980288,
           -9.410110659657164,
           -9.394629189511452,
           -9.37914771936574,
           -9.363666249220024,
           -9.34818477907431,
           -9.332703308928599,
           -9.317221838782883,
           -9.30174036863717,
           -9.286258898491457,
           -9.270777428345744,
           -9.25529595820003,
           -9.239814488054314,
           -9.224333017908604,
           -9.20885154776289,
           -9.193370077617175,
           -9.177888607471463,
           -9.162407137325749,
           -9.146925667180033,
           -9.131444197034321,
           -9.11596272688861,
           -9.100481256742892,
           -9.084999786597184,
           -9.069518316451466,
           -9.055736661939694,
           -9.042466140263404,
           -9.029195618587112,
           -9.01592509691082,
           -9.002654575234526,
           -8.989384053558236,
           -8.976113531881944,
           -8.962843010205649,
           -8.94957248852936,
           -8.936301966853069,
           -8.923031445176775,
           -8.909760923500482,
           -8.896490401824192
          ],
          [
           -5.516970218413122,
           -5.527100288763192,
           -5.537230359113261,
           -5.547360429463331,
           -5.5574904998134,
           -5.56762057016347,
           -5.577750640513539,
           -5.587880710863608,
           -5.598010781213678,
           -5.608140851563748,
           -5.618270921913817,
           -5.628400992263886,
           -5.638531062613956,
           -5.648661132964026,
           -5.658791203314095,
           -5.668921273664165,
           -5.679051344014233,
           -5.689181414364303,
           -5.699311484714373,
           -5.709441555064443,
           -5.719571625414512,
           -5.729701695764581,
           -5.739831766114651,
           -5.7499618364647205,
           -5.76009190681479,
           -5.7702219771648595,
           -5.7803520475149295,
           -5.790482117864999,
           -5.8006121882150685,
           -5.810742258565138,
           -5.820872328915207,
           -5.831002399265277,
           -5.841132469615346,
           -5.851262539965417,
           -5.861392610315486,
           -5.871522680665555,
           -5.881652751015625,
           -5.891782821365694,
           -5.901912891715764,
           -5.912042962065833,
           -5.922173032415902,
           -5.932303102765971,
           -5.942433173116041,
           -5.952563243466111,
           -5.96269331381618,
           -5.97282338416625,
           -5.9819159899974546,
           -5.988933676369631,
           -5.995951362741808,
           -6.002969049113984,
           -6.0099867354861605,
           -6.017004421858337,
           -6.024022108230514,
           -6.03103979460269,
           -6.038057480974867,
           -6.0450751673470435,
           -6.052092853719219,
           -6.059110540091396,
           -6.066128226463572,
           -6.073145912835749,
           -6.080163599207925,
           -6.087181285580102,
           -6.094198971952278,
           -6.101216658324455,
           -6.108234344696632,
           -6.115252031068808,
           -6.122269717440984,
           -6.12928740381316,
           -6.1363050901853375,
           -6.143322776557514,
           -6.150340462929689,
           -6.157358149301866,
           -6.164375835674043,
           -6.17139352204622,
           -6.178411208418396,
           -6.185428894790573,
           -6.192446581162749,
           -6.199464267534926,
           -6.206481953907103,
           -6.213499640279279,
           -6.220517326651455,
           -6.2275350130236315,
           -6.234552699395808,
           -6.241570385767985,
           -6.249614344020623,
           -6.257863556649355,
           -6.266112769278086,
           -6.274361981906818,
           -6.28261119453555,
           -6.290860407164281,
           -6.299109619793013,
           -6.307358832421743,
           -6.3156080450504755,
           -6.323857257679208,
           -6.332106470307939,
           -6.34035568293667,
           -6.348604895565402,
           -6.356854108194133,
           -6.365103320822866,
           -6.373352533451596,
           -6.381601746080328,
           -6.38985095870906,
           -6.398100171337791,
           -6.406349383966523,
           -6.414598596595255,
           -6.422847809223985,
           -6.431097021852718,
           -6.439346234481448,
           -6.44759544711018,
           -6.455844659738911,
           -6.464093872367643,
           -6.472343084996375,
           -6.4805922976251065,
           -6.488841510253838,
           -6.49709072288257,
           -6.5053399355113015,
           -6.513589148140032,
           -6.521838360768763,
           -6.530087573397496,
           -6.5383367860262265,
           -6.546585998654959,
           -6.55483521128369,
           -6.563084423912421,
           -6.571333636541153,
           -6.579582849169884,
           -6.587832061798617,
           -6.596081274427348,
           -6.60433048705608,
           -6.612579699684812,
           -6.620359342012606,
           -6.625791150177458,
           -6.63122295834231,
           -6.636654766507162,
           -6.642086574672013,
           -6.647518382836865,
           -6.652950191001716,
           -6.6583819991665685,
           -6.663813807331421,
           -6.669245615496273,
           -6.674677423661125,
           -6.680109231825975,
           -6.685541039990828,
           -6.690972848155679,
           -6.696404656320531,
           -6.701836464485384,
           -6.707268272650234,
           -6.712700080815086,
           -6.718131888979938,
           -6.72356369714479,
           -6.7289955053096415,
           -6.734427313474493,
           -6.739859121639345,
           -6.745290929804197,
           -6.750722737969048,
           -6.7561545461339,
           -6.7615863542987515,
           -6.7670181624636045,
           -6.772449970628455,
           -6.777881778793308,
           -6.783313586958159,
           -6.788745395123012,
           -6.7941772032878625,
           -6.7996090114527155,
           -6.805040819617567,
           -6.810472627782418,
           -6.81590443594727,
           -6.821336244112122,
           -6.8284546648246325,
           -6.836416391810973,
           -6.844378118797312,
           -6.8523398457836535,
           -6.860301572769994,
           -6.868263299756334,
           -6.876225026742674,
           -6.884186753729015,
           -6.892148480715355,
           -6.900110207701696,
           -6.908071934688036,
           -6.916033661674376,
           -6.923995388660716,
           -6.931957115647057,
           -6.939918842633396,
           -6.947880569619737,
           -6.955842296606077,
           -6.963804023592418,
           -6.971765750578758,
           -6.979727477565098,
           -6.9876892045514385,
           -6.995650931537779,
           -7.003612658524119,
           -7.01157438551046,
           -7.019536112496801,
           -7.02749783948314,
           -7.035459566469481,
           -7.043421293455821,
           -7.051383020442161,
           -7.059344747428501,
           -7.067306474414842,
           -7.075268201401183,
           -7.083229928387523,
           -7.091191655373863,
           -7.099153382360202,
           -7.107115109346544,
           -7.115076836332884,
           -7.123038563319224,
           -7.131000290305565,
           -7.138962017291905,
           -7.146923744278245,
           -7.154885471264585,
           -7.162847198250926,
           -7.170808925237266,
           -7.178770652223607,
           -7.186732379209948,
           -7.1946941061962875,
           -7.202655833182627,
           -7.210617560168968,
           -7.218579287155308,
           -7.226541014141649,
           -7.234502741127989,
           -7.2424644681143295,
           -7.25042619510067,
           -7.25838792208701,
           -7.26634964907335,
           -7.27431137605969,
           -7.282273103046031,
           -7.290234830032372,
           -7.298196557018711,
           -7.306158284005052,
           -7.314120010991392,
           -7.3199609561333006,
           -7.325519134143399,
           -7.331077312153499,
           -7.336635490163599,
           -7.342193668173698,
           -7.347751846183797,
           -7.353310024193895,
           -7.358868202203995,
           -7.364426380214095,
           -7.369984558224193,
           -7.3755427362342925,
           -7.381100914244391,
           -7.38665909225449,
           -7.392217270264589,
           -7.397775448274689,
           -7.4033336262847875,
           -7.408891804294887,
           -7.414449982304986,
           -7.420008160315086,
           -7.425566338325185,
           -7.431124516335284,
           -7.43767068317219,
           -7.445204838835904,
           -7.452738994499617,
           -7.460273150163331,
           -7.467807305827044,
           -7.475341461490758,
           -7.482875617154471,
           -7.490409772818184,
           -7.4979439284819,
           -7.5054780841456115,
           -7.513012239809325,
           -7.520546395473039,
           -7.528080551136752,
           -7.535614706800466,
           -7.54314886246418,
           -7.550683018127892,
           -7.558217173791607,
           -7.5657513294553205,
           -7.573285485119032,
           -7.580819640782746,
           -7.588353796446461,
           -7.595887952110174,
           -7.603422107773887,
           -7.6109562634376005,
           -7.620177912750172,
           -7.630594081546205,
           -7.641010250342237,
           -7.65142641913827,
           -7.661842587934302,
           -7.672258756730335,
           -7.682674925526367,
           -7.6930910943224,
           -7.70350726311843,
           -7.713923431914464,
           -7.724339600710497,
           -7.7347557695065285,
           -7.745171938302561,
           -7.755588107098594,
           -7.766004275894626,
           -7.776420444690658,
           -7.786836613486691,
           -7.7972527822827224,
           -7.807668951078756,
           -7.818085119874788,
           -7.828501288670821,
           -7.838917457466852,
           -7.849333626262886,
           -7.859749795058919,
           -7.870165963854951,
           -7.880582132650982,
           -7.8909983014470155,
           -7.901414470243048,
           -7.9118306390390805,
           -7.922246807835112,
           -7.9326629766311445,
           -7.943079145427177,
           -7.953495314223209,
           -7.963911483019243,
           -7.974327651815274,
           -7.984743820611307,
           -7.995159989407339,
           -8.005576158203372,
           -8.015992326999404,
           -8.026408495795437,
           -8.03682466459147,
           -8.047240833387502,
           -8.057657002183532,
           -8.068073170979567,
           -8.078489339775597,
           -8.088905508571631,
           -8.099321677367664,
           -8.109737846163695,
           -8.120154014959727,
           -8.130570183755761,
           -8.140986352551792,
           -8.151402521347825,
           -8.161818690143857,
           -8.172234858939891,
           -8.182651027735922,
           -8.193067196531954,
           -8.203483365327989,
           -8.21389953412402,
           -8.224315702920052,
           -8.234046896642676,
           -8.242408140218483,
           -8.25076938379429,
           -8.259130627370098,
           -8.267491870945905,
           -8.275853114521714,
           -8.284214358097522,
           -8.29257560167333,
           -8.300936845249137,
           -8.309298088824944,
           -8.317659332400751,
           -8.326020575976559,
           -8.334381819552366,
           -8.342743063128175,
           -8.351104306703983,
           -8.359465550279788,
           -8.367826793855597,
           -8.376188037431405,
           -8.384549281007212,
           -8.39291052458302,
           -8.401271768158828,
           -8.409633011734636,
           -8.417994255310443,
           -8.42635549888625,
           -8.43471674246206,
           -8.443077986037865,
           -8.451439229613673,
           -8.45980047318948,
           -8.46816171676529,
           -8.476522960341097,
           -8.484884203916904,
           -8.49338805992728,
           -8.502485583190749,
           -8.511583106454216,
           -8.520680629717685,
           -8.529778152981152,
           -8.53887567624462,
           -8.547973199508087,
           -8.557070722771556,
           -8.566168246035023,
           -8.57526576929849,
           -8.584363292561958,
           -8.593460815825427,
           -8.602558339088894,
           -8.611655862352361,
           -8.62075338561583,
           -8.629850908879297,
           -8.638948432142765,
           -8.648045955406232,
           -8.6571434786697,
           -8.666241001933168,
           -8.675338525196636,
           -8.684436048460103,
           -8.693533571723572,
           -8.702631094987037,
           -8.711728618250508,
           -8.720826141513975,
           -8.729923664777441,
           -8.739021188040908,
           -8.748118711304379,
           -8.757216234567846,
           -8.766313757831313,
           -8.77541128109478,
           -8.784508804358246,
           -8.793606327621715,
           -8.802703850885184,
           -8.811801374148652,
           -8.820898897412118,
           -8.829996420675586,
           -8.839093943939055,
           -8.848191467202522,
           -8.857288990465989,
           -8.866386513729458,
           -8.875484036992926,
           -8.884581560256393,
           -8.893679083519862,
           -8.90277660678333,
           -8.911874130046796,
           -8.920971653310264,
           -8.930069176573733,
           -8.9391666998372,
           -8.948264223100667,
           -8.957361746364136,
           -8.963723290042973,
           -8.956404935798668,
           -8.949086581554365,
           -8.94176822731006,
           -8.934449873065756,
           -8.927131518821453,
           -8.919813164577148,
           -8.912494810332845,
           -8.90517645608854,
           -8.897858101844236,
           -8.890539747599933,
           -8.883221393355628,
           -8.875903039111323,
           -8.86858468486702,
           -8.861266330622716,
           -8.85394797637841,
           -8.846629622134108,
           -8.839311267889805,
           -8.8319929136455,
           -8.824674559401195,
           -8.817356205156893,
           -8.810037850912586,
           -8.802719496668283,
           -8.79540114242398,
           -8.788082788179675,
           -8.78076443393537,
           -8.773446079691066,
           -8.766127725446763,
           -8.759177704618626,
           -8.755719053645352,
           -8.75226040267208,
           -8.748801751698808,
           -8.745343100725535,
           -8.741884449752265,
           -8.73842579877899,
           -8.734967147805719,
           -8.731508496832447,
           -8.728049845859175,
           -8.724591194885903,
           -8.721132543912631,
           -8.717673892939358,
           -8.714215241966087,
           -8.703743279808888,
           -8.688261809663176,
           -8.672780339517463,
           -8.657298869371747,
           -8.641817399226037,
           -8.626335929080321,
           -8.610854458934607,
           -8.595372988788894,
           -8.579891518643182,
           -8.564410048497468,
           -8.548928578351752,
           -8.53344710820604,
           -8.517965638060325,
           -8.502641667406461,
           -8.489371145730171,
           -8.47610062405388,
           -8.462830102377588,
           -8.449559580701294,
           -8.436289059025004,
           -8.42301853734871,
           -8.409748015672418,
           -8.396477493996128,
           -8.383206972319837,
           -8.369936450643543,
           -8.356665928967253,
           -8.343395407290961,
           -8.330124885614667,
           -8.316854363938377,
           -8.303583842262086,
           -8.290313320585792,
           -8.2770427989095,
           -8.26377227723321,
           -8.250501755556916,
           -8.237231233880625,
           -8.223960712204335,
           -8.210690190528041,
           -8.197419668851747,
           -8.184149147175459,
           -8.170878625499165,
           -8.157608103822874,
           -8.14433758214658,
           -8.13106706047029
          ],
          [
           -5.037988753477707,
           -5.048118823827776,
           -5.058248894177845,
           -5.068378964527916,
           -5.078509034877985,
           -5.088639105228054,
           -5.098769175578124,
           -5.1088992459281934,
           -5.119029316278263,
           -5.1291593866283325,
           -5.1392894569784024,
           -5.1494195273284715,
           -5.1595495976785415,
           -5.169679668028611,
           -5.1798097383786805,
           -5.1899398087287505,
           -5.20006987907882,
           -5.210199949428889,
           -5.220330019778958,
           -5.230460090129028,
           -5.240590160479098,
           -5.250720230829167,
           -5.260850301179236,
           -5.270980371529307,
           -5.281110441879376,
           -5.291240512229445,
           -5.301370582579514,
           -5.311500652929583,
           -5.321630723279654,
           -5.331760793629723,
           -5.339297206958438,
           -5.346314893330614,
           -5.353332579702791,
           -5.360350266074967,
           -5.367367952447143,
           -5.37438563881932,
           -5.381403325191497,
           -5.388421011563673,
           -5.39543869793585,
           -5.402456384308026,
           -5.4094740706802025,
           -5.416491757052379,
           -5.423509443424555,
           -5.430527129796732,
           -5.437544816168908,
           -5.444562502541085,
           -5.451580188913261,
           -5.458597875285438,
           -5.465615561657614,
           -5.472633248029791,
           -5.479650934401967,
           -5.486668620774144,
           -5.49368630714632,
           -5.5007039935184965,
           -5.507721679890673,
           -5.514739366262849,
           -5.521757052635026,
           -5.528774739007203,
           -5.535792425379379,
           -5.542810111751555,
           -5.549827798123732,
           -5.556845484495908,
           -5.5638631708680855,
           -5.570880857240261,
           -5.577898543612438,
           -5.584916229984614,
           -5.5919339163567905,
           -5.598951602728967,
           -5.605969289101143,
           -5.61298697547332,
           -5.620004661845496,
           -5.6270223482176736,
           -5.634040034589849,
           -5.641057720962025,
           -5.648075407334202,
           -5.655093093706379,
           -5.662110780078556,
           -5.669128466450731,
           -5.676146152822908,
           -5.6831638391950845,
           -5.690181525567262,
           -5.697199211939437,
           -5.704216898311614,
           -5.711234584683791,
           -5.719278542936429,
           -5.727527755565161,
           -5.735776968193893,
           -5.744026180822624,
           -5.752275393451356,
           -5.760524606080087,
           -5.7687738187088184,
           -5.77702303133755,
           -5.785272243966281,
           -5.7935214565950135,
           -5.801770669223745,
           -5.810019881852476,
           -5.818269094481208,
           -5.826518307109939,
           -5.834767519738671,
           -5.843016732367403,
           -5.851265944996134,
           -5.859515157624865,
           -5.867764370253598,
           -5.876013582882329,
           -5.884262795511059,
           -5.892512008139791,
           -5.900761220768523,
           -5.909010433397254,
           -5.917259646025986,
           -5.925508858654718,
           -5.9337580712834495,
           -5.942007283912181,
           -5.950256496540912,
           -5.956627436171896,
           -5.962059244336748,
           -5.967491052501599,
           -5.972922860666451,
           -5.978354668831303,
           -5.983786476996155,
           -5.989218285161006,
           -5.994650093325859,
           -6.00008190149071,
           -6.0055137096555615,
           -6.010945517820414,
           -6.016377325985266,
           -6.021809134150116,
           -6.027240942314968,
           -6.03267275047982,
           -6.038104558644672,
           -6.0435363668095246,
           -6.048968174974376,
           -6.054399983139227,
           -6.059831791304079,
           -6.065263599468931,
           -6.0706954076337825,
           -6.076127215798635,
           -6.081559023963486,
           -6.086990832128338,
           -6.09242264029319,
           -6.097854448458041,
           -6.1032862566228925,
           -6.108718064787745,
           -6.114149872952597,
           -6.119581681117448,
           -6.125013489282301,
           -6.130445297447153,
           -6.135877105612003,
           -6.1413089137768555,
           -6.146740721941708,
           -6.152172530106559,
           -6.157604338271411,
           -6.163036146436262,
           -6.168467954601114,
           -6.173899762765966,
           -6.1793315709308185,
           -6.18476337909567,
           -6.190195187260521,
           -6.195626995425374,
           -6.201058803590224,
           -6.206490611755076,
           -6.211922419919929,
           -6.21735422808478,
           -6.222786036249633,
           -6.228217844414484,
           -6.233649652579335,
           -6.239081460744187,
           -6.2445132689090395,
           -6.251631689621551,
           -6.25959341660789,
           -6.2675551435942305,
           -6.275516870580571,
           -6.283478597566911,
           -6.2914403245532515,
           -6.299402051539593,
           -6.307363778525932,
           -6.3153255055122735,
           -6.323287232498613,
           -6.331248959484954,
           -6.3392106864712945,
           -6.347172413457635,
           -6.355134140443974,
           -6.363095867430315,
           -6.371057594416655,
           -6.379019321402996,
           -6.386981048389336,
           -6.394942775375676,
           -6.402904502362016,
           -6.410866229348356,
           -6.418827956334697,
           -6.426789683321037,
           -6.434751410307378,
           -6.442713137293717,
           -6.4506748642800575,
           -6.4586365912664,
           -6.466598318252739,
           -6.4745600452390795,
           -6.48252177222542,
           -6.490483499211759,
           -6.4984452261981005,
           -6.506406953184441,
           -6.514368680170781,
           -6.522330407157121,
           -6.530292134143461,
           -6.538253861129803,
           -6.546215588116143,
           -6.554177315102483,
           -6.561644189897644,
           -6.567202367907742,
           -6.572760545917841,
           -6.578318723927941,
           -6.583876901938041,
           -6.58943507994814,
           -6.594993257958238,
           -6.600551435968337,
           -6.606109613978437,
           -6.611667791988536,
           -6.6172259699986355,
           -6.6227841480087335,
           -6.628342326018833,
           -6.633900504028933,
           -6.639458682039031,
           -6.6450168600491315,
           -6.65057503805923,
           -6.656133216069329,
           -6.66169139407943,
           -6.667249572089528,
           -6.6728077500996275,
           -6.678365928109727,
           -6.683924106119825,
           -6.689482284129925,
           -6.695040462140025,
           -6.700598640150124,
           -6.706156818160223,
           -6.711714996170322,
           -6.717273174180421,
           -6.72283135219052,
           -6.728389530200619,
           -6.733947708210719,
           -6.739505886220817,
           -6.745064064230916,
           -6.750622242241016,
           -6.756180420251114,
           -6.761738598261214,
           -6.767296776271314,
           -6.772854954281412,
           -6.7784131322915115,
           -6.783971310301611,
           -6.78952948831171,
           -6.79508766632181,
           -6.800645844331909,
           -6.807192011168814,
           -6.8147261668325285,
           -6.822260322496242,
           -6.829794478159956,
           -6.837328633823669,
           -6.844862789487382,
           -6.852396945151096,
           -6.859931100814809,
           -6.867465256478523,
           -6.874999412142236,
           -6.88253356780595,
           -6.890067723469663,
           -6.897601879133377,
           -6.905136034797091,
           -6.912670190460804,
           -6.9202043461245175,
           -6.92773850178823,
           -6.935272657451945,
           -6.9428068131156575,
           -6.950340968779371,
           -6.957875124443085,
           -6.9654092801067975,
           -6.972943435770512,
           -6.980477591434226,
           -6.988011747097939,
           -6.995545902761653,
           -7.003080058425366,
           -7.01061421408908,
           -7.018148369752792,
           -7.0256825254165065,
           -7.033216681080219,
           -7.040750836743934,
           -7.0482849924076465,
           -7.05581914807136,
           -7.063353303735075,
           -7.070887459398787,
           -7.078421615062501,
           -7.085955770726215,
           -7.093489926389928,
           -7.101024082053641,
           -7.108558237717355,
           -7.116092393381069,
           -7.123626549044781,
           -7.1311607047084955,
           -7.138694860372209,
           -7.146229016035922,
           -7.153763171699636,
           -7.161297327363349,
           -7.168831483027063,
           -7.178147938432903,
           -7.1885641072289355,
           -7.198980276024969,
           -7.2093964448209995,
           -7.219812613617033,
           -7.230228782413066,
           -7.240644951209097,
           -7.251061120005129,
           -7.261477288801163,
           -7.271893457597194,
           -7.282309626393228,
           -7.29272579518926,
           -7.303141963985292,
           -7.313558132781324,
           -7.323974301577357,
           -7.334390470373389,
           -7.344806639169422,
           -7.355222807965454,
           -7.3656389767614865,
           -7.376055145557517,
           -7.386471314353551,
           -7.396887483149584,
           -7.407303651945616,
           -7.417719820741649,
           -7.428135989537681,
           -7.438552158333714,
           -7.448968327129744,
           -7.459384495925779,
           -7.469800664721809,
           -7.480216833517842,
           -7.490633002313874,
           -7.501049171109908,
           -7.511465339905939,
           -7.521881508701972,
           -7.531612702424597,
           -7.539973946000403,
           -7.548335189576212,
           -7.55669643315202,
           -7.565057676727826,
           -7.5734189203036335,
           -7.581780163879442,
           -7.590141407455249,
           -7.5985026510310565,
           -7.606863894606865,
           -7.615225138182673,
           -7.623586381758479,
           -7.631947625334287,
           -7.640308868910096,
           -7.6486701124859025,
           -7.65703135606171,
           -7.665392599637517,
           -7.6737538432133245,
           -7.682115086789133,
           -7.690476330364939,
           -7.698837573940748,
           -7.707198817516556,
           -7.715560061092363,
           -7.7239213046681705,
           -7.73228254824398,
           -7.740643791819786,
           -7.749005035395594,
           -7.7573662789714,
           -7.765727522547209,
           -7.774088766123017,
           -7.782450009698825,
           -7.79081125327463,
           -7.799172496850439,
           -7.807533740426248,
           -7.815894984002054,
           -7.8242562275778615,
           -7.83261747115367,
           -7.840978714729477,
           -7.8493399583052845,
           -7.857701201881092,
           -7.866062445456898,
           -7.874423689032707,
           -7.882784932608515,
           -7.891146176184323,
           -7.8995074197601305,
           -7.907868663335937,
           -7.916229906911745,
           -7.924591150487553,
           -7.93295239406336,
           -7.941313637639167,
           -7.9496748812149765,
           -7.958036124790782,
           -7.96639736836659,
           -7.9747586119423985,
           -7.983119855518206,
           -7.991481099094014,
           -7.9998423426698215,
           -8.008203586245628,
           -8.016564829821435,
           -8.024926073397245,
           -8.033287316973052,
           -8.041648560548857,
           -8.050009804124667,
           -8.058371047700474,
           -8.066732291276281,
           -8.075093534852089,
           -8.083454778427898,
           -8.091816022003703,
           -8.10017726557951,
           -8.10853850915532,
           -8.116899752731127,
           -8.125260996306935,
           -8.133622239882742,
           -8.14198348345855,
           -8.150344727034357,
           -8.158705970610166,
           -8.167067214185973,
           -8.175428457761779,
           -8.183789701337586,
           -8.192150944913397,
           -8.200512188489203,
           -8.20887343206501,
           -8.21723467564082,
           -8.223529885120318,
           -8.216211530876013,
           -8.20889317663171,
           -8.201574822387405,
           -8.194256468143102,
           -8.186846224129635,
           -8.179370349505033,
           -8.171894474880434,
           -8.164418600255834,
           -8.156942725631232,
           -8.149466851006634,
           -8.141990976382035,
           -8.134515101757433,
           -8.127039227132832,
           -8.119563352508234,
           -8.112087477883634,
           -8.104611603259032,
           -8.097135728634433,
           -8.089659854009831,
           -8.082183979385233,
           -8.074708104760633,
           -8.067232230136032,
           -8.059756355511432,
           -8.052280480886832,
           -8.044804606262232,
           -8.037328731637631,
           -8.02985285701303,
           -8.022376982388431,
           -8.01490110776383,
           -8.00742523313923,
           -7.999949358514631,
           -7.992473483890031,
           -7.984997609265431,
           -7.977521734640831,
           -7.9700458600162305,
           -7.96256998539163,
           -7.955094110767029,
           -7.9476182361424295,
           -7.94014236151783,
           -7.932666486893228,
           -7.92519061226863,
           -7.917714737644029,
           -7.9069040017421655,
           -7.893711222070832,
           -7.880518442399494,
           -7.867325662728158,
           -7.854132883056824,
           -7.840940103385487,
           -7.82774732371415,
           -7.814554544042813,
           -7.80136176437148,
           -7.7881689847001425,
           -7.774976205028805,
           -7.761783425357472,
           -7.748590645686136,
           -7.735397866014798,
           -7.722205086343464,
           -7.709012306672127,
           -7.695819527000791,
           -7.682626747329454,
           -7.6694339676581205,
           -7.656241187986784,
           -7.643048408315447,
           -7.629855628644112,
           -7.616662848972776,
           -7.603470069301439,
           -7.590277289630105,
           -7.57708450995877,
           -7.563891730287431,
           -7.550698950616098,
           -7.537506170944761,
           -7.524313391273424,
           -7.511120611602088,
           -7.4979278319307525,
           -7.484735052259417,
           -7.4715422725880805,
           -7.458349492916746,
           -7.445156713245409,
           -7.431963933574074,
           -7.418725805821556,
           -7.405455284145264,
           -7.392184762468971,
           -7.378914240792678,
           -7.365643719116388
          ],
          [
           -4.5590072885423005,
           -4.5691373588923705,
           -4.57926742924244,
           -4.5893974995925095,
           -4.599527569942579,
           -4.609657640292649,
           -4.619787710642718,
           -4.629917780992788,
           -4.640047851342857,
           -4.650177921692926,
           -4.660307992042997,
           -4.670438062393066,
           -4.680568132743135,
           -4.689660737547254,
           -4.69667842391943,
           -4.703696110291607,
           -4.710713796663783,
           -4.717731483035959,
           -4.7247491694081365,
           -4.731766855780313,
           -4.738784542152489,
           -4.745802228524666,
           -4.7528199148968415,
           -4.759837601269019,
           -4.766855287641195,
           -4.773872974013372,
           -4.780890660385548,
           -4.787908346757725,
           -4.794926033129901,
           -4.801943719502077,
           -4.808961405874253,
           -4.81597909224643,
           -4.822996778618607,
           -4.830014464990783,
           -4.83703215136296,
           -4.844049837735136,
           -4.851067524107313,
           -4.858085210479489,
           -4.865102896851666,
           -4.872120583223842,
           -4.879138269596019,
           -4.886155955968195,
           -4.893173642340372,
           -4.900191328712548,
           -4.9072090150847245,
           -4.914226701456901,
           -4.921244387829077,
           -4.928262074201254,
           -4.93527976057343,
           -4.942297446945606,
           -4.949315133317784,
           -4.956332819689959,
           -4.963350506062136,
           -4.970368192434313,
           -4.977385878806489,
           -4.984403565178665,
           -4.991421251550842,
           -4.9984389379230185,
           -5.005456624295195,
           -5.012474310667372,
           -5.019491997039548,
           -5.026509683411724,
           -5.033527369783902,
           -5.040545056156078,
           -5.047562742528254,
           -5.054580428900431,
           -5.061598115272607,
           -5.068615801644784,
           -5.07563348801696,
           -5.082651174389136,
           -5.0896688607613125,
           -5.096686547133489,
           -5.103704233505666,
           -5.110721919877842,
           -5.1177396062500184,
           -5.124757292622196,
           -5.131774978994371,
           -5.138792665366548,
           -5.145810351738724,
           -5.1528280381109015,
           -5.159845724483078,
           -5.166863410855254,
           -5.173881097227429,
           -5.1808987835996065,
           -5.1889427418522445,
           -5.197191954480977,
           -5.205441167109708,
           -5.2136903797384395,
           -5.221939592367171,
           -5.230188804995903,
           -5.238438017624635,
           -5.246687230253366,
           -5.254936442882098,
           -5.26318565551083,
           -5.271434868139561,
           -5.279684080768293,
           -5.287463722166344,
           -5.2928955303311955,
           -5.298327338496048,
           -5.3037591466609,
           -5.309190954825752,
           -5.314622762990604,
           -5.320054571155455,
           -5.325486379320307,
           -5.3309181874851586,
           -5.336349995650011,
           -5.341781803814863,
           -5.347213611979714,
           -5.352645420144566,
           -5.358077228309417,
           -5.3635090364742695,
           -5.368940844639122,
           -5.374372652803973,
           -5.379804460968826,
           -5.385236269133676,
           -5.390668077298528,
           -5.39609988546338,
           -5.401531693628232,
           -5.406963501793083,
           -5.412395309957935,
           -5.417827118122787,
           -5.423258926287639,
           -5.428690734452491,
           -5.4341225426173425,
           -5.439554350782194,
           -5.444986158947046,
           -5.450417967111898,
           -5.455849775276749,
           -5.461281583441601,
           -5.4667133916064525,
           -5.472145199771305,
           -5.477577007936157,
           -5.483008816101008,
           -5.48844062426586,
           -5.493872432430711,
           -5.499304240595563,
           -5.504736048760416,
           -5.510167856925267,
           -5.515599665090119,
           -5.52103147325497,
           -5.526463281419822,
           -5.531895089584674,
           -5.537326897749526,
           -5.542758705914378,
           -5.548190514079229,
           -5.553622322244081,
           -5.559054130408933,
           -5.564485938573784,
           -5.5699177467386365,
           -5.575349554903489,
           -5.58078136306834,
           -5.586213171233192,
           -5.591644979398044,
           -5.597076787562895,
           -5.602508595727747,
           -5.607940403892599,
           -5.613372212057451,
           -5.618804020222302,
           -5.624235828387154,
           -5.629667636552005,
           -5.635099444716857,
           -5.6405312528817095,
           -5.645963061046561,
           -5.651394869211413,
           -5.656826677376264,
           -5.662258485541116,
           -5.667690293705967,
           -5.67480871441848,
           -5.682770441404818,
           -5.690732168391159,
           -5.698693895377501,
           -5.70665562236384,
           -5.714617349350181,
           -5.722579076336521,
           -5.730540803322862,
           -5.738502530309201,
           -5.746464257295542,
           -5.754425984281882,
           -5.762387711268222,
           -5.770349438254563,
           -5.778311165240903,
           -5.786272892227243,
           -5.794234619213584,
           -5.802196346199924,
           -5.808885601672098,
           -5.814443779682198,
           -5.820001957692296,
           -5.825560135702395,
           -5.831118313712494,
           -5.836676491722593,
           -5.842234669732693,
           -5.847792847742792,
           -5.8533510257528905,
           -5.85890920376299,
           -5.864467381773089,
           -5.870025559783189,
           -5.875583737793288,
           -5.881141915803386,
           -5.886700093813486,
           -5.892258271823585,
           -5.897816449833685,
           -5.9033746278437835,
           -5.908932805853882,
           -5.914490983863982,
           -5.920049161874081,
           -5.92560733988418,
           -5.9311655178942795,
           -5.936723695904378,
           -5.942281873914477,
           -5.947840051924577,
           -5.953398229934676,
           -5.958956407944776,
           -5.964514585954875,
           -5.970072763964973,
           -5.975630941975074,
           -5.9811891199851726,
           -5.986747297995272,
           -5.992305476005371,
           -5.99786365401547,
           -6.00342183202557,
           -6.0089800100356685,
           -6.014538188045767,
           -6.020096366055867,
           -6.025654544065965,
           -6.031212722076065,
           -6.0367709000861645,
           -6.042329078096264,
           -6.047887256106363,
           -6.053445434116462,
           -6.059003612126562,
           -6.06456179013666,
           -6.070119968146759,
           -6.075678146156859,
           -6.081236324166959,
           -6.0867945021770575,
           -6.092352680187157,
           -6.097910858197256,
           -6.103469036207356,
           -6.109027214217455,
           -6.1145853922275535,
           -6.120143570237653,
           -6.125701748247751,
           -6.131259926257851,
           -6.136818104267951,
           -6.14237628227805,
           -6.147934460288148,
           -6.153492638298248,
           -6.159050816308348,
           -6.164608994318446,
           -6.170167172328545,
           -6.1767133391654525,
           -6.184247494829165,
           -6.191781650492879,
           -6.1993158061565925,
           -6.206849961820305,
           -6.21438411748402,
           -6.2219182731477325,
           -6.229452428811446,
           -6.23698658447516,
           -6.2445207401388725,
           -6.252054895802587,
           -6.2595890514663,
           -6.267123207130014,
           -6.274657362793727,
           -6.282191518457441,
           -6.289725674121154,
           -6.297259829784867,
           -6.3047939854485815,
           -6.312328141112294,
           -6.319862296776008,
           -6.3273964524397215,
           -6.334930608103436,
           -6.342464763767148,
           -6.3499989194308615,
           -6.357533075094576,
           -6.365067230758289,
           -6.3726013864220015,
           -6.380135542085716,
           -6.387669697749429,
           -6.395203853413143,
           -6.402738009076856,
           -6.4102721647405705,
           -6.417806320404283,
           -6.425340476067996,
           -6.4328746317317105,
           -6.440408787395423,
           -6.447942943059138,
           -6.4554770987228505,
           -6.463011254386565,
           -6.470545410050278,
           -6.478079565713991,
           -6.485613721377705,
           -6.493147877041418,
           -6.500682032705132,
           -6.508216188368846,
           -6.515750344032558,
           -6.523284499696272,
           -6.530818655359987,
           -6.5383528110236995,
           -6.545886966687412,
           -6.553421122351126,
           -6.5609552780148395,
           -6.568489433678552,
           -6.576023589342267,
           -6.58355774500598,
           -6.591091900669694,
           -6.598626056333408,
           -6.606160211997121,
           -6.613694367660834,
           -6.621228523324547,
           -6.628762678988261,
           -6.636296834651975,
           -6.6438309903156885,
           -6.651365145979402,
           -6.658899301643116,
           -6.666433457306829,
           -6.673967612970542,
           -6.681501768634256,
           -6.6890359242979684,
           -6.696570079961683,
           -6.704104235625397,
           -6.711638391289108,
           -6.719172546952823,
           -6.726706702616537,
           -6.736117964115646,
           -6.746534132911679,
           -6.756950301707712,
           -6.767366470503744,
           -6.777782639299776,
           -6.7881988080958084,
           -6.798614976891843,
           -6.809031145687874,
           -6.819447314483906,
           -6.829178508206531,
           -6.837539751782338,
           -6.845900995358145,
           -6.854262238933952,
           -6.86262348250976,
           -6.870984726085568,
           -6.879345969661376,
           -6.887707213237183,
           -6.896068456812991,
           -6.904429700388798,
           -6.912790943964607,
           -6.9211521875404145,
           -6.929513431116221,
           -6.937874674692029,
           -6.946235918267837,
           -6.954597161843644,
           -6.962958405419451,
           -6.971319648995259,
           -6.979680892571066,
           -6.988042136146874,
           -6.996403379722683,
           -7.00476462329849,
           -7.0131258668742955,
           -7.020921419724202,
           -7.028126409997787,
           -7.035331400271372,
           -7.042536390544959,
           -7.049741380818544,
           -7.056946371092129,
           -7.064151361365716,
           -7.071356351639303,
           -7.078561341912888,
           -7.0857663321864734,
           -7.092971322460061,
           -7.100176312733645,
           -7.107381303007232,
           -7.114586293280818,
           -7.121791283554403,
           -7.128996273827989,
           -7.136201264101575,
           -7.143406254375161,
           -7.150611244648746,
           -7.157816234922333,
           -7.165021225195919,
           -7.172226215469505,
           -7.17943120574309,
           -7.186636196016677,
           -7.193841186290262,
           -7.201046176563848,
           -7.208251166837435,
           -7.21545615711102,
           -7.222661147384606,
           -7.229866137658192,
           -7.237071127931777,
           -7.244276118205362,
           -7.251481108478949,
           -7.258686098752536,
           -7.2658910890261215,
           -7.273096079299707,
           -7.2803010695732935,
           -7.287506059846879,
           -7.2947110501204655,
           -7.301916040394051,
           -7.309121030667637,
           -7.316326020941222,
           -7.323531011214809,
           -7.330736001488395,
           -7.33794099176198,
           -7.345145982035566,
           -7.352350972309152,
           -7.359555962582738,
           -7.366760952856324,
           -7.373965943129909,
           -7.381170933403495,
           -7.388375923677081,
           -7.395580913950668,
           -7.402785904224253,
           -7.409990894497838,
           -7.417195884771425,
           -7.424400875045012,
           -7.431605865318597,
           -7.438810855592182,
           -7.446015845865769,
           -7.450596937604305,
           -7.442058536667606,
           -7.433520135730906,
           -7.424981734794206,
           -7.416443333857508,
           -7.4079049329208075,
           -7.399366531984108,
           -7.390828131047409,
           -7.382289730110708,
           -7.373751329174009,
           -7.365212928237311,
           -7.35667452730061,
           -7.34813612636391,
           -7.339597725427211,
           -7.3310593244905125,
           -7.322520923553812,
           -7.314602328251883,
           -7.307126453627285,
           -7.299650579002684,
           -7.292174704378083,
           -7.284698829753484,
           -7.277222955128883,
           -7.269747080504283,
           -7.262271205879685,
           -7.2547953312550835,
           -7.247319456630483,
           -7.239843582005882,
           -7.232367707381282,
           -7.224891832756682,
           -7.217415958132081,
           -7.209940083507483,
           -7.202464208882882,
           -7.194988334258282,
           -7.187512459633682,
           -7.180036585009082,
           -7.172560710384481,
           -7.165084835759881,
           -7.157608961135281,
           -7.150133086510681,
           -7.14265721188608,
           -7.13518133726148,
           -7.1277054626368805,
           -7.116894726735017,
           -7.103701947063682,
           -7.090509167392346,
           -7.07731638772101,
           -7.064123608049675,
           -7.0509308283783385,
           -7.037738048707002,
           -7.024545269035665,
           -7.011352489364331,
           -6.9981597096929935,
           -6.984966930021658,
           -6.971774150350322,
           -6.958581370678987,
           -6.945388591007649,
           -6.932195811336316,
           -6.919003031664979,
           -6.905810251993643,
           -6.892617472322305,
           -6.8794246926509715,
           -6.866231912979635,
           -6.8530391333082985,
           -6.839846353636964,
           -6.826653573965627,
           -6.813460794294292,
           -6.800268014622956,
           -6.787075234951621,
           -6.772656434311101,
           -6.75736190908852,
           -6.742067383865937,
           -6.726772858643353,
           -6.71147833342077,
           -6.696183808198189,
           -6.680889282975605,
           -6.665594757753022,
           -6.650300232530442,
           -6.635005707307857,
           -6.619711182085275,
           -6.6044166568626945,
           -6.589122131640112,
           -6.573827606417527,
           -6.558533081194944,
           -6.543238555972364
          ],
          [
           -4.0796567768314755,
           -4.086674463203652,
           -4.093692149575828,
           -4.100709835948004,
           -4.1077275223201815,
           -4.114745208692358,
           -4.121762895064534,
           -4.12878058143671,
           -4.135798267808887,
           -4.142815954181064,
           -4.14983364055324,
           -4.156851326925416,
           -4.163869013297593,
           -4.1708866996697695,
           -4.177904386041946,
           -4.184922072414123,
           -4.191939758786299,
           -4.1989574451584755,
           -4.205975131530652,
           -4.212992817902828,
           -4.220010504275004,
           -4.227028190647181,
           -4.234045877019358,
           -4.241063563391535,
           -4.24808124976371,
           -4.255098936135887,
           -4.262116622508064,
           -4.26913430888024,
           -4.276151995252417,
           -4.283169681624592,
           -4.2901873679967695,
           -4.297205054368946,
           -4.304222740741122,
           -4.311240427113299,
           -4.318258113485475,
           -4.325275799857652,
           -4.332293486229828,
           -4.339311172602004,
           -4.346328858974182,
           -4.353346545346358,
           -4.360364231718534,
           -4.367381918090711,
           -4.374399604462887,
           -4.3814172908350635,
           -4.38843497720724,
           -4.395452663579416,
           -4.402470349951593,
           -4.409488036323769,
           -4.416505722695946,
           -4.423523409068123,
           -4.430541095440299,
           -4.437558781812475,
           -4.444576468184652,
           -4.451594154556828,
           -4.458611840929004,
           -4.465629527301181,
           -4.4726472136733575,
           -4.479664900045535,
           -4.486682586417711,
           -4.493700272789887,
           -4.500717959162063,
           -4.50773564553424,
           -4.514753331906417,
           -4.521771018278593,
           -4.528788704650769,
           -4.535806391022946,
           -4.542824077395122,
           -4.549841763767298,
           -4.556859450139475,
           -4.5638771365116515,
           -4.570894822883828,
           -4.577912509256004,
           -4.584930195628181,
           -4.591947882000357,
           -4.598965568372535,
           -4.605983254744711,
           -4.613000941116887,
           -4.620018627489063,
           -4.62703631386124,
           -4.634054000233417,
           -4.638947610821271,
           -4.642779189996883,
           -4.6466107691724945,
           -4.650442348348107,
           -4.655607451681417,
           -4.66103925984627,
           -4.666471068011121,
           -4.671902876175974,
           -4.677334684340825,
           -4.682766492505676,
           -4.688198300670528,
           -4.6936301088353805,
           -4.699061917000233,
           -4.704493725165084,
           -4.709925533329935,
           -4.715357341494788,
           -4.720789149659639,
           -4.726220957824491,
           -4.731652765989343,
           -4.737084574154194,
           -4.742516382319046,
           -4.747948190483898,
           -4.75337999864875,
           -4.758811806813602,
           -4.764243614978453,
           -4.769675423143305,
           -4.775107231308157,
           -4.780539039473008,
           -4.78597084763786,
           -4.791402655802712,
           -4.7968344639675635,
           -4.802266272132416,
           -4.807698080297267,
           -4.813129888462119,
           -4.81856169662697,
           -4.823993504791822,
           -4.829425312956674,
           -4.8348571211215265,
           -4.840288929286378,
           -4.84572073745123,
           -4.851152545616081,
           -4.856584353780933,
           -4.862016161945785,
           -4.867447970110637,
           -4.872879778275488,
           -4.87831158644034,
           -4.883743394605192,
           -4.889175202770044,
           -4.894607010934895,
           -4.9000388190997475,
           -4.905470627264599,
           -4.910902435429451,
           -4.916334243594302,
           -4.921766051759154,
           -4.927197859924005,
           -4.9326296680888575,
           -4.93806147625371,
           -4.943493284418562,
           -4.948925092583413,
           -4.954356900748265,
           -4.959788708913116,
           -4.965220517077968,
           -4.9706523252428205,
           -4.976084133407672,
           -4.981515941572524,
           -4.986947749737375,
           -4.992379557902227,
           -4.997811366067079,
           -5.0032431742319305,
           -5.008674982396783,
           -5.014106790561634,
           -5.019538598726486,
           -5.024970406891337,
           -5.030402215056189,
           -5.035834023221041,
           -5.041265831385893,
           -5.046697639550745,
           -5.052129447715596,
           -5.057561255880448,
           -5.062993064045299,
           -5.0684248722101515,
           -5.073856680375004,
           -5.079288488539856,
           -5.08329360364704,
           -5.085872033434175,
           -5.08845046322131,
           -5.0910288930084455,
           -5.095373104866215,
           -5.100600207759303,
           -5.105827310652389,
           -5.111054413545477,
           -5.116281516438565,
           -5.121508619331652,
           -5.12673572222474,
           -5.131962825117826,
           -5.137189928010915,
           -5.142417030904002,
           -5.1476441337970895,
           -5.152871236690177,
           -5.158098339583264,
           -5.163325442476351,
           -5.168552545369438,
           -5.173779648262525,
           -5.179006751155613,
           -5.184233854048701,
           -5.1894609569417876,
           -5.194688059834875,
           -5.199915162727963,
           -5.20514226562105,
           -5.2103693685141375,
           -5.215596471407226,
           -5.220823574300312,
           -5.2260506771934,
           -5.231277780086487,
           -5.236504882979575,
           -5.241731985872662,
           -5.246959088765749,
           -5.252186191658836,
           -5.257413294551925,
           -5.262640397445012,
           -5.267867500338099,
           -5.273094603231187,
           -5.2784541338505075,
           -5.284012311860607,
           -5.289570489870706,
           -5.295128667880805,
           -5.300686845890905,
           -5.306245023901003,
           -5.311803201911102,
           -5.317361379921202,
           -5.322919557931302,
           -5.328477735941401,
           -5.3340359139514995,
           -5.339594091961598,
           -5.345152269971698,
           -5.350710447981797,
           -5.356268625991897,
           -5.3618268040019945,
           -5.367384982012094,
           -5.372943160022194,
           -5.378501338032293,
           -5.3840595160423925,
           -5.389617694052491,
           -5.39517587206259,
           -5.40073405007269,
           -5.406292228082789,
           -5.4118504060928885,
           -5.417408584102987,
           -5.422966762113086,
           -5.428524940123186,
           -5.434083118133285,
           -5.439641296143384,
           -5.445199474153483,
           -5.450757652163583,
           -5.456315830173682,
           -5.4618740081837815,
           -5.46743218619388,
           -5.472990364203979,
           -5.478548542214079,
           -5.484106720224178,
           -5.4896648982342775,
           -5.495223076244376,
           -5.500781254254475,
           -5.506339432264575,
           -5.511897610274674,
           -5.517455788284773,
           -5.523013966294872,
           -5.528572144304971,
           -5.534130322315071,
           -5.53968850032517,
           -5.546234667162076,
           -5.5537688228257895,
           -5.561302978489502,
           -5.568837134153217,
           -5.57637128981693,
           -5.583905445480643,
           -5.591439601144357,
           -5.59897375680807,
           -5.606507912471784,
           -5.614042068135497,
           -5.621576223799211,
           -5.629110379462926,
           -5.636644535126638,
           -5.644178690790351,
           -5.651712846454065,
           -5.659247002117779,
           -5.666781157781492,
           -5.674315313445206,
           -5.6818494691089185,
           -5.689383624772632,
           -5.696917780436346,
           -5.704451936100059,
           -5.711986091763773,
           -5.719520247427486,
           -5.7270544030912,
           -5.734588558754913,
           -5.742122714418627,
           -5.749656870082341,
           -5.756638611920666,
           -5.763324413400382,
           -5.7700102148801,
           -5.776696016359818,
           -5.783381817839533,
           -5.790067619319251,
           -5.79675342079897,
           -5.803439222278687,
           -5.810125023758403,
           -5.816810825238121,
           -5.823496626717838,
           -5.8301824281975545,
           -5.836868229677273,
           -5.84355403115699,
           -5.850239832636706,
           -5.8569256341164255,
           -5.863611435596143,
           -5.870297237075859,
           -5.876983038555577,
           -5.883668840035295,
           -5.89035464151501,
           -5.897040442994728,
           -5.903726244474445,
           -5.910412045954162,
           -5.91709784743388,
           -5.923783648913597,
           -5.930469450393315,
           -5.9371552518730315,
           -5.943841053352749,
           -5.950526854832467,
           -5.957212656312183,
           -5.963898457791901,
           -5.970584259271619,
           -5.977270060751335,
           -5.983955862231053,
           -5.99064166371077,
           -5.997327465190486,
           -6.004013266670204,
           -6.010699068149922,
           -6.01738486962964,
           -6.024070671109356,
           -6.030756472589073,
           -6.03744227406879,
           -6.0441280755485085,
           -6.050813877028226,
           -6.057499678507943,
           -6.06418547998766,
           -6.070871281467378,
           -6.077557082947095,
           -6.0842428844268115,
           -6.090928685906528,
           -6.097614487386246,
           -6.104300288865963,
           -6.11098609034568,
           -6.117671891825398,
           -6.124125460695289,
           -6.1301145643455275,
           -6.136103667995765,
           -6.142092771646003,
           -6.14808187529624,
           -6.1540709789464785,
           -6.160060082596716,
           -6.166049186246955,
           -6.172038289897191,
           -6.1780273935474295,
           -6.184016497197668,
           -6.190005600847906,
           -6.195994704498143,
           -6.201983808148381,
           -6.207972911798619,
           -6.213962015448857,
           -6.219951119099094,
           -6.225940222749332,
           -6.2319293263995705,
           -6.237918430049809,
           -6.243907533700047,
           -6.249896637350285,
           -6.255885741000522,
           -6.261874844650761,
           -6.267863948300998,
           -6.273853051951236,
           -6.279842155601473,
           -6.285831259251712,
           -6.291820362901948,
           -6.297809466552188,
           -6.303798570202426,
           -6.309787673852663,
           -6.315776777502901,
           -6.321765881153139,
           -6.327754984803376,
           -6.3341732254781515,
           -6.341378215751738,
           -6.348583206025323,
           -6.355788196298908,
           -6.362993186572494,
           -6.370198176846079,
           -6.377403167119666,
           -6.384608157393252,
           -6.39181314766684,
           -6.399018137940425,
           -6.406223128214011,
           -6.413428118487596,
           -6.420633108761182,
           -6.427838099034767,
           -6.435043089308354,
           -6.4422480795819395,
           -6.449453069855525,
           -6.4566580601291115,
           -6.463863050402697,
           -6.4710680406762835,
           -6.478273030949869,
           -6.4854780212234555,
           -6.492683011497041,
           -6.499888001770627,
           -6.507092992044212,
           -6.514297982317798,
           -6.521502972591384,
           -6.528707962864971,
           -6.535912953138556,
           -6.543117943412142,
           -6.550322933685729,
           -6.557527923959315,
           -6.564732914232899,
           -6.571937904506485,
           -6.579142894780071,
           -6.586347885053658,
           -6.593552875327243,
           -6.60075786560083,
           -6.607962855874415,
           -6.615167846148001,
           -6.622372836421587,
           -6.629577826695174,
           -6.636782816968759,
           -6.643987807242345,
           -6.6511927975159315,
           -6.658397787789516,
           -6.665602778063102,
           -6.672807768336689,
           -6.677388860075225,
           -6.668850459138525,
           -6.660312058201826,
           -6.651773657265126,
           -6.643235256328428,
           -6.634696855391727,
           -6.626158454455028,
           -6.617620053518329,
           -6.6090816525816285,
           -6.600543251644929,
           -6.59200485070823,
           -6.58346644977153,
           -6.57492804883483,
           -6.566389647898131,
           -6.557851246961432,
           -6.549312846024732,
           -6.540774445088031,
           -6.532236044151334,
           -6.523697643214634,
           -6.515159242277933,
           -6.506620841341235,
           -6.498082440404534,
           -6.489544039467836,
           -6.481005638531137,
           -6.4724672375944365,
           -6.463928836657736,
           -6.4553904357210365,
           -6.446852034784337,
           -6.4383136338476366,
           -6.429775232910937,
           -6.421236831974239,
           -6.41269843103754,
           -6.404979059251117,
           -6.397503184626519,
           -6.390027310001918,
           -6.382551435377318,
           -6.375075560752717,
           -6.367599686128117,
           -6.3601238115035175,
           -6.352647936878916,
           -6.345172062254317,
           -6.337696187629716,
           -6.326885451727852,
           -6.3136926720565185,
           -6.300499892385181,
           -6.287307112713846,
           -6.274114333042511,
           -6.260921553371174,
           -6.247728773699837,
           -6.2345359940285014,
           -6.221343214357166,
           -6.20815043468583,
           -6.19412571100383,
           -6.17883118578125,
           -6.163536660558666,
           -6.148242135336083,
           -6.1329476101135025,
           -6.117653084890919,
           -6.102358559668335,
           -6.087064034445752,
           -6.071769509223172,
           -6.056474984000588,
           -6.041180458778005,
           -6.025885933555426,
           -6.010591408332841,
           -5.995296883110257,
           -5.9800023578876775,
           -5.964707832665093,
           -5.94941330744251,
           -5.9341187822199295,
           -5.918824256997345,
           -5.903529731774762,
           -5.88823520655218,
           -5.872940681329599,
           -5.857646156107015,
           -5.842351630884432,
           -5.827057105661851,
           -5.811762580439268,
           -5.7964680552166845,
           -5.7811735299941045,
           -5.765879004771521,
           -5.7505844795489365,
           -5.735289954326353,
           -5.719995429103774
          ],
          [
           -3.59908680682496,
           -3.6061044931971367,
           -3.613122179569313,
           -3.6201398659414887,
           -3.6271575523136654,
           -3.634175238685842,
           -3.6411929250580184,
           -3.648210611430195,
           -3.655228297802372,
           -3.6622459841745476,
           -3.6692636705467248,
           -3.676281356918901,
           -3.6832990432910773,
           -3.690316729663254,
           -3.6973344160354302,
           -3.704352102407607,
           -3.711369788779783,
           -3.7183874751519594,
           -3.7254051615241366,
           -3.732422847896313,
           -3.739440534268489,
           -3.7464582206406654,
           -3.7534759070128416,
           -3.7604935933850188,
           -3.767511279757195,
           -3.7745289661293713,
           -3.7815466525015475,
           -3.788564338873724,
           -3.7955820252459014,
           -3.802599711618077,
           -3.8096173979902535,
           -3.8166350843624306,
           -3.8236527707346064,
           -3.8306704571067836,
           -3.8376881434789594,
           -3.8447058298511365,
           -3.8517235162233128,
           -3.858741202595489,
           -3.865758888967666,
           -3.8727765753398415,
           -3.8797942617120187,
           -3.886811948084195,
           -3.8938296344563716,
           -3.9008473208285483,
           -3.907865007200724,
           -3.914882693572901,
           -3.921900379945077,
           -3.928918066317254,
           -3.93593575268943,
           -3.942953439061607,
           -3.949971125433783,
           -3.9569888118059597,
           -3.964006498178136,
           -3.9710241845503123,
           -3.978041870922489,
           -3.985059557294665,
           -3.992077243666842,
           -3.9990949300390186,
           -4.006112616411195,
           -4.013130302783371,
           -4.020147989155547,
           -4.0271656755277245,
           -4.034183361899901,
           -4.040670027823158,
           -4.044501606998771,
           -4.048333186174382,
           -4.0521647653499935,
           -4.055996344525606,
           -4.059827923701218,
           -4.063659502876829,
           -4.067491082052442,
           -4.071322661228053,
           -4.0751542404036645,
           -4.078985819579277,
           -4.082817398754888,
           -4.0866489779305,
           -4.090480557106112,
           -4.094312136281724,
           -4.0981437154573355,
           -4.101975294632948,
           -4.105806873808559,
           -4.1096384529841705,
           -4.113470032159783,
           -4.117301611335394,
           -4.122466714668707,
           -4.127898522833558,
           -4.13333033099841,
           -4.138762139163261,
           -4.144193947328113,
           -4.1496257554929645,
           -4.155057563657817,
           -4.160489371822669,
           -4.165921179987521,
           -4.171352988152372,
           -4.176784796317224,
           -4.182216604482075,
           -4.1876484126469276,
           -4.193080220811779,
           -4.198512028976632,
           -4.203943837141483,
           -4.209375645306335,
           -4.214807453471186,
           -4.2202392616360385,
           -4.22567106980089,
           -4.231102877965742,
           -4.236534686130594,
           -4.241966494295445,
           -4.247398302460296,
           -4.2528301106251485,
           -4.258261918790001,
           -4.263693726954852,
           -4.269125535119704,
           -4.274557343284555,
           -4.279989151449408,
           -4.285420959614259,
           -4.290852767779111,
           -4.296284575943963,
           -4.301716384108815,
           -4.307148192273666,
           -4.312580000438518,
           -4.31801180860337,
           -4.3234436167682215,
           -4.328875424933074,
           -4.334307233097925,
           -4.339739041262777,
           -4.345170849427628,
           -4.35060265759248,
           -4.356034465757332,
           -4.361466273922184,
           -4.366898082087036,
           -4.372329890251887,
           -4.377761698416739,
           -4.383193506581591,
           -4.3886253147464425,
           -4.394057122911295,
           -4.399488931076146,
           -4.404920739240998,
           -4.41035254740585,
           -4.415784355570701,
           -4.421216163735553,
           -4.4266479719004055,
           -4.432079780065257,
           -4.437511588230109,
           -4.44294339639496,
           -4.448375204559812,
           -4.453807012724663,
           -4.459238818576419,
           -4.4618172483635545,
           -4.464395678150689,
           -4.466974107937824,
           -4.469552537724959,
           -4.472130967512094,
           -4.474709397299229,
           -4.477287827086363,
           -4.479866256873499,
           -4.482444686660634,
           -4.485023116447769,
           -4.487601546234903,
           -4.490179976022039,
           -4.492758405809174,
           -4.495336835596309,
           -4.497915265383443,
           -4.5004936951705785,
           -4.503072124957714,
           -4.505650554744848,
           -4.508228984531984,
           -4.510807414319118,
           -4.5151516261768885,
           -4.520378729069976,
           -4.5256058319630625,
           -4.530832934856151,
           -4.5360600377492375,
           -4.541287140642326,
           -4.546514243535413,
           -4.5517413464285,
           -4.556968449321588,
           -4.562195552214675,
           -4.567422655107763,
           -4.57264975800085,
           -4.577876860893937,
           -4.583103963787025,
           -4.588331066680112,
           -4.5935581695732,
           -4.598785272466287,
           -4.604012375359374,
           -4.609239478252462,
           -4.61446658114555,
           -4.619693684038637,
           -4.624920786931725,
           -4.63014788982481,
           -4.635374992717899,
           -4.640602095610985,
           -4.645829198504074,
           -4.651056301397161,
           -4.656283404290248,
           -4.661510507183336,
           -4.666737610076423,
           -4.67196471296951,
           -4.6771918158625985,
           -4.682418918755685,
           -4.6876460216487725,
           -4.69287312454186,
           -4.6981002274349475,
           -4.703327330328035,
           -4.708554433221122,
           -4.713781536114209,
           -4.719008639007297,
           -4.724235741900384,
           -4.7294628447934715,
           -4.734689947686559,
           -4.739917050579647,
           -4.745144153472734,
           -4.7503712563658205,
           -4.755598359258909,
           -4.760825462151996,
           -4.766052565045084,
           -4.771279667938171,
           -4.776506770831259,
           -4.781733873724346,
           -4.786960976617433,
           -4.792188079510521,
           -4.797415182403608,
           -4.802642285296695,
           -4.807869388189783,
           -4.81309649108287,
           -4.818323593975958,
           -4.823550696869045,
           -4.828777799762133,
           -4.83400490265522,
           -4.839232005548308,
           -4.844459108441395,
           -4.849686211334482,
           -4.854913314227569,
           -4.860140417120657,
           -4.865367520013744,
           -4.8705946229068315,
           -4.875821725799919,
           -4.880557262038678,
           -4.88290518168592,
           -4.885253101333161,
           -4.887601020980402,
           -4.889948940627643,
           -4.892296860274884,
           -4.8946447799221255,
           -4.896992699569367,
           -4.899340619216607,
           -4.901688538863849,
           -4.904036458511091,
           -4.906384378158331,
           -4.908732297805573,
           -4.912369035482507,
           -4.917294591189133,
           -4.92222014689576,
           -4.927145702602386,
           -4.932071258309014,
           -4.9369968140156395,
           -4.941922369722266,
           -4.9468479254288935,
           -4.95177348113552,
           -4.956699036842147,
           -4.961624592548773,
           -4.9665501482554,
           -4.971475703962026,
           -4.976401259668653,
           -4.981326815375279,
           -4.986252371081906,
           -4.991177926788533,
           -4.99610348249516,
           -5.001029038201786,
           -5.005954593908412,
           -5.010880149615039,
           -5.015805705321666,
           -5.020731261028292,
           -5.025656816734919,
           -5.030582372441547,
           -5.0355079281481725,
           -5.0404334838548,
           -5.0453590395614265,
           -5.051287744967742,
           -5.0579735464474584,
           -5.064659347927177,
           -5.071345149406894,
           -5.07803095088661,
           -5.084716752366329,
           -5.091402553846046,
           -5.098088355325762,
           -5.10477415680548,
           -5.111459958285197,
           -5.118145759764914,
           -5.124831561244632,
           -5.131517362724349,
           -5.138203164204066,
           -5.144888965683783,
           -5.1515747671635,
           -5.158260568643218,
           -5.164946370122935,
           -5.171632171602652,
           -5.17831797308237,
           -5.185003774562087,
           -5.191689576041805,
           -5.198375377521522,
           -5.205061179001239,
           -5.211746980480956,
           -5.218432781960674,
           -5.225118583440391,
           -5.231804384920108,
           -5.238490186399826,
           -5.245175987879543,
           -5.25186178935926,
           -5.258547590838977,
           -5.265233392318695,
           -5.271919193798412,
           -5.278604995278129,
           -5.285290796757845,
           -5.2919765982375635,
           -5.29866239971728,
           -5.305348201196998,
           -5.312034002676715,
           -5.318719804156432,
           -5.325405605636149,
           -5.332091407115867,
           -5.338777208595585,
           -5.345463010075301,
           -5.352148811555019,
           -5.358834613034736,
           -5.365520414514453,
           -5.37220621599417,
           -5.378892017473888,
           -5.385577818953605,
           -5.392263620433322,
           -5.39894942191304,
           -5.405635223392757,
           -5.412321024872474,
           -5.4187745937423655,
           -5.424763697392603,
           -5.430752801042841,
           -5.436741904693079,
           -5.442731008343317,
           -5.448720111993554,
           -5.454709215643793,
           -5.46069831929403,
           -5.466687422944268,
           -5.4726765265945065,
           -5.478665630244745,
           -5.484654733894983,
           -5.490643837545219,
           -5.4966329411954575,
           -5.502622044845696,
           -5.508611148495934,
           -5.514600252146171,
           -5.520589355796409,
           -5.526578459446647,
           -5.532567563096885,
           -5.538556666747123,
           -5.544545770397361,
           -5.5505348740475995,
           -5.556523977697837,
           -5.562513081348075,
           -5.568502184998312,
           -5.5744912886485505,
           -5.580480392298788,
           -5.586469495949025,
           -5.592458599599263,
           -5.598447703249502,
           -5.60443680689974,
           -5.610425910549978,
           -5.616415014200215,
           -5.6224041178504525,
           -5.628393221500691,
           -5.634382325150929,
           -5.640371428801167,
           -5.646360532451405,
           -5.652349636101643,
           -5.658338739751881,
           -5.664327843402119,
           -5.670316947052357,
           -5.676306050702594,
           -5.682295154352833,
           -5.688284258003071,
           -5.694273361653308,
           -5.700262465303545,
           -5.706251568953784,
           -5.712240672604022,
           -5.71822977625426,
           -5.724218879904498,
           -5.730207983554735,
           -5.736197087204974,
           -5.742186190855211,
           -5.748175294505448,
           -5.754164398155687,
           -5.760153501805926,
           -5.766142605456162,
           -5.7721317091064,
           -5.778120812756638,
           -5.784109916406876,
           -5.790099020057114,
           -5.796088123707352,
           -5.802077227357589,
           -5.8080663310078275,
           -5.814055434658067,
           -5.820044538308303,
           -5.826033641958541,
           -5.83202274560878,
           -5.838011849259018,
           -5.844000952909255,
           -5.849990056559494,
           -5.855979160209731,
           -5.861968263859969,
           -5.867957367510208,
           -5.872673182710573,
           -5.877048938285678,
           -5.881424693860786,
           -5.885800449435891,
           -5.890176205010997,
           -5.894551960586104,
           -5.898927716161211,
           -5.901087969845889,
           -5.892170714078431,
           -5.883253458310973,
           -5.8745610810536855,
           -5.865884989709667,
           -5.857208898365647,
           -5.848532807021625,
           -5.839856715677607,
           -5.831180624333587,
           -5.822504532989566,
           -5.813828441645548,
           -5.805152350301527,
           -5.796476258957507,
           -5.7878001676134865,
           -5.779124076269467,
           -5.770447984925447,
           -5.761771893581427,
           -5.753095802237407,
           -5.744419710893387,
           -5.735743619549367,
           -5.727067528205348,
           -5.718391436861327,
           -5.709715345517306,
           -5.701039254173288,
           -5.692363162829269,
           -5.683687071485247,
           -5.675010980141227,
           -5.666334888797207,
           -5.657658797453188,
           -5.648982706109167,
           -5.640306614765148,
           -5.631630523421128,
           -5.622954432077107,
           -5.6142783407330885,
           -5.605602249389068,
           -5.596926158045047,
           -5.588250066701027,
           -5.579573975357008,
           -5.570897884012989,
           -5.562221792668968,
           -5.553545701324948,
           -5.544869609980928,
           -5.532259266174214,
           -5.516838742037009,
           -5.501418217899801,
           -5.485997693762592,
           -5.470577169625385,
           -5.455156645488177,
           -5.439736121350968,
           -5.424315597213761,
           -5.408895073076554,
           -5.393474548939347,
           -5.378054024802138,
           -5.362633500664932,
           -5.3472129765277225,
           -5.3317924523905145,
           -5.316371928253309,
           -5.300951404116101,
           -5.285530879978893,
           -5.270110355841684,
           -5.254689831704479,
           -5.23926930756727,
           -5.223848783430061,
           -5.208428259292855,
           -5.193007735155648,
           -5.177587211018438,
           -5.162166686881233,
           -5.146746162744025,
           -5.131325638606816,
           -5.11590511446961,
           -5.100484590332401,
           -5.085064066195193,
           -5.069643542057985,
           -5.054223017920779,
           -5.038802493783571,
           -5.023381969646362,
           -5.007961445509156,
           -4.9925409213719485,
           -4.9771203972347395,
           -4.961699873097534,
           -4.946279348960325,
           -4.9307161242679545,
           -4.914686281664804,
           -4.898656439061656
          ],
          [
           -3.1185168368184346,
           -3.125534523190611,
           -3.132552209562787,
           -3.139569895934964,
           -3.1465875823071405,
           -3.153605268679317,
           -3.160622955051493,
           -3.1676406414236697,
           -3.1746583277958464,
           -3.1816760141680227,
           -3.1886937005401994,
           -3.195711386912375,
           -3.202729073284552,
           -3.2097467596567286,
           -3.2167644460289053,
           -3.223782132401082,
           -3.2307998187732583,
           -3.2378175051454345,
           -3.244835191517611,
           -3.251852877889788,
           -3.2588705642619638,
           -3.2658882506341405,
           -3.2729059370063167,
           -3.2799236233784934,
           -3.2869413097506697,
           -3.2939589961228464,
           -3.3009766824950226,
           -3.307994368867199,
           -3.315012055239376,
           -3.3220297416115523,
           -3.3290474279837285,
           -3.3360651143559052,
           -3.343082800728081,
           -3.350100487100258,
           -3.3571181734724345,
           -3.3641358598446107,
           -3.3711535462167874,
           -3.378171232588964,
           -3.3851889189611404,
           -3.392206605333316,
           -3.399224291705493,
           -3.40624197807767,
           -3.4132596644498463,
           -3.420277350822023,
           -3.427295037194199,
           -3.434312723566375,
           -3.441330409938552,
           -3.446224024000648,
           -3.45005560317626,
           -3.453887182351872,
           -3.4577187615274836,
           -3.461550340703096,
           -3.4653819198787073,
           -3.469213499054319,
           -3.4730450782299314,
           -3.4768766574055423,
           -3.4807082365811546,
           -3.4845398157567664,
           -3.488371394932378,
           -3.49220297410799,
           -3.496034553283602,
           -3.4998661324592137,
           -3.503697711634825,
           -3.507529290810437,
           -3.511360869986049,
           -3.5151924491616606,
           -3.5190240283372725,
           -3.5228556075128843,
           -3.526687186688496,
           -3.530518765864108,
           -3.5343503450397202,
           -3.5381819242153316,
           -3.5420135033909435,
           -3.5458450825665553,
           -3.549676661742167,
           -3.553508240917779,
           -3.5573398200933903,
           -3.5611713992690026,
           -3.5650029784446144,
           -3.5688345576202263,
           -3.5726661367958377,
           -3.576497715971449,
           -3.5803292951470613,
           -3.584160874322673,
           -3.589325977655985,
           -3.594757785820837,
           -3.6001895939856885,
           -3.60562140215054,
           -3.6110532103153923,
           -3.616485018480244,
           -3.6219168266450956,
           -3.6273486348099473,
           -3.6327804429747994,
           -3.638212251139651,
           -3.6436440593045027,
           -3.6490758674693544,
           -3.6545076756342065,
           -3.659939483799058,
           -3.66537129196391,
           -3.6708031001287615,
           -3.6762349082936137,
           -3.6816667164584653,
           -3.687098524623317,
           -3.692530332788169,
           -3.6979621409530203,
           -3.703393949117872,
           -3.708825757282724,
           -3.7142575654475753,
           -3.7196893736124275,
           -3.725121181777279,
           -3.730552989942131,
           -3.735984798106983,
           -3.741416606271834,
           -3.7468484144366863,
           -3.752280222601538,
           -3.7577120307663896,
           -3.7631438389312417,
           -3.768575647096093,
           -3.774007455260945,
           -3.779439263425797,
           -3.7848710715906484,
           -3.7903028797555005,
           -3.795734687920352,
           -3.801166496085204,
           -3.8065983042500555,
           -3.812030112414907,
           -3.8174619205797593,
           -3.822893728744611,
           -3.8283255369094626,
           -3.8337573450743143,
           -3.8377624632929224,
           -3.8403408930800573,
           -3.842919322867192,
           -3.845497752654327,
           -3.8480761824414618,
           -3.850654612228597,
           -3.8532330420157317,
           -3.8558114718028667,
           -3.8583899015900016,
           -3.860968331377137,
           -3.8635467611642715,
           -3.8661251909514065,
           -3.8687036207385415,
           -3.871282050525677,
           -3.873860480312812,
           -3.8764389100999463,
           -3.8790173398870818,
           -3.8815957696742167,
           -3.8841741994613512,
           -3.8867526292484866,
           -3.8893310590356216,
           -3.8919094888227566,
           -3.8944879186098915,
           -3.897066348397026,
           -3.8996447781841614,
           -3.9022232079712964,
           -3.9048016377584314,
           -3.9073800675455663,
           -3.909958497332701,
           -3.9125369271198362,
           -3.915115356906971,
           -3.917693786694106,
           -3.9202722164812416,
           -3.922850646268376,
           -3.925429076055511,
           -3.928007505842646,
           -3.930585935629781,
           -3.9349301474875515,
           -3.9401572503806386,
           -3.945384353273726,
           -3.950611456166813,
           -3.9558385590599006,
           -3.961065661952988,
           -3.9662927648460755,
           -3.971519867739163,
           -3.9767469706322505,
           -3.981974073525337,
           -3.9872011764184254,
           -3.992428279311513,
           -3.9976553822046004,
           -4.002882485097688,
           -4.008109587990774,
           -4.013336690883862,
           -4.018563793776949,
           -4.023790896670037,
           -4.029017999563124,
           -4.034245102456212,
           -4.039472205349299,
           -4.044699308242387,
           -4.049926411135474,
           -4.055153514028562,
           -4.060380616921649,
           -4.065607719814737,
           -4.070834822707824,
           -4.076061925600911,
           -4.081289028493999,
           -4.086516131387086,
           -4.091743234280173,
           -4.096970337173261,
           -4.102197440066348,
           -4.107424542959435,
           -4.112651645852523,
           -4.1178787487456106,
           -4.123105851638698,
           -4.1283329545317855,
           -4.133560057424872,
           -4.1387871603179605,
           -4.144014263211047,
           -4.1492413661041345,
           -4.154468468997223,
           -4.1596955718903095,
           -4.164922674783397,
           -4.170149777676484,
           -4.175376880569572,
           -4.180603983462659,
           -4.185831086355747,
           -4.191058189248834,
           -4.196285292141921,
           -4.201512395035008,
           -4.204773228414041,
           -4.207121148061282,
           -4.2094690677085245,
           -4.211816987355765,
           -4.214164907003006,
           -4.216512826650247,
           -4.218860746297488,
           -4.221208665944729,
           -4.223556585591971,
           -4.225904505239212,
           -4.228252424886453,
           -4.230600344533694,
           -4.232948264180936,
           -4.235296183828177,
           -4.237644103475418,
           -4.239992023122659,
           -4.242339942769901,
           -4.244687862417141,
           -4.2470357820643825,
           -4.249383701711624,
           -4.251731621358865,
           -4.2540795410061065,
           -4.256427460653347,
           -4.258775380300588,
           -4.261123299947831,
           -4.263471219595071,
           -4.265819139242312,
           -4.268167058889554,
           -4.270514978536795,
           -4.2728628981840355,
           -4.275210817831277,
           -4.278847555508211,
           -4.283773111214838,
           -4.288698666921464,
           -4.2936242226280905,
           -4.298549778334717,
           -4.303475334041344,
           -4.30840088974797,
           -4.313326445454598,
           -4.318252001161224,
           -4.323177556867851,
           -4.328103112574477,
           -4.333028668281104,
           -4.3379542239877305,
           -4.342879779694357,
           -4.3478053354009845,
           -4.35273089110761,
           -4.357656446814237,
           -4.362582002520864,
           -4.367507558227491,
           -4.372433113934116,
           -4.377358669640744,
           -4.38228422534737,
           -4.387209781053997,
           -4.3921353367606235,
           -4.39706089246725,
           -4.4019864481738775,
           -4.406912003880503,
           -4.411837559587131,
           -4.416763115293757,
           -4.421688671000384,
           -4.426614226707009,
           -4.431539782413637,
           -4.436465338120263,
           -4.44139089382689,
           -4.446316449533517,
           -4.451242005240143,
           -4.45616756094677,
           -4.461093116653396,
           -4.466018672360023,
           -4.470944228066649,
           -4.475869783773276,
           -4.4807953394799025,
           -4.485720895186529,
           -4.490646450893156,
           -4.495572006599783,
           -4.500497562306409,
           -4.505423118013035,
           -4.510348673719663,
           -4.515274229426289,
           -4.520199785132915,
           -4.525125340839542,
           -4.530050896546169,
           -4.5349764522527956,
           -4.539902007959422,
           -4.544827563666049,
           -4.549753119372675,
           -4.554678675079302,
           -4.559604230785929,
           -4.564529786492555,
           -4.569455342199182,
           -4.574380897905809,
           -4.5793064536124355,
           -4.584232009319062,
           -4.589157565025689,
           -4.594083120732315,
           -4.599008676438942,
           -4.603934232145568,
           -4.608859787852195,
           -4.6137853435588205,
           -4.620054738683212,
           -4.62674054016293,
           -4.633426341642647,
           -4.640112143122364,
           -4.646797944602081,
           -4.653483746081799,
           -4.660169547561516,
           -4.666855349041233,
           -4.6735411505209505,
           -4.680226952000668,
           -4.686912753480385,
           -4.6935985549601025,
           -4.70028435643982,
           -4.706970157919537,
           -4.713423726789428,
           -4.719412830439666,
           -4.725401934089904,
           -4.731391037740141,
           -4.737380141390379,
           -4.743369245040617,
           -4.749358348690855,
           -4.755347452341094,
           -4.761336555991331,
           -4.767325659641569,
           -4.773314763291808,
           -4.779303866942045,
           -4.785292970592282,
           -4.79128207424252,
           -4.797271177892759,
           -4.803260281542997,
           -4.809249385193235,
           -4.815238488843471,
           -4.82122759249371,
           -4.827216696143948,
           -4.832240947256481,
           -4.836616702831588,
           -4.840992458406694,
           -4.845368213981801,
           -4.849743969556907,
           -4.854119725132014,
           -4.85849548070712,
           -4.862871236282226,
           -4.867246991857333,
           -4.87162274743244,
           -4.875998503007546,
           -4.880374258582652,
           -4.884750014157759,
           -4.889125769732864,
           -4.893501525307971,
           -4.897877280883078,
           -4.902253036458184,
           -4.90662879203329,
           -4.911004547608396,
           -4.915380303183504,
           -4.91975605875861,
           -4.924131814333716,
           -4.928507569908822,
           -4.93288332548393,
           -4.937259081059035,
           -4.941634836634142,
           -4.946010592209248,
           -4.950386347784354,
           -4.954762103359461,
           -4.959137858934567,
           -4.963513614509674,
           -4.96788937008478,
           -4.972265125659886,
           -4.976640881234994,
           -4.981016636810099,
           -4.985392392385206,
           -4.989768147960312,
           -4.994143903535419,
           -4.998519659110525,
           -5.002895414685632,
           -5.007271170260738,
           -5.011646925835844,
           -5.016022681410951,
           -5.020398436986057,
           -5.024774192561164,
           -5.02914994813627,
           -5.033525703711376,
           -5.037901459286482,
           -5.042277214861589,
           -5.046652970436696,
           -5.051028726011802,
           -5.055404481586909,
           -5.059780237162015,
           -5.064155992737122,
           -5.068531748312228,
           -5.072907503887334,
           -5.077283259462441,
           -5.081659015037547,
           -5.086034770612654,
           -5.09041052618776,
           -5.094786281762866,
           -5.0991620373379725,
           -5.10353779291308,
           -5.105698046597758,
           -5.0967807908303,
           -5.0878635350628425,
           -5.078946279295384,
           -5.070029023527928,
           -5.061111767760471,
           -5.0521945119930125,
           -5.043277256225556,
           -5.034360000458098,
           -5.02544274469064,
           -5.016525488923184,
           -5.007608233155726,
           -4.998690977388268,
           -4.98977372162081,
           -4.980856465853353,
           -4.971939210085896,
           -4.963021954318438,
           -4.9541046985509825,
           -4.945187442783524,
           -4.93640878696997,
           -4.927732695625951,
           -4.919056604281931,
           -4.91038051293791,
           -4.901704421593892,
           -4.893028330249871,
           -4.8843522389058505,
           -4.87567614756183,
           -4.867000056217811,
           -4.858323964873791,
           -4.84964787352977,
           -4.840971782185752,
           -4.832295690841731,
           -4.823619599497711,
           -4.814943508153691,
           -4.806267416809671,
           -4.797591325465651,
           -4.78891523412163,
           -4.780239142777612,
           -4.77156305143359,
           -4.7628869600895705,
           -4.7542108687455515,
           -4.745534777401532,
           -4.7329244335948175,
           -4.717503909457611,
           -4.702083385320403,
           -4.686662861183194,
           -4.671242337045989,
           -4.655821812908781,
           -4.640401288771573,
           -4.624980764634364,
           -4.609560240497158,
           -4.594139716359949,
           -4.578719192222741,
           -4.563298668085535,
           -4.547878143948326,
           -4.532457619811118,
           -4.5170370956739125,
           -4.5016165715367045,
           -4.4861960473994955,
           -4.470775523262287,
           -4.455354999125082,
           -4.439934474987873,
           -4.424513950850664,
           -4.40909342671346,
           -4.39367290257625,
           -4.377891689190529,
           -4.361861846587381,
           -4.3458320039842295,
           -4.32980216138108,
           -4.313772318777932,
           -4.297742476174781,
           -4.281712633571631,
           -4.26568279096848,
           -4.249652948365333,
           -4.233623105762183,
           -4.217593263159032,
           -4.201563420555884,
           -4.185533577952734,
           -4.169503735349584,
           -4.153473892746435,
           -4.137444050143285,
           -4.121414207540134,
           -4.105384364936984,
           -4.089354522333837
          ],
          [
           -2.6379468668119186,
           -2.644964553184095,
           -2.651982239556271,
           -2.658999925928448,
           -2.6660176123006245,
           -2.6730352986728008,
           -2.680052985044977,
           -2.6870706714171537,
           -2.6940883577893304,
           -2.7011060441615067,
           -2.7081237305336834,
           -2.715141416905859,
           -2.722159103278036,
           -2.7291767896502126,
           -2.7361944760223893,
           -2.743212162394566,
           -2.7502298487667423,
           -2.7572475351389185,
           -2.764265221511095,
           -2.7712829078832715,
           -2.7783005942554477,
           -2.7853182806276244,
           -2.7923359669998002,
           -2.7993536533719774,
           -2.8063713397441536,
           -2.8133890261163303,
           -2.8204067124885066,
           -2.827424398860683,
           -2.8344420852328596,
           -2.841459771605036,
           -2.847946441002536,
           -2.851778020178148,
           -2.8556095993537602,
           -2.8594411785293716,
           -2.863272757704984,
           -2.8671043368805957,
           -2.870935916056207,
           -2.874767495231819,
           -2.878599074407431,
           -2.8824306535830426,
           -2.8862622327586545,
           -2.8900938119342663,
           -2.893925391109878,
           -2.89775697028549,
           -2.901588549461102,
           -2.905420128636713,
           -2.9092517078123254,
           -2.913083286987937,
           -2.9169148661635487,
           -2.9207464453391605,
           -2.9245780245147723,
           -2.9284096036903846,
           -2.9322411828659956,
           -2.9360727620416074,
           -2.9399043412172197,
           -2.943735920392831,
           -2.9475674995684433,
           -2.951399078744055,
           -2.9552306579196665,
           -2.959062237095279,
           -2.96289381627089,
           -2.9667253954465025,
           -2.9705569746221143,
           -2.974388553797726,
           -2.9782201329733375,
           -2.9820517121489494,
           -2.985883291324561,
           -2.989714870500173,
           -2.993546449675785,
           -2.9973780288513967,
           -3.0012096080270085,
           -3.00504118720262,
           -3.008872766378232,
           -3.012704345553844,
           -3.016535924729456,
           -3.0203675039050677,
           -3.0241990830806795,
           -3.028030662256291,
           -3.031862241431903,
           -3.0356938206075146,
           -3.039525399783127,
           -3.0433569789587382,
           -3.04718855813435,
           -3.051020137309962,
           -3.0561852406432735,
           -3.0616170488081256,
           -3.0670488569729772,
           -3.072480665137829,
           -3.077912473302681,
           -3.0833442814675323,
           -3.0887760896323844,
           -3.094207897797236,
           -3.0996397059620877,
           -3.10507151412694,
           -3.1105033222917915,
           -3.115935130456643,
           -3.1213669386214953,
           -3.1267987467863465,
           -3.1322305549511986,
           -3.1376623631160507,
           -3.143094171280902,
           -3.148525979445754,
           -3.1539577876106053,
           -3.1593895957754574,
           -3.1648214039403086,
           -3.1702532121051608,
           -3.175685020270013,
           -3.181116828434864,
           -3.186548636599716,
           -3.191980444764568,
           -3.1974122529294196,
           -3.2028440610942717,
           -3.208275869259123,
           -3.213707677423975,
           -3.216286108009436,
           -3.218864537796571,
           -3.221442967583706,
           -3.2240213973708407,
           -3.2265998271579757,
           -3.229178256945111,
           -3.231756686732246,
           -3.2343351165193805,
           -3.236913546306516,
           -3.239491976093651,
           -3.242070405880786,
           -3.244648835667921,
           -3.2472272654550562,
           -3.2498056952421908,
           -3.2523841250293257,
           -3.254962554816461,
           -3.2575409846035956,
           -3.2601194143907306,
           -3.2626978441778656,
           -3.2652762739650005,
           -3.2678547037521355,
           -3.2704331335392705,
           -3.2730115633264054,
           -3.2755899931135404,
           -3.2781684229006753,
           -3.2807468526878103,
           -3.2833252824749453,
           -3.2859037122620807,
           -3.2884821420492156,
           -3.29106057183635,
           -3.293639001623485,
           -3.2962174314106205,
           -3.2987958611977555,
           -3.30137429098489,
           -3.303952720772025,
           -3.3065311505591604,
           -3.3091095803462953,
           -3.3116880101334303,
           -3.314266439920565,
           -3.3168448697077,
           -3.3194232994948347,
           -3.3220017292819697,
           -3.3245801590691046,
           -3.32715858885624,
           -3.329737018643375,
           -3.33231544843051,
           -3.3348938782176445,
           -3.33747230800478,
           -3.340050737791915,
           -3.34262916757905,
           -3.345207597366185,
           -3.3477860271533197,
           -3.3503644569404547,
           -3.3547086687982253,
           -3.359935771691312,
           -3.3651628745843993,
           -3.370389977477487,
           -3.3756170803705743,
           -3.3808441832636618,
           -3.3860712861567492,
           -3.3912983890498367,
           -3.396525491942924,
           -3.4017525948360112,
           -3.406979697729099,
           -3.4122068006221857,
           -3.4174339035152737,
           -3.422661006408361,
           -3.427888109301448,
           -3.4331152121945356,
           -3.438342315087623,
           -3.443569417980711,
           -3.448796520873798,
           -3.4540236237668855,
           -3.459250726659973,
           -3.4644778295530605,
           -3.469704932446148,
           -3.474932035339235,
           -3.4801591382323225,
           -3.4853862411254095,
           -3.490613344018497,
           -3.4958404469115845,
           -3.5010675498046724,
           -3.50629465269776,
           -3.511521755590847,
           -3.5167488584839344,
           -3.521975961377022,
           -3.5266412751421754,
           -3.528989194789416,
           -3.5313371144366577,
           -3.5336850340838986,
           -3.53603295373114,
           -3.5383808733783813,
           -3.540728793025622,
           -3.543076712672863,
           -3.5454246323201044,
           -3.5477725519673458,
           -3.5501204716145867,
           -3.5524683912618285,
           -3.55481631090907,
           -3.5571642305563103,
           -3.5595121502035516,
           -3.561860069850793,
           -3.564207989498034,
           -3.566555909145275,
           -3.5689038287925166,
           -3.5712517484397575,
           -3.573599668086999,
           -3.57594758773424,
           -3.5782955073814806,
           -3.580643427028722,
           -3.5829913466759638,
           -3.5853392663232047,
           -3.587687185970447,
           -3.5900351056176873,
           -3.5923830252649287,
           -3.59473094491217,
           -3.597078864559411,
           -3.599426784206652,
           -3.6017747038538936,
           -3.6041226235011345,
           -3.606470543148376,
           -3.6088184627956164,
           -3.6111663824428586,
           -3.613514302090099,
           -3.6158622217373404,
           -3.6182101413845817,
           -3.6205580610318226,
           -3.6229059806790636,
           -3.625253900326305,
           -3.6276018199735462,
           -3.6299497396207876,
           -3.632297659268028,
           -3.63464557891527,
           -3.636993498562511,
           -3.639341418209752,
           -3.641689337856994,
           -3.6453260755339274,
           -3.650251631240554,
           -3.6551771869471805,
           -3.660102742653807,
           -3.665028298360434,
           -3.6699538540670607,
           -3.6748794097736868,
           -3.679804965480314,
           -3.6847305211869408,
           -3.6896560768935664,
           -3.694581632600194,
           -3.6995071883068205,
           -3.704432744013447,
           -3.7093582997200736,
           -3.7142838554267006,
           -3.719209411133327,
           -3.7241349668399533,
           -3.7290605225465807,
           -3.7339860782532073,
           -3.7389116339598334,
           -3.7438371896664604,
           -3.748762745373087,
           -3.753688301079713,
           -3.75861385678634,
           -3.7635394124929666,
           -3.768464968199593,
           -3.7733905239062198,
           -3.7783160796128468,
           -3.7832416353194733,
           -3.7881671910260994,
           -3.793092746732727,
           -3.7980183024393535,
           -3.8029438581459796,
           -3.8078694138526066,
           -3.812794969559233,
           -3.8177205252658597,
           -3.8226460809724863,
           -3.8275716366791133,
           -3.83249719238574,
           -3.8374227480923655,
           -3.8423483037989925,
           -3.8472738595056186,
           -3.852199415212245,
           -3.857124970918872,
           -3.862050526625499,
           -3.8669760823321253,
           -3.8719016380387523,
           -3.8768271937453793,
           -3.8817527494520054,
           -3.886678305158632,
           -3.891603860865259,
           -3.8965294165718856,
           -3.901454972278512,
           -3.9063805279851387,
           -3.9113060836917657,
           -3.916231639398392,
           -3.921157195105019,
           -3.926082750811646,
           -3.9310083065182715,
           -3.9351727518966313,
           -3.938107716898622,
           -3.9410426819006115,
           -3.9439776469026007,
           -3.946912611904591,
           -3.949847576906581,
           -3.9527825419085705,
           -3.9557175069105606,
           -3.9586524719125507,
           -3.96158743691454,
           -3.9645224019165304,
           -3.9674573669185205,
           -3.97039233192051,
           -3.9733272969225,
           -3.97626226192449,
           -3.9791972269264795,
           -3.98213219192847,
           -3.985067156930459,
           -3.988002121932449,
           -3.990937086934439,
           -3.993872051936429,
           -3.996807016938419,
           -3.999741981940409,
           -4.002676946942398,
           -4.00561400067269,
           -4.00855523185958,
           -4.011496463046472,
           -4.014437694233362,
           -4.017378925420254,
           -4.020320156607145,
           -4.023261387794036,
           -4.0262026189809275,
           -4.029143850167818,
           -4.03208508135471,
           -4.035026312541601,
           -4.037967543728492,
           -4.040908774915383,
           -4.043850006102274,
           -4.046791237289165,
           -4.049732468476057,
           -4.0526736996629475,
           -4.055614930849838,
           -4.05855616203673,
           -4.061497393223621,
           -4.064438624410513,
           -4.0673798555974034,
           -4.070321086784294,
           -4.073262317971185,
           -4.076203549158077,
           -4.079144780344968,
           -4.0820860115318585,
           -4.08502724271875,
           -4.087968473905642,
           -4.090909705092533,
           -4.093850936279424,
           -4.096792167466314,
           -4.099733398653206,
           -4.102674629840097,
           -4.105615861026989,
           -4.108557092213879,
           -4.111498323400771,
           -4.114439554587662,
           -4.117380785774552,
           -4.1203220169614445,
           -4.124366135510494,
           -4.128741891085601,
           -4.133117646660708,
           -4.137493402235814,
           -4.14186915781092,
           -4.146244913386026,
           -4.150620668961133,
           -4.154996424536239,
           -4.159372180111346,
           -4.163747935686453,
           -4.168123691261558,
           -4.172499446836665,
           -4.176875202411771,
           -4.181250957986878,
           -4.185626713561984,
           -4.19000246913709,
           -4.194378224712198,
           -4.198753980287303,
           -4.20312973586241,
           -4.207505491437516,
           -4.211881247012623,
           -4.216257002587729,
           -4.220632758162836,
           -4.225008513737942,
           -4.229384269313048,
           -4.233760024888155,
           -4.238135780463261,
           -4.242511536038367,
           -4.246887291613474,
           -4.25126304718858,
           -4.255638802763687,
           -4.260014558338793,
           -4.2643903139139,
           -4.268766069489006,
           -4.273141825064112,
           -4.277517580639219,
           -4.281893336214326,
           -4.286269091789431,
           -4.290644847364538,
           -4.295020602939645,
           -4.299396358514752,
           -4.303772114089857,
           -4.308147869664964,
           -4.3103081233496425,
           -4.301390867582185,
           -4.292473611814726,
           -4.283556356047269,
           -4.2746391002798125,
           -4.265721844512354,
           -4.256804588744897,
           -4.24788733297744,
           -4.2389700772099825,
           -4.230052821442524,
           -4.221135565675069,
           -4.212218309907611,
           -4.2033010541401525,
           -4.194383798372694,
           -4.185466542605238,
           -4.176549286837781,
           -4.1676320310703225,
           -4.158714775302866,
           -4.149797519535408,
           -4.140880263767951,
           -4.131963008000494,
           -4.123045752233036,
           -4.114128496465579,
           -4.1052112406981225,
           -4.096293984930664,
           -4.087376729163206,
           -4.078459473395748,
           -4.0695422176282925,
           -4.060624961860834,
           -4.051707706093375,
           -4.04279045032592,
           -4.0338731945584625,
           -4.024955938791004,
           -4.016038683023548,
           -4.00712142725609,
           -3.998256492886269,
           -3.989580401542249,
           -3.9809043101982304,
           -3.9722282188542097,
           -3.9635521275101895,
           -3.9548760361661706,
           -3.9461999448221503,
           -3.933589601015436,
           -3.9181690768782302,
           -3.9027485527410217,
           -3.887328028603814,
           -3.8719075044666083,
           -3.8564869803293993,
           -3.8410664561921903,
           -3.8250672541131174,
           -3.80903741150997,
           -3.7930075689068197,
           -3.7769777263036692,
           -3.7609478837005215,
           -3.744918041097371,
           -3.7288881984942206,
           -3.712858355891073,
           -3.6968285132879224,
           -3.680798670684772,
           -3.6647688280816215,
           -3.6487389854784738,
           -3.632709142875323,
           -3.616679300272173,
           -3.600649457669025,
           -3.5846196150658742,
           -3.5685897724627242,
           -3.5525599298595765,
           -3.536530087256425,
           -3.5205002446532756,
           -3.5044704020501283,
           -3.488440559446977,
           -3.472410716843827,
           -3.4563808742406765,
           -3.4403510316375288,
           -3.424321189034378,
           -3.4082913464312274,
           -3.39226150382808,
           -3.3762316612249297,
           -3.3602018186217792,
           -3.3441719760186315,
           -3.328142133415481,
           -3.3121122908123306,
           -3.29608244820918,
           -3.2800526056060324
          ],
          [
           -2.1573768968053937,
           -2.1643945831775704,
           -2.171412269549746,
           -2.178429955921923,
           -2.1854476422940996,
           -2.192465328666276,
           -2.199483015038452,
           -2.206500701410629,
           -2.2135183877828055,
           -2.2205360741549818,
           -2.2275537605271585,
           -2.2345714468993347,
           -2.2415891332715114,
           -2.2486068196436877,
           -2.2535004371800262,
           -2.2573320163556385,
           -2.2611635955312495,
           -2.2649951747068617,
           -2.268826753882473,
           -2.2726583330580854,
           -2.276489912233697,
           -2.2803214914093086,
           -2.284153070584921,
           -2.2879846497605323,
           -2.291816228936144,
           -2.295647808111756,
           -2.299479387287368,
           -2.3033109664629796,
           -2.3071425456385914,
           -2.3109741248142033,
           -2.314805703989815,
           -2.318637283165427,
           -2.3224688623410388,
           -2.3263004415166506,
           -2.3301320206922624,
           -2.3339635998678743,
           -2.3377951790434857,
           -2.3416267582190975,
           -2.3454583373947093,
           -2.3492899165703216,
           -2.353121495745933,
           -2.356953074921545,
           -2.3607846540971567,
           -2.3646162332727685,
           -2.3684478124483803,
           -2.3722793916239917,
           -2.376110970799604,
           -2.379942549975216,
           -2.383774129150827,
           -2.3876057083264395,
           -2.3914372875020513,
           -2.395268866677663,
           -2.3991004458532745,
           -2.4029320250288864,
           -2.4067636042044986,
           -2.41059518338011,
           -2.4144267625557223,
           -2.4182583417313337,
           -2.4220899209069455,
           -2.4259215000825574,
           -2.4297530792581696,
           -2.433584658433781,
           -2.437416237609393,
           -2.4412478167850047,
           -2.4450793959606165,
           -2.4489109751362284,
           -2.4527425543118397,
           -2.456574133487452,
           -2.4604057126630634,
           -2.4642372918386757,
           -2.468068871014287,
           -2.471900450189899,
           -2.4757320293655107,
           -2.4795636085411226,
           -2.4833951877167344,
           -2.4872267668923462,
           -2.491058346067958,
           -2.49488992524357,
           -2.4987215044191817,
           -2.5025530835947936,
           -2.5063846627704054,
           -2.510216241946017,
           -2.514047821121629,
           -2.5178794002972404,
           -2.523044503630552,
           -2.528476311795404,
           -2.533908119960256,
           -2.5393399281251074,
           -2.5447717362899596,
           -2.550203544454811,
           -2.555635352619663,
           -2.5610671607845146,
           -2.5664989689493662,
           -2.5719307771142184,
           -2.57736258527907,
           -2.5827943934439217,
           -2.588226201608774,
           -2.592231322938804,
           -2.5948097527259395,
           -2.5973881825130745,
           -2.599966612300209,
           -2.6025450420873444,
           -2.605123471874479,
           -2.607701901661614,
           -2.610280331448749,
           -2.6128587612358842,
           -2.6154371910230187,
           -2.618015620810154,
           -2.620594050597289,
           -2.623172480384424,
           -2.6257509101715586,
           -2.628329339958694,
           -2.6309077697458285,
           -2.6334861995329635,
           -2.636064629320099,
           -2.638643059107234,
           -2.641221488894369,
           -2.6437999186815038,
           -2.6463783484686387,
           -2.6489567782557737,
           -2.6515352080429087,
           -2.6541136378300436,
           -2.6566920676171786,
           -2.6592704974043135,
           -2.6618489271914485,
           -2.6644273569785835,
           -2.667005786765719,
           -2.6695842165528534,
           -2.6721626463399883,
           -2.6747410761271238,
           -2.6773195059142583,
           -2.6798979357013932,
           -2.6824763654885286,
           -2.685054795275663,
           -2.6876332250627986,
           -2.690211654849933,
           -2.6927900846370685,
           -2.695368514424203,
           -2.6979469442113384,
           -2.700525373998473,
           -2.7031038037856083,
           -2.7056822335727433,
           -2.7082606633598783,
           -2.7108390931470128,
           -2.713417522934148,
           -2.715995952721283,
           -2.718574382508418,
           -2.721152812295553,
           -2.723731242082688,
           -2.726309671869823,
           -2.728888101656958,
           -2.7314665314440933,
           -2.734044961231228,
           -2.736623391018363,
           -2.739201820805498,
           -2.7417802505926328,
           -2.7443586803797677,
           -2.7469371101669027,
           -2.7495155399540376,
           -2.752093969741172,
           -2.7546723995283076,
           -2.7572508293154425,
           -2.7598292591025775,
           -2.762407688889713,
           -2.7649861186768474,
           -2.767564548463983,
           -2.7701429782511178,
           -2.7744871901088874,
           -2.779714293001975,
           -2.7849413958950624,
           -2.79016849878815,
           -2.795395601681237,
           -2.800622704574325,
           -2.8058498074674123,
           -2.8110769103604993,
           -2.816304013253587,
           -2.821531116146674,
           -2.8267582190397618,
           -2.831985321932849,
           -2.8372124248259363,
           -2.8424395277190238,
           -2.8476666306121112,
           -2.8508572415175375,
           -2.8532051611647793,
           -2.85555308081202,
           -2.8579010004592615,
           -2.8602489201065024,
           -2.862596839753744,
           -2.864944759400985,
           -2.8672926790482265,
           -2.869640598695468,
           -2.8719885183427083,
           -2.8743364379899496,
           -2.876684357637191,
           -2.879032277284432,
           -2.8813801969316737,
           -2.8837281165789146,
           -2.8860760362261555,
           -2.888423955873397,
           -2.890771875520638,
           -2.893119795167879,
           -2.8954677148151204,
           -2.8978156344623613,
           -2.9001635541096027,
           -2.902511473756844,
           -2.9048593934040854,
           -2.9072073130513263,
           -2.909555232698567,
           -2.911903152345809,
           -2.91425107199305,
           -2.9165989916402912,
           -2.9189469112875326,
           -2.9212948309347735,
           -2.923642750582015,
           -2.9259906702292557,
           -2.928338589876497,
           -2.9306865095237384,
           -2.9330344291709793,
           -2.9353823488182202,
           -2.9377302684654616,
           -2.9400781881127034,
           -2.9424261077599443,
           -2.9447740274071856,
           -2.947121947054427,
           -2.949469866701668,
           -2.9518177863489092,
           -2.95416570599615,
           -2.9565136256433915,
           -2.958861545290633,
           -2.9612094649378733,
           -2.963557384585115,
           -2.9659053042323564,
           -2.9682532238795973,
           -2.970601143526839,
           -2.9729490631740796,
           -2.975296982821321,
           -2.9776449024685623,
           -2.9799928221158036,
           -2.9823407417630445,
           -2.984688661410286,
           -2.9870365810575272,
           -2.9893845007047677,
           -2.991732420352009,
           -2.994080339999251,
           -2.9964282596464913,
           -2.9987761792937326,
           -3.0011240989409744,
           -3.0034720185882153,
           -3.0058199382354562,
           -3.008167857882698,
           -3.0118045955596315,
           -3.0167301512662585,
           -3.0216557069728847,
           -3.026581262679511,
           -3.0315068183861382,
           -3.036432374092765,
           -3.0413579297993913,
           -3.0462834855060184,
           -3.0512090412126454,
           -3.056134596919271,
           -3.061060152625898,
           -3.0659857083325246,
           -3.070911264039151,
           -3.075836819745778,
           -3.0807623754524047,
           -3.0856879311590313,
           -3.0906134868656574,
           -3.0955390425722844,
           -3.100464598278911,
           -3.1053901539855375,
           -3.1103157096921645,
           -3.115241265398791,
           -3.1189958882891906,
           -3.121930853291181,
           -3.1248658182931712,
           -3.127800783295161,
           -3.1307357482971505,
           -3.1336707132991406,
           -3.1366056783011307,
           -3.13954064330312,
           -3.14247560830511,
           -3.1454105733071,
           -3.1483455383090897,
           -3.1512805033110793,
           -3.1542154683130694,
           -3.15715043331506,
           -3.160085398317049,
           -3.1630203633190392,
           -3.1659553283210293,
           -3.168890293323019,
           -3.171825258325009,
           -3.174760223326999,
           -3.177695188328989,
           -3.180630153330979,
           -3.183565118332969,
           -3.186500083334958,
           -3.1894350483369482,
           -3.1923700133389383,
           -3.1953049783409284,
           -3.1982399433429176,
           -3.2011749083449077,
           -3.204109873346898,
           -3.2070448383488874,
           -3.2099798033508775,
           -3.2129147683528676,
           -3.2158497333548572,
           -3.2187846983568473,
           -3.221719663358837,
           -3.2246546283608275,
           -3.2275895933628167,
           -3.230524558364807,
           -3.233459523366797,
           -3.2363944883687865,
           -3.2393294533707766,
           -3.2422644183727662,
           -3.245199383374756,
           -3.248134348376746,
           -3.2510693133787356,
           -3.2540042783807257,
           -3.256939243382716,
           -3.259874208384706,
           -3.262809173386696,
           -3.265744138388685,
           -3.2686791033906752,
           -3.2716140683926653,
           -3.2745490333946545,
           -3.2774839983966446,
           -3.280418963398635,
           -3.283353928400625,
           -3.2862888934026144,
           -3.289223858404605,
           -3.2921588234065946,
           -3.2950937884085842,
           -3.298030842138875,
           -3.3009720733257657,
           -3.3039133045126565,
           -3.3068545356995482,
           -3.309795766886439,
           -3.3127369980733303,
           -3.3156782292602216,
           -3.3186194604471133,
           -3.321560691634004,
           -3.324501922820895,
           -3.3274431540077867,
           -3.3303843851946775,
           -3.3333256163815683,
           -3.3362668475684596,
           -3.3392080787553504,
           -3.3421493099422417,
           -3.3450905411291325,
           -3.3480317723160242,
           -3.350973003502915,
           -3.3539142346898063,
           -3.3568554658766976,
           -3.359796697063589,
           -3.36273792825048,
           -3.3656791594373714,
           -3.3686203906242618,
           -3.3715616218111526,
           -3.3745028529980443,
           -3.3774440841849356,
           -3.380385315371827,
           -3.383326546558718,
           -3.3862677777456094,
           -3.3892090089324998,
           -3.392150240119391,
           -3.3950914713062827,
           -3.398032702493174,
           -3.4009739336800644,
           -3.403915164866956,
           -3.4068563960538474,
           -3.4097976272407386,
           -3.41273885842763,
           -3.4156800896145203,
           -3.4186213208014116,
           -3.421562551988303,
           -3.424503783175194,
           -3.4274450143620854,
           -3.430386245548976,
           -3.433327476735868,
           -3.4362687079227587,
           -3.439209939109649,
           -3.4421511702965404,
           -3.445092401483432,
           -3.448033632670323,
           -3.450974863857214,
           -3.4539160950441055,
           -3.4568573262309963,
           -3.4597985574178876,
           -3.462739788604779,
           -3.46568101979167,
           -3.468622250978561,
           -3.471563482165452,
           -3.474504713352344,
           -3.4774459445392347,
           -3.480387175726126,
           -3.4833284069130173,
           -3.4862696380999076,
           -3.489210869286799,
           -3.49215210047369,
           -3.4950933316605814,
           -3.4980345628474727,
           -3.499164319126825,
           -3.5001342317509607,
           -3.5011041443750974,
           -3.5020740569992337,
           -3.5030439696233695,
           -3.5040138822475053,
           -3.504983794871641,
           -3.505953707495777,
           -3.5069236201199128,
           -3.5078935327440486,
           -3.508863445368185,
           -3.5098333579923207,
           -3.5108032706164565,
           -3.5117731832405927,
           -3.510979930608227,
           -3.501370851693359,
           -3.4917617727784904,
           -3.4821526938636223,
           -3.4725436149487554,
           -3.4630892620987237,
           -3.454007977278649,
           -3.444926692458576,
           -3.435845407638502,
           -3.426764122818427,
           -3.4176828379983544,
           -3.4086015531782796,
           -3.3995202683582053,
           -3.390438983538131,
           -3.3813576987180576,
           -3.3722764138979837,
           -3.363195129077909,
           -3.3541138442578355,
           -3.3450325594377617,
           -3.335951274617687,
           -3.326869989797614,
           -3.317788704977539,
           -3.3087074201574653,
           -3.299626135337392,
           -3.2905448505173176,
           -3.281463565697243,
           -3.2723822808771685,
           -3.2633009960570956,
           -3.254219711237021,
           -3.2451384264169465,
           -3.2360571415968735,
           -3.2269758567767988,
           -3.2178945719567245,
           -3.208813287136652,
           -3.199732002316577,
           -3.1906507174965024,
           -3.181569432676428,
           -3.172488147856355,
           -3.163406863036281,
           -3.154325578216206,
           -3.145244293396133,
           -3.1361630085760583,
           -3.123064206022643,
           -3.1070957479454164,
           -3.0911272898681865,
           -3.0751588317909566,
           -3.05919037371373,
           -3.043221915636501,
           -3.027253457559271,
           -3.011284999482041,
           -2.9953165414048146,
           -2.9793480833275847,
           -2.963379625250355,
           -2.947411167173129,
           -2.931442709095899,
           -2.9154742510186695,
           -2.8995057929414427,
           -2.883537334864213,
           -2.867568876786983,
           -2.8516004187097534,
           -2.835631960632527,
           -2.819663502555297,
           -2.8036950444780677,
           -2.787726586400841,
           -2.7717581283236115,
           -2.755789670246382,
           -2.7398212121691543,
           -2.7238527540919253,
           -2.707884296014696,
           -2.691915837937469,
           -2.675947379860239,
           -2.6599789217830097,
           -2.64401046370578,
           -2.6280420056285534,
           -2.6120735475513235,
           -2.5961050894740936,
           -2.5801366313968677,
           -2.5641681733196378,
           -2.548199715242408,
           -2.5360271462736494,
           -2.5244042442847388,
           -2.512781342295828,
           -2.5011584403069174,
           -2.4895355383180084
          ],
          [
           -1.676677121976143,
           -1.6805087011517545,
           -1.6843402803273666,
           -1.6881718595029784,
           -1.69200343867859,
           -1.6958350178542019,
           -1.6996665970298137,
           -1.7034981762054255,
           -1.7073297553810372,
           -1.7111613345566492,
           -1.714992913732261,
           -1.7188244929078726,
           -1.7226560720834847,
           -1.7264876512590963,
           -1.7303192304347081,
           -1.73415080961032,
           -1.7379823887859316,
           -1.7418139679615436,
           -1.7456455471371553,
           -1.749477126312767,
           -1.753308705488379,
           -1.7571402846639907,
           -1.7609718638396026,
           -1.7648034430152144,
           -1.7686350221908262,
           -1.7724666013664379,
           -1.77629818054205,
           -1.7801297597176615,
           -1.7839613388932734,
           -1.787792918068885,
           -1.7916244972444968,
           -1.7954560764201088,
           -1.7992876555957205,
           -1.8031192347713323,
           -1.8069508139469441,
           -1.810782393122556,
           -1.8146139722981678,
           -1.8184455514737796,
           -1.8222771306493915,
           -1.8261087098250033,
           -1.8299402890006151,
           -1.8337718681762267,
           -1.8376034473518388,
           -1.8414350265274502,
           -1.845266605703062,
           -1.849098184878674,
           -1.8529297640542857,
           -1.856761343229898,
           -1.8605929224055093,
           -1.8644245015811212,
           -1.868256080756733,
           -1.8720876599323448,
           -1.8759192391079567,
           -1.8797508182835685,
           -1.8835823974591803,
           -1.8874139766347922,
           -1.8912455558104038,
           -1.8950771349860158,
           -1.8989087141616274,
           -1.9027402933372393,
           -1.9065718725128509,
           -1.910403451688463,
           -1.9142350308640748,
           -1.9180666100396864,
           -1.9218981892152982,
           -1.92572976839091,
           -1.9295613475665216,
           -1.9333929267421335,
           -1.9372245059177455,
           -1.9410560850933574,
           -1.944887664268969,
           -1.9487192434445806,
           -1.9525508226201926,
           -1.9563824017958045,
           -1.960213980971416,
           -1.9640455601470281,
           -1.9678771393226397,
           -1.9717087184982516,
           -1.9755402976738634,
           -1.9793718768494752,
           -1.9832034560250873,
           -1.983824186934027,
           -1.984444913881054,
           -1.9850656408280818,
           -1.9849108203923245,
           -1.9846008904800108,
           -1.984290960567697,
           -1.9859066073523342,
           -1.9884850371394693,
           -1.9910634669266039,
           -1.993641896713739,
           -1.996220326500874,
           -1.998798756288009,
           -2.001377186075144,
           -2.003955615862279,
           -2.006534045649414,
           -2.009112475436549,
           -2.0116909052236838,
           -2.014269335010819,
           -2.016847764797954,
           -2.0194261945850887,
           -2.022004624372224,
           -2.024583054159359,
           -2.027161483946494,
           -2.0297399137336285,
           -2.032318343520764,
           -2.0348967733078984,
           -2.0374752030950334,
           -2.040053632882169,
           -2.0426320626693037,
           -2.0452104924564383,
           -2.0477889222435737,
           -2.0503673520307086,
           -2.0529457818178436,
           -2.0555242116049786,
           -2.0581026413921135,
           -2.0606810711792485,
           -2.0632595009663834,
           -2.0658379307535184,
           -2.0684163605406534,
           -2.0709947903277883,
           -2.0735732201149233,
           -2.0761516499020582,
           -2.078730079689193,
           -2.081308509476328,
           -2.083886939263463,
           -2.086465369050598,
           -2.089043798837733,
           -2.0916222286248676,
           -2.094200658412003,
           -2.0967790881991384,
           -2.099357517986273,
           -2.1019359477734083,
           -2.104514377560543,
           -2.1070928073476782,
           -2.1096712371348127,
           -2.1122496669219477,
           -2.1148280967090827,
           -2.117406526496218,
           -2.119984956283353,
           -2.1225633860704876,
           -2.1251418158576225,
           -2.1277202456447575,
           -2.1302986754318924,
           -2.132877105219028,
           -2.1354555350061624,
           -2.1380339647932978,
           -2.1406123945804327,
           -2.1431908243675677,
           -2.1457692541547027,
           -2.1483476839418376,
           -2.1509261137289726,
           -2.1535045435161075,
           -2.1560829733032425,
           -2.1586614030903775,
           -2.1612398328775124,
           -2.1638182626646474,
           -2.1663966924517823,
           -2.1689751222389173,
           -2.1715535520260523,
           -2.1741319818131872,
           -2.1767104116003226,
           -2.179288841387457,
           -2.181867271174592,
           -2.184445700961727,
           -2.1870241307488625,
           -2.189602560535997,
           -2.1902850207508564,
           -2.190019496179578,
           -2.1897539716082997,
           -2.189488447037021,
           -2.191126435294563,
           -2.1934694231963983,
           -2.195812411098233,
           -2.1981553990000684,
           -2.200498386901903,
           -2.202841374803738,
           -2.205184362705573,
           -2.207527350607408,
           -2.2098703385092424,
           -2.212213326411077,
           -2.2145563143129126,
           -2.216899302214747,
           -2.2192422901165823,
           -2.2215852780184173,
           -2.223928265920252,
           -2.2262712538220866,
           -2.2286142417239216,
           -2.2309572296257567,
           -2.2333002175275913,
           -2.2356432054294264,
           -2.237986193331261,
           -2.240329181233096,
           -2.242672169134931,
           -2.245015157036766,
           -2.247358144938601,
           -2.2497011328404355,
           -2.252044120742271,
           -2.2543871086441056,
           -2.2567300965459403,
           -2.2590730844477753,
           -2.26141607234961,
           -2.263759060251445,
           -2.2661020481532796,
           -2.2684450360551147,
           -2.27078802395695,
           -2.2731310118587844,
           -2.2754739997606195,
           -2.2778169876624546,
           -2.280159975564289,
           -2.282502963466124,
           -2.284845951367959,
           -2.287188939269794,
           -2.2895319271716286,
           -2.2918749150734636,
           -2.2942179029752987,
           -2.2965608908771333,
           -2.2989038787789684,
           -2.3012468666808035,
           -2.303589854582638,
           -2.305932842484473,
           -2.308275830386308,
           -2.310618818288143,
           -2.312961806189978,
           -2.3153047940918126,
           -2.3176477819936476,
           -2.3199907698954823,
           -2.3223337577973173,
           -2.324676745699152,
           -2.327019733600987,
           -2.329362721502822,
           -2.3317057094046567,
           -2.334048697306492,
           -2.336391685208327,
           -2.3387346731101615,
           -2.3410776610119965,
           -2.343420648913831,
           -2.345763636815666,
           -2.348106624717501,
           -2.350449612619336,
           -2.352792600521171,
           -2.3551355884230056,
           -2.3574785763248407,
           -2.3598215642266753,
           -2.362164552128511,
           -2.3645075400303455,
           -2.36685052793218,
           -2.369193515834015,
           -2.37153650373585,
           -2.373879491637685,
           -2.376195087002773,
           -2.3784832898311152,
           -2.380771492659458,
           -2.3830596954878005,
           -2.3853478983161427,
           -2.3876361011444844,
           -2.389924303972827,
           -2.3922125068011697,
           -2.3945007096295123,
           -2.396788912457854,
           -2.3990771152861967,
           -2.401365318114539,
           -2.403653520942881,
           -2.4059417237712237,
           -2.4082299265995664,
           -2.410518129427908,
           -2.4128063322562503,
           -2.4150945350845934,
           -2.4173827379129356,
           -2.4196709407412778,
           -2.42195914356962,
           -2.424247346397962,
           -2.4265355492263048,
           -2.4288237520546474,
           -2.43111195488299,
           -2.433400157711332,
           -2.435688360539674,
           -2.4379765633680166,
           -2.4402647661963592,
           -2.442552969024701,
           -2.4448411718530436,
           -2.447129374681386,
           -2.4494175775097284,
           -2.4517057803380706,
           -2.4539939831664133,
           -2.4562821859947555,
           -2.4585703888230976,
           -2.4608585916514403,
           -2.463146794479782,
           -2.4654349973081247,
           -2.4677232001364677,
           -2.4700114029648095,
           -2.4722996057931517,
           -2.4745878086214943,
           -2.4768760114498365,
           -2.479164214278179,
           -2.481851889803134,
           -2.4847868548051237,
           -2.4877218198071134,
           -2.4906567848091035,
           -2.4935917498110935,
           -2.4965267148130836,
           -2.499461679815073,
           -2.502396644817063,
           -2.505331609819053,
           -2.508266574821043,
           -2.5112015398230327,
           -2.514136504825023,
           -2.5170714698270125,
           -2.520006434829002,
           -2.5229413998309926,
           -2.525876364832982,
           -2.528811329834972,
           -2.531746294836962,
           -2.534681259838952,
           -2.5376162248409417,
           -2.5405511898429314,
           -2.5434861548449215,
           -2.546421119846911,
           -2.549356084848901,
           -2.5522910498508913,
           -2.555226014852881,
           -2.5581609798548706,
           -2.561095944856861,
           -2.5640309098588507,
           -2.5669658748608404,
           -2.5699008398628305,
           -2.5728358048648206,
           -2.57577076986681,
           -2.5787057348688,
           -2.58164069987079,
           -2.58457566487278,
           -2.5875106298747697,
           -2.59044768360506,
           -2.593388914791951,
           -2.5963301459788424,
           -2.599271377165733,
           -2.6022126083526245,
           -2.6051538395395157,
           -2.6080950707264066,
           -2.6110363019132983,
           -2.613977533100189,
           -2.6169187642870804,
           -2.6198599954739716,
           -2.6228012266608625,
           -2.6257424578477537,
           -2.628683689034645,
           -2.631624920221536,
           -2.634566151408427,
           -2.6375073825953184,
           -2.640049022775638,
           -2.641018935399774,
           -2.64198884802391,
           -2.642958760648046,
           -2.643928673272182,
           -2.644898585896318,
           -2.645868498520454,
           -2.6468384111445897,
           -2.6478083237687255,
           -2.648778236392862,
           -2.6497481490169976,
           -2.6507180616411334,
           -2.6516879742652693,
           -2.652657886889405,
           -2.653627799513541,
           -2.6545977121376767,
           -2.6555676247618134,
           -2.656537537385949,
           -2.6575074500100846,
           -2.658477362634221,
           -2.6594472752583567,
           -2.6604171878824925,
           -2.6613871005066283,
           -2.6623570131307646,
           -2.6633269257549004,
           -2.6642968383790366,
           -2.6652667510031725,
           -2.6662366636273083,
           -2.667206576251444,
           -2.66817648887558,
           -2.669146401499716,
           -2.6701163141238515,
           -2.671086226747988,
           -2.6720561393721236,
           -2.6730260519962594,
           -2.6739959646203957,
           -2.6749658772445315,
           -2.6759357898686673,
           -2.6769057024928036,
           -2.6778756151169394,
           -2.678845527741075,
           -2.679815440365211,
           -2.6807853529893473,
           -2.681755265613483,
           -2.682725178237619,
           -2.683695090861755,
           -2.6846650034858905,
           -2.6856349161100264,
           -2.6866048287341626,
           -2.6875747413582984,
           -2.6885446539824343,
           -2.6895145666065705,
           -2.6904844792307063,
           -2.691454391854842,
           -2.6924243044789784,
           -2.693394217103114,
           -2.69436412972725,
           -2.6953340423513863,
           -2.6963039549755217,
           -2.697273867599658,
           -2.6982437802237937,
           -2.6992136928479296,
           -2.700183605472066,
           -2.7011535180962016,
           -2.7021234307203374,
           -2.7030933433444737,
           -2.7023000907121086,
           -2.69269101179724,
           -2.683081932882372,
           -2.6734728539675032,
           -2.6638637750526364,
           -2.6542546961377687,
           -2.6446456172229,
           -2.6350365383080336,
           -2.6254274593931655,
           -2.615818380478297,
           -2.6062093015634304,
           -2.5966002226485623,
           -2.5869911437336937,
           -2.5773820648188255,
           -2.5677729859039586,
           -2.5581639069890905,
           -2.5485548280742223,
           -2.5389457491593554,
           -2.529336670244487,
           -2.5197275913296187,
           -2.5101185124147523,
           -2.500509433499884,
           -2.4910857113096405,
           -2.4820044264895675,
           -2.4729231416694932,
           -2.4638418568494185,
           -2.4547605720293437,
           -2.445679287209271,
           -2.4365980023891964,
           -2.427516717569122,
           -2.418435432749049,
           -2.4093541479289744,
           -2.4002728631089,
           -2.391191578288827,
           -2.3821102934687524,
           -2.373029008648678,
           -2.3639477238286037,
           -2.3548664390085308,
           -2.345785154188456,
           -2.3367038693683817,
           -2.3276225845483083,
           -2.318541299728234,
           -2.3054424971748184,
           -2.2894740390975916,
           -2.273505581020362,
           -2.2575371229431322,
           -2.2415686648659054,
           -2.225600206788676,
           -2.2096317487114465,
           -2.1936632906342166,
           -2.1776948325569903,
           -2.161726374479761,
           -2.1457579164025304,
           -2.129789458325304,
           -2.1138210002480746,
           -2.0978525421708447,
           -2.0818840840936184,
           -2.0659156260163885,
           -2.049947167939159,
           -2.0339787098619295,
           -2.0180102517847027,
           -2.002041793707473,
           -1.9896170293249171,
           -1.9779941273360089,
           -1.966371225347098,
           -1.9547483233581873,
           -1.9431254213692783,
           -1.9315025193803677,
           -1.9198796173914567,
           -1.9082567154025478,
           -1.8966338134136373,
           -1.8850109114247264,
           -1.873388009435816,
           -1.861765107446907,
           -1.8501422054579963,
           -1.8385193034690859,
           -1.8268964014801767,
           -1.815273499491266,
           -1.8036505975023556,
           -1.7920276955134469,
           -1.780404793524536,
           -1.768781891535625,
           -1.7571589895467143,
           -1.7455360875578056
          ],
          [
           -1.195430800254592,
           -1.1992623794302038,
           -1.2030939586058158,
           -1.2069255377814274,
           -1.2107571169570392,
           -1.214588696132651,
           -1.218420275308263,
           -1.2222518544838747,
           -1.2260834336594864,
           -1.2299150128350984,
           -1.2337465920107098,
           -1.2375781711863216,
           -1.2414097503619337,
           -1.2452413295375453,
           -1.2490729087131571,
           -1.252904487888769,
           -1.2567360670643808,
           -1.2605676462399924,
           -1.2643992254156045,
           -1.2682308045912163,
           -1.272062383766828,
           -1.2758939629424397,
           -1.2797255421180516,
           -1.2835571212936634,
           -1.2873887004692752,
           -1.2912202796448868,
           -1.2950518588204987,
           -1.2988834379961105,
           -1.3027150171717223,
           -1.3065465963473342,
           -1.310378175522946,
           -1.3142097546985578,
           -1.3180413338741697,
           -1.3218729130497815,
           -1.3257044922253933,
           -1.3295360714010052,
           -1.333367650576617,
           -1.3371992297522286,
           -1.3410308089278404,
           -1.3448623881034523,
           -1.348693967279064,
           -1.3525255464546757,
           -1.3563571256302878,
           -1.3601887048058994,
           -1.3640202839815112,
           -1.367851863157123,
           -1.3716834423327349,
           -1.375515021508347,
           -1.3793466006839585,
           -1.3831781798595704,
           -1.387009759035182,
           -1.390841338210794,
           -1.3946729173864059,
           -1.3985044965620175,
           -1.4023360757376295,
           -1.4061676549132411,
           -1.409999234088853,
           -1.413830813264465,
           -1.4176623924400766,
           -1.4214939716156882,
           -1.4253255507913,
           -1.4291571299669121,
           -1.4329887091425237,
           -1.4368202883181356,
           -1.4390464448115776,
           -1.439667171758605,
           -1.4402878987056322,
           -1.4409086256526595,
           -1.4415293525996868,
           -1.4421500795467144,
           -1.4427708064937417,
           -1.443391533440769,
           -1.4440122603877963,
           -1.4446329873348236,
           -1.445253714281851,
           -1.4458744412288784,
           -1.4464951681759057,
           -1.4471158951229328,
           -1.4477366220699606,
           -1.4483573490169876,
           -1.4489780759640152,
           -1.4495988029110425,
           -1.4502195298580698,
           -1.4508402568050973,
           -1.4506854363693402,
           -1.4503755064570265,
           -1.4500655765447128,
           -1.4497556466323993,
           -1.4494457167200856,
           -1.4491357868077719,
           -1.4488258568954582,
           -1.4485159269831445,
           -1.448205997070831,
           -1.4478960671585173,
           -1.4475861372462038,
           -1.44727620733389,
           -1.4469662774215766,
           -1.4466563475092626,
           -1.4463464175969492,
           -1.4460364876846354,
           -1.445726557772322,
           -1.4454166278600082,
           -1.4451066979476945,
           -1.445278164406028,
           -1.447856594193163,
           -1.4504350239802979,
           -1.4530134537674328,
           -1.4555918835545678,
           -1.458170313341703,
           -1.460748743128838,
           -1.4633271729159727,
           -1.4659056027031079,
           -1.4684840324902426,
           -1.4710624622773778,
           -1.4736408920645128,
           -1.4762193218516477,
           -1.478797751638783,
           -1.4813761814259174,
           -1.4839546112130526,
           -1.4865330410001878,
           -1.4891114707873225,
           -1.4916899005744577,
           -1.4942683303615927,
           -1.4968467601487276,
           -1.4994251899358626,
           -1.5020036197229976,
           -1.5045820495101325,
           -1.5071604792972675,
           -1.5097389090844024,
           -1.5123173388715374,
           -1.5148957686586724,
           -1.5174741984458073,
           -1.5200526282329423,
           -1.5226310580200773,
           -1.5252094878072122,
           -1.5277879175943472,
           -1.5303663473814821,
           -1.532944777168617,
           -1.5355232069557523,
           -1.5381016367428872,
           -1.5406800665300222,
           -1.543258496317157,
           -1.5458369261042921,
           -1.5484153558914269,
           -1.5509937856785623,
           -1.5535722154656968,
           -1.5561506452528322,
           -1.558729075039967,
           -1.561307504827102,
           -1.563885934614237,
           -1.566464364401372,
           -1.569042794188507,
           -1.5716212239756417,
           -1.5741996537627767,
           -1.5767780835499117,
           -1.5793565133370466,
           -1.5819349431241816,
           -1.5845133729113168,
           -1.5870918026984517,
           -1.5896702324855865,
           -1.5922486622727217,
           -1.5948270920598566,
           -1.5974055218469916,
           -1.5999839516341265,
           -1.6025623814212615,
           -1.6051408112083967,
           -1.6077192409955314,
           -1.6084017012103906,
           -1.6081361766391125,
           -1.6078706520678339,
           -1.6076051274965553,
           -1.607339602925277,
           -1.6070740783539983,
           -1.6068085537827197,
           -1.606543029211441,
           -1.606277504640163,
           -1.6060119800688841,
           -1.6057464554976058,
           -1.6054809309263274,
           -1.6052154063550486,
           -1.60494988178377,
           -1.6046843572124916,
           -1.604418832641213,
           -1.6041533080699344,
           -1.6038877834986558,
           -1.6036222589273774,
           -1.6033567343560988,
           -1.60309120978482,
           -1.602825685213542,
           -1.6025601606422635,
           -1.6022946360709849,
           -1.60259311595657,
           -1.6049361038584051,
           -1.60727909176024,
           -1.609622079662075,
           -1.61196506756391,
           -1.6143080554657447,
           -1.6166510433675798,
           -1.6189940312694144,
           -1.621337019171249,
           -1.6236800070730844,
           -1.6260229949749194,
           -1.6283659828767543,
           -1.6307089707785891,
           -1.6330519586804235,
           -1.6353949465822586,
           -1.6377379344840937,
           -1.6400809223859287,
           -1.6424239102877634,
           -1.6447668981895982,
           -1.6471098860914333,
           -1.649452873993268,
           -1.651795861895103,
           -1.6541388497969378,
           -1.6564818376987727,
           -1.6588248256006075,
           -1.6611678135024426,
           -1.6635108014042774,
           -1.6658537893061123,
           -1.6681967772079473,
           -1.670539765109782,
           -1.672882753011617,
           -1.6752257409134517,
           -1.6775687288152867,
           -1.6799117167171218,
           -1.6822547046189564,
           -1.6845976925207915,
           -1.6869406804226261,
           -1.6892836683244612,
           -1.691626656226296,
           -1.693969644128131,
           -1.6963126320299657,
           -1.6986556199318006,
           -1.7009986078336359,
           -1.7033415957354707,
           -1.7056845836373056,
           -1.7080275715391402,
           -1.7103705594409753,
           -1.7127135473428101,
           -1.715056535244645,
           -1.71739952314648,
           -1.7197425110483149,
           -1.7220854989501497,
           -1.7244284868519844,
           -1.7267714747538194,
           -1.729114462655654,
           -1.7314574505574893,
           -1.733800438459324,
           -1.736143426361159,
           -1.7384864142629939,
           -1.7408020096280823,
           -1.743090212456425,
           -1.7453784152847673,
           -1.7476666181131095,
           -1.7499548209414522,
           -1.7522430237697944,
           -1.7545312265981365,
           -1.756819429426479,
           -1.7591076322548214,
           -1.7613958350831636,
           -1.7636840379115062,
           -1.7659722407398486,
           -1.7682604435681908,
           -1.7705486463965328,
           -1.7728368492248756,
           -1.7751250520532178,
           -1.7774132548815598,
           -1.7797014577099024,
           -1.7819896605382446,
           -1.7842778633665872,
           -1.7865660661949294,
           -1.7888542690232718,
           -1.791142471851614,
           -1.7934306746799564,
           -1.7957188775082988,
           -1.7980070803366413,
           -1.8002952831649837,
           -1.802583485993326,
           -1.8048716888216683,
           -1.8071598916500105,
           -1.8094480944783529,
           -1.8117362973066955,
           -1.8140245001350375,
           -1.8163127029633799,
           -1.8186009057917225,
           -1.8208891086200645,
           -1.823177311448407,
           -1.8254655142767493,
           -1.8277537171050917,
           -1.8300419199334341,
           -1.8323301227617765,
           -1.834618325590119,
           -1.836906528418461,
           -1.8391947312468035,
           -1.841482934075146,
           -1.8437711369034882,
           -1.8460593397318303,
           -1.848347542560173,
           -1.8506357453885152,
           -1.8529239482168576,
           -1.8552121510452,
           -1.8575003538735422,
           -1.8597885567018846,
           -1.8620767595302268,
           -1.8643649623585694,
           -1.8666531651869114,
           -1.868941368015254,
           -1.8712295708435966,
           -1.8735177736719386,
           -1.875805976500281,
           -1.8780941793286234,
           -1.8803823821569658,
           -1.8826705849853078,
           -1.8849587878136502,
           -1.8872469906419924,
           -1.8895351934703348,
           -1.8918233962986772,
           -1.8940145272371822,
           -1.8931770771198972,
           -1.8923396270026125,
           -1.8915021768853268,
           -1.8906647267680416,
           -1.8898272766507567,
           -1.8889898265334717,
           -1.8881523764161867,
           -1.8873149262989017,
           -1.8864774761816165,
           -1.8856400260643316,
           -1.8848025759470466,
           -1.8839651258297616,
           -1.8831276757124766,
           -1.8822902255951914,
           -1.8814527754779062,
           -1.88072781938949,
           -1.8802278513588124,
           -1.8797278833281346,
           -1.8792279152974565,
           -1.8787279472667788,
           -1.8782279792361007,
           -1.8777280112054229,
           -1.8772280431747448,
           -1.8767280751440674,
           -1.8762281071133893,
           -1.8757281390827114,
           -1.8752281710520335,
           -1.8747282030213557,
           -1.8742282349906778,
           -1.8737282669599997,
           -1.8732282989293223,
           -1.872728330898644,
           -1.8722283628679666,
           -1.8717283948372883,
           -1.8712284268066104,
           -1.8707284587759325,
           -1.8702284907452547,
           -1.8697285227145768,
           -1.869228554683899,
           -1.868728586653221,
           -1.8682286186225432,
           -1.8677286505918653,
           -1.8672286825611872,
           -1.8667287145305096,
           -1.8662287464998315,
           -1.8657287784691536,
           -1.8652288104384758,
           -1.8647288424077977,
           -1.86422887437712,
           -1.863728906346442,
           -1.8632289383157645,
           -1.8627289702850862,
           -1.8622290022544088,
           -1.8617290342237305,
           -1.8612290661930526,
           -1.8607290981623748,
           -1.8602291301316967,
           -1.8597291621010186,
           -1.859229194070341,
           -1.858729226039663,
           -1.8585267363553406,
           -1.8594966489794764,
           -1.8604665616036122,
           -1.861436474227748,
           -1.8624063868518843,
           -1.8633762994760201,
           -1.864346212100156,
           -1.8653161247242922,
           -1.866286037348428,
           -1.8672559499725638,
           -1.8682258625967,
           -1.869195775220836,
           -1.8701656878449717,
           -1.8711356004691075,
           -1.8721055130932436,
           -1.8730754257173796,
           -1.8740453383415154,
           -1.8750152509656515,
           -1.8759851635897873,
           -1.876955076213923,
           -1.8779249888380591,
           -1.878894901462195,
           -1.879864814086331,
           -1.8808347267104666,
           -1.8818046393346028,
           -1.8827745519587387,
           -1.8837444645828745,
           -1.8847143772070107,
           -1.8856842898311466,
           -1.8866542024552824,
           -1.8876241150794184,
           -1.8885940277035544,
           -1.88956394032769,
           -1.8905338529518263,
           -1.8915037655759621,
           -1.892473678200098,
           -1.8934435908242337,
           -1.8944135034483698,
           -1.893620250816005,
           -1.8840111719011368,
           -1.8744020929862684,
           -1.8647930140714,
           -1.8551839351565333,
           -1.8455748562416652,
           -1.8359657773267968,
           -1.82635669841193,
           -1.8167476194970615,
           -1.8071385405821934,
           -1.797529461667327,
           -1.7879203827524586,
           -1.77831130383759,
           -1.7687022249227216,
           -1.7590931460078554,
           -1.749484067092987,
           -1.7398749881781184,
           -1.730265909263252,
           -1.7206568303483833,
           -1.7110477514335152,
           -1.7014386725186488,
           -1.6918295936037802,
           -1.682220514688912,
           -1.6726114357740456,
           -1.663002356859177,
           -1.6533932779443086,
           -1.6437841990294402,
           -1.6341751201145738,
           -1.6245660411997054,
           -1.614956962284837,
           -1.6053478833699704,
           -1.5957388044551022,
           -1.5861297255402338,
           -1.5765206466253672,
           -1.5669115677104988,
           -1.5573024887956306,
           -1.5476934098807622,
           -1.5380843309658956,
           -1.528475252051027,
           -1.5190821605205729,
           -1.5100008757005,
           -1.5009195908804256,
           -1.48782078832701,
           -1.471852330249783,
           -1.4558838721725536,
           -1.443206912376202,
           -1.4315840103872934,
           -1.4199611083983823,
           -1.408338206409472,
           -1.3967153044205611,
           -1.3850924024316522,
           -1.3734695004427413,
           -1.3618465984538306,
           -1.3502236964649221,
           -1.3386007944760112,
           -1.3269778924871005,
           -1.3153549904981918,
           -1.303732088509281,
           -1.2921091865203702,
           -1.2804862845314593,
           -1.2688633825425506,
           -1.2572404805536397,
           -1.245617578564729,
           -1.2339946765758203,
           -1.2223717745869096,
           -1.2107488725979987,
           -1.19912597060909,
           -1.1875030686201793,
           -1.1758801666312686,
           -1.1642572646423597,
           -1.152634362653449,
           -1.1410114606645383,
           -1.1293885586756276,
           -1.1177656566867187,
           -1.106142754697808,
           -1.094519852708897,
           -1.0828969507199884,
           -1.0712740487310777,
           -1.059651146742167,
           -1.048028244753258,
           -1.0364053427643474,
           -1.0247824407754367,
           -1.0131595387865258,
           -1.001536636797617
          ],
          [
           -0.7141844785330318,
           -0.7180160577086437,
           -0.7218476368842554,
           -0.7256792160598673,
           -0.7295107952354789,
           -0.7333423744110908,
           -0.7371739535867028,
           -0.7410055327623144,
           -0.7448371119379262,
           -0.7486686911135382,
           -0.7525002702891499,
           -0.7563318494647617,
           -0.7601634286403736,
           -0.7639950078159853,
           -0.7678265869915972,
           -0.7716581661672091,
           -0.7754897453428207,
           -0.7793213245184325,
           -0.7831529036940443,
           -0.7869844828696562,
           -0.7908160620452678,
           -0.7946476412208798,
           -0.7984792203964914,
           -0.8023107995721033,
           -0.8061423787477152,
           -0.8099739579233269,
           -0.8138055370989388,
           -0.8176371162745506,
           -0.8214686954501624,
           -0.8253002746257742,
           -0.8291318538013859,
           -0.8329634329769977,
           -0.8367950121526095,
           -0.8406265913282214,
           -0.8444581705038332,
           -0.848289749679445,
           -0.8521213288550568,
           -0.8559529080306686,
           -0.8597844872062804,
           -0.8636160663818923,
           -0.8674476455575039,
           -0.8712792247331158,
           -0.8751108039087276,
           -0.8789423830843394,
           -0.8827739622599512,
           -0.8866055414355629,
           -0.8904371206111749,
           -0.8942686997867866,
           -0.8948894296361453,
           -0.8955101565831727,
           -0.8961308835302,
           -0.8967516104772273,
           -0.8973723374242547,
           -0.8979930643712821,
           -0.8986137913183094,
           -0.8992345182653367,
           -0.8998552452123642,
           -0.9004759721593916,
           -0.9010966991064189,
           -0.9017174260534462,
           -0.9023381530004736,
           -0.9029588799475009,
           -0.9035796068945283,
           -0.9042003338415556,
           -0.9048210607885829,
           -0.9054417877356103,
           -0.9060625146826377,
           -0.9066832416296651,
           -0.9073039685766924,
           -0.9079246955237197,
           -0.9085454224707471,
           -0.9091661494177744,
           -0.9097868763648018,
           -0.9104076033118291,
           -0.9110283302588564,
           -0.911649057205884,
           -0.9122697841529113,
           -0.9128905110999386,
           -0.9135112380469659,
           -0.9141319649939933,
           -0.9147526919410207,
           -0.915373418888048,
           -0.9159941458350753,
           -0.9166148727821026,
           -0.9164600523463459,
           -0.9161501224340323,
           -0.9158401925217186,
           -0.9155302626094048,
           -0.9152203326970912,
           -0.9149104027847776,
           -0.9146004728724639,
           -0.9142905429601502,
           -0.9139806130478365,
           -0.9136706831355229,
           -0.9133607532232093,
           -0.9130508233108956,
           -0.9127408933985819,
           -0.9124309634862683,
           -0.9121210335739547,
           -0.911811103661641,
           -0.9115011737493273,
           -0.9111912438370137,
           -0.9108813139247,
           -0.9105713840123864,
           -0.9102614541000726,
           -0.9099515241877589,
           -0.9096415942754453,
           -0.9093316643631317,
           -0.909021734450818,
           -0.9087118045385043,
           -0.9084018746261907,
           -0.9080919447138771,
           -0.9077820148015634,
           -0.9074720848892497,
           -0.9071621549769361,
           -0.9068522250646224,
           -0.9065422951523088,
           -0.9062323652399951,
           -0.9059224353276814,
           -0.9056125054153678,
           -0.9072281512468459,
           -0.9098065810339809,
           -0.9123850108211159,
           -0.914963440608251,
           -0.9175418703953858,
           -0.9201203001825208,
           -0.9226987299696559,
           -0.9252771597567907,
           -0.9278555895439256,
           -0.9304340193310607,
           -0.9330124491181956,
           -0.9355908789053307,
           -0.9381693086924655,
           -0.9407477384796006,
           -0.9433261682667355,
           -0.9459045980538705,
           -0.9484830278410055,
           -0.9510614576281404,
           -0.9536398874152756,
           -0.9562183172024106,
           -0.9587967469895453,
           -0.9613751767766803,
           -0.9639536065638152,
           -0.9665320363509502,
           -0.9691104661380854,
           -0.9716888959252203,
           -0.9742673257123553,
           -0.9768457554994903,
           -0.9794241852866252,
           -0.9820026150737603,
           -0.9845810448608953,
           -0.9871594746480302,
           -0.9897379044351652,
           -0.9923163342223,
           -0.9948947640094352,
           -0.99747319379657,
           -1.0000516235837051,
           -1.00263005337084,
           -1.0052084831579748,
           -1.0077869129451098,
           -1.010365342732245,
           -1.0129437725193797,
           -1.015522202306515,
           -1.0181006320936499,
           -1.0206790618807848,
           -1.0232574916679198,
           -1.0258359214550548,
           -1.026518381669914,
           -1.0262528570986356,
           -1.025987332527357,
           -1.0257218079560786,
           -1.0254562833848,
           -1.0251907588135216,
           -1.0249252342422426,
           -1.0246597096709644,
           -1.0243941850996858,
           -1.0241286605284072,
           -1.0238631359571286,
           -1.0235976113858503,
           -1.0233320868145717,
           -1.023066562243293,
           -1.022801037672015,
           -1.0225355131007363,
           -1.0222699885294577,
           -1.0220044639581793,
           -1.0217389393869007,
           -1.0214734148156221,
           -1.021207890244343,
           -1.020942365673065,
           -1.0206768411017864,
           -1.0204113165305078,
           -1.0201457919592294,
           -1.0198802673879508,
           -1.0196147428166722,
           -1.019349218245394,
           -1.0190836936741152,
           -1.0188181691028368,
           -1.018552644531558,
           -1.0182871199602799,
           -1.0180215953890013,
           -1.0177560708177222,
           -1.0174905462464443,
           -1.0172250216751655,
           -1.0169594971038871,
           -1.0166939725326085,
           -1.0164284479613297,
           -1.0161629233900513,
           -1.0158973988187727,
           -1.0156318742474943,
           -1.0153663496762158,
           -1.0151008251049372,
           -1.0148353005336588,
           -1.0164027845204,
           -1.0187457724222346,
           -1.0210887603240697,
           -1.0234317482259045,
           -1.0257747361277394,
           -1.0281177240295742,
           -1.0304607119314093,
           -1.032803699833244,
           -1.0351466877350788,
           -1.0374896756369139,
           -1.0398326635387487,
           -1.0421756514405836,
           -1.0445186393424186,
           -1.0468616272442537,
           -1.0492046151460883,
           -1.0515476030479234,
           -1.053890590949758,
           -1.0562335788515929,
           -1.058576566753428,
           -1.0609195546552628,
           -1.0632625425570976,
           -1.0656055304589327,
           -1.0679485183607675,
           -1.0702915062626022,
           -1.0726344941644372,
           -1.074977482066272,
           -1.077320469968107,
           -1.0796634578699418,
           -1.0820064457717768,
           -1.0843494336736117,
           -1.0866924215754465,
           -1.0890354094772816,
           -1.0913783973791162,
           -1.093721385280951,
           -1.096064373182786,
           -1.0984073610846208,
           -1.1007503489864559,
           -1.1030933368882907,
           -1.105408932253379,
           -1.1076971350817215,
           -1.109985337910064,
           -1.1122735407384061,
           -1.1145617435667488,
           -1.116849946395091,
           -1.1191381492234331,
           -1.1214263520517755,
           -1.1237145548801182,
           -1.1260027577084601,
           -1.1282909605368026,
           -1.1305791633651452,
           -1.1328673661934872,
           -1.1351555690218298,
           -1.137443771850172,
           -1.1397319746785144,
           -1.1420201775068566,
           -1.144308380335199,
           -1.1465965831635412,
           -1.1488847859918836,
           -1.1511729888202262,
           -1.1534611916485686,
           -1.1557493944769106,
           -1.158037597305253,
           -1.1603258001335957,
           -1.1626140029619378,
           -1.1649022057902803,
           -1.1671904086186227,
           -1.1694786114469649,
           -1.1717668142753073,
           -1.1740550171036495,
           -1.176343219931992,
           -1.178631422760334,
           -1.1809196255886765,
           -1.183207828417019,
           -1.185496031245361,
           -1.1877842340737035,
           -1.1900724369020461,
           -1.192360639730388,
           -1.1946488425587307,
           -1.1969370453870734,
           -1.1992252482154155,
           -1.2015134510437577,
           -1.2038016538721001,
           -1.2042066962233027,
           -1.2033692461060175,
           -1.2025317959887327,
           -1.2016943458714473,
           -1.200856895754162,
           -1.200019445636877,
           -1.1991819955195921,
           -1.198344545402307,
           -1.197507095285022,
           -1.196669645167737,
           -1.195832195050452,
           -1.1949947449331666,
           -1.1941572948158818,
           -1.1933198446985969,
           -1.1924823945813119,
           -1.1916449444640267,
           -1.1908074943467417,
           -1.1899700442294565,
           -1.1891325941121713,
           -1.1882951439948866,
           -1.1874576938776014,
           -1.1866202437603162,
           -1.1857827936430312,
           -1.184945343525746,
           -1.184107893408461,
           -1.183270443291176,
           -1.1824329931738906,
           -1.1815955430566056,
           -1.1807580929393207,
           -1.1799206428220357,
           -1.1790831927047505,
           -1.1782457425874655,
           -1.1774082924701805,
           -1.1765708423528956,
           -1.1757333922356104,
           -1.1748959421183254,
           -1.1740584920010402,
           -1.1732210418837554,
           -1.1723835917664702,
           -1.1716586356780545,
           -1.1711586676473764,
           -1.1706586996166988,
           -1.170158731586021,
           -1.169658763555343,
           -1.1691587955246652,
           -1.168658827493987,
           -1.1681588594633092,
           -1.1676588914326314,
           -1.1671589234019535,
           -1.1666589553712754,
           -1.1661589873405975,
           -1.1656590193099197,
           -1.1651590512792418,
           -1.1646590832485642,
           -1.1641591152178863,
           -1.1636591471872084,
           -1.1631591791565303,
           -1.1626592111258525,
           -1.1621592430951746,
           -1.1616592750644967,
           -1.1611593070338189,
           -1.160659339003141,
           -1.1601593709724631,
           -1.1596594029417853,
           -1.1591594349111074,
           -1.1586594668804295,
           -1.1581594988497517,
           -1.1576595308190736,
           -1.1571595627883957,
           -1.1566595947577176,
           -1.15615962672704,
           -1.1556596586963621,
           -1.155159690665684,
           -1.1546597226350062,
           -1.1541597546043285,
           -1.1536597865736504,
           -1.1531598185429728,
           -1.152659850512295,
           -1.1521598824816168,
           -1.151659914450939,
           -1.1511599464202609,
           -1.150659978389583,
           -1.1501600103589051,
           -1.149660042328227,
           -1.1491600742975494,
           -1.1486601062668713,
           -1.1481601382361937,
           -1.1476601702055158,
           -1.1471602021748377,
           -1.1466602341441599,
           -1.146160266113482,
           -1.1456602980828041,
           -1.1451603300521263,
           -1.1446603620214484,
           -1.1441603939907705,
           -1.1436604259600927,
           -1.1431604579294148,
           -1.1426604898987367,
           -1.142160521868059,
           -1.1416605538373812,
           -1.141160585806703,
           -1.1406606177760252,
           -1.1379636326652267,
           -1.1352198965551148,
           -1.1324761604450024,
           -1.1297324243348903,
           -1.1269886882247788,
           -1.1242449521146662,
           -1.121501216004554,
           -1.1187574798944422,
           -1.11601374378433,
           -1.113270007674218,
           -1.1105262715641062,
           -1.1077825354539939,
           -1.105038799343882,
           -1.1022950632337698,
           -1.0995513271236579,
           -1.0968075910135455,
           -1.0940638549034334,
           -1.0913201187933217,
           -1.0885763826832093,
           -1.0858326465730972,
           -1.0817289168297708,
           -1.07082521892037,
           -1.0599215210109691,
           -1.0490178231015683,
           -1.0381141251921693,
           -1.0272104272827685,
           -1.0163067293733676,
           -1.005403031463969,
           -0.9949824887187054,
           -0.9851329449923034,
           -0.9752834012659032,
           -0.9654338575395013,
           -0.9555843138130993,
           -0.9457347700866974,
           -0.9358852263602973,
           -0.9260356826338952,
           -0.9161861389074935,
           -0.9063365951810932,
           -0.8964870514546912,
           -0.8866375077282892,
           -0.8767879640018892,
           -0.8669384202754874,
           -0.8570888765490854,
           -0.8472393328226852,
           -0.8373897890962834,
           -0.8275402453698815,
           -0.8176907016434792,
           -0.8078411579170791,
           -0.7979916141906772,
           -0.7881420704642754,
           -0.7782925267378751,
           -0.7684429830114732,
           -0.7585934392850713,
           -0.7487438955586712,
           -0.7388943518322693,
           -0.7290448081058671,
           -0.7191952643794652,
           -0.7093457206530651,
           -0.6994961769266632,
           -0.6896466332002611,
           -0.679797089473861,
           -0.6699475457474591,
           -0.6595617294072459,
           -0.6487928612000269,
           -0.6380239929928058,
           -0.6272551247855847,
           -0.6164862565783659,
           -0.6057173883711445,
           -0.5949485201639234,
           -0.5841796519567025,
           -0.5734107837494833,
           -0.5626419155422622,
           -0.5518730473350412,
           -0.541104179127822,
           -0.5303353109206009,
           -0.5195664427133797,
           -0.5087975745061608,
           -0.4980287062989397,
           -0.4872598380917187,
           -0.47649096988449763,
           -0.4657221016772786,
           -0.4549532334700574,
           -0.44418436526283633,
           -0.4334154970556172,
           -0.4226466288483961,
           -0.4118777606411752,
           -0.401108892433956,
           -0.39034002422673497,
           -0.37957115601951374,
           -0.36880228781229474,
           -0.3580334196050737,
           -0.3472645513978526,
           -0.3364956831906315,
           -0.3257268149834124,
           -0.31495794677619127,
           -0.3041890785689702,
           -0.30080122568622697,
           -0.3004526306459371,
           -0.30010403560564725,
           -0.2997554405653575,
           -0.2994068455250678,
           -0.29905825048477813,
           -0.2987096554444884,
           -0.2983610604041987
          ],
          [
           -0.23293815681148067,
           -0.23676973598709256,
           -0.24060131516270433,
           -0.24443289433831614,
           -0.24826447351392789,
           -0.2520960526895397,
           -0.25592763186515144,
           -0.2597592110407633,
           -0.2635907902163751,
           -0.26742236939198727,
           -0.2712539485675991,
           -0.2750855277432108,
           -0.27891710691882265,
           -0.28274868609443443,
           -0.28658026527004626,
           -0.2904118444456581,
           -0.2942434236212698,
           -0.2980750027968816,
           -0.3019065819724935,
           -0.30573816114810526,
           -0.309569740323717,
           -0.3134013194993288,
           -0.31723289867494064,
           -0.3210644778505525,
           -0.3248960570261643,
           -0.32872763620177603,
           -0.33255921537738786,
           -0.3363907945529997,
           -0.34022237372861147,
           -0.3440539529042233,
           -0.347885532079835,
           -0.3501116875136959,
           -0.35073241446072323,
           -0.3513531414077506,
           -0.3519738683547779,
           -0.3525945953018053,
           -0.3532153222488326,
           -0.35383604919586004,
           -0.3544567761428874,
           -0.3550775030899147,
           -0.35569823003694206,
           -0.3563189569839694,
           -0.35693968393099684,
           -0.35756041087802415,
           -0.3581811378250515,
           -0.3588018647720789,
           -0.35942259171910607,
           -0.3600433186661337,
           -0.360664045613161,
           -0.36128477256018815,
           -0.36190549950721573,
           -0.36252622645424293,
           -0.36314695340127046,
           -0.36376768034829776,
           -0.36438840729532496,
           -0.3650091342423525,
           -0.3656298611893797,
           -0.36625058813640726,
           -0.36687131508343457,
           -0.3674920420304617,
           -0.36811276897748935,
           -0.36873349592451643,
           -0.369354222871544,
           -0.3699749498185714,
           -0.37059567676559857,
           -0.37121640371262593,
           -0.3718371306596533,
           -0.3724578576066807,
           -0.373078584553708,
           -0.3736993115007354,
           -0.37432003844776274,
           -0.37494076539479004,
           -0.3755614923418174,
           -0.3761822192888448,
           -0.3768029462358722,
           -0.37742367318289954,
           -0.37804440012992685,
           -0.3786651270769542,
           -0.3792858540239816,
           -0.379906580971009,
           -0.3805273079180363,
           -0.38114803486506366,
           -0.381768761812091,
           -0.3823894887591183,
           -0.3822346683233615,
           -0.38192473841104785,
           -0.3816148084987342,
           -0.38130487858642054,
           -0.3809949486741069,
           -0.3806850187617933,
           -0.38037508884947957,
           -0.38006515893716586,
           -0.37975522902485226,
           -0.3794452991125386,
           -0.3791353692002249,
           -0.3788254392879111,
           -0.3785155093755977,
           -0.3782055794632838,
           -0.3778956495509704,
           -0.3775857196386567,
           -0.37727578972634296,
           -0.37696585981402925,
           -0.3766559299017156,
           -0.37634599998940194,
           -0.3760360700770883,
           -0.3757261401647746,
           -0.37541621025246097,
           -0.37510628034014737,
           -0.37479635042783366,
           -0.37448642051552,
           -0.37417649060320635,
           -0.37386656069089264,
           -0.37355663077857904,
           -0.3732467008662653,
           -0.3729367709539517,
           -0.372626841041638,
           -0.37231691112932425,
           -0.3720069812170106,
           -0.37169705130469716,
           -0.3713871213923833,
           -0.3710771914800698,
           -0.37076726156775597,
           -0.3704573316554423,
           -0.3701474017431289,
           -0.369837471830815,
           -0.36952754191850146,
           -0.36921761200618775,
           -0.36890768209387415,
           -0.3685977521815605,
           -0.3682878222692468,
           -0.3679778923569331,
           -0.36766796244461947,
           -0.3673580325323058,
           -0.36704810261999216,
           -0.3667381727076785,
           -0.3664282427953648,
           -0.36659970830053984,
           -0.3691781380876748,
           -0.3717565678748099,
           -0.37433499766194483,
           -0.37691342744907974,
           -0.3794918572362147,
           -0.38207028702334966,
           -0.3846487168104846,
           -0.3872271465976197,
           -0.38980557638475466,
           -0.3923840061718897,
           -0.39496243595902464,
           -0.39754086574615954,
           -0.4001192955332946,
           -0.4026977253204295,
           -0.40527615510756454,
           -0.4078545848946995,
           -0.4104330146818344,
           -0.41301144446896954,
           -0.41558987425610444,
           -0.41816830404323946,
           -0.4207467338303745,
           -0.42332516361750927,
           -0.42590359340464423,
           -0.4284820231917792,
           -0.4310604529789142,
           -0.4336388827660492,
           -0.4362173125531842,
           -0.43879574234031915,
           -0.44137417212745417,
           -0.443952601914589,
           -0.44463506212944837,
           -0.4443695375581699,
           -0.44410401298689123,
           -0.44383848841561274,
           -0.4435729638443342,
           -0.4433074392730559,
           -0.4430419147017774,
           -0.44277639013049885,
           -0.44251086555922026,
           -0.4422453409879417,
           -0.4419798164166631,
           -0.44171429184538463,
           -0.441448767274106,
           -0.4411832427028275,
           -0.4409177181315491,
           -0.44065219356027047,
           -0.440386668988992,
           -0.4401211444177135,
           -0.439855619846435,
           -0.4395900952751565,
           -0.43932457070387765,
           -0.4390590461325994,
           -0.43879352156132084,
           -0.43852799699004225,
           -0.4382624724187637,
           -0.43799694784748505,
           -0.43773142327620673,
           -0.43746589870492814,
           -0.43720037413364965,
           -0.4369348495623713,
           -0.4366693249910924,
           -0.4364038004198141,
           -0.4361382758485355,
           -0.4358727512772568,
           -0.4356072267059786,
           -0.4353417021346998,
           -0.43507617756342154,
           -0.4348106529921429,
           -0.4345451284208641,
           -0.4342796038495857,
           -0.43401407927830715,
           -0.43374855470702867,
           -0.43348303013575007,
           -0.4332175055644716,
           -0.43295198099319304,
           -0.43268645642191456,
           -0.432420931850636,
           -0.4321554072793574,
           -0.43188988270807893,
           -0.4316243581368003,
           -0.43135883356552196,
           -0.4310933089942433,
           -0.43082778442296477,
           -0.43056225985168617,
           -0.4302967352804077,
           -0.43003121070912914,
           -0.42976568613785054,
           -0.429500161566572,
           -0.42923463699529385,
           -0.4289691124240152,
           -0.42870358785273666,
           -0.42843806328145806,
           -0.4281725387101796,
           -0.427907014138901,
           -0.42764148956762243,
           -0.4278694651824066,
           -0.43021245308424155,
           -0.4325554409860765,
           -0.4348984288879115,
           -0.43724141678974626,
           -0.439584404691581,
           -0.44192739259341596,
           -0.4442703804952509,
           -0.4466133683970859,
           -0.4489563562989206,
           -0.45129934420075557,
           -0.45364233210259053,
           -0.4559853200044255,
           -0.4583283079062603,
           -0.46067129580809496,
           -0.4630142837099299,
           -0.4653572716117649,
           -0.46770025951359984,
           -0.47001585487868824,
           -0.4723040577070308,
           -0.474592260535373,
           -0.47688046336371526,
           -0.4791686661920578,
           -0.48145686902039997,
           -0.4837450718487422,
           -0.4860332746770848,
           -0.4883214775054272,
           -0.49060968033376917,
           -0.49289788316211175,
           -0.4951860859904543,
           -0.4974742888187964,
           -0.4997624916471387,
           -0.5020506944754812,
           -0.5043388973038235,
           -0.5066271001321657,
           -0.5089153029605081,
           -0.5112035057888503,
           -0.5134917086171928,
           -0.5152363153267219,
           -0.5143988652094368,
           -0.5135614150921519,
           -0.5127239649748668,
           -0.5118865148575815,
           -0.5110490647402967,
           -0.5102116146230116,
           -0.5093741645057264,
           -0.5085367143884415,
           -0.5076992642711564,
           -0.5068618141538713,
           -0.5060243640365861,
           -0.5051869139193012,
           -0.5043494638020162,
           -0.503512013684731,
           -0.5026745635674459,
           -0.5018371134501609,
           -0.5009996633328758,
           -0.5001622132155908,
           -0.49932476309830576,
           -0.49848731298102067,
           -0.49764986286373564,
           -0.4968124127464506,
           -0.4959749626291655,
           -0.4951375125118804,
           -0.49430006239459545,
           -0.49346261227731025,
           -0.4926251621600252,
           -0.49178771204274013,
           -0.4909502619254551,
           -0.49011281180817,
           -0.489275361690885,
           -0.48843791157359984,
           -0.48760046145631475,
           -0.4867630113390297,
           -0.4859255612217448,
           -0.4850881111044596,
           -0.4842506609871745,
           -0.4834132108698895,
           -0.48257576075260444,
           -0.4817383106353194,
           -0.4809008605180343,
           -0.4800634104007493,
           -0.47922596028346415,
           -0.4783885101661791,
           -0.4775510600488941,
           -0.476713609931609,
           -0.47587615981432385,
           -0.47503870969703893,
           -0.4742012595797538,
           -0.47336380946246875,
           -0.47252635934518367,
           -0.47168890922789863,
           -0.4708514591106135,
           -0.47001400899332846,
           -0.4691765588760434,
           -0.4683391087587583,
           -0.4675016586414733,
           -0.46666420852418833,
           -0.4658267584069032,
           -0.46498930828961793,
           -0.4641518581723329,
           -0.463314408055048,
           -0.4625894519666318,
           -0.462089483935954,
           -0.46158951590527614,
           -0.4610895478745982,
           -0.46058957984392035,
           -0.4600896118132426,
           -0.45958964378256467,
           -0.45908967575188675,
           -0.4585897077212087,
           -0.4580897396905308,
           -0.45758977165985293,
           -0.4570898036291752,
           -0.45658983559849725,
           -0.4560898675678194,
           -0.4555898995371415,
           -0.45415503290663883,
           -0.4514112967965266,
           -0.44866756068641456,
           -0.44592382457630264,
           -0.4431800884661904,
           -0.4404363523560782,
           -0.43769261624596617,
           -0.4349488801358543,
           -0.43220514402574206,
           -0.42946140791563003,
           -0.42671767180551806,
           -0.42397393569540587,
           -0.42123019958529384,
           -0.4184864634751819,
           -0.4157427273650697,
           -0.4129989912549574,
           -0.4102552551448458,
           -0.40751151903473354,
           -0.40476778292462123,
           -0.4020240468145093,
           -0.3992803107043973,
           -0.39653657459428515,
           -0.3937928384841731,
           -0.3910491023740612,
           -0.3883053662639489,
           -0.38556163015383693,
           -0.382817894043725,
           -0.38007415793361277,
           -0.3773304218235005,
           -0.3745866857133885,
           -0.37184294960327663,
           -0.3690992134931643,
           -0.36635547738305235,
           -0.36361174127294044,
           -0.36086800516282813,
           -0.3581242690527162,
           -0.3553805329426043,
           -0.35263679683249205,
           -0.3498930607223798,
           -0.3471493246122681,
           -0.3444055885021558,
           -0.3416618523920436,
           -0.3389181162819317,
           -0.3361743801718197,
           -0.3334306440617074,
           -0.3306869079515955,
           -0.32794317184148347,
           -0.3251994357313713,
           -0.3224556996212593,
           -0.31971196351114733,
           -0.3169682274010351,
           -0.3142244912909229,
           -0.31148075518081114,
           -0.3087370190706989,
           -0.3059932829605868,
           -0.3032495468504746,
           -0.3005058107403628,
           -0.2977620746302506,
           -0.29501833852013853,
           -0.29227460241002656,
           -0.2895308662999145,
           -0.2867871301898022,
           -0.28404339407969037,
           -0.2812996579695781,
           -0.2785559218594659,
           -0.275812185749354,
           -0.27306844963924204,
           -0.27032471352912973,
           -0.2662209837858032,
           -0.25531728587640234,
           -0.24441358796700163,
           -0.2335098900576008,
           -0.22260619214820204,
           -0.21170249423880116,
           -0.20079879632940023,
           -0.18989509842000163,
           -0.1789914005106008,
           -0.16808770260119998,
           -0.15718400469180116,
           -0.14628030678240023,
           -0.1353766088729994,
           -0.12447291096359858,
           -0.11356921305419976,
           -0.10266551514479894,
           -0.09176181723539822,
           -0.08085811932599962,
           -0.0699544214165988,
           -0.05905072350719798,
           -0.04814702559779904,
           -0.03724332768839822,
           -0.026339629778997398,
           -0.015435931869598352,
           -0.004532233960197751,
           0.006371463949203071,
           0.01633813460022324,
           0.026187678326623456,
           0.036037222053025286,
           0.0458867657794272,
           0.05573630950582739,
           0.06558585323222929,
           0.07543539695863136,
           0.08528494068503134,
           0.0951344844114334,
           0.1049840281378353,
           0.11483357186423715,
           0.12468311559063738,
           0.13453265931703923,
           0.14438220304344135,
           0.1542317467698413,
           0.16408129049624331,
           0.1744671068364566,
           0.18523597504367562,
           0.19600484325089684,
           0.20677371145811768,
           0.21754257966533697,
           0.22831144787255792,
           0.2390803160797791,
           0.2498491842870002,
           0.2606180524942192,
           0.27138692070144044,
           0.28215578890866133,
           0.2929246571158804,
           0.30369352532310157,
           0.3144623935303228,
           0.32523126173754163,
           0.3360001299447629,
           0.3438744908555914,
           0.3442230858958812,
           0.34457168093617085,
           0.34492027597646063,
           0.3452688710167504,
           0.34561746605704013,
           0.3459660610973299,
           0.3463146561376197,
           0.34666325117790936,
           0.347011846218199,
           0.34736044125848886,
           0.3477090362987786,
           0.3480576313390683,
           0.348406226379358,
           0.348754821419648,
           0.3491034164599376,
           0.3494520115002274,
           0.34980060654051714,
           0.35014920158080676,
           0.35049779662109654,
           0.35084639166138637,
           0.35119498670167604,
           0.351543581741966,
           0.3518921767822555,
           0.35224077182254526,
           0.3525893668628351
          ],
          [
           0.24830816491007962,
           0.2444765857344678,
           0.240645006558856,
           0.23681342738324415,
           0.23298184820763246,
           0.2291502690320206,
           0.22531868985640882,
           0.22148711068079696,
           0.21765553150518518,
           0.21382395232957316,
           0.2099923731539613,
           0.20616079397834952,
           0.2023292148027377,
           0.1984976356271259,
           0.19466605645151414,
           0.19404532766173654,
           0.19342460071470924,
           0.19280387376768193,
           0.19218314682065463,
           0.1915624198736272,
           0.1909416929265999,
           0.1903209659795725,
           0.18970023903254518,
           0.18907951208551776,
           0.18845878513849035,
           0.18783805819146304,
           0.18721733124443574,
           0.18659660429740832,
           0.185975877350381,
           0.1853551504033537,
           0.1847344234563263,
           0.18411369650929887,
           0.18349296956227157,
           0.18287224261524426,
           0.18225151566821685,
           0.18163078872118954,
           0.18101006177416223,
           0.18038933482713482,
           0.1797686078801074,
           0.1791478809330801,
           0.1785271539860528,
           0.17790642703902537,
           0.17728570009199796,
           0.17666497314497065,
           0.17604424619794334,
           0.17542351925091615,
           0.1748027923038885,
           0.17418206535686132,
           0.173561338409834,
           0.17294061146280648,
           0.1723198845157793,
           0.17169915756875165,
           0.17107843062172456,
           0.17045770367469726,
           0.16983697672766962,
           0.16921624978064254,
           0.1685955228336149,
           0.1679747958865878,
           0.1673540689395605,
           0.16673334199253287,
           0.16611261504550578,
           0.16549188809847815,
           0.16487116115145106,
           0.16425043420442376,
           0.16362970725739628,
           0.16300898031036887,
           0.16238825336334156,
           0.16176752641631426,
           0.16114679946928684,
           0.16052607252225953,
           0.15990534557523212,
           0.1592846186282048,
           0.1586638916811775,
           0.1580431647341501,
           0.15742243778712273,
           0.1568017108400953,
           0.156180983893068,
           0.1555602569460406,
           0.15493952999901328,
           0.15431880305198586,
           0.15369807610495856,
           0.15307734915793114,
           0.15245662221090384,
           0.15183589526387642,
           0.1519907156996333,
           0.152300645611947,
           0.1526105755242606,
           0.15292050543657432,
           0.15323043534888792,
           0.15354036526120163,
           0.15385029517351523,
           0.15416022508582894,
           0.15447015499814254,
           0.15478008491045625,
           0.15509001482276957,
           0.15539994473508378,
           0.15570987464739688,
           0.1560198045597111,
           0.1563297344720242,
           0.1566396643843379,
           0.1569495942966519,
           0.1572595242089655,
           0.1575694541212792,
           0.15787938403359292,
           0.15818931394590652,
           0.15849924385822023,
           0.15880917377053383,
           0.15911910368284754,
           0.15942903359516114,
           0.15973896350747474,
           0.16004889341978845,
           0.16035882333210216,
           0.16066875324441576,
           0.16097868315672947,
           0.16128861306904307,
           0.16159854298135679,
           0.1619084728936706,
           0.1622184028059842,
           0.1625283327182977,
           0.16283826263061152,
           0.163148192542925,
           0.16345812245523894,
           0.16376805236755243,
           0.16407798227986592,
           0.16438791219217985,
           0.16469784210449334,
           0.16500777201680705,
           0.16531770192912065,
           0.16562763184143436,
           0.16593756175374808,
           0.16624749166606168,
           0.1665574215783754,
           0.166867351490689,
           0.1671772814030027,
           0.1674872113153164,
           0.16779714122763,
           0.1681070711399436,
           0.16841700105225732,
           0.16872693096457092,
           0.16903686087688463,
           0.16934679078919823,
           0.16965672070151194,
           0.16996665061382565,
           0.17027658052613925,
           0.17058651043845297,
           0.17089644035076657,
           0.17120637026308028,
           0.171516300175394,
           0.1718262300877076,
           0.1721361600000212,
           0.1724460899123349,
           0.1727560198246485,
           0.1730659497369622,
           0.17145030485864265,
           0.16887187507150753,
           0.16629344528437268,
           0.1637150154972377,
           0.16113658571010267,
           0.15855815592296776,
           0.15597972613583283,
           0.15340129634869773,
           0.15082286656156277,
           0.14824443677442778,
           0.14566600698729293,
           0.1430875772001579,
           0.1405091474130229,
           0.137930717625888,
           0.13724825741102864,
           0.13751378198230713,
           0.13777930655358578,
           0.13804483112486432,
           0.13831035569614286,
           0.13857588026742113,
           0.1388414048386996,
           0.1391069294099782,
           0.13937245398125675,
           0.13963797855253535,
           0.13990350312381394,
           0.14016902769509243,
           0.14043455226637103,
           0.14070007683764957,
           0.1409656014089281,
           0.14123112598020632,
           0.1414966505514852,
           0.14176217512276346,
           0.142027699694042,
           0.1422932242653206,
           0.14255874883659936,
           0.14282427340787768,
           0.14308979797915622,
           0.14335532255043482,
           0.14362084712171336,
           0.14388637169299218,
           0.14415189626427014,
           0.144417420835549,
           0.14468294540682727,
           0.1449484699781058,
           0.14521399454938463,
           0.14547951912066293,
           0.1457450436919415,
           0.14601056826322034,
           0.14627609283449844,
           0.14654161740577729,
           0.14680714197705552,
           0.1470726665483341,
           0.14733819111961294,
           0.1476037156908913,
           0.14786924026216985,
           0.14813476483344845,
           0.148400289404727,
           0.14866581397600553,
           0.14893133854728396,
           0.1491968631185625,
           0.14946238768984105,
           0.1497279122611196,
           0.14999343683239819,
           0.15025896140367673,
           0.15052448597495516,
           0.15079001054623364,
           0.15105553511751224,
           0.15132105968879078,
           0.15158658426006932,
           0.15185210883134792,
           0.15211763340262646,
           0.152383157973905,
           0.15264868254518324,
           0.1529142071164618,
           0.15317973168774035,
           0.15344525625901892,
           0.1537107808302975,
           0.15397630540157603,
           0.1542418299728546,
           0.15450735454413314,
           0.1547728791154117,
           0.15503840368669025,
           0.15530392825796846,
           0.15556945282924703,
           0.1558349774005256,
           0.15617213819501188,
           0.15708236012481067,
           0.15799258205460948,
           0.15890280398440823,
           0.15981302591420704,
           0.16072324784400582,
           0.16163346977380463,
           0.1625436917036034,
           0.1634539136334022,
           0.164364135563201,
           0.1652743574929998,
           0.1661845794227986,
           0.1681371633741296,
           0.1711321093469929,
           0.17412705531985592,
           0.17712200129271893,
           0.18011694726558225,
           0.1814054857913126,
           0.18224802564677464,
           0.1830905655022368,
           0.1839331053576989,
           0.18477564521316087,
           0.18561818506862302,
           0.1864607249240851,
           0.18730326477954717,
           0.18814580463500924,
           0.1889883444904714,
           0.1898308843459334,
           0.19067342420139544,
           0.1915159640568576,
           0.19235850391231968,
           0.19320104376778172,
           0.1940435836232438,
           0.19488612347870596,
           0.1957286633341679,
           0.19657120318963006,
           0.1974137430450922,
           0.19825628290055422,
           0.19909882275601629,
           0.1999413626114784,
           0.20078390246694042,
           0.2016264423224025,
           0.20246898217786466,
           0.2033115220333268,
           0.2041540618887887,
           0.20499660174425088,
           0.205839141599713,
           0.20668168145517504,
           0.20752422131063714,
           0.20836676116609926,
           0.2092093010215613,
           0.21005184087702333,
           0.21089438073248548,
           0.21173692058794752,
           0.21257946044340958,
           0.21342200029887168,
           0.21426454015433388,
           0.21510708000979578,
           0.21594961986525796,
           0.21679215972072005,
           0.21763469957618214,
           0.2184772394316442,
           0.21931977928710628,
           0.2201623191425683,
           0.22100485899803035,
           0.2218473988534925,
           0.22268993870895468,
           0.22353247856441666,
           0.22437501841987875,
           0.22521755827534085,
           0.22606009813080288,
           0.22690263798626498,
           0.22774517784172707,
           0.22858771769718914,
           0.22943025755265115,
           0.2302727974081133,
           0.23111533726357536,
           0.23195787711903743,
           0.23280041697449955,
           0.23364295682996164,
           0.23448549668542368,
           0.23532803654088577,
           0.23617057639634792,
           0.23701311625180999,
           0.237855656107272,
           0.23869819596273414,
           0.23954073581819615,
           0.24038327567365822,
           0.24122581552912034,
           0.24206835538458238,
           0.24291089524004447,
           0.24375343509550662,
           0.24459597495096871,
           0.2454385148064308,
           0.2462810546618928,
           0.24822138512599756,
           0.2523572968073864,
           0.25649320848877494,
           0.26062912017016404,
           0.26476503185155287,
           0.26890094353294147,
           0.2730368552143305,
           0.2771727668957197,
           0.2813086785771082,
           0.28544459025849733,
           0.2895805019398864,
           0.29371641362127493,
           0.29785232530266376,
           0.30198823698405286,
           0.3061241486654415,
           0.3102600603468303,
           0.3143959720282194,
           0.31853188370960817,
           0.3226677953909968,
           0.32680370707238593,
           0.33093961875377503,
           0.3350755304351638,
           0.3392114421165524,
           0.34334735379794146,
           0.3474832654793303,
           0.3516191771607191,
           0.35575508884210827,
           0.35989100052349676,
           0.3640269122048856,
           0.3681628238862745,
           0.3722987355676636,
           0.3764346472490522,
           0.3805705589304412,
           0.3847064706118304,
           0.38884238229321916,
           0.3929782939746077,
           0.39711420565599687,
           0.40125011733738547,
           0.40538602901877424,
           0.4095219407001633,
           0.4136578523815521,
           0.41779376406294094,
           0.42192967574433005,
           0.42606558742571893,
           0.43020149910710775,
           0.4343374107884963,
           0.43847332246988546,
           0.44260923415127423,
           0.446745145832663,
           0.45088105751405216,
           0.4550169691954407,
           0.45915288087682954,
           0.46287113621149123,
           0.4656148723216034,
           0.46835860843171506,
           0.4711023445418274,
           0.4738460806519395,
           0.4765898167620515,
           0.4793335528721635,
           0.48207728898227575,
           0.4848210250923878,
           0.4875647612024997,
           0.49030849731261195,
           0.4930522334227239,
           0.49579596953283583,
           0.4985397056429482,
           0.5012834417530604,
           0.504027177863172,
           0.5067709139732844,
           0.5095146500833965,
           0.5122583861935087,
           0.5150021223036205,
           0.5177458584137326,
           0.5204895945238448,
           0.5232333306339566,
           0.5259770667440687,
           0.5287208028541811,
           0.5314645389642928,
           0.5342082750744052,
           0.5369520111845173,
           0.5396957472946291,
           0.5424394834047412,
           0.5451832195148534,
           0.5492869492581799,
           0.5601906471675808,
           0.5710943450769816,
           0.5819980429863822,
           0.5929017408957813,
           0.6038054388051821,
           0.6147091367145829,
           0.6256128346239815,
           0.6365165325333824,
           0.6474202304427832,
           0.658323928352182,
           0.6692276262615829,
           0.6801313241709839,
           0.6910350220803845,
           0.7019387199897834,
           0.7128424178991842,
           0.7237461158085852,
           0.7346498137179835,
           0.7455535116273844,
           0.7564572095367853,
           0.7673609074461842,
           0.7782646053555851,
           0.7891683032649858,
           0.8000720011743848,
           0.8109756990837854,
           0.8218793969931862,
           0.8327830949025872,
           0.8436867928119858,
           0.8545904907213867,
           0.8654941886307873,
           0.8763978865401862,
           0.8873015844495872,
           0.898205282358988,
           0.9091089802683868,
           0.9200126781777874,
           0.9309163760871882,
           0.9420135487709741,
           0.9531628127445501,
           0.9643120767181279,
           0.975461340691706,
           0.9866106046652818,
           0.9977598686388596,
           1.001352546327443,
           0.9995476623838901,
           0.997742778440337,
           0.9959378944967835,
           0.9941330105532306,
           0.9923281266096772,
           0.9913389677197401,
           0.9916875627600299,
           0.9920361578003196,
           0.9923847528406092,
           0.9927333478808991,
           0.9930819429211888,
           0.9934305379614785,
           0.9937791330017683,
           0.994127728042058,
           0.9944763230823478,
           0.9948249181226375,
           0.9951735131629273,
           0.9955221082032171,
           0.9958707032435068,
           0.9962192982837965,
           0.9965678933240862,
           0.9969164883643761,
           0.9972650834046658,
           0.9976136784449554,
           0.9979622734852451,
           0.9983108685255351,
           0.9986594635658246,
           0.9990080586061145,
           0.9993566536464042,
           0.9997052486866941,
           1.0000538437269837,
           1.0004024387672736,
           1.0007510338075634,
           1.0010996288478529,
           1.0014482238881426,
           1.0017968189284325,
           1.0021454139687223,
           1.002494009009012,
           1.0028426040493017,
           1.0031911990895916,
           1.0035397941298811
          ],
          [
           0.7294691186254569,
           0.7320553313840831,
           0.7346415441427091,
           0.7356242857371481,
           0.7350035587901208,
           0.7343828318430934,
           0.733762104896066,
           0.7331413779490387,
           0.7325206510020114,
           0.7318999240549839,
           0.7312791971079566,
           0.7306584701609292,
           0.7300377432139019,
           0.7294170162668745,
           0.7287962893198471,
           0.7281755623728198,
           0.7275548354257924,
           0.7269341084787652,
           0.7263133815317377,
           0.7256926545847104,
           0.725071927637683,
           0.7244512006906556,
           0.7238304737436284,
           0.723209746796601,
           0.7225890198495737,
           0.7219682929025463,
           0.7213475659555189,
           0.7207268390084915,
           0.7201061120614641,
           0.7194853851144369,
           0.7188646581674095,
           0.7182439312203821,
           0.7176232042733548,
           0.7170024773263275,
           0.7163817503793002,
           0.7157610234322728,
           0.7151402964852454,
           0.714519569538218,
           0.7138988425911907,
           0.7132781156441633,
           0.7126573886971359,
           0.7120366617501086,
           0.7114159348030813,
           0.7107952078560539,
           0.7101744809090266,
           0.7095537539619992,
           0.7089330270149719,
           0.7083123000679444,
           0.7076915731209171,
           0.7070708461738898,
           0.7064501192268624,
           0.7058293922798351,
           0.7052086653328076,
           0.7045879383857803,
           0.703967211438753,
           0.7033464844917257,
           0.7027257575446983,
           0.7021050305976708,
           0.7014843036506435,
           0.7008635767036162,
           0.7002428497565888,
           0.6996221228095616,
           0.6990013958625341,
           0.6983806689155068,
           0.6977599419684795,
           0.6971392150214522,
           0.6965184880744247,
           0.6958977611273973,
           0.69527703418037,
           0.6946563072333427,
           0.6940355802863153,
           0.693414853339288,
           0.6927941263922606,
           0.6921733994452333,
           0.691552672498206,
           0.6909319455511784,
           0.6903112186041512,
           0.6896904916571238,
           0.6890697647100965,
           0.6884490377630691,
           0.6878283108160417,
           0.6872075838690144,
           0.6865868569219871,
           0.6859661299749598,
           0.6861209504107165,
           0.6864308803230302,
           0.6867408102353438,
           0.6870507401476575,
           0.6873606700599711,
           0.6876705999722847,
           0.6879805298845985,
           0.6882904597969122,
           0.6886003897092259,
           0.6889103196215394,
           0.6892202495338531,
           0.6895301794461667,
           0.6898401093584805,
           0.6901500392707941,
           0.6904599691831078,
           0.6907698990954214,
           0.6910798290077351,
           0.6913897589200488,
           0.6916996888323624,
           0.692009618744676,
           0.6923195486569897,
           0.6926294785693035,
           0.6929394084816171,
           0.6932493383939307,
           0.6935592683062444,
           0.6938691982185581,
           0.6941791281308718,
           0.6944890580431854,
           0.694798987955499,
           0.6951089178678127,
           0.6954188477801263,
           0.6957287776924399,
           0.6960387076047536,
           0.6963486375170673,
           0.696658567429381,
           0.6969684973416946,
           0.6972784272540083,
           0.697588357166322,
           0.6978982870786357,
           0.6982082169909494,
           0.698518146903263,
           0.6988280768155766,
           0.6991380067278903,
           0.699447936640204,
           0.6997578665525176,
           0.7000677964648313,
           0.7003777263771449,
           0.7006876562894586,
           0.7009975862017723,
           0.7013075161140859,
           0.7016174460263996,
           0.7019273759387132,
           0.702237305851027,
           0.7025472357633404,
           0.7028571656756541,
           0.7031670955879679,
           0.7034770255002815,
           0.7037869554125952,
           0.7040968853249088,
           0.7044068152372225,
           0.7047167451495362,
           0.7050266750618498,
           0.7053366049741635,
           0.7056465348864771,
           0.7059564647987908,
           0.7062663947111044,
           0.7065763246234181,
           0.7068862545357317,
           0.7071961844480454,
           0.7075061143603592,
           0.7078160442726728,
           0.7081259741849865,
           0.7084359040973001,
           0.7087458340096138,
           0.7090557639219274,
           0.7093656938342411,
           0.7096756237465548,
           0.7099855536588684,
           0.7102954835711821,
           0.7106054134834956,
           0.7114026290308486,
           0.7146362799266859,
           0.7178699308225233,
           0.7209884629512414,
           0.7240494356963992,
           0.7271104084415577,
           0.7301713811867158,
           0.7314400602372194,
           0.7323502821670181,
           0.7332605040968169,
           0.7341707260266156,
           0.7350809479564144,
           0.7359911698862132,
           0.7369013918160121,
           0.7378116137458107,
           0.7387218356756098,
           0.7396320576054085,
           0.7405422795352072,
           0.7414525014650061,
           0.7423627233948049,
           0.7432729453246036,
           0.7441831672544025,
           0.7450933891842012,
           0.7460036111139999,
           0.7469138330437988,
           0.7478240549735975,
           0.7487342769033963,
           0.7496444988331952,
           0.750554720762994,
           0.7514649426927927,
           0.7523751646225916,
           0.7532853865523904,
           0.7541956084821893,
           0.755105830411988,
           0.7560160523417868,
           0.7569262742715855,
           0.7578364962013843,
           0.7587467181311831,
           0.7596569400609818,
           0.7605671619907807,
           0.7614773839205795,
           0.7623876058503782,
           0.7632978277801771,
           0.7642080497099758,
           0.7651182716397746,
           0.7660284935695736,
           0.7669387154993723,
           0.7678489374291712,
           0.7687591593589699,
           0.7696693812887685,
           0.7705796032185674,
           0.7714898251483662,
           0.772400047078165,
           0.7733102690079638,
           0.7742204909377627,
           0.7751307128675614,
           0.7760409347973602,
           0.776951156727159,
           0.7778613786569578,
           0.7787716005867565,
           0.7796818225165554,
           0.7805920444463541,
           0.7815022663761529,
           0.7824124883059517,
           0.7833227102357505,
           0.7842329321655492,
           0.785143154095348,
           0.7860533760251468,
           0.7869635979549455,
           0.7878738198847444,
           0.7887840418145432,
           0.789694263744342,
           0.7906044856741408,
           0.7915147076039396,
           0.7924249295337383,
           0.7933351514635372,
           0.7942453733933359,
           0.7951555953231347,
           0.7960658172529336,
           0.7969760391827324,
           0.7978862611125312,
           0.79879648304233,
           0.7997067049721288,
           0.8006169269019275,
           0.8015271488317264,
           0.8024373707615251,
           0.8043899547128561,
           0.8073849006857193,
           0.8103798466585825,
           0.8133747926314455,
           0.8163697386043088,
           0.8193646845771718,
           0.8223596305500348,
           0.8253545765228981,
           0.8283495224957615,
           0.8313444684686242,
           0.8343394144414875,
           0.8373343604143509,
           0.8403293063872139,
           0.8433242523600769,
           0.8463191983329402,
           0.8493141443058033,
           0.8523090902786663,
           0.8553040362515295,
           0.8582989822243926,
           0.8612939281972557,
           0.864288874170119,
           0.8672838201429823,
           0.8702787661158451,
           0.8732737120887083,
           0.8762686580615716,
           0.8792636040344347,
           0.8822585500072977,
           0.885253495980161,
           0.8882484419530241,
           0.8912433879258871,
           0.8942383338987504,
           0.8972332798716137,
           0.9002282258444764,
           0.9032231718173397,
           0.906218117790203,
           0.9092130637630661,
           0.9122080097359291,
           0.9152029557087924,
           0.9181979016816554,
           0.919893647004422,
           0.9207361868598841,
           0.9215787267153461,
           0.9224212665708081,
           0.9232638064262704,
           0.9241063462817326,
           0.9249488861371945,
           0.9257914259926566,
           0.9266339658481187,
           0.9274765057035808,
           0.9283190455590429,
           0.929161585414505,
           0.9300041252699671,
           0.930846665125429,
           0.9316892049808911,
           0.9325317448363534,
           0.9333742846918154,
           0.9342168245472774,
           0.9350593644027396,
           0.9359019042582016,
           0.9367444441136636,
           0.9375869839691259,
           0.9384295238245877,
           0.9392720636800499,
           0.9401146035355121,
           0.940957143390974,
           0.9417996832464361,
           0.9426422231018982,
           0.9434847629573603,
           0.9443273028128222,
           0.9451698426682844,
           0.9460123825237466,
           0.9468549223792087,
           0.9476974622346708,
           0.948540002090133,
           0.9493825419455948,
           0.9502250818010569,
           0.951067621656519,
           0.951910161511981,
           0.952752701367443,
           0.9535952412229052,
           0.9544377810783672,
           0.9552803209338294,
           0.9561228607892915,
           0.9580631912533962,
           0.9621991029347849,
           0.9663350146161737,
           0.9704709262975628,
           0.9746068379789515,
           0.9787427496603402,
           0.9828786613417292,
           0.9870145730231183,
           0.9911504847045068,
           0.995286396385896,
           0.9994223080672852,
           1.0035582197486737,
           1.0076941314300625,
           1.0118300431114513,
           1.0159659547928401,
           1.020101866474229,
           1.0242377781556182,
           1.0283736898370068,
           1.0325096015183954,
           1.0366455131997845,
           1.0407814248811738,
           1.0449173365625626,
           1.049053248243951,
           1.0531891599253402,
           1.0573250716067288,
           1.0614609832881177,
           1.065596894969507,
           1.0697328066508955,
           1.0738687183322844,
           1.0780046300136732,
           1.0821405416950622,
           1.0862764533764508,
           1.09041236505784,
           1.094548276739229,
           1.0986841884206178,
           1.1028201001020064,
           1.1069560117833954,
           1.111091923464784,
           1.1152278351461729,
           1.119363746827562,
           1.1234996585089507,
           1.1276355701903396,
           1.1317714818717288,
           1.1359073935531177,
           1.1400433052345065,
           1.1441792169158949,
           1.1483151285972841,
           1.152451040278673,
           1.1565869519600618,
           1.1607228636414506,
           1.1648587753228394,
           1.1689946870042283,
           1.1731305986856173,
           1.1772665103670064,
           1.1814024220483947,
           1.1855383337297838,
           1.1896742454111728,
           1.1942876916030047,
           1.2008877105013982,
           1.207487729399792,
           1.2140877482981856,
           1.2206877671965788,
           1.2272877860949727,
           1.2338878049933661,
           1.2404878238917596,
           1.2470878427901535,
           1.2536878616885474,
           1.2602878805869402,
           1.2668878994853343,
           1.273487918383728,
           1.2800879372821214,
           1.286687956180515,
           1.2932879750789086,
           1.2998879939773018,
           1.3064880128756955,
           1.3130880317740894,
           1.3196880506724833,
           1.326288069570876,
           1.33288808846927,
           1.339488107367664,
           1.3460881262660571,
           1.3526881451644506,
           1.3592881640628445,
           1.3668118250236903,
           1.3789536962968016,
           1.3910955675699133,
           1.4032374388430242,
           1.4153793101161336,
           1.427521181389245,
           1.4396630526623564,
           1.4518049239354658,
           1.463946795208577,
           1.4760886664816883,
           1.4882305377547975,
           1.4999699576287904,
           1.5111192216023683,
           1.522268485575946,
           1.533417749549522,
           1.5445670135230998,
           1.555716277496678,
           1.5668655414702535,
           1.5780148054438317,
           1.5891640694174096,
           1.6003133333909856,
           1.6114625973645635,
           1.6226118613381413,
           1.633761125311717,
           1.6449103892852952,
           1.656059653258873,
           1.6672089172324511,
           1.6783581812060269,
           1.689507445179605,
           1.7006567091531826,
           1.7118059731267588,
           1.7229552371003367,
           1.7341045010739145,
           1.7452537650474902,
           1.7564030290210684,
           1.767552292994646,
           1.7787015569682239,
           1.7898508209417998,
           1.8010000849153778,
           1.8121493488889557,
           1.8232986128625317,
           1.8344478768361094,
           1.8380405545246932,
           1.83623567058114,
           1.8344307866375869,
           1.8326259026940335,
           1.8308210187504803,
           1.8290161348069272,
           1.8272112508633735,
           1.8254063669198202,
           1.8236014829762675,
           1.8217965990327138,
           1.8199917150891602,
           1.8181868311456073,
           1.816381947202054,
           1.8145770632585008,
           1.8127721793149476,
           1.8109672953713942,
           1.809162411427841,
           1.8073575274842877,
           1.8055526435407345,
           1.8037477595971811,
           1.8019428756536278,
           1.8001379917100748,
           1.7983331077665214,
           1.796528223822968,
           1.7947233398794151,
           1.7929184559358617,
           1.7911135719923081,
           1.7893086880487554,
           1.7875038041052018,
           1.7856989201616484,
           1.7838940362180953,
           1.7701038488922443,
           1.7525540602598033,
           1.7350042716273624,
           1.7174544829949243,
           1.6999046943624831,
           1.6823549057300422,
           1.6648051170976044,
           1.6472553284651634,
           1.6297055398327225,
           1.6121557512002813,
           1.5946059625678435
          ],
          [
           1.2101520114084798,
           1.212738224167106,
           1.2153244369257319,
           1.2179106496843581,
           1.2204968624429844,
           1.2230830752016104,
           1.2256692879602364,
           1.2282555007188627,
           1.2308417134774885,
           1.2334279262361147,
           1.2360141389947408,
           1.2386003517533668,
           1.241186564511993,
           1.243772777270619,
           1.2463589900292453,
           1.2489452027878714,
           1.2515314155464974,
           1.2541176283051234,
           1.2567038410637497,
           1.2592900530401607,
           1.2586693260931334,
           1.258048599146106,
           1.2574278721990788,
           1.2568071452520513,
           1.256186418305024,
           1.2555656913579967,
           1.2549449644109694,
           1.254324237463942,
           1.2537035105169145,
           1.2530827835698872,
           1.25246205662286,
           1.2518413296758324,
           1.2512206027288053,
           1.2505998757817778,
           1.2499791488347503,
           1.249358421887723,
           1.2487376949406956,
           1.2481169679936683,
           1.2474962410466408,
           1.2468755140996137,
           1.2462547871525862,
           1.245634060205559,
           1.2450133332585316,
           1.244392606311504,
           1.243771879364477,
           1.2431511524174494,
           1.2425304254704221,
           1.2419096985233948,
           1.2412889715763673,
           1.24066824462934,
           1.2400475176823127,
           1.2394267907352852,
           1.2388060637882579,
           1.2381853368412306,
           1.2375646098942032,
           1.236943882947176,
           1.2363231560001486,
           1.2357024290531213,
           1.2350817021060938,
           1.2344609751590665,
           1.2338402482120392,
           1.2332195212650117,
           1.2325987943179844,
           1.231978067370957,
           1.2313573404239297,
           1.2307366134769024,
           1.230115886529875,
           1.2294951595828476,
           1.2288744326358203,
           1.228253705688793,
           1.2276329787417657,
           1.2270122517947382,
           1.2263915248477109,
           1.2257707979006836,
           1.2251500709536562,
           1.2245293440066287,
           1.2239086170596014,
           1.223287890112574,
           1.2226671631655468,
           1.2220464362185195,
           1.2214257092714922,
           1.2208049823244647,
           1.2201842553774374,
           1.21956352843041,
           1.219718348866167,
           1.2200282787784804,
           1.2203382086907941,
           1.2206481386031078,
           1.2209580685154215,
           1.221267998427735,
           1.2215779283400487,
           1.2218878582523625,
           1.2221977881646762,
           1.2225077180769897,
           1.2228176479893036,
           1.223127577901617,
           1.2234375078139308,
           1.2237474377262445,
           1.224057367638558,
           1.224367297550872,
           1.2246772274631854,
           1.224987157375499,
           1.2252970872878128,
           1.2256070172001263,
           1.22591694711244,
           1.2262268770247537,
           1.2265368069370672,
           1.226846736849381,
           1.2271566667616947,
           1.2274665966740084,
           1.227776526586322,
           1.2280864564986356,
           1.2283963864109493,
           1.228706316323263,
           1.2290162462355767,
           1.2293261761478904,
           1.229636106060204,
           1.2299460359725176,
           1.2302559658848313,
           1.230565895797145,
           1.2308758257094585,
           1.2311857556217722,
           1.231495685534086,
           1.2318056154463997,
           1.2321155453587131,
           1.2324254752710269,
           1.2327354051833408,
           1.233045335095654,
           1.233355265007968,
           1.2336651949202815,
           1.2339751248325952,
           1.234285054744909,
           1.2345949846572224,
           1.2349049145695363,
           1.2352148444818498,
           1.2355247743941635,
           1.2358347043064772,
           1.2361446342187907,
           1.2364545641311044,
           1.2367644940434181,
           1.2370744239557319,
           1.2373843538680456,
           1.237694283780359,
           1.2380042136926728,
           1.2383141436049865,
           1.2386240735173002,
           1.238934003429614,
           1.2392439333419274,
           1.2415030098634565,
           1.2447366607592942,
           1.2479703116551315,
           1.251203962550969,
           1.254437613446806,
           1.2576712643426433,
           1.2609049152384808,
           1.264138566134318,
           1.2673722170301556,
           1.2706058679259928,
           1.27383951882183,
           1.2770731697176676,
           1.280306820613505,
           1.2835404715093424,
           1.2867741224051799,
           1.2900077733010171,
           1.2932414241968546,
           1.2964750750926919,
           1.2997087259885292,
           1.3028272581172473,
           1.3058882308624051,
           1.3089492036075636,
           1.3120101763527217,
           1.3150711490978797,
           1.3181321218430382,
           1.3211930945881962,
           1.3242540673333545,
           1.3273150400785125,
           1.3303760128236708,
           1.333436985568829,
           1.3364979583139873,
           1.3395589310591454,
           1.3426199038043034,
           1.3456808765494617,
           1.34874184929462,
           1.351802822039778,
           1.3548637947849365,
           1.3579247675300947,
           1.3609857402752528,
           1.3640467130204108,
           1.3671076857655688,
           1.370168658510727,
           1.3732296312558856,
           1.3762906040010432,
           1.3793515767462017,
           1.38241254949136,
           1.385473522236518,
           1.388534494981676,
           1.3904483998209278,
           1.3913586217507266,
           1.3922688436805255,
           1.3931790656103245,
           1.394089287540123,
           1.394999509469922,
           1.3959097313997206,
           1.3968199533295196,
           1.3977301752593183,
           1.3986403971891168,
           1.399550619118916,
           1.4004608410487147,
           1.4013710629785132,
           1.4022812849083124,
           1.4031915068381107,
           1.40410172876791,
           1.4050119506977086,
           1.4059221726275073,
           1.4068323945573062,
           1.407742616487105,
           1.408652838416904,
           1.4095630603467024,
           1.4104732822765014,
           1.4113835042063003,
           1.412293726136099,
           1.4132039480658978,
           1.4141141699956965,
           1.4150243919254952,
           1.4159346138552942,
           1.416844835785093,
           1.4177550577148916,
           1.4186652796446904,
           1.4195755015744895,
           1.420485723504288,
           1.421395945434087,
           1.4223061673638857,
           1.4232163892936844,
           1.4241266112234834,
           1.425036833153282,
           1.4259470550830808,
           1.4268572770128796,
           1.4277674989426783,
           1.4286777208724775,
           1.429587942802276,
           1.4304981647320751,
           1.4314083866618736,
           1.4323186085916724,
           1.4332288305214713,
           1.4341390524512698,
           1.4350492743810688,
           1.4359594963108677,
           1.4368697182406662,
           1.4377799401704652,
           1.438690162100264,
           1.440642746051595,
           1.4436376920244585,
           1.4466326379973211,
           1.4496275839701844,
           1.4526225299430475,
           1.4556174759159106,
           1.4586124218887737,
           1.4616073678616373,
           1.4646023138345003,
           1.467597259807363,
           1.470592205780226,
           1.4735871517530896,
           1.4765820977259527,
           1.4795770436988158,
           1.482571989671679,
           1.485566935644542,
           1.4885618816174049,
           1.4915568275902684,
           1.4945517735631313,
           1.4975467195359946,
           1.5005416655088577,
           1.5035366114817212,
           1.5065315574545841,
           1.5095265034274472,
           1.5125214494003103,
           1.5155163953731736,
           1.5185113413460363,
           1.5215062873188996,
           1.5245012332917627,
           1.527496179264626,
           1.530491125237489,
           1.5334860712103526,
           1.5364810171832153,
           1.5394759631560784,
           1.5424709091289417,
           1.545465855101805,
           1.548460801074668,
           1.5514557470475312,
           1.5544506930203943,
           1.5574456389932574,
           1.5604405849661207,
           1.5634355309389836,
           1.566430476911847,
           1.56942542288471,
           1.5724203688575733,
           1.575415314830436,
           1.5784102608032995,
           1.5814052067761628,
           1.5844001527490257,
           1.5873950987218888,
           1.590390044694752,
           1.5933849906676152,
           1.596379936640478,
           1.5993748826133416,
           1.6023698285862047,
           1.6053647745590676,
           1.6083597205319309,
           1.611354666504794,
           1.6143496124776573,
           1.6173445584505202,
           1.6203395044233837,
           1.6233344503962464,
           1.6263293963691094,
           1.6293243423419728,
           1.6323192883148359,
           1.6353142342876985,
           1.6383091802605623,
           1.6413041262334254,
           1.6442990722062882,
           1.6472940181791513,
           1.6502889641520149,
           1.6532839101248777,
           1.656278856097741,
           1.6583818082175452,
           1.6592243480730076,
           1.6600668879284695,
           1.6609094277839316,
           1.6617519676393935,
           1.6625945074948556,
           1.6634370473503177,
           1.6642795872057798,
           1.6651221270612417,
           1.665964666916704,
           1.6679049973808087,
           1.6720409090621973,
           1.676176820743586,
           1.6803127324249751,
           1.6844486441063637,
           1.6885845557877526,
           1.6927204674691416,
           1.696856379150531,
           1.700992290831919,
           1.7051282025133083,
           1.7092641141946974,
           1.7134000258760862,
           1.7175359375574748,
           1.7224645563342593,
           1.7290645752326523,
           1.7356645941310462,
           1.74226461302944,
           1.7488646319278334,
           1.7554646508262266,
           1.7620646697246205,
           1.7686646886230146,
           1.7752647075214076,
           1.7818647264198013,
           1.7884647453181952,
           1.7950647642165884,
           1.8016647831149817,
           1.808264802013376,
           1.8148648209117688,
           1.8214648398101625,
           1.8280648587085564,
           1.8346648776069503,
           1.841264896505343,
           1.847864915403737,
           1.8544649343021309,
           1.8610649532005241,
           1.8676649720989178,
           1.8742649909973115,
           1.880865009895705,
           1.8874650287940984,
           1.8940650476924923,
           1.9006650665908853,
           1.907265085489279,
           1.9138651043876729,
           1.9204651232860668,
           1.92706514218446,
           1.9336651610828535,
           1.9402651799812474,
           1.9468651988796408,
           1.9534652177780338,
           1.960065236676428,
           1.9666652555748216,
           1.9732652744732146,
           1.9798652933716085,
           1.9864653122700024,
           1.9930653311683955,
           1.9996653500667891,
           2.0062653689651833,
           2.0128653878635765,
           2.0194654067619697,
           2.026065425660364,
           2.032665444558757,
           2.0392654634571503,
           2.0458654823555444,
           2.0524655012539377,
           2.0590655201523314,
           2.065665539050725,
           2.072265557949119,
           2.0788655768475115,
           2.085465595745906,
           2.0920656146442997,
           2.098665633542693,
           2.1052656524410867,
           2.1118656713394803,
           2.1184656902378736,
           2.125065709136267,
           2.131665728034661,
           2.138265746933055,
           2.144865765831448,
           2.151465784729842,
           2.1580658036282356,
           2.164665822526629,
           2.171265841425022,
           2.1778658603234162,
           2.185389521284262,
           2.197531392557373,
           2.209673263830484,
           2.2218151351035957,
           2.233957006376705,
           2.2460988776498167,
           2.258240748922928,
           2.2703826201960373,
           2.2825244914691485,
           2.2946663627422597,
           2.306808234015369,
           2.3189501052884802,
           2.3310919765615914,
           2.343233847834703,
           2.355375719107812,
           2.3675175903809236,
           2.379659461654035,
           2.3918013329271446,
           2.4039432042002558,
           2.416085075473367,
           2.4282269467464763,
           2.4403688180195875,
           2.4525106892926987,
           2.464652560565808,
           2.4767944318389192,
           2.4889363031120313,
           2.501078174385142,
           2.513220045658252,
           2.525361916931363,
           2.537344717350449,
           2.548493981324025,
           2.5596432452976026,
           2.5707925092711807,
           2.581941773244756,
           2.593091037218334,
           2.6042403011919126,
           2.61538956516549,
           2.6265388291390663,
           2.6376880931126436,
           2.648837357086222,
           2.6599866210597978,
           2.6711358850333755,
           2.6747285627219592,
           2.672923678778406,
           2.6711187948348525,
           2.669313910891299,
           2.667509026947746,
           2.665704143004193,
           2.6638992590606394,
           2.662094375117086,
           2.660289491173533,
           2.6584846072299797,
           2.6566797232864263,
           2.6548748393428734,
           2.6529690133798405,
           2.6354192247474,
           2.6178694361149617,
           2.6003196474825208,
           2.58276985885008,
           2.565220070217639,
           2.5476702815852015,
           2.53012049295276,
           2.512570704320319,
           2.4950209156878813,
           2.47747112705544,
           2.4599213384229994,
           2.442371549790561,
           2.42482176115812,
           2.4072719725256793,
           2.3897221838932414,
           2.3721723952608005,
           2.354622606628359,
           2.337072817995918,
           2.3195230293634808,
           2.3019732407310394,
           2.284423452098599,
           2.2668736634661606,
           2.2493238748337196,
           2.2317740862012787,
           2.214224297568841,
           2.1966745089364,
           2.1791247203039585,
           2.1615749316715176,
           2.14402514303908
          ],
          [
           1.6908349041915027,
           1.6934211169501288,
           1.6960073297087548,
           1.6985935424673808,
           1.701179755226007,
           1.703765967984633,
           1.7063521807432593,
           1.7089383935018854,
           1.7115246062605114,
           1.7141108190191376,
           1.7166970317777637,
           1.7192832445363897,
           1.721869457295016,
           1.724455670053642,
           1.727041882812268,
           1.7296280955708943,
           1.73221430832952,
           1.7348005210881463,
           1.7373867338467723,
           1.7399729466053984,
           1.7425591593640246,
           1.7451453721226506,
           1.7477315848812767,
           1.750317797639903,
           1.752904010398529,
           1.755490223157155,
           1.7580764359157808,
           1.7606626486744075,
           1.7632488614330333,
           1.7658350741916593,
           1.7684212869502858,
           1.7710074997089116,
           1.7735937124675376,
           1.7761799252261636,
           1.77876613798479,
           1.781352350743416,
           1.7823350933961462,
           1.7817143664491186,
           1.7810936395020913,
           1.780472912555064,
           1.7798521856080365,
           1.7792314586610092,
           1.7786107317139817,
           1.7779900047669543,
           1.777369277819927,
           1.7767485508728997,
           1.7761278239258724,
           1.7755070969788451,
           1.7748863700318178,
           1.7742656430847905,
           1.773644916137763,
           1.7730241891907357,
           1.7724034622437084,
           1.771782735296681,
           1.7711620083496538,
           1.7705412814026262,
           1.769920554455599,
           1.7692998275085716,
           1.7686791005615443,
           1.768058373614517,
           1.7674376466674895,
           1.7668169197204622,
           1.7661961927734349,
           1.7655754658264076,
           1.76495473887938,
           1.7643340119323527,
           1.7637132849853254,
           1.763092558038298,
           1.7624718310912706,
           1.7618511041442433,
           1.761230377197216,
           1.7606096502501887,
           1.7599889233031614,
           1.7593681963561338,
           1.7587474694091065,
           1.7581267424620792,
           1.757506015515052,
           1.7568852885680246,
           1.756264561620997,
           1.7556438346739698,
           1.7550231077269425,
           1.7544023807799152,
           1.7537816538328879,
           1.7531609268858603,
           1.753315747321617,
           1.7536256772339307,
           1.7539356071462444,
           1.7542455370585581,
           1.7545554669708716,
           1.7548653968831853,
           1.755175326795499,
           1.7554852567078127,
           1.7557951866201265,
           1.75610511653244,
           1.7564150464447539,
           1.7567249763570674,
           1.757034906269381,
           1.7573448361816946,
           1.7576547660940085,
           1.7579646960063222,
           1.7582746259186357,
           1.7585845558309494,
           1.758894485743263,
           1.7592044156555768,
           1.7595143455678903,
           1.759824275480204,
           1.7601342053925177,
           1.7604441353048315,
           1.7607540652171452,
           1.7610639951294584,
           1.7613739250417724,
           1.761683854954086,
           1.7619937848663996,
           1.7623037147787133,
           1.7626136446910268,
           1.7629235746033407,
           1.7632335045156542,
           1.763543434427968,
           1.7638533643402816,
           1.764163294252595,
           1.764473224164909,
           1.7647831540772225,
           1.7650930839895362,
           1.7654030139018497,
           1.7657129438141634,
           1.7660228737264771,
           1.7663328036387909,
           1.7666427335511046,
           1.766952663463418,
           1.767262593375732,
           1.7675725232880455,
           1.7683697398002274,
           1.7716033906960644,
           1.7748370415919017,
           1.7780706924877392,
           1.7813043433835765,
           1.7845379942794137,
           1.7877716451752512,
           1.7910052960710887,
           1.794238946966926,
           1.7974725978627633,
           1.8007062487586007,
           1.8039398996544382,
           1.8071735505502753,
           1.8104072014461128,
           1.8136408523419503,
           1.8168745032377878,
           1.820108154133625,
           1.8233418050294623,
           1.8265754559252998,
           1.8298091068211373,
           1.8330427577169746,
           1.8362764086128114,
           1.8395100595086489,
           1.8427437104044864,
           1.8459773613003236,
           1.8492110121961611,
           1.8524446630919984,
           1.855678313987836,
           1.8589119648836732,
           1.8621456157795107,
           1.865379266675348,
           1.8686129175711854,
           1.871846568467023,
           1.8750802193628602,
           1.8783138702586974,
           1.8815475211545347,
           1.8846660532832529,
           1.887727026028411,
           1.8907879987735692,
           1.8938489715187274,
           1.8969099442638855,
           1.8999709170090435,
           1.903031889754202,
           1.90609286249936,
           1.9091538352445183,
           1.9122148079896766,
           1.9152757807348346,
           1.918336753479993,
           1.9213977262251511,
           1.9244586989703094,
           1.9275196717154675,
           1.9305806444606257,
           1.9336416172057838,
           1.9367025899509418,
           1.9397635626961003,
           1.9428245354412583,
           1.9458855081864164,
           1.9489464809315746,
           1.9520074536767327,
           1.9550684264218907,
           1.958129399167049,
           1.9611903719122075,
           1.9642513446573657,
           1.9673123174025235,
           1.9703732901476823,
           1.97343426289284,
           1.9764952356379981,
           1.9795562083831568,
           1.9826171811283144,
           1.9856781538734727,
           1.988739126618631,
           1.9918000993637892,
           1.9948610721089475,
           1.9979220448541055,
           2.0009830175992636,
           2.004043990344422,
           2.00710496308958,
           2.010165935834738,
           2.013226908579896,
           2.016287881325055,
           2.0193488540702127,
           2.022409826815371,
           2.0254707995605292,
           2.028531772305687,
           2.0315927450508453,
           2.0346537177960036,
           2.037714690541162,
           2.0407756632863197,
           2.0438366360314784,
           2.046897608776636,
           2.0494567394046364,
           2.050366961334435,
           2.051277183264234,
           2.052187405194033,
           2.0530976271238317,
           2.0540078490536304,
           2.054918070983429,
           2.055828292913228,
           2.0567385148430266,
           2.0576487367728253,
           2.058558958702624,
           2.0594691806324237,
           2.060379402562222,
           2.061289624492021,
           2.0621998464218194,
           2.063110068351618,
           2.064020290281417,
           2.0649305122112156,
           2.0658407341410143,
           2.0667509560708135,
           2.067661178000612,
           2.0685713999304114,
           2.0694816218602097,
           2.070391843790009,
           2.071302065719807,
           2.072212287649606,
           2.073122509579405,
           2.0740327315092038,
           2.0749429534390025,
           2.076895537390334,
           2.079890483363197,
           2.0828854293360597,
           2.085880375308923,
           2.0888753212817863,
           2.091870267254649,
           2.094865213227512,
           2.0978601592003754,
           2.100855105173239,
           2.103850051146102,
           2.106844997118965,
           2.109839943091828,
           2.112834889064691,
           2.1158298350375544,
           2.1188247810104177,
           2.1218197269832806,
           2.124814672956144,
           2.127809618929007,
           2.13080456490187,
           2.133799510874733,
           2.1367944568475963,
           2.13978940282046,
           2.1427843487933225,
           2.145779294766186,
           2.148774240739049,
           2.1517691867119124,
           2.154764132684775,
           2.157759078657638,
           2.1607540246305015,
           2.163748970603365,
           2.1667439165762277,
           2.169738862549091,
           2.172733808521954,
           2.175728754494817,
           2.1787237004676805,
           2.181718646440544,
           2.1847135924134067,
           2.18770853838627,
           2.1907034843591324,
           2.1936984303319957,
           2.1966933763048595,
           2.1996883222777224,
           2.2026832682505857,
           2.2056782142234486,
           2.208673160196312,
           2.2116681061691743,
           2.2146630521420385,
           2.2176579981149014,
           2.2206529440877643,
           2.223647890060627,
           2.2266428360334904,
           2.2299484315288534,
           2.2345743100563125,
           2.2392001885837725,
           2.243826067111232,
           2.248451945638691,
           2.2530778241661515,
           2.257703702693611,
           2.2623295812210706,
           2.26695545974853,
           2.2715813382759897,
           2.2762072168034497,
           2.280833095330909,
           2.285458973858369,
           2.2900848523858284,
           2.294710730913288,
           2.2993366094407475,
           2.303962487968208,
           2.3085883664956666,
           2.3132142450231266,
           2.3178401235505866,
           2.322466002078046,
           2.327091880605505,
           2.3317177591329656,
           2.3363436376604247,
           2.3409695161878843,
           2.3455953947153443,
           2.350221273242804,
           2.354847151770263,
           2.359473030297723,
           2.364098908825183,
           2.3687247873526425,
           2.373350665880102,
           2.379054462451725,
           2.386914095111674,
           2.3947737277716232,
           2.402633360431573,
           2.4104929930915215,
           2.4183526257514707,
           2.4262122584114203,
           2.43407189107137,
           2.441931523731318,
           2.4497911563912678,
           2.4576507890512174,
           2.465510421711166,
           2.473370054371115,
           2.4812296870310644,
           2.489089319691013,
           2.4969489523509627,
           2.504808585010912,
           2.512668217670861,
           2.5205278503308097,
           2.5283874829907598,
           2.5362471156507094,
           2.544106748310658,
           2.5519663809706072,
           2.5598260136305564,
           2.5676856462905056,
           2.5755452789504547,
           2.583404911610404,
           2.5912645442703526,
           2.599124176930302,
           2.6069838095902518,
           2.614843442250201,
           2.6227030749101488,
           2.630562707570099,
           2.638422340230049,
           2.6462819728899976,
           2.6541416055499467,
           2.662001238209896,
           2.669860870869845,
           2.6777205035297937,
           2.6855801361897433,
           2.693439768849692,
           2.701299401509641,
           2.7091590341695904,
           2.7170186668295404,
           2.72487829948949,
           2.7327379321494383,
           2.740597564809388,
           2.748457197469337,
           2.756316830129286,
           2.7641764627892353,
           2.772036095449184,
           2.779895728109133,
           2.787755360769083,
           2.7956149934290324,
           2.8034746260889807,
           2.8113342587489303,
           2.81919389140888,
           2.8270535240688295,
           2.8349131567287778,
           2.8427727893887274,
           2.850632422048676,
           2.857843159717722,
           2.864443178616116,
           2.871043197514509,
           2.8776432164129027,
           2.8842432353112963,
           2.8908432542096905,
           2.8974432731080837,
           2.9040432920064774,
           2.910643310904871,
           2.9172433298032647,
           2.923843348701658,
           2.930443367600052,
           2.9370433864984453,
           2.9436434053968386,
           2.9502434242952322,
           2.956843443193627,
           2.963443462092019,
           2.970043480990413,
           2.976643499888807,
           2.9832435187872,
           2.9898435376855943,
           2.996443556583988,
           3.0039672175448335,
           3.0161090888179443,
           3.0282509600910554,
           3.040392831364168,
           3.052534702637277,
           3.064676573910388,
           3.0768184451834992,
           3.088960316456608,
           3.10110218772972,
           3.113244059002832,
           3.125385930275941,
           3.1375278015490515,
           3.1496696728221627,
           3.1618115440952748,
           3.1739534153683837,
           3.1860952866414953,
           3.198237157914607,
           3.210379029187716,
           3.222520900460827,
           3.230383276290199,
           3.2258352800857897,
           3.221287283881379,
           3.2167392876769685,
           3.2121912914725588,
           3.2076432952681486,
           3.2030952990637385,
           3.198547302859328,
           3.1939993066549186,
           3.189451310450508,
           3.1849033142460974,
           3.1803553180416873,
           3.175807321837277,
           3.171259325632867,
           3.1667113294284572,
           3.1621633332240466,
           3.157615337019636,
           3.153067340815226,
           3.148519344610816,
           3.143971348406406,
           3.1394233522019954,
           3.134875355997586,
           3.1303273597931756,
           3.125779363588765,
           3.1212313673843557,
           3.116683371179945,
           3.112135374975535,
           3.1075873787711252,
           3.103039382566715,
           3.0984913863623045,
           3.093943390157894,
           3.089395393953484,
           3.084847397749074,
           3.0802994015446634,
           3.075751405340254,
           3.0712034091358436,
           3.066655412931433,
           3.0621074167270237,
           3.0575594205226135,
           3.053011424318203,
           3.0484634281137923,
           3.043915431909383,
           3.039367435704972,
           3.034819439500562,
           3.030271443296152,
           3.0257234470917416,
           3.0093405188942355,
           2.9917907302617976,
           2.974240941629357,
           2.9566911529969158,
           2.939141364364478,
           2.921591575732037,
           2.904041787099596,
           2.8864919984671547,
           2.8689422098347173,
           2.8513924212022763,
           2.833842632569835,
           2.816292843937397,
           2.7987430553049566,
           2.781193266672515,
           2.7636434780400774,
           2.7460936894076364,
           2.728543900775195,
           2.710994112142754,
           2.6934443235103167
          ],
          [
           2.1715177969745167,
           2.174104009733143,
           2.176690222491769,
           2.1792764352503946,
           2.181862648009021,
           2.184448860767647,
           2.187035073526273,
           2.189621286284899,
           2.1922074990435254,
           2.194793711802151,
           2.1973799245607775,
           2.1999661373194037,
           2.2025523500780295,
           2.2051385628366558,
           2.207724775595282,
           2.210310988353908,
           2.212897201112534,
           2.2154834138711603,
           2.218069626629786,
           2.2206558393884124,
           2.2232420521470386,
           2.2258282649056644,
           2.2284144776642902,
           2.231000690422917,
           2.2335869031815427,
           2.236173115940169,
           2.238759328698795,
           2.241345541457421,
           2.2439317542160473,
           2.246517966974673,
           2.2491041797332993,
           2.251690392491925,
           2.254276605250552,
           2.2568628180091777,
           2.2594490307678035,
           2.2620352435264297,
           2.264621456285056,
           2.267207669043682,
           2.269793881802308,
           2.2723800945609343,
           2.27496630731956,
           2.2775525200781863,
           2.2801387328368126,
           2.282724945595439,
           2.2853111583540646,
           2.287897371112691,
           2.2904835838713167,
           2.2930697966299434,
           2.295656009388569,
           2.298242222147195,
           2.3008284349058217,
           2.3034146476644475,
           2.3060008604230733,
           2.305380133752121,
           2.3047594068050934,
           2.304138679858066,
           2.303517952911039,
           2.3028972259640113,
           2.302276499016984,
           2.3016557720699566,
           2.301035045122929,
           2.300414318175902,
           2.2997935912288745,
           2.2991728642818474,
           2.29855213733482,
           2.297931410387793,
           2.2973106834407653,
           2.296689956493738,
           2.2960692295467107,
           2.295448502599683,
           2.294827775652656,
           2.2942070487056285,
           2.2935863217586014,
           2.292965594811574,
           2.2923448678645464,
           2.2917241409175193,
           2.2911034139704918,
           2.2904826870234647,
           2.289861960076437,
           2.2892412331294096,
           2.2886205061823826,
           2.287999779235355,
           2.287379052288328,
           2.2867583253413004,
           2.2869131457770573,
           2.2872230756893708,
           2.2875330056016847,
           2.287842935513998,
           2.2881528654263117,
           2.2884627953386256,
           2.288772725250939,
           2.289082655163253,
           2.289392585075566,
           2.28970251498788,
           2.290012444900194,
           2.2903223748125074,
           2.290632304724821,
           2.2909422346371344,
           2.2912521645494484,
           2.2915620944617623,
           2.291872024374076,
           2.2921819542863893,
           2.292491884198703,
           2.2928018141110167,
           2.2931117440233306,
           2.293421673935644,
           2.2937316038479576,
           2.294041533760271,
           2.294351463672585,
           2.294661393584899,
           2.294971323497212,
           2.295281253409526,
           2.2955911833218394,
           2.2959011132341534,
           2.2962110431464673,
           2.298470120632824,
           2.3017037715286612,
           2.3049374224244983,
           2.308171073320336,
           2.3114047242161737,
           2.3146383751120108,
           2.3178720260078483,
           2.3211056769036853,
           2.324339327799523,
           2.3275729786953603,
           2.3308066295911973,
           2.3340402804870353,
           2.3372739313828723,
           2.3405075822787094,
           2.3437412331745473,
           2.3469748840703843,
           2.350208534966222,
           2.3534421858620593,
           2.3566758367578964,
           2.359909487653734,
           2.363143138549571,
           2.3663767894454084,
           2.369610440341246,
           2.3728440912370834,
           2.376077742132921,
           2.379311393028758,
           2.382545043924595,
           2.385778694820433,
           2.38901234571627,
           2.3922459966121075,
           2.395479647507945,
           2.3987132984037824,
           2.40194694929962,
           2.405180600195457,
           2.4084142510912945,
           2.4116479019871315,
           2.4148815528829695,
           2.4181152037788065,
           2.4213488546746436,
           2.4245825055704815,
           2.4278161564663185,
           2.4310498073621556,
           2.4342834582579935,
           2.4375171091538306,
           2.4407507600496676,
           2.4439844109455056,
           2.4472180618413426,
           2.4504517127371805,
           2.4536853636330176,
           2.4569190145288546,
           2.460152665424692,
           2.4633863163205296,
           2.4665048484492478,
           2.4695658211944056,
           2.472626793939564,
           2.4756877666847217,
           2.4787487394298804,
           2.4818097121750387,
           2.4848706849201965,
           2.487931657665355,
           2.490992630410513,
           2.4940536031556713,
           2.4971145759008295,
           2.500175548645988,
           2.5032365213911456,
           2.5062974941363043,
           2.509358466881462,
           2.51241943962662,
           2.5154804123717787,
           2.518541385116937,
           2.521602357862095,
           2.524663330607253,
           2.527724303352411,
           2.530785276097569,
           2.5338462488427274,
           2.536907221587886,
           2.539968194333044,
           2.543029167078202,
           2.5460901398233604,
           2.5491511125685182,
           2.552212085313677,
           2.5552730580588348,
           2.558334030803993,
           2.5613950035491513,
           2.5644559762943095,
           2.5675169490394674,
           2.5705779217846256,
           2.5736388945297843,
           2.576699867274942,
           2.5797608400201,
           2.5828218127652587,
           2.5858827855104165,
           2.5889437582555743,
           2.592004731000733,
           2.595065703745891,
           2.598126676491049,
           2.6011876492362074,
           2.6042486219813656,
           2.6073095947265235,
           2.610370567471682,
           2.6134315402168404,
           2.6164925129619983,
           2.619553485707157,
           2.622614458452315,
           2.625675431197473,
           2.6287364039426313,
           2.6317973766877896,
           2.6348583494329474,
           2.6379193221781057,
           2.640980294923264,
           2.644041267668422,
           2.6471022404135804,
           2.650163213158738,
           2.6532241859038965,
           2.656285158649055,
           2.659346131394213,
           2.662407104139371,
           2.665468076884529,
           2.6685290496296874,
           2.6715900223748457,
           2.6746509951200044,
           2.677711967865162,
           2.6807729406103196,
           2.6838339133554783,
           2.6868948861006365,
           2.689955858845795,
           2.693016831590953,
           2.6960778043361113,
           2.699138777081269,
           2.702199749826428,
           2.705260722571586,
           2.708321695316744,
           2.709375300918132,
           2.7102855228479306,
           2.711195744777729,
           2.7131483287290603,
           2.716143274701923,
           2.7191382206747865,
           2.7221331666476494,
           2.7251281126205127,
           2.7281230585933756,
           2.731719896255384,
           2.736345774782844,
           2.740971653310304,
           2.745597531837763,
           2.750223410365223,
           2.7548492888926828,
           2.759475167420142,
           2.7641010459476014,
           2.768726924475062,
           2.773352803002521,
           2.7779786815299805,
           2.7826045600574405,
           2.7872304385849,
           2.791856317112359,
           2.796482195639819,
           2.801108074167279,
           2.8057339526947382,
           2.8103598312221982,
           2.8149857097496582,
           2.8196115882771173,
           2.8242374668045773,
           2.828863345332037,
           2.8334892238594964,
           2.838115102386956,
           2.842740980914416,
           2.847366859441876,
           2.8519927379693346,
           2.856618616496794,
           2.861244495024255,
           2.865870373551714,
           2.8704962520791737,
           2.8751221306066332,
           2.879748009134093,
           2.8843738876615523,
           2.888999766189012,
           2.8936256447164714,
           2.898251523243931,
           2.9028774017713914,
           2.9075032802988514,
           2.9121291588263105,
           2.91675503735377,
           2.9213809158812305,
           2.9260067944086896,
           2.9306326729361487,
           2.935258551463609,
           2.9398844299910687,
           2.9445103085185282,
           2.949136187045988,
           2.9537620655734473,
           2.958387944100907,
           2.9630138226283664,
           2.967639701155827,
           2.972265579683286,
           2.976891458210746,
           2.9815173367382055,
           2.986143215265665,
           2.9907690937931246,
           2.995394972320584,
           3.0000208508480437,
           3.0046467293755033,
           3.0092726079029632,
           3.0138984864304232,
           3.018524364957882,
           3.023150243485342,
           3.027776122012802,
           3.0324020005402614,
           3.037027879067721,
           3.0416537575951805,
           3.04627963612264,
           3.0509055146500996,
           3.055531393177559,
           3.0601572717050187,
           3.0647831502324783,
           3.0694090287599383,
           3.0740349072873987,
           3.078660785814858,
           3.0832866643423174,
           3.0889904609139407,
           3.09685009357389,
           3.104709726233839,
           3.1125693588937877,
           3.120428991553737,
           3.128288624213686,
           3.1361482568736356,
           3.144007889533585,
           3.151867522193534,
           3.159727154853483,
           3.1675867875134327,
           3.1754464201733814,
           3.183306052833331,
           3.19116568549328,
           3.199025318153229,
           3.206884950813178,
           3.214744583473127,
           3.222604216133077,
           3.2304638487930255,
           3.238323481452975,
           3.2461831141129247,
           3.254042746772874,
           3.2619023794328226,
           3.269762012092772,
           3.277621644752721,
           3.28548127741267,
           3.2933409100726196,
           3.301200542732569,
           3.309060175392518,
           3.3169198080524667,
           3.3247794407124167,
           3.3326390733723645,
           3.340498706032314,
           3.348358338692264,
           3.356217971352213,
           3.364077604012162,
           3.371937236672111,
           3.379796869332061,
           3.3876565019920095,
           3.3955161346519587,
           3.403375767311908,
           3.411235399971857,
           3.419095032631806,
           3.426954665291756,
           3.434814297951705,
           3.4426739306116536,
           3.4505335632716037,
           3.4583931959315524,
           3.466252828591501,
           3.4741124612514507,
           3.4819720939114,
           3.4898317265713485,
           3.4976913592312986,
           3.5074983088297147,
           3.518031866020869,
           3.528565423212025,
           3.539098980403182,
           3.549632537594337,
           3.5601660947854925,
           3.570699651976649,
           3.5812332091678045,
           3.5917667663589596,
           3.602300323550116,
           3.6128338807412717,
           3.623367437932427,
           3.633900995123583,
           3.64443455231474,
           3.6549681095058943,
           3.6655016666970512,
           3.6760352238882072,
           3.6865687810793624,
           3.6971023382705184,
           3.7076358954616744,
           3.7181694526528295,
           3.728703009843985,
           3.7392365670351415,
           3.7497701242262984,
           3.7603036814174526,
           3.770837238608609,
           3.781370795799765,
           3.7919043529909207,
           3.8024379101820758,
           3.8129714673732327,
           3.8237105422563307,
           3.835477205599149,
           3.8472438689419666,
           3.8590105322847843,
           3.8707771956276003,
           3.882543858970418,
           3.894310522313236,
           3.906077185656051,
           3.91784384899887,
           3.9296105123416876,
           3.941377175684503,
           3.9531438390273212,
           3.9649105023701385,
           3.9766771657129567,
           3.986676409219971,
           3.9821284130155603,
           3.9775804168111497,
           3.9730324206067404,
           3.96848442440233,
           3.9639364281979192,
           3.95938843199351,
           3.9548404357891,
           3.950292439584689,
           3.9457444433802795,
           3.9411964471758685,
           3.9366484509714583,
           3.932100454767048,
           3.9275524585626385,
           3.923004462358228,
           3.9184564661538177,
           3.9139084699494084,
           3.9093604737449974,
           3.9048124775405872,
           3.900264481336178,
           3.895716485131767,
           3.8911684889273572,
           3.8866204927229466,
           3.882072496518537,
           3.8775245003141268,
           3.872976504109716,
           3.868428507905306,
           3.863880511700896,
           3.8593325154964857,
           3.8547845192920764,
           3.850236523087666,
           3.8456885268832552,
           3.8411405306788455,
           3.836592534474435,
           3.832044538270025,
           3.8274965420656146,
           3.8229485458612045,
           3.8184005496567943,
           3.813852553452384,
           3.8093045572479745,
           3.804756561043564,
           3.8002085648391537,
           3.7956605686347444,
           3.7911125724303343,
           3.7865645762259232,
           3.782016580021513,
           3.777468583817103,
           3.7729205876126928,
           3.7683725914082826,
           3.7638245952038725,
           3.7592765989994623,
           3.754728602795052,
           3.7501806065906425,
           3.745632610386232,
           3.7410846141818217,
           3.734453201391635,
           3.69418955290264,
           3.6539259044136436,
           3.6136622559246483,
           3.5733986074356596,
           3.533134958946664,
           3.4928713104576676,
           3.4526076619686794,
           3.412344013479683,
           3.3720803649906874,
           3.3318167165016987,
           3.2915530680127034,
           3.251289419523707,
           3.2110257710347114,
           3.170762122545723
          ],
          [
           2.652200689757539,
           2.6547869025161654,
           2.6573731152747913,
           2.6599593280334175,
           2.6625455407920438,
           2.6651317535506696,
           2.667717966309296,
           2.6703041790679216,
           2.672890391826548,
           2.6754766045851737,
           2.6780628173438004,
           2.680649030102426,
           2.683235242861052,
           2.6858214556196787,
           2.6884076683783045,
           2.690993881136931,
           2.6935800938955565,
           2.6961663066541828,
           2.698752519412809,
           2.7013387321714353,
           2.703924944930061,
           2.706511157688687,
           2.709097370447313,
           2.7116835832059394,
           2.714269795964565,
           2.716856008723192,
           2.7194422214818177,
           2.722028434240444,
           2.72461464699907,
           2.727200859757696,
           2.7297870725163222,
           2.732373285274948,
           2.7349594980335743,
           2.7375457107922,
           2.740131923550827,
           2.7427181363094526,
           2.7453043490680784,
           2.747890561826705,
           2.750476774585331,
           2.7530629873439567,
           2.755649200102583,
           2.758235412861209,
           2.760821625619835,
           2.7634078383784613,
           2.7659940511370875,
           2.7685802638957133,
           2.7711664766543396,
           2.773752689412966,
           2.7763389021715916,
           2.7789251149302174,
           2.781511327688844,
           2.78409754044747,
           2.786683753206096,
           2.7892699659647224,
           2.7918561787233482,
           2.7944423914819745,
           2.7970286042406007,
           2.799614816999227,
           2.802201029757853,
           2.8047872425164786,
           2.8073734552751053,
           2.809959668033731,
           2.812545880792357,
           2.815132093550983,
           2.8177183063096094,
           2.8203045190682356,
           2.8228907318268615,
           2.8254769445854877,
           2.828063157344114,
           2.8290459010551334,
           2.828425174108106,
           2.827804447161079,
           2.8271837202140513,
           2.8265629932670238,
           2.8259422663199967,
           2.825321539372969,
           2.824700812425942,
           2.8240800854789145,
           2.823459358531887,
           2.82283863158486,
           2.8222179046378324,
           2.8215971776908053,
           2.820976450743778,
           2.8203557237967503,
           2.820510544232507,
           2.820820474144821,
           2.8211304040571346,
           2.821440333969448,
           2.8217502638817615,
           2.8220601937940755,
           2.8223701237063894,
           2.822680053618703,
           2.8229899835310164,
           2.82329991344333,
           2.823609843355644,
           2.8239197732679577,
           2.824229703180271,
           2.8245396330925847,
           2.8253368505695944,
           2.828570501465432,
           2.831804152361269,
           2.8350378032571064,
           2.838271454152944,
           2.841505105048781,
           2.8447387559446184,
           2.847972406840456,
           2.8512060577362934,
           2.85443970863213,
           2.857673359527968,
           2.8609070104238055,
           2.8641406613196425,
           2.86737431221548,
           2.8706079631113175,
           2.8738416140071545,
           2.877075264902992,
           2.8803089157988295,
           2.883542566694667,
           2.8867762175905045,
           2.8900098684863416,
           2.893243519382179,
           2.8964771702780165,
           2.899710821173854,
           2.902944472069691,
           2.906178122965529,
           2.909411773861366,
           2.912645424757203,
           2.915879075653041,
           2.919112726548878,
           2.9223463774447156,
           2.925580028340553,
           2.9288136792363906,
           2.932047330132228,
           2.935280981028065,
           2.938514631923902,
           2.9417482828197397,
           2.944981933715577,
           2.9482155846114146,
           2.9514492355072517,
           2.954682886403089,
           2.9579165372989262,
           2.9611501881947637,
           2.964383839090601,
           2.9676174899864387,
           2.9708511408822758,
           2.9740847917781137,
           2.9773184426739507,
           2.9805520935697882,
           2.9837857444656253,
           2.9870193953614628,
           2.9902530462573003,
           2.9934866971531378,
           2.9967203480489752,
           2.999953998944812,
           3.0031876498406493,
           3.0064213007364873,
           3.0096549516323243,
           3.0128886025281614,
           3.016122253423999,
           3.0193559043198364,
           3.022589555215674,
           3.025823206111511,
           3.0290568570073484,
           3.032290507903186,
           3.0355241587990234,
           3.0387578096948604,
           3.041991460590698,
           3.0452251114865354,
           3.0483436436152536,
           3.0514046163604114,
           3.05446558910557,
           3.057526561850728,
           3.060587534595886,
           3.063648507341045,
           3.0667094800862027,
           3.069770452831361,
           3.072831425576519,
           3.075892398321677,
           3.0789533710668353,
           3.0820143438119936,
           3.085075316557152,
           3.0881362893023097,
           3.0911972620474684,
           3.094258234792626,
           3.0973192075377844,
           3.1003801802829427,
           3.103441153028101,
           3.106502125773259,
           3.1095630985184166,
           3.112624071263575,
           3.115685044008733,
           3.118746016753892,
           3.1218069894990492,
           3.1248679622442075,
           3.1279289349893666,
           3.1309899077345236,
           3.1340508804796827,
           3.137111853224841,
           3.140172825969999,
           3.1432337987151566,
           3.1462947714603153,
           3.149355744205473,
           3.1524167169506314,
           3.1554776896957897,
           3.1585386624409475,
           3.161599635186106,
           3.164660607931264,
           3.1677215806764223,
           3.1707825534215806,
           3.1738435261667384,
           3.177476630930455,
           3.1816818660607,
           3.185887101190945,
           3.1900923363211904,
           3.1942975714514352,
           3.19850280658168,
           3.202708041711925,
           3.2069132768421706,
           3.2111185119724155,
           3.215323747102661,
           3.2195289822329056,
           3.223734217363151,
           3.227939452493396,
           3.2321446876236406,
           3.236349922753886,
           3.240555157884131,
           3.244760393014376,
           3.2489656281446218,
           3.2531708632748666,
           3.257376098405112,
           3.261581333535357,
           3.2657865686656016,
           3.269991803795847,
           3.274197038926092,
           3.278402274056337,
           3.2826075091865823,
           3.2868127443168276,
           3.2910179794470724,
           3.2952232145773173,
           3.2994284497075625,
           3.3036336848378083,
           3.307838919968053,
           3.312044155098298,
           3.3162493902285433,
           3.3204546253587885,
           3.3246598604890334,
           3.3288650956192782,
           3.3330703307495235,
           3.3372755658797684,
           3.3414808010100137,
           3.345686036140259,
           3.3506073169638704,
           3.3562446434808493,
           3.3618819699978273,
           3.3675192965148053,
           3.373156623031784,
           3.378793949548762,
           3.384431276065741,
           3.3900686025827196,
           3.395705929099698,
           3.401343255616676,
           3.406980582133655,
           3.412617908650633,
           3.4182552351676114,
           3.4238925616845894,
           3.4295298882015683,
           3.4351672147185464,
           3.440804541235525,
           3.4464418677525037,
           3.4520791942694817,
           3.4577165207864597,
           3.4633538473034386,
           3.4689911738204176,
           3.4746285003373956,
           3.4802658268543745,
           3.4859031533713525,
           3.4915404798883305,
           3.497177806405309,
           3.5028151329222874,
           3.508452459439266,
           3.5140897859562434,
           3.5197271124732223,
           3.5253644389902012,
           3.5310017655071793,
           3.5366390920241573,
           3.542276418541136,
           3.547913745058115,
           3.5535510715750926,
           3.5591883980920715,
           3.56482572460905,
           3.570463051126028,
           3.576100377643007,
           3.581737704159985,
           3.587375030676963,
           3.593012357193942,
           3.5986496837109208,
           3.6042870102278988,
           3.6099243367448772,
           3.6155616632618557,
           3.6211989897788337,
           3.6268363162958126,
           3.6324736428127915,
           3.6381109693297695,
           3.6437482958467475,
           3.649385622363726,
           3.6550229488807044,
           3.660660275397682,
           3.6662976019146605,
           3.6719349284316394,
           3.6775722549486183,
           3.6832095814655963,
           3.6888469079825748,
           3.694484234499553,
           3.7001215610165317,
           3.7053309707828133,
           3.7099568493102733,
           3.714582727837733,
           3.7192086063651923,
           3.7238344848926523,
           3.728460363420112,
           3.733086241947571,
           3.7377121204750314,
           3.7423379990024905,
           3.74696387752995,
           3.7515897560574105,
           3.756215634584869,
           3.7608415131123287,
           3.765467391639789,
           3.7700932701672483,
           3.774719148694708,
           3.7793450272221674,
           3.783970905749628,
           3.7885967842770873,
           3.7932226628045465,
           3.7989264593761702,
           3.806786092036119,
           3.8146457246960677,
           3.8225053573560177,
           3.8303649900159664,
           3.838224622675915,
           3.846084255335865,
           3.8539438879958148,
           3.861803520655763,
           3.869663153315712,
           3.877522785975662,
           3.885382418635611,
           3.895857852843657,
           3.906391410034814,
           3.9169249672259694,
           3.927458524417124,
           3.937992081608281,
           3.9485256387994365,
           3.9590591959905916,
           3.969592753181748,
           3.980126310372904,
           3.9906598675640597,
           4.001193424755215,
           4.011726981946372,
           4.022260539137528,
           4.032794096328683,
           4.043327653519839,
           4.053861210710995,
           4.06439476790215,
           4.074928325093306,
           4.085461882284462,
           4.095995439475617,
           4.106528996666773,
           4.117062553857929,
           4.127596111049085,
           4.138129668240241,
           4.148663225431397,
           4.159196782622553,
           4.169730339813707,
           4.180263897004865,
           4.190797454196019,
           4.201331011387175,
           4.211864568578331,
           4.222398125769488,
           4.232931682960643,
           4.243465240151799,
           4.253998797342955,
           4.2645323545341105,
           4.275065911725266,
           4.285599468916422,
           4.296133026107578,
           4.306666583298734,
           4.31720014048989,
           4.3277336976810465,
           4.3382672548722,
           4.348800812063357,
           4.359334369254514,
           4.369867926445669,
           4.380401483636824,
           4.390935040827982,
           4.401468598019136,
           4.412002155210291,
           4.422535712401449,
           4.433069269592603,
           4.443602826783759,
           4.454136383974915,
           4.464669941166071,
           4.475203498357225,
           4.485737055548382,
           4.496270612739538,
           4.506804169930694,
           4.51733772712185,
           4.527871284313006,
           4.538404841504161,
           4.5489383986953165,
           4.559471955886473,
           4.57000551307763,
           4.5805390702687845,
           4.5910726274599405,
           4.6016061846510965,
           4.6121397418422525,
           4.622673299033408,
           4.6332068562245645,
           4.6439459311076625,
           4.65571259445048,
           4.667479257793298,
           4.679245921136116,
           4.691012584478932,
           4.70277924782175,
           4.714545911164567,
           4.726312574507383,
           4.738079237850202,
           4.7498459011930185,
           4.7616125645358345,
           4.773379227878653,
           4.78514589122147,
           4.796912554564288,
           4.808679217907104,
           4.820445881249922,
           4.832212544592739,
           4.843979207935556,
           4.855745871278374,
           4.867512534621191,
           4.879279197964006,
           4.891045861306825,
           4.902812524649644,
           4.914579187992459,
           4.926345851335276,
           4.938112514678094,
           4.949879178020911,
           4.961645841363727,
           4.973412504706546,
           4.985179168049363,
           4.996945831392179,
           5.008712494734997,
           5.020479158077816,
           5.0300705381918585,
           5.025522541987447,
           5.020974545783037,
           5.016426549578627,
           5.011878553374217,
           5.007330557169807,
           5.002782560965397,
           4.998234564760987,
           4.993686568556576,
           4.989138572352166,
           4.984590576147757,
           4.980042579943346,
           4.975494583738935,
           4.970946587534526,
           4.966398591330115,
           4.961850595125705,
           4.957302598921295,
           4.951564070661171,
           4.911300422172175,
           4.87103677368318,
           4.830773125194191,
           4.7905094767051954,
           4.750245828216199,
           4.709982179727211,
           4.669718531238216,
           4.629454882749219,
           4.589191234260223,
           4.548927585771236,
           4.508663937282239,
           4.4684002887932435,
           4.428136640304254,
           4.387872991815259,
           4.347609343326264,
           4.3073456948372755,
           4.267082046348278,
           4.226818397859283,
           4.186554749370295,
           4.146291100881299,
           4.106027452392303,
           4.065763803903307,
           4.025500155414319,
           3.9852365069253226,
           3.944972858436327,
           3.904709209947339,
           3.8644455614583424,
           3.824181912969347,
           3.7839182644803584,
           3.7436546159913626,
           3.7033909675023673,
           3.6631273190133706,
           3.622863670524383
          ],
          [
           3.132652600620325,
           3.1352388133789506,
           3.1378250261375764,
           3.1404112388962027,
           3.142997451654829,
           3.145583664413455,
           3.148169877172081,
           3.150756089930707,
           3.1533423026893335,
           3.1559285154479593,
           3.158514728206586,
           3.1611009409652113,
           3.1636871537238376,
           3.1662733664824643,
           3.16885957924109,
           3.171445791999716,
           3.1740320047583417,
           3.1766182175169684,
           3.179204430275594,
           3.1817906430342204,
           3.1843768557928467,
           3.1869630685514725,
           3.1895492813100983,
           3.192135494068725,
           3.194721706827351,
           3.197307919585977,
           3.199894132344603,
           3.202480345103229,
           3.2050665578618553,
           3.207652770620481,
           3.2102389833791074,
           3.212825196137733,
           3.2154114088963595,
           3.2179976216549857,
           3.2205838344136115,
           3.2231700471722378,
           3.225756259930864,
           3.22834247268949,
           3.2309286854481165,
           3.233514898206742,
           3.236101110965368,
           3.2386873237239944,
           3.2412735364826206,
           3.2438597492412464,
           3.2464459619998727,
           3.249032174758499,
           3.2516183875171247,
           3.254204600275751,
           3.2567908130343772,
           3.259377025793003,
           3.2619632385516297,
           3.2645494513102555,
           3.2671356640688813,
           3.269721876827508,
           3.272308089586134,
           3.2748943023447596,
           3.2774805151033863,
           3.280066727862012,
           3.282652940620638,
           3.285239153379264,
           3.2878253661378904,
           3.2904115788965167,
           3.2929977916551425,
           3.2955840044137683,
           3.298170217172395,
           3.300756429931021,
           3.3033426426896466,
           3.3059288554482733,
           3.308515068206899,
           3.3111012809655254,
           3.313687493724151,
           3.3162737064827774,
           3.3188599192414037,
           3.3214461320000295,
           3.324032344758656,
           3.326618557517282,
           3.3292047702759078,
           3.3317909830345336,
           3.33437719579316,
           3.3369634085517865,
           3.3395496213104123,
           3.342135834069038,
           3.3468700994957112,
           3.3526783892454124,
           3.3588003129378365,
           3.364984963418806,
           3.368218615542514,
           3.3714522664383515,
           3.374685917334189,
           3.3779195682300265,
           3.3811532191258635,
           3.384386870021701,
           3.3876205209175385,
           3.3908541718133756,
           3.394087822709213,
           3.3973214736050505,
           3.400555124500888,
           3.403788775396725,
           3.4070224262925626,
           3.4102560771884,
           3.413489728084237,
           3.4167233789800746,
           3.4199570298759125,
           3.423190680771749,
           3.4264243316675866,
           3.429657982563424,
           3.4328916334592616,
           3.4361252843550987,
           3.4393589352509366,
           3.442592586146774,
           3.4458262370426107,
           3.449059887938448,
           3.4522935388342857,
           3.455527189730123,
           3.4587608406259607,
           3.461994491521798,
           3.4652281424176357,
           3.4684617933134727,
           3.4716954442093098,
           3.4749290951051472,
           3.4781627460009847,
           3.4813963968968222,
           3.4846300477926597,
           3.487863698688497,
           3.4910973495843347,
           3.4943310004801713,
           3.4975646513760092,
           3.5007983022718467,
           3.504031953167684,
           3.5072656040635213,
           3.5104992549593588,
           3.5137329058551963,
           3.5169665567510333,
           3.520200207646871,
           3.5234338585427083,
           3.5266675094385453,
           3.529901160334383,
           3.5331348112302203,
           3.536368462126058,
           3.5396021130218953,
           3.542835763917732,
           3.54606941481357,
           3.549303065709407,
           3.5525367166052444,
           3.555770367501082,
           3.559004018396919,
           3.562237669292757,
           3.5654713201885944,
           3.568704971084431,
           3.571938621980269,
           3.575172272876106,
           3.5784059237719434,
           3.5816395746677805,
           3.5848732255636175,
           3.588106876459455,
           3.5913405273552925,
           3.59457417825113,
           3.5978078291469675,
           3.601041480042805,
           3.6042751309386425,
           3.6075087818344795,
           3.610742432730317,
           3.6139760836261545,
           3.6172097345219916,
           3.620443385417829,
           3.6236770363136666,
           3.6269106872095036,
           3.631916503836616,
           3.6378084033293647,
           3.6437003028221135,
           3.6495922023148624,
           3.653797438582505,
           3.6580026737127502,
           3.6622079088429955,
           3.666413143973241,
           3.6706183791034857,
           3.6748236142337305,
           3.6790288493639762,
           3.683234084494221,
           3.687439319624466,
           3.691644554754711,
           3.6958497898849556,
           3.7000550250152013,
           3.704260260145446,
           3.708465495275691,
           3.7126707304059368,
           3.7168759655361816,
           3.721081200666427,
           3.725286435796672,
           3.729491670926917,
           3.733696906057162,
           3.7379021411874076,
           3.742107376317652,
           3.7463126114478977,
           3.750517846578142,
           3.754723081708388,
           3.7589283168386327,
           3.763133551968878,
           3.7673387870991233,
           3.771544022229368,
           3.775749257359613,
           3.779954492489858,
           3.7841597276201036,
           3.7883649627503493,
           3.7925701978805932,
           3.7967754330108385,
           3.800980668141084,
           3.805185903271329,
           3.8093911384015744,
           3.8135963735318192,
           3.817801608662064,
           3.8220068437923094,
           3.8262120789225547,
           3.8304173140527995,
           3.8346225491830443,
           3.8388277843132896,
           3.843033019443535,
           3.8472382545737798,
           3.8514434897040246,
           3.8556487248342695,
           3.859853959964515,
           3.86405919509476,
           3.8682644302250058,
           3.8724696653552506,
           3.8766749004854955,
           3.8808801356157403,
           3.885085370745985,
           3.889290605876231,
           3.893495841006476,
           3.897701076136721,
           3.9019063112669663,
           3.906111546397211,
           3.9103167815274564,
           3.9145220166577017,
           3.9187272517879466,
           3.9229324869181914,
           3.9271377220484367,
           3.931342957178682,
           3.935548192308927,
           3.9397534274391726,
           3.9439586625694174,
           3.9481638976996623,
           3.952369132829908,
           3.9565743679601524,
           3.960779603090398,
           3.9649848382206425,
           3.969190073350888,
           3.973395308481133,
           3.977600543611378,
           3.981805778741623,
           3.9867270595652347,
           3.992364386082213,
           3.998001712599191,
           4.0036390391161705,
           4.0092763656331485,
           4.014913692150127,
           4.0205510186671045,
           4.026188345184083,
           4.031825671701062,
           4.03746299821804,
           4.043100324735019,
           4.048737651251998,
           4.054374977768976,
           4.060012304285953,
           4.065649630802932,
           4.071286957319911,
           4.07692428383689,
           4.082561610353868,
           4.088198936870846,
           4.093836263387824,
           4.099473589904803,
           4.105110916421782,
           4.11074824293876,
           4.116385569455738,
           4.122022895972717,
           4.127660222489695,
           4.133297549006674,
           4.138934875523652,
           4.14457220204063,
           4.150209528557609,
           4.155846855074587,
           4.1614841815915655,
           4.1671215081085435,
           4.172758834625522,
           4.1783961611425005,
           4.1840334876594785,
           4.189670814176457,
           4.195308140693435,
           4.200945467210414,
           4.206582793727392,
           4.212220120244371,
           4.217857446761349,
           4.223494773278327,
           4.229132099795306,
           4.234769426312285,
           4.240406752829262,
           4.246044079346241,
           4.25168140586322,
           4.257318732380198,
           4.262956058897176,
           4.268593385414155,
           4.274230711931134,
           4.279868038448112,
           4.28550536496509,
           4.291142691482069,
           4.296780017999047,
           4.302417344516025,
           4.308054671033004,
           4.313691997549983,
           4.319329324066961,
           4.324966650583939,
           4.3306039771009175,
           4.336241303617896,
           4.341878630134874,
           4.349078156778685,
           4.357473437217189,
           4.365868717655694,
           4.374263998094198,
           4.382659278532701,
           4.391054558971206,
           4.39944983940971,
           4.407845119848214,
           4.416240400286718,
           4.424635680725222,
           4.433030961163727,
           4.441426241602231,
           4.449821522040736,
           4.458216802479239,
           4.466612082917743,
           4.475007363356248,
           4.4834026437947525,
           4.491797924233257,
           4.500193204671761,
           4.5096714771755755,
           4.521315733810009,
           4.532959990444443,
           4.544604247078878,
           4.556248503713311,
           4.567892760347745,
           4.579537016982179,
           4.591181273616614,
           4.602825530251048,
           4.614469786885481,
           4.626114043519917,
           4.63775830015435,
           4.649402556788784,
           4.661046813423218,
           4.6726910700576525,
           4.684335326692086,
           4.695979583326521,
           4.707623839960954,
           4.719268096595387,
           4.730912353229823,
           4.742556609864257,
           4.7542008664986914,
           4.765845123133125,
           4.77748937976756,
           4.789133636401994,
           4.800777893036427,
           4.812422149670862,
           4.824066406305295,
           4.835710662939729,
           4.847354919574164,
           4.858999176208599,
           4.870643432843032,
           4.882287689477466,
           4.8939319461119,
           4.905576202746334,
           4.917220459380768,
           4.928864716015203,
           4.940508972649637,
           4.95215322928407,
           4.963797485918505,
           4.975441742552938,
           4.9870859991873715,
           4.9987302558218065,
           5.010374512456241,
           5.022018769090675,
           5.033663025725109,
           5.045307282359543,
           5.056951538993977,
           5.0685957956284104,
           5.080240052262845,
           5.091884308897279,
           5.103528565531713,
           5.115172822166147,
           5.126817078800582,
           5.138461335435014,
           5.150105592069449,
           5.161749848703884,
           5.173394105338319,
           5.185038361972751,
           5.196682618607187,
           5.20832687524162,
           5.219971131876053,
           5.231615388510488,
           5.2432596451449225,
           5.254903901779355,
           5.266548158413791,
           5.278192415048226,
           5.289836671682658,
           5.301480928317092,
           5.313125184951527,
           5.3247694415859605,
           5.336413698220394,
           5.34805795485483,
           5.358640230355477,
           5.369173787546633,
           5.379707344737789,
           5.390240901928946,
           5.4007744591200995,
           5.411308016311256,
           5.421841573502412,
           5.432375130693568,
           5.4429086878847235,
           5.4534422450758795,
           5.464181319958978,
           5.475947983301796,
           5.487714646644614,
           5.499481309987432,
           5.5112479733302475,
           5.523014636673065,
           5.534781300015883,
           5.536906148947357,
           5.519747507463664,
           5.5025888659799715,
           5.485430224496282,
           5.468271583012591,
           5.451112941528898,
           5.433954300045205,
           5.416795658561515,
           5.399637017077822,
           5.382478375594129,
           5.3653197341104395,
           5.348161092626748,
           5.331002451143055,
           5.313843809659366,
           5.296685168175674,
           5.279526526691981,
           5.262367885208292,
           5.245209243724599,
           5.228050602240907,
           5.210891960757214,
           5.193733319273525,
           5.176574677789832,
           5.159416036306139,
           5.142257394822449,
           5.125098753338758,
           5.107940111855065,
           5.090781470371375,
           5.073622828887682,
           5.056464187403989,
           5.039305545920298,
           5.0221469044366085,
           5.004988262952915,
           4.987829621469223,
           4.970670979985535,
           4.953512338501842,
           4.9363536970181485,
           4.919195055534459,
           4.902036414050767,
           4.884877772567076,
           4.867719131083386,
           4.850560489599693,
           4.833401848116001,
           4.816243206632308,
           4.799084565148618,
           4.781925923664925,
           4.764767282181234,
           4.747608640697544,
           4.730449999213851,
           4.713291357730158,
           4.696132716246469,
           4.678974074762777,
           4.6618154332790835,
           4.644656791795391,
           4.627498150311702,
           4.61033950882801,
           4.5931808673443175,
           4.576022225860628,
           4.558863584376935,
           4.541704942893243,
           4.524546301409553,
           4.507387659925861,
           4.490229018442168,
           4.4730703769584785,
           4.455911735474786,
           4.438753093991093,
           4.421594452507401,
           4.404435811023712,
           4.3872771695400195,
           4.370118528056326,
           4.352959886572637,
           4.316547109436994,
           4.276283460947997,
           4.236019812459009,
           4.195756163970014,
           4.155492515481018,
           4.115228866992021,
           4.074965218503033
          ],
          [
           3.6112566565723103,
           3.613842869330936,
           3.6164290820895624,
           3.6190152948481886,
           3.6216015076068144,
           3.6241877203654407,
           3.6267739331240665,
           3.6293601458826927,
           3.631946358641319,
           3.634532571399945,
           3.637118784158571,
           3.639704996917197,
           3.6422912096758235,
           3.6448774224344493,
           3.6474636351930756,
           3.650049847951702,
           3.6526360607103276,
           3.6552222734689535,
           3.65780848622758,
           3.660394698986206,
           3.6629809117448326,
           3.665567124503458,
           3.6681533372620843,
           3.6707395500207105,
           3.6733257627793368,
           3.6759119755379626,
           3.6784981882965884,
           3.681084401055214,
           3.683670613813841,
           3.6862568265724667,
           3.688843039331093,
           3.691429252089719,
           3.694015464848345,
           3.6966016776069717,
           3.6991878903655975,
           3.7017741031242233,
           3.70436031588285,
           3.706946528641476,
           3.7095327414001016,
           3.7121189541587274,
           3.714705166917354,
           3.71729137967598,
           3.719877592434606,
           3.7224638051932324,
           3.725050017951858,
           3.7276362307104844,
           3.7302224434691107,
           3.7328086562277365,
           3.7353948689863627,
           3.737981081744989,
           3.740567294503615,
           3.743153507262241,
           3.745739720020867,
           3.748325932779493,
           3.7509121455381194,
           3.753498358296745,
           3.7560845710553714,
           3.758670783813998,
           3.7612569965726235,
           3.7638432093312497,
           3.7664294220898764,
           3.7690156348485018,
           3.771601847607128,
           3.774188060365754,
           3.77677427312438,
           3.77989750058716,
           3.78570579033686,
           3.791514080086561,
           3.7973223698362615,
           3.8031306595859626,
           3.8089389493356633,
           3.814747239085364,
           3.8205555288350648,
           3.826363818584766,
           3.832172108334466,
           3.8379803980841674,
           3.8437886878338676,
           3.849596977583569,
           3.8554052673332695,
           3.86121355708297,
           3.8670218468326714,
           3.8728301365823716,
           3.8786384263320723,
           3.884446716081773,
           3.890568639774197,
           3.896753290255167,
           3.9029379407361353,
           3.9091225912171046,
           3.9153072416980734,
           3.9214918921790423,
           3.927676542660011,
           3.93386119314098,
           3.940045843621949,
           3.946230494102918,
           3.952415144583887,
           3.9585997950648557,
           3.9647844455458254,
           3.970969096026794,
           3.977153746507763,
           3.9833383969887315,
           3.989523047469701,
           3.9957076979506696,
           4.000416850353861,
           4.003650501249697,
           4.006884152145535,
           4.010117803041372,
           4.01335145393721,
           4.016585104833046,
           4.019818755728885,
           4.023052406624721,
           4.026286057520559,
           4.029519708416396,
           4.032753359312234,
           4.03598701020807,
           4.039220661103909,
           4.042454311999745,
           4.045687962895583,
           4.04892161379142,
           4.052155264687258,
           4.055388915583095,
           4.058622566478933,
           4.06185621737477,
           4.065089868270608,
           4.068323519166444,
           4.071557170062282,
           4.074790820958119,
           4.078024471853957,
           4.081258122749794,
           4.084491773645631,
           4.087725424541469,
           4.090959075437306,
           4.0941927263331435,
           4.097426377228981,
           4.1006600281248184,
           4.103893679020656,
           4.107127329916493,
           4.11036098081233,
           4.1135946317081675,
           4.116828282604006,
           4.1200619334998425,
           4.12329558439568,
           4.1265292352915175,
           4.129762886187355,
           4.1329965370831925,
           4.136230187979029,
           4.139463838874867,
           4.142697489770704,
           4.145931140666542,
           4.149164791562379,
           4.1523984424582165,
           4.155632093354054,
           4.1588657442498915,
           4.162099395145728,
           4.165333046041566,
           4.168566696937403,
           4.171800347833241,
           4.175033998729078,
           4.178267649624916,
           4.181501300520752,
           4.18473495141659,
           4.187968602312427,
           4.191202253208265,
           4.194435904104102,
           4.19766955499994,
           4.200903205895777,
           4.204136856791614,
           4.207370507687452,
           4.2123763243145635,
           4.218268223807312,
           4.224160123300061,
           4.23005202279281,
           4.235943922285559,
           4.241835821778308,
           4.247727721271057,
           4.253619620763805,
           4.259511520256554,
           4.265403419749303,
           4.271295319242053,
           4.277187218734801,
           4.28307911822755,
           4.2889710177203,
           4.294862917213049,
           4.300754816705797,
           4.306646716198546,
           4.312538615691295,
           4.318430515184044,
           4.324322414676793,
           4.330214314169542,
           4.3361062136622905,
           4.341998113155039,
           4.347890012647788,
           4.353781912140537,
           4.359673811633286,
           4.3655657111260355,
           4.3714576106187835,
           4.377349510111533,
           4.383241409604282,
           4.38913330909703,
           4.3950252085897805,
           4.4009171080825285,
           4.406809007575277,
           4.412700907068027,
           4.418592806560776,
           4.424484705351725,
           4.42868994048197,
           4.432895175612215,
           4.43710041074246,
           4.441305645872705,
           4.445510881002951,
           4.449716116133196,
           4.453921351263441,
           4.458126586393686,
           4.462331821523931,
           4.466537056654177,
           4.470742291784421,
           4.474947526914666,
           4.479152762044912,
           4.4833579971751565,
           4.487563232305401,
           4.491768467435646,
           4.495973702565893,
           4.500178937696137,
           4.504384172826382,
           4.508589407956627,
           4.512794643086872,
           4.516999878217117,
           4.521205113347363,
           4.525410348477608,
           4.529615583607852,
           4.533820818738098,
           4.538026053868343,
           4.542231288998588,
           4.546436524128833,
           4.550641759259078,
           4.554846994389323,
           4.559052229519568,
           4.563257464649813,
           4.567462699780059,
           4.5716679349103035,
           4.575873170040549,
           4.580078405170793,
           4.584283640301039,
           4.588488875431285,
           4.592694110561529,
           4.596899345691774,
           4.601104580822019,
           4.605309815952265,
           4.60951505108251,
           4.613720286212755,
           4.617925521343,
           4.622846802166611,
           4.62848412868359,
           4.634121455200568,
           4.639758781717546,
           4.645396108234525,
           4.651033434751504,
           4.656670761268482,
           4.66230808778546,
           4.667945414302439,
           4.673582740819417,
           4.679220067336395,
           4.684857393853374,
           4.690494720370353,
           4.69613204688733,
           4.70176937340431,
           4.707406699921288,
           4.713044026438266,
           4.718681352955244,
           4.724318679472223,
           4.729956005989202,
           4.735593332506179,
           4.741230659023158,
           4.746867985540137,
           4.7525053120571155,
           4.7581426385740935,
           4.7637799650910715,
           4.7694172916080495,
           4.775054618125029,
           4.780691944642006,
           4.786329271158985,
           4.791966597675963,
           4.797603924192942,
           4.80324125070992,
           4.808878577226899,
           4.814515903743877,
           4.820153230260856,
           4.825790556777834,
           4.831717178796639,
           4.840112459235143,
           4.848507739673647,
           4.856903020112152,
           4.865298300550656,
           4.87369358098916,
           4.882088861427665,
           4.890484141866169,
           4.898879422304672,
           4.907274702743177,
           4.915669983181681,
           4.924065263620186,
           4.932460544058689,
           4.940855824497194,
           4.949251104935698,
           4.957646385374201,
           4.966041665812707,
           4.9744369462512115,
           4.982832226689714,
           4.991227507128219,
           4.999622787566723,
           5.008018068005228,
           5.016413348443732,
           5.024808628882236,
           5.03320390932074,
           5.0415991897592445,
           5.049994470197749,
           5.058389750636253,
           5.066785031074757,
           5.075180311513261,
           5.0835755919517664,
           5.091970872390268,
           5.100366152828775,
           5.108761433267279,
           5.117156713705782,
           5.125551994144287,
           5.133947274582791,
           5.142342555021295,
           5.1507378354597995,
           5.159133115898304,
           5.167528396336808,
           5.1759236767753105,
           5.184318957213816,
           5.192714237652321,
           5.201109518090825,
           5.209504798529329,
           5.2189830710331435,
           5.230627327667577,
           5.242271584302011,
           5.253915840936446,
           5.265560097570879,
           5.277204354205313,
           5.288848610839748,
           5.3004928674741825,
           5.312137124108615,
           5.32378138074305,
           5.335425637377485,
           5.347069894011918,
           5.358714150646352,
           5.370358407280787,
           5.38200266391522,
           5.393646920549654,
           5.405291177184089,
           5.416935433818522,
           5.428579690452956,
           5.440223947087391,
           5.451868203721826,
           5.4635124603562595,
           5.475156716990694,
           5.486800973625128,
           5.498445230259561,
           5.510089486893995,
           5.52173374352843,
           5.533378000162863,
           5.5450222567972975,
           5.556666513431732,
           5.568310770066167,
           5.579955026700599,
           5.591599283335034,
           5.603243539969468,
           5.614887796603902,
           5.6265320532383365,
           5.638176309872771,
           5.649820566507205,
           5.661464823141638,
           5.673109079776072,
           5.684753336410506,
           5.69639759304494,
           5.708041849679375,
           5.719686106313809,
           5.731330362948243,
           5.742974619582677,
           5.754618876217111,
           5.766263132851545,
           5.777907389485979,
           5.791561579579508,
           5.806046797179219,
           5.820532014778929,
           5.835017232378641,
           5.849502449978353,
           5.863987667578062,
           5.878472885177773,
           5.892958102777485,
           5.907443320377196,
           5.921928537976907,
           5.936413755576618,
           5.950898973176328,
           5.965384190776039,
           5.97986940837575,
           5.994354625975461,
           6.0088398435751715,
           6.023325061174884,
           6.037810278774595,
           6.052295496374303,
           6.066780713974016,
           6.0812659315737285,
           6.095751149173438,
           6.110236366773148,
           6.12472158437286,
           6.139206801972571,
           6.153692019572281,
           6.168177237171992,
           6.182662454771704,
           6.197147672371414,
           6.211632889971125,
           6.226118107570837,
           6.2406033251705475,
           6.255088542770259,
           6.269573760369969,
           6.282951386629573,
           6.290791056188656,
           6.2986307257477385,
           6.306470395306821,
           6.314310064865902,
           6.3221497344249835,
           6.329989403984066,
           6.337829073543147,
           6.3456687431022285,
           6.353508412661311,
           6.361348082220392,
           6.369187751779474,
           6.377027421338555,
           6.384867090897638,
           6.3927067604567185,
           6.400546430015801,
           6.408386099574884,
           6.416225769133964,
           6.4106548856361325,
           6.3934962441524394,
           6.37633760266875,
           6.359178961185058,
           6.342020319701366,
           6.324861678217676,
           6.307703036733983,
           6.29054439525029,
           6.273385753766598,
           6.256227112282908,
           6.239068470799216,
           6.221909829315523,
           6.2047511878318335,
           6.187592546348141,
           6.170433904864449,
           6.15327526338076,
           6.136116621897067,
           6.118957980413374,
           6.101799338929682,
           6.084640697445993,
           6.0674820559623,
           6.0503234144786076,
           6.033164772994918,
           6.016006131511226,
           5.998847490027534,
           5.981688848543844,
           5.964530207060151,
           5.947371565576459,
           5.9302129240927695,
           5.913054282609076,
           5.895895641125384,
           5.878736999641691,
           5.861578358158002,
           5.844419716674309,
           5.827261075190616,
           5.810102433706927,
           5.792943792223235,
           5.775785150739543,
           5.758626509255853,
           5.74146786777216,
           5.724309226288469,
           5.707150584804776,
           5.689991943321086,
           5.672833301837393,
           5.655674660353701,
           5.638516018870012,
           5.621357377386319,
           5.604198735902627,
           5.556818631907743,
           5.491705270680413,
           5.426591909453084,
           5.361478548225767,
           5.296365186998438,
           5.231251825771109,
           5.1661384645437805,
           5.101025103316464,
           5.0359117420891355,
           4.970798380861807,
           4.90568501963449,
           4.8405716584071605,
           4.775458297179833,
           4.710344935952516,
           4.645231574725186,
           4.580118213497857,
           4.515004852270529,
           4.449891491043212
          ],
          [
           4.0898607125242865,
           4.092446925282912,
           4.095033138041539,
           4.097619350800165,
           4.100205563558791,
           4.102791776317417,
           4.105377989076043,
           4.107964201834669,
           4.110550414593295,
           4.113136627351921,
           4.115722840110548,
           4.118309052869174,
           4.1208952656278,
           4.1234814783864255,
           4.126067691145052,
           4.128653903903678,
           4.131240116662304,
           4.1338263294209305,
           4.136412542179556,
           4.138998754938182,
           4.141584967696808,
           4.144171180455435,
           4.1467573932140604,
           4.149343605972687,
           4.151929818731313,
           4.154516031489939,
           4.1571022442485654,
           4.159688457007191,
           4.162274669765817,
           4.164860882524444,
           4.16744709528307,
           4.170033308041695,
           4.172619520800322,
           4.175205733558948,
           4.177791946317574,
           4.1803781590761995,
           4.182964371834826,
           4.185550584593452,
           4.188136797352079,
           4.190723010110704,
           4.19330922286933,
           4.195895435627957,
           4.198481648386582,
           4.201067861145209,
           4.203654073903834,
           4.20624028666246,
           4.208826499421087,
           4.211412712179713,
           4.213998924938339,
           4.2187331914282975,
           4.224541481177997,
           4.2303497709277,
           4.2361580606774,
           4.2419663504271,
           4.247774640176801,
           4.253582929926502,
           4.259391219676203,
           4.265199509425903,
           4.271007799175604,
           4.2768160889253055,
           4.282624378675006,
           4.288432668424707,
           4.294240958174407,
           4.3000492479241075,
           4.305857537673809,
           4.31166582742351,
           4.3174741171732105,
           4.323282406922911,
           4.329090696672613,
           4.3348989864223135,
           4.340707276172014,
           4.346515565921715,
           4.352323855671416,
           4.358132145421116,
           4.363940435170817,
           4.369748724920518,
           4.3755570146702185,
           4.381365304419919,
           4.387173594169621,
           4.392981883919321,
           4.398790173669022,
           4.404598463418722,
           4.410406753168424,
           4.416215042918124,
           4.4223369666105485,
           4.428521617091517,
           4.434706267572486,
           4.440890918053455,
           4.447075568534425,
           4.453260219015393,
           4.459444869496362,
           4.46562951997733,
           4.4718141704583,
           4.477998820939269,
           4.484183471420238,
           4.490368121901207,
           4.496552772382175,
           4.502737422863145,
           4.508922073344114,
           4.515106723825083,
           4.521291374306052,
           4.5274760247870205,
           4.533660675267989,
           4.539845325748959,
           4.546029976229927,
           4.552214626710896,
           4.5583992771918656,
           4.5645839276728335,
           4.570768578153803,
           4.576953228634772,
           4.583137879115741,
           4.589322529596711,
           4.5955071800776786,
           4.601691830558648,
           4.607876481039616,
           4.614061131520586,
           4.620245782001555,
           4.626430432482524,
           4.6326150829634924,
           4.635848736061032,
           4.639082386956869,
           4.642316037852707,
           4.6455496887485435,
           4.648783339644382,
           4.652016990540218,
           4.655250641436056,
           4.658484292331893,
           4.661717943227731,
           4.664951594123568,
           4.668185245019405,
           4.671418895915243,
           4.67465254681108,
           4.6778861977069175,
           4.681119848602755,
           4.6843534994985925,
           4.68758715039443,
           4.690820801290267,
           4.694054452186104,
           4.6972881030819424,
           4.700521753977779,
           4.7037554048736165,
           4.706989055769454,
           4.7102227066652915,
           4.713456357561128,
           4.7166900084569665,
           4.719923659352803,
           4.7231573102486415,
           4.726390961144478,
           4.729624612040316,
           4.732858262936153,
           4.73609191383199,
           4.739325564727828,
           4.742559215623665,
           4.745792866519502,
           4.74902651741534,
           4.752260168311177,
           4.755493819207015,
           4.758727470102852,
           4.761961120998689,
           4.765194771894526,
           4.768428422790364,
           4.771662073686201,
           4.774895724582039,
           4.778129375477876,
           4.781363026373714,
           4.784596677269551,
           4.787830328165388,
           4.7928361447925,
           4.798728044285248,
           4.804619943777997,
           4.8105118432707465,
           4.8164037427634945,
           4.822295642256245,
           4.828187541748994,
           4.834079441241742,
           4.8399713407344915,
           4.8458632402272395,
           4.851755139719989,
           4.857647039212738,
           4.863538938705486,
           4.869430838198236,
           4.8753227376909845,
           4.881214637183733,
           4.887106536676482,
           4.892998436169231,
           4.898890335661981,
           4.904782235154729,
           4.910674134647478,
           4.916566034140227,
           4.922457933632976,
           4.928349833125726,
           4.9342417326184735,
           4.940133632111222,
           4.946025531603972,
           4.95191743109672,
           4.95780933058947,
           4.9637012300822185,
           4.9695931295749665,
           4.975485029067716,
           4.981376928560465,
           4.987268828053214,
           4.993160727545963,
           4.9990526270387114,
           5.004944526531461,
           5.010836426024209,
           5.016728325516958,
           5.022620225009708,
           5.028512124502456,
           5.034404023995204,
           5.040295923487954,
           5.046187822980703,
           5.052079722473452,
           5.057971621966201,
           5.06386352145895,
           5.069755420951698,
           5.075647320444448,
           5.081539219937197,
           5.087431119429946,
           5.093323018922694,
           5.099214918415443,
           5.105106817908192,
           5.110998717400941,
           5.1168906168936905,
           5.122782516386439,
           5.128674415879187,
           5.134566315371937,
           5.140458214864686,
           5.146350114357435,
           5.152242013850183,
           5.158133913342932,
           5.164025812835681,
           5.16991771232843,
           5.17580961182118,
           5.181701511313928,
           5.187593410806677,
           5.193485310299426,
           5.199377207251178,
           5.203582442381423,
           5.207787677511668,
           5.2119929126419136,
           5.216198147772158,
           5.220403382902403,
           5.224608618032649,
           5.228813853162894,
           5.233019088293139,
           5.2372243234233835,
           5.241429558553629,
           5.245634793683875,
           5.249840028814118,
           5.254045263944364,
           5.258966544767976,
           5.264603871284955,
           5.270241197801933,
           5.2758785243189115,
           5.2815158508358895,
           5.287153177352868,
           5.2927905038698455,
           5.2984278303868235,
           5.304065156903803,
           5.309702483420781,
           5.31533980993776,
           5.322751481253084,
           5.3311467616915875,
           5.339542042130091,
           5.347937322568596,
           5.3563326030071,
           5.364727883445604,
           5.373123163884109,
           5.381518444322613,
           5.389913724761117,
           5.398309005199621,
           5.406704285638126,
           5.41509956607663,
           5.423494846515134,
           5.431890126953639,
           5.4402854073921425,
           5.448680687830647,
           5.457075968269151,
           5.465471248707655,
           5.473866529146159,
           5.482261809584664,
           5.490657090023168,
           5.499052370461672,
           5.507447650900176,
           5.515842931338681,
           5.524238211777185,
           5.532633492215688,
           5.541028772654194,
           5.5494240530926975,
           5.557819333531201,
           5.566214613969706,
           5.574609894408209,
           5.583005174846713,
           5.591400455285219,
           5.599795735723722,
           5.608191016162226,
           5.6165862966007305,
           5.624981577039236,
           5.6333768574777405,
           5.641772137916243,
           5.650167418354748,
           5.6585626987932525,
           5.666957979231756,
           5.675353259670261,
           5.683748540108765,
           5.692143820547269,
           5.700539100985773,
           5.708934381424278,
           5.717329661862782,
           5.725724942301286,
           5.734120222739791,
           5.742515503178295,
           5.750910783616798,
           5.759306064055302,
           5.7677013444938074,
           5.776096624932311,
           5.784491905370815,
           5.79288718580932,
           5.801282466247823,
           5.809677746686328,
           5.818073027124833,
           5.826468307563337,
           5.834863588001841,
           5.843258868440345,
           5.85165414887885,
           5.860049429317353,
           5.868444709755857,
           5.8768399901943615,
           5.885235270632865,
           5.893630551071371,
           5.902025831509874,
           5.91042111194838,
           5.9188163923868835,
           5.928294664890697,
           5.9399389215251315,
           5.951583178159566,
           5.963227434794001,
           5.974871691428434,
           5.986515948062867,
           5.998160204697302,
           6.009804461331737,
           6.0214487179661695,
           6.033092974600605,
           6.045964449836202,
           6.060449667435911,
           6.074934885035622,
           6.0894201026353345,
           6.103905320235045,
           6.118390537834754,
           6.132875755434467,
           6.147360973034178,
           6.161846190633888,
           6.1763314082336,
           6.190816625833311,
           6.2053018434330225,
           6.219787061032733,
           6.234272278632444,
           6.248757496232154,
           6.263242713831865,
           6.277727931431577,
           6.292213149031287,
           6.3066983666309975,
           6.32118358423071,
           6.33566880183042,
           6.35015401943013,
           6.3646392370298415,
           6.379124454629553,
           6.393609672229264,
           6.408094889828973,
           6.422580107428686,
           6.437065325028396,
           6.451550542628107,
           6.466035760227818,
           6.480520977827529,
           6.495006195427239,
           6.509491413026952,
           6.523976630626663,
           6.538461848226374,
           6.552947065826084,
           6.567432283425795,
           6.581917501025506,
           6.596402718625216,
           6.610887936224929,
           6.625373153824638,
           6.639858371424349,
           6.65434358902406,
           6.668828806623772,
           6.683314024223481,
           6.697799241823192,
           6.712284459422905,
           6.726769677022615,
           6.741254894622326,
           6.755740112222037,
           6.770225329821748,
           6.784710547421459,
           6.79919576502117,
           6.81368098262088,
           6.828166200220591,
           6.842651417820303,
           6.857136635420014,
           6.8716218530197235,
           6.886107070619435,
           6.900592288219147,
           6.915077505818856,
           6.9295627234185675,
           6.94404794101828,
           6.95853315861799,
           6.9730183762177,
           6.9875035938174115,
           7.001988811417123,
           7.016474029016833,
           7.030959246616544,
           7.045444464216256,
           7.059929681815967,
           7.074414899415676,
           7.088900117015389,
           7.102277743274993,
           7.110117412834075,
           7.117957082393158,
           7.12579675195224,
           7.133636421511321,
           7.141476091070403,
           7.149315760629484,
           7.157155430188566,
           7.164995099747649,
           7.17283476930673,
           7.180674438865811,
           7.188514108424894,
           7.196353777983976,
           7.204193447543058,
           7.212033117102139,
           7.21987278666122,
           7.227712456220304,
           7.2355521257793844,
           7.243391795338467,
           7.251231464897549,
           7.259071134456629,
           7.266910804015711,
           7.274750473574794,
           7.282590143133874,
           7.290429812692958,
           7.2982694822520395,
           7.306109151811121,
           7.313948821370201,
           7.321788490929284,
           7.329628160488366,
           7.337467830047448,
           7.345307499606529,
           7.353147169165612,
           7.360986838724693,
           7.3688265082837745,
           7.376666177842856,
           7.384505847401939,
           7.3923455169610195,
           7.380915638871682,
           7.363756997387989,
           7.346598355904299,
           7.329439714420607,
           7.312281072936915,
           7.295122431453225,
           7.277963789969532,
           7.26080514848584,
           7.224664461551346,
           7.159551100324018,
           7.094437739096689,
           7.029324377869361,
           6.964211016642045,
           6.899097655414716,
           6.8339842941873865,
           6.76887093296007,
           6.703757571732741,
           6.638644210505412,
           6.573530849278096,
           6.5084174880507675,
           6.443304126823438,
           6.378190765596109,
           6.3130774043687925,
           6.247964043141464,
           6.182850681914134,
           6.1177373206868175,
           6.05262395945949,
           5.987510598232161,
           5.922397237004844,
           5.857283875777515,
           5.792170514550186,
           5.727057153322869,
           5.66194379209554,
           5.596830430868212,
           5.531717069640884,
           5.466603708413567,
           5.401490347186238,
           5.33637698595891,
           5.271263624731592,
           5.206150263504263,
           5.141036902276935,
           5.075923541049617,
           5.01081017982229,
           4.94569681859496,
           4.880583457367631,
           4.815470096140315
          ],
          [
           4.568464768476272,
           4.571050981234897,
           4.573637193993524,
           4.57622340675215,
           4.578809619510777,
           4.581395832269402,
           4.583982045028028,
           4.586568257786654,
           4.589154470545281,
           4.5917406833039065,
           4.594326896062533,
           4.596913108821159,
           4.599499321579785,
           4.6020855343384115,
           4.604671747097037,
           4.607257959855663,
           4.60984417261429,
           4.612430385372915,
           4.615016598131541,
           4.617602810890168,
           4.620189023648794,
           4.62277523640742,
           4.6253614491660455,
           4.627947661924672,
           4.630533874683298,
           4.633120087441925,
           4.6357063002005505,
           4.638292512959176,
           4.640878725717803,
           4.643464938476428,
           4.646051151235055,
           4.648637363993681,
           4.651760592519745,
           4.657568882269446,
           4.663377172019146,
           4.669185461768848,
           4.6749937515185485,
           4.680802041268249,
           4.686610331017951,
           4.692418620767651,
           4.698226910517352,
           4.704035200267052,
           4.709843490016753,
           4.715651779766454,
           4.721460069516154,
           4.727268359265856,
           4.7330766490155565,
           4.738884938765256,
           4.744693228514957,
           4.750501518264659,
           4.756309808014359,
           4.762118097764061,
           4.767926387513761,
           4.7737346772634615,
           4.779542967013162,
           4.785351256762863,
           4.7911595465125645,
           4.796967836262265,
           4.802776126011965,
           4.808584415761667,
           4.814392705511366,
           4.820200995261068,
           4.826009285010768,
           4.8318175747604695,
           4.83762586451017,
           4.843434154259871,
           4.849242444009572,
           4.855050733759272,
           4.860859023508974,
           4.866667313258674,
           4.872475603008375,
           4.878283892758075,
           4.884092182507777,
           4.8899004722574775,
           4.895708762007178,
           4.901517051756879,
           4.90732534150658,
           4.91313363125628,
           4.918941921005981,
           4.924750210755683,
           4.9305585005053825,
           4.936366790255083,
           4.942175080004784,
           4.9479833697544855,
           4.95410529344691,
           4.9602899439278785,
           4.966474594408847,
           4.972659244889816,
           4.978843895370785,
           4.985028545851754,
           4.991213196332723,
           4.997397846813692,
           5.003582497294661,
           5.00976714777563,
           5.015951798256599,
           5.022136448737568,
           5.028321099218537,
           5.034505749699505,
           5.040690400180475,
           5.046875050661443,
           5.053059701142413,
           5.0592443516233825,
           5.06542900210435,
           5.07161365258532,
           5.077798303066288,
           5.083982953547258,
           5.090167604028227,
           5.0963522545091955,
           5.102536904990164,
           5.108721555471133,
           5.114906205952102,
           5.121090856433072,
           5.12727550691404,
           5.133460157395009,
           5.139644807875978,
           5.145829458356947,
           5.152014108837916,
           5.158198759318886,
           5.1643834097998536,
           5.170568060280823,
           5.176752710761791,
           5.182937361242761,
           5.189122011723729,
           5.195306662204699,
           5.201491312685668,
           5.207675963166636,
           5.213860613647605,
           5.220045264128575,
           5.226229914609543,
           5.2324145650905125,
           5.2385992155714804,
           5.24478386605245,
           5.25096851653342,
           5.257153167014388,
           5.263337817495358,
           5.268046970872377,
           5.271280621768214,
           5.274514272664051,
           5.277747923559889,
           5.280981574455726,
           5.284215225351563,
           5.287448876247401,
           5.290682527143238,
           5.293916178039075,
           5.297149828934913,
           5.30038347983075,
           5.303617130726588,
           5.306850781622425,
           5.310084432518263,
           5.3133180834141,
           5.316551734309937,
           5.319785385205775,
           5.323019036101612,
           5.326252686997449,
           5.329486337893287,
           5.332719988789124,
           5.335953639684961,
           5.339187290580799,
           5.342420941476636,
           5.345654592372473,
           5.348888243268311,
           5.3521218941641475,
           5.355355545059986,
           5.3585891959558225,
           5.36182284685166,
           5.3650564977474975,
           5.368290148643335,
           5.373295965270447,
           5.379187864763195,
           5.385079764255946,
           5.390971663748694,
           5.396863563241443,
           5.402755462734193,
           5.40864736222694,
           5.41453926171969,
           5.420431161212438,
           5.426323060705187,
           5.432214960197937,
           5.438106859690684,
           5.443998759183435,
           5.449890658676183,
           5.4557825581689325,
           5.4616744576616805,
           5.46756635715443,
           5.473458256647179,
           5.479350156139928,
           5.485242055632677,
           5.4911339551254255,
           5.497025854618174,
           5.502917754110924,
           5.508809653603673,
           5.514701553096422,
           5.5205934525891704,
           5.526485352081919,
           5.532377251574668,
           5.538269151067418,
           5.544161050560166,
           5.550052950052914,
           5.555944849545664,
           5.561836749038412,
           5.567728648531161,
           5.573620548023911,
           5.579512447516659,
           5.585404347009408,
           5.591296246502157,
           5.597188145994905,
           5.603080045487656,
           5.608971944980404,
           5.6148638444731525,
           5.620755743965902,
           5.62664764345865,
           5.6325395429514,
           5.6384314424441495,
           5.6443233419368966,
           5.650215241429646,
           5.656107140922396,
           5.661999040415144,
           5.667890939907894,
           5.673782839400642,
           5.67967473889339,
           5.68556663838614,
           5.691458537878889,
           5.697350437371638,
           5.7032423368643865,
           5.709134236357135,
           5.715026135849884,
           5.720918035342634,
           5.726809934835382,
           5.732701834328131,
           5.73859373382088,
           5.744485633313629,
           5.752026103505505,
           5.759566575211201,
           5.767107046916896,
           5.77464751862259,
           5.782187990328286,
           5.789728462033981,
           5.7972689337396766,
           5.804809405445372,
           5.812349877151067,
           5.819890348856762,
           5.827430820562457,
           5.834971292268152,
           5.842511763973848,
           5.850052235679543,
           5.857592707385238,
           5.865133179090933,
           5.872673650796629,
           5.8802141225023234,
           5.887754594208019,
           5.89696297287286,
           5.907839258496846,
           5.918715544120831,
           5.929591829744815,
           5.940468115368802,
           5.951344400992786,
           5.962220686616771,
           5.973096972240756,
           5.983973257864743,
           5.994849543488726,
           6.005725829112712,
           6.016602114736698,
           6.027478400360684,
           6.038354685984668,
           6.049230971608654,
           6.060107257232638,
           6.070983542856624,
           6.0815710380193915,
           6.089963761992354,
           6.098356485965317,
           6.106749209938279,
           6.115141933911243,
           6.123534657884206,
           6.131927381857169,
           6.140320105830133,
           6.148712829803095,
           6.1571055537760575,
           6.1654982777490215,
           6.173891001721984,
           6.182283725694946,
           6.19067644966791,
           6.199069173640873,
           6.207461897613835,
           6.215854621586798,
           6.224247345559762,
           6.232640069532724,
           6.241032793505687,
           6.24942551747865,
           6.257818241451613,
           6.266210965424576,
           6.27460368939754,
           6.282996413370502,
           6.291389137343464,
           6.299781861316427,
           6.308174585289391,
           6.316567309262353,
           6.324960033235316,
           6.33335275720828,
           6.341745481181243,
           6.350138205154206,
           6.358530929127168,
           6.366923653100131,
           6.375316377073094,
           6.383709101046057,
           6.3921018250190205,
           6.400494548991983,
           6.408887272964946,
           6.41727999693791,
           6.425672720910873,
           6.434065444883835,
           6.442458168856799,
           6.450850892829761,
           6.459243616802723,
           6.467636340775687,
           6.47602906474865,
           6.484421788721614,
           6.492814512694576,
           6.50120723666754,
           6.509599960640502,
           6.517992684613464,
           6.526385408586428,
           6.53477813255939,
           6.543170856532353,
           6.5515635805053165,
           6.559956304478279,
           6.568349028451242,
           6.576741752424206,
           6.585134476397168,
           6.59352720037013,
           6.601919924343093,
           6.610312648316057,
           6.6187053722890195,
           6.627098096261983,
           6.637834767224247,
           6.653259332165106,
           6.668683897105966,
           6.6841084620468285,
           6.699533026987689,
           6.714957591928549,
           6.73038215686941,
           6.745806721810271,
           6.76123128675113,
           6.776655851691992,
           6.792080416632853,
           6.8075049815737145,
           6.822929546514574,
           6.838354111455436,
           6.853778676396296,
           6.869203241337155,
           6.884627806278018,
           6.900052371218878,
           6.915476936159738,
           6.9309015011006,
           6.946326066041461,
           6.961750630982322,
           6.9771751959231825,
           6.992599760864043,
           7.008024325804904,
           7.0234488907457635,
           7.038873455686625,
           7.054298020627485,
           7.0697225855683445,
           7.085147150509206,
           7.1005717154500685,
           7.115996280390927,
           7.131420845331789,
           7.14684541027265,
           7.16226997521351,
           7.177694540154371,
           7.193119105095233,
           7.208543670036093,
           7.223968234976953,
           7.239392799917814,
           7.254817364858676,
           7.270241929799534,
           7.285666494740395,
           7.301091059681258,
           7.316515624622118,
           7.331940189562978,
           7.34736475450384,
           7.362789319444699,
           7.37821388438556,
           7.393638449326422,
           7.409063014267281,
           7.424487579208142,
           7.4399121441490035,
           7.455336709089864,
           7.470761274030725,
           7.486185838971585,
           7.501610403912447,
           7.517034968853308,
           7.532459533794167,
           7.547884098735029,
           7.563308663675889,
           7.578733228616749,
           7.59415779355761,
           7.6095823584984705,
           7.625006923439331,
           7.640431488380193,
           7.655856053321055,
           7.671280618261913,
           7.686705183202775,
           7.702129748143637,
           7.717554313084496,
           7.7329788780253566,
           7.748403442966218,
           7.763828007907078,
           7.779252572847938,
           7.794677137788799,
           7.8101017027296615,
           7.82552626767052,
           7.840950832611382,
           7.856375397552244,
           7.871799962493103,
           7.887224527433964,
           7.904774274288597,
           7.919857133034911,
           7.909983979181711,
           7.877281936614643,
           7.844579894047573,
           7.811877851480511,
           7.7791758089134415,
           7.746473766346373,
           7.71377172377931,
           7.681069681212241,
           7.648367638645173,
           7.6156655960781094,
           7.582963553511041,
           7.5502615109439715,
           7.517559468376903,
           7.484857425809841,
           7.452155383242771,
           7.419453340675703,
           7.386751298108639,
           7.354049255541571,
           7.321347212974501,
           7.288645170407439,
           7.2559431278403705,
           7.223241085273301,
           7.190539042706239,
           7.157837000139169,
           7.125134957572101,
           7.092432915005032,
           7.05973087243797,
           7.0270288298709005,
           6.994326787303832,
           6.961624744736769,
           6.9289227021697,
           6.896220659602631,
           6.863518617035568,
           6.8308165744685,
           6.7981145319014304,
           6.765412489334361,
           6.7327104467673,
           6.700008404200231,
           6.667306361633162,
           6.634604319066099,
           6.601902276499031,
           6.569200233931961,
           6.536498191364897,
           6.503796148797829,
           6.47109410623076,
           6.438392063663697,
           6.405690021096628,
           6.37298797852956,
           6.340285935962491,
           6.307583893395428,
           6.2748818508283595,
           6.242179808261291,
           6.209477765694228,
           6.176775723127158,
           6.144073680560089,
           6.111371637993027,
           6.078669595425958,
           6.0459675528588885,
           6.01326551029182,
           5.980563467724758,
           5.947861425157688,
           5.91515938259062,
           5.882457340023557,
           5.849755297456488,
           5.817053254889419,
           5.784351212322356,
           5.751649169755288,
           5.718947127188219,
           5.686245084621156,
           5.653543042054087,
           5.620840999487019,
           5.588138956919948,
           5.555436914352887,
           5.5227348717858185,
           5.490032829218749,
           5.457330786651687,
           5.424628744084618,
           5.391926701517548,
           5.359224658950485,
           5.326522616383416,
           5.293820573816348,
           5.261118531249279,
           5.177799841788016
          ],
          [
           5.0470688244282575,
           5.049655037186884,
           5.052241249945509,
           5.054827462704136,
           5.0574136754627625,
           5.059999888221388,
           5.062586100980014,
           5.065172313738641,
           5.067758526497267,
           5.0703447392558925,
           5.072930952014518,
           5.075517164773145,
           5.078103377531771,
           5.080689590290397,
           5.083275803049023,
           5.08586201580765,
           5.0905962833608935,
           5.096404573110594,
           5.102212862860295,
           5.108021152609996,
           5.113829442359696,
           5.119637732109398,
           5.125446021859099,
           5.1312543116087985,
           5.1370626013585,
           5.142870891108201,
           5.148679180857901,
           5.154487470607602,
           5.160295760357303,
           5.166104050107004,
           5.171912339856705,
           5.177720629606405,
           5.183528919356106,
           5.1893372091058065,
           5.195145498855508,
           5.200953788605209,
           5.20676207835491,
           5.212570368104609,
           5.218378657854311,
           5.224186947604012,
           5.229995237353712,
           5.235803527103413,
           5.241611816853114,
           5.2474201066028145,
           5.253228396352515,
           5.259036686102216,
           5.264844975851917,
           5.270653265601617,
           5.276461555351318,
           5.28226984510102,
           5.2880781348507195,
           5.293886424600421,
           5.299694714350121,
           5.305503004099823,
           5.311311293849524,
           5.317119583599224,
           5.322927873348926,
           5.328736163098625,
           5.334544452848326,
           5.340352742598027,
           5.3461610323477275,
           5.351969322097429,
           5.35777761184713,
           5.36358590159683,
           5.369394191346531,
           5.375202481096232,
           5.381010770845933,
           5.386819060595633,
           5.392627350345334,
           5.398435640095036,
           5.404243929844736,
           5.410052219594437,
           5.415860509344137,
           5.421668799093839,
           5.427477088843539,
           5.43328537859324,
           5.439093668342941,
           5.444901958092641,
           5.450710247842342,
           5.456518537592043,
           5.462326827341744,
           5.468135117091444,
           5.473943406841145,
           5.479751696590846,
           5.48587362028327,
           5.49205827076424,
           5.498242921245208,
           5.504427571726177,
           5.510612222207146,
           5.516796872688115,
           5.522981523169084,
           5.529166173650053,
           5.535350824131021,
           5.54153547461199,
           5.54772012509296,
           5.553904775573928,
           5.560089426054898,
           5.5662740765358665,
           5.572458727016836,
           5.578643377497805,
           5.584828027978774,
           5.591012678459743,
           5.5971973289407115,
           5.60338197942168,
           5.609566629902649,
           5.615751280383618,
           5.621935930864587,
           5.628120581345556,
           5.634305231826525,
           5.640489882307494,
           5.646674532788463,
           5.652859183269432,
           5.659043833750401,
           5.6652284842313705,
           5.671413134712338,
           5.677597785193308,
           5.683782435674277,
           5.689967086155246,
           5.696151736636215,
           5.7023363871171835,
           5.708521037598153,
           5.714705688079121,
           5.720890338560091,
           5.72707498904106,
           5.7332596395220286,
           5.739444290002997,
           5.745628940483966,
           5.751813590964935,
           5.757998241445904,
           5.764182891926874,
           5.770367542407842,
           5.776552192888812,
           5.78273684336978,
           5.788921493850749,
           5.795106144331719,
           5.8012907948126875,
           5.807475445293656,
           5.813660095774625,
           5.819844746255594,
           5.826029396736563,
           5.832214047217532,
           5.8383986976985005,
           5.844583348179469,
           5.850767998660438,
           5.856952649141408,
           5.863137299622377,
           5.869321950103346,
           5.875506600584314,
           5.881691251065283,
           5.887875901546252,
           5.894060552027221,
           5.900245202508191,
           5.90347885657956,
           5.906712507475397,
           5.909946158371235,
           5.9131798092670715,
           5.916413460162909,
           5.9196471110587465,
           5.922880761954584,
           5.9261144128504215,
           5.929348063746259,
           5.932581714642096,
           5.935815365537934,
           5.939049016433771,
           5.942282667329607,
           5.945516318225446,
           5.948749969121282,
           5.9537557857483945,
           5.959647685241144,
           5.965539584733893,
           5.971431484226642,
           5.977323383719391,
           5.9832152832121395,
           5.989107182704888,
           5.994999082197637,
           6.000890981690386,
           6.006782881183135,
           6.0126747806758845,
           6.018566680168633,
           6.024458579661383,
           6.030350479154132,
           6.036242378646881,
           6.042134278139629,
           6.048026177632377,
           6.053918077125126,
           6.059809976617875,
           6.065701876110625,
           6.071593775603373,
           6.077485675096122,
           6.08337757458887,
           6.089269474081621,
           6.09516137357437,
           6.1010532730671185,
           6.1069451725598665,
           6.112837072052616,
           6.118728971545365,
           6.124620871038113,
           6.130512771902762,
           6.138053243608457,
           6.145593715314151,
           6.153134187019846,
           6.160674658725542,
           6.168215130431237,
           6.175755602136933,
           6.183296073842628,
           6.190836545548324,
           6.198377017254019,
           6.205917488959713,
           6.213457960665409,
           6.220998432371104,
           6.2285389040767996,
           6.236079375782495,
           6.2436198474881905,
           6.251160319193885,
           6.258700790899581,
           6.266241262605276,
           6.273781734310972,
           6.281322206016667,
           6.288862677722362,
           6.296403149428057,
           6.303943621133753,
           6.311484092839448,
           6.319024564545143,
           6.326565036250837,
           6.334105507956533,
           6.341645979662228,
           6.349186451367924,
           6.356726923073619,
           6.364267394779315,
           6.37180786648501,
           6.379348338190704,
           6.3868888098964005,
           6.394429281602096,
           6.401969753307791,
           6.409510225013486,
           6.417050696719182,
           6.424591168424877,
           6.432131640130573,
           6.439672111836266,
           6.447212583541962,
           6.454753055247657,
           6.462293526953353,
           6.469833998659048,
           6.477374470364744,
           6.484914942070439,
           6.492455413776133,
           6.4999958854818285,
           6.507536357187524,
           6.5150768288932195,
           6.522617300598915,
           6.531825679263756,
           6.5427019648877405,
           6.553578250511726,
           6.564454536135711,
           6.575330821759696,
           6.586207107383681,
           6.597083393007666,
           6.607959678631653,
           6.618835964255638,
           6.629712249879622,
           6.640588535503607,
           6.651464821127593,
           6.662341106751579,
           6.673217392375563,
           6.684093677999549,
           6.694969963623533,
           6.70584624924752,
           6.716722534871505,
           6.727598820495491,
           6.738475106119475,
           6.7493513917434615,
           6.760227677367446,
           6.771103962991431,
           6.781980248615416,
           6.792856534239402,
           6.803732819863386,
           6.8146091054873725,
           6.825485391111358,
           6.836361676735343,
           6.847237962359328,
           6.858114247983313,
           6.8689905336073,
           6.8798668192312835,
           6.890743104855269,
           6.901619390479254,
           6.912495676103239,
           6.923371961727225,
           6.934248247351211,
           6.945124532975195,
           6.95600081859918,
           6.966877104223165,
           6.97775338984715,
           6.988629675471136,
           6.999505961095121,
           7.010382246719107,
           7.021258532343091,
           7.032134817967076,
           7.041278382107304,
           7.049671106080266,
           7.05806383005323,
           7.066456554026193,
           7.074849277999156,
           7.083242001972119,
           7.091634725945083,
           7.100027449918045,
           7.108420173891007,
           7.11681289786397,
           7.125205621836933,
           7.133598345809896,
           7.1419910697828595,
           7.150383793755822,
           7.158776517728786,
           7.167169241701748,
           7.175561965674712,
           7.183954689647674,
           7.192347413620637,
           7.2007401375936,
           7.209132861566563,
           7.217525585539525,
           7.225918309512489,
           7.234311033485452,
           7.242703757458415,
           7.251096481431378,
           7.259489205404341,
           7.267881929377303,
           7.276274653350267,
           7.284667377323229,
           7.2930601012961915,
           7.301452825269155,
           7.309845549242119,
           7.318238273215082,
           7.326630997188044,
           7.335023721161007,
           7.345760392123271,
           7.361184957064131,
           7.376609522004991,
           7.392034086945852,
           7.407458651886713,
           7.422883216827572,
           7.438307781768434,
           7.453732346709296,
           7.469156911650154,
           7.484581476591017,
           7.500006041531877,
           7.515430606472738,
           7.530855171413599,
           7.546279736354459,
           7.56170430129532,
           7.57712886623618,
           7.592553431177041,
           7.607977996117903,
           7.623402561058763,
           7.638827125999623,
           7.654251690940486,
           7.669676255881345,
           7.685100820822206,
           7.7005253857630676,
           7.715949950703928,
           7.731374515644788,
           7.746799080585649,
           7.762223645526509,
           7.777648210467369,
           7.793072775408231,
           7.808497340349093,
           7.823921905289952,
           7.839346470230813,
           7.854771035171675,
           7.870195600112535,
           7.885620165053394,
           7.901044729994257,
           7.916469294935117,
           7.931893859875977,
           7.947318424816839,
           7.962742989757699,
           7.978167554698559,
           7.99359211963942,
           8.009016684580281,
           8.024441249521141,
           8.040521847759289,
           8.058829260637001,
           8.07713667351471,
           8.09544408639242,
           8.11375149927013,
           8.13205891214784,
           8.150366325025551,
           8.168673737903262,
           8.186981150780973,
           8.20528856365868,
           8.223595976536393,
           8.241903389414103,
           8.260210802291812,
           8.278518215169523,
           8.296825628047234,
           8.315133040924945,
           8.333440453802654,
           8.351747866680366,
           8.370055279558075,
           8.388362692435784,
           8.406670105313497,
           8.424977518191207,
           8.443284931068916,
           8.461592343946627,
           8.479899756824338,
           8.498207169702049,
           8.516514582579758,
           8.53482199545747,
           8.55312940833518,
           8.571436821212888,
           8.5897442340906,
           8.608051646968311,
           8.626359059846019,
           8.644666472723731,
           8.662973885601442,
           8.681281298479151,
           8.699588711356862,
           8.717896124234572,
           8.732978982980887,
           8.731939071070233,
           8.730899159159582,
           8.729859247248928,
           8.728819335338276,
           8.727779423427624,
           8.726739511516971,
           8.725699599606319,
           8.724659687695667,
           8.723619775785014,
           8.72257986387436,
           8.721539951963708,
           8.720500040053055,
           8.719460128142403,
           8.71842021623175,
           8.717380304321097,
           8.716340392410444,
           8.715300480499792,
           8.71426056858914,
           8.713220656678487,
           8.712180744767835,
           8.711140832857183,
           8.689394330320658,
           8.656692287753597,
           8.623990245186526,
           8.59128820261946,
           8.55858616005239,
           8.525884117485328,
           8.49318207491826,
           8.460480032351189,
           8.427777989784126,
           8.395075947217057,
           8.362373904649989,
           8.329671862082925,
           8.296969819515857,
           8.264267776948788,
           8.23156573438172,
           8.198863691814656,
           8.166161649247588,
           8.13345960668052,
           8.100757564113456,
           8.068055521546388,
           8.035353478979317,
           8.002651436412256,
           7.969949393845186,
           7.937247351278118,
           7.904545308711055,
           7.871843266143985,
           7.839141223576917,
           7.806439181009848,
           7.773737138442786,
           7.741035095875716,
           7.708333053308648,
           7.675631010741585,
           7.642928968174516,
           7.6102269256074475,
           7.577524883040384,
           7.544822840473316,
           7.512120797906246,
           7.479418755339177,
           7.446716712772115,
           7.414014670205045,
           7.352078995464838,
           7.262355818929272,
           7.172632642393689,
           7.082909465858107,
           6.993186289322541,
           6.903463112786959,
           6.813739936251375,
           6.724016759715809,
           6.634293583180227,
           6.544570406644645,
           6.454847230109062,
           6.365124053573496,
           6.275400877037912,
           6.18567770050233,
           6.095954523966764,
           6.006231347431181,
           5.916508170895598,
           5.8267849943600325,
           5.73706181782445,
           5.647338641288867,
           5.557615464753285,
           5.467892288217719
          ],
          [
           5.525455946748889,
           5.53452496245444,
           5.540876710413215,
           5.546685000162916,
           5.552493289912617,
           5.558301579662317,
           5.564109869412018,
           5.569918159161719,
           5.57572644891142,
           5.58153473866112,
           5.587343028410821,
           5.593151318160522,
           5.598959607910223,
           5.604767897659924,
           5.610576187409625,
           5.6163844771593245,
           5.622192766909026,
           5.628001056658726,
           5.633809346408428,
           5.639617636158128,
           5.645425925907829,
           5.651234215657531,
           5.65704250540723,
           5.662850795156931,
           5.668659084906632,
           5.674467374656333,
           5.680275664406033,
           5.686083954155735,
           5.691892243905436,
           5.697700533655136,
           5.703508823404836,
           5.709317113154538,
           5.715125402904238,
           5.720933692653939,
           5.72674198240364,
           5.732550272153341,
           5.738358561903041,
           5.744166851652742,
           5.749975141402444,
           5.755783431152143,
           5.761591720901845,
           5.767400010651545,
           5.773208300401246,
           5.779016590150947,
           5.784824879900648,
           5.790633169650349,
           5.796441459400049,
           5.80224974914975,
           5.808058038899451,
           5.813866328649152,
           5.819674618398852,
           5.825482908148554,
           5.831291197898254,
           5.837099487647954,
           5.842907777397656,
           5.848716067147357,
           5.854524356897058,
           5.860332646646758,
           5.866140936396458,
           5.871949226146159,
           5.87775751589586,
           5.883565805645562,
           5.8893740953952625,
           5.895182385144962,
           5.900990674894664,
           5.906798964644365,
           5.912607254394065,
           5.918415544143766,
           5.924223833893467,
           5.9300321236431675,
           5.935840413392869,
           5.941648703142569,
           5.9474569928922705,
           5.95326528264197,
           5.959073572391671,
           5.964881862141373,
           5.970690151891072,
           5.976498441640774,
           5.982306731390475,
           5.9881150211401755,
           5.993923310889876,
           5.999731600639576,
           6.005539890389278,
           6.011348180138978,
           6.0174701038314025,
           6.023654754312372,
           6.02983940479334,
           6.03602405527431,
           6.042208705755279,
           6.0483933562362475,
           6.054578006717216,
           6.060762657198185,
           6.066947307679155,
           6.073131958160125,
           6.079316608641093,
           6.085501259122062,
           6.09168590960303,
           6.097870560084,
           6.104055210564968,
           6.110239861045938,
           6.116424511526906,
           6.122609162007875,
           6.128793812488844,
           6.134978462969813,
           6.141163113450782,
           6.147347763931751,
           6.1535324144127195,
           6.159717064893688,
           6.165901715374658,
           6.172086365855627,
           6.178271016336596,
           6.1844556668175645,
           6.190640317298533,
           6.196824967779503,
           6.203009618260471,
           6.209194268741441,
           6.21537891922241,
           6.221563569703379,
           6.227748220184347,
           6.233932870665317,
           6.240117521146286,
           6.246302171627255,
           6.2524868221082235,
           6.258671472589192,
           6.264856123070162,
           6.271040773551129,
           6.277225424032099,
           6.283410074513068,
           6.2895947249940365,
           6.295779375475006,
           6.301964025955974,
           6.308148676436944,
           6.314333326917913,
           6.3205179773988815,
           6.32670262787985,
           6.332887278360819,
           6.339071928841789,
           6.345256579322758,
           6.351441229803727,
           6.357625880284695,
           6.363810530765664,
           6.369995181246633,
           6.376179831727602,
           6.382364482208571,
           6.3885491326895405,
           6.394733783170509,
           6.400918433651478,
           6.407103084132447,
           6.413287734613416,
           6.419472385094385,
           6.4256570355753535,
           6.431841686056323,
           6.438026336537292,
           6.444210987018261,
           6.45039563749923,
           6.456580287980199,
           6.462764938461167,
           6.468949588942137,
           6.475134239423105,
           6.481318889904075,
           6.487503540385044,
           6.4936881908660125,
           6.499872841346981,
           6.50605749182795,
           6.512242142308919,
           6.518426792789888,
           6.527075217879448,
           6.535946686728583,
           6.544683302109148,
           6.553419917489714,
           6.561782742239873,
           6.569323213945568,
           6.576863685651263,
           6.58440415735696,
           6.591944629062654,
           6.599485100768349,
           6.607025572474044,
           6.61456604417974,
           6.622106515885435,
           6.629646987591131,
           6.637187459296826,
           6.64472793100252,
           6.652268402708216,
           6.659808874413911,
           6.6673493461196065,
           6.674889817825302,
           6.682430289530997,
           6.689970761236693,
           6.697511232942388,
           6.705051704648082,
           6.712592176353779,
           6.720132648059473,
           6.727673119765168,
           6.735213591470863,
           6.742754063176559,
           6.750294534882254,
           6.75783500658795,
           6.765375478293644,
           6.772915949999339,
           6.780456421705035,
           6.787996893410731,
           6.795537365116426,
           6.803077836822121,
           6.810618308527817,
           6.818158780233512,
           6.825699251939206,
           6.833239723644903,
           6.840780195350598,
           6.848320667056293,
           6.855861138761988,
           6.863401610467683,
           6.870942082173379,
           6.878482553879073,
           6.886023025584768,
           6.893563497290463,
           6.901103968996159,
           6.908644440701854,
           6.91618491240755,
           6.923725384113245,
           6.93126585581894,
           6.938806327524635,
           6.946346799230331,
           6.9538872709360255,
           6.961427742641721,
           6.968968214347417,
           6.976508686053112,
           6.9840491577588075,
           6.991589629464502,
           6.999130101170198,
           7.006670572875892,
           7.014211044581588,
           7.021751516287282,
           7.029291987992978,
           7.036832459698674,
           7.044372931404369,
           7.051913403110064,
           7.05945387481576,
           7.066994346521454,
           7.074534818227151,
           7.082075289932845,
           7.089615761638542,
           7.0971562333442355,
           7.104696705049931,
           7.1122371767556265,
           7.119777648461322,
           7.127318120167017,
           7.134858591872712,
           7.142399063578408,
           7.149939535284103,
           7.157480006989798,
           7.166688385654638,
           7.177564671278624,
           7.188440956902609,
           7.199317242526593,
           7.21019352815058,
           7.221069813774564,
           7.231946099398549,
           7.242822385022536,
           7.2536986706465205,
           7.264574956270505,
           7.275451241894491,
           7.286327527518478,
           7.2972038131424615,
           7.308080098766447,
           7.318956384390432,
           7.329832670014417,
           7.340708955638402,
           7.351585241262388,
           7.362461526886373,
           7.373337812510359,
           7.384214098134343,
           7.39509038375833,
           7.405966669382314,
           7.416842955006299,
           7.427719240630285,
           7.43859552625427,
           7.449471811878255,
           7.460348097502241,
           7.471224383126226,
           7.482100668750212,
           7.492976954374196,
           7.5038532399981825,
           7.514729525622166,
           7.525605811246152,
           7.536482096870137,
           7.547358382494123,
           7.558234668118108,
           7.5691109537420935,
           7.579987239366078,
           7.590863524990064,
           7.601739810614049,
           7.612616096238034,
           7.623492381862019,
           7.6343686674860045,
           7.645244953109991,
           7.656121238733974,
           7.66699752435796,
           7.677873809981946,
           7.688750095605931,
           7.6996263812299155,
           7.710502666853903,
           7.721378952477886,
           7.732255238101872,
           7.7431315237258564,
           7.754007809349843,
           7.7648840949738265,
           7.775760380597813,
           7.786636666221799,
           7.797512951845783,
           7.808389237469768,
           7.819265523093755,
           7.830141808717739,
           7.841018094341725,
           7.851894379965709,
           7.862770665589695,
           7.873646951213679,
           7.884523236837666,
           7.895399522461651,
           7.906275808085635,
           7.917152093709621,
           7.928028379333607,
           7.938904664957591,
           7.949780950581577,
           7.960657236205562,
           7.9715335218295476,
           7.982409807453532,
           7.99259300222224,
           8.000985726195204,
           8.009378450168166,
           8.01777117414113,
           8.026163898114092,
           8.034556622087056,
           8.042949346060018,
           8.053686017022281,
           8.069110581963141,
           8.084535146904003,
           8.099959711844862,
           8.115384276785724,
           8.130808841726584,
           8.146233406667445,
           8.161657971608308,
           8.177082536549165,
           8.194576834107675,
           8.212884246985388,
           8.231191659863097,
           8.249499072740806,
           8.267806485618518,
           8.286113898496229,
           8.304421311373938,
           8.322728724251649,
           8.341036137129358,
           8.359343550007068,
           8.377650962884779,
           8.395958375762492,
           8.4142657886402,
           8.43257320151791,
           8.450880614395622,
           8.469188027273331,
           8.48749544015104,
           8.505802853028753,
           8.524110265906462,
           8.542417678784172,
           8.560725091661883,
           8.579032504539594,
           8.597339917417303,
           8.615647330295014,
           8.633954743172726,
           8.652262156050435,
           8.670569568928146,
           8.688876981805857,
           8.707184394683566,
           8.725491807561276,
           8.743799220438987,
           8.762106633316698,
           8.780414046194405,
           8.798721459072118,
           8.817028871949828,
           8.83533628482754,
           8.85364369770525,
           8.87195111058296,
           8.89025852346067,
           8.90856593633838,
           8.926873349216091,
           8.945180762093802,
           8.96348817497151,
           8.981795587849222,
           9.000103000726934,
           9.018410413604641,
           9.036717826482354,
           9.055025239360063,
           9.073332652237774,
           9.091640065115485,
           9.109947477993195,
           9.128254890870904,
           9.146562303748613,
           9.164869716626326,
           9.183177129504035,
           9.201484542381746,
           9.219791955259456,
           9.238099368137167,
           9.256406781014874,
           9.274714193892587,
           9.293021606770298,
           9.311329019648008,
           9.329636432525717,
           9.34794384540343,
           9.366251258281139,
           9.38455867115885,
           9.40286608403656,
           9.421173496914271,
           9.43948090979198,
           9.45778832266969,
           9.476095735547403,
           9.494403148425112,
           9.512710561302821,
           9.531017974180532,
           9.546100832926847,
           9.545060921016194,
           9.54402100910554,
           9.54298109719489,
           9.541941185284237,
           9.540901273373583,
           9.53986136146293,
           9.538821449552279,
           9.537781537641628,
           9.536741625730974,
           9.535701713820322,
           9.534661801909667,
           9.533621889999015,
           9.532581978088363,
           9.53154206617771,
           9.530502154267058,
           9.529462242356406,
           9.528422330445753,
           9.527382418535101,
           9.526342506624449,
           9.525302594713796,
           9.524262682803142,
           9.52322277089249,
           9.522182858981838,
           9.521142947071185,
           9.520103035160531,
           9.519063123249879,
           9.518023211339226,
           9.516983299428574,
           9.515943387517922,
           9.51490347560727,
           9.513863563696615,
           9.512823651785965,
           9.511783739875312,
           9.510743827964658,
           9.509703916054004,
           9.508664004143354,
           9.507624092232701,
           9.506584180322049,
           9.505544268411395,
           9.504504356500743,
           9.457582524085693,
           9.40696379593834,
           9.346911796070522,
           9.25718861953494,
           9.16746544299936,
           9.077742266463792,
           8.98801908992821,
           8.898295913392626,
           8.808572736857045,
           8.718849560321477,
           8.629126383785895,
           8.539403207250313,
           8.449680030714747,
           8.359956854179163,
           8.270233677643581,
           8.180510501108015,
           8.090787324572432,
           8.00106414803685,
           7.911340971501267,
           7.821617794965701,
           7.731894618430118,
           7.642171441894536,
           7.5524482653589695,
           7.462725088823388,
           7.373001912287805,
           7.283278735752237,
           7.193555559216655,
           7.103832382681073,
           7.014109206145507,
           6.924386029609924,
           6.834662853074342,
           6.744939676538759,
           6.655216500003193,
           6.565493323467609,
           6.475770146932026,
           6.38604697039646,
           6.2963237938608785,
           6.2066006173252966,
           6.11687744078973,
           6.027154264254147,
           5.937431087718565,
           5.847707911182981,
           5.757984734647415
          ],
          [
           6.000991944576379,
           6.01006096028193,
           6.019129975987481,
           6.028198991693031,
           6.037268007398582,
           6.046337023104133,
           6.055406038809684,
           6.064475054515235,
           6.073544070220786,
           6.0826130859263365,
           6.091682101631887,
           6.100751117337438,
           6.109820133042989,
           6.11888914874854,
           6.127958164454091,
           6.137027180159642,
           6.1460961958651925,
           6.155165211570743,
           6.163147320729639,
           6.16895561047934,
           6.17476390022904,
           6.180572189978742,
           6.186380479728442,
           6.192188769478143,
           6.197997059227845,
           6.203805348977545,
           6.209613638727246,
           6.215421928476946,
           6.221230218226648,
           6.2270385079763475,
           6.232846797726049,
           6.238655087475749,
           6.2444633772254505,
           6.25027166697515,
           6.256079956724852,
           6.2618882464745536,
           6.267696536224253,
           6.273504825973955,
           6.279313115723655,
           6.285121405473356,
           6.290929695223056,
           6.296737984972758,
           6.302546274722458,
           6.308354564472159,
           6.314162854221859,
           6.31997114397156,
           6.325779433721261,
           6.331587723470961,
           6.337396013220662,
           6.3432043029703635,
           6.349012592720064,
           6.354820882469765,
           6.360629172219466,
           6.3664374619691655,
           6.372245751718868,
           6.378054041468568,
           6.383862331218269,
           6.389670620967969,
           6.39547891071767,
           6.4012872004673715,
           6.407095490217071,
           6.412903779966774,
           6.418712069716473,
           6.4245203594661735,
           6.430328649215875,
           6.436136938965577,
           6.4419452287152765,
           6.447753518464978,
           6.453561808214678,
           6.4593700979643796,
           6.465178387714081,
           6.470986677463781,
           6.476794967213483,
           6.482603256963182,
           6.488411546712884,
           6.494219836462584,
           6.500028126212285,
           6.505836415961985,
           6.511644705711687,
           6.517452995461387,
           6.523261285211088,
           6.529069574960788,
           6.53487786471049,
           6.5406861544601895,
           6.546808078152614,
           6.552992728633583,
           6.559177379114553,
           6.565362029595521,
           6.571546680076491,
           6.577731330557459,
           6.5839159810384285,
           6.590100631519397,
           6.596285282000366,
           6.602469932481336,
           6.608654582962304,
           6.614839233443273,
           6.621023883924242,
           6.627208534405211,
           6.63339318488618,
           6.639577835367149,
           6.645762485848118,
           6.6519471363290865,
           6.658131786810055,
           6.664316437291025,
           6.670501087771994,
           6.676685738252962,
           6.682870388733932,
           6.6890550392148995,
           6.695239689695869,
           6.701424340176839,
           6.707608990657807,
           6.713793641138777,
           6.719978291619745,
           6.726162942100714,
           6.732347592581682,
           6.738532243062652,
           6.744716893543621,
           6.75090154402459,
           6.757086194505559,
           6.763270844986527,
           6.769455495467497,
           6.775640145948465,
           6.781824796429434,
           6.788009446910404,
           6.794194097391372,
           6.800378747872342,
           6.80656339835331,
           6.81274804883428,
           6.818932699315248,
           6.825117349796217,
           6.831302000277185,
           6.837486650758155,
           6.843671301239125,
           6.849855951720093,
           6.8560406022010625,
           6.862225252682032,
           6.868409903163,
           6.87459455364397,
           6.880779204124938,
           6.8869638546059075,
           6.8931485050868755,
           6.899333155567845,
           6.905517806048813,
           6.911702456529783,
           6.917887107010753,
           6.9240717574917205,
           6.93025640797269,
           6.936441058453658,
           6.942625708934628,
           6.949795869759585,
           6.958937045545859,
           6.968078221332134,
           6.977219397118409,
           6.986360572904684,
           6.995501748690959,
           7.004642924477233,
           7.013784100263509,
           7.022925276049783,
           7.032066451836057,
           7.041207627622332,
           7.050348803408607,
           7.059489979194882,
           7.068631154981157,
           7.077772330767431,
           7.086913506553706,
           7.09605468233998,
           7.105195858126255,
           7.114067326975391,
           7.122803942355956,
           7.131540557736522,
           7.140277173117087,
           7.149013788497653,
           7.15775040387822,
           7.166487019258785,
           7.175223634639351,
           7.183960250019916,
           7.192696865400483,
           7.201433480781048,
           7.2101700961616135,
           7.2189067115421786,
           7.2276433269227445,
           7.2363799423033095,
           7.245116557683875,
           7.253853173064442,
           7.262589788445008,
           7.271326403825573,
           7.280063019206139,
           7.288799634586704,
           7.297536249967269,
           7.306272865347836,
           7.315009480728402,
           7.323746096108967,
           7.332482711489533,
           7.3412193268701,
           7.349955942250665,
           7.3586925576312305,
           7.367429173011796,
           7.3761657883923615,
           7.3849024037729265,
           7.393639019153492,
           7.402375634534058,
           7.411112249914624,
           7.41984886529519,
           7.428585480675755,
           7.437322096056322,
           7.446058711436887,
           7.454795326817451,
           7.463531942198018,
           7.472268557578583,
           7.481005172959149,
           7.489741788339715,
           7.498478403720282,
           7.5072150191008475,
           7.515951634481413,
           7.5246882498619785,
           7.5334248652425435,
           7.542161480623109,
           7.550898096003676,
           7.5585880905041405,
           7.566128562209835,
           7.573669033915531,
           7.581209505621226,
           7.588749977326922,
           7.596290449032616,
           7.603830920738312,
           7.611371392444006,
           7.618911864149703,
           7.626452335855397,
           7.633992807561094,
           7.641533279266788,
           7.649073750972483,
           7.656614222678178,
           7.664154694383873,
           7.671695166089569,
           7.679235637795264,
           7.68677610950096,
           7.694316581206655,
           7.70185705291235,
           7.709397524618046,
           7.716937996323741,
           7.724478468029437,
           7.732018939735131,
           7.739559411440826,
           7.747099883146522,
           7.754640354852217,
           7.762180826557913,
           7.769721298263607,
           7.777261769969304,
           7.784802241674997,
           7.792342713380693,
           7.801551092045534,
           7.812427377669519,
           7.823303663293505,
           7.834179948917489,
           7.845056234541476,
           7.85593252016546,
           7.866808805789445,
           7.877685091413431,
           7.888561377037416,
           7.8994376626614,
           7.910313948285387,
           7.921190233909373,
           7.932066519533357,
           7.942942805157342,
           7.953819090781328,
           7.964695376405313,
           7.975571662029298,
           7.986447947653284,
           7.9973242332772685,
           8.008200518901253,
           8.01907680452524,
           8.029953090149226,
           8.040829375773209,
           8.051705661397195,
           8.06258194702118,
           8.073458232645166,
           8.08433451826915,
           8.095210803893135,
           8.106087089517121,
           8.116963375141106,
           8.127839660765092,
           8.138715946389079,
           8.149592232013061,
           8.160468517637048,
           8.171344803261032,
           8.182221088885019,
           8.193097374509003,
           8.20397366013299,
           8.214849945756974,
           8.226043974104359,
           8.238153842572569,
           8.25026371104078,
           8.26237357950899,
           8.274483447977202,
           8.286593316445416,
           8.298703184913625,
           8.310813053381837,
           8.322922921850049,
           8.335032790318259,
           8.34714265878647,
           8.359252527254682,
           8.371362395722892,
           8.383472264191104,
           8.395582132659316,
           8.407692001127527,
           8.419801869595736,
           8.431911738063949,
           8.44402160653216,
           8.45613147500037,
           8.46824134346858,
           8.480351211936794,
           8.492461080405004,
           8.504570948873214,
           8.516680817341426,
           8.528790685809637,
           8.540900554277847,
           8.553010422746059,
           8.56512029121427,
           8.57723015968248,
           8.589340028150692,
           8.601449896618904,
           8.613559765087114,
           8.625669633555326,
           8.637779502023538,
           8.64988937049175,
           8.66199923895996,
           8.67410910742817,
           8.68621897589638,
           8.698328844364593,
           8.710438712832804,
           8.722548581301016,
           8.734658449769226,
           8.746768318237436,
           8.761189140729762,
           8.780231871270304,
           8.79927460181085,
           8.818317332351398,
           8.837360062891943,
           8.856402793432487,
           8.875445523973033,
           8.894488254513579,
           8.913530985054123,
           8.93257371559467,
           8.951616446135217,
           8.970659176675762,
           8.989701907216306,
           9.008744637756852,
           9.027787368297396,
           9.04683009883794,
           9.065872829378488,
           9.084915559919033,
           9.103958290459579,
           9.123001021000123,
           9.14204375154067,
           9.161086482081215,
           9.180129212621761,
           9.199171943162305,
           9.218214673702853,
           9.237257404243397,
           9.256300134783944,
           9.275342865324488,
           9.294385595865034,
           9.31342832640558,
           9.332471056946126,
           9.35151378748667,
           9.370556518027216,
           9.389599248567762,
           9.408641979108307,
           9.427684709648853,
           9.446727440189399,
           9.465770170729943,
           9.48481290127049,
           9.503855631811035,
           9.52289836235158,
           9.541941092892124,
           9.56098382343267,
           9.580026553973216,
           9.59906928451376,
           9.618112015054308,
           9.637154745594856,
           9.6561974761354,
           9.675240206675944,
           9.69428293721649,
           9.713325667757035,
           9.73236839829758,
           9.751411128838127,
           9.770453859378673,
           9.789496589919217,
           9.808539320459763,
           9.82758205100031,
           9.846624781540855,
           9.8656675120814,
           9.884710242621946,
           9.903752973162492,
           9.922795703703034,
           9.941838434243582,
           9.960881164784126,
           9.97992389532467,
           9.998966625865219,
           10.018009356405765,
           10.037052086946307,
           10.056094817486855,
           10.075137548027401,
           10.094180278567947,
           10.113223009108491,
           10.13226573964904,
           10.151308470189583,
           10.170351200730126,
           10.189393931270674,
           10.20843666181122,
           10.229817616957158,
           10.251567756245255,
           10.273317895533353,
           10.29506803482145,
           10.316818174109544,
           10.338568313397644,
           10.354119624134517,
           10.338676792115306,
           10.323233960096093,
           10.307791128076882,
           10.292348296057675,
           10.242395839387237,
           10.191777111239887,
           10.141158383092542,
           10.090539654945188,
           10.039920926797834,
           9.98930219865049,
           9.938683470503136,
           9.888064742355782,
           9.837446014208428,
           9.786827286061083,
           9.73620855791373,
           9.685589829766377,
           9.634971101619033,
           9.584352373471678,
           9.533733645324325,
           9.483114917176982,
           9.432496189029628,
           9.381877460882274,
           9.33125873273493,
           9.280640004587578,
           9.230021276440223,
           9.17940254829287,
           9.128783820145525,
           9.078165091998173,
           9.027546363850817,
           8.976927635703474,
           8.92630890755612,
           8.875690179408767,
           8.825071451261422,
           8.774452723114068,
           8.723833994966714,
           8.673215266819362,
           8.622596538672017,
           8.571977810524663,
           8.52135908237731,
           8.470740354229967,
           8.420121626082611,
           8.36950289793526,
           8.318884169787914,
           8.268265441640562,
           8.217646713493206,
           8.167027985345864,
           8.11640925719851,
           8.065790529051156,
           8.015171800903804,
           7.964553072756459,
           7.913934344609105,
           7.863315616461751,
           7.812696888314408,
           7.762078160167054,
           7.7114594320197,
           7.6608407038723545,
           7.610221975725002,
           7.559603247577648,
           7.508984519430295,
           7.458365791282951,
           7.407747063135598,
           7.357128334988244,
           7.3065096068409,
           7.255890878693546,
           7.205272150546192,
           7.154653422398848,
           7.104034694251495,
           7.053415966104142,
           7.002797237956797,
           6.952178509809444,
           6.90155978166209,
           6.850941053514736,
           6.800322325367392,
           6.749703597220039,
           6.699084869072685,
           6.648466140925341,
           6.597847412777987,
           6.547228684630634,
           6.485134483585859,
           6.372689298498307,
           6.2602441134107565,
           6.147798928323206,
           6.035353743235676
          ],
          [
           6.476527942403858,
           6.485596958109409,
           6.494665973814961,
           6.503734989520511,
           6.512804005226061,
           6.521873020931613,
           6.530942036637163,
           6.540011052342715,
           6.549080068048266,
           6.558149083753816,
           6.567218099459367,
           6.576287115164917,
           6.585356130870468,
           6.59442514657602,
           6.603494162281571,
           6.612563177987122,
           6.6216321936926725,
           6.6307012093982225,
           6.639770225103773,
           6.648839240809324,
           6.657908256514875,
           6.666977272220426,
           6.676046287925978,
           6.6851153036315285,
           6.6941843193370785,
           6.70325333504263,
           6.712322350748181,
           6.721391366453732,
           6.730460382159283,
           6.739529397864834,
           6.7485984135703845,
           6.757667429275935,
           6.766736444981487,
           6.775805460687038,
           6.784874476392588,
           6.791226220795753,
           6.797034510545454,
           6.802842800295155,
           6.808651090044856,
           6.814459379794557,
           6.820267669544258,
           6.8260759592939575,
           6.831884249043659,
           6.83769253879336,
           6.8435008285430605,
           6.84930911829276,
           6.855117408042462,
           6.860925697792162,
           6.8667339875418625,
           6.872542277291565,
           6.878350567041264,
           6.884158856790966,
           6.889967146540666,
           6.895775436290366,
           6.901583726040069,
           6.907392015789768,
           6.913200305539471,
           6.91900859528917,
           6.9248168850388705,
           6.930625174788572,
           6.936433464538272,
           6.942241754287974,
           6.948050044037673,
           6.953858333787374,
           6.9596666235370765,
           6.965474913286777,
           6.971283203036478,
           6.977091492786179,
           6.982899782535879,
           6.988708072285581,
           6.994516362035281,
           7.000324651784982,
           7.006132941534682,
           7.011941231284384,
           7.017749521034084,
           7.023557810783785,
           7.029366100533485,
           7.035174390283187,
           7.0409826800328865,
           7.046790969782588,
           7.052599259532289,
           7.0584075492819895,
           7.06421583903169,
           7.070024128781391,
           7.076146052473815,
           7.082330702954785,
           7.088515353435753,
           7.0947000039167225,
           7.100884654397691,
           7.10706930487866,
           7.113253955359629,
           7.119438605840598,
           7.125623256321568,
           7.1318079068025355,
           7.1379925572835035,
           7.144177207764474,
           7.150361858245442,
           7.156546508726413,
           7.16273115920738,
           7.1689158096883485,
           7.175100460169319,
           7.181285110650288,
           7.187469761131257,
           7.193654411612226,
           7.1998390620931945,
           7.206023712574163,
           7.212208363055132,
           7.218393013536101,
           7.224577664017071,
           7.2307623144980395,
           7.236946964979008,
           7.243131615459977,
           7.249316265940946,
           7.255500916421915,
           7.261685566902884,
           7.267870217383853,
           7.274054867864823,
           7.280239518345791,
           7.286424168826759,
           7.292608819307729,
           7.298793469788697,
           7.304978120269666,
           7.311162770750636,
           7.317347421231604,
           7.323532071712574,
           7.329716722193543,
           7.3359013726745115,
           7.34208602315548,
           7.348270673636449,
           7.354455324117419,
           7.360639974598387,
           7.3668246250793565,
           7.373009275560325,
           7.381657697425986,
           7.390798873212261,
           7.399940048998536,
           7.409081224784811,
           7.418222400571086,
           7.42736357635736,
           7.436504752143635,
           7.44564592792991,
           7.454787103716184,
           7.463928279502459,
           7.473069455288733,
           7.482210631075008,
           7.4913518068612825,
           7.5004929826475575,
           7.5096341584338315,
           7.518775334220106,
           7.527916510006381,
           7.5370576857926554,
           7.54619886157893,
           7.555340037365205,
           7.56448121315148,
           7.573622388937755,
           7.582763564724029,
           7.591904740510303,
           7.601045916296579,
           7.610187092082852,
           7.619328267869128,
           7.628469443655403,
           7.637610619441678,
           7.646751795227953,
           7.655892971014227,
           7.665034146800502,
           7.674175322586776,
           7.683316498373051,
           7.692187967222187,
           7.700924582602752,
           7.709661197983317,
           7.718397813363883,
           7.727134428744448,
           7.735871044125015,
           7.744607659505581,
           7.753344274886146,
           7.762080890266711,
           7.770817505647278,
           7.779554121027844,
           7.78829073640841,
           7.797027351788975,
           7.80576396716954,
           7.814500582550107,
           7.823237197930672,
           7.831973813311238,
           7.8407104286918035,
           7.84944704407237,
           7.8581836594529335,
           7.8669202748335,
           7.875656890214067,
           7.884393505594631,
           7.893130120975198,
           7.901866736355764,
           7.910603351736329,
           7.919339967116894,
           7.92807658249746,
           7.936813197878027,
           7.945549813258591,
           7.954286428639158,
           7.963023044019723,
           7.9717596594002895,
           7.9804962747808545,
           7.989232890161421,
           7.997969505541986,
           8.006706120922551,
           8.015442736303116,
           8.024179351683683,
           8.032915967064248,
           8.041652582444813,
           8.05038919782538,
           8.059125813205945,
           8.067862428586512,
           8.076599043967077,
           8.085335659347642,
           8.094072274728209,
           8.102808890108774,
           8.11154550548934,
           8.120282120869906,
           8.129018736250472,
           8.137755351631037,
           8.146491967011602,
           8.155228582392168,
           8.163965197772734,
           8.1727018131533,
           8.181438428533866,
           8.190175043914431,
           8.198911659294998,
           8.207648274675563,
           8.216384890056128,
           8.225121505436695,
           8.23385812081726,
           8.242594736197825,
           8.251331351578392,
           8.260067966958957,
           8.268804582339524,
           8.277541197720089,
           8.286277813100654,
           8.29501442848122,
           8.303751043861785,
           8.31248765924235,
           8.321224274622917,
           8.329960890003482,
           8.338697505384049,
           8.348579540758513,
           8.359463811061985,
           8.370348081365456,
           8.38123235166893,
           8.392116621972402,
           8.403000892275875,
           8.413885162579348,
           8.424769432882819,
           8.436942868456777,
           8.450405469301222,
           8.463868070145667,
           8.47733067099011,
           8.490793271834555,
           8.504255872678998,
           8.517718473523441,
           8.531181074367886,
           8.544643675212331,
           8.558106276056773,
           8.57156887690122,
           8.585031477745664,
           8.598494078590107,
           8.61195667943455,
           8.625419280278996,
           8.638881881123439,
           8.652344481967882,
           8.665420594830685,
           8.677530463298897,
           8.689640331767107,
           8.701750200235319,
           8.713860068703532,
           8.72596993717174,
           8.738079805639952,
           8.750189674108164,
           8.762299542576375,
           8.774409411044585,
           8.786519279512797,
           8.798629147981007,
           8.810739016449219,
           8.82284888491743,
           8.834958753385642,
           8.84706862185385,
           8.859178490322062,
           8.871288358790276,
           8.883398227258485,
           8.895508095726697,
           8.907617964194909,
           8.919727832663119,
           8.93183770113133,
           8.94394756959954,
           8.956057438067752,
           8.968167306535962,
           8.980277175004176,
           8.992387043472387,
           9.004496911940597,
           9.016606780408807,
           9.02871664887702,
           9.04082651734523,
           9.052936385813442,
           9.065046254281654,
           9.077156122749864,
           9.089265991218076,
           9.101375859686286,
           9.113485728154497,
           9.12559559662271,
           9.13770546509092,
           9.149815333559133,
           9.161925202027343,
           9.174035070495552,
           9.186144938963764,
           9.198254807431976,
           9.210364675900188,
           9.2224745443684,
           9.23458441283661,
           9.24669428130482,
           9.258804149773031,
           9.270914018241243,
           9.28302388670945,
           9.295133755177662,
           9.307243623645876,
           9.319353492114086,
           9.331463360582298,
           9.34357322905051,
           9.35568309751872,
           9.36779296598693,
           9.379902834455141,
           9.392012702923353,
           9.404122571391564,
           9.416232439859776,
           9.428342308327986,
           9.4404521767962,
           9.452562045264408,
           9.466982867756734,
           9.486025598297278,
           9.505068328837824,
           9.524111059378368,
           9.543153789918913,
           9.562196520459459,
           9.581239251000005,
           9.600281981540553,
           9.619324712081093,
           9.638367442621641,
           9.657410173162187,
           9.676452903702733,
           9.695495634243278,
           9.714538364783824,
           9.733581095324368,
           9.752623825864914,
           9.77166655640546,
           9.790709286946004,
           9.80975201748655,
           9.828794748027097,
           9.847837478567644,
           9.866880209108189,
           9.885922939648733,
           9.904965670189279,
           9.924008400729825,
           9.94305113127037,
           9.962093861810915,
           9.98113659235146,
           10.000179322892004,
           10.019222053432552,
           10.038264783973098,
           10.057307514513642,
           10.076350245054188,
           10.095392975594734,
           10.114435706135279,
           10.133478436675825,
           10.15252116721637,
           10.171563897756915,
           10.190606628297461,
           10.209649358838007,
           10.228692089378551,
           10.247734819919096,
           10.267762071625317,
           10.289512210913415,
           10.31126235020151,
           10.333012489489606,
           10.354762628777705,
           10.3765127680658,
           10.398262907353896,
           10.420013046641994,
           10.44176318593009,
           10.463513325218186,
           10.485263464506286,
           10.507013603794384,
           10.528763743082475,
           10.550513882370574,
           10.572264021658672,
           10.594014160946768,
           10.615764300234863,
           10.63751443952296,
           10.659264578811054,
           10.681014718099153,
           10.702764857387251,
           10.724514996675346,
           10.74626513596344,
           10.76801527525154,
           10.789765414539637,
           10.811515553827732,
           10.83326569311583,
           10.855015832403929,
           10.876765971692024,
           10.898516110980118,
           10.920266250268217,
           10.942016389556313,
           10.96376652884441,
           10.985516668132506,
           11.007266807420605,
           11.029016946708698,
           11.050767085996796,
           11.072517225284894,
           11.09426736457299,
           11.116017503861086,
           11.137767643149182,
           11.15331895388606,
           11.137876121866848,
           11.122433289847635,
           11.106990457828424,
           11.091547625809216,
           11.076104793790005,
           11.06066196177079,
           11.045219129751583,
           11.029776297732372,
           11.014333465713161,
           10.998890633693954,
           10.983447801674739,
           10.968004969655528,
           10.952562137636317,
           10.937119305617108,
           10.921676473597898,
           10.906233641578686,
           10.890790809559476,
           10.875347977540265,
           10.859905145521054,
           10.844462313501845,
           10.829019481482632,
           10.813576649463421,
           10.798133817444214,
           10.782690985425003,
           10.767248153405792,
           10.737082128826419,
           10.686463400679076,
           10.635844672531721,
           10.585225944384367,
           10.534607216237024,
           10.48398848808967,
           10.433369759942316,
           10.382751031794971,
           10.332132303647619,
           10.281513575500265,
           10.23089484735291,
           10.180276119205567,
           10.129657391058213,
           10.079038662910861,
           10.028419934763516,
           9.977801206616162,
           9.927182478468808,
           9.876563750321463,
           9.82594502217411,
           9.775326294026758,
           9.724707565879413,
           9.674088837732059,
           9.623470109584707,
           9.572851381437353,
           9.522232653290008,
           9.471613925142654,
           9.420995196995301,
           9.370376468847956,
           9.319757740700602,
           9.26913901255325,
           9.218520284405905,
           9.167901556258553,
           9.071029989849077,
           8.958584804761527,
           8.846139619673997,
           8.733694434586447,
           8.621249249498895,
           8.508804064411365,
           8.396358879323815,
           8.283913694236265,
           8.171468509148733,
           8.059023324061185,
           7.946578138973633,
           7.834132953886103,
           7.721687768798552,
           7.609242583711001,
           7.4967973986234515,
           7.38435221353592,
           7.27190702844837,
           7.15946184336082,
           7.047016658273289,
           6.9345714731857395,
           6.822126288098188,
           6.7096811030106585,
           6.597235917923108,
           6.484790732835556,
           6.372345547748007,
           6.259900362660477
          ],
          [
           6.952063940231346,
           6.961132955936897,
           6.970201971642448,
           6.979270987347999,
           6.98834000305355,
           6.997409018759101,
           7.006478034464652,
           7.015547050170203,
           7.024616065875753,
           7.0336850815813055,
           7.042754097286856,
           7.051823112992405,
           7.060892128697957,
           7.069961144403508,
           7.07903016010906,
           7.088099175814611,
           7.09716819152016,
           7.106237207225712,
           7.115306222931263,
           7.124375238636814,
           7.133444254342365,
           7.142513270047916,
           7.1515822857534666,
           7.160651301459017,
           7.169720317164568,
           7.178789332870119,
           7.18785834857567,
           7.19692736428122,
           7.205996379986772,
           7.2150653956923225,
           7.224134411397873,
           7.233203427103423,
           7.242272442808975,
           7.251341458514526,
           7.260410474220076,
           7.269479489925628,
           7.278548505631178,
           7.2876175213367285,
           7.296686537042279,
           7.30575555274783,
           7.314824568453382,
           7.323893584158932,
           7.332962599864483,
           7.342031615570034,
           7.351100631275585,
           7.360169646981136,
           7.369238662686687,
           7.378307678392238,
           7.38737669409779,
           7.3964457098033405,
           7.405514725508891,
           7.413496831112178,
           7.419305120861878,
           7.425113410611578,
           7.43092170036128,
           7.43672999011098,
           7.442538279860681,
           7.448346569610382,
           7.454154859360083,
           7.459963149109784,
           7.465771438859484,
           7.471579728609186,
           7.4773880183588854,
           7.483196308108586,
           7.489004597858288,
           7.4948128876079885,
           7.500621177357689,
           7.50642946710739,
           7.5122377568570915,
           7.518046046606791,
           7.523854336356493,
           7.529662626106193,
           7.535470915855894,
           7.541279205605594,
           7.547087495355295,
           7.552895785104996,
           7.558704074854696,
           7.564512364604397,
           7.570320654354099,
           7.5761289441037984,
           7.5819372338535,
           7.5877455236032,
           7.5935538133529015,
           7.599362103102601,
           7.605484026795027,
           7.611668677275996,
           7.617853327756965,
           7.624037978237933,
           7.6302226287189026,
           7.6364072791998705,
           7.64259192968084,
           7.648776580161809,
           7.654961230642778,
           7.661145881123747,
           7.667330531604716,
           7.673515182085684,
           7.679699832566653,
           7.685884483047623,
           7.692069133528592,
           7.698253784009561,
           7.70443843449053,
           7.710623084971499,
           7.716807735452468,
           7.722992385933438,
           7.729177036414406,
           7.735361686895375,
           7.741546337376343,
           7.747730987857311,
           7.753915638338281,
           7.76010028881925,
           7.7662849393002205,
           7.772469589781188,
           7.778654240262156,
           7.784838890743126,
           7.791023541224094,
           7.7972081917050655,
           7.804378349306123,
           7.8135195250923974,
           7.822660700878673,
           7.831801876664948,
           7.840943052451222,
           7.850084228237497,
           7.859225404023771,
           7.868366579810046,
           7.877507755596321,
           7.886648931382595,
           7.895790107168871,
           7.904931282955145,
           7.91407245874142,
           7.923213634527695,
           7.932354810313969,
           7.941495986100245,
           7.950637161886519,
           7.959778337672793,
           7.968919513459069,
           7.978060689245343,
           7.987201865031617,
           7.996343040817893,
           8.005484216604167,
           8.014625392390442,
           8.023766568176717,
           8.03290774396299,
           8.042048919749266,
           8.05119009553554,
           8.060331271321814,
           8.06947244710809,
           8.078613622894364,
           8.087754798680638,
           8.096895974466914,
           8.106037150253188,
           8.115178326039462,
           8.124319501825738,
           8.133460677612012,
           8.142601853398288,
           8.151743029184562,
           8.160884204970838,
           8.17002538075711,
           8.179166556543386,
           8.18830773232966,
           8.197448908115936,
           8.20659008390221,
           8.215731259688484,
           8.22487243547476,
           8.234013611261034,
           8.24315478704731,
           8.252295962833584,
           8.261437138619858,
           8.270308607468994,
           8.27904522284956,
           8.287781838230124,
           8.296518453610691,
           8.305255068991256,
           8.313991684371821,
           8.322728299752388,
           8.331464915132953,
           8.34020153051352,
           8.348938145894085,
           8.357674761274652,
           8.366411376655217,
           8.375147992035782,
           8.383884607416348,
           8.392621222796913,
           8.40135783817748,
           8.410094453558045,
           8.41883106893861,
           8.427567684319175,
           8.436304299699742,
           8.445040915080305,
           8.453777530460874,
           8.462514145841439,
           8.471250761222004,
           8.479987376602573,
           8.488723991983136,
           8.497460607363703,
           8.506197222744268,
           8.514933838124833,
           8.5236704535054,
           8.532407068885965,
           8.54114368426653,
           8.549880299647096,
           8.558616915027663,
           8.567353530408228,
           8.576090145788793,
           8.584826761169358,
           8.593563376549923,
           8.60229999193049,
           8.611036607311055,
           8.61977322269162,
           8.628509838072187,
           8.637246453452754,
           8.645983068833319,
           8.654719684213884,
           8.66345629959445,
           8.672192914975016,
           8.68092953035558,
           8.689666145736147,
           8.698402761116714,
           8.70892908992525,
           8.719813360228722,
           8.730697630532196,
           8.74158190083567,
           8.752466171139142,
           8.763350441442613,
           8.774234711746086,
           8.785118982049559,
           8.796003252353032,
           8.806887522656504,
           8.817771792959975,
           8.828656063263448,
           8.839540333566923,
           8.850424603870394,
           8.861308874173867,
           8.87219314447734,
           8.883077414780812,
           8.893961685084285,
           8.904845955387758,
           8.915730225691231,
           8.926614495994702,
           8.937498766298175,
           8.948383036601648,
           8.95926730690512,
           8.970151577208592,
           8.981035847512064,
           8.991920117815537,
           9.00280438811901,
           9.013688658422483,
           9.024572928725956,
           9.035457199029427,
           9.046341469332901,
           9.057225739636372,
           9.06939917521033,
           9.082861776054775,
           9.09632437689922,
           9.109786977743664,
           9.123249578588108,
           9.136712179432552,
           9.150174780276995,
           9.16363738112144,
           9.177099981965885,
           9.190562582810326,
           9.204025183654773,
           9.217487784499218,
           9.230950385343661,
           9.244412986188104,
           9.257875587032547,
           9.271338187876992,
           9.284800788721435,
           9.29826338956588,
           9.311725990410324,
           9.325188591254769,
           9.338651192099213,
           9.352113792943658,
           9.3655763937881,
           9.379038994632545,
           9.39250159547699,
           9.405964196321433,
           9.419426797165876,
           9.432889398010321,
           9.446351998854764,
           9.459814599699207,
           9.473277200543652,
           9.486739801388097,
           9.50020240223254,
           9.513665003076985,
           9.52712760392143,
           9.540590204765873,
           9.554052805610317,
           9.56751540645476,
           9.580978007299205,
           9.594440608143648,
           9.607903208988093,
           9.621365809832536,
           9.63482841067698,
           9.648291011521426,
           9.661753612365871,
           9.675216213210314,
           9.688678814054757,
           9.702141414899202,
           9.715604015743645,
           9.729066616588089,
           9.742529217432535,
           9.755991818276978,
           9.769454419121422,
           9.782917019965867,
           9.796379620810312,
           9.809842221654755,
           9.8233048224992,
           9.836767423343643,
           9.850230024188086,
           9.86369262503253,
           9.877155225876974,
           9.890617826721419,
           9.904080427565862,
           9.917543028410307,
           9.93100562925475,
           9.944468230099194,
           9.957930830943639,
           9.971393431788083,
           9.984856032632527,
           9.998318633476972,
           10.011781234321417,
           10.025147219141072,
           10.037257087609284,
           10.049366956077495,
           10.061476824545705,
           10.073586693013915,
           10.085696561482127,
           10.097806429950339,
           10.109916298418549,
           10.12202616688676,
           10.134136035354972,
           10.146245903823184,
           10.158355772291394,
           10.172776594783718,
           10.191819325324262,
           10.210862055864807,
           10.229904786405354,
           10.2489475169459,
           10.267990247486445,
           10.28703297802699,
           10.306075708567537,
           10.327456665581586,
           10.349206804869684,
           10.370956944157781,
           10.392707083445877,
           10.414457222733974,
           10.43620736202207,
           10.457957501310167,
           10.479707640598264,
           10.50145777988636,
           10.523207919174457,
           10.544958058462553,
           10.56670819775065,
           10.588458337038748,
           10.610208476326843,
           10.63195861561494,
           10.653708754903038,
           10.675458894191133,
           10.69720903347923,
           10.718959172767327,
           10.740709312055424,
           10.762459451343519,
           10.784209590631617,
           10.805959729919715,
           10.827709869207808,
           10.849460008495907,
           10.871210147784005,
           10.8929602870721,
           10.914710426360196,
           10.936460565648293,
           10.95821070493639,
           10.979960844224486,
           11.001710983512583,
           11.023461122800677,
           11.045211262088776,
           11.066961401376874,
           11.08871154066497,
           11.110461679953067,
           11.132211819241162,
           11.15396195852926,
           11.175712097817357,
           11.197462237105452,
           11.21921237639355,
           11.240962515681646,
           11.262712654969741,
           11.284462794257841,
           11.306212933545938,
           11.327963072834033,
           11.34971321212213,
           11.371463351410226,
           11.393213490698322,
           11.41496362998642,
           11.436713769274517,
           11.458463908562614,
           11.480214047850708,
           11.501964187138807,
           11.523714326426902,
           11.545464465714998,
           11.567214605003096,
           11.588964744291193,
           11.610714883579288,
           11.632465022867386,
           11.654215162155483,
           11.67596530144358,
           11.697715440731674,
           11.719465580019772,
           11.741215719307867,
           11.762965858595965,
           11.784715997884062,
           11.80646613717216,
           11.828216276460255,
           11.849966415748352,
           11.87171655503645,
           11.893466694324546,
           11.915216833612643,
           11.93696697290074,
           11.952518283637614,
           11.937075451618403,
           11.92163261959919,
           11.90618978757998,
           11.890746955560772,
           11.87530412354156,
           11.859861291522348,
           11.844418459503139,
           11.82897562748393,
           11.813532795464717,
           11.798089963445507,
           11.782647131426296,
           11.767204299407084,
           11.751761467387873,
           11.736318635368665,
           11.720875803349454,
           11.705432971330241,
           11.689990139311034,
           11.674547307291823,
           11.65910447527261,
           11.6436616432534,
           11.62821881123419,
           11.612775979214979,
           11.59733314719577,
           11.581890315176558,
           11.566447483157347,
           11.551004651138136,
           11.535561819118925,
           11.520118987099714,
           11.504676155080501,
           11.457231061167082,
           11.386927258636462,
           11.316623456105843,
           11.246319653575236,
           11.176015851044616,
           11.105712048513997,
           11.035408245983376,
           10.96510444345277,
           10.894800640922151,
           10.824496838391532,
           10.754193035860924,
           10.683889233330305,
           10.613585430799684,
           10.543281628269078,
           10.47297782573846,
           10.40267402320784,
           10.332370220677234,
           10.262066418146613,
           10.191762615615994,
           10.121458813085374,
           10.05115501055477,
           9.980851208024148,
           9.91054740549353,
           9.840243602962921,
           9.745357349624065,
           9.632912164536512,
           9.520466979448983,
           9.408021794361431,
           9.295576609273882,
           9.183131424186332,
           9.070686239098801,
           8.95824105401125,
           8.8457958689237,
           8.73335068383617,
           8.62090549874862,
           8.508460313661068,
           8.396015128573538,
           8.28356994348599,
           8.171124758398438,
           8.058679573310908,
           7.946234388223356,
           7.833789203135806,
           7.7213440180482555,
           7.608898832960724,
           7.496453647873175,
           7.384008462785624,
           7.271563277698094,
           7.1591180926105435,
           7.046672907522993,
           6.934227722435463,
           6.821782537347913,
           6.709337352260362,
           6.596892167172811,
           6.484446982085281
          ],
          [
           7.427599938058826,
           7.436668953764378,
           7.445737969469928,
           7.454806985175479,
           7.463876000881029,
           7.47294501658658,
           7.482014032292131,
           7.491083047997682,
           7.500152063703233,
           7.509221079408785,
           7.518290095114335,
           7.527359110819885,
           7.536428126525437,
           7.545497142230988,
           7.55456615793654,
           7.56363517364209,
           7.57270418934764,
           7.581773205053191,
           7.590842220758742,
           7.599911236464293,
           7.608980252169844,
           7.618049267875395,
           7.627118283580945,
           7.636187299286497,
           7.645256314992047,
           7.654325330697598,
           7.663394346403149,
           7.6724633621087,
           7.681532377814251,
           7.690601393519802,
           7.6996704092253525,
           7.708739424930904,
           7.717808440636455,
           7.726877456342006,
           7.735946472047557,
           7.745015487753108,
           7.7540845034586585,
           7.763153519164209,
           7.77222253486976,
           7.781291550575311,
           7.790360566280862,
           7.799429581986413,
           7.808498597691964,
           7.8175676133975145,
           7.826636629103064,
           7.835705644808614,
           7.844774660514167,
           7.853843676219718,
           7.862912691925268,
           7.871981707630819,
           7.88105072333637,
           7.89011973904192,
           7.899188754747471,
           7.908257770453023,
           7.917326786158574,
           7.926395801864125,
           7.935464817569676,
           7.944533833275226,
           7.953602848980777,
           7.962671864686328,
           7.971740880391879,
           7.98080989609743,
           7.989878911802981,
           7.9989479275085325,
           8.008016943214082,
           8.017085958919633,
           8.026154974625184,
           8.035223990330735,
           8.041575731178291,
           8.047384020927993,
           8.053192310677693,
           8.059000600427394,
           8.064808890177094,
           8.070617179926796,
           8.076425469676495,
           8.082233759426197,
           8.088042049175897,
           8.093850338925598,
           8.0996586286753,
           8.105466918425,
           8.111275208174701,
           8.117083497924401,
           8.122891787674103,
           8.128700077423803,
           8.134822001116227,
           8.141006651597197,
           8.147191302078165,
           8.153375952559134,
           8.159560603040102,
           8.165745253521072,
           8.171929904002042,
           8.17811455448301,
           8.18429920496398,
           8.190483855444947,
           8.196668505925917,
           8.202853156406885,
           8.209037806887855,
           8.215222457368824,
           8.221407107849792,
           8.227591758330762,
           8.236240176972526,
           8.2453813527588,
           8.254522528545076,
           8.26366370433135,
           8.272804880117624,
           8.281946055903898,
           8.291087231690174,
           8.300228407476448,
           8.309369583262724,
           8.318510759048998,
           8.327651934835272,
           8.336793110621546,
           8.345934286407822,
           8.355075462194096,
           8.36421663798037,
           8.373357813766646,
           8.38249898955292,
           8.391640165339194,
           8.40078134112547,
           8.409922516911744,
           8.41906369269802,
           8.428204868484293,
           8.437346044270567,
           8.446487220056843,
           8.455628395843117,
           8.464769571629391,
           8.473910747415667,
           8.483051923201941,
           8.492193098988215,
           8.501334274774491,
           8.510475450560765,
           8.519616626347041,
           8.528757802133315,
           8.537898977919589,
           8.547040153705865,
           8.556181329492139,
           8.565322505278413,
           8.574463681064689,
           8.583604856850963,
           8.592746032637237,
           8.601887208423511,
           8.611028384209787,
           8.62016955999606,
           8.629310735782337,
           8.63845191156861,
           8.647593087354885,
           8.65673426314116,
           8.665875438927435,
           8.67501661471371,
           8.684157790499984,
           8.693298966286259,
           8.702440142072534,
           8.711581317858808,
           8.720722493645084,
           8.729863669431358,
           8.739004845217632,
           8.748146021003906,
           8.757287196790182,
           8.766428372576456,
           8.775569548362732,
           8.784710724149004,
           8.79385189993528,
           8.802993075721554,
           8.81213425150783,
           8.821275427294104,
           8.83041660308038,
           8.839557778866654,
           8.84842924771579,
           8.857165863096355,
           8.86590247847692,
           8.874639093857487,
           8.883375709238052,
           8.89211232461862,
           8.900848939999184,
           8.909585555379751,
           8.918322170760316,
           8.927058786140881,
           8.935795401521448,
           8.944532016902013,
           8.95326863228258,
           8.962005247663145,
           8.97074186304371,
           8.979478478424275,
           8.988215093804842,
           8.996951709185407,
           9.005688324565973,
           9.014424939946538,
           9.023161555327103,
           9.03189817070767,
           9.040634786088235,
           9.0493714014688,
           9.058394368788505,
           9.069278639091978,
           9.080162909395451,
           9.091047179698922,
           9.101931450002397,
           9.112815720305868,
           9.123699990609342,
           9.134584260912813,
           9.145468531216286,
           9.15635280151976,
           9.167237071823232,
           9.178121342126703,
           9.189005612430176,
           9.199889882733649,
           9.210774153037121,
           9.221658423340594,
           9.232542693644065,
           9.243426963947538,
           9.254311234251013,
           9.265195504554484,
           9.276079774857957,
           9.28696404516143,
           9.2978483154649,
           9.308732585768375,
           9.319616856071846,
           9.33050112637532,
           9.341385396678792,
           9.352269666982263,
           9.363153937285738,
           9.374038207589209,
           9.384922477892683,
           9.395806748196154,
           9.406691018499627,
           9.4175752888031,
           9.428459559106571,
           9.439343829410046,
           9.450228099713518,
           9.46111237001699,
           9.471996640320462,
           9.482880910623935,
           9.493765180927408,
           9.504649451230879,
           9.515533721534354,
           9.526417991837825,
           9.5373022621413,
           9.54818653244477,
           9.559070802748243,
           9.569955073051716,
           9.580839343355187,
           9.591723613658662,
           9.602607883962133,
           9.613492154265606,
           9.624376424569078,
           9.635260694872551,
           9.646144965176022,
           9.657029235479495,
           9.66791350578297,
           9.67879777608644,
           9.689682046389914,
           9.701855481963872,
           9.715318082808317,
           9.728780683652761,
           9.742243284497203,
           9.755705885341648,
           9.769168486186093,
           9.782631087030534,
           9.796093687874981,
           9.809556288719428,
           9.823018889563869,
           9.836481490408314,
           9.849944091252757,
           9.8634066920972,
           9.876869292941645,
           9.89033189378609,
           9.903794494630532,
           9.917257095474977,
           9.930719696319422,
           9.944182297163866,
           9.957644898008308,
           9.971107498852753,
           9.984570099697198,
           9.998032700541641,
           10.011495301386086,
           10.024957902230529,
           10.038420503074972,
           10.051883103919417,
           10.065345704763862,
           10.078808305608305,
           10.09227090645275,
           10.105733507297195,
           10.11919610814164,
           10.132658708986082,
           10.146121309830527,
           10.15958391067497,
           10.173046511519413,
           10.186509112363858,
           10.199971713208303,
           10.213434314052748,
           10.226896914897189,
           10.240359515741634,
           10.253822116586079,
           10.267284717430522,
           10.280747318274967,
           10.29420991911941,
           10.307672519963853,
           10.321135120808297,
           10.334597721652743,
           10.348060322497187,
           10.361522923341631,
           10.374985524186076,
           10.38844812503052,
           10.401910725874963,
           10.415373326719408,
           10.428835927563853,
           10.442298528408296,
           10.455761129252739,
           10.469223730097184,
           10.482686330941627,
           10.496427512486411,
           10.512211569719083,
           10.527995626951753,
           10.543779684184424,
           10.559563741417096,
           10.575347798649766,
           10.591131855882436,
           10.606915913115106,
           10.622699970347778,
           10.638484027580448,
           10.654268084813118,
           10.67005214204579,
           10.685836199278462,
           10.70162025651113,
           10.717404313743803,
           10.733188370976473,
           10.748972428209143,
           10.764756485441815,
           10.780540542674487,
           10.796324599907155,
           10.812108657139827,
           10.8278927143725,
           10.843676771605168,
           10.85946082883784,
           10.877402686203745,
           10.899660143836112,
           10.921917601468476,
           10.944175059100846,
           10.966432516733214,
           10.988689974365583,
           11.01094743199795,
           11.03320488963032,
           11.055462347262687,
           11.077719804895054,
           11.099977262527423,
           11.12223472015979,
           11.14449217779216,
           11.166749635424528,
           11.189007093056894,
           11.211264550689261,
           11.233522008321632,
           11.255779465953998,
           11.278036923586365,
           11.300294381218734,
           11.322551838851103,
           11.34480929648347,
           11.367066754115836,
           11.389324211748207,
           11.411581669380574,
           11.433839127012941,
           11.456096584645309,
           11.478354042277676,
           11.500611499910045,
           11.522868957542414,
           11.545126415174781,
           11.567383872807149,
           11.589641330439518,
           11.611898788071887,
           11.634156245704254,
           11.656413703336622,
           11.678671160968989,
           11.700928618601356,
           11.723186076233723,
           11.745443533866094,
           11.767700991498462,
           11.789958449130825,
           11.812215906763196,
           11.834473364395567,
           11.856730822027934,
           11.878988279660298,
           11.901245737292669,
           11.923503194925036,
           11.945760652557404,
           11.968018110189773,
           11.990275567822142,
           12.012533025454507,
           12.034790483086876,
           12.057047940719247,
           12.079305398351611,
           12.101562855983978,
           12.12382031361635,
           12.146077771248716,
           12.168335228881084,
           12.190592686513453,
           12.21285014414582,
           12.235107601778186,
           12.257365059410555,
           12.279622517042924,
           12.301879974675288,
           12.324137432307658,
           12.346394889940028,
           12.368652347572395,
           12.390909805204762,
           12.413167262837133,
           12.435424720469499,
           12.457682178101866,
           12.480958033818109,
           12.50543052053233,
           12.529903007246553,
           12.55437549396078,
           12.578847980675004,
           12.603320467389224,
           12.627792954103448,
           12.652265440817674,
           12.676737927531896,
           12.70121041424612,
           12.725682900960344,
           12.740215839792596,
           12.705051039215018,
           12.669886238637439,
           12.63472143805986,
           12.599556637482287,
           12.56439183690471,
           12.529227036327129,
           12.494062235749556,
           12.445929402325694,
           12.375625599795073,
           12.305321797264467,
           12.235017994733848,
           12.164714192203228,
           12.094410389672609,
           12.024106587142,
           11.953802784611383,
           11.883498982080763,
           11.813195179550156,
           11.742891377019538,
           11.672587574488917,
           11.60228377195831,
           11.53197996942769,
           11.461676166897071,
           11.391372364366465,
           11.321068561835844,
           11.250764759305223,
           11.180460956774606,
           11.110157154244,
           11.03985335171338,
           10.96954954918276,
           10.899245746652154,
           10.828941944121535,
           10.758638141590914,
           10.688334339060308,
           10.61803053652969,
           10.54772673399907,
           10.47742293146845,
           10.407119128937843,
           10.336815326407223,
           10.266511523876604,
           10.196207721345996,
           10.125903918815377,
           10.055600116284758,
           9.985296313754151,
           9.91499251122353,
           9.844688708692912,
           9.774384906162304,
           9.704081103631687,
           9.633777301101066,
           9.563473498570447,
           9.49316969603984,
           9.422865893509222,
           9.352562090978601,
           9.282258288447993,
           9.211954485917374,
           9.141650683386754,
           9.071346880856147,
           9.001043078325528,
           8.93073927579491,
           8.860435473264289,
           8.790131670733683,
           8.719827868203064,
           8.649524065672445,
           8.579220263141838,
           8.508916460611218,
           8.438612658080597,
           8.36830885554999,
           8.298005053019372,
           8.227701250488753,
           8.157397447958147,
           8.087093645427526,
           8.016789842896907,
           7.946486040366287,
           7.87618223783568,
           7.80587843530506,
           7.735574632774441,
           7.61578792719968,
           7.483445708003835,
           7.351103488807989,
           7.218761269612166,
           7.086419050416319,
           6.954076831220473,
           6.821734612024627,
           6.689392392828805
          ],
          [
           7.90304362292272,
           7.913747046050547,
           7.922816061756097,
           7.931885077461649,
           7.9409540931672,
           7.950023108872751,
           7.959092124578301,
           7.9681611402838515,
           7.977230155989403,
           7.986299171694954,
           7.995368187400505,
           8.004437203106056,
           8.013506218811607,
           8.022575234517157,
           8.031644250222708,
           8.04071326592826,
           8.04978228163381,
           8.05885129733936,
           8.067920313044912,
           8.076989328750463,
           8.086058344456013,
           8.095127360161564,
           8.104196375867115,
           8.113265391572666,
           8.122334407278217,
           8.131403422983768,
           8.140472438689319,
           8.149541454394868,
           8.15861047010042,
           8.167679485805971,
           8.176748501511522,
           8.185817517217073,
           8.194886532922624,
           8.203955548628176,
           8.213024564333725,
           8.222093580039276,
           8.231162595744827,
           8.240231611450378,
           8.249300627155929,
           8.25836964286148,
           8.26743865856703,
           8.276507674272581,
           8.285576689978132,
           8.294645705683685,
           8.303714721389234,
           8.312783737094787,
           8.321852752800336,
           8.330921768505887,
           8.339990784211437,
           8.349059799916988,
           8.358128815622539,
           8.367197831328092,
           8.37626684703364,
           8.385335862739193,
           8.394404878444742,
           8.403473894150295,
           8.412542909855844,
           8.421611925561395,
           8.430680941266946,
           8.439749956972497,
           8.44881897267805,
           8.4578879883836,
           8.46695700408915,
           8.476026019794702,
           8.485095035500253,
           8.494164051205804,
           8.503233066911353,
           8.512302082616905,
           8.521371098322456,
           8.530440114028007,
           8.539509129733558,
           8.548578145439109,
           8.55764716114466,
           8.56671617685021,
           8.575785192555761,
           8.584854208261312,
           8.593923223966861,
           8.602992239672414,
           8.612061255377965,
           8.621130271083516,
           8.630199286789066,
           8.639268302494619,
           8.64833731820017,
           8.65740633390572,
           8.668003111553539,
           8.677144287339814,
           8.686285463126087,
           8.695426638912362,
           8.704567814698636,
           8.713708990484912,
           8.722850166271186,
           8.73199134205746,
           8.741132517843736,
           8.75027369363001,
           8.759414869416284,
           8.76855604520256,
           8.777697220988834,
           8.786838396775108,
           8.795979572561384,
           8.805120748347658,
           8.814261924133932,
           8.82340309992021,
           8.832544275706482,
           8.841685451492758,
           8.850826627279034,
           8.859967803065306,
           8.869108978851582,
           8.878250154637856,
           8.887391330424132,
           8.896532506210406,
           8.905673681996682,
           8.914814857782956,
           8.92395603356923,
           8.933097209355505,
           8.942238385141778,
           8.951379560928054,
           8.960520736714328,
           8.969661912500602,
           8.978803088286877,
           8.987944264073153,
           8.997085439859427,
           9.006226615645701,
           9.015367791431975,
           9.024508967218251,
           9.033650143004525,
           9.0427913187908,
           9.051932494577075,
           9.06107367036335,
           9.070214846149623,
           9.079356021935899,
           9.088497197722173,
           9.097638373508449,
           9.106779549294723,
           9.115920725080997,
           9.125061900867273,
           9.134203076653547,
           9.143344252439821,
           9.152485428226097,
           9.16162660401237,
           9.170767779798645,
           9.17990895558492,
           9.189050131371195,
           9.198191307157469,
           9.207332482943745,
           9.216473658730019,
           9.225614834516293,
           9.234756010302569,
           9.243897186088843,
           9.253038361875118,
           9.262179537661392,
           9.271320713447667,
           9.280461889233942,
           9.289603065020216,
           9.298744240806492,
           9.307885416592768,
           9.31702659237904,
           9.326167768165314,
           9.33530894395159,
           9.344450119737864,
           9.35359129552414,
           9.362732471310414,
           9.371873647096688,
           9.381014822882964,
           9.390155998669238,
           9.399297174455514,
           9.408438350241788,
           9.417579526028062,
           9.428338094006243,
           9.439905358080372,
           9.451396728865662,
           9.462280999169137,
           9.473165269472606,
           9.48404953977608,
           9.494933810079553,
           9.505818080383026,
           9.516702350686499,
           9.527586620989972,
           9.538470891293445,
           9.549355161596916,
           9.560239431900388,
           9.571123702203861,
           9.582007972507334,
           9.592892242810807,
           9.60377651311428,
           9.614660783417753,
           9.625545053721225,
           9.636429324024697,
           9.647313594328168,
           9.658197864631642,
           9.669082134935113,
           9.679966405238586,
           9.690850675542059,
           9.701734945845532,
           9.712619216149005,
           9.723503486452476,
           9.73438775675595,
           9.745272027059421,
           9.756156297362896,
           9.767040567666367,
           9.77792483796984,
           9.788809108273313,
           9.799693378576785,
           9.810577648880258,
           9.82146191918373,
           9.8323461894872,
           9.843230459790675,
           9.854114730094146,
           9.86499900039762,
           9.875883270701092,
           9.886767541004566,
           9.897651811308037,
           9.90853608161151,
           9.919420351914983,
           9.930304622218454,
           9.941188892521929,
           9.9520731628254,
           9.962957433128874,
           9.973841703432345,
           9.984725973735816,
           9.995610244039291,
           10.006494514342762,
           10.017378784646237,
           10.028263054949708,
           10.039147325253179,
           10.050031595556653,
           10.060915865860125,
           10.0718001361636,
           10.08268440646707,
           10.093568676770543,
           10.104452947074016,
           10.115337217377487,
           10.126221487680962,
           10.137105757984434,
           10.147990028287905,
           10.158874298591378,
           10.169758568894851,
           10.180642839198324,
           10.191527109501797,
           10.20241137980527,
           10.21329565010874,
           10.224179920412215,
           10.235064190715686,
           10.24594846101916,
           10.256832731322632,
           10.267717001626103,
           10.278601271929576,
           10.28948554223305,
           10.300369812536522,
           10.311254082839994,
           10.322138353143467,
           10.334311788717425,
           10.34777438956187,
           10.361236990406313,
           10.374699591250756,
           10.388162192095201,
           10.401624792939646,
           10.41508739378409,
           10.428549994628533,
           10.442012595472978,
           10.45547519631742,
           10.468937797161868,
           10.482400398006313,
           10.495862998850754,
           10.509325599695199,
           10.522788200539644,
           10.536250801384085,
           10.54971340222853,
           10.563176003072975,
           10.576638603917418,
           10.590101204761861,
           10.603563805606306,
           10.617026406450751,
           10.630489007295195,
           10.64395160813964,
           10.657414208984084,
           10.670876809828528,
           10.68433941067297,
           10.697802011517414,
           10.711264612361859,
           10.725841516120212,
           10.741625573352886,
           10.757409630585558,
           10.773193687818226,
           10.788977745050897,
           10.80476180228357,
           10.82054585951624,
           10.836329916748909,
           10.85211397398158,
           10.867898031214251,
           10.883682088446921,
           10.899466145679593,
           10.915250202912263,
           10.931034260144934,
           10.946818317377605,
           10.962602374610277,
           10.978386431842946,
           10.994170489075618,
           11.00995454630829,
           11.025738603540958,
           11.04152266077363,
           11.0573067180063,
           11.07309077523897,
           11.088874832471642,
           11.104658889704313,
           11.120442946936985,
           11.136227004169653,
           11.152011061402325,
           11.167795118634997,
           11.183579175867667,
           11.199363233100339,
           11.215147290333011,
           11.23093134756568,
           11.246715404798348,
           11.262499462031021,
           11.27828351926369,
           11.29406757649636,
           11.309851633729034,
           11.325635690961704,
           11.341419748194372,
           11.357203805427044,
           11.372987862659716,
           11.388771919892386,
           11.404555977125058,
           11.420340034357729,
           11.436124091590399,
           11.45190814882307,
           11.467692206055741,
           11.483476263288411,
           11.49926032052108,
           11.515044377753753,
           11.530828434986425,
           11.546612492219094,
           11.562396549451764,
           11.580338406817669,
           11.602595864450036,
           11.624853322082403,
           11.647110779714772,
           11.66936823734714,
           11.691625694979507,
           11.713883152611874,
           11.736140610244245,
           11.758398067876612,
           11.78065552550898,
           11.802912983141347,
           11.825170440773716,
           11.847427898406082,
           11.869685356038453,
           11.891942813670818,
           11.914200271303187,
           11.936457728935554,
           11.958715186567924,
           11.98097264420029,
           12.003230101832658,
           12.025487559465029,
           12.047745017097395,
           12.070002474729764,
           12.092259932362131,
           12.1145173899945,
           12.136774847626867,
           12.159032305259235,
           12.181289762891602,
           12.20354722052397,
           12.225804678156338,
           12.248062135788707,
           12.270319593421073,
           12.292577051053442,
           12.314834508685813,
           12.337091966318178,
           12.359349423950547,
           12.381606881582915,
           12.403864339215282,
           12.42612179684765,
           12.448767519415668,
           12.473240006129892,
           12.497712492844114,
           12.52218497955834,
           12.546657466272563,
           12.571129952986787,
           12.595602439701008,
           12.620074926415235,
           12.644547413129459,
           12.66901989984368,
           12.693492386557905,
           12.717964873272127,
           12.74243735998635,
           12.766909846700575,
           12.791382333414798,
           12.815854820129019,
           12.840327306843246,
           12.86479979355747,
           12.889272280271694,
           12.913744766985914,
           12.93821725370014,
           12.962689740414362,
           12.987162227128586,
           13.01163471384281,
           13.036107200557034,
           13.060579687271256,
           13.085052173985481,
           13.109524660699705,
           13.133997147413925,
           13.158469634128153,
           13.182942120842377,
           13.207414607556599,
           13.23188709427082,
           13.256359580985047,
           13.280832067699269,
           13.305304554413492,
           13.329777041127716,
           13.354249527841942,
           13.378722014556164,
           13.403194501270388,
           13.427666987984612,
           13.452139474698834,
           13.476611961413058,
           13.501084448127283,
           13.515617386959534,
           13.480452586381954,
           13.445287785804375,
           13.410122985226797,
           13.374958184649227,
           13.339793384071648,
           13.304628583494067,
           13.269463782916496,
           13.234298982338917,
           13.199134181761337,
           13.163969381183765,
           13.128804580606186,
           13.093639780028607,
           13.058474979451027,
           13.023310178873455,
           12.988145378295876,
           12.952980577718296,
           12.917815777140724,
           12.882650976563145,
           12.847486175985566,
           12.812321375407993,
           12.777156574830414,
           12.741991774252835,
           12.706826973675263,
           12.671662173097683,
           12.636497372520106,
           12.601332571942526,
           12.566167771364952,
           12.531002970787375,
           12.495838170209794,
           12.460673369632222,
           12.398108491478512,
           12.327804688947893,
           12.257500886417287,
           12.187197083886666,
           12.116893281356047,
           12.046589478825425,
           11.97628567629482,
           11.9059818737642,
           11.83567807123358,
           11.765374268702976,
           11.695070466172355,
           11.624766663641736,
           11.554462861111128,
           11.48415905858051,
           11.413855256049889,
           11.343551453519282,
           11.273247650988663,
           11.202943848458043,
           11.132640045927424,
           11.062336243396818,
           10.992032440866199,
           10.921728638335578,
           10.827421916668102,
           10.695079697472256,
           10.56273747827641,
           10.430395259080587,
           10.29805303988474,
           10.165710820688894,
           10.033368601493049,
           9.901026382297228,
           9.76868416310138,
           9.636341943905533,
           9.503999724709711,
           9.371657505513864,
           9.23931528631802,
           9.106973067122198,
           8.97463084792635,
           8.842288628730504,
           8.709946409534682,
           8.577604190338835,
           8.445261971142989,
           8.312919751947142,
           8.180577532751322,
           8.048235313555473,
           7.915893094359628,
           7.783550875163805,
           7.6512086559679595,
           7.518866436772113,
           7.386524217576291,
           7.254181998380444,
           7.121839779184598,
           6.989497559988752,
           6.85715534079293
          ],
          [
           8.375533283698635,
           8.387871124144752,
           8.400208964590867,
           8.412546805036984,
           8.4248846454831,
           8.437222485929217,
           8.449560326375332,
           8.461898166821449,
           8.474236007267566,
           8.486573847713682,
           8.498911688159799,
           8.511249528605914,
           8.52358736905203,
           8.535925209498147,
           8.548263049944264,
           8.560600890390381,
           8.572938730836496,
           8.585276566873961,
           8.594345582579514,
           8.603414598285065,
           8.612483613990616,
           8.621552629696168,
           8.630621645401718,
           8.63969066110727,
           8.64875967681282,
           8.657828692518372,
           8.666897708223921,
           8.675966723929472,
           8.685035739635023,
           8.694104755340575,
           8.703173771046124,
           8.712242786751677,
           8.721311802457226,
           8.730380818162779,
           8.73944983386833,
           8.74851884957388,
           8.757587865279431,
           8.766656880984982,
           8.775725896690531,
           8.784794912396082,
           8.793863928101633,
           8.802932943807185,
           8.812001959512735,
           8.821070975218287,
           8.830139990923838,
           8.839209006629387,
           8.84827802233494,
           8.85734703804049,
           8.86641605374604,
           8.875485069451592,
           8.884554085157141,
           8.893623100862694,
           8.902692116568243,
           8.911761132273794,
           8.920830147979347,
           8.929899163684896,
           8.938968179390448,
           8.948037195095997,
           8.957106210801548,
           8.9661752265071,
           8.97524424221265,
           8.984313257918203,
           8.993382273623753,
           9.002451289329304,
           9.011520305034853,
           9.020589320740406,
           9.029658336445957,
           9.038727352151508,
           9.047796367857059,
           9.05686538356261,
           9.06593439926816,
           9.07500341497371,
           9.084072430679262,
           9.093141446384813,
           9.102210462090364,
           9.111279477795915,
           9.120348493501465,
           9.129417509207016,
           9.138486524912567,
           9.147555540618118,
           9.15662455632367,
           9.16569357202922,
           9.17476258773477,
           9.183831603440321,
           9.195406807521085,
           9.20748324927689,
           9.219559691032696,
           9.231636132788502,
           9.243712574544306,
           9.25578901630011,
           9.267865458055915,
           9.279941899811721,
           9.292018341567527,
           9.304094783323333,
           9.316171225079138,
           9.328247666834944,
           9.34032410859075,
           9.352400550346555,
           9.364476992102361,
           9.376553433858165,
           9.38862987561397,
           9.398260258436387,
           9.407401434222662,
           9.416542610008936,
           9.425683785795211,
           9.434824961581485,
           9.44396613736776,
           9.453107313154034,
           9.46224848894031,
           9.471389664726583,
           9.48053084051286,
           9.489672016299133,
           9.498813192085407,
           9.507954367871683,
           9.517095543657957,
           9.526236719444233,
           9.535377895230507,
           9.54451907101678,
           9.553660246803057,
           9.562801422589331,
           9.571942598375607,
           9.581083774161879,
           9.590224949948155,
           9.599366125734429,
           9.608507301520703,
           9.617648477306979,
           9.626789653093255,
           9.635930828879527,
           9.645072004665803,
           9.654213180452079,
           9.663354356238353,
           9.672495532024627,
           9.681636707810902,
           9.690777883597175,
           9.699919059383452,
           9.709060235169726,
           9.718201410956,
           9.727342586742274,
           9.73648376252855,
           9.745624938314824,
           9.754766114101098,
           9.763907289887374,
           9.773048465673648,
           9.782189641459922,
           9.791330817246198,
           9.800471993032472,
           9.809613168818748,
           9.818754344605022,
           9.827895520391296,
           9.83703669617757,
           9.846177871963846,
           9.85531904775012,
           9.864460223536396,
           9.87360139932267,
           9.882742575108946,
           9.89188375089522,
           9.901024926681494,
           9.91016610246777,
           9.919307278254042,
           9.928448454040318,
           9.937589629826592,
           9.946730805612868,
           9.955871981399142,
           9.965013157185417,
           9.974154332971692,
           9.983295508757966,
           9.992436684544241,
           10.003195252522419,
           10.014762516596548,
           10.026329780670679,
           10.03789704474481,
           10.04946430881894,
           10.061031572893071,
           10.072598836967199,
           10.084166101041331,
           10.095733365115462,
           10.107300629189591,
           10.118867893263724,
           10.130435157337853,
           10.142002421411984,
           10.153569685486115,
           10.165136949560244,
           10.176704213634375,
           10.188271477708504,
           10.199838741782635,
           10.211406005856766,
           10.222973269930895,
           10.234540534005026,
           10.246107798079157,
           10.257675062153286,
           10.269242326227419,
           10.280809590301548,
           10.292376854375679,
           10.30394411844981,
           10.315511382523939,
           10.327078646598071,
           10.3386459106722,
           10.35021317474633,
           10.36178043882046,
           10.373347702894591,
           10.384914966968722,
           10.396482231042853,
           10.408049495116982,
           10.419616759191111,
           10.431184023265242,
           10.442751287339373,
           10.454318551413504,
           10.465885815487635,
           10.477453079561764,
           10.489020343635897,
           10.500587607710026,
           10.512154871784157,
           10.523722135858286,
           10.535289399932417,
           10.546856664006548,
           10.558423928080675,
           10.569991192154808,
           10.581558456228938,
           10.593125720303068,
           10.604692984377198,
           10.616260248451328,
           10.62782751252546,
           10.63939477659959,
           10.65096204067372,
           10.662529304747851,
           10.67409656882198,
           10.685663832896111,
           10.697231096970242,
           10.708798361044373,
           10.7203656251185,
           10.731932889192635,
           10.743500153266762,
           10.755067417340893,
           10.766634681415022,
           10.778201945489155,
           10.789769209563286,
           10.801336473637415,
           10.812903737711546,
           10.824471001785678,
           10.836038265859807,
           10.847605529933936,
           10.859172794008067,
           10.870740058082196,
           10.882307322156327,
           10.893874586230458,
           10.905441850304587,
           10.917009114378718,
           10.92857637845285,
           10.94014364252698,
           10.952778989217196,
           10.96914207207775,
           10.986682113049147,
           11.00247647976308,
           11.018270846477014,
           11.03406521319095,
           11.049859579904883,
           11.065653946618818,
           11.081448313332752,
           11.097242680046687,
           11.113037046760619,
           11.128831413474554,
           11.14462578018849,
           11.160420146902421,
           11.176214513616355,
           11.19200888033029,
           11.20780043547675,
           11.22358449270942,
           11.23936854994209,
           11.255152607174763,
           11.270936664407431,
           11.286720721640105,
           11.302504778872777,
           11.318288836105445,
           11.334072893338115,
           11.349856950570786,
           11.365641007803458,
           11.381425065036128,
           11.397209122268798,
           11.41299317950147,
           11.428777236734138,
           11.444561293966812,
           11.460345351199482,
           11.476129408432152,
           11.491913465664823,
           11.507697522897494,
           11.523481580130166,
           11.539265637362835,
           11.555049694595507,
           11.570833751828175,
           11.586617809060847,
           11.602401866293519,
           11.618185923526188,
           11.63396998075886,
           11.649754037991531,
           11.665538095224203,
           11.681322152456872,
           11.697106209689544,
           11.712890266922214,
           11.728674324154884,
           11.744458381387556,
           11.760242438620226,
           11.776026495852896,
           11.791810553085567,
           11.807594610318239,
           11.823378667550909,
           11.839162724783579,
           11.85494678201625,
           11.870730839248923,
           11.886514896481593,
           11.902298953714263,
           11.918083010946935,
           11.933867068179602,
           11.949651125412275,
           11.965435182644946,
           11.981219239877616,
           11.997003297110286,
           12.012787354342958,
           12.028571411575628,
           12.044355468808298,
           12.06013952604097,
           12.075923583273642,
           12.091707640506312,
           12.107491697738983,
           12.123275754971655,
           12.139059812204325,
           12.154843869436993,
           12.170627926669667,
           12.186411983902337,
           12.202196041135005,
           12.21798009836768,
           12.233764155600351,
           12.24954821283302,
           12.265332270065691,
           12.283274127431595,
           12.305531585063962,
           12.327789042696327,
           12.350046500328698,
           12.372303957961064,
           12.394561415593433,
           12.416818873225802,
           12.441049491727453,
           12.465521978441673,
           12.489994465155899,
           12.514466951870125,
           12.538939438584348,
           12.56341192529857,
           12.587884412012794,
           12.612356898727018,
           12.636829385441239,
           12.661301872155464,
           12.685774358869688,
           12.71024684558391,
           12.734719332298134,
           12.759191819012361,
           12.783664305726584,
           12.808136792440806,
           12.832609279155031,
           12.857081765869253,
           12.881554252583475,
           12.906026739297701,
           12.930499226011925,
           12.954971712726147,
           12.979444199440373,
           13.003916686154597,
           13.028389172868815,
           13.05286165958304,
           13.077334146297266,
           13.10180663301149,
           13.126279119725712,
           13.150751606439938,
           13.17522409315416,
           13.199696579868382,
           13.224169066582608,
           13.24864155329683,
           13.273114040011052,
           13.297586526725278,
           13.322059013439501,
           13.346531500153725,
           13.371003986867947,
           13.395476473582171,
           13.419948960296395,
           13.444421447010617,
           13.468893933724843,
           13.493366420439065,
           13.517838907153287,
           13.542311393867514,
           13.566783880581738,
           13.591256367295959,
           13.615728854010184,
           13.640201340724408,
           13.664673827438632,
           13.689146314152854,
           13.713618800867078,
           13.7380912875813,
           13.762563774295522,
           13.78703626100975,
           13.811508747723972,
           13.835981234438194,
           13.86045372115242,
           13.884926207866643,
           13.909398694580863,
           13.933871181295089,
           13.958343668009315,
           13.982816154723537,
           14.00728864143776,
           14.031761128151985,
           14.056233614866205,
           14.08070610158043,
           14.105178588294656,
           14.12965107500888,
           14.154123561723102,
           14.178596048437324,
           14.20306853515155,
           14.227541021865774,
           14.252013508579996,
           14.276485995294221,
           14.291018934126473,
           14.255854133548894,
           14.220689332971315,
           14.185524532393737,
           14.150359731816165,
           14.115194931238584,
           14.080030130661006,
           14.044865330083434,
           14.009700529505857,
           13.974535728928275,
           13.939370928350703,
           13.904206127773124,
           13.869041327195545,
           13.833876526617965,
           13.798711726040393,
           13.763546925462814,
           13.728382124885234,
           13.693217324307664,
           13.658052523730086,
           13.622887723152505,
           13.587722922574933,
           13.530865888808613,
           13.439747062007523,
           13.34862823520645,
           13.257509408405356,
           13.166390581604265,
           13.075271754803175,
           12.9841529280021,
           12.89303410120101,
           12.80191527439992,
           12.710796447598844,
           12.619677620797752,
           12.528558793996663,
           12.437439967195589,
           12.346321140394497,
           12.255202313593404,
           12.164083486792315,
           12.072964659991241,
           11.981845833190151,
           11.89072700638906,
           11.799608179587985,
           11.708489352786893,
           11.617370525985802,
           11.526251699184728,
           11.435132872383637,
           11.344014045582547,
           11.252895218781472,
           11.16177639198038,
           11.07065756517929,
           10.9795387383782,
           10.888419911577126,
           10.797301084776034,
           10.706182257974943,
           10.615063431173867,
           10.523944604372776,
           10.432825777571686,
           10.341706950770611,
           10.250588123969521,
           10.159469297168428,
           10.068350470367339,
           9.977231643566265,
           9.886112816765174,
           9.794993989964082,
           9.671762672673838,
           9.539420453477991,
           9.407078234282144,
           9.274736015086322,
           9.142393795890476,
           9.010051576694629,
           8.877709357498807,
           8.74536713830296,
           8.613024919107115,
           8.480682699911267,
           8.348340480715446,
           8.2159982615196,
           8.083656042323753,
           7.951313823127931,
           7.818971603932084,
           7.6866293847362375,
           7.554287165540417,
           7.421944946344571,
           7.289602727148724,
           7.157260507952877,
           7.024918288757055
          ],
          [
           8.848022944474543,
           8.860360784920658,
           8.872698625366773,
           8.885036465812892,
           8.897374306259007,
           8.909712146705125,
           8.92204998715124,
           8.934387827597355,
           8.946725668043474,
           8.959063508489589,
           8.971401348935705,
           8.983739189381822,
           8.996077029827937,
           9.008414870274056,
           9.02075271072017,
           9.033090551166287,
           9.045428391612404,
           9.05776623205852,
           9.070104072504638,
           9.082441912950753,
           9.09477975339687,
           9.107117593842986,
           9.119455434289101,
           9.13179327473522,
           9.144131115181334,
           9.156468955627451,
           9.168806796073568,
           9.181144636519683,
           9.1934824769658,
           9.205820317411916,
           9.218158157858033,
           9.23049599830415,
           9.242833838750265,
           9.255171679196382,
           9.265875103402921,
           9.274944119108472,
           9.284013134814023,
           9.293082150519574,
           9.302151166225125,
           9.311220181930675,
           9.320289197636225,
           9.329358213341777,
           9.338427229047328,
           9.347496244752879,
           9.35656526045843,
           9.36563427616398,
           9.374703291869531,
           9.383772307575082,
           9.392841323280631,
           9.401910338986184,
           9.410979354691735,
           9.420048370397286,
           9.429117386102837,
           9.438186401808386,
           9.447255417513938,
           9.45632443321949,
           9.465393448925042,
           9.47446246463059,
           9.48353148033614,
           9.492600496041693,
           9.501669511747242,
           9.510738527452794,
           9.519807543158345,
           9.528876558863896,
           9.537945574569447,
           9.547014590274998,
           9.556083605980549,
           9.565152621686101,
           9.57422163739165,
           9.583290653097201,
           9.592359668802752,
           9.601428684508303,
           9.610497700213854,
           9.619566715919404,
           9.628635731624955,
           9.637704747330506,
           9.646773763036057,
           9.655842778741608,
           9.664911794447159,
           9.67398081015271,
           9.683049825858262,
           9.692118841563813,
           9.701187857269362,
           9.710256872974915,
           9.721832077055677,
           9.733908518811482,
           9.745984960567288,
           9.758061402323094,
           9.7701378440789,
           9.782214285834703,
           9.794290727590509,
           9.806367169346315,
           9.818443611102118,
           9.830520052857924,
           9.84259649461373,
           9.854672936369536,
           9.866749378125341,
           9.878825819881147,
           9.890902261636953,
           9.902978703392758,
           9.915055145148564,
           9.92713158690437,
           9.939208028660175,
           9.95128447041598,
           9.963360912171783,
           9.975437353927589,
           9.987513795683395,
           9.9995902374392,
           10.011666679195006,
           10.023743120950812,
           10.035819562706617,
           10.047896004462423,
           10.059972446218229,
           10.072048887974034,
           10.08412532972984,
           10.096201771485644,
           10.108278213241448,
           10.119376229532946,
           10.128517405319222,
           10.137658581105498,
           10.146799756891774,
           10.155940932678046,
           10.16508210846432,
           10.174223284250596,
           10.18336446003687,
           10.192505635823146,
           10.201646811609422,
           10.210787987395694,
           10.21992916318197,
           10.229070338968246,
           10.238211514754518,
           10.247352690540794,
           10.25649386632707,
           10.265635042113342,
           10.274776217899618,
           10.283917393685892,
           10.293058569472167,
           10.302199745258442,
           10.311340921044717,
           10.320482096830991,
           10.329623272617265,
           10.33876444840354,
           10.347905624189815,
           10.35704679997609,
           10.366187975762365,
           10.37532915154864,
           10.384470327334913,
           10.393611503121189,
           10.402752678907463,
           10.411893854693737,
           10.421035030480013,
           10.430176206266287,
           10.439317382052561,
           10.448458557838835,
           10.457599733625113,
           10.466740909411385,
           10.47588208519766,
           10.485023260983935,
           10.494164436770209,
           10.503305612556485,
           10.512446788342759,
           10.521587964129035,
           10.530729139915309,
           10.539870315701585,
           10.549011491487859,
           10.558152667274133,
           10.567293843060407,
           10.578052411038586,
           10.589619675112717,
           10.601186939186848,
           10.612754203260975,
           10.624321467335108,
           10.635888731409239,
           10.64745599548337,
           10.659023259557499,
           10.67059052363163,
           10.68215778770576,
           10.693725051779891,
           10.70529231585402,
           10.71685957992815,
           10.728426844002282,
           10.739994108076413,
           10.751561372150542,
           10.763128636224673,
           10.774695900298802,
           10.786263164372933,
           10.797830428447064,
           10.809397692521193,
           10.820964956595324,
           10.832532220669455,
           10.844099484743586,
           10.855666748817715,
           10.867234012891846,
           10.878801276965977,
           10.890368541040107,
           10.901935805114238,
           10.913503069188366,
           10.925070333262498,
           10.936637597336627,
           10.948204861410757,
           10.959772125484887,
           10.97133938955902,
           10.98290665363315,
           10.99447391770728,
           11.00604118178141,
           11.01760844585554,
           11.029175709929671,
           11.040742974003802,
           11.052310238077931,
           11.063877502152062,
           11.075444766226191,
           11.087012030300324,
           11.098579294374453,
           11.110146558448584,
           11.121713822522715,
           11.133281086596844,
           11.144848350670976,
           11.156415614745105,
           11.167982878819235,
           11.179550142893365,
           11.191117406967496,
           11.202684671041627,
           11.214251935115756,
           11.225819199189887,
           11.237386463264016,
           11.24895372733815,
           11.260520991412278,
           11.272088255486409,
           11.28365551956054,
           11.29764376824254,
           11.311845632695828,
           11.32604749714912,
           11.340249361602408,
           11.354451226055696,
           11.368653090508987,
           11.382854954962276,
           11.397056819415564,
           11.411258683868853,
           11.425460548322143,
           11.439662412775432,
           11.453864277228723,
           11.468066141682009,
           11.482268006135298,
           11.496469870588589,
           11.510671735041878,
           11.524873599495166,
           11.539075463948453,
           11.553277328401744,
           11.567479192855032,
           11.581681057308323,
           11.598044140168877,
           11.616568441436701,
           11.635092742704522,
           11.653617043972345,
           11.67214134524017,
           11.690665646507991,
           11.709189947775814,
           11.727714249043638,
           11.74623855031146,
           11.764762851579281,
           11.783287152847105,
           11.801811454114928,
           11.820335755382752,
           11.838860056650574,
           11.857384357918395,
           11.87590865918622,
           11.89443296045404,
           11.912957261721864,
           11.931481562989687,
           11.950005864257509,
           11.968530165525332,
           11.987054466793158,
           12.005578768060976,
           12.0241030693288,
           12.042627370596623,
           12.061151671864446,
           12.07967597313227,
           12.096714596833799,
           12.112508963547734,
           12.128303330261666,
           12.144097696975603,
           12.159892063689536,
           12.175686430403468,
           12.191480797117404,
           12.207275163831337,
           12.223069530545272,
           12.238863897259206,
           12.254658263973141,
           12.270452630687075,
           12.286246997401006,
           12.302041364114944,
           12.317835730828875,
           12.333630097542812,
           12.349424464256746,
           12.36521883097068,
           12.381013197684613,
           12.396807564398546,
           12.412601931112482,
           12.428396297826415,
           12.444190664540349,
           12.459985031254284,
           12.47577939796822,
           12.491573764682153,
           12.507368131396088,
           12.523162498110022,
           12.538956864823954,
           12.554751231537889,
           12.570545598251824,
           12.58633996496576,
           12.602134331679691,
           12.617928698393627,
           12.633723065107558,
           12.649517431821494,
           12.665311798535429,
           12.68110616524936,
           12.696900531963296,
           12.712694898677231,
           12.728489265391165,
           12.744283632105098,
           12.760077998819034,
           12.775872365532967,
           12.791666732246902,
           12.807461098960836,
           12.823255465674771,
           12.839049832388705,
           12.854844199102638,
           12.870638565816572,
           12.886432932530505,
           12.902227299244439,
           12.918021665958374,
           12.93381603267231,
           12.949610399386243,
           12.965404766100177,
           12.984185323610182,
           13.008938262712324,
           13.033691201814467,
           13.05844414091661,
           13.083197080018753,
           13.107950019120894,
           13.132702958223042,
           13.157455897325185,
           13.182208836427325,
           13.20696177552947,
           13.231714714631615,
           13.256467653733756,
           13.281220592835899,
           13.305973531938044,
           13.330726471040187,
           13.355479410142326,
           13.380232349244473,
           13.404985288346616,
           13.429738227448755,
           13.454491166550902,
           13.479244105653047,
           13.503997044755188,
           13.528749983857331,
           13.553502922959476,
           13.578255862061617,
           13.603008801163758,
           13.627761740265903,
           13.652514679368046,
           13.67726761847019,
           13.702020557572334,
           13.726773496674479,
           13.751526435776617,
           13.776279374878762,
           13.801032313980905,
           13.825785253083048,
           13.85053819218519,
           13.875291131287337,
           13.900044070389479,
           13.92479700949162,
           13.949549948593766,
           13.974302887695906,
           13.999055826798049,
           14.023808765900194,
           14.048561705002337,
           14.07331464410448,
           14.098067583206621,
           14.12282052230877,
           14.14757346141091,
           14.172326400513054,
           14.197079339615197,
           14.22183227871734,
           14.246585217819481,
           14.271338156921626,
           14.29609109602377,
           14.320844035125909,
           14.345596974228055,
           14.370349913330202,
           14.395102852432341,
           14.419855791534484,
           14.444608730636629,
           14.46936166973877,
           14.494114608840913,
           14.518867547943056,
           14.5436204870452,
           14.568373426147343,
           14.593126365249486,
           14.617879304351632,
           14.642632243453772,
           14.668174769006587,
           14.694235353308095,
           14.720295937609599,
           14.746356521911103,
           14.772417106212608,
           14.798477690514112,
           14.824538274815618,
           14.850598859117124,
           14.876659443418628,
           14.90272002772013,
           14.928780612021637,
           14.954841196323144,
           14.980901780624649,
           15.006962364926151,
           15.033022949227657,
           15.044842992584535,
           14.985460331218302,
           14.92607766985207,
           14.866695008485836,
           14.807312347119613,
           14.747929685753382,
           14.688547024387145,
           14.629164363020925,
           14.56978170165469,
           14.510399040288458,
           14.451016378922237,
           14.391633717556003,
           14.319688770037391,
           14.2285699432363,
           14.137451116435226,
           14.046332289634133,
           13.955213462833044,
           13.86409463603197,
           13.772975809230878,
           13.681856982429787,
           13.590738155628713,
           13.499619328827622,
           13.40850050202653,
           13.317381675225455,
           13.226262848424366,
           13.135144021623274,
           13.044025194822185,
           12.95290636802111,
           12.861787541220018,
           12.770668714418928,
           12.679549887617853,
           12.588431060816761,
           12.497312234015672,
           12.406193407214596,
           12.315074580413505,
           12.223955753612413,
           12.132836926811324,
           12.041718100010248,
           11.950599273209159,
           11.859480446408067,
           11.768361619606992,
           11.6772427928059,
           11.586123966004811,
           11.495005139203737,
           11.403886312402644,
           11.312767485601555,
           11.221648658800481,
           11.13052983199939,
           11.039411005198298,
           10.948292178397207,
           10.857173351596131,
           10.766054524795042,
           10.67493569799395,
           10.583816871192877,
           10.492698044391785,
           10.401579217590694,
           10.31046039078962,
           10.219341563988529,
           10.12822273718744,
           10.037103910386346,
           9.945985083585274,
           9.854866256784181,
           9.763747429983091,
           9.672628603182016,
           9.581509776380926,
           9.490390949579833,
           9.399272122778761,
           9.308153295977668,
           9.217034469176578,
           9.125915642375503,
           9.034796815574413,
           8.94367798877332,
           8.807898483651439,
           8.658841351674443,
           8.50978421969742,
           8.360727087720397,
           8.2116699557434,
           8.062612823766376,
           7.9135556917893535,
           7.764498559812358,
           7.615441427835334,
           7.466384295858311,
           7.317327163881289,
           7.168270031904292
          ],
          [
           9.320512605250457,
           9.332850445696574,
           9.345188286142688,
           9.357526126588805,
           9.369863967034924,
           9.382201807481039,
           9.394539647927155,
           9.406877488373272,
           9.419215328819389,
           9.431553169265504,
           9.44389100971162,
           9.456228850157737,
           9.468566690603852,
           9.480904531049969,
           9.493242371496088,
           9.505580211942203,
           9.51791805238832,
           9.530255892834436,
           9.542593733280553,
           9.554931573726668,
           9.567269414172785,
           9.579607254618901,
           9.591945095065016,
           9.604282935511133,
           9.616620775957248,
           9.628958616403366,
           9.641296456849483,
           9.653634297295598,
           9.665972137741715,
           9.678309978187832,
           9.690647818633948,
           9.702985659080065,
           9.71532349952618,
           9.727661339972297,
           9.739999180418414,
           9.75233702086453,
           9.764674861310645,
           9.77701270175676,
           9.789350542202879,
           9.801688382648994,
           9.81402622309511,
           9.826364063541227,
           9.838701903987344,
           9.85103974443346,
           9.863377584879576,
           9.875715425325692,
           9.88805326577181,
           9.900391106217926,
           9.912728946664041,
           9.925066787110158,
           9.937404624226337,
           9.946473639931888,
           9.955542655637439,
           9.96461167134299,
           9.97368068704854,
           9.982749702754091,
           9.991818718459642,
           10.000887734165193,
           10.009956749870744,
           10.019025765576295,
           10.028094781281846,
           10.037163796987397,
           10.04623281269295,
           10.055301828398498,
           10.06437084410405,
           10.0734398598096,
           10.082508875515149,
           10.091577891220702,
           10.100646906926253,
           10.109715922631803,
           10.118784938337354,
           10.127853954042905,
           10.136922969748456,
           10.145991985454009,
           10.15506100115956,
           10.164130016865109,
           10.17319903257066,
           10.18226804827621,
           10.191337063981761,
           10.200406079687312,
           10.209475095392863,
           10.218544111098415,
           10.227613126803965,
           10.236682142509517,
           10.248257346590279,
           10.260333788346085,
           10.27241023010189,
           10.284486671857694,
           10.296563113613502,
           10.308639555369306,
           10.320715997125111,
           10.332792438880917,
           10.34486888063672,
           10.356945322392527,
           10.369021764148332,
           10.381098205904138,
           10.393174647659944,
           10.40525108941575,
           10.417327531171555,
           10.42940397292736,
           10.441480414683166,
           10.453556856438972,
           10.465633298194776,
           10.477709739950582,
           10.489786181706387,
           10.501862623462193,
           10.513939065217999,
           10.526015506973803,
           10.538091948729608,
           10.550168390485414,
           10.56224483224122,
           10.574321273997024,
           10.58639771575283,
           10.598474157508635,
           10.61055059926444,
           10.622627041020246,
           10.63470348277605,
           10.646779924531856,
           10.658856366287662,
           10.670932808043467,
           10.683009249799273,
           10.695085691555079,
           10.707162133310883,
           10.71923857506669,
           10.731315016822494,
           10.7433914585783,
           10.755467900334105,
           10.76754434208991,
           10.779620783845715,
           10.79169722560152,
           10.803773667357326,
           10.815850109113132,
           10.827926550868938,
           10.840002992624743,
           10.849633376415795,
           10.858774552202071,
           10.867915727988345,
           10.87705690377462,
           10.886198079560895,
           10.89533925534717,
           10.904480431133443,
           10.913621606919719,
           10.922762782705993,
           10.931903958492267,
           10.941045134278543,
           10.950186310064819,
           10.959327485851091,
           10.968468661637367,
           10.97760983742364,
           10.986751013209915,
           10.99589218899619,
           11.005033364782465,
           11.01417454056874,
           11.023315716355015,
           11.03245689214129,
           11.041598067927564,
           11.050739243713839,
           11.059880419500113,
           11.069021595286388,
           11.078162771072662,
           11.087303946858938,
           11.096445122645212,
           11.105586298431486,
           11.114727474217762,
           11.123868650004036,
           11.133009825790312,
           11.142151001576584,
           11.152909569554765,
           11.164476833628894,
           11.176044097703025,
           11.187611361777154,
           11.199178625851285,
           11.210745889925416,
           11.222313153999545,
           11.233880418073678,
           11.245447682147807,
           11.257014946221938,
           11.268582210296069,
           11.280149474370198,
           11.291716738444329,
           11.30328400251846,
           11.31485126659259,
           11.32641853066672,
           11.33798579474085,
           11.349553058814982,
           11.361120322889112,
           11.372687586963242,
           11.384254851037372,
           11.395822115111503,
           11.407389379185632,
           11.418956643259763,
           11.430523907333892,
           11.442091171408023,
           11.453658435482154,
           11.465225699556285,
           11.476792963630416,
           11.488360227704545,
           11.499927491778676,
           11.511494755852807,
           11.523062019926936,
           11.534629284001067,
           11.546196548075198,
           11.557763812149329,
           11.569331076223458,
           11.580898340297587,
           11.592465604371718,
           11.604032868445849,
           11.61560013251998,
           11.62830668281461,
           11.6425085472679,
           11.656710411721189,
           11.67091227617448,
           11.685114140627766,
           11.699316005081055,
           11.713517869534346,
           11.727719733987634,
           11.741921598440925,
           11.75612346289421,
           11.7703253273475,
           11.784527191800791,
           11.798729056254079,
           11.81293092070737,
           11.827132785160659,
           11.841334649613946,
           11.855536514067236,
           11.869738378520525,
           11.883940242973816,
           11.898142107427105,
           11.912343971880393,
           11.926545836333682,
           11.94074770078697,
           11.954949565240259,
           11.969151429693548,
           11.983353294146838,
           11.997555158600129,
           12.011757023053416,
           12.025958887506704,
           12.040160751959995,
           12.054362616413282,
           12.068564480866574,
           12.082766345319861,
           12.09696820977315,
           12.11117007422644,
           12.125371938679729,
           12.139573803133018,
           12.153775667586306,
           12.167977532039597,
           12.182179396492884,
           12.196381260946175,
           12.210583125399463,
           12.226946208260019,
           12.245470509527841,
           12.263994810795666,
           12.282519112063486,
           12.30104341333131,
           12.319567714599133,
           12.338092015866955,
           12.35661631713478,
           12.375140618402602,
           12.393664919670424,
           12.412189220938245,
           12.43071352220607,
           12.449237823473894,
           12.467762124741714,
           12.486286426009539,
           12.50481072727736,
           12.523335028545183,
           12.541859329813008,
           12.560383631080828,
           12.578907932348649,
           12.597432233616473,
           12.615956534884297,
           12.63448083615212,
           12.653005137419942,
           12.671529438687765,
           12.690053739955587,
           12.708578041223412,
           12.727102342491232,
           12.745626643759055,
           12.764150945026877,
           12.782675246294701,
           12.801199547562524,
           12.819723848830346,
           12.838248150098169,
           12.856772451365993,
           12.875296752633815,
           12.893821053901636,
           12.91234535516946,
           12.930869656437281,
           12.949393957705105,
           12.967918258972928,
           12.98644256024075,
           13.00496686150857,
           13.023491162776395,
           13.042015464044221,
           13.06053976531204,
           13.079064066579864,
           13.097588367847687,
           13.116112669115509,
           13.13463697038333,
           13.153161271651157,
           13.171685572918978,
           13.190209874186799,
           13.206747080618467,
           13.2225414473324,
           13.238335814046334,
           13.254130180760267,
           13.269924547474202,
           13.285718914188134,
           13.301513280902071,
           13.317307647616005,
           13.333102014329938,
           13.348896381043872,
           13.364690747757807,
           13.380485114471739,
           13.396279481185672,
           13.412073847899608,
           13.427868214613543,
           13.443662581327475,
           13.459456948041414,
           13.475251314755345,
           13.49104568146928,
           13.506840048183214,
           13.522634414897148,
           13.538428781611083,
           13.554223148325015,
           13.57001751503895,
           13.585811881752885,
           13.601606248466819,
           13.617400615180753,
           13.633194981894688,
           13.64898934860862,
           13.664783715322555,
           13.68356427283256,
           13.708317211934702,
           13.733070151036845,
           13.757823090138992,
           13.782576029241133,
           13.807328968343274,
           13.832081907445417,
           13.856834846547564,
           13.881587785649703,
           13.906340724751846,
           13.931093663853993,
           13.955846602956136,
           13.980599542058279,
           14.005352481160422,
           14.030105420262563,
           14.054858359364706,
           14.079611298466851,
           14.104364237568992,
           14.129117176671135,
           14.15387011577328,
           14.178623054875425,
           14.203375993977566,
           14.22812893307971,
           14.252881872181852,
           14.277634811283995,
           14.302387750386137,
           14.327140689488283,
           14.351893628590425,
           14.376646567692568,
           14.401399506794712,
           14.426152445896856,
           14.450905384998997,
           14.47565832410114,
           14.500411263203286,
           14.525164202305426,
           14.549917141407569,
           14.574670080509714,
           14.600351946372006,
           14.626412530673509,
           14.652473114975017,
           14.678533699276521,
           14.704594283578022,
           14.73065486787953,
           14.756715452181034,
           14.78277603648254,
           14.808836620784044,
           14.834897205085547,
           14.860957789387054,
           14.887018373688559,
           14.913078957990063,
           14.939139542291567,
           14.965200126593071,
           14.99126071089458,
           15.017321295196085,
           15.043381879497586,
           15.069442463799092,
           15.095503048100596,
           15.121563632402102,
           15.147624216703607,
           15.173684801005113,
           15.199745385306617,
           15.225805969608121,
           15.251866553909625,
           15.277927138211131,
           15.303987722512634,
           15.330048306814138,
           15.356108891115646,
           15.382169475417149,
           15.408230059718653,
           15.434290644020159,
           15.460351228321667,
           15.486411812623167,
           15.512472396924675,
           15.53853298122618,
           15.56459356552768,
           15.59065414982919,
           15.616714734130694,
           15.642775318432195,
           15.668835902733703,
           15.694896487035207,
           15.720957071336711,
           15.747017655638219,
           15.773078239939721,
           15.7848982832966,
           15.725515621930368,
           15.666132960564134,
           15.606750299197904,
           15.547367637831679,
           15.487984976465448,
           15.428602315099212,
           15.36921965373299,
           15.309836992366755,
           15.250454331000523,
           15.191071669634301,
           15.131689008268065,
           15.072306346901833,
           15.0129236855356,
           14.953541024169377,
           14.894158362803143,
           14.83477570143691,
           14.77539304007069,
           14.716010378704457,
           14.656627717338221,
           14.597245055972,
           14.537862394605767,
           14.478479733239533,
           14.41909707187331,
           14.359714410507076,
           14.300331749140845,
           14.24094908777461,
           14.181566426408388,
           14.122183765042156,
           14.06280110367592,
           14.003418442309698,
           13.944035780943466,
           13.884653119577232,
           13.82527045821101,
           13.765887796844778,
           13.706505135478542,
           13.625634398958807,
           13.534515572157732,
           13.443396745356642,
           13.35227791855555,
           13.261159091754477,
           13.170040264953386,
           13.078921438152294,
           12.987802611351219,
           12.89668378455013,
           12.805564957749038,
           12.714446130947962,
           12.623327304146873,
           12.503842933613468,
           12.354785801636444,
           12.20572866965945,
           12.056671537682426,
           11.907614405705402,
           11.758557273728407,
           11.609500141751381,
           11.460443009774359,
           11.311385877797365,
           11.162328745820341,
           11.013271613843319,
           10.864214481866295,
           10.7151573498893,
           10.566100217912275,
           10.417043085935251,
           10.267985953958256,
           10.118928821981232,
           9.969871690004208,
           9.820814558027212,
           9.67175742605019,
           9.522700294073166,
           9.373643162096172,
           9.224586030119148,
           9.075528898142124,
           8.9264717661651,
           8.777414634188105,
           8.628357502211083,
           8.479300370234059,
           8.330243238257063,
           8.18118610628004,
           8.032128974303017,
           7.88307184232602,
           7.734014710348996,
           7.584957578371974,
           7.43590044639495,
           7.286843314417954
          ],
          [
           9.793002266026365,
           9.805340106472482,
           9.817677946918597,
           9.830015787364712,
           9.842353627810828,
           9.854691468256947,
           9.867029308703062,
           9.879367149149179,
           9.891704989595295,
           9.904042830041412,
           9.916380670487527,
           9.928718510933644,
           9.94105635137976,
           9.953394191825877,
           9.965732032271994,
           9.978069872718109,
           9.990407713164226,
           10.002745553610342,
           10.01508339405646,
           10.027421234502576,
           10.039759074948691,
           10.052096915394808,
           10.064434755840924,
           10.07677259628704,
           10.089110436733158,
           10.101448277179273,
           10.11378611762539,
           10.126123958071506,
           10.138461798517621,
           10.150799638963738,
           10.163137479409855,
           10.17547531985597,
           10.187813160302088,
           10.200151000748203,
           10.212488841194318,
           10.224826681640437,
           10.237164522086552,
           10.249502362532668,
           10.261840202978785,
           10.2741780434249,
           10.286515883871017,
           10.298853724317134,
           10.31119156476325,
           10.323529405209367,
           10.335867245655482,
           10.3482050861016,
           10.360542926547716,
           10.372880766993832,
           10.385218607439949,
           10.397556447886064,
           10.409894288332183,
           10.422232128778298,
           10.434569969224414,
           10.446907809670531,
           10.459245650116648,
           10.471583490562763,
           10.48392133100888,
           10.496259171454996,
           10.508597011901111,
           10.520934852347228,
           10.533272692793345,
           10.545610533239461,
           10.557948373685578,
           10.570286214131693,
           10.58262405457781,
           10.594961895023927,
           10.607299735470043,
           10.618003160755293,
           10.627072176460844,
           10.636141192166395,
           10.645210207871946,
           10.654279223577497,
           10.663348239283048,
           10.6724172549886,
           10.681486270694151,
           10.6905552863997,
           10.699624302105251,
           10.708693317810802,
           10.717762333516353,
           10.726831349221904,
           10.735900364927454,
           10.744969380633007,
           10.754038396338558,
           10.763107412044109,
           10.774682616124872,
           10.786759057880676,
           10.798835499636482,
           10.810911941392288,
           10.822988383148093,
           10.835064824903899,
           10.847141266659705,
           10.859217708415509,
           10.871294150171314,
           10.88337059192712,
           10.895447033682926,
           10.90752347543873,
           10.919599917194535,
           10.931676358950341,
           10.943752800706147,
           10.955829242461952,
           10.967905684217758,
           10.979982125973564,
           10.99205856772937,
           11.004135009485173,
           11.016211451240979,
           11.028287892996785,
           11.04036433475259,
           11.052440776508394,
           11.064517218264202,
           11.076593660020006,
           11.088670101775811,
           11.100746543531617,
           11.112822985287421,
           11.124899427043228,
           11.136975868799032,
           11.149052310554838,
           11.161128752310642,
           11.173205194066448,
           11.185281635822255,
           11.197358077578059,
           11.209434519333866,
           11.22151096108967,
           11.233587402845476,
           11.245663844601282,
           11.257740286357087,
           11.269816728112891,
           11.281893169868697,
           11.293969611624503,
           11.306046053380308,
           11.318122495136114,
           11.330198936891918,
           11.342275378647726,
           11.35435182040353,
           11.366428262159335,
           11.37850470391514,
           11.390581145670946,
           11.40265758742675,
           11.414734029182556,
           11.426810470938362,
           11.438886912694167,
           11.450963354449973,
           11.463039796205779,
           11.475116237961583,
           11.487192679717388,
           11.499269121473196,
           11.511345563228998,
           11.523422004984806,
           11.535498446740611,
           11.547574888496415,
           11.55965133025222,
           11.570749347512358,
           11.579890523298632,
           11.589031699084908,
           11.598172874871182,
           11.607314050657457,
           11.616455226443732,
           11.625596402230006,
           11.634737578016281,
           11.643878753802555,
           11.653019929588831,
           11.662161105375105,
           11.67130228116138,
           11.680443456947653,
           11.68958463273393,
           11.698725808520203,
           11.707866984306479,
           11.717008160092751,
           11.727766728070932,
           11.739333992145061,
           11.750901256219192,
           11.762468520293321,
           11.774035784367452,
           11.785603048441583,
           11.797170312515714,
           11.808737576589843,
           11.820304840663976,
           11.831872104738105,
           11.843439368812236,
           11.855006632886365,
           11.866573896960496,
           11.878141161034627,
           11.889708425108756,
           11.901275689182887,
           11.912842953257018,
           11.924410217331147,
           11.93597748140528,
           11.947544745479409,
           11.95911200955354,
           11.973171461839957,
           11.987373326293246,
           12.001575190746536,
           12.015777055199825,
           12.029978919653114,
           12.044180784106404,
           12.058382648559691,
           12.072584513012982,
           12.086786377466272,
           12.100988241919561,
           12.11519010637285,
           12.129391970826138,
           12.143593835279427,
           12.157795699732716,
           12.171997564186004,
           12.186199428639295,
           12.200401293092582,
           12.21460315754587,
           12.228805021999161,
           12.243006886452449,
           12.257208750905738,
           12.271410615359027,
           12.285612479812318,
           12.29981434426561,
           12.314016208718897,
           12.328218073172184,
           12.342419937625476,
           12.356621802078761,
           12.370823666532054,
           12.385025530985342,
           12.39922739543863,
           12.41342925989192,
           12.427631124345208,
           12.441832988798499,
           12.456034853251786,
           12.470236717705074,
           12.484438582158365,
           12.498640446611653,
           12.512842311064944,
           12.527044175518233,
           12.54124603997152,
           12.555447904424812,
           12.569649768878099,
           12.583851633331388,
           12.598053497784678,
           12.612255362237967,
           12.626457226691254,
           12.640659091144546,
           12.654860955597833,
           12.669062820051124,
           12.683264684504412,
           12.697466548957701,
           12.71166841341099,
           12.72587027786428,
           12.740072142317569,
           12.754274006770856,
           12.768475871224148,
           12.782677735677435,
           12.796879600130724,
           12.811081464584014,
           12.825283329037305,
           12.839485193490592,
           12.855848276351148,
           12.87437257761897,
           12.892896878886793,
           12.911421180154615,
           12.92994548142244,
           12.94846978269026,
           12.966994083958083,
           12.985518385225907,
           13.004042686493731,
           13.022566987761552,
           13.041091289029374,
           13.0596155902972,
           13.078139891565023,
           13.096664192832844,
           13.115188494100668,
           13.133712795368488,
           13.152237096636311,
           13.170761397904135,
           13.189285699171958,
           13.207810000439778,
           13.2263343017076,
           13.244858602975427,
           13.263382904243247,
           13.281907205511068,
           13.300431506778896,
           13.318955808046717,
           13.337480109314537,
           13.356004410582361,
           13.374528711850184,
           13.393053013118006,
           13.411577314385829,
           13.430101615653655,
           13.448625916921472,
           13.4671502181893,
           13.48567451945712,
           13.504198820724945,
           13.522723121992765,
           13.54124742326059,
           13.559771724528412,
           13.578296025796234,
           13.596820327064057,
           13.61534462833188,
           13.6338689295997,
           13.652393230867524,
           13.670917532135348,
           13.68944183340317,
           13.707966134670993,
           13.726490435938816,
           13.745014737206636,
           13.76353903847446,
           13.782063339742287,
           13.800587641010106,
           13.819111942277928,
           13.837636243545752,
           13.856160544813577,
           13.874684846081397,
           13.893209147349218,
           13.911733448617042,
           13.930257749884865,
           13.94878205115269,
           13.967306352420511,
           13.985830653688332,
           14.004354954956154,
           14.022879256223979,
           14.041403557491803,
           14.059927858759623,
           14.078452160027448,
           14.096976461295272,
           14.115500762563093,
           14.134025063830915,
           14.15254936509874,
           14.17107366636656,
           14.189597967634382,
           14.208122268902207,
           14.226646570170027,
           14.245170871437852,
           14.263695172705676,
           14.282219473973496,
           14.300743775241319,
           14.316779564403117,
           14.332573931117052,
           14.348368297830985,
           14.364162664544919,
           14.382943222054925,
           14.407696161157068,
           14.432449100259209,
           14.457202039361354,
           14.481954978463497,
           14.50670791756564,
           14.532529123737405,
           14.558589708038914,
           14.584650292340415,
           14.610710876641921,
           14.636771460943427,
           14.662832045244931,
           14.688892629546435,
           14.714953213847942,
           14.741013798149446,
           14.76707438245095,
           14.793134966752456,
           14.819195551053959,
           14.845256135355463,
           14.87131671965697,
           14.897377303958477,
           14.92343788825998,
           14.949498472561483,
           14.975559056862991,
           15.001619641164492,
           15.027680225465998,
           15.053740809767504,
           15.079801394069008,
           15.105861978370513,
           15.131922562672019,
           15.157983146973525,
           15.184043731275025,
           15.210104315576531,
           15.236164899878037,
           15.262225484179543,
           15.288286068481046,
           15.31434665278255,
           15.340407237084056,
           15.36646782138556,
           15.392528405687063,
           15.41858898998857,
           15.444649574290075,
           15.47071015859158,
           15.496770742893087,
           15.52283132719459,
           15.548891911496094,
           15.5749524957976,
           15.601013080099104,
           15.627073664400607,
           15.653134248702115,
           15.679194833003617,
           15.705255417305121,
           15.73131600160663,
           15.757376585908133,
           15.783437170209634,
           15.809497754511142,
           15.835558338812648,
           15.861618923114152,
           15.887679507415655,
           15.913740091717163,
           15.939800676018665,
           15.965861260320171,
           15.991921844621677,
           16.01798242892318,
           16.044043013224684,
           16.07010359752619,
           16.096164181827696,
           16.122224766129197,
           16.148285350430704,
           16.174345934732212,
           16.200406519033717,
           16.226467103335217,
           16.252527687636725,
           16.27858827193823,
           16.304648856239734,
           16.330709440541238,
           16.356770024842746,
           16.382830609144246,
           16.408891193445754,
           16.43495177774726,
           16.461012362048763,
           16.487072946350267,
           16.513133530651775,
           16.524953574008652,
           16.46557091264242,
           16.406188251276184,
           16.346805589909952,
           16.28742292854373,
           16.228040267177498,
           16.168657605811262,
           16.10927494444504,
           16.049892283078808,
           15.990509621712572,
           15.93112696034635,
           15.871744298980115,
           15.812361637613884,
           15.75297897624765,
           15.652059852550158,
           15.539651787209444,
           15.427243721868729,
           15.314835656528036,
           15.202427591187321,
           15.090019525846607,
           14.977611460505914,
           14.8652033951652,
           14.752795329824487,
           14.640387264483792,
           14.527979199143077,
           14.415571133802363,
           14.30316306846165,
           14.190755003120957,
           14.078346937780244,
           13.965938872439528,
           13.853530807098835,
           13.74112274175812,
           13.628714676417408,
           13.516306611076715,
           13.403898545735998,
           13.291490480395284,
           13.17908241505457,
           13.066674349713878,
           12.954266284373166,
           12.84185821903245,
           12.729450153691756,
           12.617042088351043,
           12.504634023010329,
           12.392225957669634,
           12.279817892328921,
           12.167409826988207,
           12.055001761647514,
           11.942593696306798,
           11.830185630966085,
           11.717777565625372,
           11.605369500284677,
           11.492961434943963,
           11.380553369603248,
           11.268145304262555,
           11.15573723892184,
           11.043329173581128,
           10.930921108240433,
           10.81851304289972,
           10.706104977559006,
           10.593696912218292,
           10.481288846877598,
           10.368880781536884,
           10.256472716196171,
           10.144064650855476,
           10.031656585514764,
           9.919248520174047,
           9.806840454833354,
           9.69443238949264,
           9.582024324151927,
           9.469616258811232,
           9.343159312632807,
           9.194102180655783,
           9.04504504867876,
           8.895987916701765,
           8.746930784724743,
           8.597873652747719,
           8.448816520770722,
           8.2997593887937,
           8.150702256816675,
           8.00164512483968,
           7.852587992862657,
           7.703530860885633,
           7.55447372890861,
           7.405416596931614
          ],
          [
           10.26549192680228,
           10.277829767248397,
           10.290167607694512,
           10.302505448140629,
           10.314843288586745,
           10.327181129032862,
           10.339518969478977,
           10.351856809925094,
           10.36419465037121,
           10.376532490817327,
           10.388870331263442,
           10.401208171709559,
           10.413546012155676,
           10.425883852601793,
           10.43822169304791,
           10.450559533494024,
           10.462897373940143,
           10.475235214386258,
           10.487573054832374,
           10.499910895278491,
           10.512248735724606,
           10.524586576170723,
           10.53692441661684,
           10.549262257062956,
           10.561600097509071,
           10.573937937955188,
           10.586275778401305,
           10.598613618847422,
           10.610951459293538,
           10.623289299739655,
           10.63562714018577,
           10.647964980631889,
           10.660302821078004,
           10.672640661524118,
           10.684978501970235,
           10.697316342416352,
           10.709654182862469,
           10.721992023308584,
           10.734329863754702,
           10.746667704200815,
           10.759005544646934,
           10.77134338509305,
           10.783681225539167,
           10.796019065985282,
           10.8083569064314,
           10.820694746877516,
           10.83303258732363,
           10.845370427769748,
           10.857708268215864,
           10.87004610866198,
           10.882383949108098,
           10.894721789554213,
           10.907059630000331,
           10.919397470446446,
           10.931735310892563,
           10.94407315133868,
           10.956410991784795,
           10.968748832230911,
           10.981086672677028,
           10.993424513123145,
           11.005762353569262,
           11.018100194015377,
           11.030438034461493,
           11.04277587490761,
           11.055113715353725,
           11.067451555799844,
           11.079789396245959,
           11.092127236692075,
           11.10446507713819,
           11.116802917584307,
           11.129140758030424,
           11.14147859847654,
           11.153816438922657,
           11.166154279368774,
           11.178492119814889,
           11.190829960261006,
           11.203167800707122,
           11.21550564115324,
           11.227843481599354,
           11.240181322045471,
           11.252519162491588,
           11.264857002937704,
           11.277194843383821,
           11.289532681578711,
           11.301107885659475,
           11.313184327415279,
           11.325260769171084,
           11.33733721092689,
           11.349413652682696,
           11.3614900944385,
           11.373566536194307,
           11.385642977950111,
           11.397719419705917,
           11.409795861461722,
           11.421872303217528,
           11.433948744973334,
           11.44602518672914,
           11.458101628484943,
           11.47017807024075,
           11.482254511996555,
           11.49433095375236,
           11.506407395508164,
           11.518483837263972,
           11.530560279019776,
           11.542636720775581,
           11.554713162531387,
           11.566789604287193,
           11.578866046042997,
           11.590942487798804,
           11.603018929554608,
           11.615095371310414,
           11.627171813066218,
           11.639248254822023,
           11.651324696577829,
           11.663401138333635,
           11.67547758008944,
           11.687554021845246,
           11.699630463601052,
           11.711706905356857,
           11.723783347112661,
           11.735859788868469,
           11.747936230624273,
           11.760012672380077,
           11.772089114135884,
           11.784165555891688,
           11.796241997647494,
           11.8083184394033,
           11.820394881159105,
           11.83247132291491,
           11.844547764670716,
           11.85662420642652,
           11.868700648182328,
           11.880777089938132,
           11.892853531693937,
           11.904929973449743,
           11.917006415205547,
           11.929082856961353,
           11.941159298717158,
           11.953235740472964,
           11.96531218222877,
           11.977388623984575,
           11.989465065740381,
           12.001541507496185,
           12.01361794925199,
           12.025694391007798,
           12.0377708327636,
           12.049847274519406,
           12.061923716275214,
           12.074000158031017,
           12.086076599786823,
           12.098153041542629,
           12.110229483298435,
           12.12230592505424,
           12.134382366810044,
           12.14645880856585,
           12.158535250321655,
           12.170611692077461,
           12.182688133833265,
           12.19476457558907,
           12.206841017344876,
           12.218917459100682,
           12.230993900856488,
           12.243070342612294,
           12.255146784368097,
           12.267223226123903,
           12.27929966787971,
           12.291376109635515,
           12.303834376412029,
           12.318036240865318,
           12.332238105318607,
           12.346439969771897,
           12.360641834225184,
           12.374843698678474,
           12.389045563131761,
           12.403247427585052,
           12.417449292038341,
           12.431651156491629,
           12.44585302094492,
           12.460054885398208,
           12.474256749851497,
           12.488458614304786,
           12.502660478758076,
           12.516862343211363,
           12.531064207664654,
           12.545266072117943,
           12.559467936571231,
           12.573669801024522,
           12.58787166547781,
           12.602073529931099,
           12.616275394384388,
           12.630477258837677,
           12.644679123290965,
           12.658880987744256,
           12.673082852197544,
           12.687284716650833,
           12.701486581104124,
           12.715688445557412,
           12.7298903100107,
           12.74409217446399,
           12.758294038917278,
           12.772495903370569,
           12.786697767823858,
           12.800899632277146,
           12.815101496730435,
           12.829303361183724,
           12.843505225637013,
           12.857707090090301,
           12.871908954543592,
           12.88611081899688,
           12.90031268345017,
           12.914514547903458,
           12.92871641235675,
           12.942918276810035,
           12.957120141263324,
           12.971322005716615,
           12.985523870169903,
           12.999725734623194,
           13.013927599076482,
           13.028129463529769,
           13.04233132798306,
           13.056533192436348,
           13.070735056889639,
           13.084936921342928,
           13.099138785796216,
           13.113340650249507,
           13.127542514702794,
           13.141744379156085,
           13.155946243609375,
           13.170148108062662,
           13.184349972515951,
           13.19855183696924,
           13.21275370142253,
           13.22695556587582,
           13.241157430329109,
           13.255359294782396,
           13.269561159235687,
           13.283763023688975,
           13.297964888142264,
           13.312166752595552,
           13.326368617048843,
           13.340570481502132,
           13.35477234595542,
           13.368974210408709,
           13.383176074862,
           13.39737793931529,
           13.411579803768575,
           13.425781668221864,
           13.439983532675155,
           13.454185397128445,
           13.468387261581734,
           13.484750344442288,
           13.503274645710112,
           13.521798946977935,
           13.540323248245757,
           13.55884754951358,
           13.577371850781404,
           13.595896152049225,
           13.614420453317049,
           13.632944754584871,
           13.651469055852692,
           13.669993357120516,
           13.68851765838834,
           13.707041959656161,
           13.725566260923983,
           13.744090562191808,
           13.762614863459628,
           13.781139164727453,
           13.799663465995277,
           13.818501955546195,
           13.837864097938162,
           13.857226240330133,
           13.876588382722103,
           13.895950525114067,
           13.915312667506038,
           13.93467480989801,
           13.954036952289977,
           13.973399094681945,
           13.992761237073914,
           14.012123379465883,
           14.031485521857851,
           14.05084766424982,
           14.070209806641792,
           14.08957194903376,
           14.108934091425727,
           14.128296233817697,
           14.147658376209666,
           14.167020518601635,
           14.186382660993605,
           14.205744803385574,
           14.225106945777538,
           14.244469088169511,
           14.263831230561475,
           14.283193372953445,
           14.302555515345414,
           14.321917657737387,
           14.341279800129353,
           14.360641942521323,
           14.380004084913292,
           14.399366227305261,
           14.418728369697229,
           14.4380905120892,
           14.457452654481166,
           14.476814796873136,
           14.496176939265105,
           14.515539081657074,
           14.53490122404904,
           14.554263366441011,
           14.573625508832983,
           14.59298765122495,
           14.612349793616918,
           14.63171193600889,
           14.651074078400855,
           14.670436220792824,
           14.689798363184794,
           14.709160505576762,
           14.728522647968731,
           14.7478847903607,
           14.76724693275267,
           14.786609075144638,
           14.805971217536607,
           14.825333359928578,
           14.844695502320544,
           14.864057644712513,
           14.883419787104483,
           14.902781929496452,
           14.92214407188842,
           14.94150621428039,
           14.960868356672359,
           14.980230499064326,
           14.999592641456296,
           15.018954783848267,
           15.038316926240235,
           15.057679068632202,
           15.079305583305118,
           15.105460842539909,
           15.131616101774704,
           15.1577713610095,
           15.183926620244295,
           15.210081879479088,
           15.236237138713886,
           15.262392397948682,
           15.288547657183475,
           15.31470291641827,
           15.340858175653068,
           15.36701343488786,
           15.393168694122657,
           15.419323953357452,
           15.445479212592248,
           15.471634471827043,
           15.49778973106184,
           15.523944990296634,
           15.550100249531429,
           15.576255508766225,
           15.602410768001022,
           15.628566027235816,
           15.65472128647061,
           15.680876545705406,
           15.7070318049402,
           15.733187064174995,
           15.75934232340979,
           15.785497582644584,
           15.81165284187938,
           15.837808101114177,
           15.863963360348972,
           15.890118619583765,
           15.916273878818561,
           15.94242913805336,
           15.968584397288154,
           15.994739656522947,
           16.020894915757744,
           16.04705017499254,
           16.073205434227333,
           16.099360693462128,
           16.125515952696922,
           16.151671211931717,
           16.17782647116651,
           16.20398173040131,
           16.230136989636105,
           16.2562922488709,
           16.282447508105694,
           16.30860276734049,
           16.334758026575287,
           16.360913285810078,
           16.387068545044876,
           16.41322380427967,
           16.439379063514465,
           16.465534322749264,
           16.491689581984055,
           16.517844841218853,
           16.544000100453648,
           16.570155359688442,
           16.596310618923237,
           16.62246587815803,
           16.648621137392823,
           16.67477639662762,
           16.700931655862416,
           16.727086915097214,
           16.7532057760936,
           16.77925975284128,
           16.805313729588956,
           16.83136770633663,
           16.8574216830843,
           16.883475659831976,
           16.909529636579652,
           16.935583613327324,
           16.961637590075,
           16.987691566822676,
           17.013745543570348,
           17.039799520318024,
           17.0658534970657,
           17.09190747381337,
           17.117961450561044,
           17.14401542730872,
           17.170069404056395,
           17.196123380804064,
           17.222177357551743,
           17.22941332494557,
           17.14255924557019,
           17.05570516619481,
           16.96885108681943,
           16.88199700744407,
           16.79514292806869,
           16.708288848693307,
           16.621434769317947,
           16.534580689942565,
           16.447726610567184,
           16.360872531191823,
           16.274018451816442,
           16.187164372441064,
           16.100310293065682,
           16.01345621369032,
           15.92660213431494,
           15.839635981703843,
           15.727227916363152,
           15.614819851022439,
           15.502411785681725,
           15.39000372034103,
           15.277595655000315,
           15.1651875896596,
           15.052779524318908,
           14.940371458978195,
           14.827963393637482,
           14.715555328296766,
           14.603147262956071,
           14.490739197615358,
           14.378331132274646,
           14.26592306693395,
           14.153515001593236,
           14.041106936252522,
           13.928698870911829,
           13.816290805571114,
           13.703882740230402,
           13.591474674889689,
           13.479066609548994,
           13.366658544208281,
           13.254250478867565,
           13.141842413526872,
           13.029434348186157,
           12.917026282845443,
           12.80461821750475,
           12.692210152164035,
           12.579802086823321,
           12.467394021482626,
           12.354985956141913,
           12.2425778908012,
           12.130169825460486,
           12.017761760119793,
           11.905353694779079,
           11.792945629438364,
           11.680537564097671,
           11.568129498756957,
           11.455721433416244,
           11.34331336807555,
           11.230905302734836,
           11.118497237394122,
           11.006089172053407,
           10.893681106712712,
           10.781273041372,
           10.668864976031285,
           10.556456910690592,
           10.444048845349878,
           10.331640780009163,
           10.21923271466847,
           10.098672252476455,
           9.936027864173795,
           9.773383475871167,
           9.610739087568508,
           9.44809469926585,
           9.28545031096319,
           9.122805922660561,
           8.960161534357905,
           8.797517146055245,
           8.634872757752618,
           8.472228369449958,
           8.309583981147298,
           8.146939592844669,
           7.98429520454201,
           7.8216508162393525,
           7.659006427936693,
           7.496362039634065
          ],
          [
           10.735983080895231,
           10.751511698601773,
           10.767040316308314,
           10.782568934014856,
           10.798097551721396,
           10.813626169427938,
           10.829154787134478,
           10.84468340484102,
           10.860212022547561,
           10.875740640254103,
           10.891269257960644,
           10.906797875667186,
           10.922326493373726,
           10.937855111080266,
           10.953383728786807,
           10.96891234649335,
           10.98444096419989,
           10.997842395395152,
           11.010180235841268,
           11.022518076287385,
           11.0348559167335,
           11.047193757179617,
           11.059531597625734,
           11.07186943807185,
           11.084207278517967,
           11.096545118964082,
           11.108882959410199,
           11.121220799856316,
           11.133558640302432,
           11.145896480748547,
           11.158234321194664,
           11.17057216164078,
           11.182910002086897,
           11.195247842533014,
           11.20758568297913,
           11.219923523425246,
           11.232261363871363,
           11.24459920431748,
           11.256937044763596,
           11.269274885209711,
           11.281612725655828,
           11.293950566101945,
           11.30628840654806,
           11.318626246994176,
           11.330964087440293,
           11.343301927886408,
           11.355639768332527,
           11.367977608778643,
           11.380315449224758,
           11.392653289670875,
           11.40499113011699,
           11.417328970563108,
           11.429666811009223,
           11.44200465145534,
           11.454342491901457,
           11.466680332347572,
           11.479018172793689,
           11.491356013239805,
           11.503693853685922,
           11.516031694132039,
           11.528369534578156,
           11.54070737502427,
           11.553045215470387,
           11.565383055916502,
           11.57772089636262,
           11.590058736808736,
           11.602396577254853,
           11.61473441770097,
           11.627072258147084,
           11.639410098593201,
           11.651747939039318,
           11.664085779485434,
           11.676423619931551,
           11.688761460377666,
           11.701099300823783,
           11.7134371412699,
           11.725774981716015,
           11.738112822162133,
           11.75045066260825,
           11.762788503054365,
           11.775126343500482,
           11.787464183946598,
           11.799802024392715,
           11.812139864838832,
           11.824259873043022,
           11.836336314798826,
           11.848412756554632,
           11.860489198310436,
           11.872565640066243,
           11.884642081822047,
           11.896718523577853,
           11.908794965333659,
           11.920871407089464,
           11.93294784884527,
           11.945024290601076,
           11.95710073235688,
           11.969177174112687,
           11.981253615868491,
           11.993330057624297,
           12.005406499380102,
           12.017482941135906,
           12.029559382891712,
           12.041635824647518,
           12.053712266403323,
           12.065788708159129,
           12.077865149914935,
           12.08994159167074,
           12.102018033426544,
           12.114094475182352,
           12.126170916938154,
           12.138247358693961,
           12.150323800449765,
           12.162400242205571,
           12.174476683961377,
           12.186553125717182,
           12.198629567472988,
           12.210706009228792,
           12.222782450984598,
           12.234858892740405,
           12.246935334496207,
           12.259011776252017,
           12.27108821800782,
           12.283164659763624,
           12.295241101519432,
           12.307317543275236,
           12.319393985031041,
           12.331470426786847,
           12.343546868542651,
           12.355623310298459,
           12.367699752054264,
           12.379776193810066,
           12.391852635565874,
           12.40392907732168,
           12.416005519077483,
           12.428081960833289,
           12.440158402589095,
           12.4522348443449,
           12.464311286100706,
           12.476387727856512,
           12.488464169612316,
           12.500540611368121,
           12.512617053123929,
           12.524693494879733,
           12.536769936635539,
           12.548846378391344,
           12.560922820147148,
           12.572999261902954,
           12.585075703658761,
           12.597152145414563,
           12.60922858717037,
           12.621305028926177,
           12.636264129922242,
           12.651223232427943,
           12.666182334933646,
           12.681141437439349,
           12.696100539945053,
           12.711059642450756,
           12.726018744956459,
           12.74097784746216,
           12.755936949967863,
           12.770896052473569,
           12.785855154979272,
           12.800814257484975,
           12.815773359990676,
           12.830732462496378,
           12.845691565002083,
           12.860650667507786,
           12.877040784697016,
           12.894146409228009,
           12.911252033759002,
           12.928357658289995,
           12.94546328282099,
           12.962568907351983,
           12.979674531882974,
           12.996780156413969,
           13.013885780944962,
           13.030991405475955,
           13.048097030006948,
           13.065202654537941,
           13.082308279068936,
           13.099413903599928,
           13.11651952813092,
           13.133625152661915,
           13.150730777192909,
           13.167836401723902,
           13.183954718578862,
           13.198168950780703,
           13.21238318298254,
           13.22659741518438,
           13.24081164738622,
           13.255025879588061,
           13.2692401117899,
           13.283454343991737,
           13.297668576193578,
           13.311882808395415,
           13.326097040597258,
           13.340311272799095,
           13.354525505000934,
           13.368739737202775,
           13.382953969404614,
           13.397168201606451,
           13.411382433808292,
           13.425596666010133,
           13.439810898211972,
           13.454025130413813,
           13.468239362615648,
           13.482453594817489,
           13.49666782701933,
           13.510882059221167,
           13.525096291423008,
           13.539310523624847,
           13.553524755826686,
           13.567738988028527,
           13.581953220230364,
           13.596167452432205,
           13.610381684634046,
           13.624595916835883,
           13.638810149037726,
           13.653024381239561,
           13.667238613441402,
           13.681452845643243,
           13.695667077845082,
           13.70988131004692,
           13.72409554224876,
           13.738309774450599,
           13.752524006652438,
           13.766738238854279,
           13.780952471056116,
           13.795166703257955,
           13.809380935459796,
           13.823595167661637,
           13.837809399863474,
           13.852023632065315,
           13.866237864267156,
           13.880452096468993,
           13.894666328670834,
           13.90888056087267,
           13.923094793074512,
           13.937309025276353,
           13.95152325747819,
           13.96573748968003,
           13.979951721881868,
           13.994165954083709,
           14.00838018628555,
           14.022594418487387,
           14.036808650689226,
           14.051022882891067,
           14.065237115092906,
           14.079451347294746,
           14.093665579496584,
           14.111276205904403,
           14.132283226518197,
           14.15329024713199,
           14.174297267745784,
           14.19530428835958,
           14.216311308973374,
           14.237318329587168,
           14.258325350200963,
           14.27933237081476,
           14.300339391428553,
           14.321346412042347,
           14.342353432656143,
           14.363360453269935,
           14.384367473883731,
           14.405374494497526,
           14.42638151511132,
           14.447388535725112,
           14.468395556338908,
           14.489402576952703,
           14.510409597566497,
           14.531416618180291,
           14.552423638794089,
           14.57343065940788,
           14.594437680021677,
           14.615444700635472,
           14.636451721249264,
           14.657458741863058,
           14.678465762476854,
           14.699472783090648,
           14.72047980370444,
           14.741486824318237,
           14.762493844932035,
           14.783500865545825,
           14.804077971324606,
           14.823440113716577,
           14.842802256108543,
           14.86216439850051,
           14.881526540892482,
           14.90088868328445,
           14.920250825676419,
           14.939612968068388,
           14.958975110460358,
           14.978337252852324,
           14.997699395244297,
           15.017061537636266,
           15.036423680028232,
           15.055785822420201,
           15.075147964812171,
           15.09451010720414,
           15.11387224959611,
           15.13323439198808,
           15.152596534380045,
           15.171958676772014,
           15.191320819163986,
           15.210682961555953,
           15.230045103947921,
           15.249407246339889,
           15.268769388731862,
           15.288131531123828,
           15.307493673515797,
           15.326855815907766,
           15.346217958299736,
           15.365580100691702,
           15.384942243083675,
           15.40430438547564,
           15.42366652786761,
           15.44302867025958,
           15.462390812651552,
           15.481752955043516,
           15.501115097435488,
           15.520477239827457,
           15.539839382219427,
           15.559201524611392,
           15.578563667003365,
           15.597925809395331,
           15.617287951787299,
           15.636650094179267,
           15.656012236571236,
           15.675374378963207,
           15.694736521355175,
           15.714098663747144,
           15.733460806139114,
           15.752822948531083,
           15.774449463203995,
           15.800604722438788,
           15.826759981673584,
           15.85291524090838,
           15.879070500143174,
           15.90522575937797,
           15.931381018612765,
           15.957536277847561,
           15.983691537082354,
           16.009846796317152,
           16.036002055551947,
           16.06215731478674,
           16.088312574021536,
           16.11446783325633,
           16.140623092491126,
           16.16677835172592,
           16.19293361096072,
           16.219088870195513,
           16.245244129430308,
           16.271399388665102,
           16.2975546478999,
           16.323709907134692,
           16.349865166369487,
           16.376020425604285,
           16.40217568483908,
           16.428330944073874,
           16.454486203308672,
           16.480641462543463,
           16.506796721778258,
           16.532951981013053,
           16.55910724024785,
           16.585262499482642,
           16.611417758717444,
           16.637573017952235,
           16.66372748608943,
           16.689781462837104,
           16.715835439584776,
           16.74188941633245,
           16.767943393080124,
           16.7939973698278,
           16.820051346575475,
           16.846105323323144,
           16.872159300070823,
           16.8982132768185,
           16.92426725356617,
           16.950321230313847,
           16.97637520706152,
           17.00242918380919,
           17.028483160556867,
           17.054537137304543,
           17.080591114052215,
           17.10664509079989,
           17.132699067547566,
           17.15875304429524,
           17.18480702104291,
           17.210860997790586,
           17.236914974538266,
           17.262968951285934,
           17.28902292803361,
           17.315076904781286,
           17.341130881528958,
           17.36718485827663,
           17.393238835024306,
           17.41929281177198,
           17.445346788519654,
           17.47140076526733,
           17.497454742015005,
           17.523508718762677,
           17.549562695510353,
           17.57561667225803,
           17.6016706490057,
           17.627724625753377,
           17.65377860250105,
           17.67983257924872,
           17.705886555996397,
           17.731940532744073,
           17.757994509491752,
           17.784048486239417,
           17.810102462987096,
           17.836156439734772,
           17.862210416482444,
           17.888264393230116,
           17.914318369977792,
           17.92155433737162,
           17.83470025799624,
           17.74784617862086,
           17.660992099245483,
           17.57413801987012,
           17.487283940494738,
           17.400429861119356,
           17.313575781743996,
           17.226721702368614,
           17.139867622993236,
           17.053013543617872,
           16.966159464242494,
           16.879305384867113,
           16.792451305491735,
           16.705597226116367,
           16.61874314674099,
           16.53188906736561,
           16.445034987990248,
           16.35818090861487,
           16.27132682923949,
           16.184472749864124,
           16.097618670488746,
           16.010764591113364,
           15.923910511738,
           15.837056432362623,
           15.750202352987243,
           15.663348273611863,
           15.5764941942365,
           15.48964011486112,
           15.402786035485741,
           15.315931956110377,
           15.229077876734998,
           15.142223797359616,
           15.055369717984254,
           14.968515638608874,
           14.881661559233493,
           14.794807479858116,
           14.70795340048275,
           14.621099321107371,
           14.534245241731993,
           14.447391162356627,
           14.359584474347471,
           14.240676412206675,
           14.078032023904045,
           13.915387635601386,
           13.75274324729873,
           13.5900988589961,
           13.42745447069344,
           13.264810082390785,
           13.102165694088123,
           12.939521305785496,
           12.776876917482836,
           12.614232529180178,
           12.451588140877549,
           12.28894375257489,
           12.12629936427223,
           11.9636549759696,
           11.801010587666944,
           11.638366199364285,
           11.475721811061629,
           11.313077422758997,
           11.15043303445634,
           10.98778864615368,
           10.82514425785105,
           10.662499869548395,
           10.499855481245733,
           10.337211092943107,
           10.174566704640446,
           10.011922316337788,
           9.849277928035157,
           9.686633539732501,
           9.523989151429841,
           9.361344763127184,
           9.198700374824554,
           9.036055986521895,
           8.873411598219239,
           8.710767209916607,
           8.548122821613951,
           8.38547843331129,
           8.222834045008662,
           8.060189656706003,
           7.897545268403347,
           7.734900880100686,
           7.572256491798058
          ],
          [
           11.206453841977936,
           11.221982459684476,
           11.237511077391016,
           11.25303969509756,
           11.2685683128041,
           11.284096930510643,
           11.299625548217183,
           11.315154165923722,
           11.330682783630266,
           11.346211401336806,
           11.361740019043348,
           11.377268636749887,
           11.392797254456429,
           11.40832587216297,
           11.423854489869512,
           11.439383107576054,
           11.454911725282596,
           11.470440342989136,
           11.485968960695676,
           11.501497578402219,
           11.517026196108759,
           11.5325548138153,
           11.548083431521842,
           11.563612049228384,
           11.579140666934924,
           11.594669284641466,
           11.610197902348006,
           11.625726520054547,
           11.641255137761089,
           11.65678375546763,
           11.672312373174172,
           11.687840990880712,
           11.703369608587256,
           11.718366428939206,
           11.730704269385322,
           11.743042109831439,
           11.755379950277556,
           11.767717790723673,
           11.780055631169787,
           11.792393471615904,
           11.804731312062021,
           11.817069152508136,
           11.829406992954254,
           11.84174483340037,
           11.854082673846484,
           11.866420514292603,
           11.878758354738718,
           11.891096195184836,
           11.903434035630951,
           11.915771876077068,
           11.928109716523185,
           11.9404475569693,
           11.952785397415415,
           11.965123237861533,
           11.977461078307648,
           11.989798918753765,
           12.002136759199882,
           12.014474599646,
           12.026812440092115,
           12.039150280538232,
           12.051488120984349,
           12.063825961430464,
           12.07616380187658,
           12.088501642322697,
           12.100839482768812,
           12.11317732321493,
           12.125515163661044,
           12.137853004107162,
           12.150190844553277,
           12.162528684999394,
           12.174866525445513,
           12.187204365891628,
           12.199542206337744,
           12.21188004678386,
           12.224217887229976,
           12.236555727676093,
           12.24889356812221,
           12.261231408568326,
           12.273569249014441,
           12.285907089460558,
           12.298244929906673,
           12.310582770352791,
           12.322920610798906,
           12.335258451245023,
           12.347378459449214,
           12.35945490120502,
           12.371531342960825,
           12.38360778471663,
           12.395684226472437,
           12.40776066822824,
           12.419837109984044,
           12.431913551739852,
           12.443989993495656,
           12.456066435251461,
           12.468142877007267,
           12.480219318763073,
           12.492295760518878,
           12.504372202274684,
           12.51644864403049,
           12.528525085786296,
           12.5406015275421,
           12.552677969297907,
           12.564754411053713,
           12.576830852809517,
           12.588907294565322,
           12.600983736321126,
           12.613060178076932,
           12.625136619832737,
           12.637213061588543,
           12.649289503344349,
           12.661365945100153,
           12.673442386855958,
           12.685518828611764,
           12.69759527036757,
           12.709671712123377,
           12.721748153879181,
           12.733824595634985,
           12.74590103739079,
           12.757977479146598,
           12.7700539209024,
           12.782130362658208,
           12.794206804414014,
           12.806283246169818,
           12.818359687925625,
           12.830436129681429,
           12.842512571437235,
           12.854589013193038,
           12.866665454948844,
           12.878741896704652,
           12.890818338460456,
           12.902894780216261,
           12.914971221972067,
           12.92704766372787,
           12.939124105483678,
           12.952641876580433,
           12.967600979086136,
           12.982560081591838,
           12.997519184097541,
           13.012478286603244,
           13.027437389108949,
           13.04239649161465,
           13.057355594120354,
           13.072314696626057,
           13.087273799131758,
           13.102232901637462,
           13.117192004143165,
           13.13215110664887,
           13.147110209154572,
           13.162069311660275,
           13.177028414165978,
           13.19198751667168,
           13.206946619177385,
           13.221905721683084,
           13.236864824188789,
           13.251823926694492,
           13.266783029200194,
           13.281742131705897,
           13.2967012342116,
           13.311660336717303,
           13.326619439223007,
           13.34157854172871,
           13.356537644234413,
           13.371496746740117,
           13.38645584924582,
           13.401414951751523,
           13.416374054257226,
           13.431333156762928,
           13.447723273952159,
           13.464828898483152,
           13.481934523014147,
           13.499040147545138,
           13.51614577207613,
           13.533251396607126,
           13.550357021138117,
           13.567462645669112,
           13.584568270200103,
           13.6016738947311,
           13.618779519262091,
           13.635885143793086,
           13.652990768324077,
           13.670096392855072,
           13.687202017386065,
           13.704307641917056,
           13.72141326644805,
           13.738518890979046,
           13.755624515510036,
           13.772730140041029,
           13.789835764572022,
           13.806941389103017,
           13.824047013634011,
           13.841152638165003,
           13.858258262695996,
           13.875363887226992,
           13.892469511757984,
           13.909575136288975,
           13.92668076081997,
           13.943786385350965,
           13.960892009881956,
           13.977997634412947,
           13.995103258943942,
           14.012208883474937,
           14.029314508005928,
           14.046420132536923,
           14.063525757067918,
           14.078233637883166,
           14.092447870085005,
           14.106662102286846,
           14.120876334488685,
           14.135090566690522,
           14.149304798892363,
           14.163519031094204,
           14.177733263296041,
           14.191947495497882,
           14.206161727699719,
           14.22037595990156,
           14.2345901921034,
           14.248804424305238,
           14.263018656507079,
           14.277232888708916,
           14.291447120910757,
           14.305661353112598,
           14.319875585314437,
           14.334089817516276,
           14.348304049718115,
           14.362518281919954,
           14.376732514121795,
           14.390946746323634,
           14.405160978525473,
           14.419375210727312,
           14.43358944292915,
           14.447803675130992,
           14.46201790733283,
           14.47623213953467,
           14.49044637173651,
           14.504660603938348,
           14.518874836140188,
           14.533089068342028,
           14.547303300543867,
           14.561517532745706,
           14.575731764947545,
           14.589945997149385,
           14.604160229351223,
           14.618374461553064,
           14.632588693754903,
           14.646802925956742,
           14.661017158158582,
           14.67523139036042,
           14.68944562256226,
           14.703659854764101,
           14.717874086965939,
           14.735484713373756,
           14.756491733987552,
           14.777498754601346,
           14.79850577521514,
           14.819512795828935,
           14.840519816442729,
           14.861526837056523,
           14.882533857670317,
           14.903540878284113,
           14.924547898897906,
           14.9455549195117,
           14.966561940125498,
           14.987568960739292,
           15.008575981353085,
           15.02958300196688,
           15.050590022580673,
           15.071597043194469,
           15.092604063808263,
           15.113611084422057,
           15.134618105035852,
           15.155625125649646,
           15.176632146263444,
           15.197639166877234,
           15.21864618749103,
           15.239653208104826,
           15.260660228718619,
           15.281667249332411,
           15.302674269946209,
           15.323681290560003,
           15.344688311173798,
           15.365695331787592,
           15.386702352401388,
           15.40770937301518,
           15.428716393628978,
           15.449723414242772,
           15.470730434856565,
           15.491737455470359,
           15.512744476084155,
           15.533751496697949,
           15.55475851731174,
           15.575765537925538,
           15.596772558539332,
           15.617779579153122,
           15.63878659976692,
           15.659793620380716,
           15.680800640994509,
           15.701807661608303,
           15.7228146822221,
           15.743821702835895,
           15.764828723449687,
           15.785835744063482,
           15.806842764677276,
           15.82784978529107,
           15.848856805904866,
           15.869863826518662,
           15.890870847132454,
           15.911877867746249,
           15.932884888360045,
           15.953891908973839,
           15.974898929587631,
           15.995905950201426,
           16.01691297081522,
           16.037919991429014,
           16.058927012042812,
           16.079934032656602,
           16.100941053270397,
           16.12194807388419,
           16.14295509449799,
           16.163962115111783,
           16.184969135725574,
           16.20597615633937,
           16.226983176953166,
           16.24799019756696,
           16.268997218180758,
           16.290004238794552,
           16.311011259408343,
           16.331793974078163,
           16.35115611647013,
           16.3705182588621,
           16.389880401254068,
           16.409242543646037,
           16.428604686038007,
           16.447966828429973,
           16.469593343102886,
           16.49574860233768,
           16.521903861572476,
           16.54805912080727,
           16.574214380042065,
           16.600303172832938,
           16.626357149580613,
           16.65241112632829,
           16.67846510307596,
           16.704519079823637,
           16.73057305657131,
           16.756627033318985,
           16.78268101006666,
           16.808734986814333,
           16.83478896356201,
           16.86084294030968,
           16.886896917057356,
           16.91295089380503,
           16.939004870552704,
           16.965058847300376,
           16.991112824048052,
           17.017166800795728,
           17.0432207775434,
           17.069274754291076,
           17.09532873103875,
           17.121382707786424,
           17.1474366845341,
           17.173490661281775,
           17.199544638029444,
           17.22559861477712,
           17.251652591524795,
           17.277706568272468,
           17.303760545020143,
           17.32981452176782,
           17.355868498515495,
           17.381922475263167,
           17.40797645201084,
           17.43403042875852,
           17.460084405506187,
           17.486138382253863,
           17.512192359001535,
           17.53824633574921,
           17.564300312496886,
           17.590354289244562,
           17.616408265992234,
           17.64246224273991,
           17.668516219487582,
           17.69457019623526,
           17.720624172982934,
           17.746678149730606,
           17.77273212647828,
           17.798786103225954,
           17.82484007997363,
           17.850894056721305,
           17.876948033468977,
           17.903002010216653,
           17.929055986964325,
           17.955109963712,
           17.981163940459673,
           18.00721791720735,
           18.03327189395502,
           18.059325870702697,
           18.085379847450373,
           18.111433824198045,
           18.137487800945717,
           18.163541777693393,
           18.18959575444107,
           18.21564973118874,
           18.241703707936416,
           18.267757684684092,
           18.293811661431768,
           18.31986563817944,
           18.345919614927112,
           18.371973591674788,
           18.39802756842246,
           18.424081545170136,
           18.45013552191781,
           18.476189498665487,
           18.50224347541316,
           18.528297452160835,
           18.554351428908504,
           18.580405405656183,
           18.606459382403855,
           18.613695349797684,
           18.52684127042231,
           18.439987191046928,
           18.353133111671546,
           18.266279032296183,
           18.179424952920805,
           18.092570873545423,
           18.001828136698883,
           17.86831017622432,
           17.73479221574976,
           17.60127425527522,
           17.46775629480066,
           17.3342383343261,
           17.20072037385154,
           17.067202413377,
           16.933684452902437,
           16.800166492427877,
           16.66664853195334,
           16.533130571478775,
           16.399612611004216,
           16.26609465052968,
           16.132576690055117,
           15.999058729580554,
           15.865540769106017,
           15.732022808631454,
           15.598504848156892,
           15.46498688768233,
           15.331468927207794,
           15.197950966733233,
           15.06443300625867,
           14.930915045784133,
           14.797397085309571,
           14.66387912483501,
           14.530361164360473,
           14.396843203885911,
           14.263325243411348,
           14.129807282936786,
           13.99628932246225,
           13.862771361987688,
           13.729253401513127,
           13.595735441038588,
           13.462217480564025,
           13.328699520089462,
           13.195181559614927,
           13.061663599140365,
           12.928145638665804,
           12.794627678191267,
           12.661109717716704,
           12.527591757242142,
           12.39407379676758,
           12.260555836293042,
           12.12703787581848,
           11.993519915343919,
           11.86000195486938,
           11.72648399439482,
           11.592966033920257,
           11.459448073445719,
           11.32593011297116,
           11.192412152496596,
           11.058894192022034,
           10.9253762315475,
           10.791858271072934,
           10.658340310598373,
           10.524822350123836,
           10.391304389649273,
           10.257786429174713,
           10.124268468700176,
           9.990750508225615,
           9.857232547751051,
           9.723714587276515,
           9.590196626801951,
           9.45667866632739,
           9.323160705852828,
           9.189642745378292,
           9.056124784903728,
           8.922606824429167,
           8.7866616620806,
           8.624017273777941,
           8.461372885475285,
           8.298728497172656,
           8.136084108869998,
           7.973439720567338,
           7.810795332264679,
           7.648150943962051
          ],
          [
           11.676924603060638,
           11.692453220767181,
           11.70798183847372,
           11.72351045618026,
           11.739039073886804,
           11.754567691593344,
           11.770096309299884,
           11.785624927006427,
           11.801153544712967,
           11.81668216241951,
           11.83221078012605,
           11.84773939783259,
           11.863268015539132,
           11.878796633245674,
           11.894325250952216,
           11.909853868658757,
           11.925382486365297,
           11.94091110407184,
           11.95643972177838,
           11.971968339484922,
           11.987496957191464,
           12.003025574898004,
           12.018554192604544,
           12.034082810311087,
           12.049611428017627,
           12.065140045724169,
           12.08066866343071,
           12.09619728113725,
           12.111725898843794,
           12.127254516550334,
           12.142783134256877,
           12.158311751963415,
           12.173840369669957,
           12.189368987376499,
           12.20489760508304,
           12.220426222789582,
           12.235954840496122,
           12.251483458202665,
           12.267012075909204,
           12.282540693615747,
           12.298069311322287,
           12.31359792902883,
           12.32912654673537,
           12.34465516444191,
           12.360183782148452,
           12.375712399854992,
           12.391241017561535,
           12.406769635268075,
           12.422298252974617,
           12.437826870681159,
           12.451228302929376,
           12.463566143375491,
           12.47590398382161,
           12.488241824267725,
           12.500579664713841,
           12.512917505159958,
           12.525255345606073,
           12.537593186052192,
           12.549931026498307,
           12.562268866944423,
           12.57460670739054,
           12.586944547836655,
           12.599282388282772,
           12.611620228728889,
           12.623958069175004,
           12.636295909621122,
           12.648633750067237,
           12.660971590513354,
           12.673309430959469,
           12.685647271405585,
           12.697985111851704,
           12.710322952297819,
           12.722660792743936,
           12.73499863319005,
           12.747336473636167,
           12.759674314082284,
           12.7720121545284,
           12.784349994974518,
           12.796687835420634,
           12.80902567586675,
           12.821363516312866,
           12.833701356758983,
           12.8460391972051,
           12.858377037651216,
           12.870497045855405,
           12.88257348761121,
           12.894649929367016,
           12.906726371122822,
           12.918802812878628,
           12.930879254634432,
           12.94295569639024,
           12.955032138146043,
           12.967108579901849,
           12.979185021657653,
           12.99126146341346,
           13.003337905169264,
           13.01541434692507,
           13.027490788680876,
           13.039567230436681,
           13.051643672192487,
           13.063720113948293,
           13.075796555704096,
           13.087872997459904,
           13.09994943921571,
           13.112025880971512,
           13.12410232272732,
           13.136178764483125,
           13.148255206238929,
           13.160331647994736,
           13.17240808975054,
           13.184484531506346,
           13.19656097326215,
           13.208637415017957,
           13.220713856773763,
           13.232790298529567,
           13.244866740285374,
           13.256943182041178,
           13.269019623796982,
           13.283978725744326,
           13.298937828250033,
           13.313896930755735,
           13.328856033261438,
           13.34381513576714,
           13.358774238272842,
           13.373733340778548,
           13.388692443284251,
           13.403651545789954,
           13.418610648295656,
           13.433569750801357,
           13.448528853307064,
           13.463487955812765,
           13.47844705831847,
           13.49340616082417,
           13.508365263329871,
           13.523324365835578,
           13.538283468341278,
           13.553242570846981,
           13.568201673352686,
           13.583160775858389,
           13.598119878364091,
           13.613078980869792,
           13.628038083375497,
           13.6429971858812,
           13.657956288386902,
           13.672915390892607,
           13.687874493398308,
           13.702833595904014,
           13.717792698409717,
           13.732751800915418,
           13.747710903421122,
           13.762670005926823,
           13.777629108432528,
           13.792588210938229,
           13.807547313443932,
           13.822506415949636,
           13.837465518455339,
           13.852424620961042,
           13.867383723466745,
           13.882342825972447,
           13.89730192847815,
           13.912261030983853,
           13.927220133489556,
           13.94217923599526,
           13.957138338500961,
           13.972097441006664,
           13.987056543512368,
           14.002015646018071,
           14.018405763207301,
           14.035511387738294,
           14.052617012269287,
           14.06972263680028,
           14.086828261331272,
           14.103933885862267,
           14.12103951039326,
           14.138145134924255,
           14.155250759455248,
           14.17235638398624,
           14.189462008517234,
           14.206567633048227,
           14.223673257579222,
           14.240778882110213,
           14.257884506641206,
           14.2749901311722,
           14.292095755703194,
           14.309201380234185,
           14.32630700476518,
           14.343412629296173,
           14.360518253827166,
           14.37762387835816,
           14.394729502889152,
           14.411835127420147,
           14.428940751951139,
           14.446046376482133,
           14.463152001013125,
           14.48025762554412,
           14.497363250075113,
           14.514468874606106,
           14.531574499137097,
           14.548680123668092,
           14.565785748199087,
           14.582891372730078,
           14.599996997261073,
           14.617102621792066,
           14.634208246323059,
           14.651313870854052,
           14.668419495385045,
           14.68552511991604,
           14.70263074444703,
           14.719736368978024,
           14.73684199350902,
           14.75394761804001,
           14.771053242571005,
           14.788158867101998,
           14.805264491632991,
           14.822370116163984,
           14.839475740694978,
           14.856581365225972,
           14.873686989756965,
           14.890792614287957,
           14.907898238818948,
           14.925003863349945,
           14.94210948788094,
           14.958298324985629,
           14.972512557187468,
           14.986726789389309,
           15.00094102159115,
           15.015155253792988,
           15.029369485994826,
           15.043583718196667,
           15.057797950398506,
           15.072012182600345,
           15.086226414802185,
           15.100440647004024,
           15.114654879205862,
           15.128869111407704,
           15.143083343609543,
           15.15729757581138,
           15.17151180801322,
           15.185726040215062,
           15.1999402724169,
           15.21415450461874,
           15.22836873682058,
           15.242582969022418,
           15.25679720122426,
           15.271011433426098,
           15.285225665627937,
           15.299439897829775,
           15.313654130031615,
           15.327868362233456,
           15.342082594435293,
           15.359693220843113,
           15.380700241456907,
           15.401707262070701,
           15.422714282684494,
           15.44372130329829,
           15.464728323912084,
           15.485735344525878,
           15.506742365139672,
           15.527749385753467,
           15.54875640636726,
           15.569763426981057,
           15.590770447594853,
           15.611777468208647,
           15.632784488822438,
           15.653791509436235,
           15.67479853005003,
           15.695805550663824,
           15.716812571277618,
           15.737819591891412,
           15.758826612505207,
           15.779833633119003,
           15.800840653732797,
           15.82184767434659,
           15.842854694960383,
           15.863861715574181,
           15.884868736187975,
           15.905875756801768,
           15.926882777415564,
           15.947889798029358,
           15.968896818643152,
           15.989903839256947,
           16.01091085987074,
           16.031917880484535,
           16.05292490109833,
           16.073931921712127,
           16.094938942325918,
           16.115945962939712,
           16.13695298355351,
           16.157960004167304,
           16.178967024781095,
           16.199974045394892,
           16.220981066008687,
           16.241988086622477,
           16.26299510723627,
           16.284002127850073,
           16.305009148463864,
           16.326016169077658,
           16.347023189691456,
           16.36803021030525,
           16.38903723091904,
           16.410044251532838,
           16.43105127214663,
           16.452058292760427,
           16.473448200519442,
           16.49631747019588,
           16.51918673987231,
           16.542056009548748,
           16.564925279225186,
           16.58779454890162,
           16.610663818578058,
           16.633533088254495,
           16.656402357930933,
           16.679271627607367,
           16.7021408972838,
           16.72501016696024,
           16.747879436636673,
           16.77074870631311,
           16.793617975989548,
           16.816487245665982,
           16.839356515342423,
           16.86222578501886,
           16.885095054695295,
           16.907964324371733,
           16.930833594048167,
           16.953702863724605,
           16.97657213340104,
           16.999441403077476,
           17.02231067275391,
           17.045179942430348,
           17.068049212106786,
           17.090918481783223,
           17.11378775145966,
           17.136657021136095,
           17.15991754494375,
           17.183960577013842,
           17.20800360908393,
           17.23204664115402,
           17.25608967322411,
           17.280132705294204,
           17.304175737364297,
           17.328218769434386,
           17.352261801504476,
           17.37630483357457,
           17.40034786564466,
           17.42439089771475,
           17.44843392978484,
           17.472476961854934,
           17.496519993925023,
           17.520563025995116,
           17.54460605806521,
           17.568649090135303,
           17.59269212220539,
           17.61673515427548,
           17.640778186345575,
           17.66482121841566,
           17.688864250485757,
           17.712907282555847,
           17.73719278136182,
           17.763278703623566,
           17.78936462588532,
           17.81545054814707,
           17.841536470408812,
           17.86762239267056,
           17.893708314932315,
           17.919794237194058,
           17.94588015945581,
           17.97196608171756,
           17.998052003979307,
           18.024137926241057,
           18.050223848502803,
           18.076309770764553,
           18.102395693026303,
           18.128481615288052,
           18.1545675375498,
           18.180653459811552,
           18.206739382073298,
           18.23282530433505,
           18.258911226596794,
           18.284997148858544,
           18.311083071120294,
           18.33716899338204,
           18.363254915643793,
           18.389340837905543,
           18.41542676016729,
           18.44151268242904,
           18.467598604690785,
           18.493684526952535,
           18.519770449214285,
           18.545856371476034,
           18.571942293737784,
           18.598028215999534,
           18.62411413826128,
           18.65020006052303,
           18.67628598278478,
           18.702371905046526,
           18.72845782730828,
           18.754543749570022,
           18.780629671831772,
           18.806715594093518,
           18.83280151635527,
           18.858887438617018,
           18.884973360878767,
           18.911059283140517,
           18.937145205402267,
           18.963231127664013,
           18.989317049925763,
           19.015402972187513,
           19.04148889444926,
           19.067574816711012,
           19.09366073897276,
           19.119746661234505,
           19.145832583496254,
           19.171918505758008,
           19.198004428019754,
           19.224090350281504,
           19.250176272543253,
           19.25256151576324,
           19.136443363774458,
           19.020325211785675,
           18.904207059796885,
           18.788088907808124,
           18.67197075581934,
           18.555852603830555,
           18.43973445184179,
           18.323616299853008,
           18.20749814786422,
           18.09137999587546,
           17.975261843886674,
           17.859143691897888,
           17.743025539909105,
           17.626907387920344,
           17.510789235931554,
           17.394671083942775,
           17.27855293195401,
           17.162434779965224,
           17.04631662797644,
           16.930198475987677,
           16.81190535262343,
           16.678387392148867,
           16.544869431674332,
           16.41135147119977,
           16.277833510725205,
           16.144315550250646,
           16.01079758977611,
           15.877279629301547,
           15.743761668826986,
           15.610243708352447,
           15.476725747877888,
           15.343207787403324,
           15.209689826928786,
           15.076171866454224,
           14.942653905979661,
           14.809135945505101,
           14.675617985030563,
           14.542100024556001,
           14.40858206408144,
           14.275064103606903,
           14.14154614313234,
           14.008028182657778,
           13.874510222183241,
           13.74099226170868,
           13.607474301234118,
           13.47395634075958,
           13.340438380285018,
           13.206920419810455,
           13.073402459335894,
           12.939884498861357,
           12.806366538386795,
           12.672848577912234,
           12.539330617437695,
           12.405812656963134,
           12.272294696488572,
           12.138776736014034,
           12.005258775539472,
           11.87174081506491,
           11.738222854590347,
           11.604704894115812,
           11.471186933641249,
           11.336006788739137,
           11.162596659806734,
           10.9891865308743,
           10.815776401941863,
           10.642366273009458,
           10.468956144077023,
           10.295546015144586,
           10.122135886212181,
           9.948725757279743,
           9.775315628347307,
           9.601905499414872,
           9.428495370482468,
           9.255085241550033,
           9.081675112617596,
           8.908264983685191,
           8.734854854752754,
           8.561444725820317,
           8.388034596887914,
           8.214624467955478,
           8.04121433902304,
           7.867804210090604,
           7.6943940811582
          ],
          [
           12.147395364143334,
           12.162923981849874,
           12.178452599556415,
           12.193981217262957,
           12.209509834969499,
           12.225038452676039,
           12.240567070382578,
           12.25609568808912,
           12.271624305795664,
           12.287152923502203,
           12.302681541208745,
           12.318210158915285,
           12.333738776621828,
           12.349267394328368,
           12.36479601203491,
           12.380324629741452,
           12.395853247447992,
           12.411381865154535,
           12.426910482861075,
           12.442439100567617,
           12.457967718274158,
           12.473496335980698,
           12.48902495368724,
           12.50455357139378,
           12.520082189100322,
           12.535610806806863,
           12.551139424513405,
           12.566668042219945,
           12.582196659926487,
           12.597725277633028,
           12.61325389533957,
           12.628782513046112,
           12.644311130752651,
           12.659839748459193,
           12.675368366165735,
           12.690896983872276,
           12.706425601578815,
           12.721954219285358,
           12.737482836991898,
           12.753011454698441,
           12.768540072404981,
           12.784068690111525,
           12.799597307818065,
           12.815125925524605,
           12.830654543231146,
           12.846183160937686,
           12.86171177864423,
           12.87724039635077,
           12.892769014057311,
           12.908297631763853,
           12.923826249470395,
           12.939354867176935,
           12.954883484883476,
           12.970412102590016,
           12.985940720296558,
           13.0014693380031,
           13.016997955709641,
           13.032526573416183,
           13.048055191122724,
           13.063583808829264,
           13.079112426535806,
           13.094641044242348,
           13.11016966194889,
           13.12569827965543,
           13.141226897361971,
           13.156755515068513,
           13.17175233647342,
           13.184090176919536,
           13.196428017365653,
           13.208765857811768,
           13.221103698257885,
           13.233441538704001,
           13.245779379150118,
           13.258117219596235,
           13.27045506004235,
           13.282792900488467,
           13.295130740934583,
           13.3074685813807,
           13.319806421826815,
           13.332144262272932,
           13.344482102719049,
           13.356819943165165,
           13.369157783611282,
           13.381495624057397,
           13.39361563226159,
           13.405692074017393,
           13.417768515773199,
           13.429844957529005,
           13.441921399284809,
           13.453997841040614,
           13.46607428279642,
           13.478150724552226,
           13.490227166308031,
           13.502303608063835,
           13.514380049819643,
           13.526456491575447,
           13.538532933331252,
           13.550609375087058,
           13.562685816842865,
           13.57476225859867,
           13.586838700354475,
           13.60035647240251,
           13.615315574908212,
           13.630274677413915,
           13.645233779919618,
           13.66019288242532,
           13.675151984931025,
           13.690111087436726,
           13.70507018994243,
           13.720029292448134,
           13.734988394953836,
           13.749947497459539,
           13.764906599965244,
           13.779865702470946,
           13.794824804976649,
           13.809783907482352,
           13.824743009988055,
           13.839702112493757,
           13.85466121499946,
           13.869620317505163,
           13.884579420010866,
           13.899538522516568,
           13.914497625022271,
           13.929456727527974,
           13.944415830033677,
           13.959374932539381,
           13.974334035045084,
           13.989293137550789,
           14.004252240056488,
           14.019211342562194,
           14.034170445067895,
           14.0491295475736,
           14.064088650079302,
           14.079047752585002,
           14.094006855090708,
           14.108965957596409,
           14.123925060102113,
           14.138884162607816,
           14.153843265113519,
           14.168802367619223,
           14.183761470124924,
           14.198720572630627,
           14.21367967513633,
           14.228638777642033,
           14.243597880147737,
           14.25855698265344,
           14.273516085159143,
           14.288475187664847,
           14.30343429017055,
           14.318393392676253,
           14.333352495181956,
           14.348311597687658,
           14.363270700193361,
           14.378229802699062,
           14.393188905204767,
           14.40814800771047,
           14.423107110216172,
           14.438066212721875,
           14.453025315227578,
           14.46798441773328,
           14.482943520238983,
           14.497902622744688,
           14.512861725250392,
           14.527820827756093,
           14.542779930261796,
           14.557739032767499,
           14.572698135273203,
           14.589088252462433,
           14.606193876993425,
           14.62329950152442,
           14.640405126055413,
           14.657510750586406,
           14.6746163751174,
           14.691721999648394,
           14.708827624179385,
           14.72593324871038,
           14.743038873241371,
           14.760144497772364,
           14.777250122303359,
           14.794355746834352,
           14.811461371365343,
           14.828566995896338,
           14.845672620427331,
           14.862778244958324,
           14.87988386948932,
           14.896989494020312,
           14.914095118551305,
           14.931200743082297,
           14.948306367613291,
           14.965411992144286,
           14.982517616675278,
           14.999623241206269,
           15.016728865737264,
           15.033834490268257,
           15.05094011479925,
           15.068045739330245,
           15.085151363861236,
           15.10225698839223,
           15.119362612923222,
           15.136468237454217,
           15.15357386198521,
           15.170679486516203,
           15.187785111047198,
           15.20489073557819,
           15.221996360109184,
           15.239101984640175,
           15.25620760917117,
           15.273313233702162,
           15.290418858233156,
           15.307524482764151,
           15.324630107295143,
           15.341735731826137,
           15.35884135635713,
           15.375946980888124,
           15.393052605419115,
           15.41015822995011,
           15.427263854481104,
           15.444369479012096,
           15.461475103543089,
           15.478580728074082,
           15.495686352605073,
           15.512791977136072,
           15.529897601667063,
           15.547003226198054,
           15.564108850729047,
           15.581214475260042,
           15.598320099791035,
           15.615425724322028,
           15.632531348853021,
           15.649636973384016,
           15.666742597915007,
           15.683848222446,
           15.700953846976995,
           15.718059471507988,
           15.73516509603898,
           15.752270720569976,
           15.76937634510097,
           15.78648196963196,
           15.803587594162952,
           15.820693218693947,
           15.837798843224942,
           15.852577244289922,
           15.866791476491759,
           15.881005708693602,
           15.89521994089544,
           15.90943417309728,
           15.923648405299117,
           15.93786263750096,
           15.952076869702799,
           15.966291101904638,
           15.983901728312455,
           16.00490874892625,
           16.025915769540042,
           16.046922790153836,
           16.06792981076763,
           16.088936831381428,
           16.10994385199522,
           16.130950872609016,
           16.15195789322281,
           16.172964913836605,
           16.1939719344504,
           16.214978955064197,
           16.235985975677988,
           16.256992996291782,
           16.278000016905576,
           16.29900703751937,
           16.320014058133165,
           16.34102107874696,
           16.363281195175496,
           16.386150464851934,
           16.40901973452837,
           16.43188900420481,
           16.454758273881243,
           16.477627543557677,
           16.50049681323412,
           16.523366082910552,
           16.54623535258699,
           16.569104622263428,
           16.59197389193986,
           16.614843161616296,
           16.637712431292737,
           16.660581700969175,
           16.68345097064561,
           16.706320240322043,
           16.72918950999848,
           16.75205877967492,
           16.774928049351352,
           16.79779731902779,
           16.820666588704228,
           16.843535858380662,
           16.8664051280571,
           16.889274397733534,
           16.91214366740997,
           16.935012937086405,
           16.957882206762847,
           16.98075147643928,
           17.00362074611572,
           17.026490015792156,
           17.04935928546859,
           17.072228555145028,
           17.095097824821465,
           17.1179670944979,
           17.140836364174337,
           17.16370563385077,
           17.186574903527212,
           17.209444173203646,
           17.23231344288008,
           17.25518271255652,
           17.278051982232956,
           17.30092125190939,
           17.323790521585828,
           17.346659791262265,
           17.3695290609387,
           17.392398330615137,
           17.41526760029157,
           17.43813686996801,
           17.461006139644446,
           17.48387540932088,
           17.50674467899732,
           17.529613948673756,
           17.55248321835019,
           17.575352488026624,
           17.598221757703065,
           17.6210910273795,
           17.643960297055937,
           17.66682956673237,
           17.689698836408812,
           17.712568106085246,
           17.73543737576168,
           17.758306645438118,
           17.781175915114556,
           17.80404518479099,
           17.826914454467428,
           17.850174978275085,
           17.874218010345174,
           17.898261042415264,
           17.922304074485353,
           17.946347106555447,
           17.970390138625536,
           17.99443317069563,
           18.018476202765722,
           18.04251923483581,
           18.0665622669059,
           18.090605298975994,
           18.114648331046084,
           18.138691363116173,
           18.16273439518627,
           18.18677742725636,
           18.21082045932645,
           18.234863491396542,
           18.25890652346663,
           18.28294955553672,
           18.306992587606814,
           18.33103561967691,
           18.355078651746997,
           18.37912168381709,
           18.403164715887183,
           18.42720774795727,
           18.451250780027358,
           18.475293812097455,
           18.499336844167544,
           18.523379876237634,
           18.547422908307727,
           18.57146594037782,
           18.595508972447906,
           18.619552004518,
           18.643595036588092,
           18.66763806865818,
           18.691681100728275,
           18.715724132798364,
           18.739767164868457,
           18.763810196938547,
           18.78785322900864,
           18.81189626107873,
           18.835939293148822,
           18.859982325218912,
           18.884025357289,
           18.908068389359094,
           18.932111421429187,
           18.956154453499273,
           18.980197485569366,
           19.00424051763946,
           19.02828354970955,
           19.052326581779642,
           19.07636961384973,
           19.10041264591982,
           19.125208865805387,
           19.151294788067133,
           19.177380710328883,
           19.203466632590633,
           19.22955255485238,
           19.255638477114125,
           19.28172439937588,
           19.307810321637625,
           19.333896243899375,
           19.359982166161124,
           19.386068088422874,
           19.41215401068462,
           19.43823993294637,
           19.46432585520812,
           19.490411777469863,
           19.516497699731616,
           19.542583621993366,
           19.568669544255112,
           19.59475546651686,
           19.620841388778615,
           19.64692731104036,
           19.673013233302107,
           19.699099155563857,
           19.725185077825607,
           19.751271000087357,
           19.777356922349107,
           19.803442844610853,
           19.829528766872603,
           19.85561468913435,
           19.881700611396102,
           19.884085854616092,
           19.767967702627306,
           19.65184955063852,
           19.53573139864974,
           19.419613246660973,
           19.30349509467219,
           19.187376942683404,
           19.071258790694642,
           18.955140638705856,
           18.839022486717074,
           18.72290433472831,
           18.606786182739523,
           18.49066803075074,
           18.374549878761954,
           18.258431726773193,
           18.142313574784403,
           18.026195422795624,
           17.91007727080686,
           17.793959118818073,
           17.67784096682929,
           17.561722814840525,
           17.445604662851743,
           17.329486510862957,
           17.21336835887419,
           17.09725020688541,
           16.981132054896623,
           16.86501390290784,
           16.748895750919075,
           16.63277759893029,
           16.516659446941507,
           16.400541294952745,
           16.28442314296396,
           16.168304990975173,
           16.05218683898641,
           15.936068686997626,
           15.789829503032806,
           15.636005939247251,
           15.482182375461727,
           15.328358811676173,
           15.174535247890619,
           15.020711684105093,
           14.86688812031954,
           14.713064556533988,
           14.55924099274846,
           14.405417428962908,
           14.251593865177353,
           14.097770301391828,
           13.943946737606273,
           13.790123173820719,
           13.629095378053481,
           13.455685249121078,
           13.282275120188643,
           13.108864991256205,
           12.935454862323802,
           12.762044733391365,
           12.58863460445893,
           12.415224475526525,
           12.241814346594088,
           12.068404217661652,
           11.894994088729216,
           11.721583959796812,
           11.548173830864375,
           11.37476370193194,
           11.201353572999535,
           11.027943444067098,
           10.854533315134663,
           10.681123186202258,
           10.507713057269822,
           10.334302928337385,
           10.16089279940498,
           9.987482670472545,
           9.814072541540106,
           9.640662412607671,
           9.467252283675267,
           9.293842154742832,
           9.120432025810395,
           8.94702189687799,
           8.773611767945553,
           8.600201639013118,
           8.426791510080713,
           8.253381381148277,
           8.079971252215842,
           7.906561123283404,
           7.733150994351
          ],
          [
           12.617866125226037,
           12.633394742932579,
           12.64892336063912,
           12.66445197834566,
           12.679980596052202,
           12.695509213758744,
           12.711037831465283,
           12.726566449171825,
           12.742095066878367,
           12.757623684584908,
           12.77315230229145,
           12.78868091999799,
           12.80420953770453,
           12.819738155411073,
           12.835266773117613,
           12.850795390824155,
           12.866324008530697,
           12.881852626237237,
           12.89738124394378,
           12.91290986165032,
           12.92843847935686,
           12.943967097063402,
           12.959495714769943,
           12.975024332476485,
           12.990552950183025,
           13.006081567889568,
           13.02161018559611,
           13.03713880330265,
           13.052667421009193,
           13.068196038715733,
           13.083724656422273,
           13.099253274128817,
           13.114781891835356,
           13.130310509541898,
           13.14583912724844,
           13.16136774495498,
           13.176896362661521,
           13.192424980368063,
           13.207953598074605,
           13.223482215781143,
           13.239010833487686,
           13.254539451194228,
           13.270068068900768,
           13.28559668660731,
           13.30112530431385,
           13.316653922020393,
           13.332182539726933,
           13.347711157433475,
           13.363239775140016,
           13.378768392846556,
           13.394297010553098,
           13.40982562825964,
           13.425354245966181,
           13.440882863672721,
           13.456411481379263,
           13.471940099085803,
           13.487468716792346,
           13.502997334498886,
           13.518525952205428,
           13.53405456991197,
           13.549583187618511,
           13.565111805325053,
           13.580640423031594,
           13.596169040738133,
           13.611697658444676,
           13.627226276151216,
           13.642754893857758,
           13.6582835115643,
           13.673812129270841,
           13.689340746977381,
           13.704869364683923,
           13.720397982390462,
           13.735926600097004,
           13.751455217803546,
           13.766983835510088,
           13.78251245321663,
           13.79804107092317,
           13.81356968862971,
           13.829098306336252,
           13.844626924042794,
           13.860155541749336,
           13.875684159455876,
           13.891212777162417,
           13.90461421046359,
           13.9167342190607,
           13.931693321566405,
           13.946652424072107,
           13.96161152657781,
           13.976570629083513,
           13.991529731589216,
           14.00648883409492,
           14.021447936600623,
           14.036407039106326,
           14.051366141612029,
           14.066325244117731,
           14.081284346623434,
           14.096243449129137,
           14.11120255163484,
           14.126161654140542,
           14.141120756646245,
           14.15607985915195,
           14.171038961657652,
           14.185998064163355,
           14.200957166669058,
           14.21591626917476,
           14.230875371680462,
           14.245834474186168,
           14.260793576691869,
           14.275752679197574,
           14.290711781703276,
           14.305670884208979,
           14.320629986714682,
           14.335589089220385,
           14.350548191726087,
           14.36550729423179,
           14.380466396737493,
           14.395425499243197,
           14.410384601748898,
           14.425343704254601,
           14.440302806760304,
           14.455261909266008,
           14.470221011771713,
           14.485180114277416,
           14.500139216783118,
           14.515098319288821,
           14.530057421794524,
           14.545016524300229,
           14.559975626805931,
           14.574934729311632,
           14.589893831817337,
           14.604852934323038,
           14.619812036828742,
           14.634771139334447,
           14.649730241840146,
           14.66468934434585,
           14.679648446851555,
           14.694607549357258,
           14.70956665186296,
           14.724525754368663,
           14.739484856874366,
           14.754443959380069,
           14.769403061885772,
           14.784362164391474,
           14.799321266897177,
           14.81428036940288,
           14.829239471908584,
           14.844198574414287,
           14.85915767691999,
           14.874116779425691,
           14.889075881931396,
           14.9040349844371,
           14.918994086942803,
           14.933953189448504,
           14.948912291954205,
           14.96387139445991,
           14.978830496965614,
           14.993789599471317,
           15.00874870197702,
           15.02370780448272,
           15.038666906988425,
           15.053626009494128,
           15.06858511199983,
           15.083544214505533,
           15.098503317011238,
           15.11346241951694,
           15.128421522022643,
           15.143380624528346,
           15.159770741717576,
           15.17687636624857,
           15.193981990779562,
           15.211087615310555,
           15.228193239841548,
           15.245298864372542,
           15.262404488903535,
           15.279510113434528,
           15.296930273959882,
           15.314350434568274,
           15.331770595176666,
           15.349190755785056,
           15.366610916393448,
           15.384031077001838,
           15.401451237610232,
           15.41887139821862,
           15.436291558827012,
           15.453711719435404,
           15.471131880043796,
           15.488552040652186,
           15.505972201260578,
           15.523392361868968,
           15.540812522477362,
           15.558232683085752,
           15.575652843694144,
           15.593073004302532,
           15.610493164910926,
           15.627913325519316,
           15.64533348612771,
           15.662753646736098,
           15.68017380734449,
           15.697593967952882,
           15.715014128561272,
           15.732434289169666,
           15.749854449778054,
           15.767274610386448,
           15.784694770994838,
           15.80211493160323,
           15.819535092211622,
           15.836955252820012,
           15.854375413428404,
           15.871795574036794,
           15.889215734645186,
           15.906635895253578,
           15.92405605586197,
           15.941476216470358,
           15.958896377078752,
           15.976316537687143,
           15.993736698295532,
           16.011156858903927,
           16.028577019512316,
           16.045997180120708,
           16.0634173407291,
           16.080837501337488,
           16.098257661945883,
           16.11567782255427,
           16.13309798316266,
           16.150518143771055,
           16.167938304379447,
           16.18535846498784,
           16.20277862559623,
           16.22019878620462,
           16.237618946813015,
           16.255039107421403,
           16.27245926802979,
           16.289879428638187,
           16.307299589246576,
           16.32471974985497,
           16.34213991046336,
           16.35956007107175,
           16.376980231680143,
           16.394400392288535,
           16.411820552896923,
           16.42924071350532,
           16.446660874113707,
           16.4640810347221,
           16.48150119533049,
           16.498921355938883,
           16.51634151654727,
           16.533761677155663,
           16.551181837764055,
           16.568601998372447,
           16.586022158980835,
           16.607628859892376,
           16.633422101107072,
           16.65921534232176,
           16.68500858353645,
           16.710801824751144,
           16.736595065965833,
           16.762388307180526,
           16.78818154839522,
           16.81397478960991,
           16.839768030824597,
           16.86556127203929,
           16.891179868955938,
           16.91409157252825,
           16.937003276100562,
           16.959914979672874,
           16.982826683245182,
           17.005738386817495,
           17.02865009038981,
           17.05156179396212,
           17.074473497534427,
           17.097385201106743,
           17.120296904679055,
           17.143208608251364,
           17.166120311823676,
           17.18903201539599,
           17.2119437189683,
           17.234855422540612,
           17.257767126112928,
           17.280678829685236,
           17.303590533257548,
           17.32650223682986,
           17.349413940402176,
           17.37232564397448,
           17.395237347546793,
           17.418149051119105,
           17.441060754691417,
           17.46397245826373,
           17.48688416183604,
           17.50979586540835,
           17.532707568980662,
           17.555619272552978,
           17.578530976125286,
           17.6014426796976,
           17.62435438326991,
           17.647266086842226,
           17.670177790414535,
           17.693089493986847,
           17.716001197559162,
           17.73891290113147,
           17.76182460470378,
           17.784736308276095,
           17.807648011848404,
           17.830559715420716,
           17.853471418993028,
           17.876383122565343,
           17.899294826137652,
           17.922206529709964,
           17.945118233282276,
           17.968029936854588,
           17.9909416404269,
           18.013853343999212,
           18.036765047571524,
           18.059676751143833,
           18.082588454716145,
           18.105500158288457,
           18.128394303299352,
           18.151263572975793,
           18.17413284265223,
           18.19700211232866,
           18.219871382005103,
           18.24274065168154,
           18.265609921357974,
           18.28847919103441,
           18.311348460710846,
           18.334217730387284,
           18.357087000063718,
           18.37995626974016,
           18.40282553941659,
           18.425694809093027,
           18.448564078769465,
           18.471433348445903,
           18.49430261812234,
           18.517171887798774,
           18.54043241160643,
           18.56447544367652,
           18.58851847574661,
           18.612561507816704,
           18.636604539886793,
           18.660647571956883,
           18.68469060402698,
           18.70873363609707,
           18.732776668167155,
           18.75681970023725,
           18.78086273230734,
           18.80490576437743,
           18.828948796447524,
           18.852991828517613,
           18.877034860587706,
           18.901077892657796,
           18.92512092472789,
           18.949163956797978,
           18.97320698886807,
           18.99725002093816,
           19.021293053008257,
           19.045336085078343,
           19.069379117148436,
           19.093422149218526,
           19.117465181288615,
           19.14150821335871,
           19.1655512454288,
           19.18959427749889,
           19.21363730956898,
           19.237680341639074,
           19.261723373709163,
           19.285766405779256,
           19.309809437849346,
           19.333852469919435,
           19.35789550198953,
           19.38193853405962,
           19.40598156612971,
           19.4300245981998,
           19.454067630269897,
           19.478110662339986,
           19.502153694410076,
           19.526196726480165,
           19.55023975855026,
           19.57428279062035,
           19.59832582269044,
           19.62236885476053,
           19.646411886830624,
           19.670454918900713,
           19.694497950970803,
           19.718540983040896,
           19.742584015110985,
           19.766627047181075,
           19.79067007925117,
           19.81471311132126,
           19.83875614339135,
           19.862799175461443,
           19.886842207531537,
           19.910885239601626,
           19.934928271671716,
           19.95897130374181,
           19.9830143358119,
           20.00705736788199,
           20.03110039995208,
           20.05514343202217,
           20.079186464092263,
           20.103229496162356,
           20.127272528232446,
           20.151315560302535,
           20.17535859237263,
           20.19940162444272,
           20.22344465651281,
           20.2474876885829,
           20.271530720652994,
           20.295573752723083,
           20.319616784793173,
           20.343659816863266,
           20.367702848933362,
           20.391745881003445,
           20.415788913073538,
           20.43983194514363,
           20.463874977213724,
           20.487918009283813,
           20.51322495024896,
           20.515610193468955,
           20.399492041480165,
           20.263979426853606,
           20.110155863068048,
           19.956332299282526,
           19.802508735496968,
           19.64868517171142,
           19.49486160792589,
           19.34103804414034,
           19.187214480354783,
           19.03339091656926,
           18.879567352783706,
           18.72574378899815,
           18.571920225212597,
           18.418096661427075,
           18.264273097641517,
           18.110449533855967,
           17.95662597007044,
           17.802802406284886,
           17.648978842499332,
           17.495155278713806,
           17.341331714928252,
           17.187508151142698,
           17.033684587357172,
           16.879861023571618,
           16.726037459786067,
           16.572213896000513,
           16.418390332214987,
           16.264566768429432,
           16.110743204643878,
           15.956919640858354,
           15.8030960770728,
           15.649272513287245,
           15.495448949501721,
           15.341625385716167,
           15.187801821930613,
           15.03397825814506,
           14.880154694359536,
           14.726331130573982,
           14.572507566788428,
           14.418684003002902,
           14.264860439217347,
           14.111036875431795,
           13.957213311646269,
           13.803389747860715,
           13.649566184075162,
           13.495742620289636,
           13.341919056504084,
           13.18809549271853,
           13.034271928932975,
           12.880448365147451,
           12.726624801361897,
           12.572801237576343,
           12.418977673790817,
           12.265154110005263,
           12.11133054621971,
           11.957506982434184,
           11.80368341864863,
           11.649859854863077,
           11.496036291077523,
           11.342212727291999,
           11.188389163506445,
           11.034565599720892,
           10.880742035935366,
           10.726918472149812,
           10.573094908364258,
           10.419271344578732,
           10.26544778079318,
           10.111624217007627,
           9.957800653222101,
           9.803977089436547,
           9.650153525650992,
           9.49632996186544,
           9.342506398079916,
           9.188682834294362,
           9.034859270508807,
           8.881035706723281,
           8.727212142937727,
           8.573388579152173,
           8.419565015366649,
           8.265741451581095,
           8.11191788779554,
           7.945318036476206,
           7.771907907543802
          ],
          [
           13.087781753877364,
           13.103310371583905,
           13.118838989290445,
           13.134367606996987,
           13.149896224703529,
           13.16542484241007,
           13.180953460116612,
           13.196482077823152,
           13.212010695529694,
           13.227539313236235,
           13.243067930942777,
           13.258596548649317,
           13.274125166355859,
           13.2896537840624,
           13.305182401768942,
           13.320711019475482,
           13.336239637182022,
           13.351768254888565,
           13.367296872595105,
           13.382825490301649,
           13.398354108008188,
           13.41388272571473,
           13.42941134342127,
           13.444939961127812,
           13.460468578834352,
           13.475997196540895,
           13.491525814247435,
           13.507054431953975,
           13.522583049660518,
           13.53811166736706,
           13.553640285073602,
           13.569168902780142,
           13.584697520486682,
           13.600226138193225,
           13.615754755899765,
           13.631283373606307,
           13.646811991312848,
           13.662340609019388,
           13.677869226725932,
           13.693397844432472,
           13.708926462139013,
           13.724455079845555,
           13.739983697552095,
           13.755512315258636,
           13.771040932965178,
           13.786569550671718,
           13.80209816837826,
           13.817626786084801,
           13.833155403791341,
           13.848684021497883,
           13.864212639204425,
           13.879741256910966,
           13.895269874617508,
           13.910798492324048,
           13.926327110030588,
           13.94185572773713,
           13.957384345443671,
           13.972912963150213,
           13.988441580856755,
           14.003970198563296,
           14.019498816269838,
           14.03502743397638,
           14.050556051682921,
           14.06608466938946,
           14.081613287096001,
           14.097141904802543,
           14.112670522509084,
           14.128199140215626,
           14.145227770250528,
           14.163756410805961,
           14.18228505136139,
           14.20081369191682,
           14.21934233247225,
           14.23787097302768,
           14.256399613583111,
           14.274928254138542,
           14.293456894693971,
           14.3119855352494,
           14.330514175804833,
           14.349042816360264,
           14.367571456915693,
           14.386100097471124,
           14.404628738026554,
           14.423157378581985,
           14.441044230723676,
           14.458802725182625,
           14.476561219641571,
           14.494319714100518,
           14.512078208559466,
           14.529836703018411,
           14.547595197477358,
           14.565353691936306,
           14.583112186395253,
           14.6008706808542,
           14.618629175313146,
           14.636387669772093,
           14.65414616423104,
           14.671904658689986,
           14.689663153148935,
           14.70695508312581,
           14.721914185631512,
           14.736873288137215,
           14.751832390642917,
           14.766791493148622,
           14.781750595654323,
           14.796709698160026,
           14.81166880066573,
           14.826627903171433,
           14.841587005677138,
           14.856546108182838,
           14.871505210688541,
           14.886464313194244,
           14.901423415699949,
           14.916382518205651,
           14.931341620711354,
           14.946300723217057,
           14.96125982572276,
           14.976218928228462,
           14.991178030734165,
           15.006137133239868,
           15.021096235745572,
           15.036055338251275,
           15.051014440756978,
           15.06597354326268,
           15.080932645768383,
           15.095891748274088,
           15.110850850779793,
           15.125809953285495,
           15.140769055791196,
           15.1557281582969,
           15.170687260802604,
           15.185646363308306,
           15.200605465814009,
           15.21556456831971,
           15.230523670825413,
           15.245482773331116,
           15.260441875836818,
           15.275400978342521,
           15.290360080848226,
           15.305319183353928,
           15.32027828585963,
           15.335237388365336,
           15.350196490871038,
           15.36515559337674,
           15.380114695882444,
           15.395073798388147,
           15.41003290089385,
           15.424992003399552,
           15.439951105905255,
           15.454910208410958,
           15.469869310916662,
           15.484828413422365,
           15.499787515928066,
           15.514746618433767,
           15.529705720939472,
           15.544664823445176,
           15.559623925950879,
           15.574583028456582,
           15.589542130962284,
           15.604501233467987,
           15.619460335973692,
           15.634419438479394,
           15.649378540985097,
           15.6643376434908,
           15.679296745996503,
           15.694255848502205,
           15.709214951007908,
           15.727393142234757,
           15.747180877822178,
           15.766968613409597,
           15.786756348997018,
           15.80654408458444,
           15.826331820171859,
           15.84611955575928,
           15.865907291346701,
           15.885695026934119,
           15.905482762521538,
           15.925270498108961,
           15.94505823369638,
           15.9648459692838,
           15.984633704871221,
           16.004421440458643,
           16.02420917604606,
           16.04399691163348,
           16.063784647220903,
           16.08357238280832,
           16.10336011839574,
           16.123147853983163,
           16.14182143760441,
           16.1592415982128,
           16.176661758821194,
           16.194081919429586,
           16.211502080037974,
           16.22892224064637,
           16.246342401254758,
           16.263762561863153,
           16.28118272247154,
           16.29860288307993,
           16.316023043688325,
           16.333443204296714,
           16.350863364905106,
           16.368283525513498,
           16.385703686121886,
           16.40312384673028,
           16.42054400733867,
           16.437964167947065,
           16.455384328555454,
           16.472804489163845,
           16.490224649772237,
           16.507644810380626,
           16.52506497098902,
           16.54248513159741,
           16.5599052922058,
           16.577325452814193,
           16.594745613422585,
           16.612165774030974,
           16.62958593463937,
           16.647006095247757,
           16.664426255856146,
           16.68184641646454,
           16.699266577072933,
           16.716686737681325,
           16.734106898289713,
           16.751527058898105,
           16.7689472195065,
           16.786367380114886,
           16.80378754072328,
           16.821207701331673,
           16.83862786194006,
           16.856048022548453,
           16.873468183156845,
           16.890888343765234,
           16.90830850437363,
           16.925728664982017,
           16.94314882559041,
           16.9605689861988,
           16.977989146807193,
           16.995409307415585,
           17.012829468023977,
           17.03024962863237,
           17.047669789240757,
           17.06508994984915,
           17.08251011045754,
           17.099930271065933,
           17.117350431674325,
           17.134770592282713,
           17.152190752891105,
           17.169610913499497,
           17.18703107410789,
           17.204451234716277,
           17.226057935627818,
           17.25185117684251,
           17.277644418057204,
           17.303437659271893,
           17.32923090048659,
           17.355024141701275,
           17.380817382915964,
           17.40661062413066,
           17.43240386534535,
           17.45819710656004,
           17.483990347774732,
           17.50978358898942,
           17.535576830204118,
           17.561370071418807,
           17.587163312633496,
           17.61295655384819,
           17.63874979506288,
           17.66454303627757,
           17.690336277492264,
           17.71612951870695,
           17.741922759921643,
           17.767716001136336,
           17.79350924235103,
           17.819302483565718,
           17.84509572478041,
           17.8708889659951,
           17.896682207209793,
           17.922475448424485,
           17.94826868963917,
           17.974061930853864,
           17.999855172068557,
           18.02564841328325,
           18.051441654497935,
           18.07723489571263,
           18.102853495280293,
           18.125765198852605,
           18.148676902424913,
           18.171588605997226,
           18.194500309569538,
           18.217412013141846,
           18.240323716714162,
           18.263235420286474,
           18.286147123858782,
           18.309058827431095,
           18.33197053100341,
           18.35488223457572,
           18.37779393814803,
           18.400705641720343,
           18.423617345292655,
           18.446529048864967,
           18.46944075243728,
           18.49235245600959,
           18.515264159581903,
           18.538175863154216,
           18.561087566726528,
           18.583999270298836,
           18.606910973871152,
           18.62982267744346,
           18.652734381015776,
           18.675646084588085,
           18.698557788160397,
           18.72146949173271,
           18.74438119530502,
           18.76729289887733,
           18.79020460244964,
           18.813116306021954,
           18.836028009594266,
           18.858939713166578,
           18.881851416738886,
           18.904763120311202,
           18.927674823883514,
           18.950586527455823,
           18.973498231028135,
           18.996409934600447,
           19.01932163817276,
           19.04223334174507,
           19.065145045317383,
           19.08805674888969,
           19.110968452462004,
           19.13388015603432,
           19.15679185960663,
           19.17970356317894,
           19.202615266751252,
           19.224473787681134,
           19.244225943326143,
           19.263978098971158,
           19.28373025461617,
           19.303482410261186,
           19.323234565906198,
           19.342986721551213,
           19.36273887719623,
           19.38249103284124,
           19.402243188486256,
           19.42199534413127,
           19.441747499776284,
           19.461499655421292,
           19.481251811066308,
           19.50100396671132,
           19.520756122356335,
           19.540508278001347,
           19.560260433646363,
           19.58001258929138,
           19.59976474493639,
           19.619516900581406,
           19.639269056226418,
           19.659021211871433,
           19.67877336751645,
           19.69852552316146,
           19.71827767880647,
           19.739590012784426,
           19.763495345161644,
           19.787400677538862,
           19.811306009916077,
           19.835211342293295,
           19.85911667467051,
           19.883022007047728,
           19.906927339424946,
           19.93083267180216,
           19.95473800417938,
           19.978643336556594,
           20.002548668933812,
           20.02645400131103,
           20.050359333688245,
           20.074264666065464,
           20.09816999844268,
           20.122075330819897,
           20.145980663197115,
           20.169885995574333,
           20.193791327951548,
           20.217696660328766,
           20.241601992705984,
           20.2655073250832,
           20.289412657460417,
           20.313317989837632,
           20.337223322214847,
           20.361128654592065,
           20.385033986969287,
           20.4089393193465,
           20.432844651723716,
           20.456749984100934,
           20.48065531647815,
           20.504560648855367,
           20.528465981232586,
           20.552371313609804,
           20.57627664598702,
           20.600181978364237,
           20.62408731074145,
           20.647992643118666,
           20.671897975495884,
           20.695803307873106,
           20.719708640250317,
           20.743613972627536,
           20.767519305004754,
           20.791424637381972,
           20.815329969759187,
           20.839235302136405,
           20.86314063451362,
           20.887045966890835,
           20.910951299268053,
           20.93485663164527,
           20.958761964022486,
           20.982667296399704,
           21.006572628776922,
           21.030477961154137,
           21.05438329353135,
           21.07828862590857,
           21.07392786935342,
           20.92823666813642,
           20.782545466919423,
           20.636854265702425,
           20.491163064485455,
           20.345471863268457,
           20.199780662051463,
           20.05408946083449,
           19.908398259617492,
           19.762707058400498,
           19.617015857183528,
           19.471324655966534,
           19.325633454749536,
           19.179942253532538,
           19.034251052315568,
           18.88855985109857,
           18.742868649881572,
           18.597177448664603,
           18.451486247447605,
           18.305795046230607,
           18.16010384501364,
           18.014412643796643,
           17.868721442579645,
           17.723030241362675,
           17.577339040145677,
           17.43164783892868,
           17.285956637711685,
           17.134803994796616,
           16.980980431011062,
           16.827156867225508,
           16.673333303439982,
           16.519509739654428,
           16.365686175868873,
           16.211862612083348,
           16.058039048297797,
           15.90421548451224,
           15.750391920726688,
           15.596568356941162,
           15.442744793155608,
           15.288921229370056,
           15.13509766558453,
           14.981274101798975,
           14.827450538013423,
           14.673626974227897,
           14.519803410442345,
           14.36597984665679,
           14.212156282871264,
           14.05833271908571,
           13.904509155300156,
           13.750685591514603,
           13.596862027729077,
           13.443038463943523,
           13.28921490015797,
           13.135391336372445,
           12.98156777258689,
           12.827744208801338,
           12.673920645015812,
           12.506278980689597,
           12.324545575304592,
           12.142812169919587,
           11.961078764534616,
           11.779345359149612,
           11.597611953764607,
           11.415878548379636,
           11.234145142994633,
           11.052411737609628,
           10.870678332224657,
           10.688944926839651,
           10.507211521454646,
           10.325478116069675,
           10.143744710684672,
           9.962011305299667,
           9.780277899914662,
           9.59854449452969,
           9.416811089144687,
           9.235077683759684,
           9.05334427837471,
           8.871610872989706,
           8.689877467604703,
           8.508144062219731,
           8.326410656834726,
           8.144677251449721,
           7.962943846064717,
           7.781210440679747
          ],
          [
           13.557667854213282,
           13.573196471919822,
           13.588725089626363,
           13.604253707332903,
           13.619782325039445,
           13.635310942745988,
           13.650839560452527,
           13.666368178159068,
           13.681896795865612,
           13.697425413572152,
           13.712954031278695,
           13.728482648985235,
           13.744011266691775,
           13.759539884398318,
           13.775068502104858,
           13.790597119811398,
           13.80612573751794,
           13.821654355224481,
           13.837182972931025,
           13.852711590637565,
           13.868240208344105,
           13.883768826050645,
           13.899297443757186,
           13.914826061463728,
           13.93035467917027,
           13.945883296876811,
           13.961411914583353,
           13.976940532289895,
           13.992469149996435,
           14.007997767702978,
           14.023526385409518,
           14.03905500311606,
           14.0545836208226,
           14.070112238529141,
           14.085640856235683,
           14.101169473942223,
           14.116698091648766,
           14.132226709355304,
           14.14775532706185,
           14.163283944768388,
           14.178812562474931,
           14.194341180181471,
           14.209869797888013,
           14.225398415594555,
           14.240927033301093,
           14.256455651007636,
           14.271984268714176,
           14.28751288642072,
           14.30304150412726,
           14.318570121833801,
           14.334098739540343,
           14.349627358645808,
           14.368155999201237,
           14.386684639756666,
           14.405213280312099,
           14.423741920867528,
           14.442270561422959,
           14.46079920197839,
           14.479327842533817,
           14.49785648308925,
           14.516385123644678,
           14.534913764200109,
           14.553442404755542,
           14.57197104531097,
           14.590499685866401,
           14.60902832642183,
           14.62755696697726,
           14.646085607532692,
           14.664614248088121,
           14.683142888643552,
           14.70167152919898,
           14.72020016975441,
           14.73872881030984,
           14.757257450865273,
           14.775786091420702,
           14.794314731976133,
           14.812843372531562,
           14.831372013086993,
           14.849900653642424,
           14.868429294197854,
           14.886957934753283,
           14.905486575308714,
           14.924015215864143,
           14.942543856419574,
           14.960430708561269,
           14.978189203020216,
           14.995947697479162,
           15.01370619193811,
           15.031464686397056,
           15.049223180856002,
           15.066981675314949,
           15.084740169773898,
           15.102498664232844,
           15.120257158691793,
           15.138015653150736,
           15.155774147609684,
           15.173532642068633,
           15.191291136527578,
           15.209049630986526,
           15.226808125445471,
           15.244566619904418,
           15.262325114363367,
           15.280083608822313,
           15.297842103281258,
           15.315600597740206,
           15.333359092199153,
           15.351117586658102,
           15.368876081117048,
           15.386634575575993,
           15.40439307003494,
           15.422151564493888,
           15.439910058952833,
           15.45766855341178,
           15.475427047870728,
           15.493185542329675,
           15.510944036788622,
           15.526836271250776,
           15.541795373756475,
           15.556754476262181,
           15.571713578767884,
           15.586672681273587,
           15.60163178377929,
           15.616590886284992,
           15.631549988790695,
           15.646509091296398,
           15.661468193802103,
           15.676427296307805,
           15.691386398813508,
           15.706345501319209,
           15.721304603824914,
           15.736263706330616,
           15.751222808836319,
           15.766181911342022,
           15.781141013847725,
           15.79610011635343,
           15.811059218859132,
           15.826018321364835,
           15.840977423870537,
           15.85593652637624,
           15.870895628881943,
           15.885854731387646,
           15.900813833893348,
           15.915772936399051,
           15.930732038904754,
           15.945691141410457,
           15.96065024391616,
           15.975609346421866,
           15.990568448927569,
           16.00552755143327,
           16.020486653938974,
           16.035445756444677,
           16.05040485895038,
           16.06536396145608,
           16.080323063961785,
           16.095282166467488,
           16.11024126897319,
           16.125200371478893,
           16.140159473984596,
           16.1551185764903,
           16.170077678996,
           16.185036781501704,
           16.19999588400741,
           16.214954986513114,
           16.229914089018813,
           16.244873191524515,
           16.259832294030222,
           16.274791396535925,
           16.292969587762773,
           16.31275732335019,
           16.33254505893761,
           16.352332794525033,
           16.372120530112454,
           16.391908265699872,
           16.411696001287293,
           16.431483736874714,
           16.451271472462132,
           16.471059208049553,
           16.490846943636974,
           16.510634679224395,
           16.530422414811817,
           16.550210150399238,
           16.569997885986655,
           16.589785621574073,
           16.609573357161494,
           16.629361092748915,
           16.649148828336337,
           16.668936563923758,
           16.68872429951118,
           16.708512035098597,
           16.728299770686018,
           16.74808750627344,
           16.767875241860857,
           16.787662977448278,
           16.8074507130357,
           16.82723844862312,
           16.84702618421054,
           16.86681391979796,
           16.88660165538538,
           16.9063893909728,
           16.926177126560223,
           16.945964862147644,
           16.96575259773506,
           16.985540333322483,
           17.005328068909904,
           17.025115804497325,
           17.044903540084743,
           17.064691275672164,
           17.08447901125958,
           17.104266746847003,
           17.124054482434424,
           17.14349404672447,
           17.160914207332866,
           17.178334367941254,
           17.195754528549646,
           17.213174689158038,
           17.230594849766426,
           17.24801501037482,
           17.26543517098321,
           17.282855331591602,
           17.300275492199994,
           17.317695652808386,
           17.335115813416778,
           17.352535974025166,
           17.36995613463356,
           17.38737629524195,
           17.40479645585034,
           17.422216616458734,
           17.43963677706713,
           17.457056937675514,
           17.47447709828391,
           17.491897258892298,
           17.50931741950069,
           17.52673758010908,
           17.544157740717473,
           17.56157790132586,
           17.578998061934257,
           17.596418222542646,
           17.613838383151037,
           17.63125854375943,
           17.648678704367825,
           17.666098864976213,
           17.6835190255846,
           17.700939186192993,
           17.718359346801385,
           17.735779507409777,
           17.753199668018166,
           17.770619828626558,
           17.78803998923495,
           17.80546014984334,
           17.822880310451733,
           17.844487011363274,
           17.870280252577967,
           17.896073493792656,
           17.92186673500735,
           17.947659976222038,
           17.973453217436727,
           17.99924645865142,
           18.025039699866113,
           18.050832941080806,
           18.07662618229549,
           18.102419423510188,
           18.128212664724877,
           18.15400590593957,
           18.17979914715426,
           18.205592388368952,
           18.23138562958364,
           18.257178870798334,
           18.282972112013027,
           18.308765353227717,
           18.334558594442406,
           18.3603518356571,
           18.38614507687179,
           18.411938318086477,
           18.43773155930117,
           18.463524800515863,
           18.489318041730556,
           18.515111282945245,
           18.540904524159938,
           18.56669776537463,
           18.59249100658932,
           18.61828424780401,
           18.644077489018702,
           18.66987073023339,
           18.695663971448084,
           18.721457212662777,
           18.747250453877466,
           18.773043695092156,
           18.798836936306852,
           18.82463017752154,
           18.85042341873623,
           18.876216659950924,
           18.902009901165613,
           18.927803142380306,
           18.953596383595,
           18.97938962480969,
           19.005182866024377,
           19.03097610723907,
           19.056769348453763,
           19.082562589668456,
           19.10835583088314,
           19.134149072097834,
           19.159942313312527,
           19.18573555452722,
           19.211528795741906,
           19.237322036956602,
           19.26311527817129,
           19.288908519385984,
           19.31452712160466,
           19.337438825176967,
           19.360350528749283,
           19.383262232321595,
           19.406173935893904,
           19.429085639466216,
           19.45199734303853,
           19.47490904661084,
           19.497820750183152,
           19.520732453755464,
           19.543644157327776,
           19.56655586090008,
           19.589467564472397,
           19.612379268044712,
           19.635290971617025,
           19.658202675189333,
           19.681114378761645,
           19.704026082333957,
           19.726937785906266,
           19.74984948947858,
           19.77276119305089,
           19.795672896623202,
           19.818584600195514,
           19.84149630376783,
           19.86440800734014,
           19.88731971091245,
           19.90917823184233,
           19.928930387487345,
           19.948682543132357,
           19.96843469877737,
           19.988186854422388,
           20.007939010067396,
           20.02769116571241,
           20.047443321357427,
           20.067195477002436,
           20.08694763264745,
           20.106699788292467,
           20.12645194393748,
           20.14620409958249,
           20.165956255227506,
           20.18570841087252,
           20.205460566517534,
           20.22521272216255,
           20.24496487780756,
           20.264717033452577,
           20.284469189097585,
           20.3042213447426,
           20.323973500387616,
           20.34372565603263,
           20.363477811677644,
           20.383229967322656,
           20.40298212296767,
           20.422734278612687,
           20.442486434257695,
           20.46223858990271,
           20.481990745547726,
           20.50174290119274,
           20.52149505683775,
           20.541247212482766,
           20.56099936812778,
           20.58075152377279,
           20.60050367941781,
           20.62025583506282,
           20.640007990707833,
           20.65976014635285,
           20.67951230199786,
           20.699264457642876,
           20.719016613287884,
           20.7387687689329,
           20.758520924577915,
           20.77827308022293,
           20.798025235867946,
           20.81777739151296,
           20.83752954715797,
           20.857281702802982,
           20.877033858447998,
           20.89678601409301,
           20.916538169738025,
           20.93629032538304,
           20.956042481028057,
           20.975794636673065,
           20.99554679231808,
           21.01636470317508,
           21.040270035552293,
           21.064175367929508,
           21.088080700306726,
           21.111986032683944,
           21.13589136506116,
           21.15979669743838,
           21.183702029815592,
           21.20760736219281,
           21.23151269457003,
           21.255418026947247,
           21.279323359324458,
           21.303228691701676,
           21.327134024078898,
           21.351039356456113,
           21.374944688833327,
           21.398850021210546,
           21.42275535358776,
           21.44666068596498,
           21.470566018342197,
           21.49447135071941,
           21.518376683096626,
           21.542282015473845,
           21.566187347851063,
           21.59009268022828,
           21.613998012605496,
           21.637903344982718,
           21.63354258842756,
           21.48785138721056,
           21.342160185993563,
           21.19646898477657,
           21.0507777835596,
           20.9050865823426,
           20.759395381125604,
           20.613704179908638,
           20.468012978691632,
           20.32232177747464,
           20.176630576257672,
           20.030939375040674,
           19.885248173823676,
           19.739556972606678,
           19.59386577138971,
           19.44817457017271,
           19.302483368955713,
           19.156792167738743,
           19.011100966521745,
           18.86540976530475,
           18.71971856408778,
           18.57402736287078,
           18.428336161653785,
           18.282644960436812,
           18.136953759219818,
           17.991262558002823,
           17.845571356785825,
           17.699880155568856,
           17.536890893875075,
           17.364162387448694,
           17.19143388102234,
           17.01870537459596,
           16.84597686816958,
           16.673248361743227,
           16.500519855316846,
           16.327791348890464,
           16.155062842464083,
           15.98233433603773,
           15.80960582961135,
           15.636877323184965,
           15.464148816758616,
           15.291420310332233,
           15.11869180390585,
           14.945963297479501,
           14.773234791053119,
           14.600506284626736,
           14.427777778200387,
           14.255049271774006,
           14.082320765347623,
           13.90959225892124,
           13.736863752494891,
           13.564135246068508,
           13.391406739642125,
           13.218678233215776,
           13.045949726789393,
           12.87322122036301,
           12.695748197153488,
           12.514014791768485,
           12.33228138638348,
           12.150547980998477,
           11.968814575613505,
           11.787081170228502,
           11.605347764843495,
           11.423614359458524,
           11.24188095407352,
           11.060147548688516,
           10.878414143303544,
           10.69668073791854,
           10.514947332533534,
           10.333213927148565,
           10.151480521763558,
           9.969747116378555,
           9.788013710993551,
           9.606280305608578,
           9.424546900223575,
           9.24281349483857,
           9.061080089453599,
           8.879346684068594,
           8.69761327868359,
           8.51587987329862,
           8.334146467913614,
           8.152413062528609,
           7.970679657143606,
           7.7889462517586345
          ],
          [
           14.02755395454919,
           14.04308257225573,
           14.05861118996227,
           14.074139807668814,
           14.089668425375354,
           14.105197043081894,
           14.120725660788436,
           14.136254278494977,
           14.151782896201519,
           14.16731151390806,
           14.182840131614602,
           14.198368749321144,
           14.213897367027682,
           14.229425984734227,
           14.244954602440767,
           14.260483220147307,
           14.276011837853849,
           14.29154045556039,
           14.307069073266932,
           14.322597690973474,
           14.338126308680014,
           14.353654926386554,
           14.369183544093096,
           14.384712161799637,
           14.400240779506177,
           14.41576939721272,
           14.431298014919262,
           14.446826632625802,
           14.462355250332344,
           14.477883868038885,
           14.493412485745425,
           14.508941103451967,
           14.524469721158507,
           14.53999833886505,
           14.555526956571592,
           14.572555587596504,
           14.591084228151935,
           14.609612868707362,
           14.628141509262797,
           14.646670149818224,
           14.665198790373655,
           14.683727430929084,
           14.702256071484513,
           14.720784712039944,
           14.739313352595374,
           14.757841993150805,
           14.776370633706234,
           14.794899274261665,
           14.813427914817094,
           14.831956555372525,
           14.850485195927956,
           14.869013836483386,
           14.887542477038817,
           14.906071117594248,
           14.924599758149677,
           14.943128398705106,
           14.961657039260539,
           14.980185679815968,
           14.998714320371395,
           15.017242960926827,
           15.035771601482256,
           15.054300242037687,
           15.07282888259312,
           15.091357523148549,
           15.10988616370398,
           15.128414804259409,
           15.146943444814838,
           15.16547208537027,
           15.1840007259257,
           15.20252936648113,
           15.22105800703656,
           15.239586647591992,
           15.258115288147419,
           15.276643928702851,
           15.29517256925828,
           15.313701209813711,
           15.33222985036914,
           15.350758490924571,
           15.369287131480002,
           15.387815772035433,
           15.406344412590862,
           15.424873053146293,
           15.443401693701723,
           15.461930334257152,
           15.479817186398847,
           15.497575680857796,
           15.515334175316742,
           15.533092669775689,
           15.550851164234635,
           15.56860965869358,
           15.586368153152529,
           15.604126647611476,
           15.621885142070424,
           15.639643636529371,
           15.657402130988316,
           15.675160625447262,
           15.692919119906211,
           15.710677614365157,
           15.728436108824106,
           15.74619460328305,
           15.763953097741998,
           15.781711592200946,
           15.799470086659891,
           15.817228581118837,
           15.834987075577784,
           15.852745570036733,
           15.87050406449568,
           15.888262558954626,
           15.906021053413575,
           15.92377954787252,
           15.941538042331466,
           15.959296536790415,
           15.97705503124936,
           15.994813525708306,
           16.012572020167255,
           16.0303305146262,
           16.04808900908515,
           16.065847503544095,
           16.083605998003044,
           16.10136449246199,
           16.119122986920935,
           16.13688148137988,
           16.15463997583883,
           16.172398470297775,
           16.190156964756724,
           16.20791545921567,
           16.22567395367462,
           16.243432448133564,
           16.26119094259251,
           16.27894943705146,
           16.296707931510404,
           16.314466425969353,
           16.331758356870026,
           16.34671745937573,
           16.36167656188143,
           16.376635664387134,
           16.391594766892837,
           16.40655386939854,
           16.421512971904242,
           16.43647207440995,
           16.451431176915648,
           16.466390279421354,
           16.481349381927053,
           16.49630848443276,
           16.51126758693846,
           16.526226689444165,
           16.541185791949868,
           16.55614489445557,
           16.571103996961273,
           16.586063099466976,
           16.60102220197268,
           16.61598130447838,
           16.630940406984084,
           16.645899509489787,
           16.660858611995494,
           16.675817714501193,
           16.6907768170069,
           16.7057359195126,
           16.720695022018305,
           16.735654124524004,
           16.75061322702971,
           16.76557232953541,
           16.780531432041116,
           16.795490534546815,
           16.81044963705252,
           16.825408739558224,
           16.840367842063927,
           16.85854603329077,
           16.878333768878193,
           16.898121504465614,
           16.917909240053035,
           16.937696975640456,
           16.957484711227877,
           16.9772724468153,
           16.997060182402716,
           17.016847917990138,
           17.036635653577555,
           17.05642338916498,
           17.076211124752398,
           17.09599886033982,
           17.11578659592724,
           17.13557433151466,
           17.155362067102082,
           17.1751498026895,
           17.194937538276918,
           17.214725273864342,
           17.23451300945176,
           17.25430074503918,
           17.274088480626602,
           17.29387621621402,
           17.31366395180144,
           17.333451687388862,
           17.353239422976284,
           17.3730271585637,
           17.392814894151122,
           17.412602629738544,
           17.432390365325965,
           17.452178100913386,
           17.471965836500807,
           17.491753572088225,
           17.511541307675646,
           17.531329043263064,
           17.551116778850485,
           17.570904514437906,
           17.590692250025327,
           17.61047998561275,
           17.63026772120017,
           17.650055456787587,
           17.669843192375005,
           17.689630927962426,
           17.709418663549847,
           17.72920639913727,
           17.74899413472469,
           17.768781870312107,
           17.78856960589953,
           17.80835734148695,
           17.82814507707437,
           17.84793281266179,
           17.86772054824921,
           17.887508283836627,
           17.907296019424052,
           17.92708375501147,
           17.94687149059889,
           17.966659226186312,
           17.98644696177373,
           18.006234697361155,
           18.026022432948572,
           18.045810168535997,
           18.065597904123415,
           18.085385639710836,
           18.105173375298254,
           18.124961110885675,
           18.144748846473096,
           18.162586816452915,
           18.180006977061304,
           18.1974271376697,
           18.214847298278087,
           18.23226745888648,
           18.24968761949487,
           18.267107780103263,
           18.28452794071165,
           18.301948101320047,
           18.319368261928435,
           18.336788422536827,
           18.35420858314522,
           18.371628743753607,
           18.389048904362,
           18.40646906497039,
           18.423889225578783,
           18.441309386187175,
           18.462916087098716,
           18.48870932831341,
           18.514502569528098,
           18.54029581074279,
           18.56608905195748,
           18.59188229317217,
           18.617675534386862,
           18.643468775601555,
           18.669262016816248,
           18.695055258030937,
           18.72084849924563,
           18.74664174046032,
           18.772434981675012,
           18.7982282228897,
           18.824021464104394,
           18.849814705319083,
           18.875607946533773,
           18.90140118774847,
           18.92719442896316,
           18.952987670177848,
           18.97878091139254,
           19.004574152607233,
           19.03036739382192,
           19.056160635036612,
           19.081953876251305,
           19.107747117465998,
           19.133540358680687,
           19.15933359989538,
           19.185126841110073,
           19.21092008232476,
           19.23671332353945,
           19.262506564754144,
           19.288299805968833,
           19.314093047183526,
           19.33988628839822,
           19.365679529612912,
           19.391472770827598,
           19.41726601204229,
           19.443059253256983,
           19.468852494471676,
           19.49464573568637,
           19.520438976901055,
           19.546232218115748,
           19.57202545933044,
           19.597818700545133,
           19.62361194175982,
           19.64940518297451,
           19.675198424189205,
           19.700991665403894,
           19.726784906618587,
           19.752578147833276,
           19.77837138904797,
           19.80416463026266,
           19.829957871477355,
           19.855751112692044,
           19.881544353906733,
           19.907337595121422,
           19.933130836336115,
           19.958924077550808,
           19.984717318765497,
           20.01051055998019,
           20.03630380119488,
           20.062097042409572,
           20.087890283624265,
           20.113683524838954,
           20.139476766053644,
           20.16527000726834,
           20.19106324848303,
           20.21685648969772,
           20.24264973091241,
           20.2684429721271,
           20.294236213341797,
           20.320029454556483,
           20.345822695771176,
           20.37161593698587,
           20.397409178200558,
           20.423202419415247,
           20.44899566062994,
           20.47478890184463,
           20.500582143059326,
           20.526200747929014,
           20.549112451501326,
           20.572024155073635,
           20.593882676003517,
           20.613634831648525,
           20.63338698729354,
           20.653139142938556,
           20.67289129858357,
           20.69264345422858,
           20.712395609873596,
           20.73214776551861,
           20.75189992116362,
           20.771652076808635,
           20.79140423245365,
           20.811156388098663,
           20.830908543743675,
           20.850660699388694,
           20.870412855033706,
           20.890165010678718,
           20.909917166323734,
           20.929669321968746,
           20.949421477613758,
           20.969173633258777,
           20.988925788903785,
           21.0086779445488,
           21.028430100193813,
           21.048182255838828,
           21.06793441148384,
           21.087686567128856,
           21.10743872277387,
           21.127190878418883,
           21.1469430340639,
           21.16669518970891,
           21.186447345353926,
           21.206199500998935,
           21.22595165664395,
           21.245703812288966,
           21.265455967933974,
           21.28520812357899,
           21.30496027922401,
           21.32471243486902,
           21.34446459051403,
           21.364216746159048,
           21.38396890180406,
           21.403721057449076,
           21.423473213094084,
           21.4432253687391,
           21.462977524384115,
           21.482549180308357,
           21.501759860377728,
           21.520970540447095,
           21.540181220516466,
           21.559391900585837,
           21.578602580655208,
           21.597813260724575,
           21.617023940793946,
           21.636234620863316,
           21.655445300932683,
           21.674655981002054,
           21.693866661071425,
           21.713077341140796,
           21.732288021210167,
           21.751498701279534,
           21.7707093813489,
           21.78992006141827,
           21.809130741487643,
           21.828341421557013,
           21.84755210162638,
           21.86676278169575,
           21.885973461765122,
           21.905184141834493,
           21.92439482190386,
           21.94360550197323,
           21.9628161820426,
           21.98202686211197,
           22.001237542181343,
           22.02044822225071,
           22.039658902320078,
           22.05886958238945,
           22.07808026245882,
           22.097290942528186,
           22.116501622597557,
           22.135712302666928,
           22.1549229827363,
           22.17413366280567,
           22.193344342875037,
           22.180312913937403,
           22.006070939964758,
           21.83182896599211,
           21.657866824564664,
           21.48513831813831,
           21.31240981171193,
           21.139681305285546,
           20.9669527988592,
           20.79422429243282,
           20.621495786006435,
           20.448767279580085,
           20.276038773153704,
           20.10331026672732,
           19.93058176030094,
           19.75785325387459,
           19.585124747448205,
           19.412396241021824,
           19.23966773459547,
           19.06693922816909,
           18.89421072174271,
           18.721482215316357,
           18.548753708889976,
           18.376025202463595,
           18.203296696037242,
           18.03056818961086,
           17.85783968318448,
           17.685111176758095,
           17.512382670331746,
           17.339654163905365,
           17.166925657478984,
           16.99419715105263,
           16.82146864462625,
           16.64874013819987,
           16.476011631773517,
           16.30328312534714,
           16.130554618920755,
           15.957826112494374,
           15.785097606068025,
           15.612369099641642,
           15.439640593215259,
           15.266912086788906,
           15.094183580362525,
           14.921455073936144,
           14.748726567509792,
           14.57599806108341,
           14.403269554657028,
           14.230541048230677,
           14.057812541804298,
           13.885084035377915,
           13.712355528951534,
           13.539627022525181,
           13.3668985160988,
           13.194170009672417,
           13.021441503246066,
           12.848712996819685,
           12.675984490393303,
           12.503255983966952,
           12.33052747754057,
           12.15779897111419,
           11.985070464687809,
           11.812341958261458,
           11.639613451835075,
           11.466884945408694,
           11.294156438982343,
           11.12142793255596,
           10.94869942612958,
           10.775970919703228,
           10.603242413276845,
           10.430513906850464,
           10.257785400424115,
           10.08505689399773,
           9.91232838757135,
           9.739599881144967,
           9.566871374718616,
           9.394142868292235,
           9.221414361865852,
           9.048685855439501,
           8.87595734901312,
           8.703228842586737,
           8.530500336160388,
           8.357771829734006,
           8.170133872127927,
           7.982219094476834,
           7.794304316825775
          ],
          [
           14.497440054885107,
           14.512968672591647,
           14.528497290298189,
           14.54402590800473,
           14.55955452571127,
           14.575083143417812,
           14.590611761124352,
           14.606140378830894,
           14.621668996537435,
           14.637197614243977,
           14.652726231950519,
           14.66825484965706,
           14.6837834673636,
           14.699312085070142,
           14.714840702776684,
           14.730369320483225,
           14.745897938189765,
           14.761426555896307,
           14.776955175991777,
           14.795483816547208,
           14.814012457102638,
           14.832541097658073,
           14.8510697382135,
           14.86959837876893,
           14.888127019324362,
           14.906655659879792,
           14.925184300435221,
           14.94371294099065,
           14.962241581546081,
           14.980770222101512,
           14.999298862656943,
           15.017827503212372,
           15.036356143767803,
           15.054884784323232,
           15.073413424878664,
           15.091942065434093,
           15.110470705989524,
           15.128999346544955,
           15.147527987100386,
           15.166056627655815,
           15.184585268211244,
           15.203113908766676,
           15.221642549322105,
           15.240171189877536,
           15.258699830432967,
           15.277228470988394,
           15.295757111543825,
           15.314285752099256,
           15.332814392654686,
           15.351343033210116,
           15.369871673765548,
           15.388400314320977,
           15.406928954876406,
           15.425457595431837,
           15.443986235987268,
           15.462514876542699,
           15.48104351709813,
           15.49957215765356,
           15.51810079820899,
           15.536629438764418,
           15.555158079319849,
           15.57368671987528,
           15.59221536043071,
           15.61074400098614,
           15.629272641541569,
           15.647801282097,
           15.666329922652428,
           15.684858563207861,
           15.70338720376329,
           15.72191584431872,
           15.74044448487415,
           15.75897312542958,
           15.777501765985011,
           15.796030406540442,
           15.814559047095871,
           15.833087687651304,
           15.851616328206733,
           15.870144968762162,
           15.888673609317593,
           15.907202249873023,
           15.925730890428454,
           15.944259530983883,
           15.962788171539314,
           15.981316812094743,
           15.999203664236438,
           16.016962158695385,
           16.03472065315433,
           16.05247914761328,
           16.070237642072225,
           16.08799613653117,
           16.105754630990116,
           16.123513125449065,
           16.141271619908014,
           16.15903011436696,
           16.176788608825905,
           16.194547103284854,
           16.2123055977438,
           16.23006409220275,
           16.247822586661695,
           16.26558108112064,
           16.28333957557959,
           16.301098070038535,
           16.31885656449748,
           16.336615058956426,
           16.354373553415375,
           16.37213204787432,
           16.38989054233327,
           16.407649036792215,
           16.425407531251164,
           16.44316602571011,
           16.460924520169055,
           16.478683014628004,
           16.49644150908695,
           16.5142000035459,
           16.531958498004844,
           16.54971699246379,
           16.56747548692274,
           16.585233981381684,
           16.60299247584063,
           16.62075097029958,
           16.638509464758524,
           16.656267959217473,
           16.67402645367642,
           16.691784948135364,
           16.709543442594317,
           16.727301937053262,
           16.745060431512208,
           16.762818925971153,
           16.7805774204301,
           16.798335914889048,
           16.816094409347997,
           16.833852903806942,
           16.851611398265888,
           16.869369892724833,
           16.88712838718378,
           16.904886881642724,
           16.922645376101677,
           16.940403870560623,
           16.958162365019568,
           16.975920859478514,
           16.99367935393746,
           17.01143784839641,
           17.029196342855357,
           17.046954837314303,
           17.06471333177325,
           17.082471826232197,
           17.100230320691146,
           17.117988815150092,
           17.135747309609037,
           17.151639544994993,
           17.16659864750069,
           17.181557750006398,
           17.196516852512097,
           17.2114759550178,
           17.226435057523503,
           17.241394160029206,
           17.25635326253491,
           17.271312365040615,
           17.286271467546314,
           17.30123057005202,
           17.316189672557723,
           17.331148775063426,
           17.34610787756913,
           17.36106698007483,
           17.376026082580534,
           17.390985185086237,
           17.40594428759194,
           17.42412247881879,
           17.44391021440621,
           17.46369794999363,
           17.483485685581048,
           17.50327342116847,
           17.52306115675589,
           17.54284889234331,
           17.562636627930733,
           17.58242436351815,
           17.60221209910557,
           17.621999834692993,
           17.641787570280414,
           17.66157530586783,
           17.681363041455253,
           17.70115077704267,
           17.72093851263009,
           17.740726248217513,
           17.760513983804934,
           17.780301719392355,
           17.800089454979776,
           17.819877190567194,
           17.83966492615462,
           17.859452661742036,
           17.879240397329458,
           17.899028132916875,
           17.918815868504296,
           17.938603604091718,
           17.95839133967914,
           17.978179075266556,
           17.997966810853974,
           18.017754546441395,
           18.03754228202882,
           18.057330017616238,
           18.07711775320366,
           18.09690548879108,
           18.1166932243785,
           18.136480959965922,
           18.15626869555334,
           18.17605643114076,
           18.19584416672818,
           18.2156319023156,
           18.23541963790302,
           18.255207373490443,
           18.27499510907786,
           18.294782844665285,
           18.314570580252706,
           18.334358315840124,
           18.354146051427545,
           18.373933787014966,
           18.393721522602384,
           18.413509258189805,
           18.433296993777226,
           18.453084729364644,
           18.472872464952065,
           18.492660200539486,
           18.512447936126907,
           18.532235671714325,
           18.552023407301746,
           18.571811142889167,
           18.59159887847659,
           18.611386614064006,
           18.63117434965143,
           18.65096208523885,
           18.67074982082627,
           18.690537556413688,
           18.71032529200111,
           18.73011302758853,
           18.74990076317595,
           18.769688498763372,
           18.78996219836753,
           18.81047887664241,
           18.830995554917294,
           18.851512233192175,
           18.87202891146706,
           18.89254558974194,
           18.91306226801682,
           18.933578946291703,
           18.954095624566584,
           18.974612302841468,
           18.99512898111635,
           19.015645659391232,
           19.036162337666116,
           19.056679015940997,
           19.081003209958663,
           19.109134919719107,
           19.13726662947956,
           19.165398339240003,
           19.193530049000458,
           19.2216617587609,
           19.24979346852135,
           19.277925178281794,
           19.305159963990686,
           19.331427473129636,
           19.357694982268587,
           19.38396249140754,
           19.410230000546495,
           19.43649750968544,
           19.462765018824395,
           19.489032527963346,
           19.515300037102296,
           19.54156754624125,
           19.5678350553802,
           19.594102564519147,
           19.6203700736581,
           19.64663758279706,
           19.672905091936002,
           19.699172601074956,
           19.72544011021391,
           19.751707619352864,
           19.77797512849181,
           19.80424263763076,
           19.830510146769715,
           19.85677765590866,
           19.88304516504762,
           19.909312674186573,
           19.935580183325516,
           19.96184769246447,
           19.98811520160342,
           20.014382710742375,
           20.04065021988132,
           20.066917729020275,
           20.093185238159226,
           20.119452747298176,
           20.14572025643713,
           20.17198776557608,
           20.198255274715034,
           20.224522783853985,
           20.25079029299294,
           20.277057802131885,
           20.303325311270836,
           20.32959282040979,
           20.35586032954874,
           20.382127838687687,
           20.408395347826648,
           20.434662856965595,
           20.460930366104545,
           20.487197875243503,
           20.51346538438245,
           20.539732893521396,
           20.56600040266035,
           20.592267911799304,
           20.618535420938258,
           20.644802930077205,
           20.67107043921616,
           20.697337948355113,
           20.72360545749406,
           20.749872966633014,
           20.776140475771964,
           20.802407984910914,
           20.828675494049868,
           20.854943003188822,
           20.88121051232777,
           20.907478021466723,
           20.933745530605677,
           20.960013039744624,
           20.986280548883578,
           21.012548058022524,
           21.03881556716148,
           21.065083076300425,
           21.09135058543938,
           21.117618094578333,
           21.14388560371728,
           21.170153112856234,
           21.196420621995188,
           21.222688131134134,
           21.24895564027309,
           21.270771168121517,
           21.2836827333889,
           21.29659429865628,
           21.30950586392367,
           21.322417429191052,
           21.335328994458433,
           21.348240559725816,
           21.3611521249932,
           21.374063690260584,
           21.386975255527968,
           21.399886820795352,
           21.412798386062736,
           21.42570995133012,
           21.4386215165975,
           21.451533081864884,
           21.464444647132268,
           21.477356212399652,
           21.490267777667036,
           21.503179342934416,
           21.516090908201804,
           21.529002473469188,
           21.541914038736568,
           21.554825604003952,
           21.56773716927134,
           21.58064873453872,
           21.593560299806104,
           21.606471865073487,
           21.619383430340868,
           21.635182080278476,
           21.65439276034784,
           21.673603440417214,
           21.69281412048658,
           21.71202480055595,
           21.731235480625323,
           21.750446160694693,
           21.769656840764057,
           21.78886752083343,
           21.808078200902806,
           21.82728888097217,
           21.84649956104154,
           21.86571024111091,
           21.884920921180278,
           21.904131601249652,
           21.92334228131902,
           21.94255296138839,
           21.961763641457758,
           21.980974321527132,
           22.000185001596495,
           22.01939568166587,
           22.03860636173524,
           22.057817041804604,
           22.07702772187398,
           22.09623840194335,
           22.115449082012717,
           22.134659762082087,
           22.153870442151458,
           22.17308112222083,
           22.192291802290192,
           22.211502482359567,
           22.230713162428938,
           22.2499238424983,
           22.269134522567676,
           22.288345202637046,
           22.307555882706414,
           22.326766562775788,
           22.345977242845155,
           22.365187922914522,
           22.38439860298389,
           22.403609283053264,
           22.42281996312263,
           22.442030643192002,
           22.461241323261373,
           22.480452003330743,
           22.499662683400107,
           22.518873363469478,
           22.538084043538852,
           22.55729472360822,
           22.576505403677587,
           22.595716083746957,
           22.614926763816328,
           22.6341374438857,
           22.653348123955066,
           22.672558804024437,
           22.659527375086803,
           22.485285401114155,
           22.311043427141513,
           22.136801453168868,
           21.96255947919626,
           21.78831750522361,
           21.61407553125097,
           21.439833557278355,
           21.26559158330571,
           21.091349609333065,
           20.917107635360452,
           20.742865661387807,
           20.568623687415162,
           20.39438171344252,
           20.220139739469907,
           20.045897765497262,
           19.871655791524617,
           19.697413817552007,
           19.523171843579362,
           19.348929869606717,
           19.174687895634104,
           19.00044592166146,
           18.826203947688814,
           18.651961973716205,
           18.477719999743556,
           18.30347802577091,
           18.12923605179827,
           17.954994077825656,
           17.78075210385301,
           17.60651012988037,
           17.432268155907757,
           17.25802618193511,
           17.08378420796247,
           16.910354148685244,
           16.73762564225886,
           16.564897135832474,
           16.392168629406093,
           16.219440122979744,
           16.04671161655336,
           15.873983110126979,
           15.70125460370063,
           15.528526097274247,
           15.355797590847864,
           15.183069084421515,
           15.010340577995132,
           14.83761207156875,
           14.6648835651424,
           14.492155058716019,
           14.319426552289638,
           14.146698045863257,
           13.973969539436904,
           13.79167054259452,
           13.603755764943426,
           13.415840987292366,
           13.227926209641272,
           13.040011431990179,
           12.852096654339121,
           12.664181876688028,
           12.476267099036935,
           12.28835232138584,
           12.100437543734781,
           11.912522766083686,
           11.724607988432593,
           11.536693210781534,
           11.348778433130443,
           11.160863655479346,
           10.97294887782829,
           10.785034100177196,
           10.597119322526101,
           10.409204544875042,
           10.221289767223947,
           10.033374989572856,
           9.845460211921761,
           9.657545434270704,
           9.469630656619609,
           9.281715878968516,
           9.093801101317457,
           8.905886323666364,
           8.71797154601527,
           8.530056768364211,
           8.342141990713117,
           8.154227213062024,
           7.966312435410929,
           7.7783976577598715
          ],
          [
           14.967326155221023,
           14.982854772927565,
           14.999883404942485,
           15.018412045497914,
           15.036940686053345,
           15.055469326608776,
           15.073997967164207,
           15.092526607719636,
           15.111055248275067,
           15.129583888830497,
           15.148112529385928,
           15.166641169941357,
           15.185169810496788,
           15.203698451052219,
           15.222227091607648,
           15.240755732163079,
           15.259284372718508,
           15.277813013273938,
           15.29634165382937,
           15.314870294384798,
           15.333398934940229,
           15.35192757549566,
           15.370456216051089,
           15.38898485660652,
           15.407513497161949,
           15.426042137717381,
           15.444570778272812,
           15.46309941882824,
           15.481628059383672,
           15.500156699939101,
           15.518685340494532,
           15.537213981049963,
           15.55574262160539,
           15.574271262160822,
           15.592799902716251,
           15.611328543271682,
           15.629857183827113,
           15.64838582438254,
           15.666914464937975,
           15.685443105493402,
           15.703971746048833,
           15.722500386604263,
           15.741029027159694,
           15.759557667715125,
           15.778086308270554,
           15.796614948825983,
           15.815143589381416,
           15.833672229936846,
           15.852200870492275,
           15.870729511047703,
           15.889258151603135,
           15.907786792158568,
           15.926315432713995,
           15.944844073269426,
           15.963372713824855,
           15.981901354380287,
           16.000429994935715,
           16.018958635491146,
           16.037487276046576,
           16.056015916602007,
           16.074544557157438,
           16.09307319771287,
           16.1116018382683,
           16.13013047882373,
           16.148659119379158,
           16.167187759934592,
           16.18571640049002,
           16.20424504104545,
           16.22277368160088,
           16.24130232215631,
           16.259830962711742,
           16.27835960326717,
           16.2968882438226,
           16.31541688437803,
           16.333945524933462,
           16.352474165488893,
           16.37100280604432,
           16.38953144659975,
           16.40806008715518,
           16.426588727710612,
           16.445117368266043,
           16.463646008821474,
           16.482174649376905,
           16.500703289932336,
           16.518590142074025,
           16.536348636532974,
           16.55410713099192,
           16.57186562545087,
           16.589624119909814,
           16.607382614368763,
           16.62514110882771,
           16.642899603286654,
           16.660658097745603,
           16.67841659220455,
           16.696175086663498,
           16.713933581122443,
           16.73169207558139,
           16.749450570040338,
           16.767209064499283,
           16.784967558958233,
           16.802726053417178,
           16.820484547876124,
           16.838243042335073,
           16.856001536794018,
           16.873760031252964,
           16.89151852571191,
           16.909277020170858,
           16.927035514629807,
           16.944794009088753,
           16.9625525035477,
           16.980310998006647,
           16.998069492465593,
           17.015827986924542,
           17.033586481383487,
           17.051344975842433,
           17.069103470301382,
           17.086861964760327,
           17.104620459219277,
           17.122378953678222,
           17.140137448137168,
           17.157895942596117,
           17.175654437055062,
           17.19341293151401,
           17.211171425972957,
           17.228929920431902,
           17.246688414890848,
           17.264446909349797,
           17.282205403808742,
           17.29996389826769,
           17.317722392726637,
           17.335480887185582,
           17.353239381644528,
           17.370997876103477,
           17.388756370562426,
           17.40651486502137,
           17.424273359480317,
           17.442031853939266,
           17.45979034839821,
           17.47754884285716,
           17.495307337316106,
           17.51306583177505,
           17.530824326234,
           17.548582820692946,
           17.56634131515189,
           17.58409980961084,
           17.601858304069786,
           17.61961679852873,
           17.63737529298768,
           17.655133787446626,
           17.672892281905575,
           17.69065077636452,
           17.708409270823466,
           17.726167765282415,
           17.74392625974136,
           17.76168475420031,
           17.779443248659256,
           17.7972017431182,
           17.81496023757715,
           17.832718732036096,
           17.85047722649504,
           17.86823572095399,
           17.885994215412936,
           17.90375270987188,
           17.92151120433083,
           17.93926969878978,
           17.95656163061425,
           17.971520733119952,
           17.989698924346804,
           18.009486659934222,
           18.029274395521643,
           18.049062131109064,
           18.068849866696485,
           18.088637602283903,
           18.109093538020986,
           18.129610216295866,
           18.15012689457075,
           18.17064357284563,
           18.191160251120515,
           18.21167692939539,
           18.232193607670276,
           18.252710285945156,
           18.273226964220044,
           18.293743642494924,
           18.314260320769808,
           18.334776999044685,
           18.355293677319573,
           18.37581035559445,
           18.396327033869333,
           18.416843712144217,
           18.437360390419094,
           18.457877068693982,
           18.478393746968862,
           18.498910425243743,
           18.519427103518623,
           18.539943781793507,
           18.560460460068388,
           18.580977138343272,
           18.601493816618156,
           18.622010494893036,
           18.642527173167917,
           18.6630438514428,
           18.68356052971768,
           18.70407720799256,
           18.72459388626745,
           18.745110564542326,
           18.76562724281721,
           18.78614392109209,
           18.80666059936697,
           18.827177277641855,
           18.84769395591674,
           18.86821063419162,
           18.888727312466504,
           18.909243990741388,
           18.929760669016265,
           18.950277347291145,
           18.97079402556603,
           18.99131070384091,
           19.011827382115793,
           19.032344060390677,
           19.052860738665558,
           19.07337741694044,
           19.09389409521532,
           19.114410773490203,
           19.134927451765087,
           19.155444130039967,
           19.175960808314848,
           19.196477486589732,
           19.216994164864612,
           19.237510843139496,
           19.258027521414377,
           19.278544199689257,
           19.29906087796414,
           19.31957755623902,
           19.340094234513906,
           19.36061091278879,
           19.38112759106367,
           19.40164426933855,
           19.42216094761343,
           19.442677625888315,
           19.463194304163196,
           19.48371098243808,
           19.50422766071296,
           19.524744338987844,
           19.545261017262725,
           19.56577769553761,
           19.58629437381249,
           19.60681105208737,
           19.627327730362254,
           19.647844408637134,
           19.668361086912018,
           19.69268528092968,
           19.720816990690132,
           19.74894870045058,
           19.777080410211024,
           19.805212119971475,
           19.833343829731923,
           19.861475539492368,
           19.88960724925282,
           19.91773895901327,
           19.94587066877372,
           19.974002378534163,
           20.00213408829461,
           20.030265798055062,
           20.05839750781551,
           20.086529217575958,
           20.114660927336402,
           20.142792637096854,
           20.170924346857298,
           20.19905605661775,
           20.227187766378194,
           20.255319476138645,
           20.283451185899096,
           20.31158289565954,
           20.339714605419985,
           20.367846315180437,
           20.395978024940884,
           20.424109734701332,
           20.452241444461784,
           20.48037315422223,
           20.508504863982672,
           20.536636573743124,
           20.564768283503575,
           20.59289999326402,
           20.62103170302447,
           20.649163412784915,
           20.677295122545367,
           20.705426832305815,
           20.733558542066262,
           20.76169025182671,
           20.78982196158716,
           20.817953671347603,
           20.846085381108054,
           20.874217090868502,
           20.90234880062895,
           20.929214261747248,
           20.9554817708862,
           20.98174928002515,
           21.008016789164103,
           21.034284298303053,
           21.060551807442003,
           21.086819316580954,
           21.113086825719904,
           21.139354334858858,
           21.16562184399781,
           21.191889353136762,
           21.21815686227571,
           21.24442437141466,
           21.270691880553617,
           21.296959389692567,
           21.323226898831518,
           21.349494407970468,
           21.37576191710942,
           21.40202942624837,
           21.428296935387323,
           21.454564444526273,
           21.480831953665223,
           21.507099462804177,
           21.53336697194313,
           21.559634481082078,
           21.585901990221032,
           21.612169499359986,
           21.638437008498936,
           21.664704517637887,
           21.690972026776837,
           21.717239535915787,
           21.743507045054738,
           21.769774554193692,
           21.796042063332642,
           21.822309572471593,
           21.848577081610543,
           21.874844590749497,
           21.901112099888447,
           21.927379609027398,
           21.949195136875826,
           21.96210670214321,
           21.975018267410594,
           21.987929832677978,
           22.00084139794536,
           22.01375296321274,
           22.026664528480126,
           22.03957609374751,
           22.052487659014893,
           22.065399224282277,
           22.07831078954966,
           22.091222354817045,
           22.10413392008443,
           22.117045485351813,
           22.129957050619197,
           22.142868615886577,
           22.155780181153965,
           22.168691746421345,
           22.18160331168873,
           22.194514876956116,
           22.207426442223497,
           22.22033800749088,
           22.23324957275826,
           22.24616113802565,
           22.25907270329303,
           22.271984268560416,
           22.284895833827797,
           22.29780739909518,
           22.310718964362565,
           22.32363052962995,
           22.336542094897332,
           22.349453660164713,
           22.3623652254321,
           22.37527679069948,
           22.388188355966868,
           22.40109992123425,
           22.414011486501632,
           22.426923051769016,
           22.439834617036396,
           22.452746182303784,
           22.465657747571168,
           22.478569312838548,
           22.491480878105932,
           22.50439244337332,
           22.5173040086407,
           22.53021557390808,
           22.543127139175468,
           22.556038704442848,
           22.568950269710232,
           22.581861834977616,
           22.594773400245,
           22.607684965512384,
           22.62059653077977,
           22.63350809604715,
           22.646419661314532,
           22.65933122658192,
           22.672242791849303,
           22.685154357116684,
           22.698065922384068,
           22.710977487651455,
           22.729138303647705,
           22.748348983717076,
           22.767559663786443,
           22.786770343855814,
           22.80598102392518,
           22.82519170399455,
           22.844402384063926,
           22.863613064133293,
           22.882823744202664,
           22.90203442427203,
           22.921245104341402,
           22.94045578441077,
           22.95966646448014,
           22.978877144549507,
           22.99808782461888,
           23.017298504688252,
           23.03650918475762,
           23.05571986482699,
           23.074930544896358,
           23.09414122496573,
           23.113351905035096,
           23.132562585104466,
           23.151773265173837,
           23.138741836236203,
           22.96449986226356,
           22.79025788829091,
           22.61601591431827,
           22.44177394034566,
           22.26753196637301,
           22.09328999240037,
           21.91904801842776,
           21.74480604445511,
           21.57056407048247,
           21.396322096509856,
           21.222080122537207,
           21.047838148564566,
           20.873596174591917,
           20.699354200619304,
           20.525112226646662,
           20.350870252674017,
           20.176628278701408,
           20.002386304728766,
           19.828144330756118,
           19.653902356783505,
           19.479660382810863,
           19.29535432602767,
           19.105665148986212,
           18.915975971944725,
           18.72628679490323,
           18.536597617861744,
           18.346908440820286,
           18.1572192637788,
           17.967530086737305,
           17.777840909695854,
           17.58815173265436,
           17.398462555612873,
           17.208773378571415,
           17.019084201529928,
           16.829395024488438,
           16.639705847446947,
           16.45001667040549,
           16.260327493364,
           16.070638316322512,
           15.880949139281055,
           15.691259962239565,
           15.501570785198075,
           15.311881608156618,
           15.122192431115128,
           14.932503254073637,
           14.742814077032182,
           14.553124899990694,
           14.363435722949204,
           14.173746545907713,
           13.984057368866257,
           13.794368191824766,
           13.604679014783276,
           13.414989837741823,
           13.225300660700333,
           13.035611483658842,
           12.845922306617386,
           12.656233129575895,
           12.466543952534408,
           12.276854775492918,
           12.087165598451461,
           11.897476421409971,
           11.70870132936669,
           11.52078655171563,
           11.33287177406454,
           11.144956996413445,
           10.957042218762385,
           10.76912744111129,
           10.581212663460198,
           10.393297885809138,
           10.205383108158046,
           10.01746833050695,
           9.82955355285586,
           9.6416387752048,
           9.453723997553706,
           9.265809219902613,
           9.077894442251552,
           8.88997966460046,
           8.702064886949366,
           8.514150109298306,
           8.326235331647215,
           8.13832055399612,
           7.9504057763450255,
           7.762490998693966
          ],
          [
           15.43682106070483,
           15.455349701260259,
           15.47387834181569,
           15.492406982371119,
           15.510935622926551,
           15.52946426348198,
           15.547992904037411,
           15.56652154459284,
           15.585050185148273,
           15.603578825703702,
           15.62210746625913,
           15.640636106814561,
           15.659164747369992,
           15.677693387925423,
           15.69622202848085,
           15.714750669036281,
           15.733279309591712,
           15.751807950147143,
           15.770336590702573,
           15.788865231258004,
           15.807393871813433,
           15.825922512368864,
           15.844451152924293,
           15.862979793479726,
           15.881508434035155,
           15.900037074590585,
           15.918565715146014,
           15.937094355701444,
           15.955622996256876,
           15.974151636812307,
           15.992680277367738,
           16.011208917923167,
           16.029737558478594,
           16.04826619903403,
           16.066794839589456,
           16.085323480144886,
           16.103852120700317,
           16.122380761255748,
           16.14090940181118,
           16.159438042366606,
           16.177966682922037,
           16.196495323477468,
           16.2150239640329,
           16.23355260458833,
           16.252081245143756,
           16.270609885699187,
           16.289138526254618,
           16.30766716681005,
           16.32619580736548,
           16.344724447920907,
           16.36325308847634,
           16.38178172903177,
           16.4003103695872,
           16.41883901014263,
           16.43736765069806,
           16.45589629125349,
           16.474424931808922,
           16.49295357236435,
           16.51148221291978,
           16.53001085347521,
           16.548539494030642,
           16.567068134586073,
           16.585596775141504,
           16.60412541569693,
           16.62265405625236,
           16.641182696807792,
           16.659711337363223,
           16.678239977918654,
           16.69676861847408,
           16.717596284766906,
           16.73888375461596,
           16.76017122446501,
           16.78145869431407,
           16.802746164163125,
           16.824033634012178,
           16.845321103861234,
           16.866608573710288,
           16.88789604355934,
           16.909183513408397,
           16.93047098325745,
           16.951758453106507,
           16.97304592295556,
           16.994333392804617,
           17.01562086265367,
           17.036213792178582,
           17.05666781363867,
           17.077121835098755,
           17.09757585655884,
           17.11802987801893,
           17.138483899479017,
           17.158937920939103,
           17.17939194239919,
           17.199845963859275,
           17.22029998531936,
           17.240754006779447,
           17.261208028239533,
           17.28166204969962,
           17.302116071159706,
           17.322570092619795,
           17.340777842874537,
           17.358536337333486,
           17.376294831792432,
           17.39405332625138,
           17.411811820710327,
           17.429570315169272,
           17.44732880962822,
           17.465087304087167,
           17.482845798546116,
           17.50060429300506,
           17.518362787464007,
           17.536121281922956,
           17.5538797763819,
           17.57163827084085,
           17.589396765299796,
           17.60715525975874,
           17.624913754217687,
           17.642672248676636,
           17.660430743135585,
           17.67818923759453,
           17.695947732053476,
           17.71370622651242,
           17.73146472097137,
           17.74922321543032,
           17.766981709889265,
           17.78474020434821,
           17.80249869880716,
           17.82025719326611,
           17.838015687725054,
           17.855774182184,
           17.873532676642945,
           17.891291171101894,
           17.90904966556084,
           17.92680816001979,
           17.944566654478734,
           17.96232514893768,
           17.980083643396625,
           17.997842137855574,
           18.015600632314523,
           18.03335912677347,
           18.051117621232414,
           18.068876115691364,
           18.08663461015031,
           18.104393104609258,
           18.1221515990682,
           18.13991009352715,
           18.157668587986095,
           18.175427082445044,
           18.193185576903993,
           18.21094407136294,
           18.228702565821884,
           18.24646106028083,
           18.26421955473978,
           18.281978049198724,
           18.29973654365767,
           18.317495038116615,
           18.335253532575564,
           18.353012027034513,
           18.37077052149346,
           18.388529015952404,
           18.406287510411353,
           18.4240460048703,
           18.441804499329248,
           18.459562993788193,
           18.47732148824714,
           18.495079982706088,
           18.512838477165033,
           18.53059697162398,
           18.55143289743855,
           18.573807538930925,
           18.596182180423305,
           18.618556821915682,
           18.640931463408062,
           18.663306104900443,
           18.68568074639282,
           18.7080553878852,
           18.730430029377576,
           18.752804670869953,
           18.775179312362333,
           18.79755395385471,
           18.81992859534709,
           18.842303236839467,
           18.864677878331847,
           18.887052519824223,
           18.9094271613166,
           18.93180180280898,
           18.95417644430136,
           18.976551085793737,
           18.998925727286117,
           19.021300368778494,
           19.04367501027087,
           19.066049651763255,
           19.08842429325563,
           19.110592496214753,
           19.131109174489637,
           19.151625852764518,
           19.1721425310394,
           19.192659209314282,
           19.213175887589163,
           19.23369256586404,
           19.254209244138927,
           19.274725922413808,
           19.29524260068869,
           19.315759278963576,
           19.336275957238456,
           19.356792635513337,
           19.377309313788217,
           19.3978259920631,
           19.418342670337978,
           19.438859348612866,
           19.459376026887746,
           19.479892705162626,
           19.500409383437507,
           19.520926061712395,
           19.541442739987275,
           19.561959418262155,
           19.58247609653704,
           19.60299277481192,
           19.623509453086804,
           19.644026131361684,
           19.664542809636565,
           19.68505948791145,
           19.70557616618633,
           19.72609284446121,
           19.746609522736094,
           19.767126201010978,
           19.78764287928586,
           19.808159557560742,
           19.828676235835623,
           19.849192914110507,
           19.869709592385387,
           19.89022627066027,
           19.910742948935148,
           19.931259627210032,
           19.951776305484913,
           19.972292983759793,
           19.992809662034677,
           20.01332634030956,
           20.033843018584445,
           20.054359696859326,
           20.07487637513421,
           20.09539305340909,
           20.11590973168397,
           20.13642640995885,
           20.156943088233735,
           20.177459766508616,
           20.1979764447835,
           20.21849312305838,
           20.23900980133326,
           20.259526479608144,
           20.280043157883025,
           20.30436735190069,
           20.332499061661142,
           20.360630771421587,
           20.388762481182034,
           20.416894190942486,
           20.445025900702937,
           20.47315761046338,
           20.50128932022383,
           20.529421029984277,
           20.55755273974472,
           20.58568444950517,
           20.61381615926562,
           20.641947869026065,
           20.670079578786517,
           20.698211288546965,
           20.726342998307416,
           20.754474708067857,
           20.78260641782831,
           20.810738127588756,
           20.838869837349208,
           20.867001547109652,
           20.895133256870103,
           20.923264966630548,
           20.951396676391,
           20.97952838615145,
           21.007660095911895,
           21.03579180567234,
           21.06392351543279,
           21.09205522519324,
           21.120186934953686,
           21.148318644714138,
           21.176450354474586,
           21.20458206423503,
           21.232713773995478,
           21.26084548375593,
           21.288977193516374,
           21.317108903276825,
           21.345240613037273,
           21.37337232279772,
           21.401504032558165,
           21.429635742318617,
           21.45776745207906,
           21.485899161839512,
           21.514030871599964,
           21.542162581360408,
           21.570294291120856,
           21.598426000881304,
           21.626557710641755,
           21.6546894204022,
           21.682821130162647,
           21.710952839923095,
           21.739084549683547,
           21.76721625944399,
           21.795347969204443,
           21.82347967896489,
           21.851611388725335,
           21.879743098485786,
           21.907874808246238,
           21.936006518006685,
           21.96413822776713,
           21.992269937527578,
           22.020401647288026,
           22.048533357048473,
           22.076665066808925,
           22.104796776569373,
           22.132928486329817,
           22.161060196090265,
           22.18919190585072,
           22.217323615611164,
           22.245455325371612,
           22.27358703513206,
           22.301718744892504,
           22.329850454652952,
           22.357982164413404,
           22.38611387417385,
           22.414245583934296,
           22.44237729369475,
           22.470509003455195,
           22.49864071321564,
           22.526772422976094,
           22.5532685595038,
           22.57953606864275,
           22.605803577781696,
           22.627619105630124,
           22.640530670897512,
           22.65344223616489,
           22.666353801432273,
           22.67926536669966,
           22.692176931967044,
           22.705088497234424,
           22.71800006250181,
           22.730911627769192,
           22.743823193036576,
           22.75673475830396,
           22.769646323571344,
           22.78255788883873,
           22.795469454106108,
           22.808381019373492,
           22.82129258464088,
           22.83420414990826,
           22.847115715175647,
           22.860027280443028,
           22.872938845710408,
           22.885850410977795,
           22.89876197624518,
           22.911673541512563,
           22.924585106779947,
           22.93646913370817,
           22.94817772925842,
           22.959886324808664,
           22.97159492035891,
           22.983303515909157,
           22.995012111459403,
           23.006720707009652,
           23.0184293025599,
           23.030137898110144,
           23.04184649366039,
           23.053555089210633,
           23.065263684760883,
           23.076972280311132,
           23.08868087586137,
           23.100389471411624,
           23.11209806696187,
           23.123806662512116,
           23.135515258062362,
           23.147223853612612,
           23.158932449162858,
           23.1706410447131,
           23.18234964026335,
           23.194058235813596,
           23.205766831363842,
           23.217475426914092,
           23.229184022464338,
           23.240892618014584,
           23.25260121356483,
           23.264309809115076,
           23.276018404665322,
           23.28772700021557,
           23.299435595765814,
           23.311144191316064,
           23.32285278686631,
           23.334561382416556,
           23.346269977966806,
           23.357978573517048,
           23.369687169067294,
           23.381395764617544,
           23.393104360167793,
           23.404812955718036,
           23.416521551268282,
           23.42823014681853,
           23.439938742368778,
           23.451647337919024,
           23.46335593346927,
           23.475064529019516,
           23.486773124569766,
           23.49848172012001,
           23.510190315670258,
           23.5218989112205,
           23.53360750677075,
           23.545316102321,
           23.557024697871242,
           23.568733293421488,
           23.580441888971738,
           23.59215048452198,
           23.60385908007223,
           23.615567675622476,
           23.59188067369925,
           23.391215684408674,
           23.190550695118098,
           22.989885705827522,
           22.78922071653698,
           22.588555727246405,
           22.38789073795583,
           22.18722574866529,
           21.988847363232573,
           21.799158186191082,
           21.609469009149628,
           21.419779832108137,
           21.230090655066647,
           21.040401478025156,
           20.850712300983698,
           20.661023123942208,
           20.471333946900717,
           20.281644769859263,
           20.091955592817772,
           19.902266415776282,
           19.71257723873483,
           19.522888061693344,
           19.33319888465185,
           19.143509707610395,
           18.953820530568905,
           18.764131353527414,
           18.574442176485924,
           18.38475299944447,
           18.19506382240298,
           18.00537464536149,
           17.815685468320034,
           17.62599629127854,
           17.436307114237053,
           17.246617937195598,
           17.056928760154108,
           16.867239583112617,
           16.677550406071127,
           16.487861229029672,
           16.298172051988182,
           16.10848287494669,
           15.918793697905237,
           15.729104520863746,
           15.539415343822256,
           15.349726166780801,
           15.16003698973931,
           14.97034781269782,
           14.780658635656364,
           14.590969458614875,
           14.401280281573385,
           14.211591104531895,
           14.02190192749044,
           13.83221275044895,
           13.642523573407459,
           13.452834396366004,
           13.263145219324514,
           13.073456042283023,
           12.883766865241569,
           12.694077688200078,
           12.504388511158588,
           12.314699334117098,
           12.125010157075643,
           11.935320980034152,
           11.745631802992662,
           11.555942625951207,
           11.366253448909717,
           11.176564271868227,
           10.98687509482677,
           10.79718591778528,
           10.607496740743793,
           10.417807563702336,
           10.228118386660846,
           10.038429209619355,
           9.848740032577865,
           9.659050855536409,
           9.469361678494918,
           9.279672501453428,
           9.08758242810474,
           8.89538797360346,
           8.703193519102182,
           8.510999064600938,
           8.318804610099658,
           8.126610155598378,
           7.934415701097098,
           7.742221246595854
          ],
          [
           15.90627684673144,
           15.924805487286871,
           15.943334127842302,
           15.961862768397731,
           15.980391408953164,
           15.998920049508591,
           16.017448690064022,
           16.035977330619453,
           16.054505971174883,
           16.073034611730314,
           16.091563252285745,
           16.110091892841172,
           16.128620533396603,
           16.147149173952034,
           16.165677814507465,
           16.184206455062895,
           16.202735095618326,
           16.221263736173754,
           16.239792376729184,
           16.258321017284615,
           16.276849657840046,
           16.295378298395477,
           16.313906938950904,
           16.33243557950634,
           16.350964220061766,
           16.369492860617196,
           16.38802150117263,
           16.406550141728054,
           16.42507878228349,
           16.443607422838916,
           16.462136063394347,
           16.480664703949778,
           16.49919334450521,
           16.51772198506064,
           16.53625062561607,
           16.5547792661715,
           16.57330790672693,
           16.59183654728236,
           16.610365187837793,
           16.62889382839322,
           16.64742246894865,
           16.665951109504082,
           16.68447975005951,
           16.70300839061494,
           16.72153703117037,
           16.7400656717258,
           16.758594312281232,
           16.777122952836663,
           16.79565159339209,
           16.81418023394752,
           16.832708874502952,
           16.851237515058383,
           16.87068576520023,
           16.891973235049285,
           16.913260704898338,
           16.934548174747395,
           16.955835644596448,
           16.977123114445504,
           16.998410584294554,
           17.01969805414361,
           17.040985523992667,
           17.06227299384172,
           17.083560463690777,
           17.10484793353983,
           17.126135403388886,
           17.14742287323794,
           17.168710343086993,
           17.18999781293605,
           17.211285282785102,
           17.232572752634155,
           17.253860222483212,
           17.275147692332265,
           17.296435162181318,
           17.317722632030375,
           17.33901010187943,
           17.360297571728484,
           17.381585041577537,
           17.402872511426594,
           17.424159981275647,
           17.4454474511247,
           17.466734920973757,
           17.48802239082281,
           17.509309860671866,
           17.53059733052092,
           17.551190260045836,
           17.57164428150592,
           17.592098302966008,
           17.612552324426094,
           17.63300634588618,
           17.653460367346266,
           17.673914388806352,
           17.69436841026644,
           17.714822431726525,
           17.735276453186614,
           17.755730474646697,
           17.776184496106787,
           17.796638517566873,
           17.81709253902696,
           17.837546560487045,
           17.85800058194713,
           17.878454603407217,
           17.898908624867303,
           17.91936264632739,
           17.939816667787476,
           17.96027068924756,
           17.980724710707648,
           18.001178732167734,
           18.02163275362782,
           18.04208677508791,
           18.062540796547992,
           18.082994818008082,
           18.103448839468168,
           18.123902860928254,
           18.14435688238834,
           18.164810903848426,
           18.184366416134097,
           18.202124910593042,
           18.219883405051988,
           18.237641899510937,
           18.255400393969886,
           18.27315888842883,
           18.290917382887777,
           18.308675877346722,
           18.32643437180567,
           18.34419286626462,
           18.361951360723566,
           18.379709855182515,
           18.39746834964146,
           18.415226844100403,
           18.432985338559355,
           18.4507438330183,
           18.468502327477246,
           18.486260821936195,
           18.504019316395137,
           18.521777810854086,
           18.539536305313035,
           18.55729479977198,
           18.575053294230926,
           18.592811788689872,
           18.61057028314882,
           18.62832877760777,
           18.646087272066715,
           18.66384576652566,
           18.681604260984606,
           18.699362755443556,
           18.7171212499025,
           18.73487974436145,
           18.752638238820396,
           18.77039673327934,
           18.788155227738294,
           18.80591372219724,
           18.823672216656185,
           18.84143071111513,
           18.859189205574076,
           18.87694770003302,
           18.89470619449197,
           18.912464688950916,
           18.930223183409865,
           18.94798167786881,
           18.965740172327756,
           18.983498666786705,
           19.001257161245654,
           19.0190156557046,
           19.036774150163545,
           19.05453264462249,
           19.07229113908144,
           19.09004963354039,
           19.110885559354955,
           19.13326020084733,
           19.155634842339712,
           19.178009483832092,
           19.20038412532447,
           19.22275876681685,
           19.245133408309226,
           19.267508049801606,
           19.289882691293982,
           19.31225733278636,
           19.33463197427874,
           19.35700661577112,
           19.379381257263496,
           19.401755898755873,
           19.424130540248253,
           19.44650518174063,
           19.46887982323301,
           19.491254464725387,
           19.513629106217767,
           19.536003747710144,
           19.558378389202524,
           19.5807530306949,
           19.60312767218728,
           19.625502313679657,
           19.647876955172034,
           19.670251596664414,
           19.69262623815679,
           19.71500087964917,
           19.737375521141548,
           19.759750162633928,
           19.78212480412631,
           19.804499445618685,
           19.826874087111065,
           19.849248728603445,
           19.871623370095822,
           19.8939980115882,
           19.916372653080575,
           19.938747294572956,
           19.961121936065336,
           19.983496577557716,
           20.00587121905009,
           20.02824586054247,
           20.05062050203485,
           20.072995143527226,
           20.095369785019606,
           20.117744426511983,
           20.14011906800436,
           20.16249370949674,
           20.184868350989113,
           20.207242992481497,
           20.229617633973874,
           20.25199227546625,
           20.274366916958634,
           20.29674155845101,
           20.31725823715735,
           20.337774915432234,
           20.358291593707115,
           20.378808271982,
           20.39932495025688,
           20.419841628531763,
           20.440358306806644,
           20.460874985081524,
           20.48139166335641,
           20.50190834163129,
           20.522425019906173,
           20.542941698181053,
           20.563458376455934,
           20.583975054730818,
           20.6044917330057,
           20.625008411280582,
           20.645525089555463,
           20.666041767830347,
           20.686558446105227,
           20.707075124380108,
           20.72759180265499,
           20.748108480929872,
           20.768625159204756,
           20.789141837479637,
           20.80965851575452,
           20.8301751940294,
           20.85069187230428,
           20.871208550579166,
           20.891725228854046,
           20.916049422871712,
           20.944181132632163,
           20.972312842392608,
           21.000444552153056,
           21.028576261913507,
           21.05670797167395,
           21.0848396814344,
           21.112971391194847,
           21.141103100955302,
           21.169234810715743,
           21.197366520476194,
           21.225498230236646,
           21.253629939997094,
           21.281761649757538,
           21.30989335951799,
           21.338025069278437,
           21.36615677903888,
           21.394288488799333,
           21.42242019855978,
           21.45055190832023,
           21.478683618080673,
           21.506815327841124,
           21.53494703760157,
           21.56307874736202,
           21.591210457122468,
           21.619342166882916,
           21.647473876643364,
           21.67560558640381,
           21.70373729616426,
           21.731869005924707,
           21.76000071568516,
           21.788132425445607,
           21.816264135206048,
           21.8443958449665,
           21.87252755472695,
           21.900659264487395,
           21.928790974247846,
           21.956922684008294,
           21.985054393768742,
           22.013186103529186,
           22.041317813289638,
           22.069449523050082,
           22.097581232810533,
           22.125712942570978,
           22.153844652331433,
           22.18303036822302,
           22.21256217715069,
           22.242093986078366,
           22.271625795006038,
           22.301157603933703,
           22.33068941286138,
           22.36022122178905,
           22.38975303071672,
           22.41928483964439,
           22.448816648572066,
           22.47834845749973,
           22.507880266427403,
           22.53741207535508,
           22.56694388428275,
           22.596475693210422,
           22.62600750213809,
           22.655539311065763,
           22.68507111999343,
           22.714602928921103,
           22.744134737848775,
           22.773666546776447,
           22.80319835570412,
           22.83273016463179,
           22.862261973559463,
           22.891793782487134,
           22.921325591414806,
           22.950857400342475,
           22.980389209270147,
           23.009921018197822,
           23.039452827125487,
           23.06898463605316,
           23.098516444980834,
           23.128048253908503,
           23.157580062836175,
           23.187111871763847,
           23.21664368069152,
           23.24617548961919,
           23.27570729854686,
           23.29651148724208,
           23.299860435472397,
           23.303209383702715,
           23.306558331933033,
           23.30990728016335,
           23.313256228393673,
           23.31660517662399,
           23.319954124854313,
           23.323303073084627,
           23.32665202131495,
           23.330000969545267,
           23.333349917775585,
           23.336698866005904,
           23.340047814236225,
           23.343396762466543,
           23.34674571069686,
           23.350094658927183,
           23.3534436071575,
           23.35679255538782,
           23.360141503618138,
           23.363490451848456,
           23.366839400078774,
           23.370188348309092,
           23.37353729653941,
           23.37688624476973,
           23.38023519300005,
           23.383584141230365,
           23.386933089460687,
           23.390282037691005,
           23.393630985921323,
           23.399815363746285,
           23.411523959296527,
           23.423232554846777,
           23.434941150397027,
           23.446649745947273,
           23.458358341497515,
           23.47006693704776,
           23.481775532598014,
           23.493484128148253,
           23.505192723698503,
           23.516901319248753,
           23.528609914798995,
           23.54031851034924,
           23.55202710589949,
           23.56373570144974,
           23.575444296999983,
           23.58715289255023,
           23.59886148810048,
           23.61057008365072,
           23.622278679200967,
           23.63398727475122,
           23.645695870301466,
           23.657404465851712,
           23.669113061401955,
           23.680821656952205,
           23.69253025250245,
           23.7042388480527,
           23.715947443602943,
           23.727656039153192,
           23.73936463470344,
           23.751073230253684,
           23.762781825803934,
           23.77449042135418,
           23.786199016904423,
           23.797907612454672,
           23.809616208004922,
           23.821324803555164,
           23.833033399105414,
           23.84474199465566,
           23.856450590205906,
           23.868159185756152,
           23.879867781306398,
           23.891576376856648,
           23.90328497240689,
           23.91499356795714,
           23.926702163507386,
           23.938410759057632,
           23.950119354607878,
           23.96182795015812,
           23.97353654570837,
           23.985245141258616,
           23.996953736808862,
           24.008662332359112,
           23.984975330435887,
           23.784310341145307,
           23.583645351854727,
           23.382980362564155,
           23.182315373273617,
           22.981650383983038,
           22.780985394692458,
           22.58032040540192,
           22.379655416111348,
           22.178990426820768,
           21.97832543753023,
           21.77766044823965,
           21.57699545894907,
           21.376330469658498,
           21.175665480367954,
           20.97500049107738,
           20.7743355017868,
           20.573670512496264,
           20.373005523205688,
           20.17234053391511,
           19.971675544624567,
           19.771010555333994,
           19.570345566043414,
           19.369680576752874,
           19.1690155874623,
           18.96835059817172,
           18.767685608881145,
           18.567020619590604,
           18.366355630300028,
           18.16569064100945,
           17.96502565171891,
           17.764360662428334,
           17.563695673137758,
           17.363030683847217,
           17.16236569455664,
           16.96170070526606,
           16.76103571597549,
           16.560370726684948,
           16.35970573739437,
           16.159040748103795,
           15.964778288793418,
           15.775089111751928,
           15.585399934710438,
           15.395710757668983,
           15.204560162575387,
           15.012365708074107,
           14.820171253572862,
           14.627976799071583,
           14.435782344570303,
           14.243587890069024,
           14.05139343556778,
           13.859198981066498,
           13.667004526565218,
           13.474810072063974,
           13.282615617562694,
           13.090421163061416,
           12.89822670856017,
           12.706032254058892,
           12.51383779955761,
           12.32164334505633,
           12.129448890555087,
           11.937254436053808,
           11.745059981552528,
           11.552865527051283,
           11.360671072550002,
           11.168476618048723,
           10.976282163547479,
           10.784087709046197,
           10.591893254544917,
           10.399698800043673,
           10.207504345542395,
           10.015309891041115,
           9.823115436539835,
           9.63092098203859,
           9.43872652753731,
           9.24653207303603,
           9.054337618534786,
           8.862143164033506,
           8.669948709532227,
           8.477754255030982,
           8.285559800529702,
           8.093365346028422,
           7.901170891527143,
           7.708976437025899
          ],
          [
           16.375732632758044,
           16.394261273313475,
           16.412789913868906,
           16.431318554424337,
           16.449847194979764,
           16.4683758355352,
           16.486904476090626,
           16.505433116646053,
           16.523961757201487,
           16.542490397756914,
           16.561019038312345,
           16.579547678867776,
           16.598076319423207,
           16.616604959978638,
           16.63513360053407,
           16.6536622410895,
           16.672190881644926,
           16.69071952220036,
           16.709248162755788,
           16.72777680331122,
           16.74630544386665,
           16.764834084422077,
           16.783362724977508,
           16.80189136553294,
           16.82042000608837,
           16.8389486466438,
           16.85747728719923,
           16.87600592775466,
           16.894534568310092,
           16.91306320886552,
           16.931591849420954,
           16.95012048997638,
           16.968649130531812,
           16.987177771087243,
           17.00570641164267,
           17.0242350521981,
           17.0450627154826,
           17.066350185331654,
           17.08763765518071,
           17.108925125029764,
           17.13021259487882,
           17.151500064727877,
           17.172787534576926,
           17.194075004425983,
           17.215362474275036,
           17.23664994412409,
           17.257937413973146,
           17.279224883822202,
           17.300512353671255,
           17.32179982352031,
           17.343087293369365,
           17.364374763218418,
           17.385662233067475,
           17.406949702916528,
           17.428237172765584,
           17.449524642614637,
           17.47081211246369,
           17.492099582312747,
           17.5133870521618,
           17.534674522010853,
           17.55596199185991,
           17.577249461708966,
           17.59853693155802,
           17.619824401407072,
           17.64111187125613,
           17.662399341105182,
           17.683686810954235,
           17.70497428080329,
           17.726261750652345,
           17.747549220501398,
           17.768836690350454,
           17.790124160199507,
           17.811411630048564,
           17.832699099897617,
           17.853986569746674,
           17.875274039595727,
           17.896561509444783,
           17.917848979293836,
           17.93913644914289,
           17.960423918991943,
           17.981711388841,
           18.002998858690056,
           18.024286328539112,
           18.045573798388165,
           18.066166727913075,
           18.086620749373168,
           18.10707477083325,
           18.127528792293337,
           18.147982813753423,
           18.168436835213512,
           18.188890856673595,
           18.209344878133685,
           18.229798899593767,
           18.250252921053857,
           18.270706942513943,
           18.291160963974026,
           18.311614985434115,
           18.332069006894198,
           18.352523028354288,
           18.372977049814374,
           18.393431071274456,
           18.413885092734546,
           18.434339114194636,
           18.454793135654718,
           18.475247157114804,
           18.49570117857489,
           18.516155200034977,
           18.536609221495063,
           18.55706324295515,
           18.577517264415235,
           18.597971285875325,
           18.618425307335407,
           18.638879328795493,
           18.659333350255583,
           18.67978737171567,
           18.70024139317576,
           18.72069541463584,
           18.741149436095924,
           18.761603457556014,
           18.7820574790161,
           18.802511500476186,
           18.822965521936275,
           18.843419543396358,
           18.863873564856448,
           18.88432758631653,
           18.90478160777662,
           18.925235629236706,
           18.945689650696792,
           18.96614367215688,
           18.986597693616964,
           19.00705171507705,
           19.02750573653714,
           19.045713483852587,
           19.063471978311533,
           19.081230472770482,
           19.09898896722943,
           19.116747461688377,
           19.134505956147322,
           19.15226445060627,
           19.170022945065217,
           19.187781439524166,
           19.20553993398311,
           19.223298428442057,
           19.241056922901002,
           19.258815417359955,
           19.2765739118189,
           19.294332406277846,
           19.31209090073679,
           19.329849395195737,
           19.347607889654686,
           19.365366384113635,
           19.38312487857258,
           19.400883373031526,
           19.41864186749047,
           19.436400361949417,
           19.454158856408366,
           19.471917350867315,
           19.48967584532626,
           19.507434339785206,
           19.52519283424415,
           19.5429513287031,
           19.56070982316205,
           19.578468317620995,
           19.59622681207994,
           19.61398530653889,
           19.631743800997835,
           19.649502295456784,
           19.67033822127135,
           19.692712862763727,
           19.715087504256108,
           19.737462145748488,
           19.759836787240864,
           19.78221142873324,
           19.80458607022562,
           19.826960711718,
           19.84933535321038,
           19.871709994702755,
           19.89408463619513,
           19.916459277687515,
           19.938833919179892,
           19.96120856067227,
           19.983583202164645,
           20.00595784365703,
           20.028332485149406,
           20.050707126641782,
           20.073081768134166,
           20.09545640962654,
           20.117831051118916,
           20.140205692611296,
           20.162580334103673,
           20.184954975596053,
           20.207329617088433,
           20.22970425858081,
           20.25207890007319,
           20.274453541565567,
           20.296828183057947,
           20.319202824550324,
           20.341577466042704,
           20.36395210753508,
           20.38632674902746,
           20.408701390519838,
           20.431076032012218,
           20.453450673504594,
           20.47582531499697,
           20.498199956489348,
           20.52057459798173,
           20.542949239474112,
           20.56532388096649,
           20.587698522458865,
           20.610073163951242,
           20.632447805443622,
           20.654822446936,
           20.67719708842838,
           20.699571729920756,
           20.721946371413136,
           20.744321012905512,
           20.766695654397893,
           20.78907029589027,
           20.811444937382646,
           20.83381957887503,
           20.856194220367406,
           20.878568861859787,
           20.900943503352163,
           20.923318144844536,
           20.945692786336917,
           20.968067427829297,
           20.990442069321677,
           21.012816710814054,
           21.035191352306434,
           21.057565993798814,
           21.07994063529119,
           21.102315276783564,
           21.124689918275944,
           21.147064559768324,
           21.169439201260705,
           21.19181384275308,
           21.214188484245458,
           21.236563125737838,
           21.25893776723022,
           21.281312408722595,
           21.303687050214975,
           21.326061691707356,
           21.34843633319973,
           21.37081097469211,
           21.393185616184486,
           21.415560257676866,
           21.437934899169242,
           21.46030954066162,
           21.482684182154,
           21.503407299825056,
           21.527731493842722,
           21.55586320360317,
           21.584545512985535,
           21.6140773219132,
           21.643609130840876,
           21.673140939768547,
           21.702672748696216,
           21.73220455762389,
           21.76173636655156,
           21.79126817547923,
           21.820799984406904,
           21.85033179333458,
           21.87986360226225,
           21.90939541118992,
           21.93892722011759,
           21.968459029045263,
           21.997990837972935,
           22.027522646900604,
           22.057054455828272,
           22.086586264755944,
           22.116118073683616,
           22.14564988261129,
           22.175181691538956,
           22.20471350046663,
           22.234245309394304,
           22.263777118321975,
           22.293308927249647,
           22.322840736177316,
           22.352372545104988,
           22.38190435403266,
           22.41143616296033,
           22.440967971888004,
           22.470499780815672,
           22.500031589743344,
           22.529563398671016,
           22.559095207598688,
           22.58862701652636,
           22.61815882545403,
           22.647690634381703,
           22.67722244330937,
           22.706754252237047,
           22.736286061164716,
           22.765817870092384,
           22.79534967902006,
           22.824881487947728,
           22.8544132968754,
           22.883945105803072,
           22.913476914730747,
           22.943008723658412,
           22.972540532586088,
           23.00207234151376,
           23.03160415044143,
           23.0611359593691,
           23.090667768296772,
           23.120199577224447,
           23.149731386152116,
           23.179263195079784,
           23.20879500400746,
           23.23832681293513,
           23.2678586218628,
           23.297390430790475,
           23.326922239718144,
           23.356454048645816,
           23.385985857573488,
           23.41551766650116,
           23.445049475428828,
           23.474581284356503,
           23.504113093284175,
           23.533644902211844,
           23.563176711139516,
           23.592708520067188,
           23.622240328994856,
           23.651772137922528,
           23.6813039468502,
           23.71083575577787,
           23.74036756470554,
           23.769899373633216,
           23.799431182560884,
           23.828962991488556,
           23.85849480041623,
           23.888026609343903,
           23.91755841827157,
           23.94709022719924,
           23.967894415894463,
           23.97124336412478,
           23.9745923123551,
           23.977941260585418,
           23.981290208815736,
           23.984639157046058,
           23.987988105276372,
           23.991337053506694,
           23.994686001737012,
           23.998034949967327,
           24.001383898197652,
           24.00473284642797,
           24.00808179465829,
           24.011430742888606,
           24.014779691118925,
           24.018128639349243,
           24.02147758757956,
           24.024826535809883,
           24.028175484040197,
           24.03152443227052,
           24.034873380500837,
           24.038222328731155,
           24.041571276961477,
           24.044920225191795,
           24.048269173422113,
           24.05161812165243,
           24.05496706988275,
           24.05831601811307,
           24.06166496634339,
           24.06501391457371,
           24.06836286280403,
           24.071711811034348,
           24.075060759264666,
           24.07840970749498,
           24.081758655725302,
           24.08510760395562,
           24.08845655218594,
           24.091805500416257,
           24.095154448646575,
           24.098503396876893,
           24.10185234510721,
           24.10520129333753,
           24.108550241567848,
           24.11189918979817,
           24.115248138028488,
           24.118597086258806,
           24.121946034489127,
           24.125294982719442,
           24.128643930949764,
           24.131992879180082,
           24.1353418274104,
           24.138690775640722,
           24.142039723871036,
           24.145388672101358,
           24.148737620331673,
           24.15208656856199,
           24.155435516792316,
           24.158784465022634,
           24.162133413252953,
           24.16548236148327,
           24.16883130971359,
           24.172180257943907,
           24.175529206174225,
           24.179293673641055,
           24.1910022691913,
           24.202710864741547,
           24.21441946029179,
           24.22612805584204,
           24.237836651392286,
           24.24954524694253,
           24.261253842492778,
           24.272962438043024,
           24.28467103359327,
           24.296379629143516,
           24.308088224693762,
           24.319796820244008,
           24.331505415794254,
           24.343214011344504,
           24.354922606894753,
           24.366631202445,
           24.378339797995242,
           24.39004839354549,
           24.401756989095738,
           24.378069987172513,
           24.177404997881936,
           23.976740008591356,
           23.776075019300784,
           23.575410030010243,
           23.374745040719663,
           23.174080051429083,
           22.97341506213855,
           22.772750072847973,
           22.572085083557397,
           22.371420094266853,
           22.17075510497628,
           21.9700901156857,
           21.769425126395124,
           21.568760137104583,
           21.368095147814007,
           21.16743015852343,
           20.963222856606222,
           20.75892916571345,
           20.554635474820675,
           20.35034178392794,
           20.14604809303517,
           19.941754402142394,
           19.73746071124966,
           19.533167020356885,
           19.328873329464113,
           19.12457963857134,
           18.920285947678607,
           18.715992256785835,
           18.51169856589306,
           18.307404875000326,
           18.10311118410755,
           17.89881749321478,
           17.694523802322045,
           17.49023011142927,
           17.285936420536498,
           17.081642729643722,
           16.877349038750992,
           16.673055347858217,
           16.468761656965444,
           16.264467966072708,
           16.060174275179936,
           15.855880584287164,
           15.651586893394427,
           15.447293202501655,
           15.24299951160888,
           15.038705820716146,
           14.834412129823374,
           14.6301184389306,
           14.425824748037826,
           14.221531057145091,
           14.017237366252319,
           13.812943675359547,
           13.60864998446681,
           13.404356293574038,
           13.200062602681266,
           12.99576891178853,
           12.791475220895759,
           12.587181530002985,
           12.38288783911021,
           12.178594148217474,
           11.974300457324702,
           11.77000676643193,
           11.565713075539193,
           11.361419384646421,
           11.157125693753649,
           10.952832002860912,
           10.750842899476243,
           10.558648444974963,
           10.366453990473719,
           10.17425953597244,
           9.98206508147116,
           9.789870626969881,
           9.597676172468637,
           9.405481717967357,
           9.213287263466077,
           9.021092808964832,
           8.828898354463552,
           8.636703899962274,
           8.444509445461028,
           8.252314990959748,
           8.060120536458466,
           7.867926081957188,
           7.675731627455944
          ],
          [
           16.84518841878466,
           16.86371705934009,
           16.882245699895517,
           16.900774340450948,
           16.91930298100638,
           16.93783162156181,
           16.956360262117236,
           16.974888902672667,
           16.993417543228098,
           17.01194618378353,
           17.03047482433896,
           17.049003464894387,
           17.06753210544982,
           17.086060746005252,
           17.10458938656068,
           17.12311802711611,
           17.141646667671537,
           17.16017530822697,
           17.178703948782402,
           17.198152195915924,
           17.21943966576498,
           17.240727135614033,
           17.262014605463087,
           17.283302075312143,
           17.3045895451612,
           17.32587701501025,
           17.347164484859306,
           17.368451954708362,
           17.38973942455742,
           17.41102689440647,
           17.432314364255525,
           17.453601834104578,
           17.47488930395363,
           17.496176773802688,
           17.517464243651744,
           17.538751713500798,
           17.56003918334985,
           17.581326653198907,
           17.602614123047964,
           17.623901592897013,
           17.64518906274607,
           17.666476532595127,
           17.68776400244418,
           17.709051472293233,
           17.73033894214229,
           17.751626411991342,
           17.7729138818404,
           17.794201351689452,
           17.81548882153851,
           17.83677629138756,
           17.858063761236615,
           17.87935123108567,
           17.900638700934728,
           17.92192617078378,
           17.943213640632834,
           17.964501110481887,
           17.985788580330944,
           18.007076050179997,
           18.028363520029053,
           18.049650989878106,
           18.07093845972716,
           18.092225929576216,
           18.113513399425273,
           18.134800869274322,
           18.15608833912338,
           18.17737580897243,
           18.19866327882149,
           18.21995074867054,
           18.241238218519598,
           18.26252568836865,
           18.283813158217708,
           18.30510062806676,
           18.326388097915817,
           18.34767556776487,
           18.368963037613927,
           18.39025050746298,
           18.411537977312033,
           18.43282544716109,
           18.454112917010143,
           18.475400386859196,
           18.496687856708252,
           18.517975326557305,
           18.539262796406362,
           18.560550266255415,
           18.58114319578033,
           18.601597217240418,
           18.622051238700504,
           18.64250526016059,
           18.662959281620676,
           18.683413303080762,
           18.703867324540848,
           18.724321346000934,
           18.74477536746102,
           18.765229388921107,
           18.785683410381193,
           18.80613743184128,
           18.82659145330137,
           18.84704547476145,
           18.86749949622154,
           18.887953517681623,
           18.908407539141713,
           18.9288615606018,
           18.949315582061885,
           18.96976960352197,
           18.990223624982058,
           19.010677646442144,
           19.03113166790223,
           19.051585689362316,
           19.072039710822402,
           19.092493732282488,
           19.112947753742574,
           19.133401775202664,
           19.153855796662747,
           19.174309818122836,
           19.194763839582922,
           19.21521786104301,
           19.235671882503095,
           19.25612590396318,
           19.276579925423267,
           19.297033946883353,
           19.317487968343443,
           19.337941989803525,
           19.358396011263615,
           19.378850032723697,
           19.399304054183787,
           19.419758075643873,
           19.44021209710396,
           19.460666118564045,
           19.48112014002413,
           19.501574161484218,
           19.522028182944304,
           19.542482204404394,
           19.562936225864476,
           19.583390247324566,
           19.60384426878465,
           19.624298290244734,
           19.64475231170482,
           19.665206333164907,
           19.685660354624996,
           19.706114376085083,
           19.726568397545165,
           19.747022419005255,
           19.76747644046534,
           19.787930461925427,
           19.808384483385513,
           19.8288385048456,
           19.849292526305685,
           19.86974654776577,
           19.889302057112143,
           19.907060551571092,
           19.924819046030038,
           19.942577540488983,
           19.960336034947932,
           19.978094529406878,
           19.995853023865827,
           20.013611518324772,
           20.031370012783718,
           20.049128507242667,
           20.066887001701613,
           20.08464549616056,
           20.102403990619507,
           20.120162485078453,
           20.1379209795374,
           20.155679473996347,
           20.173437968455296,
           20.19119646291424,
           20.208954957373187,
           20.229790883187757,
           20.252165524680137,
           20.274540166172514,
           20.296914807664894,
           20.31928944915727,
           20.34166409064965,
           20.364038732142028,
           20.386413373634404,
           20.408788015126785,
           20.43116265661916,
           20.45353729811154,
           20.475911939603918,
           20.4982865810963,
           20.52066122258868,
           20.543035864081055,
           20.565410505573432,
           20.58778514706581,
           20.610159788558192,
           20.63253443005057,
           20.654909071542946,
           20.67728371303533,
           20.699658354527703,
           20.722032996020083,
           20.74440763751246,
           20.766782279004836,
           20.78915692049722,
           20.811531561989597,
           20.833906203481973,
           20.856280844974357,
           20.878655486466734,
           20.901030127959107,
           20.923404769451487,
           20.945779410943864,
           20.968154052436248,
           20.99052869392862,
           21.012903335421,
           21.035277976913378,
           21.057652618405758,
           21.080027259898134,
           21.102401901390515,
           21.12477654288289,
           21.14715118437527,
           21.169525825867648,
           21.19190046736003,
           21.214275108852405,
           21.237178392718548,
           21.2606690626234,
           21.284159732528245,
           21.307650402433097,
           21.33114107233795,
           21.354631742242795,
           21.378122412147647,
           21.401613082052496,
           21.425103751957344,
           21.448594421862197,
           21.472085091767045,
           21.495575761671894,
           21.519066431576743,
           21.54255710148159,
           21.566047771386444,
           21.589538441291293,
           21.61302911119614,
           21.63651978110099,
           21.660010451005842,
           21.683501120910687,
           21.706991790815543,
           21.73048246072039,
           21.75397313062524,
           21.777463800530086,
           21.800954470434938,
           21.824445140339783,
           21.847935810244635,
           21.871426480149488,
           21.894917150054336,
           21.918407819959185,
           21.941898489864034,
           21.965389159768883,
           21.988879829673735,
           22.012370499578584,
           22.035861169483436,
           22.059351839388285,
           22.082842509293133,
           22.106333179197986,
           22.13326146078547,
           22.163627354055592,
           22.193993247325714,
           22.224359140595833,
           22.25472503386596,
           22.285090927136082,
           22.315456820406204,
           22.34582271367633,
           22.376188606946457,
           22.406554500216572,
           22.4369203934867,
           22.467286286756824,
           22.497652180026947,
           22.52801807329707,
           22.55838396656719,
           22.588749859837314,
           22.619115753107437,
           22.64948164637756,
           22.67984753964768,
           22.710213432917804,
           22.74057932618793,
           22.770945219458056,
           22.801311112728175,
           22.8316770059983,
           22.86204289926842,
           22.892408792538546,
           22.92277468580867,
           22.95314057907879,
           22.983506472348914,
           23.013872365619036,
           23.04423825888916,
           23.074604152159285,
           23.104970045429404,
           23.135335938699527,
           23.165701831969656,
           23.19606772523978,
           23.226433618509898,
           23.256799511780024,
           23.287165405050146,
           23.317531298320265,
           23.34789719159039,
           23.378263084860514,
           23.408628978130633,
           23.43899487140076,
           23.46936076467088,
           23.499726657941004,
           23.530092551211126,
           23.560458444481252,
           23.590824337751375,
           23.621190231021494,
           23.651556124291623,
           23.681922017561742,
           23.71228791083186,
           23.74265380410199,
           23.773019697372114,
           23.80338559064223,
           23.83375148391236,
           23.86411737718248,
           23.894483270452604,
           23.924849163722726,
           23.955215056992852,
           23.98558095026297,
           24.015946843533094,
           24.04631273680322,
           24.07667863007334,
           24.107044523343465,
           24.137410416613587,
           24.167776309883713,
           24.198142203153832,
           24.22850809642396,
           24.25887398969408,
           24.289239882964203,
           24.319605776234326,
           24.34997166950445,
           24.380337562774574,
           24.410703456044693,
           24.44106934931482,
           24.470814111213283,
           24.500345920140948,
           24.529877729068623,
           24.559409537996295,
           24.588941346923967,
           24.618473155851635,
           24.639277344546855,
           24.642626292777177,
           24.645975241007495,
           24.649324189237813,
           24.65267313746813,
           24.65602208569845,
           24.65937103392877,
           24.66271998215909,
           24.666068930389407,
           24.669417878619726,
           24.672766826850044,
           24.676115775080362,
           24.679464723310684,
           24.682813671541002,
           24.684808267063534,
           24.686028919799714,
           24.687249572535887,
           24.688470225272066,
           24.689690878008243,
           24.690911530744415,
           24.692132183480595,
           24.693352836216768,
           24.69457348895295,
           24.695794141689127,
           24.697014794425304,
           24.69823544716148,
           24.69945609989766,
           24.700676752633836,
           24.70189740537001,
           24.703118058106188,
           24.704338710842364,
           24.705559363578544,
           24.706780016314717,
           24.708000669050897,
           24.709221321787073,
           24.71044197452325,
           24.71166262725943,
           24.7128832799956,
           24.71410393273178,
           24.71532458546796,
           24.716545238204134,
           24.71776589094031,
           24.71898654367649,
           24.720207196412666,
           24.721427849148846,
           24.72264850188502,
           24.723869154621198,
           24.725089807357374,
           24.72631046009355,
           24.727531112829723,
           24.728751765565907,
           24.729972418302083,
           24.731193071038263,
           24.732413723774435,
           24.73363437651061,
           24.734855029246795,
           24.736075681982967,
           24.73729633471914,
           24.73851698745532,
           24.739737640191496,
           24.74095829292768,
           24.742178945663852,
           24.743399598400025,
           24.74462025113621,
           24.745840903872384,
           24.747061556608564,
           24.748282209344737,
           24.749502862080917,
           24.750723514817093,
           24.75194416755327,
           24.753164820289445,
           24.75438547302562,
           24.7556061257618,
           24.756826778497974,
           24.758047431234154,
           24.75926808397033,
           24.760488736706506,
           24.761709389442686,
           24.762930042178862,
           24.76415069491504,
           24.765371347651215,
           24.766592000387394,
           24.767812653123567,
           24.7314788147,
           24.5073725204777,
           24.283266226255392,
           24.05915993203309,
           23.83505363781083,
           23.610947343588528,
           23.38684104936622,
           23.162734755143962,
           22.93862846092166,
           22.714522166699357,
           22.490415872477094,
           22.26630957825479,
           22.04220328403249,
           21.818096989810183,
           21.604309712974977,
           21.40001602208221,
           21.195722331189437,
           20.9914286402967,
           20.787134949403928,
           20.582841258511156,
           20.378547567618416,
           20.174253876725647,
           19.969960185832875,
           19.765666494940135,
           19.561372804047366,
           19.35707911315459,
           19.152785422261818,
           18.94849173136908,
           18.74419804047631,
           18.539904349583537,
           18.3356106586908,
           18.13131696779803,
           17.927023276905253,
           17.72272958601252,
           17.518435895119747,
           17.314142204226975,
           17.1098485133342,
           16.905554822441466,
           16.701261131548694,
           16.496967440655922,
           16.292673749763185,
           16.088380058870413,
           15.88408636797764,
           15.679792677084905,
           15.47549898619213,
           15.27120529529936,
           15.066911604406625,
           14.862617913513851,
           14.658324222621077,
           14.454030531728304,
           14.24973684083557,
           14.045443149942797,
           13.841149459050024,
           13.63685576815729,
           13.432562077264514,
           13.228268386371743,
           13.023974695479009,
           12.819681004586233,
           12.615387313693462,
           12.411093622800689,
           12.206799931907955,
           12.00250624101518,
           11.798212550122408,
           11.593918859229673,
           11.389625168336899,
           11.185331477444127,
           10.98103778655139,
           10.776744095658618,
           10.572450404765846,
           10.36815671387311,
           10.169995024371232,
           9.975196010547853,
           9.780396996724473,
           9.58559798290113,
           9.39079896907775,
           9.195999955254372,
           9.001200941431026,
           8.806401927607645,
           8.611602913784267,
           8.416803899960923,
           8.222004886137544,
           8.027205872314163,
           7.832406858490783,
           7.637607844667439
          ],
          [
           17.31464420481126,
           17.33317284536669,
           17.35170148592212,
           17.372529146198296,
           17.39381661604735,
           17.415104085896402,
           17.43639155574546,
           17.457679025594512,
           17.478966495443565,
           17.50025396529262,
           17.521541435141675,
           17.54282890499073,
           17.564116374839784,
           17.58540384468884,
           17.606691314537894,
           17.62797878438695,
           17.649266254236004,
           17.670553724085057,
           17.691841193934113,
           17.713128663783166,
           17.734416133632223,
           17.755703603481276,
           17.77699107333033,
           17.798278543179386,
           17.81956601302844,
           17.840853482877492,
           17.86214095272655,
           17.883428422575605,
           17.90471589242466,
           17.92600336227371,
           17.947290832122768,
           17.96857830197182,
           17.989865771820874,
           18.01115324166993,
           18.032440711518987,
           18.05372818136804,
           18.075015651217093,
           18.09630312106615,
           18.117590590915206,
           18.138878060764256,
           18.160165530613313,
           18.18145300046237,
           18.202740470311422,
           18.224027940160475,
           18.245315410009532,
           18.266602879858585,
           18.28789034970764,
           18.309177819556695,
           18.33046528940575,
           18.351752759254804,
           18.373040229103857,
           18.394327698952914,
           18.41561516880197,
           18.436902638651024,
           18.458190108500077,
           18.47947757834913,
           18.500765048198186,
           18.52205251804724,
           18.543339987896296,
           18.56462745774535,
           18.585914927594402,
           18.60720239744346,
           18.628489867292515,
           18.64977733714157,
           18.67106480699062,
           18.692352276839678,
           18.71363974668873,
           18.734927216537784,
           18.75621468638684,
           18.777502156235894,
           18.79878962608495,
           18.820077095934003,
           18.84136456578306,
           18.862652035632113,
           18.88393950548117,
           18.905226975330223,
           18.926514445179276,
           18.947801915028332,
           18.969089384877385,
           18.99037685472644,
           19.011664324575495,
           19.032951794424548,
           19.054239264273605,
           19.075526734122658,
           19.096119663647574,
           19.11657368510766,
           19.137027706567746,
           19.157481728027832,
           19.17793574948792,
           19.198389770948005,
           19.21884379240809,
           19.239297813868177,
           19.259751835328263,
           19.28020585678835,
           19.300659878248435,
           19.32111389970852,
           19.34156792116861,
           19.362021942628694,
           19.382475964088783,
           19.402929985548866,
           19.423384007008956,
           19.44383802846904,
           19.464292049929128,
           19.484746071389214,
           19.5052000928493,
           19.525654114309386,
           19.546108135769472,
           19.56656215722956,
           19.587016178689645,
           19.60747020014973,
           19.627924221609817,
           19.648378243069907,
           19.66883226452999,
           19.68928628599008,
           19.709740307450165,
           19.73019432891025,
           19.750648350370337,
           19.771102371830423,
           19.79155639329051,
           19.812010414750596,
           19.832464436210685,
           19.852918457670768,
           19.873372479130857,
           19.89382650059094,
           19.91428052205103,
           19.934734543511116,
           19.955188564971202,
           19.975642586431288,
           19.996096607891374,
           20.01655062935146,
           20.037004650811546,
           20.057458672271636,
           20.07791269373172,
           20.098366715191805,
           20.11882073665189,
           20.139274758111977,
           20.159728779572063,
           20.18018280103215,
           20.20063682249224,
           20.221090843952325,
           20.241544865412408,
           20.261998886872497,
           20.282452908332584,
           20.30290692979267,
           20.323360951252756,
           20.343814972712842,
           20.364268994172928,
           20.384723015633014,
           20.4051770370931,
           20.425631058553186,
           20.446085080013273,
           20.46653910147336,
           20.48699312293345,
           20.50744714439353,
           20.52790116585362,
           20.548355187313707,
           20.568809208773793,
           20.58926323023388,
           20.609717251693965,
           20.63017127315405,
           20.650625294614137,
           20.671079316074223,
           20.69153333753431,
           20.711987358994396,
           20.732441380454482,
           20.750649124830638,
           20.768407619289587,
           20.789243545104153,
           20.81161818659653,
           20.83399282808891,
           20.856367469581286,
           20.878742111073663,
           20.901586654725158,
           20.925077324630006,
           20.94856799453486,
           20.972058664439707,
           20.995549334344556,
           21.019040004249405,
           21.042530674154253,
           21.066021344059102,
           21.089512013963954,
           21.1130026838688,
           21.136493353773652,
           21.1599840236785,
           21.18347469358335,
           21.2069653634882,
           21.230456033393054,
           21.2539467032979,
           21.277437373202748,
           21.3009280431076,
           21.32441871301245,
           21.347909382917297,
           21.371400052822146,
           21.394890722727,
           21.418381392631847,
           21.441872062536696,
           21.465362732441548,
           21.488853402346393,
           21.512344072251246,
           21.53583474215609,
           21.559325412060943,
           21.58281608196579,
           21.606306751870644,
           21.629797421775493,
           21.65328809168034,
           21.67677876158519,
           21.70026943149004,
           21.723760101394888,
           21.74725077129974,
           21.77074144120459,
           21.79423211110944,
           21.81772278101429,
           21.84121345091914,
           21.864704120823987,
           21.88819479072884,
           21.911685460633684,
           21.935176130538537,
           21.958666800443385,
           21.982157470348234,
           22.005648140253083,
           22.029138810157935,
           22.052629480062784,
           22.076120149967632,
           22.09961081987248,
           22.123101489777333,
           22.146592159682182,
           22.17008282958703,
           22.19357349949188,
           22.21706416939673,
           22.24055483930158,
           22.264045509206433,
           22.287536179111278,
           22.31102684901613,
           22.334517518920975,
           22.358008188825828,
           22.381498858730676,
           22.404989528635525,
           22.428480198540377,
           22.451970868445226,
           22.475461538350075,
           22.498952208254924,
           22.52244287815978,
           22.545933548064625,
           22.569424217969473,
           22.592914887874322,
           22.616405557779174,
           22.639896227684023,
           22.66338689758887,
           22.68687756749372,
           22.71036823739857,
           22.737296518986057,
           22.767662412256183,
           22.798028305526305,
           22.828394198796428,
           22.85876009206655,
           22.889125985336673,
           22.91949187860679,
           22.949857771876918,
           22.980223665147044,
           23.010589558417163,
           23.04095545168729,
           23.07132134495741,
           23.101687238227534,
           23.132053131497656,
           23.162419024767782,
           23.1927849180379,
           23.223150811308024,
           23.25351670457815,
           23.283882597848272,
           23.314248491118395,
           23.34461438438852,
           23.374980277658644,
           23.405346170928762,
           23.43571206419889,
           23.46607795746901,
           23.496443850739134,
           23.526809744009256,
           23.55717563727938,
           23.5875415305495,
           23.617907423819624,
           23.64827331708975,
           23.678639210359876,
           23.70900510362999,
           23.739370996900114,
           23.769736890170243,
           23.800102783440362,
           23.83046867671049,
           23.86083456998061,
           23.89120046325073,
           23.921566356520856,
           23.95193224979098,
           23.9822981430611,
           24.01266403633122,
           24.043029929601346,
           24.073395822871476,
           24.10376171614159,
           24.134127609411713,
           24.16449350268184,
           24.194859395951962,
           24.225225289222085,
           24.25559118249221,
           24.28595707576233,
           24.316322969032452,
           24.346688862302578,
           24.377054755572704,
           24.40742064884282,
           24.43778654211295,
           24.468152435383068,
           24.498518328653194,
           24.528884221923313,
           24.561429248315765,
           24.594115374575633,
           24.626801500835498,
           24.65948762709537,
           24.692173753355235,
           24.7248598796151,
           24.75754600587497,
           24.79023213213484,
           24.8229182583947,
           24.855604384654573,
           24.88829051091444,
           24.920976637174306,
           24.95366276343417,
           24.986348889694042,
           25.019035015953907,
           25.051721142213776,
           25.084407268473644,
           25.117093394733512,
           25.149779520993373,
           25.182465647253245,
           25.215151773513117,
           25.24783789977298,
           25.28052402603285,
           25.29931348903841,
           25.290309625535393,
           25.281305762032368,
           25.27230189852935,
           25.263298035026327,
           25.254294171523302,
           25.24529030802028,
           25.236286444517255,
           25.227282581014233,
           25.21827871751121,
           25.209274854008186,
           25.200270990505164,
           25.19126712700214,
           25.182263263499117,
           25.173259399996095,
           25.16425553649307,
           25.155251672990047,
           25.146247809487026,
           25.137243945984004,
           25.128240082480982,
           25.119236218977957,
           25.110232355474935,
           25.101228491971913,
           25.092224628468887,
           25.083220764965866,
           25.074216901462844,
           25.065213037959822,
           25.056209174456797,
           25.04720531095377,
           25.038201447450753,
           25.02919758394773,
           25.020193720444702,
           25.011189856941684,
           25.012252753459617,
           25.013473406195796,
           25.01469405893197,
           25.01591471166815,
           25.017135364404325,
           25.0183560171405,
           25.019576669876677,
           25.020797322612857,
           25.02201797534903,
           25.023238628085213,
           25.024459280821386,
           25.025679933557566,
           25.026900586293742,
           25.028121239029918,
           25.029341891766094,
           25.03056254450227,
           25.031783197238447,
           25.033003849974627,
           25.034224502710803,
           25.035445155446983,
           25.03666580818316,
           25.03788646091933,
           25.03910711365551,
           25.040327766391687,
           25.041548419127864,
           25.042769071864043,
           25.04398972460022,
           25.045210377336396,
           25.046431030072572,
           25.04765168280875,
           25.04887233554493,
           25.050092988281104,
           25.05131364101728,
           25.05253429375346,
           25.053754946489637,
           25.054975599225816,
           25.05619625196199,
           25.057416904698165,
           25.058637557434345,
           25.059858210170525,
           25.061078862906697,
           25.062299515642877,
           25.06352016837905,
           25.06474082111523,
           25.06596147385141,
           25.067182126587582,
           25.068402779323762,
           25.069623432059934,
           25.070844084796114,
           25.072064737532287,
           25.03573089910872,
           24.81162460488642,
           24.587518310664112,
           24.363412016441814,
           24.13930572221955,
           23.915199427997248,
           23.69109313377494,
           23.466986839552682,
           23.24288054533038,
           23.018774251108077,
           22.794667956885814,
           22.57056166266351,
           22.346455368441205,
           22.122349074218903,
           21.898242779996643,
           21.67413648577434,
           21.450030191552038,
           21.22592389732978,
           21.001817603107476,
           20.777711308885173,
           20.553605014662907,
           20.329498720440604,
           20.1053924262183,
           19.88128613199604,
           19.65717983777374,
           19.433073543551433,
           19.20896724932913,
           18.984860955106868,
           18.760754660884565,
           18.536648366662263,
           18.312542072440003,
           18.088435778217697,
           17.864329483995395,
           17.64022318977313,
           17.416116895550832,
           17.192010601328526,
           16.967904307106224,
           16.744451050940448,
           16.528181195573445,
           16.31191134020644,
           16.095641484839476,
           15.87937162947247,
           15.663101774105463,
           15.446831918738496,
           15.23056206337149,
           15.014292208004486,
           14.799811585363527,
           14.605012571540147,
           14.410213557716768,
           14.215414543893386,
           14.020615530070042,
           13.825816516246663,
           13.631017502423283,
           13.43621848859994,
           13.24141947477656,
           13.046620460953182,
           12.851821447129836,
           12.657022433306457,
           12.462223419483077,
           12.267424405659696,
           12.072625391836354,
           11.877826378012973,
           11.683027364189593,
           11.48822835036625,
           11.293429336542872,
           11.09863032271949,
           10.903831308896146,
           10.709032295072767,
           10.514233281249385,
           10.319434267426043,
           10.124635253602662,
           9.929836239779284,
           9.735037225955905,
           9.54023821213256,
           9.34543919830918,
           9.150640184485802,
           8.955841170662456,
           8.761042156839077,
           8.566243143015697,
           8.371444129192353,
           8.176645115368974,
           7.981846101545594,
           7.787047087722215,
           7.592248073898871
          ],
          [
           17.782815300343746,
           17.8041027701928,
           17.825390240041852,
           17.84667770989091,
           17.86796517973996,
           17.889252649589018,
           17.91054011943807,
           17.931827589287124,
           17.95311505913618,
           17.974402528985237,
           17.99568999883429,
           18.016977468683343,
           18.0382649385324,
           18.059552408381457,
           18.08083987823051,
           18.102127348079563,
           18.123414817928616,
           18.144702287777672,
           18.165989757626726,
           18.187277227475782,
           18.20856469732484,
           18.229852167173892,
           18.251139637022945,
           18.272427106872,
           18.29371457672105,
           18.315002046570108,
           18.336289516419164,
           18.357576986268217,
           18.378864456117274,
           18.400151925966327,
           18.42143939581538,
           18.442726865664437,
           18.46401433551349,
           18.485301805362546,
           18.5065892752116,
           18.527876745060652,
           18.54916421490971,
           18.570451684758766,
           18.591739154607822,
           18.61302662445687,
           18.634314094305928,
           18.65560156415498,
           18.676889034004038,
           18.69817650385309,
           18.719463973702148,
           18.7407514435512,
           18.762038913400254,
           18.783326383249307,
           18.80461385309836,
           18.825901322947416,
           18.847188792796473,
           18.868476262645526,
           18.88976373249458,
           18.911051202343636,
           18.93233867219269,
           18.953626142041745,
           18.9749136118908,
           18.996201081739855,
           19.017488551588908,
           19.038776021437965,
           19.060063491287018,
           19.081350961136074,
           19.102638430985127,
           19.12392590083418,
           19.145213370683237,
           19.166500840532294,
           19.187788310381347,
           19.2090757802304,
           19.230363250079456,
           19.25207311643147,
           19.27589499006161,
           19.299716863691746,
           19.323538737321883,
           19.34736061095202,
           19.37118248458216,
           19.3950043582123,
           19.418826231842438,
           19.442648105472575,
           19.466469979102712,
           19.490291852732852,
           19.51411372636299,
           19.537935599993126,
           19.561757473623267,
           19.585579347253404,
           19.608744259461755,
           19.63177777938575,
           19.654811299309742,
           19.677844819233734,
           19.70087833915773,
           19.723911859081724,
           19.746945379005716,
           19.769978898929708,
           19.793012418853703,
           19.816045938777695,
           19.839079458701686,
           19.862112978625678,
           19.885146498549677,
           19.90818001847367,
           19.92992378496505,
           19.950377806425138,
           19.970831827885224,
           19.99128584934531,
           20.011739870805396,
           20.032193892265482,
           20.052647913725565,
           20.073101935185655,
           20.09355595664574,
           20.114009978105827,
           20.134463999565916,
           20.154918021026003,
           20.17537204248609,
           20.195826063946175,
           20.21628008540626,
           20.236734106866347,
           20.257188128326433,
           20.27764214978652,
           20.298096171246605,
           20.31855019270669,
           20.339004214166778,
           20.359458235626864,
           20.37991225708695,
           20.400366278547036,
           20.420820300007122,
           20.44127432146721,
           20.461728342927294,
           20.482182364387384,
           20.50263638584747,
           20.523090407307556,
           20.543544428767643,
           20.56399845022773,
           20.584452471687815,
           20.6049064931479,
           20.625360514607987,
           20.645814536068073,
           20.66626855752816,
           20.686722578988245,
           20.70717660044833,
           20.727630621908418,
           20.748084643368504,
           20.76853866482859,
           20.78899268628868,
           20.809446707748762,
           20.829900729208852,
           20.850354750668934,
           20.870808772129024,
           20.89126279358911,
           20.911716815049196,
           20.932170836509286,
           20.95262485796937,
           20.97307887942946,
           20.99353290088954,
           21.013986922349627,
           21.034440943809717,
           21.054894965269803,
           21.07534898672989,
           21.095803008189975,
           21.116257029650058,
           21.136711051110147,
           21.15716507257023,
           21.17761909403032,
           21.198073115490406,
           21.21852713695049,
           21.238981158410578,
           21.259435179870664,
           21.27988920133075,
           21.300343222790836,
           21.320797244250922,
           21.344183537653517,
           21.369035967027358,
           21.393888396401202,
           21.418740825775046,
           21.443593255148883,
           21.468445684522727,
           21.493298113896568,
           21.518150543270412,
           21.543002972644253,
           21.567855402018097,
           21.59270783139194,
           21.61756026076578,
           21.642412690139622,
           21.667265119513466,
           21.692117548887307,
           21.71696997826115,
           21.74182240763499,
           21.766674837008836,
           21.791527266382676,
           21.816379695756517,
           21.84123212513036,
           21.866084554504205,
           21.890936983878042,
           21.915789413251886,
           21.94064184262573,
           21.96549427199957,
           21.990346701373415,
           22.015199130747256,
           22.0400515601211,
           22.064903989494937,
           22.08975641886878,
           22.114608848242625,
           22.139461277616466,
           22.163360470261544,
           22.18685114016639,
           22.21034181007124,
           22.233832479976094,
           22.25732314988094,
           22.28081381978579,
           22.30430448969064,
           22.32779515959549,
           22.35128582950034,
           22.374776499405193,
           22.39826716931004,
           22.42175783921489,
           22.445248509119736,
           22.46873917902459,
           22.492229848929433,
           22.515720518834286,
           22.539211188739134,
           22.562701858643987,
           22.586192528548835,
           22.609683198453684,
           22.633173868358533,
           22.656664538263385,
           22.680155208168234,
           22.703645878073083,
           22.72713654797793,
           22.75062721788278,
           22.774117887787632,
           22.79760855769248,
           22.82109922759733,
           22.844589897502175,
           22.868080567407027,
           22.891571237311876,
           22.915061907216725,
           22.938552577121577,
           22.962043247026426,
           22.98553391693128,
           23.009024586836127,
           23.03251525674098,
           23.056005926645827,
           23.079496596550676,
           23.102987266455525,
           23.126477936360374,
           23.149968606265226,
           23.17345927617007,
           23.196949946074923,
           23.22044061597977,
           23.24393128588462,
           23.267421955789473,
           23.29091262569432,
           23.31440329559917,
           23.341331577186658,
           23.37169747045678,
           23.402063363726903,
           23.432429256997025,
           23.462795150267148,
           23.49316104353727,
           23.523526936807396,
           23.55389283007752,
           23.58425872334764,
           23.61462461661776,
           23.644990509887887,
           23.675356403158013,
           23.70572229642813,
           23.736088189698254,
           23.76645408296838,
           23.796819976238503,
           23.827185869508625,
           23.85755176277875,
           23.88791765604887,
           23.918283549318993,
           23.948649442589115,
           23.979015335859245,
           24.00938122912936,
           24.039747122399486,
           24.070113015669612,
           24.100478908939735,
           24.130844802209857,
           24.16121069547998,
           24.191576588750102,
           24.22194248202022,
           24.252308375290347,
           24.282674268560477,
           24.313040161830596,
           24.34340605510072,
           24.37512018704584,
           24.40780631330571,
           24.440492439565574,
           24.473178565825442,
           24.50586469208531,
           24.53855081834518,
           24.571236944605047,
           24.603923070864912,
           24.636609197124777,
           24.669295323384645,
           24.70198144964452,
           24.734667575904382,
           24.76735370216425,
           24.800039828424122,
           24.832725954683987,
           24.865412080943855,
           24.898098207203724,
           24.930784333463592,
           24.963470459723453,
           24.996156585983325,
           25.028842712243193,
           25.061528838503058,
           25.094214964762926,
           25.126901091022795,
           25.159587217282663,
           25.192273343542528,
           25.2249594698024,
           25.257645596062265,
           25.29033172232213,
           25.323017848581998,
           25.355703974841866,
           25.38839010110173,
           25.4210762273616,
           25.45376235362147,
           25.486448479881332,
           25.5191346061412,
           25.551820732401072,
           25.584506858660937,
           25.617192984920806,
           25.64987911118067,
           25.68256523744054,
           25.715251363700403,
           25.747937489960275,
           25.78062361622014,
           25.81330974248001,
           25.845995868739877,
           25.878681994999745,
           25.911368121259613,
           25.944054247519475,
           25.962843710525046,
           25.953839847022024,
           25.944835983519,
           25.935832120015974,
           25.926828256512955,
           25.917824393009933,
           25.90882052950691,
           25.899816666003886,
           25.89081280250086,
           25.88180893899784,
           25.872805075494817,
           25.86380121199179,
           25.854797348488773,
           25.845793484985748,
           25.836789621482726,
           25.827785757979704,
           25.81878189447668,
           25.809778030973657,
           25.800774167470635,
           25.791770303967617,
           25.78276644046459,
           25.773762576961566,
           25.76475871345854,
           25.755754849955515,
           25.746750986452497,
           25.73774712294947,
           25.728743259446453,
           25.719739395943428,
           25.710735532440406,
           25.701731668937384,
           25.692727805434355,
           25.683723941931337,
           25.674720078428315,
           25.66571621492529,
           25.656712351422264,
           25.647708487919246,
           25.63870462441622,
           25.629700760913195,
           25.620696897410177,
           25.61169303390715,
           25.602689170404133,
           25.593685306901108,
           25.584681443398082,
           25.57567757989506,
           25.566673716392035,
           25.557669852889013,
           25.54866598938599,
           25.53966212588297,
           25.53065826237995,
           25.521654398876926,
           25.5126505353739,
           25.503646671870875,
           25.494642808367853,
           25.48563894486483,
           25.476635081361813,
           25.467631217858788,
           25.458627354355762,
           25.44962349085274,
           25.44061962734972,
           25.431615763846693,
           25.422611900343675,
           25.413608036840653,
           25.404604173337624,
           25.395600309834606,
           25.38659644633158,
           25.377592582828555,
           25.368588719325533,
           25.359584855822515,
           25.35922768363454,
           25.360448336370712,
           25.361668989106892,
           25.36288964184307,
           25.36411029457925,
           25.36533094731542,
           25.366551600051597,
           25.367772252787777,
           25.368992905523957,
           25.370213558260133,
           25.37143421099631,
           25.37265486373249,
           25.37387551646866,
           25.375096169204845,
           25.376316821941014,
           25.339982983517444,
           25.115876689295142,
           24.89177039507284,
           24.66766410085054,
           24.443557806628274,
           24.21945151240597,
           23.99534521818367,
           23.77123892396141,
           23.547132629739107,
           23.323026335516804,
           23.098920041294544,
           22.874813747072235,
           22.656390623348763,
           22.440120767981757,
           22.223850912614793,
           22.007581057247787,
           21.79131120188078,
           21.575041346513814,
           21.358771491146808,
           21.1425016357798,
           20.926231780412838,
           20.709961925045832,
           20.493692069678826,
           20.27742221431186,
           20.061152358944856,
           19.84488250357785,
           19.628612648210847,
           19.412342792843877,
           19.19607293747687,
           18.979803082109864,
           18.7635332267429,
           18.547263371375895,
           18.33099351600889,
           18.114723660641925,
           17.89845380527492,
           17.682183949907913,
           17.465914094540906,
           17.249644239173943,
           17.033374383806937,
           16.817104528439934,
           16.600834673072967,
           16.38456481770596,
           16.168294962338955,
           15.95202510697199,
           15.735755251604981,
           15.519485396237979,
           15.303215540871014,
           15.086945685504007,
           14.870675830137001,
           14.654405974769997,
           14.43813611940303,
           14.221866264036024,
           14.005596408669017,
           13.789326553302054,
           13.573056697935048,
           13.356786842568042,
           13.140516987201078,
           12.924247131834068,
           12.707977276467064,
           12.491707421100058,
           12.275437565733094,
           12.05916771036609,
           11.842897854999084,
           11.626627999632117,
           11.410358144265112,
           11.194088288898106,
           10.97781843353114,
           10.761548578164136,
           10.54527872279713,
           10.329008867430165,
           10.112739012063159,
           9.896469156696153,
           9.689677455187335,
           9.49487844136399,
           9.30007942754061,
           9.10528041371723,
           8.910481399893886,
           8.715682386070506,
           8.520883372247127,
           8.326084358423783,
           8.131285344600403,
           7.936486330777023,
           7.7416873169536435,
           7.5468883031303
          ],
          [
           18.25079219829314,
           18.272079668142197,
           18.29336713799125,
           18.314654607840307,
           18.33594207768936,
           18.357229547538417,
           18.37851701738747,
           18.399804487236523,
           18.42109195708558,
           18.442379426934636,
           18.463666896783685,
           18.484954366632742,
           18.5062418364818,
           18.52752930633085,
           18.548816776179905,
           18.57010424602896,
           18.591391715878014,
           18.61267918572707,
           18.633966655576124,
           18.65525412542518,
           18.676541595274234,
           18.697829065123287,
           18.719116534972343,
           18.7404040048214,
           18.76169147467045,
           18.782978944519506,
           18.804266414368563,
           18.825553884217616,
           18.846841354066672,
           18.868128823915725,
           18.88941629376478,
           18.910703763613835,
           18.931991233462888,
           18.953278703311945,
           18.974566173160998,
           18.99585364301005,
           19.017141112859107,
           19.03842858270816,
           19.05971605255722,
           19.08100352240627,
           19.102290992255323,
           19.123578462104376,
           19.144865931953433,
           19.166153401802486,
           19.187440871651546,
           19.2087283415006,
           19.230015811349652,
           19.251303281198705,
           19.27259075104776,
           19.293878220896815,
           19.315165690745868,
           19.336453160594925,
           19.357740630443978,
           19.38071769910471,
           19.40453957273485,
           19.42836144636499,
           19.452183319995125,
           19.476005193625266,
           19.499827067255403,
           19.523648940885543,
           19.54747081451568,
           19.57129268814582,
           19.595114561775958,
           19.618936435406095,
           19.642758309036232,
           19.666580182666372,
           19.69040205629651,
           19.71422392992665,
           19.738045803556787,
           19.761867677186927,
           19.785689550817064,
           19.8095114244472,
           19.833333298077342,
           19.85715517170748,
           19.88097704533762,
           19.904798918967757,
           19.928620792597894,
           19.952442666228034,
           19.97626453985817,
           20.00008641348831,
           20.02390828711845,
           20.047730160748586,
           20.071552034378726,
           20.095373908008863,
           20.118538820217214,
           20.14157234014121,
           20.1646058600652,
           20.187639379989193,
           20.210672899913188,
           20.23370641983718,
           20.256739939761175,
           20.279773459685167,
           20.302806979609162,
           20.325840499533154,
           20.34887401945715,
           20.37190753938114,
           20.394941059305133,
           20.417974579229128,
           20.441008099153123,
           20.46404161907711,
           20.487075139001107,
           20.5101086589251,
           20.533142178849094,
           20.55617569877309,
           20.57920921869708,
           20.602242738621072,
           20.625276258545068,
           20.648309778469056,
           20.671343298393055,
           20.694376818317046,
           20.71741033824104,
           20.740443858165033,
           20.763477378089025,
           20.78651089801302,
           20.80954441416197,
           20.829998435622056,
           20.850452457082145,
           20.870906478542228,
           20.891360500002314,
           20.911814521462404,
           20.932268542922493,
           20.95272256438258,
           20.97317658584266,
           20.993630607302748,
           21.014084628762834,
           21.03453865022292,
           21.05499267168301,
           21.075446693143093,
           21.095900714603182,
           21.11635473606327,
           21.136808757523355,
           21.15726277898344,
           21.177716800443527,
           21.198170821903613,
           21.2186248433637,
           21.239078864823785,
           21.25953288628387,
           21.279986907743957,
           21.300440929204044,
           21.320894950664133,
           21.341348972124216,
           21.361802993584305,
           21.38225701504439,
           21.402711036504478,
           21.423165057964564,
           21.44361907942465,
           21.464073100884736,
           21.484527122344822,
           21.504981143804905,
           21.525435165264994,
           21.54588918672508,
           21.566343208185167,
           21.586797229645253,
           21.60725125110534,
           21.62770527256543,
           21.64815929402551,
           21.6686133154856,
           21.689067336945683,
           21.709521358405773,
           21.729975379865856,
           21.750429401325945,
           21.770883422786028,
           21.791337444246118,
           21.8117914657062,
           21.83224548716629,
           21.852699508626376,
           21.873153530086462,
           21.896539823489057,
           21.921392252862894,
           21.94624468223674,
           21.97109711161058,
           21.995949540984427,
           22.020801970358264,
           22.045654399732108,
           22.070506829105952,
           22.09535925847979,
           22.120211687853633,
           22.145064117227477,
           22.16991654660132,
           22.194768975975165,
           22.219621405349006,
           22.244473834722843,
           22.269326264096687,
           22.29417869347053,
           22.319031122844372,
           22.343883552218216,
           22.368735981592057,
           22.393588410965897,
           22.41844084033974,
           22.443293269713585,
           22.46814569908743,
           22.49299812846127,
           22.51785055783511,
           22.542702987208955,
           22.567555416582795,
           22.592407845956636,
           22.61726027533048,
           22.642112704704317,
           22.666965134078165,
           22.691817563452005,
           22.71666999282585,
           22.741522422199694,
           22.76637485157353,
           22.791227280947375,
           22.816079710321215,
           22.84093213969506,
           22.8657845690689,
           22.890636998442744,
           22.915489427816585,
           22.940341857190425,
           22.96519428656427,
           22.990046715938114,
           23.014899145311958,
           23.0397515746858,
           23.06460400405964,
           23.089456433433483,
           23.114308862807327,
           23.139161292181164,
           23.16401372155501,
           23.18886615092885,
           23.213718580302693,
           23.238571009676534,
           23.263423439050378,
           23.288275868424215,
           23.313128297798063,
           23.337980727171907,
           23.362833156545744,
           23.387685585919584,
           23.41253801529343,
           23.437390444667273,
           23.462242874041117,
           23.487095303414957,
           23.511947732788798,
           23.536800162162642,
           23.561652591536483,
           23.586505020910327,
           23.611357450284167,
           23.63620987965801,
           23.660040984846425,
           23.683531654751274,
           23.707022324656123,
           23.730512994560975,
           23.754003664465824,
           23.777494334370672,
           23.800985004275525,
           23.824475674180373,
           23.847966344085222,
           23.871457013990074,
           23.894947683894923,
           23.918438353799772,
           23.945366635387256,
           23.97573252865738,
           24.006098421927504,
           24.036464315197623,
           24.06683020846775,
           24.097196101737875,
           24.127561995007994,
           24.15792788827812,
           24.18881112577592,
           24.221497252035782,
           24.254183378295657,
           24.286869504555526,
           24.319555630815387,
           24.35224175707526,
           24.384927883335124,
           24.417614009594992,
           24.450300135854857,
           24.48298626211473,
           24.51567238837459,
           24.54835851463446,
           24.581044640894326,
           24.6137307671542,
           24.64641689341406,
           24.67910301967393,
           24.711789145933803,
           24.744475272193664,
           24.77716139845353,
           24.8098475247134,
           24.842533650973266,
           24.875219777233134,
           24.907905903493003,
           24.94059202975287,
           24.973278156012736,
           25.005964282272608,
           25.038650408532476,
           25.07133653479234,
           25.104022661052205,
           25.136708787312074,
           25.169394913571942,
           25.20208103983181,
           25.23476716609168,
           25.26745329235154,
           25.30013941861141,
           25.332825544871277,
           25.365511671131152,
           25.398197797391013,
           25.43088392365088,
           25.46357004991075,
           25.49625617617062,
           25.528942302430483,
           25.561628428690355,
           25.59431455495022,
           25.627000681210085,
           25.659686807469953,
           25.69237293372982,
           25.72505905998969,
           25.757745186249558,
           25.790431312509426,
           25.823117438769287,
           25.85580356502916,
           25.88848969128903,
           25.921175817548892,
           25.95386194380876,
           25.98654807006863,
           26.019234196328497,
           26.05192032258836,
           26.084606448848227,
           26.117292575108102,
           26.149978701367964,
           26.182664827627832,
           26.2153509538877,
           26.24803708014757,
           26.280723206407437,
           26.3134093326673,
           26.346095458927174,
           26.378781585187035,
           26.411467711446903,
           26.44415383770677,
           26.47683996396664,
           26.509526090226505,
           26.542212216486373,
           26.57489834274624,
           26.607584469006106,
           26.626373932011678,
           26.617370068508652,
           26.60836620500563,
           26.59936234150261,
           26.590358477999587,
           26.58135461449656,
           26.57235075099354,
           26.563346887490518,
           26.553595690456913,
           26.5412879606039,
           26.52898023075089,
           26.51667250089788,
           26.50436477104487,
           26.492057041191856,
           26.479749311338846,
           26.467441581485836,
           26.455133851632823,
           26.44282612177981,
           26.430518391926803,
           26.41821066207379,
           26.405902932220776,
           26.39359520236777,
           26.381287472514757,
           26.368979742661747,
           26.356672012808737,
           26.344364282955723,
           26.332056553102714,
           26.319748823249704,
           26.30744109339669,
           26.295133363543677,
           26.28282563369067,
           26.270517903837657,
           26.258210173984644,
           26.245902444131637,
           26.233594714278624,
           26.221286984425614,
           26.2089792545726,
           26.19667152471959,
           26.184363794866584,
           26.17205606501357,
           26.159748335160558,
           26.14744060530755,
           26.135132875454538,
           26.122825145601524,
           26.110517415748518,
           26.098209685895505,
           26.08590195604249,
           26.07359422618948,
           26.06128649633647,
           26.048978766483458,
           26.036671036630448,
           26.02436330677744,
           26.012055576924425,
           25.99974784707141,
           25.987440117218405,
           25.97513238736539,
           25.96282465751238,
           25.950516927659372,
           25.93820919780636,
           25.92590146795335,
           25.91359373810034,
           25.901286008247325,
           25.88897827839432,
           25.876670548541306,
           25.864362818688292,
           25.852055088835282,
           25.839747358982276,
           25.827439629129262,
           25.81513189927625,
           25.802824169423236,
           25.790516439570226,
           25.77820870971722,
           25.765900979864206,
           25.753593250011196,
           25.741285520158186,
           25.728977790305173,
           25.716670060452163,
           25.70436233059915,
           25.69205460074614,
           25.67974687089313,
           25.667439141040116,
           25.655131411187106,
           25.642823681334093,
           25.59190381338423,
           25.34792325495009,
           25.103942696515944,
           24.8599621380818,
           24.615981579647702,
           24.372001021213563,
           24.128020462779418,
           23.884039904345318,
           23.64005934591118,
           23.396078787477038,
           23.15209822904294,
           22.908117670608796,
           22.664137112174654,
           22.42015655374051,
           22.176175995306416,
           21.932195436872274,
           21.688214878438128,
           21.444234320004032,
           21.20025376156989,
           20.956273203135744,
           20.712292644701648,
           20.494868245071018,
           20.278598389704012,
           20.06232853433705,
           19.846058678970042,
           19.629788823603036,
           19.41351896823603,
           19.197249112869066,
           18.980979257502057,
           18.764709402135054,
           18.548439546768087,
           18.332169691401084,
           18.115899836034078,
           17.89962998066711,
           17.683360125300105,
           17.4670902699331,
           17.250820414566093,
           17.03455055919913,
           16.818280703832123,
           16.602010848465117,
           16.385740993098153,
           16.169471137731147,
           15.953201282364141,
           15.736931426997177,
           15.520661571630171,
           15.304391716263165,
           15.0881218608962,
           14.871852005529194,
           14.65558215016219,
           14.439312294795183,
           14.223042439428216,
           14.00677258406121,
           13.790502728694205,
           13.57423287332724,
           13.357963017960236,
           13.14169316259323,
           12.925423307226264,
           12.709153451859258,
           12.492883596492252,
           12.276613741125246,
           12.06034388575828,
           11.844074030391276,
           11.62780417502427,
           11.415772271753777,
           11.219844827343115,
           11.023917382932453,
           10.827989938521828,
           10.632062494111167,
           10.436135049700503,
           10.240207605289879,
           10.044280160879216,
           9.848352716468554,
           9.652425272057894,
           9.456497827647269,
           9.260570383236606,
           9.064642938825944,
           8.86871549441532,
           8.672788050004657,
           8.476860605593995,
           8.280933161183372,
           8.08500571677271,
           7.889078272362048,
           7.693150827951386,
           7.49722338354076
          ],
          [
           18.718769096242532,
           18.740056566091585,
           18.76134403594064,
           18.782631505789695,
           18.80391897563875,
           18.825206445487805,
           18.846493915336858,
           18.867781385185914,
           18.889068855034967,
           18.91035632488402,
           18.931643794733077,
           18.95293126458213,
           18.974218734431183,
           18.99550620428024,
           19.016793674129296,
           19.03808114397835,
           19.059368613827402,
           19.08065608367646,
           19.101943553525512,
           19.12323102337457,
           19.14451849322362,
           19.16580596307268,
           19.18709343292173,
           19.208380902770788,
           19.22966837261984,
           19.250955842468894,
           19.27224331231795,
           19.293530782167004,
           19.31481825201606,
           19.336105721865113,
           19.357393191714166,
           19.378680661563223,
           19.399968131412276,
           19.421255601261333,
           19.442543071110386,
           19.46383054095944,
           19.485540408147806,
           19.509362281777946,
           19.533184155408087,
           19.557006029038224,
           19.580827902668357,
           19.6046497762985,
           19.62847164992864,
           19.652293523558775,
           19.676115397188912,
           19.699937270819053,
           19.72375914444919,
           19.747581018079327,
           19.771402891709464,
           19.795224765339608,
           19.819046638969745,
           19.842868512599885,
           19.86669038623002,
           19.89051225986016,
           19.9143341334903,
           19.938156007120433,
           19.961977880750574,
           19.985799754380714,
           20.00962162801085,
           20.033443501640992,
           20.05726537527113,
           20.081087248901266,
           20.104909122531403,
           20.128730996161543,
           20.152552869791684,
           20.17637474342182,
           20.200196617051958,
           20.2240184906821,
           20.247840364312232,
           20.271662237942373,
           20.295484111572513,
           20.31930598520265,
           20.34312785883279,
           20.366949732462928,
           20.390771606093068,
           20.4145934797232,
           20.438415353353342,
           20.462237226983483,
           20.48605910061362,
           20.509880974243757,
           20.533702847873897,
           20.557524721504034,
           20.58134659513417,
           20.60516846876431,
           20.628333380972663,
           20.651366900896654,
           20.674400420820646,
           20.69743394074464,
           20.720467460668637,
           20.74350098059263,
           20.76653450051662,
           20.789568020440612,
           20.81260154036461,
           20.835635060288602,
           20.858668580212594,
           20.881702100136586,
           20.90473562006058,
           20.927769139984573,
           20.950802659908568,
           20.97383617983256,
           20.996869699756555,
           21.01990321968055,
           21.042936739604542,
           21.065970259528534,
           21.089003779452526,
           21.11203729937652,
           21.135070819300516,
           21.158104339224508,
           21.181137859148503,
           21.20417137907249,
           21.227204898996487,
           21.250238418920482,
           21.273271938844474,
           21.29630545876847,
           21.31933897869246,
           21.342372498616452,
           21.365406018540448,
           21.38843953846444,
           21.411473058388435,
           21.434506578312423,
           21.45754009823642,
           21.480573618160413,
           21.503607138084405,
           21.5266406580084,
           21.549674177932392,
           21.572707697856387,
           21.59574121778038,
           21.618774737704374,
           21.641808257628366,
           21.66484177755236,
           21.687875297476353,
           21.70961906481897,
           21.730073086279056,
           21.750527107739142,
           21.770981129199225,
           21.791435150659314,
           21.8118891721194,
           21.832343193579486,
           21.852797215039573,
           21.873251236499662,
           21.893705257959745,
           21.914159279419835,
           21.93461330087992,
           21.955067322340003,
           21.975521343800093,
           21.99597536526018,
           22.01642938672026,
           22.03688340818035,
           22.057337429640434,
           22.077791451100524,
           22.09824547256061,
           22.118699494020696,
           22.139153515480785,
           22.159607536940868,
           22.180061558400958,
           22.200515579861044,
           22.22096960132113,
           22.241423622781216,
           22.261877644241302,
           22.282331665701385,
           22.302785687161474,
           22.323239708621557,
           22.343693730081647,
           22.36414775154173,
           22.38460177300182,
           22.4050557944619,
           22.42550981592199,
           22.448896109324583,
           22.473748538698423,
           22.498600968072267,
           22.52345339744611,
           22.548305826819952,
           22.573158256193793,
           22.598010685567637,
           22.622863114941477,
           22.647715544315318,
           22.672567973689162,
           22.697420403063006,
           22.722272832436847,
           22.74712526181069,
           22.77197769118453,
           22.796830120558376,
           22.821682549932216,
           22.846534979306057,
           22.8713874086799,
           22.896239838053745,
           22.92109226742759,
           22.945944696801426,
           22.970797126175274,
           22.99564955554911,
           23.020501984922955,
           23.045354414296796,
           23.070206843670636,
           23.095059273044484,
           23.119911702418324,
           23.14476413179217,
           23.16961656116601,
           23.194468990539846,
           23.21932141991369,
           23.24417384928753,
           23.269026278661375,
           23.29387870803522,
           23.31873113740906,
           23.343583566782904,
           23.368435996156748,
           23.393288425530585,
           23.41814085490443,
           23.44299328427827,
           23.467845713652117,
           23.492698143025954,
           23.5175505723998,
           23.54240300177364,
           23.567255431147487,
           23.592107860521324,
           23.616960289895168,
           23.641812719269012,
           23.666665148642853,
           23.691517578016693,
           23.716370007390534,
           23.74122243676438,
           23.76607486613822,
           23.790927295512063,
           23.815779724885903,
           23.840632154259744,
           23.86548458363359,
           23.890337013007432,
           23.915189442381273,
           23.940041871755113,
           23.96489430112896,
           23.9897467305028,
           24.01499722909525,
           24.04132821389738,
           24.067659198699506,
           24.09399018350163,
           24.120321168303757,
           24.146652153105887,
           24.17298313790801,
           24.199314122710135,
           24.22564510751226,
           24.251976092314386,
           24.278307077116512,
           24.304638061918634,
           24.330969046720764,
           24.35730003152289,
           24.383631016325015,
           24.40996200112714,
           24.436292985929263,
           24.462623970731393,
           24.48895495553352,
           24.515285940335644,
           24.545749974452683,
           24.580347057884644,
           24.614944141316602,
           24.649541224748557,
           24.684138308180515,
           24.71873539161247,
           24.753332475044427,
           24.787929558476385,
           24.822526641908343,
           24.857123725340294,
           24.891720808772256,
           24.926317892204214,
           24.960914975636168,
           24.995512059068126,
           25.03010914250008,
           25.064706225932042,
           25.099303309363997,
           25.133900392795958,
           25.168497476227913,
           25.20309455965987,
           25.23769164309183,
           25.270788007883382,
           25.303446667444558,
           25.336105327005743,
           25.36876398656693,
           25.401422646128108,
           25.434081305689286,
           25.466739965250476,
           25.499398624811658,
           25.532057284372836,
           25.564715943934022,
           25.597374603495204,
           25.630033263056383,
           25.66269192261757,
           25.69535058217875,
           25.728009241739933,
           25.76066790130111,
           25.793326560862297,
           25.82598522042348,
           25.858643879984662,
           25.891302539545844,
           25.923961199107026,
           25.95661985866821,
           25.98927851822939,
           26.021937177790576,
           26.054595837351755,
           26.08725449691294,
           26.119913156474123,
           26.152571816035305,
           26.18523047559649,
           26.21788913515767,
           26.25054779471885,
           26.283206454280034,
           26.315865113841216,
           26.348523773402405,
           26.38118243296358,
           26.413841092524766,
           26.44649975208595,
           26.479158411647127,
           26.511817071208313,
           26.5444757307695,
           26.577134390330674,
           26.60979304989186,
           26.64245170945304,
           26.675110369014224,
           26.707769028575406,
           26.74042768813659,
           26.773086347697777,
           26.805745007258952,
           26.838403666820135,
           26.87106232638132,
           26.9037209859425,
           26.936379645503685,
           26.96903830506487,
           27.001696964626046,
           27.034355624187235,
           27.067014283748414,
           27.099672943309596,
           27.132331602870778,
           27.16499026243196,
           27.197648921993146,
           27.230307581554325,
           27.262966241115507,
           27.276702087315925,
           27.252592306794824,
           27.22848252627372,
           27.204372745752615,
           27.180262965231513,
           27.156153184710412,
           27.132043404189304,
           27.107933623668202,
           27.0838238431471,
           27.059714062626,
           27.035604282104895,
           27.01149450158379,
           26.987384721062693,
           26.963274940541588,
           26.939165160020487,
           26.915055379499382,
           26.890945598978284,
           26.86683581845718,
           26.842726037936075,
           26.818616257414973,
           26.79450647689387,
           26.770396696372767,
           26.746286915851666,
           26.722177135330558,
           26.69806735480946,
           26.673957574288355,
           26.64984779376725,
           26.62573801324615,
           26.601628232725048,
           26.577518452203947,
           26.553408671682842,
           26.52929889116174,
           26.505189110640636,
           26.48107933011953,
           26.456969549598433,
           26.437025189122966,
           26.424717459269957,
           26.412409729416943,
           26.400101999563933,
           26.387794269710923,
           26.37548653985791,
           26.363178810004904,
           26.35087108015189,
           26.338563350298877,
           26.32625562044587,
           26.313947890592857,
           26.301640160739844,
           26.289332430886834,
           26.277024701033824,
           26.26471697118081,
           26.252409241327804,
           26.240101511474787,
           26.227793781621777,
           26.215486051768767,
           26.203178321915757,
           26.190870592062744,
           26.178562862209738,
           26.166255132356724,
           26.15394740250371,
           26.1416396726507,
           26.12933194279769,
           26.117024212944678,
           26.10471648309167,
           26.092408753238658,
           26.080101023385648,
           26.067793293532638,
           26.055485563679625,
           26.04317783382661,
           26.030870103973605,
           26.01856237412059,
           26.006254644267578,
           25.99394691441457,
           25.981639184561555,
           25.96933145470855,
           25.95702372485554,
           25.944715995002525,
           25.932408265149512,
           25.920100535296502,
           25.907792805443492,
           25.895485075590482,
           25.883177345737472,
           25.87086961588446,
           25.85856188603145,
           25.80764201808158,
           25.56366145964744,
           25.319680901213296,
           25.075700342779157,
           24.831719784345058,
           24.587739225910916,
           24.34375866747677,
           24.099778109042674,
           23.855797550608536,
           23.61181699217439,
           23.367836433740294,
           23.12385587530615,
           22.879875316872006,
           22.635894758437864,
           22.391914200003768,
           22.147933641569626,
           21.903953083135484,
           21.659972524701384,
           21.415991966267242,
           21.172011407833097,
           20.928030849399,
           20.68405029096486,
           20.440069732530716,
           20.19608917409662,
           19.952108615662475,
           19.708128057228336,
           19.464147498794194,
           19.220166940360095,
           18.97618638192595,
           18.73220582349181,
           18.48822526505771,
           18.24424470662357,
           18.012479094045858,
           17.786998873189702,
           17.561518652333504,
           17.336038431477302,
           17.110558210621104,
           16.885077989764945,
           16.659597768908746,
           16.434117548052548,
           16.20863732719639,
           15.98315710634019,
           15.75767688548399,
           15.53219666462783,
           15.306716443771633,
           15.081236222915432,
           14.855756002059275,
           14.630275781203075,
           14.404795560346875,
           14.179315339490676,
           13.953835118634519,
           13.728354897778319,
           13.517840538960403,
           13.321913094549778,
           13.125985650139114,
           12.930058205728455,
           12.734130761317829,
           12.538203316907168,
           12.342275872496508,
           12.146348428085844,
           11.950420983675219,
           11.754493539264557,
           11.558566094853894,
           11.36263865044327,
           11.166711206032607,
           10.970783761621945,
           10.77485631721132,
           10.57892887280066,
           10.383001428389997,
           10.18707398397937,
           9.99114653956871,
           9.795219095158046,
           9.599291650747386,
           9.40336420633676,
           9.2074367619261,
           9.011509317515438,
           8.815581873104811,
           8.619654428694151,
           8.423726984283489,
           8.227799539872864,
           8.031872095462202,
           7.835944651051539,
           7.640017206640878,
           7.444089762230252
          ],
          [
           19.18674599419193,
           19.208033464040984,
           19.229320933890037,
           19.250608403739093,
           19.271895873588146,
           19.2931833434372,
           19.314470813286256,
           19.33575828313531,
           19.357045752984362,
           19.37833322283342,
           19.399620692682475,
           19.42090816253153,
           19.442195632380585,
           19.463483102229638,
           19.48477057207869,
           19.506058041927748,
           19.5273455117768,
           19.548632981625857,
           19.56992045147491,
           19.591207921323967,
           19.61418499082105,
           19.63800686445119,
           19.66182873808133,
           19.685650611711466,
           19.709472485341603,
           19.733294358971744,
           19.757116232601884,
           19.780938106232018,
           19.80475997986216,
           19.828581853492295,
           19.852403727122432,
           19.87622560075257,
           19.900047474382713,
           19.92386934801285,
           19.947691221642987,
           19.971513095273128,
           19.995334968903265,
           20.019156842533405,
           20.042978716163542,
           20.06680058979368,
           20.09062246342382,
           20.114444337053957,
           20.138266210684094,
           20.162088084314234,
           20.18590995794437,
           20.20973183157451,
           20.23355370520465,
           20.257375578834786,
           20.281197452464923,
           20.305019326095064,
           20.3288411997252,
           20.352663073355345,
           20.376484946985478,
           20.400306820615615,
           20.424128694245756,
           20.447950567875893,
           20.471772441506033,
           20.49559431513617,
           20.519416188766307,
           20.543238062396448,
           20.567059936026585,
           20.59088180965672,
           20.614703683286862,
           20.638525556916996,
           20.66234743054714,
           20.68616930417728,
           20.709991177807417,
           20.733813051437554,
           20.75763492506769,
           20.781456798697832,
           20.805278672327972,
           20.82910054595811,
           20.852922419588246,
           20.876744293218387,
           20.90056616684852,
           20.924388040478664,
           20.9482099141088,
           20.972031787738935,
           20.99585366136908,
           21.019675534999216,
           21.043497408629356,
           21.06731928225949,
           21.091141155889627,
           21.11496302951977,
           21.138127941728115,
           21.16116146165211,
           21.184194981576105,
           21.207228501500097,
           21.230262021424092,
           21.253295541348084,
           21.276329061272076,
           21.29936258119607,
           21.322396101120063,
           21.345429621044055,
           21.368463140968053,
           21.391496660892045,
           21.414530180816037,
           21.43756370074003,
           21.460597220664024,
           21.48363074058802,
           21.50666426051201,
           21.529697780436003,
           21.552731300359998,
           21.575764820283993,
           21.598798340207985,
           21.621831860131977,
           21.64486538005597,
           21.667898899979964,
           21.69093241990396,
           21.71396593982795,
           21.736999459751942,
           21.760032979675938,
           21.78306649959993,
           21.806100019523925,
           21.829133539447916,
           21.852167059371908,
           21.875200579295903,
           21.8982340992199,
           21.92126761914389,
           21.944301139067882,
           21.967334658991874,
           21.990368178915872,
           22.01340169883986,
           22.036435218763856,
           22.059468738687848,
           22.082502258611843,
           22.105535778535835,
           22.12856929845983,
           22.15160281838382,
           22.174636338307817,
           22.197669858231812,
           22.220703378155804,
           22.243736898079796,
           22.266770418003787,
           22.289803937927783,
           22.312837457851778,
           22.335870977775766,
           22.358904497699765,
           22.381938017623753,
           22.404971537547752,
           22.428005057471744,
           22.451038577395735,
           22.47407209731973,
           22.49710561724372,
           22.520139137167718,
           22.543172657091713,
           22.5662061770157,
           22.58923969401589,
           22.609693715475977,
           22.630147736936063,
           22.65060175839615,
           22.671055779856236,
           22.691509801316325,
           22.711963822776408,
           22.732417844236497,
           22.752871865696584,
           22.77332588715667,
           22.793779908616756,
           22.814233930076842,
           22.834687951536928,
           22.855141972997014,
           22.8755959944571,
           22.896050015917186,
           22.916504037377273,
           22.93695805883736,
           22.957412080297445,
           22.97786610175753,
           23.001252395160122,
           23.026104824533967,
           23.050957253907804,
           23.07580968328165,
           23.10066211265549,
           23.125514542029336,
           23.150366971403173,
           23.17521940077702,
           23.20007183015086,
           23.224924259524705,
           23.249776688898546,
           23.27462911827239,
           23.299481547646227,
           23.32433397702007,
           23.349186406393912,
           23.37403883576776,
           23.398891265141597,
           23.42374369451544,
           23.448596123889285,
           23.473448553263122,
           23.498300982636966,
           23.523153412010807,
           23.548005841384654,
           23.572858270758495,
           23.59771070013234,
           23.622563129506176,
           23.64741555888002,
           23.67226798825386,
           23.6971204176277,
           23.72197284700155,
           23.746825276375386,
           23.771677705749234,
           23.79653013512307,
           23.82138256449691,
           23.846917401103354,
           23.873248385905484,
           23.899579370707606,
           23.925910355509732,
           23.952241340311858,
           23.978572325113984,
           24.00490330991611,
           24.031234294718235,
           24.05756527952036,
           24.083896264322487,
           24.110227249124613,
           24.136558233926742,
           24.162889218728864,
           24.189220203530986,
           24.215551188333116,
           24.24188217313524,
           24.268213157937367,
           24.294544142739493,
           24.32087512754162,
           24.347206112343745,
           24.37353709714587,
           24.399868081947997,
           24.426199066750122,
           24.452530051552248,
           24.478861036354374,
           24.5051920211565,
           24.531523005958626,
           24.55785399076075,
           24.584184975562877,
           24.610515960365007,
           24.63684694516713,
           24.663177929969255,
           24.68950891477138,
           24.715839899573506,
           24.742170884375632,
           24.768501869177758,
           24.794832853979884,
           24.82116383878201,
           24.847494823584135,
           24.87382580838626,
           24.900156793188387,
           24.926487777990513,
           24.95281876279264,
           24.979149747594764,
           25.00548073239689,
           25.031811717199012,
           25.058142702001142,
           25.084473686803264,
           25.110804671605393,
           25.14126870572243,
           25.175865789154393,
           25.21046287258635,
           25.245059956018306,
           25.279657039450264,
           25.314254122882218,
           25.34885120631418,
           25.383448289746134,
           25.418045373178096,
           25.452642456610047,
           25.487239540042005,
           25.521836623473966,
           25.55643370690592,
           25.591030790337875,
           25.625627873769837,
           25.66022495720179,
           25.694822040633746,
           25.729419124065707,
           25.76401620749766,
           25.798613290929616,
           25.833210374361578,
           25.867807457793536,
           25.902404541225486,
           25.937001624657448,
           25.971598708089406,
           26.006195791521364,
           26.04079287495332,
           26.07538995838528,
           26.10998704181723,
           26.14458412524919,
           26.17918120868115,
           26.213778292113105,
           26.24837537554506,
           26.282972458977017,
           26.317569542408975,
           26.35216662584093,
           26.38676370927289,
           26.42136079270485,
           26.455957876136807,
           26.490554959568758,
           26.525152043000716,
           26.559749126432678,
           26.59434620986463,
           26.628943293296587,
           26.663540376728548,
           26.698137460160495,
           26.732734543592457,
           26.76733162702442,
           26.801928710456373,
           26.836525793888327,
           26.87112287732029,
           26.905391678392476,
           26.93805033795366,
           26.97070899751484,
           27.00336765707603,
           27.036026316637205,
           27.068684976198387,
           27.101343635759573,
           27.13400229532075,
           27.166660954881937,
           27.199319614443123,
           27.2319782740043,
           27.26463693356548,
           27.297295593126666,
           27.32995425268785,
           27.362612912249027,
           27.395271571810213,
           27.4279302313714,
           27.460588890932573,
           27.49324755049376,
           27.52590621005495,
           27.558564869616127,
           27.591223529177306,
           27.62388218873849,
           27.656540848299674,
           27.689199507860856,
           27.72185816742204,
           27.75451682698322,
           27.7871754865444,
           27.819834146105585,
           27.85249280566677,
           27.88515146522795,
           27.917810124789135,
           27.931545970989546,
           27.90743619046845,
           27.883326409947344,
           27.85921662942624,
           27.835106848905138,
           27.810997068384037,
           27.786887287862932,
           27.76277750734183,
           27.73866772682073,
           27.714557946299625,
           27.69044816577852,
           27.66633838525742,
           27.642228604736317,
           27.61811882421521,
           27.594009043694108,
           27.569899263173006,
           27.545789482651905,
           27.521679702130804,
           27.497569921609703,
           27.473460141088594,
           27.44935036056749,
           27.42524058004639,
           27.40113079952529,
           27.37702101900419,
           27.352911238483085,
           27.32880145796198,
           27.304691677440875,
           27.280581896919774,
           27.256472116398673,
           27.23236233587757,
           27.208252555356466,
           27.184142774835365,
           27.16003299431426,
           27.135923213793156,
           27.111813433272054,
           27.087703652750953,
           27.06359387222985,
           27.039484091708747,
           27.015374311187646,
           26.99126453066654,
           26.967154750145436,
           26.943044969624335,
           26.918935189103234,
           26.89482540858213,
           26.870715628061028,
           26.846605847539923,
           26.822496067018818,
           26.798386286497717,
           26.774276505976616,
           26.750166725455514,
           26.72605694493441,
           26.70194716441331,
           26.677837383892204,
           26.653727603371102,
           26.62961782285,
           26.605508042328893,
           26.58139826180779,
           26.557288481286694,
           26.53317870076559,
           26.509068920244484,
           26.484959139723383,
           26.46084935920228,
           26.436739578681177,
           26.412629798160072,
           26.388520017638974,
           26.36441023711787,
           26.34030045659676,
           26.316190676075667,
           26.29208089555456,
           26.267971115033458,
           26.243861334512353,
           26.21975155399125,
           26.197377389258914,
           26.185069659405904,
           26.172761929552895,
           26.16045419969988,
           26.148146469846868,
           26.13583873999386,
           26.123531010140848,
           26.111223280287838,
           26.09891555043483,
           26.086607820581815,
           26.074300090728805,
           26.023380222778936,
           25.779399664344798,
           25.535419105910652,
           25.29143854747651,
           25.047457989042414,
           24.803477430608275,
           24.55949687217413,
           24.315516313740034,
           24.08979888152348,
           23.86431866066728,
           23.63883843981112,
           23.413358218954922,
           23.18787799809872,
           22.962397777242526,
           22.736917556386366,
           22.511437335530164,
           22.28595711467397,
           22.06047689381781,
           21.834996672961612,
           21.60951645210541,
           21.38403623124925,
           21.158556010393053,
           20.933075789536858,
           20.707595568680695,
           20.4821153478245,
           20.2566351269683,
           20.031154906112096,
           19.80567468525594,
           19.58019446439974,
           19.35471424354354,
           19.12923402268738,
           18.903753801831183,
           18.678273580974984,
           18.45279336011883,
           18.227313139262627,
           18.00183291840643,
           17.77635269755023,
           17.55087247669407,
           17.32539225583787,
           17.099912034981674,
           16.874431814125515,
           16.648951593269317,
           16.423471372413115,
           16.19799115155696,
           15.97251093070076,
           15.747030709844559,
           15.521550488988401,
           15.296070268132201,
           15.070590047276001,
           14.845109826419803,
           14.619629605563643,
           14.394149384707445,
           14.168669163851245,
           13.943188942995087,
           13.71770872213889,
           13.492228501282689,
           13.266748280426533,
           13.041268059570331,
           12.815787838714133,
           12.590307617857935,
           12.364827397001775,
           12.139347176145577,
           11.913866955289375,
           11.68838673443322,
           11.46290651357702,
           11.237426292720821,
           11.011946071864664,
           10.786465851008463,
           10.560985630152263,
           10.335505409296106,
           10.110025188439906,
           9.884544967583706,
           9.659064746727505,
           9.433584525871348,
           9.20810430501515,
           8.98262408415895,
           8.762448251794304,
           8.56652080738364,
           8.37059336297298,
           8.174665918562356,
           7.978738474151694,
           7.782811029741032,
           7.58688358533037,
           7.390956140919744
          ],
          [
           19.65472289214132,
           19.67601036199037,
           19.697297831839425,
           19.719007699864147,
           19.742829573494284,
           19.76665144712442,
           19.79047332075456,
           19.814295194384698,
           19.83811706801484,
           19.861938941644976,
           19.885760815275116,
           19.909582688905253,
           19.933404562535394,
           19.95722643616553,
           19.98104830979567,
           20.004870183425805,
           20.028692057055945,
           20.052513930686082,
           20.076335804316223,
           20.10015767794636,
           20.123979551576497,
           20.147801425206637,
           20.171623298836774,
           20.195445172466915,
           20.219267046097052,
           20.243088919727192,
           20.26691079335733,
           20.290732666987466,
           20.314554540617607,
           20.338376414247744,
           20.36219828787788,
           20.38602016150802,
           20.40984203513816,
           20.4336639087683,
           20.457485782398436,
           20.481307656028577,
           20.50512952965871,
           20.52895140328885,
           20.55277327691899,
           20.576595150549128,
           20.600417024179265,
           20.624238897809406,
           20.648060771439543,
           20.67188264506968,
           20.69570451869982,
           20.719526392329957,
           20.7433482659601,
           20.767170139590235,
           20.79099201322037,
           20.814813886850516,
           20.83863576048065,
           20.86245763411079,
           20.886279507740927,
           20.910101381371064,
           20.933923255001204,
           20.95774512863134,
           20.98156700226148,
           21.00538887589162,
           21.029210749521756,
           21.053032623151896,
           21.076854496782033,
           21.100676370412174,
           21.12449824404231,
           21.148320117672448,
           21.17214199130259,
           21.195963864932725,
           21.219785738562866,
           21.243607612193003,
           21.267429485823143,
           21.29125135945328,
           21.315073233083417,
           21.338895106713558,
           21.362716980343695,
           21.386538853973832,
           21.410360727603972,
           21.434182601234113,
           21.45800447486425,
           21.481826348494387,
           21.505648222124524,
           21.529470095754665,
           21.5532919693848,
           21.57711384301494,
           21.60093571664508,
           21.62475759027522,
           21.647922502483567,
           21.670956022407562,
           21.693989542331554,
           21.717023062255546,
           21.74005658217954,
           21.763090102103533,
           21.786123622027528,
           21.80915714195152,
           21.832190661875515,
           21.855224181799507,
           21.8782577017235,
           21.901291221647497,
           21.92432474157149,
           21.947358261495484,
           21.970391781419472,
           21.993425301343464,
           22.01645882126746,
           22.039492341191455,
           22.062525861115446,
           22.08555938103944,
           22.108592900963433,
           22.13162642088743,
           22.15465994081142,
           22.177693460735412,
           22.200726980659407,
           22.2237605005834,
           22.246794020507394,
           22.269827540431386,
           22.292861060355378,
           22.315894580279373,
           22.33892810020337,
           22.36196162012736,
           22.384995140051355,
           22.408028659975347,
           22.43106217989934,
           22.454095699823334,
           22.477129219747326,
           22.50016273967132,
           22.52319625959531,
           22.546229779519308,
           22.5692632994433,
           22.59229681936729,
           22.615330339291287,
           22.63836385921528,
           22.661397379139274,
           22.684430899063265,
           22.707464418987257,
           22.730497938911252,
           22.753531458835244,
           22.77656497875924,
           22.79959849868323,
           22.822632018607226,
           22.845665538531218,
           22.868699058455213,
           22.891732578379205,
           22.914766098303197,
           22.937799618227192,
           22.960833138151187,
           22.98386665807518,
           23.00690017799917,
           23.029933697923166,
           23.05296721784716,
           23.076000737771153,
           23.099034257695145,
           23.122067777619137,
           23.145101297543132,
           23.168134817467127,
           23.19116833739112,
           23.21420185731511,
           23.237235377239102,
           23.260268897163098,
           23.283302417087093,
           23.306335937011085,
           23.32936945693508,
           23.352402976859068,
           23.375436496783063,
           23.398470016707055,
           23.421503536631054,
           23.444537056555045,
           23.467570576479037,
           23.489314344672884,
           23.50976836613297,
           23.530222387593057,
           23.55360868099565,
           23.578461110369492,
           23.603313539743336,
           23.628165969117177,
           23.653018398491017,
           23.678837573111444,
           23.70516855791357,
           23.731499542715696,
           23.757830527517818,
           23.78416151231995,
           23.810492497122077,
           23.8368234819242,
           23.863154466726325,
           23.88948545152845,
           23.91581643633058,
           23.942147421132702,
           23.968478405934828,
           23.994809390736954,
           24.021140375539083,
           24.04747136034121,
           24.07380234514333,
           24.100133329945457,
           24.126464314747583,
           24.15279529954971,
           24.179126284351835,
           24.20545726915396,
           24.231788253956086,
           24.258119238758212,
           24.28445022356034,
           24.310781208362464,
           24.33711219316459,
           24.363443177966715,
           24.389774162768845,
           24.416105147570967,
           24.442436132373093,
           24.46876711717522,
           24.49509810197734,
           24.52142908677947,
           24.547760071581596,
           24.574091056383722,
           24.600422041185844,
           24.626753025987973,
           24.6530840107901,
           24.679414995592225,
           24.70574598039435,
           24.732076965196477,
           24.7584079499986,
           24.78473893480073,
           24.811069919602854,
           24.83740090440498,
           24.863731889207106,
           24.89006287400923,
           24.916393858811354,
           24.942724843613483,
           24.969055828415613,
           24.99538681321773,
           25.021717798019857,
           25.048048782821986,
           25.074379767624116,
           25.100710752426238,
           25.127041737228364,
           25.153372722030486,
           25.179703706832612,
           25.20603469163474,
           25.23236567643687,
           25.25869666123899,
           25.285027646041115,
           25.311358630843245,
           25.337689615645367,
           25.3640206004475,
           25.390351585249622,
           25.416682570051748,
           25.443013554853874,
           25.469344539656,
           25.495675524458125,
           25.522006509260247,
           25.548337494062377,
           25.574668478864503,
           25.600999463666632,
           25.627330448468754,
           25.653661433270884,
           25.679992418073006,
           25.70632340287513,
           25.736787436992174,
           25.77138452042413,
           25.80598160385609,
           25.840578687288044,
           25.875175770720002,
           25.90977285415196,
           25.944369937583915,
           25.978967021015873,
           26.01356410444783,
           26.048161187879785,
           26.082758271311743,
           26.117355354743705,
           26.15195243817566,
           26.186549521607613,
           26.22114660503957,
           26.255743688471533,
           26.290340771903487,
           26.324937855335442,
           26.3595349387674,
           26.394132022199358,
           26.428729105631312,
           26.463326189063274,
           26.497923272495225,
           26.532520355927186,
           26.567117439359144,
           26.601714522791102,
           26.636311606223057,
           26.670908689655015,
           26.705505773086973,
           26.740102856518927,
           26.774699939950885,
           26.809297023382847,
           26.843894106814794,
           26.87849119024676,
           26.913088273678717,
           26.94768535711067,
           26.98228244054263,
           27.016879523974588,
           27.05147660740654,
           27.086073690838496,
           27.120670774270454,
           27.155267857702412,
           27.189864941134367,
           27.22446202456633,
           27.259059107998283,
           27.293656191430237,
           27.328253274862192,
           27.362850358294157,
           27.397447441726108,
           27.43204452515807,
           27.466641608590027,
           27.50123869202198,
           27.535835775453936,
           27.570432858885898,
           27.605029942317856,
           27.63962702574981,
           27.67422410918177,
           27.708821192613723,
           27.74341827604568,
           27.77801535947764,
           27.812612442909597,
           27.84720952634155,
           27.88180660977351,
           27.916403693205467,
           27.95100077663742,
           27.98559786006938,
           28.02019494350134,
           28.0547920269333,
           28.08938911036525,
           28.123986193797208,
           28.158583277229166,
           28.193180360661124,
           28.22777744409308,
           28.262374527525036,
           28.29697161095699,
           28.33156869438895,
           28.366165777820907,
           28.400762861252865,
           28.435359944684823,
           28.46995702811678,
           28.504554111548735,
           28.539151194980697,
           28.572654008462745,
           28.58638985466316,
           28.56228007414206,
           28.538170293620954,
           28.514060513099853,
           28.48995073257875,
           28.461879230726293,
           28.4330706789968,
           28.404262127267305,
           28.375453575537815,
           28.346645023808318,
           28.317836472078827,
           28.289027920349337,
           28.260219368619843,
           28.23141081689035,
           28.202602265160856,
           28.173793713431362,
           28.144985161701868,
           28.116176609972378,
           28.087368058242888,
           28.05855950651339,
           28.029750954783896,
           28.000942403054403,
           27.972133851324912,
           27.94332529959542,
           27.914516747865928,
           27.885708196136434,
           27.856899644406937,
           27.828091092677447,
           27.799282540947956,
           27.77047398921846,
           27.74166543748896,
           27.712856885759475,
           27.68404833402998,
           27.655239782300487,
           27.626431230570997,
           27.5976226788415,
           27.568814127112006,
           27.540005575382516,
           27.511197023653022,
           27.482388471923528,
           27.453579920194038,
           27.424771368464544,
           27.39596281673505,
           27.367154265005556,
           27.338345713276066,
           27.309537161546572,
           27.28072860981708,
           27.251920058087585,
           27.223111506358094,
           27.1943029546286,
           27.165494402899107,
           27.136685851169617,
           27.107877299440123,
           27.07906874771063,
           27.05026019598114,
           27.02145164425164,
           26.992643092522147,
           26.963834540792654,
           26.935025989063163,
           26.90621743733367,
           26.877408885604176,
           26.848600333874685,
           26.81979178214519,
           26.790983230415698,
           26.762174678686208,
           26.73336612695671,
           26.704557575227216,
           26.67574902349773,
           26.646940471768232,
           26.61813192003874,
           26.58932336830924,
           26.560514816579754,
           26.53170626485026,
           26.502897713120767,
           26.474089161391273,
           26.44528060966178,
           26.416472057932285,
           26.3876635062028,
           26.3588549544733,
           26.330046402743807,
           26.301237851014314,
           26.27242929928482,
           26.24362074755533,
           26.17628628670594,
           25.916322280257024,
           25.656358273808117,
           25.396394267359202,
           25.136430260910345,
           24.87646625446143,
           24.616502248012523,
           24.356538241563662,
           24.09657423511475,
           23.836610228665837,
           23.576646222216976,
           23.316682215768065,
           23.056718209319154,
           22.796754202870247,
           22.536790196421382,
           22.276826189972475,
           22.01686218352356,
           21.7568981770747,
           21.496934170625785,
           21.236970164176878,
           20.977006157728017,
           20.717042151279106,
           20.45707814483019,
           20.19711413838133,
           19.937150131932423,
           19.67718612548351,
           19.4172221190346,
           19.157258112585737,
           18.90771120268395,
           18.68223098182775,
           18.456750760971588,
           18.23127054011539,
           18.00579031925919,
           17.78031009840303,
           17.554829877546837,
           17.32934965669064,
           17.103869435834437,
           16.878389214978277,
           16.65290899412208,
           16.42742877326588,
           16.201948552409725,
           15.976468331553523,
           15.750988110697325,
           15.525507889841167,
           15.300027668984967,
           15.074547448128767,
           14.84906722727261,
           14.62358700641641,
           14.398106785560207,
           14.172626564704009,
           13.947146343847852,
           13.721666122991653,
           13.496185902135451,
           13.270705681279294,
           13.045225460423094,
           12.819745239566894,
           12.619974706248044,
           12.424231110797464,
           12.228487515346888,
           12.03274391989631,
           11.837000324445768,
           11.641256728995192,
           11.445513133544614,
           11.249769538094071,
           11.054025942643493,
           10.858282347192915,
           10.662538751742373,
           10.466795156291798,
           10.271051560841219,
           10.075307965390678,
           9.879564369940098,
           9.683820774489522,
           9.488077179038944,
           9.292333583588404,
           9.096589988137826,
           8.900846392687248,
           8.705102797236707,
           8.509359201786129,
           8.313615606335551,
           8.11787201088501,
           7.922128415434432,
           7.726384819983853,
           7.530641224533276,
           7.334897629082734
          ],
          [
           20.119699886153942,
           20.145913095280633,
           20.172126304407325,
           20.198339513534016,
           20.224552722660707,
           20.2507659317874,
           20.27697914091409,
           20.30319235004078,
           20.329405559167476,
           20.355618768294168,
           20.38183197742086,
           20.40804518654755,
           20.43425839567424,
           20.460471604800933,
           20.485887700174057,
           20.50970957380419,
           20.53353144743433,
           20.55735332106447,
           20.58117519469461,
           20.604997068324746,
           20.628818941954886,
           20.652640815585027,
           20.676462689215164,
           20.700284562845304,
           20.724106436475438,
           20.74792831010558,
           20.771750183735715,
           20.795572057365852,
           20.819393930995993,
           20.843215804626134,
           20.867037678256267,
           20.890859551886408,
           20.914681425516545,
           20.938503299146685,
           20.962325172776822,
           20.986147046406963,
           21.0099689200371,
           21.03379079366724,
           21.057612667297377,
           21.081434540927518,
           21.105256414557655,
           21.12907828818779,
           21.152900161817932,
           21.17672203544807,
           21.200543909078206,
           21.224365782708347,
           21.248187656338487,
           21.27200952996862,
           21.29583140359876,
           21.319653277228902,
           21.343475150859035,
           21.367297024489176,
           21.391118898119316,
           21.414940771749453,
           21.43876264537959,
           21.46258451900973,
           21.486406392639868,
           21.51022826627001,
           21.534050139900145,
           21.55787201353028,
           21.581693887160423,
           21.60551576079056,
           21.6293376344207,
           21.653159508050837,
           21.676981381680974,
           21.700803255311115,
           21.724625128941252,
           21.74844700257139,
           21.77226887620153,
           21.796090749831666,
           21.819912623461807,
           21.843734497091944,
           21.86755637072208,
           21.891378244352218,
           21.91520011798236,
           21.939021991612496,
           21.962843865242636,
           21.986665738872773,
           22.010487612502914,
           22.034309486133047,
           22.058131359763188,
           22.081953233393325,
           22.105775107023465,
           22.129596980653606,
           22.15480774046049,
           22.18029627750273,
           22.205784814544963,
           22.231273351587205,
           22.256761888629438,
           22.282250425671673,
           22.307738962713913,
           22.33322749975615,
           22.358716036798388,
           22.384204573840623,
           22.409693110882863,
           22.4351816479251,
           22.460670184967338,
           22.48574955051732,
           22.50878307044131,
           22.531816590365302,
           22.554850110289294,
           22.57788363021329,
           22.60091715013728,
           22.623950670061273,
           22.646984189985268,
           22.67001770990926,
           22.693051229833255,
           22.716084749757243,
           22.739118269681242,
           22.762151789605234,
           22.785185309529226,
           22.80821882945322,
           22.831252349377213,
           22.854285869301208,
           22.8773193892252,
           22.900352909149195,
           22.92338642907319,
           22.946419948997182,
           22.969453468921174,
           22.992486988845165,
           23.015520508769164,
           23.038554028693156,
           23.061587548617148,
           23.08462106854114,
           23.107654588465135,
           23.130688108389126,
           23.15372162831312,
           23.176755148237113,
           23.199788668161105,
           23.2228221880851,
           23.245855708009096,
           23.268889227933087,
           23.29192274785708,
           23.31495626778107,
           23.337989787705066,
           23.361023307629058,
           23.384056827553053,
           23.407090347477045,
           23.43012386740104,
           23.45315738732503,
           23.476190907249027,
           23.49922442717302,
           23.522257947097014,
           23.545291467021006,
           23.568324986945,
           23.591358506868993,
           23.614392026792984,
           23.63742554671698,
           23.66045906664097,
           23.683492586564967,
           23.706526106488955,
           23.729559626412954,
           23.752593146336945,
           23.775626666260937,
           23.798660186184936,
           23.821693706108924,
           23.84472722603292,
           23.867760745956907,
           23.890794265880903,
           23.9138277858049,
           23.93686130572889,
           23.959894825652885,
           23.982928345576877,
           24.005961865500872,
           24.028995385424867,
           24.052028905348855,
           24.07506242527285,
           24.100878870830066,
           24.12808677920389,
           24.155294687577722,
           24.182502595951547,
           24.209710504325372,
           24.2369184126992,
           24.26412632107302,
           24.291334229446853,
           24.318542137820682,
           24.345750046194503,
           24.372957954568335,
           24.40016586294216,
           24.427373771315988,
           24.454581679689813,
           24.48178958806364,
           24.508997496437466,
           24.536205404811295,
           24.56341331318512,
           24.590621221558948,
           24.617829129932773,
           24.645037038306597,
           24.67224494668043,
           24.69945285505425,
           24.72666076342808,
           24.753868671801907,
           24.781076580175732,
           24.80828448854956,
           24.835492396923385,
           24.862700305297214,
           24.889908213671042,
           24.917116122044867,
           24.944324030418695,
           24.971531938792516,
           24.99873984716634,
           25.025947755540173,
           25.053155663913998,
           25.080363572287826,
           25.10757148066165,
           25.13477938903548,
           25.161987297409304,
           25.189195205783133,
           25.216403114156957,
           25.243611022530786,
           25.27081893090461,
           25.29802683927844,
           25.325234747652267,
           25.352442656026092,
           25.37965056439992,
           25.406588650872607,
           25.43291963567473,
           25.45925062047686,
           25.48558160527898,
           25.51191259008111,
           25.538243574883236,
           25.56457455968536,
           25.590905544487484,
           25.617236529289613,
           25.643567514091735,
           25.66989849889386,
           25.69622948369599,
           25.722560468498116,
           25.74889145330024,
           25.775222438102368,
           25.80155342290449,
           25.827884407706616,
           25.854215392508745,
           25.880546377310868,
           25.906877362112997,
           25.933208346915123,
           25.95953933171725,
           25.98587031651937,
           26.012201301321497,
           26.038532286123623,
           26.064863270925752,
           26.091194255727878,
           26.11752524053,
           26.14385622533213,
           26.17018721013425,
           26.19651819493638,
           26.222849179738507,
           26.24918016454063,
           26.275511149342755,
           26.301842134144884,
           26.332306168261923,
           26.366903251693884,
           26.40150033512584,
           26.436097418557793,
           26.47069450198975,
           26.505291585421705,
           26.539888668853663,
           26.57448575228562,
           26.60908283571758,
           26.64367991914953,
           26.678277002581492,
           26.71287408601345,
           26.747471169445408,
           26.782068252877362,
           26.81666533630932,
           26.851262419741282,
           26.885859503173236,
           26.920456586605194,
           26.955053670037152,
           26.989650753469107,
           27.02424783690107,
           27.058844920333026,
           27.093442003764977,
           27.128039087196935,
           27.162636170628897,
           27.19723325406085,
           27.231830337492806,
           27.266427420924764,
           27.30102450435672,
           27.335621587788676,
           27.370218671220634,
           27.404815754652596,
           27.440002991907804,
           27.475531202885907,
           27.51105941386401,
           27.54658762484211,
           27.58211583582021,
           27.61764404679832,
           27.65317225777642,
           27.68870046875452,
           27.724228679732622,
           27.759756890710722,
           27.795285101688822,
           27.830813312666926,
           27.866341523645033,
           27.90186973462313,
           27.937397945601234,
           27.972926156579337,
           28.00845436755744,
           28.04398257853554,
           28.07951078951364,
           28.11503900049175,
           28.150567211469845,
           28.18609542244795,
           28.221623633426052,
           28.25715184440415,
           28.292680055382252,
           28.328208266360356,
           28.363736477338456,
           28.39926468831656,
           28.434792899294663,
           28.470321110272764,
           28.505849321250864,
           28.54137753222897,
           28.57690574320707,
           28.61243395418517,
           28.647962165163275,
           28.68349037614137,
           28.719018587119475,
           28.75454679809758,
           28.790075009075686,
           28.82560322005378,
           28.861131431031882,
           28.896659642009986,
           28.932187852988086,
           28.967716063966186,
           29.003244274944294,
           29.038772485922394,
           29.074300696900494,
           29.109828907878594,
           29.1453571188567,
           29.1808853298348,
           29.2164135408129,
           29.226154365934605,
           29.184320419343543,
           29.142486472752477,
           29.10065252616141,
           29.058818579570342,
           29.01698463297928,
           28.975150686388208,
           28.933316739797142,
           28.89148279320608,
           28.849648846615015,
           28.807814900023946,
           28.76598095343288,
           28.72414700684181,
           28.682313060250745,
           28.64047911365968,
           28.598645167068614,
           28.556811220477545,
           28.51497727388648,
           28.473143327295418,
           28.43130938070435,
           28.389475434113283,
           28.34764148752221,
           28.305807540931152,
           28.26397359434008,
           28.22213964774902,
           28.180305701157955,
           28.138471754566886,
           28.096637807975817,
           28.05480386138475,
           28.012969914793686,
           27.971135968202617,
           27.929302021611555,
           27.887468075020482,
           27.845634128429417,
           27.80380018183835,
           27.761966235247286,
           27.720132288656217,
           27.678298342065155,
           27.64157505464887,
           27.612766502919378,
           27.583957951189888,
           27.555149399460394,
           27.5263408477309,
           27.497532296001403,
           27.468723744271912,
           27.439915192542422,
           27.41110664081293,
           27.382298089083434,
           27.353489537353944,
           27.324680985624447,
           27.295872433894957,
           27.267063882165466,
           27.23825533043597,
           27.20944677870648,
           27.18063822697699,
           27.15182967524749,
           27.123021123518,
           27.094212571788503,
           27.065404020059013,
           27.03659546832952,
           27.007786916600026,
           26.978978364870535,
           26.95016981314104,
           26.921361261411548,
           26.892552709682057,
           26.86374415795256,
           26.834935606223066,
           26.806127054493576,
           26.777318502764082,
           26.748509951034585,
           26.719701399305094,
           26.6908928475756,
           26.662084295846107,
           26.633275744116617,
           26.604467192387123,
           26.57565864065763,
           26.546850088928135,
           26.518041537198645,
           26.48923298546915,
           26.460424433739654,
           26.431615882010163,
           26.402807330280673,
           26.373998778551176,
           26.306664317701788,
           26.046700311252874,
           25.786736304803963,
           25.526772298355056,
           25.266808291906187,
           25.006844285457284,
           24.746880279008366,
           24.486916272559508,
           24.226952266110594,
           23.966988259661687,
           23.707024253212822,
           23.44706024676391,
           23.187096240315,
           22.92713223386609,
           22.667168227417232,
           22.40720422096832,
           22.147240214519407,
           21.887276208070546,
           21.62731220162164,
           21.367348195172724,
           21.107384188723863,
           20.847420182274952,
           20.58745617582604,
           20.32749216937718,
           20.06752816292827,
           19.80756415647936,
           19.547600150030448,
           19.307080953509477,
           19.075172286831766,
           18.843263620154055,
           18.611354953476386,
           18.379446286798682,
           18.14753762012097,
           17.915628953443303,
           17.683720286765595,
           17.451811620087884,
           17.219902953410177,
           16.98799428673251,
           16.7560856200548,
           16.52417695337709,
           16.292268286699425,
           16.060359620021714,
           15.828450953344003,
           15.596542286666338,
           15.364633619988629,
           15.13272495331092,
           14.900816286633251,
           14.668907619955544,
           14.436998953277834,
           14.205090286600125,
           13.973181619922457,
           13.741272953244748,
           13.509364286567038,
           13.277455619889372,
           13.045546953211662,
           12.813638286533953,
           12.581729619856285,
           12.36694797151186,
           12.171204376061283,
           11.975460780610707,
           11.779717185160166,
           11.583973589709586,
           11.38822999425901,
           11.192486398808466,
           10.99674280335789,
           10.800999207907312,
           10.60525561245677,
           10.409512017006193,
           10.213768421555615,
           10.018024826105075,
           9.822281230654497,
           9.626537635203917,
           9.43079403975334,
           9.2350504443028,
           9.03930684885222,
           8.843563253401644,
           8.647819657951104,
           8.452076062500524,
           8.256332467049948,
           8.060588871599407,
           7.864845276148827,
           7.669101680698249,
           7.473358085247672,
           7.277614489797131
          ],
          [
           20.584054948613446,
           20.610268157740137,
           20.63648136686683,
           20.66269457599352,
           20.68890778512021,
           20.715120994246902,
           20.741334203373594,
           20.767547412500285,
           20.793760621626976,
           20.819973830753668,
           20.84618703988036,
           20.87240024900705,
           20.89861345813374,
           20.924826667260437,
           20.951039876387128,
           20.977253085513823,
           21.00346629464051,
           21.029679503767202,
           21.055892712893893,
           21.082105922020588,
           21.108319131147276,
           21.13453234027397,
           21.16074554940066,
           21.186958758527354,
           21.213171967654045,
           21.239385176780736,
           21.265598385907424,
           21.29181159503412,
           21.31802480416081,
           21.3442380132875,
           21.370451222414193,
           21.394671650433605,
           21.418493524063745,
           21.442315397693882,
           21.46613727132402,
           21.489959144954163,
           21.513781018584297,
           21.537602892214437,
           21.561424765844578,
           21.585246639474715,
           21.609068513104848,
           21.632890386734992,
           21.65671226036513,
           21.680534133995266,
           21.704356007625407,
           21.728177881255544,
           21.75199975488568,
           21.77582162851582,
           21.79964350214596,
           21.823465375776095,
           21.847287249406236,
           21.871109123036376,
           21.89493099666651,
           21.91875287029665,
           21.942574743926787,
           21.966396617556928,
           21.990218491187065,
           22.014040364817205,
           22.037862238447342,
           22.061684112077483,
           22.08550598570762,
           22.109327859337757,
           22.133149732967894,
           22.156971606598034,
           22.180793480228175,
           22.204615353858316,
           22.22843722748845,
           22.25225910111859,
           22.276080974748727,
           22.299902848378863,
           22.323724722009004,
           22.34754659563914,
           22.37136846926928,
           22.39519034289942,
           22.41901221652956,
           22.442834090159693,
           22.466655963789833,
           22.490477837419974,
           22.51429971105011,
           22.538121584680248,
           22.561943458310388,
           22.585765331940525,
           22.609587205570662,
           22.633409079200803,
           22.658619839007688,
           22.684108376049927,
           22.709596913092163,
           22.7350854501344,
           22.760573987176638,
           22.786062524218877,
           22.811551061261113,
           22.83703959830335,
           22.86252813534559,
           22.888016672387828,
           22.913505209430063,
           22.9389937464723,
           22.96448228351454,
           22.989970820556774,
           23.015459357599013,
           23.04094789464125,
           23.066436431683485,
           23.091924968725724,
           23.117413505767963,
           23.1429020428102,
           23.168390579852435,
           23.19387911689467,
           23.21936765393691,
           23.244856190979146,
           23.270344728021385,
           23.29583326506362,
           23.321321802105857,
           23.346810339148096,
           23.37229887619033,
           23.39778741323257,
           23.421639270628503,
           23.444672790552495,
           23.467706310476487,
           23.490739830400482,
           23.513773350324477,
           23.53680687024847,
           23.559840390172464,
           23.582873910096456,
           23.605907430020448,
           23.628940949944443,
           23.651974469868435,
           23.675007989792427,
           23.69804150971642,
           23.721075029640417,
           23.74410854956441,
           23.7671420694884,
           23.790175589412392,
           23.813209109336388,
           23.836242629260383,
           23.859276149184378,
           23.882309669108366,
           23.905343189032358,
           23.928376708956357,
           23.95141022888035,
           23.97444374880434,
           23.997477268728336,
           24.020510788652327,
           24.043544308576323,
           24.066577828500314,
           24.089611348424306,
           24.1126448683483,
           24.135678388272293,
           24.158711908196288,
           24.18174542812028,
           24.20477894804427,
           24.227812467968267,
           24.250845987892262,
           24.273879507816254,
           24.29691302774025,
           24.31994654766424,
           24.342980067588233,
           24.366013587512228,
           24.389047107436223,
           24.412080627360215,
           24.43511414728421,
           24.4581476672082,
           24.481181187132197,
           24.50421470705619,
           24.52724822698018,
           24.550281746904172,
           24.573315266828168,
           24.596348786752163,
           24.619382306676155,
           24.64519875223337,
           24.672406660607194,
           24.699614568981023,
           24.72682247735485,
           24.754030385728676,
           24.7812382941025,
           24.80844620247633,
           24.835654110850157,
           24.862862019223982,
           24.890069927597807,
           24.91727783597164,
           24.944485744345464,
           24.97169365271929,
           24.998901561093117,
           25.02610946946694,
           25.05331737784077,
           25.080525286214595,
           25.107733194588423,
           25.13494110296225,
           25.162149011336076,
           25.1893569197099,
           25.216564828083733,
           25.243772736457558,
           25.270980644831383,
           25.29818855320521,
           25.325396461579036,
           25.352604369952864,
           25.37981227832669,
           25.40702018670052,
           25.434228095074346,
           25.461436003448167,
           25.488643911822,
           25.515851820195824,
           25.54305972856965,
           25.570267636943477,
           25.5974755453173,
           25.62468345369113,
           25.65189136206496,
           25.679099270438783,
           25.706307178812608,
           25.733515087186433,
           25.76072299556026,
           25.78793090393409,
           25.815138812307918,
           25.842346720681746,
           25.86955462905557,
           25.896762537429392,
           25.92397044580322,
           25.951178354177046,
           25.978386262550874,
           26.005594170924706,
           26.032802079298527,
           26.06000998767236,
           26.087217896046184,
           26.114425804420012,
           26.141633712793837,
           26.168841621167665,
           26.19604952954149,
           26.223257437915315,
           26.250465346289143,
           26.277673254662968,
           26.304881163036796,
           26.332089071410625,
           26.35929697978445,
           26.386504888158274,
           26.413712796532103,
           26.44092070490593,
           26.468128613279756,
           26.495336521653584,
           26.52254443002741,
           26.549752338401237,
           26.576960246775062,
           26.60416815514889,
           26.631376063522715,
           26.660019099577315,
           26.68904851309493,
           26.718077926612537,
           26.74710734013015,
           26.776136753647762,
           26.805166167165368,
           26.834195580682977,
           26.86322499420059,
           26.892254407718198,
           26.92503912087996,
           26.96157913368587,
           26.998119146491778,
           27.034659159297686,
           27.071199172103594,
           27.107739184909505,
           27.144279197715417,
           27.180819210521324,
           27.217359223327236,
           27.253899236133144,
           27.29043924893905,
           27.326979261744963,
           27.36351927455087,
           27.400059287356783,
           27.43659930016269,
           27.4731393129686,
           27.50967932577451,
           27.54621933858042,
           27.582759351386326,
           27.619299364192234,
           27.655839376998145,
           27.69237938980406,
           27.728919402609964,
           27.765459415415876,
           27.80106545960946,
           27.83659367058756,
           27.872121881565658,
           27.907650092543765,
           27.943178303521865,
           27.978706514499965,
           28.01423472547807,
           28.049762936456176,
           28.08529114743427,
           28.120819358412376,
           28.156347569390476,
           28.191875780368576,
           28.227403991346684,
           28.262932202324784,
           28.298460413302884,
           28.333988624280984,
           28.36951683525909,
           28.40504504623719,
           28.44057325721529,
           28.476101468193395,
           28.5116296791715,
           28.5471578901496,
           28.582686101127702,
           28.618214312105806,
           28.653742523083906,
           28.689270734062006,
           28.72479894504011,
           28.760327156018214,
           28.795855366996314,
           28.831383577974417,
           28.86691178895252,
           28.902439999930618,
           28.93796821090872,
           28.97349642188683,
           29.00902463286493,
           29.044552843843025,
           29.080081054821132,
           29.11560926579923,
           29.151137476777333,
           29.186665687755436,
           29.222193898733536,
           29.257722109711636,
           29.293250320689737,
           29.328778531667844,
           29.36430674264594,
           29.399834953624044,
           29.435363164602148,
           29.470891375580248,
           29.50641958655835,
           29.541947797536455,
           29.577476008514555,
           29.613004219492655,
           29.64853243047076,
           29.68406064144886,
           29.71958885242696,
           29.755117063405066,
           29.790645274383166,
           29.826173485361267,
           29.861701696339367,
           29.871442521461077,
           29.82960857487001,
           29.787774628278946,
           29.745940681687877,
           29.70410673509681,
           29.662272788505746,
           29.620438841914677,
           29.578604895323608,
           29.53677094873255,
           29.494937002141477,
           29.45310305555041,
           29.41126910895935,
           29.369435162368283,
           29.32760121577721,
           29.285767269186145,
           29.243933322595083,
           29.202099376004014,
           29.16026542941295,
           29.118431482821883,
           29.076597536230818,
           29.034763589639745,
           28.992929643048683,
           28.95109569645762,
           28.90926174986655,
           28.867427803275486,
           28.82559385668442,
           28.78375991009335,
           28.74192596350229,
           28.70009201691122,
           28.65825807032015,
           28.616424123729082,
           28.574590177138024,
           28.532756230546955,
           28.490922283955886,
           28.44908833736482,
           28.40725439077376,
           28.36542044418269,
           28.323586497591627,
           28.281752551000558,
           28.23991860440949,
           28.198084657818427,
           28.156250711227358,
           28.11441676463629,
           28.072582818045223,
           28.030748871454158,
           27.988914924863096,
           27.94708097827202,
           27.90524703168096,
           27.863413085089896,
           27.821579138498826,
           27.77974519190776,
           27.7379112453167,
           27.69607729872563,
           27.65424335213456,
           27.6124094055435,
           27.57057545895243,
           27.52874151236136,
           27.486907565770295,
           27.445073619179233,
           27.403239672588164,
           27.3614057259971,
           27.319571779406033,
           27.277737832814964,
           27.235903886223895,
           27.194069939632836,
           27.152235993041764,
           27.110402046450698,
           27.068568099859633,
           27.026734153268567,
           26.9849002066775,
           26.943066260086432,
           26.90123231349537,
           26.8593983669043,
           26.81756442031324,
           26.77573047372217,
           26.733896527131105,
           26.692062580540032,
           26.650228633948974,
           26.619611016464997,
           26.590802464735503,
           26.56199391300601,
           26.53318536127652,
           26.504376809547022,
           26.43704234869763,
           26.17707834224872,
           25.91711433579981,
           25.657150329350902,
           25.420565745331743,
           25.188657078654035,
           24.956748411976324,
           24.724839745298656,
           24.492931078620945,
           24.261022411943234,
           24.02911374526557,
           23.79720507858786,
           23.565296411910154,
           23.333387745232443,
           23.101479078554775,
           22.869570411877067,
           22.63766174519936,
           22.40575307852169,
           22.17384441184398,
           21.941935745166273,
           21.710027078488608,
           21.478118411810897,
           21.246209745133186,
           21.01430107845552,
           20.78239241177781,
           20.550483745100102,
           20.31857507842239,
           20.086666411744726,
           19.854757745067015,
           19.622849078389308,
           19.39094041171164,
           19.15903174503393,
           18.927123078356217,
           18.695214411678553,
           18.463305745000845,
           18.231397078323138,
           17.999488411645423,
           17.767579744967758,
           17.53567107829005,
           17.30376241161234,
           17.071853744934675,
           16.839945078256964,
           16.608036411579256,
           16.376127744901588,
           16.144219078223877,
           15.912310411546168,
           15.680401744868501,
           15.448493078190793,
           15.216584411513084,
           14.984675744835373,
           14.752767078157706,
           14.520858411479995,
           14.288949744802288,
           14.057041078124621,
           13.82513241144691,
           13.593223744769201,
           13.361315078091534,
           13.129406411413825,
           12.897497744736118,
           12.665589078058407,
           12.433680411380742,
           12.20177174470303,
           11.969863078025321,
           11.737954411347655,
           11.506045744669946,
           11.274137077992236,
           11.04222841131457,
           10.81031974463686,
           10.578411077959153,
           10.346502411281485,
           10.114593744603775,
           9.882685077926066,
           9.650776411248357,
           9.418867744570688,
           9.186959077892979,
           8.95505041121527,
           8.723141744537603,
           8.491233077859894,
           8.259324411182186,
           8.02741574450452,
           7.807562136863225,
           7.611818541412648,
           7.4160749459620705,
           7.220331350511528
          ],
          [
           21.048410011072953,
           21.074623220199648,
           21.10083642932634,
           21.12704963845303,
           21.15326284757972,
           21.179476056706417,
           21.205689265833108,
           21.231902474959803,
           21.258115684086484,
           21.28432889321318,
           21.31054210233987,
           21.33675531146656,
           21.362968520593256,
           21.389181729719947,
           21.415394938846642,
           21.44160814797333,
           21.46782135710002,
           21.494034566226716,
           21.520247775353404,
           21.5464609844801,
           21.57267419360679,
           21.598887402733478,
           21.625100611860173,
           21.65131382098686,
           21.677527030113556,
           21.703740239240247,
           21.729953448366935,
           21.75616665749363,
           21.782379866620317,
           21.808593075747012,
           21.834806284873707,
           21.861019494000395,
           21.88723270312709,
           21.913445912253778,
           21.939659121380473,
           21.96587233050716,
           21.992085539633855,
           22.018298748760547,
           22.044511957887238,
           22.070725167013933,
           22.09693837614062,
           22.123151585267312,
           22.149364794394003,
           22.175578003520695,
           22.201791212647386,
           22.228004421774077,
           22.25421763090077,
           22.27963372706303,
           22.30345560069317,
           22.327277474323306,
           22.351099347953447,
           22.374921221583584,
           22.39874309521372,
           22.422564968843858,
           22.446386842474,
           22.47020871610414,
           22.494030589734276,
           22.517852463364417,
           22.541674336994554,
           22.565496210624694,
           22.58931808425483,
           22.613139957884968,
           22.636961831515105,
           22.660783705145242,
           22.684605578775383,
           22.708427452405523,
           22.732249326035657,
           22.7560711996658,
           22.779893073295938,
           22.803714946926075,
           22.827536820556215,
           22.851358694186352,
           22.875180567816493,
           22.89900244144663,
           22.922824315076767,
           22.946646188706907,
           22.97046806233704,
           22.99428993596718,
           23.018111809597322,
           23.04193368322746,
           23.065755556857596,
           23.089577430487736,
           23.113399304117877,
           23.13722117774801,
           23.1624319375549,
           23.187920474597135,
           23.21340901163937,
           23.238897548681614,
           23.26438608572385,
           23.289874622766085,
           23.31536315980832,
           23.34085169685056,
           23.3663402338928,
           23.391828770935035,
           23.41731730797727,
           23.44280584501951,
           23.46829438206175,
           23.493782919103985,
           23.51927145614622,
           23.54475999318846,
           23.570248530230696,
           23.595737067272935,
           23.62122560431517,
           23.646714141357407,
           23.672202678399643,
           23.697691215441882,
           23.72317975248412,
           23.748668289526357,
           23.774156826568593,
           23.79964536361083,
           23.825133900653068,
           23.850622437695307,
           23.876110974737543,
           23.90159951177978,
           23.927088048822018,
           23.952576585864257,
           23.978065122906493,
           24.00355365994873,
           24.029042196990968,
           24.054530734033204,
           24.080019271075443,
           24.10550780811768,
           24.130996345159915,
           24.156484882202154,
           24.181973419244393,
           24.20746195628663,
           24.232950493328865,
           24.2584390303711,
           24.283927567413336,
           24.30941610445558,
           24.33449547081571,
           24.357528990739702,
           24.380562510663694,
           24.403596030587686,
           24.426629550511684,
           24.449663070435676,
           24.472696590359668,
           24.49573011028366,
           24.518763630207655,
           24.541797150131647,
           24.564830670055642,
           24.587864189979634,
           24.61089770990363,
           24.63393122982762,
           24.656964749751616,
           24.679998269675608,
           24.7030317895996,
           24.726065309523594,
           24.749098829447586,
           24.77213234937158,
           24.795165869295573,
           24.81819938921957,
           24.84123290914356,
           24.864266429067552,
           24.887299948991547,
           24.91033346891554,
           24.933366988839534,
           24.95640050876353,
           24.979434028687518,
           25.002467548611516,
           25.025501068535505,
           25.048534588459503,
           25.07156810838349,
           25.094601628307487,
           25.11763514823148,
           25.140668668155474,
           25.163702188079466,
           25.18951863363668,
           25.21672654201051,
           25.243934450384337,
           25.271142358758162,
           25.298350267131987,
           25.32555817550582,
           25.352766083879644,
           25.379973992253472,
           25.4071819006273,
           25.43438980900112,
           25.46159771737495,
           25.488805625748775,
           25.516013534122607,
           25.54322144249643,
           25.570429350870256,
           25.59763725924408,
           25.62484516761791,
           25.652053075991738,
           25.679260984365563,
           25.706468892739387,
           25.733676801113212,
           25.760884709487044,
           25.78809261786087,
           25.8153005262347,
           25.842508434608522,
           25.869716342982347,
           25.896924251356175,
           25.924132159730004,
           25.95134006810383,
           25.97854797647766,
           26.00575588485148,
           26.032963793225314,
           26.060171701599135,
           26.08737960997296,
           26.114587518346788,
           26.141795426720613,
           26.169003335094445,
           26.19621124346827,
           26.223419151842094,
           26.250627060215923,
           26.277834968589747,
           26.305042876963576,
           26.3322507853374,
           26.359458693711233,
           26.386666602085057,
           26.413874510458886,
           26.441082418832707,
           26.468290327206535,
           26.49549823558036,
           26.52270614395419,
           26.549914052328017,
           26.578557087544727,
           26.60758650106234,
           26.636615914579945,
           26.665645328097558,
           26.69467474161517,
           26.723704155132772,
           26.752733568650388,
           26.781762982167997,
           26.81079239568561,
           26.839821809203215,
           26.86885122272082,
           26.897880636238437,
           26.926910049756046,
           26.95593946327365,
           26.984968876791267,
           27.013998290308876,
           27.043027703826485,
           27.072057117344098,
           27.101086530861707,
           27.130115944379316,
           27.159145357896925,
           27.188174771414538,
           27.217204184932147,
           27.246233598449756,
           27.275263011967365,
           27.304292425484974,
           27.333321839002586,
           27.362351252520195,
           27.391380666037804,
           27.42041007955541,
           27.449439493073022,
           27.478468906590635,
           27.511253619752395,
           27.547793632558307,
           27.584333645364215,
           27.620873658170122,
           27.657413670976034,
           27.69395368378194,
           27.730493696587853,
           27.76703370939376,
           27.803573722199673,
           27.840113735005577,
           27.87665374781149,
           27.913193760617396,
           27.949733773423308,
           27.98627378622922,
           28.02281379903513,
           28.059353811841035,
           28.095893824646943,
           28.132433837452854,
           28.168973850258766,
           28.205513863064674,
           28.24205387587058,
           28.278593888676497,
           28.315133901482398,
           28.351673914288313,
           28.388213927094224,
           28.424753939900135,
           28.461293952706036,
           28.49783396551195,
           28.53437397831786,
           28.570913991123767,
           28.60745400392968,
           28.64399401673559,
           28.68053402954149,
           28.717074042347406,
           28.753614055153314,
           28.790154067959225,
           28.826694080765137,
           28.863234093571045,
           28.899774106376952,
           28.936314119182864,
           28.97285413198877,
           29.009394144794676,
           29.04593415760059,
           29.082474170406503,
           29.119014183212414,
           29.155554196018315,
           29.19209420882423,
           29.22863422163014,
           29.265174234436053,
           29.301714247241957,
           29.33825426004787,
           29.374794272853773,
           29.411334285659684,
           29.447874298465592,
           29.484414311271504,
           29.52095432407741,
           29.557494336883323,
           29.59403434968923,
           29.630574362495146,
           29.667114375301054,
           29.703654388106962,
           29.74019440091287,
           29.77673441371878,
           29.813274426524686,
           29.8498144393306,
           29.88635445213651,
           29.922894464942416,
           29.959434477748328,
           29.995974490554236,
           30.032514503360147,
           30.069054516166055,
           30.105594528971963,
           30.142134541777875,
           30.178674554583786,
           30.21521456738969,
           30.251754580195602,
           30.28829459300151,
           30.32483460580742,
           30.36137461861333,
           30.39791463141924,
           30.434454644225152,
           30.470994657031063,
           30.50698985186585,
           30.516730676987553,
           30.474896730396487,
           30.430711972870093,
           30.382609151606076,
           30.334506330342077,
           30.286403509078074,
           30.238300687814057,
           30.19019786655005,
           30.14209504528605,
           30.093992224022035,
           30.045889402758032,
           29.997786581494022,
           29.949683760230023,
           29.90158093896601,
           29.853478117702004,
           29.805375296438,
           29.75727247517399,
           29.70916965390999,
           29.66106683264598,
           29.612964011381973,
           29.564861190117966,
           29.516758368853957,
           29.468655547589954,
           29.420552726325944,
           29.372449905061938,
           29.32434708379793,
           29.276244262533925,
           29.22814144126992,
           29.180038620005913,
           29.131935798741907,
           29.083832977477897,
           29.035730156213894,
           28.987627334949888,
           28.939524513685875,
           28.891421692421872,
           28.84331887115787,
           28.79521604989386,
           28.74711322862985,
           28.699010407365847,
           28.650907586101837,
           28.602804764837835,
           28.55470194357383,
           28.506599122309815,
           28.45849630104581,
           28.410393479781803,
           28.362290658517797,
           28.31418783725379,
           28.266085015989788,
           28.217982194725778,
           28.169879373461768,
           28.121776552197765,
           28.073673730933763,
           28.02557090966975,
           27.977468088405743,
           27.92936526714174,
           27.88126244587773,
           27.83315962461372,
           27.78505680334972,
           27.736953982085716,
           27.688851160821706,
           27.640748339557703,
           27.592645518293693,
           27.544542697029684,
           27.49643987576568,
           27.44833705450168,
           27.400234233237665,
           27.35213141197366,
           27.304028590709656,
           27.255925769445646,
           27.207822948181636,
           27.159720126917627,
           27.111617305653624,
           27.063514484389618,
           27.015411663125608,
           26.967308841861605,
           26.9192060205976,
           26.87110319933359,
           26.823000378069587,
           26.774897556805577,
           26.726794735541567,
           26.678691914277564,
           26.63058909301356,
           26.58248627174955,
           26.497072495469332,
           26.22510394410802,
           25.95313539274671,
           25.681166841385398,
           25.409198290024136,
           25.137229738662825,
           24.865261187301513,
           24.59329263594025,
           24.32132408457894,
           24.04935553321763,
           23.777386981856367,
           23.505418430495055,
           23.233449879133744,
           22.961481327772432,
           22.689512776411174,
           22.417544225049863,
           22.145575673688555,
           21.873607122327293,
           21.60163857096598,
           21.32967001960467,
           21.05770146824341,
           20.785732916882097,
           20.513764365520785,
           20.241795814159524,
           19.969827262798216,
           19.6978587114369,
           19.42589016007559,
           19.153921608714327,
           18.881953057353016,
           18.609984505991708,
           18.338015954630446,
           18.066047403269135,
           17.794078851907823,
           17.52211030054656,
           17.250141749185254,
           16.978173197823942,
           16.706204646462627,
           16.44440272474851,
           16.212494058070803,
           15.980585391393092,
           15.748676724715423,
           15.516768058037714,
           15.284859391360005,
           15.052950724682336,
           14.821042058004627,
           14.58913339132692,
           14.357224724649251,
           14.159580434598716,
           13.96520610307683,
           13.770831771554947,
           13.5764574400331,
           13.382083108511214,
           13.187708776989329,
           12.99333444546748,
           12.798960113945597,
           12.604585782423712,
           12.410211450901866,
           12.21583711937998,
           12.021462787858095,
           11.827088456336211,
           11.632714124814363,
           11.438339793292478,
           11.243965461770594,
           11.049591130248745,
           10.855216798726861,
           10.660842467204976,
           10.466468135683128,
           10.272093804161244,
           10.077719472639359,
           9.883345141117509,
           9.688970809595624,
           9.49459647807374,
           9.300222146551857,
           9.105847815030007,
           8.911473483508123,
           8.71709915198624,
           8.52272482046439,
           8.328350488942506,
           8.133976157420621,
           7.939601825898773,
           7.745227494376889,
           7.550853162855003,
           7.356478831333119,
           7.162104499811271
          ],
          [
           21.512765073532467,
           21.53897828265916,
           21.56519149178585,
           21.59140470091254,
           21.617617910039232,
           21.643831119165924,
           21.670044328292615,
           21.696257537419307,
           21.722470746546,
           21.748683955672693,
           21.77489716479938,
           21.801110373926072,
           21.827323583052763,
           21.853536792179458,
           21.87975000130615,
           21.905963210432844,
           21.932176419559532,
           21.958389628686223,
           21.984602837812915,
           22.01081604693961,
           22.037029256066297,
           22.063242465192992,
           22.08945567431968,
           22.115668883446375,
           22.141882092573066,
           22.168095301699758,
           22.194308510826446,
           22.22052171995314,
           22.24673492907983,
           22.272948138206523,
           22.299161347333214,
           22.325374556459906,
           22.351587765586597,
           22.37780097471329,
           22.404014183839983,
           22.43022739296667,
           22.456440602093366,
           22.482653811220054,
           22.50886702034675,
           22.53508022947344,
           22.56129343860013,
           22.587506647726823,
           22.613719856853514,
           22.63993306598021,
           22.666146275106897,
           22.69235948423359,
           22.71857269336028,
           22.744785902486974,
           22.770999111613666,
           22.797212320740357,
           22.823425529867052,
           22.849638738993736,
           22.87585194812043,
           22.902065157247122,
           22.92827836637381,
           22.95449157550051,
           22.980704784627196,
           23.00691799375389,
           23.03313120288058,
           23.05934441200727,
           23.085557621133965,
           23.111770830260653,
           23.137984039387348,
           23.16419724851404,
           23.18841767732259,
           23.21223955095273,
           23.236061424582868,
           23.259883298213005,
           23.283705171843145,
           23.307527045473286,
           23.331348919103423,
           23.355170792733563,
           23.378992666363697,
           23.402814539993837,
           23.426636413623974,
           23.450458287254115,
           23.474280160884252,
           23.498102034514392,
           23.52192390814453,
           23.545745781774666,
           23.569567655404807,
           23.593389529034944,
           23.617211402665085,
           23.64103327629522,
           23.666244036102107,
           23.69173257314435,
           23.717221110186586,
           23.74270964722882,
           23.768198184271057,
           23.793686721313293,
           23.819175258355536,
           23.84466379539777,
           23.870152332440007,
           23.895640869482243,
           23.921129406524486,
           23.946617943566714,
           23.972106480608957,
           23.997595017651193,
           24.023083554693436,
           24.04857209173567,
           24.074060628777907,
           24.099549165820143,
           24.125037702862386,
           24.15052623990462,
           24.176014776946857,
           24.201503313989093,
           24.22699185103133,
           24.252480388073565,
           24.277968925115808,
           24.303457462158043,
           24.32894599920028,
           24.354434536242515,
           24.37992307328475,
           24.405411610326993,
           24.43090014736923,
           24.456388684411465,
           24.4818772214537,
           24.507365758495936,
           24.53285429553818,
           24.55834283258041,
           24.58383136962265,
           24.60931990666489,
           24.634808443707126,
           24.660296980749365,
           24.685785517791597,
           24.711274054833837,
           24.73676259187608,
           24.762251128918315,
           24.78773966596055,
           24.813228203002787,
           24.838716740045022,
           24.864205277087258,
           24.8896938141295,
           24.915182351171737,
           24.940670888213972,
           24.96615942525621,
           24.99164796229845,
           25.017136499340687,
           25.042625036382923,
           25.06811357342516,
           25.093602110467394,
           25.119090647509637,
           25.144579184551873,
           25.17006772159411,
           25.195556258636344,
           25.221044795678587,
           25.246533332720816,
           25.27038519092691,
           25.2934187108509,
           25.316452230774896,
           25.339485750698884,
           25.362519270622883,
           25.385552790546875,
           25.408586310470866,
           25.43161983039486,
           25.454653350318853,
           25.477686870242845,
           25.500720390166844,
           25.523753910090832,
           25.546787430014827,
           25.56982094993882,
           25.592854469862814,
           25.61588798978681,
           25.6389215097108,
           25.661955029634793,
           25.68498854955879,
           25.708022069482777,
           25.73383851504,
           25.76104642341382,
           25.78825433178765,
           25.815462240161477,
           25.8426701485353,
           25.86987805690913,
           25.897085965282958,
           25.924293873656783,
           25.95150178203061,
           25.978709690404436,
           26.005917598778264,
           26.033125507152093,
           26.060333415525918,
           26.087541323899746,
           26.11474923227357,
           26.1419571406474,
           26.169165049021224,
           26.196372957395052,
           26.223580865768877,
           26.250788774142702,
           26.277996682516527,
           26.305204590890355,
           26.33241249926418,
           26.35962040763801,
           26.386828316011837,
           26.41403622438566,
           26.441244132759493,
           26.468452041133315,
           26.497095075512135,
           26.526124489029748,
           26.555153902547353,
           26.584183316064966,
           26.613212729582575,
           26.642242143100184,
           26.671271556617796,
           26.700300970135405,
           26.729330383653014,
           26.75835979717062,
           26.787389210688232,
           26.816418624205845,
           26.84544803772345,
           26.874477451241063,
           26.903506864758675,
           26.93253627827628,
           26.961565691793897,
           26.990595105311503,
           27.01962451882911,
           27.048653932346724,
           27.077683345864333,
           27.106712759381946,
           27.135742172899555,
           27.16477158641716,
           27.193800999934776,
           27.22283041345238,
           27.251859826969994,
           27.280889240487603,
           27.30991865400521,
           27.338948067522825,
           27.367977481040434,
           27.397006894558046,
           27.426036308075652,
           27.455065721593265,
           27.484095135110874,
           27.513124548628483,
           27.542153962146095,
           27.5711833756637,
           27.600212789181313,
           27.629242202698922,
           27.65827161621653,
           27.687301029734144,
           27.71633044325175,
           27.745359856769362,
           27.774389270286974,
           27.803418683804583,
           27.83244809732219,
           27.861477510839798,
           27.89050692435741,
           27.919536337875023,
           27.94856575139263,
           27.97759516491024,
           28.00662457842785,
           28.03565399194546,
           28.06468340546307,
           28.097468118624832,
           28.134008131430743,
           28.170548144236648,
           28.20708815704256,
           28.24362816984847,
           28.28016818265438,
           28.316708195460286,
           28.353248208266198,
           28.389788221072106,
           28.426328233878014,
           28.462868246683925,
           28.499408259489837,
           28.535948272295744,
           28.572488285101652,
           28.609028297907564,
           28.64556831071347,
           28.68210832351938,
           28.71864833632529,
           28.7551883491312,
           28.79172836193711,
           28.82826837474302,
           28.864808387548926,
           28.901348400354838,
           28.937888413160746,
           28.974428425966657,
           29.010968438772565,
           29.047508451578473,
           29.084048464384388,
           29.120588477190296,
           29.157128489996204,
           29.19366850280211,
           29.230208515608027,
           29.26674852841393,
           29.303288541219843,
           29.33982855402575,
           29.37636856683166,
           29.412908579637573,
           29.44944859244348,
           29.48598860524939,
           29.5225286180553,
           29.55906863086121,
           29.595608643667116,
           29.63214865647302,
           29.668688669278936,
           29.705228682084847,
           29.74176869489075,
           29.778308707696663,
           29.814848720502578,
           29.851388733308486,
           29.887928746114394,
           29.924468758920302,
           29.961008771726213,
           29.99754878453212,
           30.034088797338033,
           30.070628810143944,
           30.108706872007744,
           30.14691310561153,
           30.185119339215312,
           30.223325572819096,
           30.261531806422877,
           30.299738040026657,
           30.337944273630445,
           30.37615050723422,
           30.414356740838002,
           30.45256297444179,
           30.49076920804557,
           30.52897544164935,
           30.56718167525314,
           30.605387908856915,
           30.643594142460703,
           30.681800376064487,
           30.720006609668268,
           30.758212843272048,
           30.796419076875832,
           30.834625310479616,
           30.872831544083397,
           30.911037777687177,
           30.949244011290965,
           30.98745024489474,
           31.025656478498526,
           31.06386271210231,
           31.102068945706094,
           31.140275179309878,
           31.145092544884623,
           31.083132174401328,
           31.02117180391803,
           30.95921143343473,
           30.897251062951433,
           30.83529069246814,
           30.77333032198484,
           30.711369951501542,
           30.64940958101825,
           30.58744921053495,
           30.52548884005165,
           30.463528469568352,
           30.40156809908506,
           30.339607728601763,
           30.27764735811846,
           30.215686987635166,
           30.153726617151868,
           30.091766246668573,
           30.02980587618528,
           29.96784550570198,
           29.905885135218675,
           29.843924764735384,
           29.78196439425209,
           29.720004023768787,
           29.658043653285493,
           29.596083282802198,
           29.5341229123189,
           29.4721625418356,
           29.410202171352307,
           29.34824180086901,
           29.286281430385706,
           29.224321059902415,
           29.162360689419113,
           29.100400318935815,
           29.03843994845252,
           28.97647957796923,
           28.914519207485927,
           28.852558837002633,
           28.790598466519338,
           28.728638096036036,
           28.666677725552738,
           28.605230608557484,
           28.55712778729348,
           28.509024966029468,
           28.460922144765462,
           28.41281932350146,
           28.364716502237453,
           28.316613680973443,
           28.26851085970944,
           28.220408038445434,
           28.172305217181428,
           28.124202395917422,
           28.076099574653412,
           28.027996753389402,
           27.9798939321254,
           27.931791110861393,
           27.88368828959738,
           27.835585468333377,
           27.787482647069375,
           27.739379825805365,
           27.69127700454136,
           27.643174183277353,
           27.595071362013343,
           27.54696854074934,
           27.498865719485334,
           27.450762898221324,
           27.402660076957314,
           27.354557255693315,
           27.306454434429305,
           27.258351613165296,
           27.21024879190129,
           27.162145970637283,
           27.114043149373277,
           27.06594032810927,
           27.017837506845268,
           26.96973468558126,
           26.92163186431725,
           26.873529043053246,
           26.82542622178924,
           26.777323400525233,
           26.729220579261224,
           26.681117757997217,
           26.63301493673321,
           26.54760116045299,
           26.27563260909168,
           26.00366405773037,
           25.73169550636906,
           25.459726955007795,
           25.187758403646487,
           24.915789852285172,
           24.643821300923914,
           24.371852749562606,
           24.09988419820129,
           23.82791564684003,
           23.555947095478718,
           23.28397854411741,
           23.012009992756095,
           22.740041441394833,
           22.468072890033522,
           22.196104338672214,
           21.924135787310956,
           21.652167235949644,
           21.380198684588333,
           21.10823013322707,
           20.836261581865756,
           20.573656911732236,
           20.33801731928002,
           20.10237772682777,
           19.866738134375513,
           19.63109854192326,
           19.395458949471053,
           19.159819357018797,
           18.924179764566542,
           18.68854017211433,
           18.452900579662078,
           18.217260987209823,
           17.981621394757614,
           17.74598180230536,
           17.510342209853107,
           17.274702617400852,
           17.039063024948643,
           16.803423432496388,
           16.567783840044136,
           16.332144247591923,
           16.096504655139668,
           15.860865062687415,
           15.625225470235202,
           15.389585877782949,
           15.153946285330697,
           14.918306692878485,
           14.682667100426233,
           14.447027507973978,
           14.211387915521724,
           13.975748323069514,
           13.74010873061726,
           13.504469138165005,
           13.268829545712796,
           13.03318995326054,
           12.797550360808287,
           12.561910768356077,
           12.326271175903823,
           12.090631583451568,
           11.854991990999315,
           11.619352398547104,
           11.383712806094849,
           11.18557979247745,
           10.991205460955603,
           10.796831129433716,
           10.602456797911833,
           10.408082466389985,
           10.213708134868101,
           10.019333803346216,
           9.824959471824368,
           9.630585140302482,
           9.436210808780599,
           9.241836477258712,
           9.047462145736866,
           8.85308781421498,
           8.658713482693095,
           8.464339151171247,
           8.269964819649363,
           8.075590488127478,
           7.88121615660563,
           7.686841825083745,
           7.492467493561861,
           7.298093162039976,
           7.103718830518128
          ],
          [
           21.977120135991967,
           22.00333334511866,
           22.02954655424535,
           22.05575976337204,
           22.081972972498733,
           22.108186181625424,
           22.134399390752115,
           22.160612599878807,
           22.1868258090055,
           22.213039018132193,
           22.239252227258884,
           22.265465436385576,
           22.291678645512263,
           22.317891854638958,
           22.34410506376565,
           22.37031827289234,
           22.396531482019036,
           22.422744691145724,
           22.448957900272415,
           22.475171109399106,
           22.5013843185258,
           22.527597527652492,
           22.553810736779184,
           22.580023945905875,
           22.606237155032566,
           22.632450364159258,
           22.65866357328595,
           22.684876782412644,
           22.711089991539335,
           22.737303200666027,
           22.763516409792715,
           22.78972961891941,
           22.8159428280461,
           22.842156037172792,
           22.868369246299483,
           22.894582455426175,
           22.920795664552866,
           22.947008873679557,
           22.973222082806252,
           22.99943529193294,
           23.025648501059635,
           23.051861710186323,
           23.078074919313018,
           23.104288128439705,
           23.1305013375664,
           23.15671454669309,
           23.182927755819783,
           23.209140964946478,
           23.235354174073166,
           23.261567383199857,
           23.28778059232655,
           23.313993801453236,
           23.34020701057993,
           23.366420219706626,
           23.392633428833314,
           23.41884663796001,
           23.445059847086696,
           23.47127305621339,
           23.49748626534008,
           23.523699474466774,
           23.54991268359347,
           23.576125892720157,
           23.60233910184685,
           23.628552310973543,
           23.65476552010023,
           23.680978729226926,
           23.707191938353613,
           23.733405147480305,
           23.759618356607,
           23.785831565733687,
           23.812044774860382,
           23.838257983987074,
           23.864471193113765,
           23.890684402240456,
           23.916897611367148,
           23.943110820493843,
           23.96932402962053,
           23.99553723874722,
           24.021750447873913,
           24.047963657000608,
           24.073379753952008,
           24.097201627582145,
           24.121023501212285,
           24.144845374842422,
           24.17005613464931,
           24.195544671691547,
           24.221033208733786,
           24.246521745776025,
           24.272010282818258,
           24.297498819860497,
           24.322987356902736,
           24.348475893944972,
           24.373964430987208,
           24.399452968029447,
           24.424941505071683,
           24.45043004211392,
           24.475918579156154,
           24.501407116198394,
           24.526895653240633,
           24.55238419028287,
           24.577872727325108,
           24.603361264367347,
           24.628849801409583,
           24.65433833845182,
           24.679826875494054,
           24.705315412536294,
           24.730803949578533,
           24.75629248662077,
           24.781781023663005,
           24.80726956070524,
           24.83275809774748,
           24.85824663478972,
           24.883735171831955,
           24.909223708874194,
           24.93471224591643,
           24.96020078295867,
           24.9856893200009,
           25.011177857043137,
           25.036666394085376,
           25.062154931127615,
           25.08764346816985,
           25.113132005212087,
           25.138620542254323,
           25.164109079296562,
           25.1895976163388,
           25.21508615338104,
           25.240574690423276,
           25.266063227465512,
           25.291551764507748,
           25.31704030154999,
           25.342528838592226,
           25.368017375634462,
           25.393505912676698,
           25.418994449718937,
           25.444482986761173,
           25.469971523803412,
           25.495460060845648,
           25.520948597887884,
           25.546437134930123,
           25.571925671972362,
           25.597414209014598,
           25.622902746056834,
           25.648391283099073,
           25.67387982014131,
           25.69936835718355,
           25.724856894225784,
           25.75034543126802,
           25.77583396831026,
           25.8013225053525,
           25.826811042394734,
           25.85229957943697,
           25.87778811647921,
           25.903276653521445,
           25.92876519056368,
           25.95425372760592,
           25.979742264648156,
           26.00523080169039,
           26.03071933873263,
           26.05620787577487,
           26.081696412817106,
           26.10718494985934,
           26.13267348690158,
           26.158162023943817,
           26.183241391114105,
           26.206274911038097,
           26.229308430962092,
           26.25234195088608,
           26.278158396443303,
           26.305366304817127,
           26.332574213190952,
           26.359782121564784,
           26.3869900299386,
           26.415633063479536,
           26.44466247699714,
           26.473691890514754,
           26.502721304032363,
           26.531750717549972,
           26.56078013106758,
           26.589809544585194,
           26.6188389581028,
           26.647868371620408,
           26.676897785138024,
           26.70592719865563,
           26.73495661217324,
           26.76398602569085,
           26.79301543920846,
           26.822044852726073,
           26.851074266243685,
           26.88010367976129,
           26.909133093278896,
           26.938162506796512,
           26.96719192031412,
           26.996221333831727,
           27.025250747349343,
           27.05428016086695,
           27.08330957438456,
           27.11233898790217,
           27.14136840141978,
           27.170397814937388,
           27.199427228455,
           27.22845664197261,
           27.25748605549022,
           27.286515469007828,
           27.31554488252544,
           27.34457429604305,
           27.37360370956066,
           27.40263312307827,
           27.431662536595876,
           27.46069195011349,
           27.4897213636311,
           27.51875077714871,
           27.547780190666323,
           27.57680960418393,
           27.605839017701534,
           27.634868431219147,
           27.66389784473676,
           27.69292725825437,
           27.721956671771977,
           27.750986085289586,
           27.7800154988072,
           27.809044912324808,
           27.83807432584242,
           27.867103739360026,
           27.896133152877635,
           27.92516256639525,
           27.954191979912856,
           27.98322139343047,
           28.01225080694808,
           28.041280220465683,
           28.070309633983296,
           28.099339047500905,
           28.128368461018518,
           28.157397874536127,
           28.186427288053736,
           28.215456701571348,
           28.244486115088957,
           28.27351552860657,
           28.30254494212418,
           28.331574355641784,
           28.360603769159397,
           28.389633182677006,
           28.418662596194615,
           28.447692009712227,
           28.476721423229836,
           28.505750836747445,
           28.534780250265054,
           28.563809663782664,
           28.592839077300276,
           28.621868490817885,
           28.650897904335498,
           28.683682617497254,
           28.720222630303166,
           28.756762643109074,
           28.793302655914985,
           28.829842668720893,
           28.866382681526805,
           28.902922694332712,
           28.93946270713862,
           28.976002719944532,
           29.01254273275044,
           29.04908274555635,
           29.08562275836226,
           29.12216277116817,
           29.15870278397408,
           29.195242796779986,
           29.231782809585894,
           29.268322822391806,
           29.304862835197714,
           29.341402848003625,
           29.377942860809533,
           29.414482873615444,
           29.451022886421356,
           29.487562899227264,
           29.52410291203317,
           29.560642924839083,
           29.597375193467933,
           29.635581427071717,
           29.6737876606755,
           29.71199389427928,
           29.750200127883062,
           29.78840636148685,
           29.82661259509063,
           29.86481882869441,
           29.90302506229819,
           29.941231295901982,
           29.979437529505763,
           30.01764376310954,
           30.055849996713327,
           30.094056230317108,
           30.132262463920892,
           30.170468697524672,
           30.208674931128456,
           30.246881164732237,
           30.285087398336024,
           30.323293631939805,
           30.361499865543585,
           30.39970609914737,
           30.437912332751154,
           30.476118566354934,
           30.514324799958715,
           30.552531033562502,
           30.590737267166286,
           30.628943500770063,
           30.667149734373844,
           30.705355967977635,
           30.743562201581412,
           30.781768435185192,
           30.819974668788984,
           30.85818090239276,
           30.89638713599654,
           30.93459336960033,
           30.97279960320411,
           31.011005836807886,
           31.049212070411677,
           31.087418304015454,
           31.125624537619238,
           31.163830771223022,
           31.202037004826806,
           31.240243238430583,
           31.278449472034367,
           31.316655705638155,
           31.354861939241935,
           31.393068172845716,
           31.431274406449504,
           31.46948064005328,
           31.507686873657065,
           31.545893107260852,
           31.58409934086463,
           31.622305574468413,
           31.660511808072194,
           31.69871804167598,
           31.736924275279762,
           31.775130508883542,
           31.779947874458287,
           31.717987503974996,
           31.656027133491698,
           31.5940667630084,
           31.532106392525105,
           31.47014602204181,
           31.40818565155851,
           31.346225281075206,
           31.28426491059192,
           31.22230454010862,
           31.16034416962532,
           31.09838379914202,
           31.03642342865873,
           30.974463058175427,
           30.912502687692136,
           30.850542317208834,
           30.788581946725536,
           30.72662157624224,
           30.664661205758946,
           30.602700835275648,
           30.540740464792343,
           30.47878009430905,
           30.416819723825757,
           30.354859353342455,
           30.292898982859157,
           30.230938612375866,
           30.168978241892564,
           30.107017871409273,
           30.04505750092597,
           29.983097130442676,
           29.92113675995937,
           29.859176389476083,
           29.797216018992785,
           29.735255648509483,
           29.67329527802619,
           29.61133490754289,
           29.549374537059595,
           29.487414166576297,
           29.425453796093002,
           29.3634934256097,
           29.301533055126406,
           29.23957268464311,
           29.17761231415981,
           29.11565194367651,
           29.053691573193213,
           28.991731202709918,
           28.929770832226616,
           28.867810461743325,
           28.80585009126003,
           28.74388972077673,
           28.681929350293437,
           28.619968979810135,
           28.558008609326837,
           28.496048238843535,
           28.434087868360244,
           28.372127497876946,
           28.310167127393647,
           28.248206756910353,
           28.186246386427054,
           28.124286015943756,
           28.06232564546046,
           28.000365274977167,
           27.938404904493865,
           27.87644453401057,
           27.814484163527275,
           27.752523793043974,
           27.690563422560675,
           27.628603052077388,
           27.566642681594086,
           27.504682311110784,
           27.44272194062749,
           27.380761570144195,
           27.318801199660896,
           27.256840829177598,
           27.194880458694303,
           27.132920088211005,
           27.070959717727703,
           27.008999347244416,
           26.94703897676111,
           26.885078606277812,
           26.823118235794517,
           26.761157865311223,
           26.699197494827924,
           26.596265544436243,
           26.353214478911312,
           26.117574886459057,
           25.881935294006805,
           25.646295701554592,
           25.41065610910234,
           25.17501651665009,
           24.939376924197873,
           24.703737331745625,
           24.46809773929337,
           24.232458146841157,
           23.996818554388902,
           23.76117896193665,
           23.525539369484395,
           23.289899777032183,
           23.054260184579928,
           22.818620592127676,
           22.582980999675467,
           22.34734140722321,
           22.111701814770957,
           21.876062222318748,
           21.640422629866492,
           21.40478303741424,
           21.169143444962028,
           20.933503852509773,
           20.69786426005752,
           20.46222466760527,
           20.22658507515306,
           19.990945482700806,
           19.75530589024855,
           19.51966629779634,
           19.284026705344086,
           19.04838711289183,
           18.812747520439622,
           18.577107927987367,
           18.34146833553511,
           18.10582874308286,
           17.87018915063065,
           17.634549558178396,
           17.39890996572614,
           17.16327037327393,
           16.92763078082168,
           16.69199118836942,
           16.456351595917212,
           16.220712003464957,
           15.985072411012705,
           15.749432818560493,
           15.51379322610824,
           15.278153633655986,
           15.04251404120373,
           14.806874448751522,
           14.571234856299267,
           14.335595263847011,
           14.099955671394802,
           13.864316078942547,
           13.628676486490296,
           13.393036894038083,
           13.157397301585831,
           12.921757709133576,
           12.686118116681321,
           12.450478524229112,
           12.214838931776857,
           11.979199339324603,
           11.743559746872393,
           11.507920154420137,
           11.272280561967886,
           11.036640969515673,
           10.801001377063422,
           10.565361784611166,
           10.329722192158957,
           10.094082599706702,
           9.858443007254447,
           9.622803414802194,
           9.387163822349983,
           9.15152422989773,
           8.915884637445476,
           8.680245044993265,
           8.44460545254101,
           8.208965860088757,
           7.973326267636547,
           7.737686675184293,
           7.502047082732039,
           7.266407490279785,
           7.045342719295057
          ],
          [
           22.43633495345867,
           22.464918756944183,
           22.4935025604297,
           22.522086363915218,
           22.55067016740073,
           22.579253970886246,
           22.60783777437176,
           22.636421577857273,
           22.66500538134279,
           22.69358918482831,
           22.722172988313822,
           22.750756791799336,
           22.77934059528485,
           22.807924398770364,
           22.834137607948076,
           22.86035081707477,
           22.886564026201462,
           22.91277723532815,
           22.938990444454845,
           22.965203653581536,
           22.991416862708228,
           23.01763007183492,
           23.04384328096161,
           23.0700564900883,
           23.096269699214993,
           23.122482908341684,
           23.148696117468376,
           23.174909326595067,
           23.20112253572176,
           23.227335744848453,
           23.253548953975145,
           23.279762163101836,
           23.305975372228524,
           23.33218858135522,
           23.35840179048191,
           23.3846149996086,
           23.410828208735293,
           23.437041417861984,
           23.463254626988675,
           23.489467836115367,
           23.515681045242058,
           23.54189425436875,
           23.568107463495444,
           23.594320672622136,
           23.620533881748823,
           23.646747090875515,
           23.67296030000221,
           23.699173509128897,
           23.725386718255592,
           23.751599927382287,
           23.777813136508975,
           23.80402634563567,
           23.830239554762358,
           23.856452763889045,
           23.88266597301574,
           23.90887918214243,
           23.935092391269126,
           23.961305600395818,
           23.987518809522506,
           24.0137320186492,
           24.03994522777589,
           24.066158436902583,
           24.092371646029275,
           24.118584855155966,
           24.144798064282657,
           24.17101127340935,
           24.19722448253604,
           24.22343769166273,
           24.249650900789426,
           24.275864109916114,
           24.302077319042805,
           24.3282905281695,
           24.35450373729619,
           24.380716946422883,
           24.406930155549574,
           24.43314336467627,
           24.459356573802957,
           24.485569782929648,
           24.511782992056343,
           24.537996201183034,
           24.564209410309726,
           24.590422619436413,
           24.61663582856311,
           24.6428490376898,
           24.668458353412777,
           24.693946890455017,
           24.719435427497253,
           24.744923964539492,
           24.770412501581724,
           24.795901038623963,
           24.821389575666203,
           24.846878112708435,
           24.872366649750674,
           24.897855186792917,
           24.923343723835146,
           24.94883226087739,
           24.974320797919624,
           24.99980933496186,
           25.025297872004103,
           25.05078640904634,
           25.076274946088574,
           25.10176348313081,
           25.12725202017305,
           25.15274055721529,
           25.178229094257524,
           25.20371763129976,
           25.229206168341996,
           25.25469470538423,
           25.280183242426475,
           25.30567177946871,
           25.331160316510946,
           25.35664885355318,
           25.38213739059542,
           25.40762592763766,
           25.433114464679896,
           25.458603001722132,
           25.484091538764375,
           25.50958007580661,
           25.53506861284884,
           25.560557149891082,
           25.586045686933318,
           25.61153422397556,
           25.637022761017796,
           25.662511298060032,
           25.687999835102268,
           25.713488372144504,
           25.738976909186743,
           25.76446544622898,
           25.789953983271218,
           25.815442520313454,
           25.84093105735569,
           25.86641959439793,
           25.891908131440168,
           25.917396668482404,
           25.94288520552464,
           25.96837374256688,
           25.993862279609118,
           26.01935081665135,
           26.04483935369359,
           26.07032789073583,
           26.09581642777806,
           26.1213049648203,
           26.14679350186254,
           26.172282038904775,
           26.197770575947015,
           26.22325911298925,
           26.248747650031486,
           26.274236187073726,
           26.29972472411596,
           26.3252132611582,
           26.350701798200436,
           26.376190335242672,
           26.40167887228491,
           26.427167409327147,
           26.454209074780223,
           26.482027304363502,
           26.509845533946788,
           26.53766376353007,
           26.565481993113345,
           26.59330022269663,
           26.62111845227991,
           26.648936681863194,
           26.67675491144648,
           26.70457314102976,
           26.73239137061304,
           26.76020960019632,
           26.7880278297796,
           26.816921388090872,
           26.84635261076612,
           26.875783833441375,
           26.90521505611663,
           26.934646278791885,
           26.964077501467138,
           26.993508724142394,
           27.022939946817644,
           27.0523711694929,
           27.081802392168157,
           27.111233614843407,
           27.140664837518663,
           27.170096060193917,
           27.19952728286917,
           27.228958505544423,
           27.258389728219676,
           27.287820950894933,
           27.317252173570186,
           27.34668339624544,
           27.376114618920692,
           27.405545841595945,
           27.434977064271198,
           27.464408286946455,
           27.493839509621708,
           27.52327073229696,
           27.552701954972218,
           27.582133177647467,
           27.611564400322724,
           27.640995622997977,
           27.67042684567323,
           27.699858068348483,
           27.72928929102374,
           27.75872051369899,
           27.788151736374246,
           27.817582959049496,
           27.84701418172475,
           27.87644540440001,
           27.90587662707526,
           27.935307849750515,
           27.964739072425772,
           27.994170295101025,
           28.023601517776278,
           28.053032740451528,
           28.082463963126784,
           28.11189518580204,
           28.141326408477287,
           28.170757631152547,
           28.200188853827797,
           28.229620076503053,
           28.25905129917831,
           28.28848252185356,
           28.317913744528816,
           28.34734496720407,
           28.376776189879322,
           28.40620741255458,
           28.435638635229832,
           28.465069857905082,
           28.49450108058034,
           28.523932303255595,
           28.55336352593085,
           28.582794748606098,
           28.612225971281354,
           28.641657193956608,
           28.671088416631864,
           28.700519639307117,
           28.729950861982367,
           28.759382084657624,
           28.78881330733288,
           28.81824453000813,
           28.847675752683383,
           28.87710697535864,
           28.906538198033893,
           28.935969420709146,
           28.965400643384402,
           28.994831866059656,
           29.024263088734905,
           29.05369431141016,
           29.083125534085415,
           29.11255675676067,
           29.141987979435925,
           29.171419202111178,
           29.202943101394297,
           29.234520658997486,
           29.27031193833637,
           29.310316939410942,
           29.350321940485514,
           29.390301855044367,
           29.428525702947628,
           29.466749550850885,
           29.504973398754146,
           29.543197246657403,
           29.581421094560667,
           29.61964494246392,
           29.657868790367182,
           29.696092638270443,
           29.734316486173697,
           29.772540334076954,
           29.81076418198021,
           29.848988029883472,
           29.887211877786733,
           29.925435725689987,
           29.963659573593247,
           30.001883421496505,
           30.040107269399762,
           30.078331117303023,
           30.116554965206277,
           30.15477881310954,
           30.193002661012798,
           30.23122650891606,
           30.269450356819313,
           30.307674204722574,
           30.345898052625834,
           30.384121900529088,
           30.42234574843235,
           30.46056959633561,
           30.498793444238864,
           30.537017292142124,
           30.575241140045385,
           30.613464987948642,
           30.6516888358519,
           30.68991268375516,
           30.72813653165842,
           30.76636037956167,
           30.80458422746493,
           30.842808075368193,
           30.88103192327145,
           30.919255771174708,
           30.95747961907797,
           30.995703466981222,
           31.033927314884487,
           31.072151162787748,
           31.110375010691,
           31.14859885859426,
           31.186822706497516,
           31.225046554400777,
           31.26327040230403,
           31.30149425020729,
           31.339718098110556,
           31.37794194601381,
           31.416165793917074,
           31.454389641820327,
           31.49261348972358,
           31.530837337626842,
           31.569061185530103,
           31.60728503343336,
           31.645508881336617,
           31.68373272923988,
           31.72195657714314,
           31.760180425046393,
           31.798404272949654,
           31.836628120852914,
           31.874851968756168,
           31.913075816659425,
           31.95129966456269,
           31.989523512465944,
           32.027747360369204,
           32.06597120827246,
           32.104195056175726,
           32.14241890407898,
           32.18064275198224,
           32.218866599885494,
           32.25709044778875,
           32.29531429569201,
           32.33353814359527,
           32.37176199149853,
           32.409985838457224,
           32.412842498112944,
           32.34292374076297,
           32.27300498341299,
           32.20308622606301,
           32.133167468713026,
           32.06324871136305,
           31.993329954013063,
           31.923411196663082,
           31.85349243931311,
           31.78357368196313,
           31.713654924613145,
           31.643736167263167,
           31.57381740991319,
           31.503898652563205,
           31.433979895213227,
           31.36406113786325,
           31.294142380513264,
           31.224223623163287,
           31.154304865813316,
           31.08438610846333,
           31.014467351113346,
           30.944548593763372,
           30.87462983641339,
           30.80471107906341,
           30.73479232171343,
           30.664873564363454,
           30.59495480701347,
           30.525036049663495,
           30.455117292313517,
           30.385198534963532,
           30.31527977761355,
           30.24536102026358,
           30.17544226291359,
           30.10552350556361,
           30.035604748213633,
           29.965685990863655,
           29.895767233513673,
           29.8258484761637,
           29.755929718813718,
           29.686010961463737,
           29.61609220411376,
           29.54617344676378,
           29.4762546894138,
           29.40633593206381,
           29.336417174713837,
           29.266498417363856,
           29.196579660013875,
           29.126660902663897,
           29.056742145313923,
           28.986823387963938,
           28.91690463061396,
           28.846985873263982,
           28.777067115914,
           28.70714835856402,
           28.637229601214045,
           28.567310843864064,
           28.49739208651408,
           28.427473329164105,
           28.357554571814127,
           28.28763581446414,
           28.21771705711416,
           28.147798299764187,
           28.077879542414202,
           28.00796078506422,
           27.938042027714246,
           27.868123270364265,
           27.798204513014284,
           27.72828575566431,
           27.658366998314328,
           27.588448240964343,
           27.518529483614365,
           27.448610726264384,
           27.378691968914403,
           27.308773211564425,
           27.23885445421445,
           27.168935696864466,
           27.099016939514485,
           27.02909818216451,
           26.959179424814526,
           26.88926066746454,
           26.819341910114566,
           26.749423152764592,
           26.679504395414604,
           26.574554007464783,
           26.29444546651568,
           26.014336925566578,
           25.734228384617474,
           25.454119843668423,
           25.17401130271932,
           24.89390276177022,
           24.613794220821166,
           24.333685679872065,
           24.05357713892296,
           23.773468597973913,
           23.49336005702481,
           23.213251516075708,
           22.933142975126604,
           22.65303443417755,
           22.372925893228448,
           22.092817352279347,
           21.812708811330296,
           21.532600270381195,
           21.25249172943209,
           20.972383188483043,
           20.69227464753394,
           20.412166106584834,
           20.132057565635783,
           19.851949024686682,
           19.57184048373758,
           19.29173194278848,
           19.011623401839422,
           18.73151486089032,
           18.45140631994122,
           18.17129777899217,
           17.89118923804307,
           17.611080697093964,
           17.330972156144913,
           17.050863615195812,
           16.770755074246708,
           16.490646533297607,
           16.210537992348556,
           15.930429451399451,
           15.664740661563593,
           15.427891370385371,
           15.1910420792071,
           14.954192788028832,
           14.717343496850608,
           14.48049420567234,
           14.281090094289741,
           14.089175020349131,
           13.897259946408484,
           13.70534487246784,
           13.513429798527195,
           13.321514724586585,
           13.129599650645941,
           12.937684576705298,
           12.745769502764688,
           12.553854428824042,
           12.361939354883399,
           12.170024280942789,
           11.978109207002143,
           11.786194133061498,
           11.594279059120854,
           11.402363985180244,
           11.210448911239599,
           11.018533837298957,
           10.826618763358347,
           10.634703689417702,
           10.442788615477056,
           10.250873541536446,
           10.0589584675958,
           9.867043393655157,
           9.675128319714549,
           9.483213245773904,
           9.291298171833258,
           9.099383097892613,
           8.907468023952003,
           8.715552950011359,
           8.523637876070714,
           8.331722802130104,
           8.13980772818946,
           7.947892654248815,
           7.755977580308205,
           7.564062506367561,
           7.372147432426916,
           7.180232358486271,
           6.988317284545662
          ],
          [
           22.894165858757475,
           22.92274966224299,
           22.951333465728506,
           22.97991726921402,
           23.008501072699538,
           23.037084876185048,
           23.065668679670566,
           23.09425248315608,
           23.122836286641594,
           23.15142009012711,
           23.180003893612625,
           23.208587697098142,
           23.237171500583656,
           23.26575530406917,
           23.294339107554688,
           23.3229229110402,
           23.351506714525716,
           23.38009051801123,
           23.408674321496747,
           23.43725812498226,
           23.46584192846778,
           23.49442573195329,
           23.523009535438806,
           23.55159333892432,
           23.580177142409838,
           23.60876094589535,
           23.637344749380865,
           23.665928552866383,
           23.694512356351893,
           23.72309615983741,
           23.75049466658568,
           23.776707875712372,
           23.802921084839063,
           23.829134293965758,
           23.855347503092446,
           23.88156071221914,
           23.90777392134583,
           23.933987130472524,
           23.96020033959921,
           23.986413548725906,
           24.012626757852594,
           24.03883996697929,
           24.06505317610598,
           24.09126638523267,
           24.11747959435936,
           24.143692803486054,
           24.16990601261275,
           24.196119221739437,
           24.222332430866125,
           24.248545639992823,
           24.27475884911951,
           24.300972058246206,
           24.327185267372897,
           24.353398476499585,
           24.37961168562628,
           24.405824894752968,
           24.432038103879663,
           24.45825131300635,
           24.484464522133045,
           24.51067773125974,
           24.536890940386428,
           24.563104149513123,
           24.58931735863981,
           24.615530567766502,
           24.641743776893193,
           24.667956986019888,
           24.694170195146576,
           24.72038340427327,
           24.746596613399962,
           24.772809822526654,
           24.79902303165335,
           24.825236240780036,
           24.85144944990673,
           24.87766265903342,
           24.903875868160114,
           24.9300890772868,
           24.956302286413496,
           24.982515495540188,
           25.00872870466688,
           25.034941913793567,
           25.061155122920262,
           25.087368332046953,
           25.113581541173644,
           25.13979475030034,
           25.165404066023314,
           25.190892603065553,
           25.21638114010779,
           25.241869677150028,
           25.267358214192264,
           25.2928467512345,
           25.318335288276735,
           25.343823825318978,
           25.369312362361214,
           25.39480089940345,
           25.420289436445685,
           25.445777973487928,
           25.47126651053016,
           25.496755047572403,
           25.522243584614635,
           25.54773212165687,
           25.573220658699114,
           25.59870919574135,
           25.624197732783585,
           25.64968626982583,
           25.675174806868064,
           25.7006633439103,
           25.726151880952536,
           25.75164041799477,
           25.777128955037014,
           25.80261749207925,
           25.828106029121486,
           25.85359456616372,
           25.879083103205957,
           25.9045716402482,
           25.930060177290436,
           25.95554871433267,
           25.98103725137491,
           26.006525788417147,
           26.03201432545938,
           26.05750286250162,
           26.082991399543854,
           26.108479936586097,
           26.133968473628332,
           26.159457010670568,
           26.184945547712807,
           26.210434084755043,
           26.23592262179728,
           26.261411158839515,
           26.286899695881758,
           26.312388232923993,
           26.33787676996623,
           26.363365307008465,
           26.388853844050708,
           26.414342381092943,
           26.43983091813518,
           26.465319455177415,
           26.49080799221965,
           26.5166848117866,
           26.544503041369886,
           26.572321270953164,
           26.600139500536446,
           26.627957730119732,
           26.65577595970301,
           26.683594189286293,
           26.711412418869575,
           26.739230648452857,
           26.76704887803614,
           26.79486710761942,
           26.822685337202703,
           26.85050356678599,
           26.87832179636927,
           26.90614002595255,
           26.933958255535835,
           26.961776485119113,
           26.9895947147024,
           27.017412944285677,
           27.04523117386896,
           27.073049403452245,
           27.100867633035524,
           27.128685862618806,
           27.15650409220209,
           27.184322321785373,
           27.212140551368655,
           27.239958780951934,
           27.267777010535216,
           27.295595240118498,
           27.32341346970178,
           27.352307028013044,
           27.381738250688297,
           27.41116947336355,
           27.440600696038807,
           27.47003191871406,
           27.499463141389313,
           27.52889436406457,
           27.558325586739823,
           27.587756809415076,
           27.61718803209033,
           27.646619254765586,
           27.67605047744084,
           27.705481700116092,
           27.73491292279135,
           27.764344145466602,
           27.79377536814185,
           27.823206590817108,
           27.852637813492365,
           27.882069036167614,
           27.911500258842867,
           27.940931481518124,
           27.970362704193377,
           27.99979392686863,
           28.029225149543883,
           28.058656372219133,
           28.08808759489439,
           28.117518817569646,
           28.146950040244896,
           28.176381262920156,
           28.20581248559541,
           28.235243708270666,
           28.264674930945915,
           28.294106153621172,
           28.32353737629642,
           28.352968598971675,
           28.382399821646928,
           28.411831044322184,
           28.441262266997438,
           28.47069348967269,
           28.500124712347947,
           28.529555935023197,
           28.558987157698454,
           28.588418380373707,
           28.61784960304896,
           28.647280825724213,
           28.676712048399466,
           28.706143271074723,
           28.73557449374998,
           28.76500571642523,
           28.794436939100486,
           28.823868161775735,
           28.85329938445099,
           28.882730607126245,
           28.9121618298015,
           28.941593052476755,
           28.971024275152004,
           29.00045549782726,
           29.029886720502518,
           29.059317943177767,
           29.088749165853024,
           29.118180388528273,
           29.14761161120353,
           29.179081852520717,
           29.210659410123906,
           29.242236967727102,
           29.273814525330298,
           29.305392082933494,
           29.336969640536687,
           29.368547198139883,
           29.400124755743075,
           29.431702313346268,
           29.46327987094946,
           29.494857428552653,
           29.526434986155845,
           29.55801254375904,
           29.589590101362234,
           29.62116765896543,
           29.652745216568626,
           29.684322774171818,
           29.71590033177501,
           29.747477889378207,
           29.7790554469814,
           29.81063300458459,
           29.846424283923476,
           29.88642928499805,
           29.92643428607262,
           29.96643928714719,
           30.00644428822177,
           30.04644928929634,
           30.086454290370913,
           30.126459291445485,
           30.16646429252006,
           30.206469293594626,
           30.246474294669202,
           30.286479295743774,
           30.32648429681835,
           30.366489297892922,
           30.406494298967495,
           30.446499300042067,
           30.48650430111664,
           30.52650930219121,
           30.56651430326578,
           30.606519304340356,
           30.64652430541493,
           30.686529306489504,
           30.726534307564073,
           30.766539308638645,
           30.806544309713225,
           30.846549310787797,
           30.886554311862366,
           30.92655931293694,
           30.966564314011514,
           31.006569315086082,
           31.046060040829204,
           31.084283888732458,
           31.12250773663571,
           31.160731584538976,
           31.198955432442233,
           31.237179280345494,
           31.27540312824875,
           31.313626976152012,
           31.35185082405527,
           31.390074671958526,
           31.42829851986179,
           31.46652236776504,
           31.5047462156683,
           31.542970063571563,
           31.58119391147482,
           31.619417759378074,
           31.657641607281334,
           31.695865455184595,
           31.734089303087853,
           31.772313150991117,
           31.81053699889437,
           31.848760846797624,
           31.886984694700878,
           31.925208542604146,
           31.963432390507403,
           32.00165623841066,
           32.03988008631392,
           32.07810393421718,
           32.116327782120436,
           32.1545516300237,
           32.19277547792696,
           32.23099932583021,
           32.26922317373347,
           32.30744702163673,
           32.34567086953999,
           32.38389471744324,
           32.42211856534651,
           32.46034241324976,
           32.498566261153016,
           32.536790109056284,
           32.575013956959545,
           32.6132378048628,
           32.65146165276605,
           32.68968550066932,
           32.727909348572574,
           32.76613319647583,
           32.80435704437909,
           32.84258089228235,
           32.8808047401856,
           32.919028588088864,
           32.95725243599213,
           32.995476283895385,
           33.03370013179864,
           33.0311144097849,
           32.94690954793719,
           32.86270468608948,
           32.77849982424176,
           32.69429496239405,
           32.610090100546344,
           32.52588523869862,
           32.44168037685091,
           32.35747551500321,
           32.27327065315549,
           32.189065791307776,
           32.10486092946006,
           32.02065606761236,
           31.93645120576464,
           31.85224634391693,
           31.768041482069222,
           31.6838366202215,
           31.599631758373793,
           31.515426896526083,
           31.431222034678367,
           31.34701717283065,
           31.26281231098294,
           31.178607449135228,
           31.09440258728751,
           31.010197725439806,
           30.925992863592096,
           30.841788001744384,
           30.757583139896667,
           30.673378278048958,
           30.589173416201245,
           30.504968554353532,
           30.420763692505826,
           30.336558830658113,
           30.252353968810393,
           30.16814910696268,
           30.083944245114974,
           29.999739383267258,
           29.91553452141955,
           29.831329659571843,
           29.74712479772412,
           29.66291993587641,
           29.578715074028704,
           29.494510212180987,
           29.41030535033327,
           29.326100488485558,
           29.2447868803924,
           29.174868123042415,
           29.10494936569244,
           29.035030608342463,
           28.96511185099248,
           28.8951930936425,
           28.825274336292523,
           28.75535557894254,
           28.685436821592553,
           28.615518064242586,
           28.5455993068926,
           28.475680549542616,
           28.405761792192642,
           28.33584303484266,
           28.26592427749268,
           28.196005520142705,
           28.126086762792724,
           28.056168005442743,
           27.98624924809277,
           27.916330490742787,
           27.846411733392806,
           27.776492976042817,
           27.70657421869285,
           27.63665546134287,
           27.56673670399288,
           27.496817946642903,
           27.426899189292925,
           27.356980431942944,
           27.287061674592966,
           27.217142917242988,
           27.147224159893007,
           27.077305402543022,
           27.00738664519305,
           26.93746788784307,
           26.86754913049308,
           26.797630373143107,
           26.72771161579313,
           26.657792858443145,
           26.55284247049332,
           26.27273392954422,
           25.992625388595116,
           25.712516847646015,
           25.432408306696964,
           25.152299765747863,
           24.872191224798758,
           24.59208268384971,
           24.311974142900603,
           24.031865601951502,
           23.75175706100245,
           23.471648520053346,
           23.19153997910425,
           22.911431438155148,
           22.63132289720609,
           22.351214356256992,
           22.071105815307885,
           21.790997274358837,
           21.528913431124362,
           21.292064139946092,
           21.055214848767868,
           20.8183655575896,
           20.58151626641133,
           20.344666975233107,
           20.10781768405484,
           19.870968392876573,
           19.634119101698303,
           19.39726981052008,
           19.160420519341812,
           18.923571228163542,
           18.686721936985318,
           18.449872645807048,
           18.21302335462878,
           17.976174063450557,
           17.73932477227229,
           17.502475481094024,
           17.265626189915757,
           17.02877689873753,
           16.791927607559263,
           16.555078316380992,
           16.31822902520277,
           16.081379734024498,
           15.844530442846231,
           15.607681151668007,
           15.370831860489739,
           15.13398256931147,
           14.897133278133246,
           14.66028398695498,
           14.423434695776713,
           14.186585404598443,
           13.949736113420219,
           13.71288682224195,
           13.476037531063682,
           13.239188239885458,
           13.00233894870719,
           12.76548965752892,
           12.528640366350697,
           12.29179107517243,
           12.054941783994163,
           11.818092492815895,
           11.581243201637669,
           11.344393910459402,
           11.107544619281134,
           10.870695328102908,
           10.63384603692464,
           10.396996745746371,
           10.193848106787053,
           10.001933032846408,
           9.810017958905762,
           9.618102884965154,
           9.426187811024509,
           9.234272737083863,
           9.04235766314322,
           8.85044258920261,
           8.658527515261966,
           8.46661244132132,
           8.27469736738071,
           8.082782293440067,
           7.890867219499422,
           7.698952145558812,
           7.507037071618168,
           7.315121997677522,
           7.123206923736877,
           6.931291849796269
          ],
          [
           23.351996764056288,
           23.380580567541802,
           23.40916437102732,
           23.437748174512834,
           23.46633197799835,
           23.49491578148386,
           23.52349958496938,
           23.552083388454893,
           23.580667191940407,
           23.609250995425928,
           23.637834798911438,
           23.666418602396956,
           23.69500240588247,
           23.723586209367983,
           23.7521700128535,
           23.78075381633901,
           23.80933761982453,
           23.837921423310043,
           23.86650522679556,
           23.895089030281074,
           23.92367283376659,
           23.952256637252102,
           23.98084044073762,
           24.009424244223133,
           24.038008047708647,
           24.066591851194165,
           24.09517565467968,
           24.123759458165193,
           24.152343261650707,
           24.180927065136224,
           24.209510868621738,
           24.238094672107255,
           24.26667847559277,
           24.295262279078287,
           24.323846082563797,
           24.352429886049315,
           24.38101368953483,
           24.409597493020343,
           24.43818129650586,
           24.466765099991374,
           24.495348903476888,
           24.523932706962405,
           24.55251651044792,
           24.581100313933433,
           24.60968411741895,
           24.638267920904468,
           24.66685172438998,
           24.693064934349984,
           24.71927814347667,
           24.745491352603374,
           24.771704561730058,
           24.797917770856756,
           24.824130979983444,
           24.85034418911013,
           24.87655739823683,
           24.902770607363514,
           24.928983816490213,
           24.955197025616897,
           24.981410234743592,
           25.007623443870287,
           25.033836652996975,
           25.06004986212367,
           25.086263071250357,
           25.112476280377045,
           25.138689489503744,
           25.164902698630435,
           25.191115907757126,
           25.217329116883818,
           25.243542326010513,
           25.2697555351372,
           25.295968744263895,
           25.322181953390583,
           25.348395162517278,
           25.37460837164397,
           25.40082158077066,
           25.427034789897352,
           25.453247999024043,
           25.479461208150738,
           25.505674417277426,
           25.531887626404117,
           25.55810083553081,
           25.584314044657503,
           25.61052725378419,
           25.636740462910886,
           25.66234977863386,
           25.687838315676103,
           25.71332685271834,
           25.738815389760575,
           25.76430392680281,
           25.78979246384505,
           25.815281000887286,
           25.840769537929525,
           25.86625807497176,
           25.891746612014,
           25.91723514905624,
           25.942723686098468,
           25.96821222314071,
           25.993700760182946,
           26.01918929722519,
           26.044677834267425,
           26.07016637130966,
           26.095654908351896,
           26.121143445394132,
           26.146631982436375,
           26.17212051947861,
           26.197609056520847,
           26.223097593563082,
           26.248586130605318,
           26.27407466764756,
           26.299563204689797,
           26.325051741732032,
           26.350540278774268,
           26.376028815816504,
           26.401517352858747,
           26.427005889900983,
           26.45249442694322,
           26.477982963985454,
           26.50347150102769,
           26.528960038069933,
           26.554448575112165,
           26.579937112154404,
           26.606978778376273,
           26.634797007959556,
           26.662615237542838,
           26.690433467126123,
           26.7182516967094,
           26.746069926292684,
           26.773888155875966,
           26.801706385459248,
           26.82952461504253,
           26.857342844625812,
           26.885161074209094,
           26.912979303792376,
           26.940797533375658,
           26.96861576295894,
           26.996433992542222,
           27.024252222125504,
           27.052070451708786,
           27.07988868129207,
           27.10770691087535,
           27.135525140458633,
           27.163343370041915,
           27.191161599625197,
           27.21897982920848,
           27.24679805879176,
           27.274616288375043,
           27.302434517958325,
           27.330252747541607,
           27.35807097712489,
           27.385889206708175,
           27.413707436291457,
           27.441525665874735,
           27.469343895458017,
           27.4971621250413,
           27.524980354624585,
           27.552798584207867,
           27.580616813791146,
           27.608435043374428,
           27.636253272957706,
           27.664071502540992,
           27.691889732124274,
           27.719707961707556,
           27.747526191290838,
           27.77534442087412,
           27.803162650457406,
           27.830980880040684,
           27.858799109623966,
           27.887692667935234,
           27.917123890610483,
           27.94655511328574,
           27.975986335960997,
           28.005417558636246,
           28.034848781311503,
           28.064280003986756,
           28.09371122666201,
           28.123142449337266,
           28.152573672012515,
           28.182004894687772,
           28.211436117363025,
           28.240867340038278,
           28.270298562713535,
           28.299729785388784,
           28.32916100806404,
           28.358592230739294,
           28.388023453414547,
           28.417454676089804,
           28.446885898765057,
           28.476317121440307,
           28.50574834411556,
           28.535179566790816,
           28.56461078946607,
           28.594042012141326,
           28.62347323481658,
           28.652904457491836,
           28.68233568016709,
           28.711766902842342,
           28.74119812551759,
           28.770629348192845,
           28.8000605708681,
           28.829491793543355,
           28.85892301621861,
           28.888354238893864,
           28.917785461569117,
           28.94721668424437,
           28.976647906919624,
           29.00607912959488,
           29.03551035227013,
           29.064941574945383,
           29.094372797620636,
           29.123804020295893,
           29.155220603647148,
           29.186798161250344,
           29.218375718853533,
           29.24995327645673,
           29.281530834059925,
           29.313108391663118,
           29.344685949266314,
           29.376263506869506,
           29.4078410644727,
           29.439418622075895,
           29.470996179679084,
           29.502573737282283,
           29.534151294885476,
           29.565728852488668,
           29.597306410091868,
           29.628883967695057,
           29.660461525298253,
           29.692039082901445,
           29.723616640504634,
           29.755194198107834,
           29.786771755711023,
           29.818349313314222,
           29.849926870917415,
           29.881504428520607,
           29.9130819861238,
           29.944659543726992,
           29.976237101330188,
           30.007814658933384,
           30.039392216536573,
           30.07096977413977,
           30.10254733174296,
           30.134124889346154,
           30.165702446949354,
           30.197280004552546,
           30.22885756215574,
           30.26043511975893,
           30.292012677362123,
           30.32359023496532,
           30.355167792568515,
           30.386745350171708,
           30.42253662951059,
           30.462541630585164,
           30.502546631659733,
           30.54255163273431,
           30.582556633808885,
           30.622561634883454,
           30.662566635958022,
           30.702571637032598,
           30.742576638107177,
           30.782581639181743,
           30.82258664025632,
           30.86259164133089,
           30.902596642405463,
           30.94260164348004,
           30.98260664455461,
           31.02261164562918,
           31.062616646703752,
           31.102621647778328,
           31.142626648852897,
           31.182631649927472,
           31.22263665100205,
           31.262641652076624,
           31.302646653151186,
           31.34265165422576,
           31.382656655300337,
           31.422661656374906,
           31.462666657449482,
           31.50267165852405,
           31.542676659598627,
           31.582681660673195,
           31.622686661747775,
           31.662691662822347,
           31.70269666389692,
           31.74270166497149,
           31.782706666046064,
           31.82271166712064,
           31.86271666819521,
           31.90272166926978,
           31.942726670344353,
           31.98273167141893,
           32.022736672493494,
           32.06274167356807,
           32.102746674642646,
           32.14275167571722,
           32.1827566767918,
           32.222761677866366,
           32.262766678940935,
           32.30277168001551,
           32.342776681090086,
           32.382781682164655,
           32.422786683239224,
           32.4627916843138,
           32.50279668538837,
           32.542801686462944,
           32.58280668753752,
           32.62281168861209,
           32.66281668968666,
           32.701818226614044,
           32.740042074517305,
           32.77826592242056,
           32.81648977032382,
           32.85471361822707,
           32.892937466130334,
           32.931161314033595,
           32.96938516193685,
           33.00760900984011,
           33.04583285774337,
           33.08405670564663,
           33.122280553549885,
           33.160504401453146,
           33.19872824935641,
           33.23695209725966,
           33.27517594516292,
           33.31339979306618,
           33.351623640969436,
           33.38984748887269,
           33.42807133677596,
           33.46629518467922,
           33.504519032582465,
           33.54274288048573,
           33.58096672838899,
           33.619190576292254,
           33.6574144241955,
           33.65482870218176,
           33.57062384033405,
           33.48641897848634,
           33.40221411663862,
           33.318009254790915,
           33.233804392943206,
           33.14959953109549,
           33.06539466924777,
           32.981189807400064,
           32.896984945552354,
           32.81278008370464,
           32.72857522185693,
           32.64437036000922,
           32.5601654981615,
           32.47596063631379,
           32.391755774466084,
           32.30755091261837,
           32.22334605077066,
           32.13914118892295,
           32.05493632707523,
           31.970731465227512,
           31.886526603379806,
           31.802321741532097,
           31.71811687968438,
           31.633912017836668,
           31.549707155988962,
           31.465502294141242,
           31.381297432293536,
           31.297092570445827,
           31.212887708598107,
           31.128682846750394,
           31.04447798490269,
           30.96027312305497,
           30.87606826120726,
           30.79186339935955,
           30.70765853751184,
           30.623453675664123,
           30.539248813816414,
           30.4550439519687,
           30.37083909012098,
           30.28663422827328,
           30.20242936642557,
           30.11822450457785,
           30.034019642730136,
           29.949814780882427,
           29.865609919034714,
           29.781405057187,
           29.697200195339292,
           29.61299533349158,
           29.528790471643863,
           29.444585609796153,
           29.36038074794844,
           29.27617588610073,
           29.19197102425301,
           29.10776616240531,
           29.02356130055759,
           28.939356438709876,
           28.855151576862166,
           28.770946715014453,
           28.68674185316674,
           28.602536991319027,
           28.51833212947132,
           28.4341272676236,
           28.349922405775896,
           28.265717543928183,
           28.18151268208047,
           28.09730782023275,
           28.013102958385055,
           27.928898096537335,
           27.844693234689615,
           27.760488372841905,
           27.676283510994203,
           27.585253306623425,
           27.49136889548116,
           27.397484484338893,
           27.303600073196616,
           27.209715662054343,
           27.115831250912088,
           27.02194683976981,
           26.928062428627538,
           26.83417801748527,
           26.74029360634301,
           26.646409195200732,
           26.52072273686926,
           26.23602604259168,
           25.951329348314097,
           25.666632654036523,
           25.381935959758994,
           25.097239265481413,
           24.812542571203828,
           24.527845876926307,
           24.24314918264873,
           23.998325314418732,
           23.76147602324051,
           23.524626732062238,
           23.28777744088397,
           23.050928149705705,
           22.81407885852748,
           22.577229567349214,
           22.34038027617094,
           22.10353098499272,
           21.866681693814453,
           21.629832402636186,
           21.39298311145796,
           21.156133820279692,
           20.91928452910142,
           20.682435237923194,
           20.445585946744934,
           20.208736655566664,
           19.971887364388394,
           19.73503807321017,
           19.498188782031903,
           19.261339490853636,
           19.02449019967541,
           18.78764090849714,
           18.550791617318872,
           18.313942326140648,
           18.07709303496238,
           17.84024374378411,
           17.60339445260584,
           17.366545161427617,
           17.12969587024935,
           16.892846579071083,
           16.65599728789286,
           16.419147996714592,
           16.182298705536322,
           15.945449414358098,
           15.70860012317983,
           15.471750832001561,
           15.234901540823337,
           14.99805224964507,
           14.761202958466804,
           14.524353667288533,
           14.28750437611031,
           14.050655084932043,
           13.813805793753772,
           13.576956502575548,
           13.340107211397282,
           13.103257920219013,
           12.866408629040787,
           12.629559337862519,
           12.392710046684254,
           12.155860755505985,
           11.91901146432776,
           11.682162173149493,
           11.445312881971223,
           11.208463590792999,
           10.97161429961473,
           10.734765008436463,
           10.497915717258238,
           10.26106642607997,
           10.024217134901704,
           9.78736784372348,
           9.55051855254521,
           9.313669261366941,
           9.076819970188673,
           8.83997067901045,
           8.60312138783218,
           8.382397789490387,
           8.193925546888304,
           8.005453304286188,
           7.816981061684072,
           7.628508819081991,
           7.4400365764798755,
           7.2515643338777585,
           7.063092091275643,
           6.874619848673562
          ],
          [
           23.809827669355094,
           23.838411472840605,
           23.86699527632612,
           23.89557907981164,
           23.92416288329715,
           23.952746686782667,
           23.98133049026818,
           24.0099142937537,
           24.038498097239213,
           24.067081900724727,
           24.095665704210244,
           24.124249507695755,
           24.152833311181276,
           24.181417114666786,
           24.210000918152303,
           24.238584721637817,
           24.26716852512333,
           24.29575232860885,
           24.32433613209436,
           24.35291993557988,
           24.38150373906539,
           24.410087542550908,
           24.438671346036422,
           24.46725514952194,
           24.495838953007453,
           24.524422756492967,
           24.553006559978485,
           24.581590363463995,
           24.610174166949513,
           24.638757970435027,
           24.66734177392054,
           24.695925577406058,
           24.724509380891575,
           24.75309318437709,
           24.781676987862603,
           24.810260791348117,
           24.83884459483363,
           24.86742839831915,
           24.896012201804663,
           24.924596005290176,
           24.953179808775694,
           24.981763612261208,
           25.010347415746722,
           25.03893121923224,
           25.067515022717753,
           25.096098826203267,
           25.124682629688785,
           25.153266433174302,
           25.181850236659812,
           25.210434040145326,
           25.239017843630847,
           25.267601647116358,
           25.296185450601875,
           25.32476925408739,
           25.353353057572903,
           25.38193686105842,
           25.410520664543935,
           25.439104468029452,
           25.467688271514966,
           25.496272075000476,
           25.524855878485994,
           25.553439681971508,
           25.582023485457025,
           25.609421992987585,
           25.63563520211428,
           25.661848411240975,
           25.688061620367662,
           25.714274829494357,
           25.74048803862105,
           25.76670124774774,
           25.79291445687443,
           25.819127666001123,
           25.845340875127814,
           25.871554084254505,
           25.8977672933812,
           25.923980502507888,
           25.950193711634583,
           25.97640692076127,
           26.002620129887966,
           26.028833339014657,
           26.05504654814135,
           26.08125975726804,
           26.10747296639473,
           26.133686175521422,
           26.1592954912444,
           26.18478402828664,
           26.210272565328875,
           26.235761102371114,
           26.26124963941335,
           26.286738176455586,
           26.312226713497825,
           26.337715250540064,
           26.363203787582297,
           26.388692324624536,
           26.41418086166678,
           26.439669398709007,
           26.46515793575125,
           26.490646472793483,
           26.51613500983573,
           26.541623546877965,
           26.567112083920197,
           26.592600620962436,
           26.618089158004672,
           26.64357769504691,
           26.669454515382654,
           26.69727274496594,
           26.72509097454922,
           26.7529092041325,
           26.780727433715786,
           26.808545663299068,
           26.83636389288235,
           26.864182122465632,
           26.892000352048914,
           26.919818581632196,
           26.947636811215478,
           26.975455040798764,
           27.00327327038204,
           27.03109149996532,
           27.058909729548606,
           27.08672795913189,
           27.114546188715174,
           27.142364418298452,
           27.17018264788173,
           27.198000877465017,
           27.2258191070483,
           27.25363733663158,
           27.281455566214863,
           27.309273795798145,
           27.337092025381427,
           27.36491025496471,
           27.392728484547987,
           27.42054671413127,
           27.44836494371455,
           27.476183173297837,
           27.504001402881123,
           27.5318196324644,
           27.55963786204768,
           27.587456091630965,
           27.61527432121425,
           27.64309255079753,
           27.670910780380808,
           27.69872900996409,
           27.726547239547372,
           27.754365469130654,
           27.782183698713936,
           27.81000192829722,
           27.8378201578805,
           27.865638387463783,
           27.893456617047065,
           27.92127484663035,
           27.94909307621363,
           27.97691130579691,
           28.004729535380196,
           28.032547764963475,
           28.06036599454676,
           28.088184224130043,
           28.11600245371332,
           28.143820683296607,
           28.171638912879885,
           28.199457142463167,
           28.22727537204645,
           28.25509360162973,
           28.282911831213013,
           28.310730060796296,
           28.338548290379578,
           28.36636651996286,
           28.39418474954614,
           28.42307830785741,
           28.452509530532666,
           28.481940753207915,
           28.51137197588317,
           28.540803198558425,
           28.57023442123368,
           28.599665643908935,
           28.629096866584188,
           28.658528089259438,
           28.68795931193469,
           28.71739053460995,
           28.7468217572852,
           28.776252979960454,
           28.80568420263571,
           28.83511542531096,
           28.864546647986216,
           28.893977870661473,
           28.923409093336723,
           28.95284031601198,
           28.982271538687236,
           29.01170276136248,
           29.04113398403774,
           29.070565206712992,
           29.09999642938824,
           29.13135935477357,
           29.162936912376765,
           29.194514469979957,
           29.22609202758315,
           29.257669585186342,
           29.289247142789538,
           29.320824700392734,
           29.352402257995927,
           29.38397981559912,
           29.415557373202315,
           29.447134930805504,
           29.478712488408704,
           29.510290046011896,
           29.54186760361509,
           29.573445161218284,
           29.60502271882148,
           29.63660027642467,
           29.668177834027865,
           29.699755391631058,
           29.731332949234254,
           29.762910506837446,
           29.794488064440635,
           29.826065622043835,
           29.857643179647027,
           29.88922073725022,
           29.920798294853416,
           29.952375852456605,
           29.983953410059797,
           30.015530967662997,
           30.04710852526619,
           30.078686082869385,
           30.110263640472574,
           30.141841198075767,
           30.173418755678966,
           30.20499631328216,
           30.23657387088536,
           30.268151428488547,
           30.299728986091736,
           30.331306543694936,
           30.36288410129813,
           30.39446165890132,
           30.42603921650452,
           30.457616774107713,
           30.489194331710905,
           30.5207718893141,
           30.55234944691729,
           30.583927004520486,
           30.61550456212368,
           30.64708211972687,
           30.678659677330067,
           30.710237234933256,
           30.741814792536456,
           30.773392350139652,
           30.804969907742844,
           30.836547465346037,
           30.86812502294923,
           30.89970258055242,
           30.931280138155618,
           30.96285769575881,
           30.998648975097687,
           31.038653976172267,
           31.07865897724684,
           31.118663978321415,
           31.158668979395987,
           31.19867398047056,
           31.238678981545128,
           31.278683982619704,
           31.31868898369428,
           31.35869398476885,
           31.398698985843424,
           31.438703986917997,
           31.47870898799257,
           31.518713989067138,
           31.558718990141713,
           31.598723991216282,
           31.638728992290854,
           31.678733993365434,
           31.718738994440006,
           31.75874399551457,
           31.798748996589147,
           31.838753997663723,
           31.87875899873829,
           31.918763999812867,
           31.958769000887443,
           31.998774001962015,
           32.03877900303658,
           32.07878400411116,
           32.11878900518573,
           32.1587940062603,
           32.19879900733488,
           32.238804008409446,
           32.27880900948402,
           32.3188140105586,
           32.35881901163317,
           32.39882401270774,
           32.43882901378231,
           32.478834014856886,
           32.518839015931455,
           32.558844017006024,
           32.5988490180806,
           32.638854019155175,
           32.678859020229744,
           32.71886402130432,
           32.7588690223789,
           32.798874023453465,
           32.83887902452804,
           32.878884025602616,
           32.918889026677185,
           32.958894027751754,
           32.99889902882633,
           33.038904029900905,
           33.07890903097548,
           33.11891403205005,
           33.15891903312462,
           33.198924034199194,
           33.23892903527377,
           33.278934036348346,
           33.318939037422915,
           33.35894403849749,
           33.39894903957206,
           33.43895404064663,
           33.478959041721204,
           33.51896404279578,
           33.55896904387035,
           33.598974044944924,
           33.63897904601949,
           33.678984047094076,
           33.71898904816864,
           33.75899404924321,
           33.79899905031779,
           33.83900405139236,
           33.879009052466934,
           33.9190140535415,
           33.95901905461608,
           33.99902405569065,
           34.03902905676522,
           34.07903405783979,
           34.11903905891437,
           34.15904405998894,
           34.19904906106352,
           34.23905406213809,
           34.279394600397076,
           34.270345625002385,
           34.16833980283493,
           34.074455391692666,
           33.98057098055039,
           33.886686569408134,
           33.792802158265864,
           33.69891774712359,
           33.60503333598131,
           33.511148924839055,
           33.41726451369678,
           33.32338010255451,
           33.22949569141224,
           33.13561128026998,
           33.0417268691277,
           32.94784245798543,
           32.85395804684317,
           32.76007363570089,
           32.66618922455863,
           32.572304813416366,
           32.47842040227409,
           32.38453599113182,
           32.29065157998955,
           32.19676716884728,
           32.10288275770501,
           32.00899834656275,
           31.91511393542048,
           31.821229524278206,
           31.72734511313594,
           31.633460701993673,
           31.5395762908514,
           31.445691879709127,
           31.351807468566868,
           31.25792305742459,
           31.164038646282314,
           31.070154235140052,
           30.976269823997786,
           30.882385412855513,
           30.78850100171325,
           30.694616590570984,
           30.600732179428707,
           30.50684776828644,
           30.412963357144182,
           30.319078946001902,
           30.225194534859625,
           30.131310123717363,
           30.037425712575093,
           29.943541301432823,
           29.849656890290557,
           29.75577247914829,
           29.661888068006014,
           29.568003656863752,
           29.474119245721486,
           29.380234834579213,
           29.286350423436936,
           29.19246601229468,
           29.098581601152404,
           29.004697190010134,
           28.910812778867864,
           28.816928367725595,
           28.723043956583325,
           28.629159545441055,
           28.535275134298793,
           28.441390723156516,
           28.347506312014254,
           28.253621900871984,
           28.159737489729714,
           28.065853078587438,
           27.971968667445182,
           27.878084256302905,
           27.784199845160636,
           27.690315434018366,
           27.596431022876104,
           27.502546611733827,
           27.408662200591564,
           27.3147777894493,
           27.220893378307025,
           27.12700896716475,
           27.033124556022493,
           26.93924014488022,
           26.845355733737943,
           26.751471322595677,
           26.657586911453414,
           26.563702500311138,
           26.43801604197966,
           26.15331934770208,
           25.868622653424502,
           25.583925959146924,
           25.299229264869396,
           25.01453257059182,
           24.729835876314237,
           24.445139182036712,
           24.160442487759134,
           23.87574579348155,
           23.591049099204024,
           23.306352404926443,
           23.021655710648865,
           22.736959016371284,
           22.45226232209376,
           22.16756562781618,
           21.882868933538596,
           21.598172239261075,
           21.313475544983493,
           21.028778850705912,
           20.744082156428384,
           20.459385462150806,
           20.174688767873228,
           19.8899920735957,
           19.60529537931812,
           19.32059868504054,
           19.035901990762962,
           18.751205296485434,
           18.466508602207853,
           18.181811907930275,
           17.89711521365275,
           17.61241851937517,
           17.32772182509759,
           17.043025130820062,
           16.76005902512838,
           16.52416603817811,
           16.28827305122783,
           16.052380064277596,
           15.816487077327318,
           15.58059409037704,
           15.344701103426809,
           15.10880811647653,
           14.872915129526254,
           14.637022142576019,
           14.40112915562574,
           14.165236168675465,
           13.929343181725232,
           13.693450194774952,
           13.457557207824676,
           13.227886129805658,
           13.039413887203578,
           12.85094164460146,
           12.662469401999344,
           12.473997159397262,
           12.285524916795147,
           12.097052674193034,
           11.90858043159095,
           11.720108188988833,
           11.531635946386718,
           11.343163703784601,
           11.154691461182521,
           10.966219218580404,
           10.777746975978287,
           10.589274733376206,
           10.40080249077409,
           10.212330248171973,
           10.023858005569894,
           9.835385762967778,
           9.646913520365661,
           9.45844127776358,
           9.269969035161463,
           9.081496792559346,
           8.89302454995723,
           8.70455230735515,
           8.516080064753034,
           8.327607822150918,
           8.139135579548837,
           7.95066333694672,
           7.762191094344605,
           7.573718851742523,
           7.385246609140407,
           7.196774366538291,
           7.008302123936174,
           6.819829881334092
          ],
          [
           24.267658574653908,
           24.29624237813942,
           24.324826181624935,
           24.35340998511045,
           24.381993788595963,
           24.41057759208148,
           24.439161395566998,
           24.467745199052512,
           24.496329002538026,
           24.52491280602354,
           24.553496609509057,
           24.58208041299457,
           24.610664216480085,
           24.6392480199656,
           24.667831823451113,
           24.69641562693663,
           24.724999430422148,
           24.753583233907662,
           24.782167037393176,
           24.81075084087869,
           24.839334644364207,
           24.86791844784972,
           24.896502251335235,
           24.92508605482075,
           24.953669858306263,
           24.98225366179178,
           25.010837465277298,
           25.039421268762812,
           25.068005072248326,
           25.096588875733836,
           25.125172679219354,
           25.15375648270487,
           25.182340286190385,
           25.2109240896759,
           25.239507893161413,
           25.268091696646927,
           25.296675500132444,
           25.325259303617962,
           25.35384310710348,
           25.38242691058899,
           25.411010714074504,
           25.43959451756002,
           25.468178321045535,
           25.496762124531053,
           25.525345928016566,
           25.55392973150208,
           25.582513534987598,
           25.61109733847311,
           25.639681141958626,
           25.668264945444143,
           25.696848748929657,
           25.72543255241517,
           25.75401635590069,
           25.7826001593862,
           25.811183962871716,
           25.839767766357234,
           25.868351569842744,
           25.89693537332826,
           25.925519176813776,
           25.954102980299293,
           25.982686783784807,
           26.01127058727032,
           26.03985439075584,
           26.068438194241352,
           26.09702199772687,
           26.12560580121238,
           26.154189604697894,
           26.18277340818341,
           26.211357211668926,
           26.239941015154443,
           26.268524818639957,
           26.29710862212547,
           26.32569242561099,
           26.3542762290965,
           26.382860032582016,
           26.41144383606753,
           26.440027639553048,
           26.46861144303856,
           26.49719524652408,
           26.525779050009593,
           26.5519922607519,
           26.578205469878586,
           26.60441867900528,
           26.630631888131973,
           26.65624120385495,
           26.68172974089719,
           26.707218277939422,
           26.73270681498166,
           26.759748481972334,
           26.787566711555616,
           26.815384941138895,
           26.84320317072218,
           26.87102140030546,
           26.898839629888744,
           26.926657859472027,
           26.954476089055305,
           26.98229431863859,
           27.01011254822187,
           27.037930777805155,
           27.065749007388433,
           27.093567236971715,
           27.121385466555,
           27.14920369613828,
           27.177021925721565,
           27.204840155304844,
           27.23265838488813,
           27.260476614471408,
           27.28829484405469,
           27.316113073637972,
           27.343931303221254,
           27.371749532804536,
           27.399567762387818,
           27.4273859919711,
           27.455204221554382,
           27.483022451137664,
           27.510840680720946,
           27.53865891030423,
           27.56647713988751,
           27.594295369470792,
           27.622113599054074,
           27.649931828637357,
           27.67775005822064,
           27.705568287803917,
           27.733386517387203,
           27.761204746970485,
           27.789022976553767,
           27.81684120613705,
           27.84465943572033,
           27.872477665303613,
           27.900295894886895,
           27.928114124470177,
           27.95593235405346,
           27.98375058363674,
           28.011568813220023,
           28.039387042803305,
           28.067205272386587,
           28.09502350196987,
           28.12284173155315,
           28.150659961136434,
           28.178478190719716,
           28.206296420302994,
           28.23411464988628,
           28.26193287946956,
           28.28975110905284,
           28.317569338636122,
           28.345387568219405,
           28.37320579780269,
           28.401024027385972,
           28.428842256969254,
           28.456660486552536,
           28.48447871613582,
           28.512296945719097,
           28.540115175302383,
           28.567933404885665,
           28.595751634468947,
           28.62356986405223,
           28.651388093635507,
           28.679206323218793,
           28.70702455280207,
           28.734842782385357,
           28.76266101196864,
           28.79047924155192,
           28.818297471135203,
           28.84611570071848,
           28.873933930301767,
           28.901752159885046,
           28.929570389468328,
           28.958463947779595,
           28.98789517045485,
           29.017326393130105,
           29.046757615805355,
           29.07618883848061,
           29.107498105900003,
           29.139075663503196,
           29.170653221106388,
           29.202230778709584,
           29.233808336312777,
           29.265385893915973,
           29.296963451519165,
           29.328541009122354,
           29.360118566725554,
           29.391696124328746,
           29.42327368193194,
           29.454851239535135,
           29.486428797138327,
           29.518006354741523,
           29.549583912344715,
           29.581161469947908,
           29.612739027551104,
           29.644316585154296,
           29.675894142757492,
           29.707471700360685,
           29.739049257963877,
           29.77062681556707,
           29.802204373170262,
           29.833781930773455,
           29.865359488376654,
           29.896937045979847,
           29.92851460358304,
           29.960092161186232,
           29.991669718789428,
           30.023247276392624,
           30.054824833995816,
           30.08640239159901,
           30.1179799492022,
           30.149557506805397,
           30.181135064408593,
           30.212712622011786,
           30.24429017961498,
           30.27586773721817,
           30.307445294821363,
           30.339022852424563,
           30.370600410027755,
           30.402177967630948,
           30.43375552523414,
           30.465333082837333,
           30.496910640440532,
           30.52848819804372,
           30.56006575564691,
           30.59164331325011,
           30.623220870853302,
           30.6547984284565,
           30.686375986059694,
           30.717953543662887,
           30.749531101266086,
           30.78110865886927,
           30.81268621647247,
           30.844263774075664,
           30.875841331678853,
           30.90741888928205,
           30.93899644688524,
           30.970574004488434,
           31.00215156209163,
           31.033729119694826,
           31.065306677298018,
           31.096884234901214,
           31.128461792504407,
           31.160039350107603,
           31.19161690771079,
           31.223194465313988,
           31.25477202291718,
           31.286349580520373,
           31.317927138123565,
           31.34950469572676,
           31.38108225332996,
           31.41265981093315,
           31.444237368536346,
           31.475814926139538,
           31.507392483742734,
           31.538970041345923,
           31.574761320684807,
           31.61476632175938,
           31.654771322833955,
           31.694776323908524,
           31.734781324983096,
           31.774786326057676,
           31.814791327132244,
           31.854796328206817,
           31.894801329281393,
           31.93480633035596,
           31.974945543488694,
           32.015458639746626,
           32.05597173600456,
           32.09648483226249,
           32.13699792852043,
           32.177511024778354,
           32.21802412103629,
           32.25853721729422,
           32.29905031355215,
           32.33956340981008,
           32.38007650606802,
           32.42058960232596,
           32.461102698583886,
           32.501615794841825,
           32.54212889109976,
           32.58264198735769,
           32.62315508361562,
           32.663668179873554,
           32.70418127613148,
           32.74469437238942,
           32.78520746864735,
           32.82572056490528,
           32.866233661163214,
           32.906746757421146,
           32.947259853679085,
           32.98777294993701,
           33.02828604619495,
           33.06879914245289,
           33.109312238710814,
           33.14982533496875,
           33.19033843122668,
           33.23085152748461,
           33.27136462374254,
           33.31187772000048,
           33.35239081625841,
           33.392903912516346,
           33.43341700877428,
           33.47393010503221,
           33.51444320129014,
           33.554956297548074,
           33.59546939380601,
           33.63598249006394,
           33.67649558632187,
           33.71700868257981,
           33.75752177883774,
           33.798034875095674,
           33.838547971353606,
           33.879061067611545,
           33.91957416386947,
           33.96008726012741,
           34.000600356385334,
           34.04111345264327,
           34.0816265489012,
           34.12213964515914,
           34.16265274141707,
           34.203165837675,
           34.243678933932934,
           34.284192030190866,
           34.3247051264488,
           34.36521822270673,
           34.40573131896466,
           34.4462444152226,
           34.48675751148053,
           34.527270607738465,
           34.56778370399639,
           34.60829680025432,
           34.64880989651226,
           34.6893229927702,
           34.729836089028126,
           34.770349185286065,
           34.810862281544,
           34.85137537780193,
           34.89188847405986,
           34.882839498665156,
           34.774666379965225,
           34.6664932612653,
           34.558320142565364,
           34.45014702386544,
           34.34197390516552,
           34.23380078646557,
           34.12562766776564,
           34.01745454906572,
           33.90928143036579,
           33.80110831166585,
           33.692935192965926,
           33.584762074265996,
           33.47658895556606,
           33.368415836866134,
           33.260242718166204,
           33.152069599466266,
           33.04389648076634,
           32.93572336206642,
           32.82755024336648,
           32.71937712466654,
           32.61120400596661,
           32.50303088726669,
           32.39485776856675,
           32.28668464986683,
           32.178511531166905,
           32.07033841246697,
           31.962165293767036,
           31.853992175067113,
           31.745819056367175,
           31.637645937667237,
           31.52947281896732,
           31.421299700267383,
           31.313126581567452,
           31.204953462867522,
           31.0967803441676,
           30.98860722546766,
           30.88043410676773,
           30.772260988067806,
           30.66408786936787,
           30.55591475066794,
           30.447741631968015,
           30.339568513268077,
           30.231395394568143,
           30.123222275868223,
           30.015049157168292,
           29.906876038468354,
           29.798702919768427,
           29.6905298010685,
           29.582356682368562,
           29.485296961974154,
           29.391412550831888,
           29.29752813968961,
           29.203643728547338,
           29.10975931740508,
           29.01587490626281,
           28.921990495120536,
           28.82810608397827,
           28.734221672835996,
           28.64033726169373,
           28.54645285055146,
           28.452568439409195,
           28.35868402826692,
           28.26479961712466,
           28.170915205982393,
           28.077030794840116,
           27.983146383697843,
           27.889261972555584,
           27.79537756141331,
           27.701493150271034,
           27.60760873912877,
           27.513724327986505,
           27.419839916844232,
           27.325955505701963,
           27.232071094559696,
           27.138186683417423,
           27.04430227227515,
           26.950417861132895,
           26.856533449990618,
           26.762649038848345,
           26.668764627706082,
           26.574880216563812,
           26.480995805421536,
           26.355309347090063,
           26.070612652812486,
           25.785915958534908,
           25.501219264257326,
           25.216522569979798,
           24.93182587570222,
           24.64712918142464,
           24.362432487147114,
           24.077735792869532,
           23.793039098591954,
           23.508342404314426,
           23.223645710036845,
           22.938949015759263,
           22.654252321481685,
           22.380372063721044,
           22.144479076770768,
           21.908586089820496,
           21.67269310287026,
           21.436800115919986,
           21.200907128969707,
           20.96501414201947,
           20.729121155069194,
           20.493228168118915,
           20.25733518116868,
           20.021442194218405,
           19.78554920726813,
           19.54965622031785,
           19.313763233367613,
           19.07787024641734,
           18.841977259467065,
           18.60608427251683,
           18.37019128556655,
           18.134298298616272,
           17.89840531166604,
           17.662512324715763,
           17.426619337765484,
           17.190726350815208,
           16.954833363864974,
           16.7189403769147,
           16.48304738996442,
           16.247154403014186,
           16.01126141606391,
           15.775368429113632,
           15.539475442163397,
           15.303582455213117,
           15.067689468262843,
           14.83179648131261,
           14.595903494362332,
           14.360010507412055,
           14.124117520461779,
           13.888224533511545,
           13.652331546561266,
           13.41643855961099,
           13.180545572660755,
           12.944652585710479,
           12.7087595987602,
           12.472866611809968,
           12.23697362485969,
           12.001080637909412,
           11.765187650959135,
           11.529294664008901,
           11.293401677058625,
           11.057508690108346,
           10.821615703158113,
           10.585722716207837,
           10.349829729257557,
           10.113936742307324,
           9.878043755357048,
           9.64215076840677,
           9.406257781456537,
           9.215179067821994,
           9.026706825219875,
           8.838234582617762,
           8.64976234001568,
           8.461290097413565,
           8.27281785481145,
           8.084345612209367,
           7.89587336960725,
           7.707401127005135,
           7.518928884403055,
           7.330456641800938,
           7.1419843991988206,
           6.953512156596705,
           6.765039913994624
          ],
          [
           24.71931972548138,
           24.75029443398891,
           24.78126914249643,
           24.81224385100396,
           24.84321855951149,
           24.87419326801902,
           24.905167976526545,
           24.93614268503407,
           24.967117393541603,
           24.998092102049135,
           25.02906681055666,
           25.06004151906419,
           25.091016227571718,
           25.12039700142186,
           25.148980804907374,
           25.177564608392892,
           25.206148411878402,
           25.234732215363916,
           25.263316018849434,
           25.291899822334948,
           25.32048362582046,
           25.34906742930598,
           25.377651232791493,
           25.40623503627701,
           25.434818839762524,
           25.46340264324804,
           25.491986446733552,
           25.520570250219066,
           25.549154053704584,
           25.577737857190098,
           25.60632166067561,
           25.634905464161125,
           25.663489267646643,
           25.692073071132157,
           25.720656874617674,
           25.74924067810319,
           25.777824481588702,
           25.80640828507422,
           25.834992088559737,
           25.863575892045247,
           25.89215969553076,
           25.920743499016275,
           25.949327302501793,
           25.97791110598731,
           26.00649490947282,
           26.035078712958338,
           26.063662516443852,
           26.092246319929366,
           26.120830123414883,
           26.149413926900397,
           26.17799773038591,
           26.20658153387143,
           26.235165337356946,
           26.263749140842457,
           26.292332944327974,
           26.320916747813484,
           26.349500551299002,
           26.37808435478452,
           26.40666815827003,
           26.43525196175555,
           26.463835765241065,
           26.492419568726582,
           26.521003372212093,
           26.549587175697607,
           26.578170979183124,
           26.60675478266864,
           26.635338586154155,
           26.66392238963967,
           26.692506193125183,
           26.7210899966107,
           26.749673800096218,
           26.77825760358173,
           26.806841407067242,
           26.83542521055276,
           26.864009014038274,
           26.89259281752379,
           26.9211766210093,
           26.94976042449482,
           26.978344227980337,
           27.006928031465847,
           27.035511834951365,
           27.06409563843688,
           27.092679441922396,
           27.12126324540791,
           27.14920907064156,
           27.177027300224847,
           27.204845529808125,
           27.232663759391407,
           27.26048198897469,
           27.28830021855797,
           27.316118448141253,
           27.343936677724535,
           27.371754907307817,
           27.3995731368911,
           27.427391366474385,
           27.455209596057664,
           27.48302782564095,
           27.51084605522423,
           27.538664284807513,
           27.566482514390795,
           27.594300743974074,
           27.62211897355736,
           27.64993720314064,
           27.677755432723924,
           27.705573662307206,
           27.733391891890484,
           27.761210121473766,
           27.78902835105705,
           27.816846580640334,
           27.844664810223613,
           27.872483039806898,
           27.900301269390177,
           27.92811949897346,
           27.95593772855674,
           27.983755958140023,
           28.01157418772331,
           28.039392417306587,
           28.06721064688987,
           28.095028876473158,
           28.122847106056433,
           28.150665335639722,
           28.178483565222997,
           28.20630179480628,
           28.23412002438957,
           28.261938253972843,
           28.289756483556125,
           28.31757471313941,
           28.345392942722693,
           28.37321117230597,
           28.401029401889257,
           28.428847631472536,
           28.45666586105582,
           28.484484090639103,
           28.512302320222386,
           28.540120549805664,
           28.567938779388946,
           28.59575700897223,
           28.623575238555514,
           28.651393468138796,
           28.67921169772208,
           28.70702992730536,
           28.734848156888642,
           28.762666386471924,
           28.790484616055206,
           28.818302845638488,
           28.84612107522177,
           28.87393930480505,
           28.901757534388334,
           28.929575763971616,
           28.9573939935549,
           28.98521222313818,
           29.013030452721463,
           29.040848682304745,
           29.068666911888023,
           29.096485143336118,
           29.126506279703733,
           29.156527416071356,
           29.186548552438975,
           29.216569688806594,
           29.246590825174216,
           29.276611961541835,
           29.306633097909454,
           29.336654234277077,
           29.366675370644696,
           29.396696507012315,
           29.426717643379938,
           29.456738779747557,
           29.489115041740327,
           29.522668866545672,
           29.556222691351014,
           29.58977651615636,
           29.623330340961697,
           29.656884165767046,
           29.690437990572388,
           29.723991815377733,
           29.757545640183075,
           29.79109946498842,
           29.824653289793766,
           29.858207114599107,
           29.891760939404453,
           29.925314764209794,
           29.95886858901514,
           29.99095556389032,
           30.022518661021913,
           30.0540817581535,
           30.0856448552851,
           30.117207952416685,
           30.14877104954828,
           30.180334146679876,
           30.211897243811464,
           30.24346034094306,
           30.27502343807465,
           30.306586535206243,
           30.33814963233783,
           30.369712729469423,
           30.401275826601015,
           30.432838923732607,
           30.464402020864203,
           30.49596511799579,
           30.527528215127383,
           30.55909131225898,
           30.59065440939057,
           30.622217506522162,
           30.653780603653757,
           30.685343700785346,
           30.71690679791694,
           30.74846989504853,
           30.780032992180125,
           30.811596089311713,
           30.84315918644331,
           30.874722283574897,
           30.906285380706493,
           30.937848477838088,
           30.969411574969676,
           31.00097467210127,
           31.03253776923286,
           31.064100866364452,
           31.095663963496044,
           31.12722706062764,
           31.158790157759228,
           31.190353254890816,
           31.221916352022415,
           31.253479449154007,
           31.285042546285602,
           31.31660564341719,
           31.348168740548786,
           31.37973183768037,
           31.41129493481197,
           31.442858031943558,
           31.47442112907515,
           31.505984226206746,
           31.537547323338337,
           31.56911042046993,
           31.60067351760152,
           31.632236614733113,
           31.663799711864705,
           31.695362808996297,
           31.72692590612789,
           31.758489003259477,
           31.790052100391073,
           31.821615197522668,
           31.853178294654256,
           31.884741391785848,
           31.91630448891744,
           31.947867586049032,
           31.979430683180624,
           32.01099378031222,
           32.04255687744381,
           32.0741199745754,
           32.10568307170699,
           32.142239038479595,
           32.1837878748932,
           32.22533671130681,
           32.266885547720406,
           32.30843438413402,
           32.34998322054762,
           32.391532056961225,
           32.433080893374836,
           32.47462972978845,
           32.51617856620204,
           32.557727402615654,
           32.599276239029265,
           32.64082507544287,
           32.68237391185647,
           32.723922748270084,
           32.76547158468369,
           32.80702042109729,
           32.8485692575109,
           32.8901180939245,
           32.93166693033811,
           32.973215766751714,
           33.014764603165325,
           33.05631343957893,
           33.09786227599253,
           33.139411112406144,
           33.18095994881975,
           33.22250878523335,
           33.26405762164696,
           33.305606458060566,
           33.34715529447417,
           33.388704130887774,
           33.430252967301385,
           33.47180180371499,
           33.51335064012859,
           33.554899476542204,
           33.59644831295581,
           33.63799714936941,
           33.67954598578302,
           33.72109482219662,
           33.762319208631524,
           33.80283230488946,
           33.84334540114739,
           33.88385849740531,
           33.92437159366325,
           33.96488468992119,
           34.00539778617912,
           34.045910882437056,
           34.08642397869498,
           34.12693707495291,
           34.167450171210845,
           34.207963267468784,
           34.248476363726716,
           34.28898945998465,
           34.32950255624258,
           34.37001565250051,
           34.410528748758445,
           34.45104184501638,
           34.491554941274316,
           34.53206803753224,
           34.57258113379018,
           34.613094230048105,
           34.653607326306044,
           34.69412042256397,
           34.73463351882191,
           34.77514661507984,
           34.81565971133777,
           34.85617280759571,
           34.896685903853644,
           34.93719900011157,
           34.9777120963695,
           35.01822519262744,
           35.05873828888537,
           35.099251385143305,
           35.13976448140124,
           35.18027757765917,
           35.2207906739171,
           35.26130377017503,
           35.30181686643297,
           35.342329962690904,
           35.382843058948836,
           35.423356155206775,
           35.4638692514647,
           35.50438234772263,
           35.49533337232793,
           35.387160253628,
           35.27898713492808,
           35.17081401622814,
           35.06264089752821,
           34.95446777882829,
           34.84629466012835,
           34.73812154142841,
           34.629948422728496,
           34.521775304028566,
           34.41360218532862,
           34.305429066628705,
           34.19725594792877,
           34.089082829228836,
           33.980909710528906,
           33.87273659182898,
           33.764563473129044,
           33.65639035442912,
           33.54821723572919,
           33.44004411702925,
           33.331870998329315,
           33.22369787962939,
           33.11552476092946,
           33.00735164222953,
           32.8991785235296,
           32.791005404829676,
           32.68283228612974,
           32.574659167429814,
           32.466486048729884,
           32.35831293002995,
           32.25013981133001,
           32.14196669263009,
           32.033793573930154,
           31.925620455230224,
           31.817447336530293,
           31.70927421783037,
           31.60110109913043,
           31.49292798043051,
           31.384754861730578,
           31.276581743030643,
           31.168408624330716,
           31.06023550563079,
           30.952062386930855,
           30.843889268230917,
           30.73571614953099,
           30.627543030831063,
           30.519369912131125,
           30.411196793431202,
           30.30302367473127,
           30.194850556031334,
           30.086677437331414,
           29.978504318631487,
           29.87033119993155,
           29.76215808123161,
           29.653984962531695,
           29.545811843831757,
           29.43763872513182,
           29.329465606431896,
           29.221292487731965,
           29.113119369032034,
           29.004946250332107,
           28.89677313163218,
           28.788600012932243,
           28.675918728432812,
           28.556377268066967,
           28.436835807701122,
           28.31729434733527,
           28.19775288696944,
           28.078211426603588,
           27.95866996623774,
           27.839128505871898,
           27.71958704550606,
           27.600045585140208,
           27.48050412477437,
           27.36096266440853,
           27.24142120404268,
           27.12187974367683,
           27.002338283310998,
           26.882796822945146,
           26.7632553625793,
           26.643713902213456,
           26.524172441847615,
           26.404630981481766,
           26.257309153579957,
           25.971085487998224,
           25.68486182241649,
           25.39863815683476,
           25.112414491253084,
           24.826190825671347,
           24.539967160089613,
           24.253743494507937,
           23.967519828926203,
           23.681296163344467,
           23.395072497762786,
           23.108848832181053,
           22.82262516659932,
           22.536401501017586,
           22.25017783543591,
           21.963954169854176,
           21.677730504272443,
           21.391506838690766,
           21.105283173109033,
           20.86100152951094,
           20.625108542560703,
           20.389215555610427,
           20.15332256866015,
           19.917429581709914,
           19.681536594759635,
           19.445643607809362,
           19.209750620859086,
           18.973857633908853,
           18.737964646958574,
           18.502071660008294,
           18.26617867305806,
           18.030285686107785,
           17.794392699157505,
           17.558499712207272,
           17.322606725256996,
           17.08671373830672,
           16.85082075135644,
           16.61492776440621,
           16.37903477745593,
           16.143141790505656,
           15.907248803555419,
           15.671355816605143,
           15.435462829654865,
           15.19956984270463,
           14.963676855754352,
           14.727783868804075,
           14.491890881853843,
           14.255997894903565,
           14.02010490795329,
           13.78421192100301,
           13.548318934052777,
           13.3124259471025,
           13.076532960152223,
           12.840639973201988,
           12.604746986251712,
           12.368853999301434,
           12.132961012351199,
           11.897068025400923,
           11.661175038450645,
           11.425282051500368,
           11.189389064550134,
           10.953496077599858,
           10.717603090649579,
           10.481710103699346,
           10.24581711674907,
           10.027144570951567,
           9.842912260167447,
           9.658679949383291,
           9.474447638599138,
           9.290215327815018,
           9.105983017030862,
           8.921750706246709,
           8.737518395462555,
           8.553286084678433,
           8.36905377389428,
           8.184821463110124,
           8.000589152326004,
           7.81635684154185,
           7.632124530757695,
           7.447892219973575,
           7.26365990918942,
           7.079427598405266,
           6.89519528762111,
           6.710962976836989
          ],
          [
           25.168896500282255,
           25.199871208789784,
           25.23084591729731,
           25.261820625804837,
           25.292795334312366,
           25.323770042819895,
           25.354744751327424,
           25.38571945983495,
           25.41669416834248,
           25.44766887685001,
           25.47864358535754,
           25.50961829386506,
           25.54059300237259,
           25.57156771088012,
           25.60254241938765,
           25.63351712789518,
           25.664491836402703,
           25.695466544910232,
           25.72644125341776,
           25.75741596192529,
           25.78839067043282,
           25.819365378940347,
           25.850340087447872,
           25.881314795955404,
           25.91228950446293,
           25.943264212970462,
           25.97423892147799,
           26.005213629985512,
           26.036188338493044,
           26.06676456524869,
           26.095348368734204,
           26.123932172219718,
           26.152515975705235,
           26.18109977919075,
           26.209683582676263,
           26.23826738616178,
           26.266851189647294,
           26.295434993132808,
           26.324018796618326,
           26.352602600103843,
           26.381186403589354,
           26.40977020707487,
           26.43835401056038,
           26.466937814045902,
           26.495521617531413,
           26.524105421016927,
           26.552689224502444,
           26.581273027987958,
           26.609856831473476,
           26.63844063495899,
           26.667024438444503,
           26.69560824193002,
           26.724192045415535,
           26.75277584890105,
           26.781359652386563,
           26.80994345587208,
           26.838527259357594,
           26.86711106284311,
           26.895694866328625,
           26.92427866981414,
           26.952862473299653,
           26.98144627678517,
           27.01003008027069,
           27.0386138837562,
           27.067197687241716,
           27.09578149072723,
           27.124365294212744,
           27.15294909769826,
           27.181532901183775,
           27.21011670466929,
           27.238700508154807,
           27.26728431164032,
           27.295868115125835,
           27.324451918611352,
           27.353035722096866,
           27.38161952558238,
           27.410203329067897,
           27.43878713255341,
           27.467370936038925,
           27.495954739524443,
           27.524538543009953,
           27.55312234649547,
           27.581706149980985,
           27.610289953466502,
           27.63823577870015,
           27.66605400828343,
           27.693872237866714,
           27.72169046745,
           27.749508697033278,
           27.77732692661656,
           27.805145156199846,
           27.832963385783124,
           27.860781615366413,
           27.888599844949688,
           27.916418074532977,
           27.944236304116256,
           27.97205453369954,
           27.999872763282816,
           28.027690992866106,
           28.055509222449388,
           28.08332745203267,
           28.111145681615948,
           28.138963911199234,
           28.166782140782512,
           28.19460037036579,
           28.222418599949076,
           28.25023682953236,
           28.278055059115644,
           28.305873288698923,
           28.3336915182822,
           28.361509747865487,
           28.389327977448772,
           28.417146207032054,
           28.444964436615333,
           28.47278266619861,
           28.500600895781897,
           28.528419125365176,
           28.556237354948458,
           28.584055584531747,
           28.61187381411502,
           28.63969204369831,
           28.667510273281593,
           28.69532850286487,
           28.723146732448157,
           28.750964962031432,
           28.778783191614718,
           28.806601421198,
           28.83441965078128,
           28.862237880364564,
           28.890056109947846,
           28.917874339531128,
           28.94569256911441,
           28.973510798697692,
           29.001329028280974,
           29.029147257864256,
           29.056965487447535,
           29.08478371703082,
           29.112601946614106,
           29.14152163181784,
           29.17154276818546,
           29.20156390455308,
           29.2315850409207,
           29.26160617728832,
           29.29162731365594,
           29.32164845002356,
           29.351669586391182,
           29.3816907227588,
           29.41171185912642,
           29.441732995494043,
           29.471754131861662,
           29.50177526822928,
           29.531796404596907,
           29.56181754096452,
           29.59183867733214,
           29.621859813699764,
           29.65188095006738,
           29.681902086435006,
           29.71192322280262,
           29.74194435917024,
           29.771965495537863,
           29.801986631905482,
           29.8320077682731,
           29.862028904640727,
           29.892050041008343,
           29.922071177375962,
           29.952092313743584,
           29.982113450111203,
           30.01448971210398,
           30.04804353690932,
           30.081597361714664,
           30.115151186520006,
           30.148705011325355,
           30.182258836130693,
           30.215812660936038,
           30.24936648574138,
           30.28292031054673,
           30.316474135352067,
           30.350027960157412,
           30.383581784962754,
           30.4171356097681,
           30.450689434573444,
           30.484243259378786,
           30.51779708418413,
           30.55135090898947,
           30.58490473379482,
           30.61845855860016,
           30.652012383405506,
           30.685566208210847,
           30.71912003301619,
           30.75267385782153,
           30.78622768262688,
           30.819781507432225,
           30.853335332237563,
           30.88688915704291,
           30.920442981848247,
           30.953996806653596,
           30.987550631458937,
           31.021104456264286,
           31.054658281069624,
           31.08821210587497,
           31.121765930680308,
           31.155319755485657,
           31.1873543431881,
           31.218917440319693,
           31.25048053745128,
           31.282043634582877,
           31.313606731714465,
           31.34516982884606,
           31.376732925977656,
           31.40829602310924,
           31.43985912024084,
           31.471422217372428,
           31.502985314504024,
           31.534548411635615,
           31.5661115087672,
           31.597674605898796,
           31.62923770303039,
           31.660800800161983,
           31.69236389729357,
           31.723926994425163,
           31.75549009155676,
           31.787053188688354,
           31.81861628581994,
           31.85017938295153,
           31.881742480083126,
           31.91330557721472,
           31.944868674346317,
           31.976431771477902,
           32.007994868609494,
           32.03955796574108,
           32.07112106287268,
           32.10268416000427,
           32.13424725713586,
           32.16581035426746,
           32.19737345139905,
           32.22893654853064,
           32.26049964566223,
           32.292062742793824,
           32.32362583992541,
           32.355188937057015,
           32.3867520341886,
           32.41831513132019,
           32.44987822845178,
           32.481441325583376,
           32.51300442271497,
           32.54456751984656,
           32.57613061697815,
           32.60769371410974,
           32.63925681124134,
           32.670819908372934,
           32.70737587514552,
           32.74892471155914,
           32.790473547972745,
           32.83202238438635,
           32.87357122079995,
           32.91512005721356,
           32.95666889362717,
           32.99821773004078,
           33.03976656645438,
           33.08131540286798,
           33.12286423928159,
           33.1644130756952,
           33.205961912108805,
           33.24751074852241,
           33.28905958493601,
           33.33060842134962,
           33.37215725776323,
           33.41370609417683,
           33.45525493059044,
           33.496803767004046,
           33.53835260341765,
           33.57990143983126,
           33.62145027624486,
           33.66299911265847,
           33.70454794907208,
           33.74609678548568,
           33.78764562189929,
           33.8291944583129,
           33.870743294726495,
           33.912292131140106,
           33.95384096755372,
           33.99538980396733,
           34.036938640380924,
           34.078487476794535,
           34.12003631320814,
           34.16158514962174,
           34.20313398603535,
           34.24468282244896,
           34.28623165886256,
           34.327780495276166,
           34.36932933168978,
           34.41087816810338,
           34.452427004516984,
           34.493975840930595,
           34.5355246773442,
           34.577073513757796,
           34.61862235017141,
           34.66017118658502,
           34.70172002299862,
           34.743268859412225,
           34.784817695825836,
           34.82636653223944,
           34.867915368653044,
           34.909464205066655,
           34.951013041480266,
           34.99256187789386,
           35.03411071430747,
           35.07565955072108,
           35.11720838713468,
           35.158757223548285,
           35.200306059961896,
           35.2418548963755,
           35.283403732789104,
           35.324952569202715,
           35.36650140561632,
           35.40805024202992,
           35.44959907844353,
           35.491147914857144,
           35.532696751270734,
           35.574245587684345,
           35.615794424097956,
           35.65734326051157,
           35.698892096925164,
           35.740440933338775,
           35.78198976975238,
           35.82353860616598,
           35.86508744257959,
           35.906636278993204,
           35.94818511540681,
           35.98973395182042,
           36.031282788234016,
           36.07283162464762,
           36.11505152419771,
           36.098984666463,
           35.965539020558886,
           35.83659934681271,
           35.71705788644687,
           35.59751642608103,
           35.477974965715184,
           35.35843350534933,
           35.23889204498349,
           35.119350584617656,
           34.999809124251804,
           34.88026766388595,
           34.76072620352011,
           34.64118474315427,
           34.52164328278842,
           34.40210182242258,
           34.28256036205674,
           34.16301890169089,
           34.04347744132505,
           33.92393598095921,
           33.80439452059336,
           33.68485306022751,
           33.565311599861666,
           33.445770139495835,
           33.32622867912998,
           33.20668721876414,
           33.0871457583983,
           32.96760429803245,
           32.84806283766662,
           32.72852137730077,
           32.60897991693492,
           32.48943845656907,
           32.36989699620324,
           32.250355535837386,
           32.13081407547154,
           32.0112726151057,
           31.89173115473986,
           31.77218969437401,
           31.65264823400817,
           31.53310677364233,
           31.413565313276482,
           31.294023852910637,
           31.1744823925448,
           31.05494093217895,
           30.9353994718131,
           30.81585801144726,
           30.696316551081416,
           30.576775090715568,
           30.45723363034973,
           30.33769216998389,
           30.218150709618037,
           30.0986092492522,
           29.979067788886354,
           29.85952632852051,
           29.739984868154657,
           29.62044340778883,
           29.500901947422975,
           29.38136048705713,
           29.261819026691285,
           29.14227756632545,
           29.022736105959595,
           28.903194645593757,
           28.783653185227916,
           28.664111724862067,
           28.54457026449623,
           28.425028804130392,
           28.30548734376454,
           28.185945883398688,
           28.06640442303286,
           27.946862962667005,
           27.82732150230116,
           27.707780041935315,
           27.588238581569478,
           27.468697121203625,
           27.34915566083779,
           27.22961420047195,
           27.110072740106098,
           26.990531279740246,
           26.870989819374422,
           26.75144835900857,
           26.63190689864272,
           26.51236543827688,
           26.39282397791104,
           26.27328251754519,
           26.125960689643378,
           25.839737024061645,
           25.553513358479908,
           25.26728969289818,
           24.9810660273165,
           24.694842361734764,
           24.408618696153034,
           24.122395030571354,
           23.83617136498962,
           23.549947699407888,
           23.263724033826207,
           22.977500368244478,
           22.69127670266274,
           22.405053037081007,
           22.118829371499327,
           21.832605705917597,
           21.546382040335864,
           21.260158374754184,
           20.97393470917245,
           20.687711043590717,
           20.401487378009037,
           20.115263712427307,
           19.82904004684557,
           19.54281638126389,
           19.256592715682157,
           18.970369050100423,
           18.684145384518693,
           18.39792171893701,
           18.11169805335528,
           17.825474387773546,
           17.558010519717683,
           17.324819090426857,
           17.09162766113603,
           16.858436231845246,
           16.62524480255442,
           16.392053373263597,
           16.15886194397277,
           15.925670514681988,
           15.692479085391163,
           15.459287656100335,
           15.226096226809554,
           14.992904797518728,
           14.759713368227901,
           14.526521938937119,
           14.293330509646292,
           14.060139080355468,
           13.826947651064685,
           13.593756221773859,
           13.360564792483032,
           13.127373363192207,
           12.894181933901427,
           12.660990504610599,
           12.427799075319774,
           12.194607646028992,
           12.001216228872448,
           11.816983918088292,
           11.632751607304172,
           11.448519296520017,
           11.264286985735861,
           11.080054674951711,
           10.89582236416759,
           10.711590053383434,
           10.527357742599278,
           10.343125431815158,
           10.158893121031005,
           9.97466081024685,
           9.79042849946273,
           9.606196188678574,
           9.42196387789442,
           9.2377315671103,
           9.053499256326145,
           8.869266945541991,
           8.685034634757837,
           8.500802323973716,
           8.31657001318956,
           8.132337702405406,
           7.9481053916212865,
           7.763873080837131,
           7.579640770052977,
           7.395408459268857,
           7.211176148484702,
           7.026943837700547,
           6.842711526916393,
           6.658479216132272
          ],
          [
           25.618473275083137,
           25.64944798359067,
           25.68042269209819,
           25.71139740060572,
           25.742372109113248,
           25.773346817620777,
           25.804321526128305,
           25.835296234635834,
           25.866270943143363,
           25.89724565165089,
           25.92822036015842,
           25.95919506866595,
           25.990169777173477,
           26.021144485681006,
           26.052119194188535,
           26.083093902696064,
           26.11406861120359,
           26.145043319711117,
           26.176018028218646,
           26.206992736726175,
           26.2379674452337,
           26.26894215374123,
           26.299916862248757,
           26.330891570756286,
           26.361866279263815,
           26.392840987771343,
           26.423815696278872,
           26.454790404786394,
           26.48576511329393,
           26.516739821801455,
           26.547714530308983,
           26.578689238816516,
           26.609663947324037,
           26.640638655831566,
           26.671613364339095,
           26.702588072846623,
           26.733562781354152,
           26.76453748986168,
           26.79551219836921,
           26.826486906876735,
           26.857461615384263,
           26.888436323891792,
           26.91941103239932,
           26.950385740906853,
           26.981360449414378,
           27.012335157921903,
           27.041715932561043,
           27.070299736046557,
           27.09888353953207,
           27.12746734301759,
           27.1560511465031,
           27.18463494998862,
           27.21321875347413,
           27.241802556959648,
           27.270386360445162,
           27.298970163930676,
           27.327553967416193,
           27.356137770901707,
           27.384721574387225,
           27.413305377872735,
           27.441889181358256,
           27.470472984843767,
           27.499056788329284,
           27.527640591814798,
           27.556224395300312,
           27.58480819878583,
           27.61339200227134,
           27.64197580575686,
           27.67055960924237,
           27.69914341272789,
           27.727727216213403,
           27.75631101969892,
           27.784894823184434,
           27.813478626669948,
           27.842062430155465,
           27.870646233640983,
           27.899230037126493,
           27.927813840612007,
           27.95639764409752,
           27.98498144758304,
           28.013565251068556,
           28.04214905455407,
           28.070732858039584,
           28.099316661525098,
           28.127262486758752,
           28.155080716342034,
           28.182898945925317,
           28.2107171755086,
           28.23853540509188,
           28.266353634675163,
           28.294171864258445,
           28.321990093841727,
           28.34980832342501,
           28.37762655300829,
           28.405444782591573,
           28.433263012174855,
           28.461081241758137,
           28.48889947134142,
           28.516717700924705,
           28.544535930507983,
           28.572354160091265,
           28.600172389674547,
           28.627990619257833,
           28.65580884884111,
           28.683627078424394,
           28.711445308007676,
           28.739263537590958,
           28.76708176717424,
           28.794899996757522,
           28.822718226340804,
           28.850536455924086,
           28.878354685507368,
           28.90617291509065,
           28.933991144673932,
           28.961809374257214,
           28.989627603840496,
           29.017445833423775,
           29.045264063007057,
           29.073082292590346,
           29.100900522173625,
           29.128718751756907,
           29.15653698393196,
           29.186558120299576,
           29.216579256667195,
           29.24660039303482,
           29.27662152940244,
           29.306642665770063,
           29.336663802137682,
           29.366684938505294,
           29.396706074872924,
           29.426727211240543,
           29.456748347608162,
           29.486769483975785,
           29.516790620343397,
           29.54681175671102,
           29.57683289307864,
           29.606854029446257,
           29.636875165813883,
           29.666896302181502,
           29.69691743854912,
           29.726938574916744,
           29.75695971128436,
           29.786980847651982,
           29.817001984019605,
           29.847023120387224,
           29.877044256754843,
           29.907065393122465,
           29.937086529490085,
           29.967107665857704,
           29.997128802225326,
           30.027149938592945,
           30.057171074960564,
           30.08719221132818,
           30.117213347695802,
           30.147234484063425,
           30.177255620431044,
           30.207276756798663,
           30.237297893166286,
           30.267319029533905,
           30.297340165901524,
           30.327361302269146,
           30.357382438636765,
           30.387403575004384,
           30.417424711372007,
           30.447445847739623,
           30.47746698410725,
           30.507488120474868,
           30.539864382467638,
           30.573418207272976,
           30.60697203207832,
           30.640525856883666,
           30.67407968168901,
           30.707633506494357,
           30.741187331299695,
           30.77474115610504,
           30.80829498091039,
           30.841848805715724,
           30.875402630521073,
           30.908956455326415,
           30.942510280131764,
           30.976064104937105,
           31.009617929742447,
           31.04317175454779,
           31.076725579353138,
           31.11027940415848,
           31.14383322896382,
           31.177387053769166,
           31.210940878574508,
           31.24449470337985,
           31.278048528185195,
           31.311602352990533,
           31.345156177795882,
           31.378710002601224,
           31.41226382740657,
           31.445817652211915,
           31.479371477017256,
           31.512925301822595,
           31.54647912662794,
           31.580032951433285,
           31.613586776238627,
           31.647140601043972,
           31.680694425849314,
           31.714248250654656,
           31.747802075460005,
           31.781355900265343,
           31.814909725070688,
           31.848463549876033,
           31.882017374681375,
           31.91557119948672,
           31.949125024292062,
           31.98267884909741,
           32.01623267390275,
           32.049786498708094,
           32.08334032351344,
           32.11689414831878,
           32.15044797312413,
           32.184001797929476,
           32.217555622734814,
           32.25110944754015,
           32.284663272345504,
           32.31821709715084,
           32.35177092195619,
           32.38375312248589,
           32.41531621961748,
           32.446879316749076,
           32.47844241388067,
           32.51000551101226,
           32.54156860814385,
           32.57313170527544,
           32.60469480240703,
           32.63625789953863,
           32.66782099667022,
           32.69938409380181,
           32.730947190933406,
           32.762510288064995,
           32.79407338519659,
           32.82563648232818,
           32.85719957945977,
           32.88876267659136,
           32.92032577372296,
           32.951888870854546,
           32.98345196798614,
           33.01501506511773,
           33.046578162249325,
           33.078141259380914,
           33.10970435651251,
           33.141267453644105,
           33.17283055077569,
           33.20439364790729,
           33.23595674503888,
           33.27251271181147,
           33.314061548225084,
           33.35561038463869,
           33.39715922105229,
           33.4387080574659,
           33.480256893879506,
           33.52180573029311,
           33.56335456670672,
           33.60490340312033,
           33.64645223953393,
           33.68800107594754,
           33.72954991236114,
           33.77109874877475,
           33.81264758518836,
           33.85419642160196,
           33.895745258015566,
           33.93729409442917,
           33.97884293084278,
           34.020391767256385,
           34.06194060366999,
           34.1034894400836,
           34.14503827649721,
           34.18658711291081,
           34.22813594932442,
           34.26968478573802,
           34.31123362215163,
           34.35278245856524,
           34.39433129497884,
           34.43588013139245,
           34.47742896780605,
           34.518977804219666,
           34.56052664063327,
           34.602075477046874,
           34.643624313460485,
           34.68517314987409,
           34.72672198628769,
           34.7682708227013,
           34.80981965911491,
           34.851368495528504,
           34.892917331942115,
           34.934466168355726,
           34.97601500476932,
           35.01756384118293,
           35.05911267759654,
           35.10066151401015,
           35.142210350423746,
           35.18375918683736,
           35.22530802325096,
           35.26740329792255,
           35.31002583427257,
           35.352648370622596,
           35.39527090697262,
           35.437893443322636,
           35.480515979672674,
           35.5231385160227,
           35.565761052372714,
           35.608383588722745,
           35.65100612507277,
           35.693628661422785,
           35.736251197772816,
           35.77887373412284,
           35.82149627047286,
           35.86411880682289,
           35.90674134317291,
           35.949363879522934,
           35.99198641587296,
           36.03460895222298,
           36.07723148857301,
           36.11985402492303,
           36.16247656127305,
           36.20509909762308,
           36.2477216339731,
           36.290344170323124,
           36.33296670667315,
           36.37558924302317,
           36.4182117793732,
           36.460834315723226,
           36.50345685207325,
           36.546079388423266,
           36.5887019247733,
           36.63132446112333,
           36.673946997473344,
           36.71656953382337,
           36.70050267608866,
           36.56705703018455,
           36.43361138428044,
           36.300165738376315,
           36.166720092472204,
           36.03327444656809,
           35.89982880066397,
           35.76638315475985,
           35.63293750885575,
           35.49949186295163,
           35.3660462170475,
           35.232600571143394,
           35.099154925239276,
           34.96570927933516,
           34.83226363343105,
           34.69881798752694,
           34.56537234162281,
           34.4319266957187,
           34.29848104981458,
           34.165035403910466,
           34.03158975800634,
           33.89814411210223,
           33.76469846619812,
           33.631252820293994,
           33.497807174389884,
           33.36436152848577,
           33.230915882581655,
           33.09747023667754,
           32.964024590773434,
           32.83057894486931,
           32.697133298965184,
           32.56368765306109,
           32.43024200715696,
           32.29679636125284,
           32.16335071534873,
           32.02990506944462,
           31.89645942354049,
           31.76301377763638,
           31.62956813173227,
           31.496122485828145,
           31.36267683992403,
           31.22923119401992,
           31.0957855481158,
           30.962339902211674,
           30.828894256307564,
           30.695448610403453,
           30.562002964499328,
           30.428557318595217,
           30.295111672691107,
           30.161666026786982,
           30.02822038088287,
           29.894774734978764,
           29.76132908907464,
           29.627883443170514,
           29.494437797266414,
           29.3695534834864,
           29.250012023120544,
           29.130470562754702,
           29.010929102388864,
           28.891387642023016,
           28.771846181657175,
           28.652304721291337,
           28.53276326092548,
           28.413221800559647,
           28.293680340193806,
           28.174138879827957,
           28.0545974194621,
           27.935055959096275,
           27.815514498730426,
           27.69597303836457,
           27.576431577998733,
           27.456890117632895,
           27.337348657267043,
           27.2178071969012,
           27.098265736535364,
           26.978724276169515,
           26.859182815803663,
           26.739641355437836,
           26.62009989507198,
           26.500558434706132,
           26.381016974340294,
           26.261475513974453,
           26.1419340536086,
           25.994612225706796,
           25.70838856012506,
           25.422164894543325,
           25.135941228961595,
           24.849717563379915,
           24.563493897798182,
           24.27727023221645,
           23.99104656663477,
           23.70482290105304,
           23.418599235471305,
           23.132375569889625,
           22.884122348379677,
           22.65093091908885,
           22.417739489798024,
           22.184548060507243,
           21.951356631216417,
           21.71816520192559,
           21.484973772634806,
           21.25178234334398,
           21.018590914053153,
           20.785399484762372,
           20.552208055471546,
           20.31901662618072,
           20.085825196889935,
           19.85263376759911,
           19.619442338308286,
           19.386250909017463,
           19.15305947972668,
           18.919868050435852,
           18.686676621145025,
           18.45348519185425,
           18.22029376256342,
           17.987102333272592,
           17.75391090398181,
           17.520719474690985,
           17.28752804540016,
           17.05433661610933,
           16.82114518681855,
           16.587953757527725,
           16.354762328236898,
           16.121570898946118,
           15.88837946965529,
           15.655188040364465,
           15.421996611073682,
           15.188805181782858,
           14.955613752492031,
           14.722422323201249,
           14.489230893910424,
           14.256039464619597,
           14.022848035328773,
           13.789656606037987,
           13.556465176747162,
           13.323273747456337,
           13.090082318165553,
           12.856890888874727,
           12.623699459583904,
           12.390508030293121,
           12.157316601002295,
           11.92412517171147,
           11.690933742420643,
           11.457742313129861,
           11.224550883839036,
           10.99135945454821,
           10.758168025257426,
           10.524976595966601,
           10.291785166675776,
           10.058593737384992,
           9.825402308094167,
           9.592210878803343,
           9.359019449512559,
           9.125828020221732,
           8.892636590930907,
           8.659445161640082,
           8.448318563268996,
           8.264086252484843,
           8.079853941700689,
           7.895621630916567,
           7.711389320132412,
           7.527157009348258,
           7.342924698564137,
           7.158692387779983,
           6.974460076995829,
           6.790227766211674,
           6.6059954554275535
          ],
          [
           26.068050049884015,
           26.099024758391543,
           26.12999946689907,
           26.160974175406597,
           26.191948883914126,
           26.222923592421655,
           26.25389830092918,
           26.28487300943671,
           26.315847717944237,
           26.346822426451766,
           26.377797134959295,
           26.408771843466823,
           26.43974655197435,
           26.47072126048188,
           26.501695968989406,
           26.532670677496935,
           26.563645386004463,
           26.594620094511992,
           26.62559480301952,
           26.65656951152705,
           26.687544220034578,
           26.718518928542107,
           26.74949363704963,
           26.78046834555716,
           26.811443054064686,
           26.842417762572218,
           26.873392471079747,
           26.90436717958727,
           26.9353418880948,
           26.96631659660233,
           26.997291305109858,
           27.028266013617387,
           27.059240722124912,
           27.090215430632444,
           27.121190139139973,
           27.1521648476475,
           27.18313955615503,
           27.214114264662552,
           27.245088973170084,
           27.27606368167761,
           27.307038390185138,
           27.338013098692667,
           27.368987807200195,
           27.399962515707724,
           27.430937224215253,
           27.46191193272278,
           27.49288664123031,
           27.52386134973784,
           27.554836058245364,
           27.585810766752893,
           27.61678547526042,
           27.64776018376795,
           27.67873489227548,
           27.709709600783007,
           27.740684309290533,
           27.77165901779806,
           27.80263372630559,
           27.83360843481312,
           27.864583143320647,
           27.895557851828176,
           27.9265325603357,
           27.95750726884323,
           27.988083496387876,
           28.016667299873387,
           28.045251103358904,
           28.073834906844418,
           28.102418710329935,
           28.13100251381545,
           28.159586317300967,
           28.18817012078648,
           28.216753924272,
           28.245337727757512,
           28.273921531243023,
           28.30250533472854,
           28.331089138214054,
           28.35967294169957,
           28.388256745185085,
           28.4168405486706,
           28.445424352156117,
           28.474008155641634,
           28.502591959127145,
           28.53117576261266,
           28.559759566098176,
           28.58834336958369,
           28.61628919481734,
           28.644107424400627,
           28.671925653983905,
           28.69974388356719,
           28.72756211315047,
           28.75538034273375,
           28.783198572317037,
           28.811016801900315,
           28.8388350314836,
           28.86665326106688,
           28.894471490650165,
           28.922289720233447,
           28.950107949816733,
           28.97792617940001,
           29.005744408983293,
           29.033562638566575,
           29.061380868149858,
           29.08919909773314,
           29.117017327316425,
           29.144835556899704,
           29.172653786482986,
           29.20157347241368,
           29.231594608781304,
           29.261615745148923,
           29.291636881516542,
           29.321658017884165,
           29.351679154251784,
           29.381700290619406,
           29.411721426987025,
           29.441742563354644,
           29.471763699722267,
           29.501784836089886,
           29.531805972457505,
           29.561827108825128,
           29.591848245192747,
           29.621869381560366,
           29.65189051792799,
           29.681911654295607,
           29.711932790663226,
           29.741953927030846,
           29.771975063398468,
           29.801996199766087,
           29.83201733613371,
           29.86203847250133,
           29.892059608868948,
           29.92208074523657,
           29.95210188160419,
           29.98212301797181,
           30.01214415433943,
           30.042165290707047,
           30.07218642707467,
           30.10220756344229,
           30.132228699809907,
           30.16224983617753,
           30.192270972545153,
           30.222292108912768,
           30.25231324528039,
           30.28233438164801,
           30.31235551801563,
           30.34237665438325,
           30.37239779075087,
           30.40241892711849,
           30.432440063486112,
           30.46246119985373,
           30.49248233622135,
           30.522503472588973,
           30.552524608956592,
           30.582545745324218,
           30.612566881691833,
           30.642588018059453,
           30.672609154427075,
           30.70263029079469,
           30.73265142716231,
           30.762672563529932,
           30.792693699897555,
           30.82271483626517,
           30.852735972632793,
           30.882757109000416,
           30.912778245368038,
           30.942799381735654,
           30.972820518103276,
           31.0028416544709,
           31.032862790838514,
           31.065239052831288,
           31.098792877636626,
           31.13234670244197,
           31.165900527247317,
           31.19945435205266,
           31.233008176858004,
           31.266562001663345,
           31.30011582646869,
           31.333669651274036,
           31.367223476079374,
           31.400777300884723,
           31.434331125690065,
           31.46788495049541,
           31.501438775300752,
           31.534992600106097,
           31.56854642491144,
           31.602100249716784,
           31.635654074522122,
           31.66920789932747,
           31.702761724132813,
           31.73631554893816,
           31.769869373743497,
           31.803423198548845,
           31.836977023354187,
           31.87053084815953,
           31.90408467296487,
           31.93763849777022,
           31.97119232257556,
           32.0047461473809,
           32.038299972186245,
           32.07185379699159,
           32.105407621796935,
           32.13896144660228,
           32.17251527140762,
           32.206069096212964,
           32.23962292101831,
           32.27317674582365,
           32.306730570629,
           32.34028439543434,
           32.37383822023968,
           32.40739204504502,
           32.44094586985037,
           32.47449969465571,
           32.50805351946106,
           32.5416073442664,
           32.57516116907175,
           32.608714993877086,
           32.64226881868243,
           32.67582264348778,
           32.70937646829312,
           32.74293029309846,
           32.776484117903806,
           32.81003794270915,
           32.843591767514496,
           32.877145592319835,
           32.91069941712518,
           32.944253241930525,
           32.97780706673586,
           33.01136089154121,
           33.044914716346554,
           33.0784685411519,
           33.11202236595724,
           33.14557619076258,
           33.17913001556792,
           33.212683840373266,
           33.24623766517861,
           33.279791489983964,
           33.313345314789295,
           33.34689913959465,
           33.380452964399986,
           33.41400678920533,
           33.447560614010676,
           33.481114438816014,
           33.51466826362136,
           33.548222088426705,
           33.580151901783665,
           33.61171499891526,
           33.643278096046856,
           33.67484119317844,
           33.70640429031004,
           33.73796738744163,
           33.769530484573224,
           33.80109358170481,
           33.837649548477415,
           33.87919838489102,
           33.92074722130462,
           33.96229605771823,
           34.00384489413184,
           34.04539373054544,
           34.086942566959046,
           34.12849140337266,
           34.17004023978626,
           34.211589076199864,
           34.253137912613475,
           34.294686749027086,
           34.33623558544068,
           34.37778442185429,
           34.41975507164738,
           34.4623776079974,
           34.50500014434742,
           34.54762268069745,
           34.590245217047475,
           34.6328677533975,
           34.67549028974753,
           34.71811282609755,
           34.76073536244757,
           34.8033578987976,
           34.845980435147624,
           34.88860297149765,
           34.931225507847664,
           34.973848044197695,
           35.01647058054772,
           35.05909311689774,
           35.101715653247766,
           35.14433818959779,
           35.18696072594781,
           35.22958326229784,
           35.27220579864787,
           35.314828334997884,
           35.35745087134791,
           35.40007340769793,
           35.442695944047955,
           35.48531848039798,
           35.527941016748,
           35.570563553098026,
           35.61318608944805,
           35.65580862579808,
           35.698431162148104,
           35.74105369849813,
           35.78367623484815,
           35.826298771198175,
           35.8689213075482,
           35.91154384389822,
           35.95416638024825,
           35.99678891659827,
           36.03941145294829,
           36.082033989298324,
           36.12465652564835,
           36.167279061998364,
           36.209901598348395,
           36.25252413469842,
           36.29514667104844,
           36.337769207398466,
           36.38039174374849,
           36.42301428009851,
           36.46563681644854,
           36.50825935279856,
           36.550881889148584,
           36.59350442549861,
           36.63612696184863,
           36.67874949819866,
           36.72137203454868,
           36.7639945708987,
           36.806617107248734,
           36.84923964359876,
           36.891862179948774,
           36.934484716298805,
           36.97710725264883,
           37.01972978899885,
           37.06235232534887,
           37.1049748616989,
           37.14759739804892,
           37.190219934398954,
           37.23284247074898,
           37.275465007099,
           37.318087543449025,
           37.30202068571431,
           37.1685750398102,
           37.03512939390609,
           36.90168374800197,
           36.768238102097854,
           36.63479245619375,
           36.50134681028962,
           36.3679011643855,
           36.2344555184814,
           36.10100987257728,
           35.967564226673154,
           35.834118580769044,
           35.70067293486493,
           35.56722728896081,
           35.4337816430567,
           35.30033599715259,
           35.16689035124846,
           35.03344470534435,
           34.89999905944024,
           34.766553413536116,
           34.633107767632,
           34.49966212172788,
           34.36621647582377,
           34.23277082991965,
           34.09932518401554,
           33.96587953811142,
           33.832433892207305,
           33.698988246303195,
           33.565542600399084,
           33.43209695449496,
           33.298651308590834,
           33.16520566268674,
           33.03176001678261,
           32.89831437087849,
           32.76486872497438,
           32.63142307907027,
           32.49797743316614,
           32.36453178726203,
           32.23108614135792,
           32.097640495453795,
           31.964194849549685,
           31.83074920364557,
           31.69730355774145,
           31.563857911837324,
           31.430412265933217,
           31.296966620029107,
           31.16352097412498,
           31.03007532822087,
           30.89662968231676,
           30.76318403641264,
           30.629738390508525,
           30.496292744604414,
           30.36284709870029,
           30.229401452796164,
           30.095955806892064,
           29.962510160987943,
           29.823109601926287,
           29.67667148308475,
           29.530233364243223,
           29.38379524540168,
           29.237357126560145,
           29.09091900771861,
           28.944480888877067,
           28.798042770035536,
           28.651604651194006,
           28.505166532352455,
           28.358728413510914,
           28.212290294669398,
           28.06585217582785,
           27.919414056986305,
           27.772975938144768,
           27.62653781930324,
           27.48009970046169,
           27.333661581620163,
           27.187223462778633,
           27.040785343937085,
           26.894347225095537,
           26.74790910625402,
           26.601470987412476,
           26.45503286857093,
           26.308594749729398,
           26.162156630887864,
           26.01571851204632,
           25.84614413267436,
           25.560888450650175,
           25.27563276862599,
           24.9903770866018,
           24.705121404577664,
           24.41986572255348,
           24.134610040529296,
           23.84935435850516,
           23.56409867648097,
           23.278842994456785,
           22.993587312432652,
           22.708331630408466,
           22.423075948384277,
           22.137820266360087,
           21.852564584335955,
           21.56730890231177,
           21.28205322028758,
           20.996797538263447,
           20.711541856239258,
           20.426286174215072,
           20.14103049219094,
           19.855774810166753,
           19.570519128142564,
           19.28526344611843,
           19.000007764094242,
           18.714752082070056,
           18.42949640004587,
           18.144240718021734,
           17.85898503599755,
           17.57372935397336,
           17.288473671949227,
           17.00321798992504,
           16.768786763538017,
           16.535595334247233,
           16.302403904956407,
           16.06921247566558,
           15.836021046374753,
           15.602829617083973,
           15.369638187793146,
           15.13644675850232,
           14.903255329211536,
           14.670063899920711,
           14.436872470629886,
           14.203681041339102,
           13.970489612048278,
           13.737298182757453,
           13.50410675346667,
           13.270915324175846,
           13.03772389488502,
           12.804532465594194,
           12.571341036303409,
           12.338149607012584,
           12.115209299492738,
           11.935835325923188,
           11.756461352353607,
           11.577087378784025,
           11.397713405214475,
           11.218339431644893,
           11.038965458075308,
           10.859591484505728,
           10.680217510936178,
           10.500843537366595,
           10.321469563797011,
           10.142095590227463,
           9.962721616657879,
           9.783347643088298,
           9.603973669518746,
           9.424599695949166,
           9.245225722379582,
           9.065851748810033,
           8.88647777524045,
           8.707103801670868,
           8.527729828101284,
           8.348355854531734,
           8.168981880962153,
           7.989607907392571,
           7.810233933823021,
           7.630859960253439,
           7.451485986683856,
           7.272112013114307,
           7.092738039544725,
           6.9133640659751405,
           6.733990092405557,
           6.554616118836009
          ],
          [
           26.517626824684896,
           26.548601533192425,
           26.579576241699954,
           26.610550950207482,
           26.641525658715008,
           26.672500367222536,
           26.703475075730065,
           26.734449784237594,
           26.76542449274512,
           26.796399201252648,
           26.827373909760176,
           26.858348618267705,
           26.889323326775234,
           26.920298035282766,
           26.95127274379029,
           26.98224745229782,
           27.013222160805345,
           27.044196869312877,
           27.075171577820406,
           27.106146286327935,
           27.137120994835463,
           27.168095703342992,
           27.199070411850514,
           27.230045120358046,
           27.26101982886557,
           27.2919945373731,
           27.32296924588063,
           27.353943954388154,
           27.384918662895686,
           27.415893371403214,
           27.446868079910743,
           27.477842788418272,
           27.508817496925797,
           27.53979220543333,
           27.570766913940854,
           27.601741622448383,
           27.632716330955912,
           27.663691039463433,
           27.69466574797097,
           27.72564045647849,
           27.756615164986023,
           27.787589873493552,
           27.81856458200108,
           27.84953929050861,
           27.880513999016138,
           27.911488707523663,
           27.94246341603119,
           27.97343812453872,
           28.004412833046246,
           28.035387541553774,
           28.066362250061303,
           28.09733695856883,
           28.12831166707636,
           28.15928637558389,
           28.190261084091418,
           28.221235792598947,
           28.252210501106475,
           28.283185209614004,
           28.314159918121533,
           28.34513462662906,
           28.376109335136587,
           28.407084043644115,
           28.438058752151644,
           28.469033460659173,
           28.5000081691667,
           28.53098287767423,
           28.561957586181755,
           28.592932294689284,
           28.623907003196813,
           28.65488171170434,
           28.68585642021187,
           28.7168311287194,
           28.747805837226927,
           28.778780545734453,
           28.809755254241985,
           28.840729962749514,
           28.87170467125704,
           28.902679379764567,
           28.933654088272096,
           28.963034863700234,
           28.991618667185744,
           29.020202470671258,
           29.048786274156775,
           29.07737007764229,
           29.105315902875944,
           29.133134132459226,
           29.160952362042508,
           29.18877059162579,
           29.2165888245278,
           29.24660996089542,
           29.276631097263042,
           29.30665223363066,
           29.33667336999828,
           29.366694506365903,
           29.39671564273352,
           29.42673677910114,
           29.456757915468764,
           29.486779051836383,
           29.516800188204,
           29.54682132457162,
           29.57684246093924,
           29.606863597306862,
           29.63688473367448,
           29.666905870042104,
           29.696927006409723,
           29.726948142777342,
           29.75696927914496,
           29.786990415512584,
           29.817011551880203,
           29.847032688247822,
           29.877053824615444,
           29.907074960983064,
           29.937096097350683,
           29.967117233718305,
           29.997138370085924,
           30.027159506453543,
           30.057180642821166,
           30.087201779188785,
           30.117222915556404,
           30.147244051924027,
           30.177265188291646,
           30.207286324659265,
           30.237307461026887,
           30.267328597394506,
           30.297349733762125,
           30.327370870129748,
           30.35739200649737,
           30.387413142864986,
           30.417434279232605,
           30.44745541560023,
           30.47747655196785,
           30.50749768833547,
           30.53751882470309,
           30.567539961070707,
           30.59756109743833,
           30.627582233805946,
           30.657603370173568,
           30.68762450654119,
           30.717645642908806,
           30.74766677927643,
           30.777687915644048,
           30.807709052011667,
           30.83773018837929,
           30.86775132474691,
           30.897772461114535,
           30.92779359748215,
           30.957814733849773,
           30.987835870217395,
           31.01785700658501,
           31.047878142952634,
           31.077899279320253,
           31.10792041568787,
           31.137941552055487,
           31.16796268842311,
           31.197983824790732,
           31.228004961158348,
           31.25802609752597,
           31.288047233893593,
           31.31806837026121,
           31.34808950662883,
           31.378110642996454,
           31.40813177936407,
           31.438152915731695,
           31.46817405209931,
           31.498195188466937,
           31.528216324834553,
           31.55823746120217,
           31.590613723194945,
           31.624167548000287,
           31.657721372805632,
           31.691275197610977,
           31.72482902241632,
           31.75838284722166,
           31.791936672027006,
           31.82549049683235,
           31.859044321637693,
           31.892598146443035,
           31.926151971248384,
           31.959705796053722,
           31.993259620859067,
           32.02681344566441,
           32.060367270469754,
           32.09392109527509,
           32.127474920080445,
           32.16102874488578,
           32.194582569691136,
           32.228136394496474,
           32.26169021930181,
           32.295244044107164,
           32.3287978689125,
           32.36235169371784,
           32.39590551852319,
           32.42945934332853,
           32.46301316813388,
           32.49656699293922,
           32.53037798778274,
           32.564225718293486,
           32.59807344880423,
           32.631921179314965,
           32.6657689098257,
           32.699616640336444,
           32.73346437084719,
           32.76731210135793,
           32.80115983186867,
           32.8350075623794,
           32.868855292890146,
           32.90270302340089,
           32.936550753911625,
           32.97039848442237,
           33.004246214933104,
           33.038093945443855,
           33.071941675954584,
           33.10578940646533,
           33.13963713697607,
           33.173484867486806,
           33.20733259799755,
           33.24118032850829,
           33.27502805901903,
           33.30887578952977,
           33.34272352004051,
           33.37657125055125,
           33.410418981061994,
           33.44426671157273,
           33.47811444208347,
           33.51196217259421,
           33.54580990310495,
           33.579657633615696,
           33.61350536412643,
           33.64735309463717,
           33.68120082514791,
           33.715048555658655,
           33.7488962861694,
           33.782744016680134,
           33.81659174719087,
           33.85043947770161,
           33.884287208212356,
           33.91813493872309,
           33.951982669233836,
           33.98583039974458,
           34.019678130255315,
           34.05352586076606,
           34.087373591276794,
           34.12122132178754,
           34.15506905229828,
           34.18891678280902,
           34.22276451331976,
           34.256612243830496,
           34.29045997434123,
           34.324307704851975,
           34.35815543536272,
           34.39721925399123,
           34.441499160737514,
           34.48577906748379,
           34.530058974230066,
           34.57433888097635,
           34.61861878772263,
           34.66289869446891,
           34.70717860121519,
           34.75145850796147,
           34.79573841470775,
           34.84001832145403,
           34.884298228200315,
           34.9285781349466,
           34.972858041692874,
           35.01609399196784,
           35.05878310472748,
           35.10147221748712,
           35.14416133024676,
           35.1868504430064,
           35.22953955576604,
           35.272228668525685,
           35.31491778128533,
           35.35760689404496,
           35.40029600680461,
           35.44298511956425,
           35.48567423232389,
           35.528363345083534,
           35.571052457843166,
           35.61374157060281,
           35.656430683362444,
           35.69911979612209,
           35.74180890888174,
           35.78449802164137,
           35.827187134401015,
           35.869876247160654,
           35.91256535992029,
           35.95525447267994,
           35.99794358543958,
           36.04063269819922,
           36.08332181095885,
           36.126010923718496,
           36.168700036478135,
           36.211389149237775,
           36.25407826199742,
           36.29676737475707,
           36.3394564875167,
           36.382145600276345,
           36.424834713035985,
           36.467523825795624,
           36.51021293855526,
           36.55290205131491,
           36.59559116407455,
           36.63828027683419,
           36.680969389593834,
           36.72365850235347,
           36.766347615113105,
           36.80903672787275,
           36.85172584063239,
           36.89441495339203,
           36.937104066151676,
           36.979793178911315,
           37.022482291670954,
           37.06517140443059,
           37.10786051719023,
           37.15054962994988,
           37.19323874270951,
           37.23592785546916,
           37.2786169682288,
           37.321306080988435,
           37.363995193748075,
           37.40668430650772,
           37.44937341926736,
           37.492062532027,
           37.534751644786645,
           37.57744075754628,
           37.620129870305924,
           37.66281898306556,
           37.705508095825195,
           37.74819720858485,
           37.79088632134449,
           37.83357543410413,
           37.87626454686377,
           37.918953659623405,
           37.89419522844842,
           37.73454170940424,
           37.574888190360056,
           37.41543493024209,
           37.268996811400555,
           37.122558692559025,
           36.97612057371748,
           36.829682454875936,
           36.68324433603442,
           36.536806217192876,
           36.39036809835133,
           36.2439299795098,
           36.09749186066826,
           35.95105374182672,
           35.80461562298519,
           35.65817750414365,
           35.51173938530211,
           35.36530126646058,
           35.21886314761904,
           35.0724250287775,
           34.92598690993596,
           34.77954879109442,
           34.6331106722529,
           34.486672553411346,
           34.340234434569815,
           34.193796315728285,
           34.047358196886734,
           33.9009200780452,
           33.754481959203666,
           33.60804384036213,
           33.461605721520584,
           33.315167602679054,
           33.16872948383752,
           33.02229136499598,
           32.87585324615444,
           32.729415127312905,
           32.58297700847137,
           32.43653888962983,
           32.2901007707883,
           32.143662651946755,
           31.997224533105218,
           31.85078641426369,
           31.70434829542214,
           31.5579101765806,
           31.41147205773907,
           31.26503393889754,
           31.118595820055987,
           30.972157701214456,
           30.825719582372926,
           30.679281463531378,
           30.532843344689848,
           30.386405225848314,
           30.239967107006773,
           30.093528988165218,
           29.947090869323706,
           29.800652750482165,
           29.654214631640613,
           29.507776512799087,
           29.361338393957553,
           29.214900275116,
           29.068462156274478,
           28.922024037432944,
           28.775585918591396,
           28.629147799749866,
           28.48270968090833,
           28.336271562066788,
           28.18983344322524,
           28.04339532438372,
           27.896957205542183,
           27.75051908670063,
           27.6040809678591,
           27.45764284901757,
           27.311204730176023,
           27.164766611334493,
           27.018328492492962,
           26.87189037365141,
           26.725452254809866,
           26.57901413596835,
           26.432576017126802,
           26.28613789828526,
           26.139699779443724,
           25.993261660602197,
           25.846823541760653,
           25.677249162388694,
           25.391993480364505,
           25.10673779834032,
           24.82148211631613,
           24.536226434291994,
           24.250970752267808,
           23.96571507024362,
           23.68045938821949,
           23.3952037061953,
           23.109948024171114,
           22.824692342146978,
           22.539436660122792,
           22.254180978098603,
           21.968925296074417,
           21.683669614050288,
           21.3984139320261,
           21.11315825000191,
           20.827902567977777,
           20.542646885953587,
           20.2573912039294,
           19.97213552190527,
           19.68687983988108,
           19.401624157856894,
           19.11636847583276,
           18.831112793808572,
           18.545857111784386,
           18.261296255728126,
           17.978125044122073,
           17.694953832515978,
           17.41178262090987,
           17.128611409303822,
           16.845440197697723,
           16.56226898609162,
           16.27909777448557,
           15.995926562879468,
           15.712755351273367,
           15.429584139667265,
           15.146412928061217,
           14.863241716455114,
           14.580070504849012,
           14.29689929324296,
           14.013728081636858,
           13.793614873821666,
           13.618543097285709,
           13.443471320749719,
           13.268399544213732,
           13.093327767677776,
           12.918255991141784,
           12.743184214605797,
           12.568112438069807,
           12.393040661533849,
           12.21796888499786,
           12.04289710846187,
           11.867825331925912,
           11.692753555389924,
           11.517681778853934,
           11.34261000231798,
           11.167538225781989,
           10.98888129020132,
           10.80950731663174,
           10.630133343062191,
           10.450759369492607,
           10.271385395923025,
           10.092011422353474,
           9.912637448783892,
           9.73326347521431,
           9.55388950164476,
           9.374515528075177,
           9.195141554505595,
           9.015767580936044,
           8.836393607366462,
           8.65701963379688,
           8.477645660227298,
           8.298271686657747,
           8.118897713088165,
           7.939523739518583,
           7.760149765949032,
           7.58077579237945,
           7.401401818809868,
           7.222027845240318,
           7.042653871670736,
           6.863279898101153,
           6.68390592453157,
           6.50453195096202
          ],
          [
           26.960883552105926,
           26.99424663387441,
           27.0276097156429,
           27.060972797411385,
           27.09433587917987,
           27.127698960948354,
           27.16106204271684,
           27.194425124485324,
           27.227788206253813,
           27.261151288022294,
           27.294514369790782,
           27.327877451559267,
           27.36044441170027,
           27.3914191202078,
           27.42239382871533,
           27.453368537222858,
           27.484343245730383,
           27.515317954237915,
           27.54629266274544,
           27.577267371252972,
           27.6082420797605,
           27.63921678826803,
           27.67019149677555,
           27.70116620528308,
           27.73214091379061,
           27.763115622298137,
           27.794090330805663,
           27.82506503931319,
           27.85603974782072,
           27.887014456328252,
           27.91798916483578,
           27.948963873343306,
           27.979938581850835,
           28.010913290358367,
           28.041887998865892,
           28.07286270737342,
           28.10383741588095,
           28.13481212438848,
           28.165786832896007,
           28.196761541403532,
           28.22773624991106,
           28.25871095841859,
           28.28968566692612,
           28.320660375433647,
           28.351635083941172,
           28.3826097924487,
           28.41358450095623,
           28.44455920946376,
           28.475533917971283,
           28.506508626478812,
           28.53748333498634,
           28.56845804349387,
           28.5994327520014,
           28.630407460508927,
           28.661382169016456,
           28.692356877523984,
           28.723331586031513,
           28.75430629453904,
           28.78528100304657,
           28.8162557115541,
           28.847230420061624,
           28.878205128569153,
           28.90917983707668,
           28.94015454558421,
           28.97112925409174,
           29.002103962599268,
           29.033078671106793,
           29.06405337961432,
           29.09502808812185,
           29.12600279662938,
           29.156977505136908,
           29.187952213644436,
           29.218926922151965,
           29.249901630659494,
           29.280876339167023,
           29.31185104767455,
           29.342825756182076,
           29.373800464689605,
           29.404775173197134,
           29.435749881704663,
           29.46672459021219,
           29.497699298719716,
           29.528674007227245,
           29.559648715734774,
           29.589828780792377,
           29.61984991716,
           29.64987105352762,
           29.67989218989524,
           29.70991332626286,
           29.73993446263048,
           29.769955598998102,
           29.79997673536572,
           29.82999787173334,
           29.860019008100963,
           29.89004014446858,
           29.9200612808362,
           29.950082417203824,
           29.980103553571443,
           30.01012468993906,
           30.04014582630668,
           30.0701669626743,
           30.100188099041922,
           30.13020923540954,
           30.160230371777164,
           30.190251508144783,
           30.220272644512402,
           30.25029378088002,
           30.280314917247644,
           30.310336053615263,
           30.340357189982882,
           30.370378326350504,
           30.400399462718124,
           30.430420599085743,
           30.460441735453365,
           30.490462871820984,
           30.520484008188603,
           30.550505144556226,
           30.580526280923845,
           30.610547417291464,
           30.640568553659087,
           30.670589690026706,
           30.700610826394325,
           30.730631962761944,
           30.760653099129563,
           30.790674235497185,
           30.820695371864804,
           30.850716508232427,
           30.880737644600046,
           30.910758780967665,
           30.940779917335284,
           30.970801053702907,
           31.00082219007053,
           31.030843326438145,
           31.060864462805768,
           31.09088559917339,
           31.120906735541006,
           31.150927871908628,
           31.180949008276247,
           31.210970144643866,
           31.24099128101149,
           31.271012417379108,
           31.301033553746727,
           31.33105469011435,
           31.36107582648197,
           31.391096962849588,
           31.42111809921721,
           31.45113923558483,
           31.48116037195245,
           31.511181508320067,
           31.541202644687687,
           31.57122378105531,
           31.60124491742293,
           31.631266053790547,
           31.66128719015817,
           31.691308326525792,
           31.72202124426228,
           31.754117717456126,
           31.78621419064997,
           31.818310663843818,
           31.850407137037664,
           31.88250361023151,
           31.914600083425356,
           31.9466965566192,
           31.978793029813048,
           32.010889503006894,
           32.04298597620074,
           32.075082449394586,
           32.10940751616088,
           32.14484687971339,
           32.180286243265904,
           32.215725606818424,
           32.25116497037094,
           32.28660433392345,
           32.32204369747596,
           32.357483061028475,
           32.392922424580995,
           32.42836178813351,
           32.46380115168603,
           32.49924051523853,
           32.53467987879105,
           32.570119242343566,
           32.60555860589608,
           32.6409979694486,
           32.67643733300111,
           32.71131192660661,
           32.745159657117355,
           32.77900738762809,
           32.81285511813883,
           32.84670284864957,
           32.880550579160314,
           32.91439830967105,
           32.94824604018179,
           32.98209377069253,
           33.01594150120327,
           33.04978923171401,
           33.08363696222475,
           33.11748469273549,
           33.15133242324623,
           33.185180153756974,
           33.21902788426771,
           33.25287561477845,
           33.28672334528919,
           33.32057107579993,
           33.354418806310676,
           33.38826653682142,
           33.422114267332155,
           33.45596199784289,
           33.489809728353634,
           33.52365745886437,
           33.557505189375114,
           33.59135291988585,
           33.62520065039659,
           33.659048380907336,
           33.69289611141807,
           33.726743841928815,
           33.76059157243955,
           33.7944393029503,
           33.82828703346104,
           33.86213476397178,
           33.895982494482524,
           33.92983022499325,
           33.963677955504,
           33.99752568601474,
           34.03137341652548,
           34.065221147036226,
           34.09906887754696,
           34.1329166080577,
           34.16676433856844,
           34.20061206907918,
           34.23445979958992,
           34.268307530100664,
           34.3021552606114,
           34.33600299112214,
           34.36985072163288,
           34.40369845214362,
           34.437546182654366,
           34.4713939131651,
           34.505241643675845,
           34.53908937418658,
           34.572937104697324,
           34.60678483520807,
           34.6406325657188,
           34.67448029622955,
           34.70832802674028,
           34.742175757251026,
           34.77602348776177,
           34.809871218272505,
           34.84371894878325,
           34.877566679293984,
           34.91141440980473,
           34.950478228433234,
           34.994758135179524,
           35.03903804192579,
           35.083317948672075,
           35.12759785541836,
           35.17187776216464,
           35.216157668910924,
           35.26043757565721,
           35.30471748240348,
           35.34899738914976,
           35.39327729589604,
           35.437557202642324,
           35.4818371093886,
           35.52611701613488,
           35.570396922881166,
           35.61467682962744,
           35.658956736373725,
           35.70323664312001,
           35.74751654986628,
           35.791796456612566,
           35.83607636335885,
           35.88035627010513,
           35.92463617685141,
           35.96891608359769,
           36.013195990343974,
           36.05747589709024,
           36.101755803836525,
           36.14603571058281,
           36.19031561732909,
           36.23459552407537,
           36.27887543082166,
           36.32315533756793,
           36.36743524431421,
           36.41171515106049,
           36.455995057806774,
           36.50027496455306,
           36.54455487129933,
           36.588834778045616,
           36.631623315554506,
           36.674312428314146,
           36.717001541073785,
           36.759690653833424,
           36.80237976659307,
           36.84506887935271,
           36.887757992112356,
           36.93044710487199,
           36.973136217631634,
           37.01582533039127,
           37.05851444315091,
           37.10120355591055,
           37.1438926686702,
           37.18658178142984,
           37.229270894189476,
           37.271960006949115,
           37.31464911970876,
           37.35733823246839,
           37.40002734522804,
           37.442716457987686,
           37.48540557074732,
           37.528094683506964,
           37.5707837962666,
           37.61347290902624,
           37.65616202178588,
           37.69885113454552,
           37.74154024730516,
           37.7842293600648,
           37.826918472824445,
           37.869607585584085,
           37.912296698343724,
           37.95498581110336,
           37.99767492386301,
           38.04036403662265,
           38.08305314938229,
           38.125742262141934,
           38.168431374901566,
           38.21112048766121,
           38.25380960042086,
           38.29649871318049,
           38.33918782594013,
           38.38187693869977,
           38.424566051459415,
           38.46725516421906,
           38.50994427697869,
           38.485185845803706,
           38.32553232675952,
           38.165878807715345,
           38.006225288671146,
           37.84657176962696,
           37.686918250582785,
           37.52726473153859,
           37.36761121249439,
           37.207957693450226,
           37.04830417440603,
           36.88865065536183,
           36.728997136317645,
           36.56934361727347,
           36.40969009822927,
           36.250036579185085,
           36.09038306014091,
           35.93072954109671,
           35.771076022052526,
           35.61142250300834,
           35.45176898396415,
           35.29211546491995,
           35.13246194587577,
           34.97280842683159,
           34.81315490778739,
           34.65350138874321,
           34.493847869699024,
           34.334194350654826,
           34.17454083161065,
           34.014887312566465,
           33.855233793522274,
           33.695580274478075,
           33.535926755433906,
           33.37627323638971,
           33.21661971734551,
           33.05696619830133,
           32.89731267925715,
           32.73765916021295,
           32.578005641168765,
           32.41835212212459,
           32.25869860308039,
           32.099045084036206,
           31.939391564992025,
           31.77973804594783,
           31.620084526903632,
           31.460431007859448,
           31.300777488815264,
           31.14112396977107,
           30.98147045072689,
           30.821816931682704,
           30.662163412638513,
           30.50250989359433,
           30.34285637455015,
           30.18320285550595,
           30.023549336461755,
           29.86389581741759,
           29.70424229837339,
           29.544588779329196,
           29.384935260285015,
           29.22528174124083,
           29.065628222196633,
           28.905974703152456,
           28.75312906714727,
           28.606690948305726,
           28.460252829464196,
           28.313814710622665,
           28.16737659178112,
           28.020938472939577,
           27.874500354098053,
           27.728062235256512,
           27.581624116414964,
           27.43518599757343,
           27.2887478787319,
           27.142309759890352,
           26.995871641048822,
           26.849433522207292,
           26.70299540336574,
           26.556557284524203,
           26.41011916568268,
           26.263681046841135,
           26.11724292799959,
           25.970804809158057,
           25.824366690316527,
           25.67792857147498,
           25.508354192103024,
           25.223098510078838,
           24.93784282805465,
           24.65258714603046,
           24.367331464006327,
           24.08207578198214,
           23.79682009995795,
           23.51156441793382,
           23.228260376064267,
           22.945089164458167,
           22.661917952852118,
           22.37874674124601,
           22.095575529639913,
           21.812404318033813,
           21.529233106427764,
           21.246061894821658,
           20.962890683215555,
           20.679719471609506,
           20.396548260003406,
           20.113377048397304,
           19.83020583679125,
           19.54703462518515,
           19.26386341357905,
           18.980692201973,
           18.6975209903669,
           18.414349778760798,
           18.131178567154695,
           17.848007355548646,
           17.564836143942543,
           17.28166493233644,
           16.998493720730394,
           16.715322509124288,
           16.43215129751819,
           16.14898008591214,
           15.865808874306035,
           15.582637662699932,
           15.299466451093831,
           15.016295239487782,
           14.73312402788168,
           14.449952816275578,
           14.166781604669527,
           13.883610393063426,
           13.663497185248232,
           13.488425408712274,
           13.313353632176288,
           13.138281855640301,
           12.963210079104343,
           12.788138302568353,
           12.613066526032362,
           12.437994749496372,
           12.262922972960418,
           12.087851196424428,
           11.912779419888437,
           11.737707643352483,
           11.562635866816493,
           11.387564090280502,
           11.212492313744546,
           11.037420537208558,
           10.862348760672567,
           10.687276984136577,
           10.512205207600623,
           10.337133431064633,
           10.162061654528642,
           9.986989877992688,
           9.811918101456698,
           9.636846324920707,
           9.46177454838475,
           9.286702771848761,
           9.111630995312773,
           8.936559218776814,
           8.761487442240826,
           8.586415665704838,
           8.411343889168847,
           8.236272112632891,
           8.061200336096901,
           7.886128559560912,
           7.710065598075046,
           7.530691624505463,
           7.351317650935881,
           7.171943677366332,
           6.9925697037967485,
           6.813195730227166,
           6.633821756657583,
           6.454447783088034
          ],
          [
           27.40152197537514,
           27.434885057143624,
           27.46824813891211,
           27.501611220680594,
           27.53497430244908,
           27.568337384217564,
           27.60170046598605,
           27.635063547754534,
           27.66842662952302,
           27.701789711291507,
           27.735152793059992,
           27.768515874828477,
           27.801878956596962,
           27.835242038365447,
           27.868605120133935,
           27.90196820190242,
           27.935331283670905,
           27.96869436543939,
           28.002057447207875,
           28.03542052897636,
           28.068783610744845,
           28.10214669251333,
           28.135509774281815,
           28.168872856050303,
           28.202235937818784,
           28.235599019587273,
           28.268962101355758,
           28.302325183124243,
           28.33568826489273,
           28.367061037101067,
           28.3980357456086,
           28.429010454116128,
           28.459985162623656,
           28.490959871131185,
           28.52193457963871,
           28.55290928814624,
           28.583883996653768,
           28.614858705161296,
           28.645833413668825,
           28.676808122176354,
           28.707782830683882,
           28.738757539191404,
           28.76973224769894,
           28.800706956206465,
           28.831681664713994,
           28.862656373221526,
           28.89363108172905,
           28.924605790236583,
           28.95558049874411,
           28.986555207251634,
           29.017529915759166,
           29.048504624266688,
           29.079479332774223,
           29.11045404128175,
           29.141428749789274,
           29.172403458296806,
           29.20337816680433,
           29.234352875311863,
           29.26532758381939,
           29.296302292326914,
           29.327277000834446,
           29.35825170934197,
           29.389226417849503,
           29.42020112635703,
           29.451175834864557,
           29.482150543372086,
           29.513125251879615,
           29.544099960387143,
           29.575074668894672,
           29.6060493774022,
           29.63702408590973,
           29.667998794417255,
           29.698973502924783,
           29.729948211432312,
           29.76092291993984,
           29.79189762844737,
           29.822872336954894,
           29.853847045462423,
           29.884821753969952,
           29.91579646247748,
           29.94677117098501,
           29.977745879492538,
           30.008720588000063,
           30.039695296507595,
           30.069875361565195,
           30.099896497932818,
           30.129917634300437,
           30.159938770668056,
           30.18995990703568,
           30.219981043403298,
           30.250002179770917,
           30.28002331613854,
           30.31004445250616,
           30.34006558887378,
           30.3700867252414,
           30.40010786160902,
           30.43012899797664,
           30.46015013434426,
           30.490171270711883,
           30.5201924070795,
           30.55021354344712,
           30.58023467981474,
           30.61025581618236,
           30.640276952549982,
           30.6702980889176,
           30.70031922528522,
           30.730340361652843,
           30.760361498020462,
           30.79038263438808,
           30.820403770755703,
           30.85042490712332,
           30.88044604349094,
           30.910467179858564,
           30.940488316226183,
           30.970509452593802,
           31.00053058896142,
           31.030551725329044,
           31.060572861696663,
           31.090593998064282,
           31.120615134431905,
           31.150636270799524,
           31.180657407167146,
           31.210678543534762,
           31.240699679902384,
           31.270720816270003,
           31.300741952637622,
           31.330763089005245,
           31.360784225372868,
           31.390805361740483,
           31.420826498108106,
           31.45084763447573,
           31.480868770843347,
           31.510889907210966,
           31.54091104357859,
           31.570932179946205,
           31.60095331631382,
           31.63097445268145,
           31.660995589049065,
           31.691016725416688,
           31.72276731043478,
           31.754863783628625,
           31.786960256822468,
           31.819056730016317,
           31.85115320321016,
           31.88324967640401,
           31.915346149597855,
           31.947442622791705,
           31.97953909598555,
           32.01163556917939,
           32.04373204237324,
           32.07582851556709,
           32.10792498876093,
           32.140021461954774,
           32.17211793514862,
           32.20421440834247,
           32.23631088153631,
           32.268407354730165,
           32.30050382792401,
           32.33260030111786,
           32.3646967743117,
           32.39679324750555,
           32.428889720699395,
           32.46098619389324,
           32.49308266708709,
           32.52517914028094,
           32.55727561347478,
           32.589372086668625,
           32.623697153434925,
           32.65913651698743,
           32.69457588053995,
           32.73001524409246,
           32.765454607644976,
           32.800893971197496,
           32.83633333475,
           32.87177269830252,
           32.907212061855034,
           32.94265142540755,
           32.97809078896007,
           33.01353015251257,
           33.04896951606509,
           33.08440887961761,
           33.119848243170125,
           33.15528760672264,
           33.19072697027515,
           33.22616633382766,
           33.261605697380176,
           33.297045060932696,
           33.3324844244852,
           33.36792378803772,
           33.403363151590234,
           33.43880251514275,
           33.47424187869527,
           33.50968124224778,
           33.54512060580029,
           33.580559969352805,
           33.61599933290532,
           33.65143869645783,
           33.68687806001034,
           33.72231742356287,
           33.757756787115376,
           33.79319615066789,
           33.82863551422041,
           33.86407487777292,
           33.899514241325434,
           33.93495360487795,
           33.97039296843046,
           34.00583233198297,
           34.04127169553549,
           34.076711059088005,
           34.11076416381713,
           34.14461189432787,
           34.17845962483862,
           34.21230735534935,
           34.246155085860096,
           34.28000281637084,
           34.313850546881575,
           34.34769827739232,
           34.38154600790306,
           34.4153937384138,
           34.44924146892454,
           34.48308919943528,
           34.51693692994601,
           34.550784660456756,
           34.5846323909675,
           34.61848012147824,
           34.65232785198898,
           34.686175582499715,
           34.72002331301046,
           34.7538710435212,
           34.78771877403194,
           34.82156650454268,
           34.85541423505342,
           34.88926196556416,
           34.923109696074896,
           34.95695742658564,
           34.99080515709638,
           35.02465288760712,
           35.05850061811786,
           35.092348348628605,
           35.12619607913934,
           35.160043809650084,
           35.19389154016082,
           35.22773927067156,
           35.261587001182306,
           35.29543473169305,
           35.329282462203786,
           35.36313019271452,
           35.396977923225265,
           35.430825653736,
           35.464673384246744,
           35.50373720287526,
           35.54801710962154,
           35.592297016367816,
           35.63657692311409,
           35.680856829860375,
           35.72513673660666,
           35.76941664335294,
           35.81369655009922,
           35.8579764568455,
           35.902256363591775,
           35.94653627033806,
           35.99081617708434,
           36.035096083830624,
           36.07937599057691,
           36.12365589732318,
           36.167935804069465,
           36.21221571081574,
           36.256495617562024,
           36.3007755243083,
           36.34505543105458,
           36.389335337800865,
           36.43361524454715,
           36.477895151293424,
           36.52217505803971,
           36.56645496478599,
           36.610734871532266,
           36.65501477827855,
           36.69929468502483,
           36.74357459177111,
           36.78785449851739,
           36.83213440526367,
           36.876414312009956,
           36.920694218756225,
           36.96497412550251,
           37.00925403224879,
           37.05353393899507,
           37.09781384574135,
           37.14209375248763,
           37.186373659233915,
           37.23065356598019,
           37.274933472726474,
           37.31921337947275,
           37.36349328621903,
           37.407773192965315,
           37.4520530997116,
           37.496333006457874,
           37.54061291320416,
           37.58489281995044,
           37.629172726696716,
           37.67345263344299,
           37.717732540189274,
           37.76201244693555,
           37.80629235368183,
           37.85057226042812,
           37.894852167174406,
           37.939132073920675,
           37.98341198066696,
           38.02769188741324,
           38.07197179415952,
           38.1162517009058,
           38.16053160765208,
           38.204463526381545,
           38.247152639141184,
           38.28984175190082,
           38.33253086466046,
           38.3752199774201,
           38.41790909017974,
           38.46059820293939,
           38.503287315699026,
           38.545976428458665,
           38.58866554121831,
           38.63135465397795,
           38.67404376673758,
           38.716732879497236,
           38.75942199225687,
           38.80211110501651,
           38.844800217776154,
           38.88748933053579,
           38.93017844329544,
           38.97286755605507,
           39.01555666881472,
           39.058245781574364,
           39.100934894333996,
           39.076176463159,
           38.916522944114824,
           38.75686942507065,
           38.59721590602645,
           38.437562386982265,
           38.27790886793808,
           38.11825534889389,
           37.958601829849684,
           37.79894831080553,
           37.63929479176133,
           37.47964127271713,
           37.31998775367295,
           37.16033423462876,
           37.000680715584565,
           36.841027196540395,
           36.68137367749621,
           36.52172015845201,
           36.36206663940782,
           36.202413120363644,
           36.042759601319446,
           35.88310608227525,
           35.72345256323107,
           35.56379904418689,
           35.40414552514268,
           35.24449200609851,
           35.08483848705433,
           34.92518496801013,
           34.765531448965945,
           34.60587792992176,
           34.44622441087756,
           34.28657089183337,
           34.1269173727892,
           33.96726385374501,
           33.80761033470081,
           33.64795681565663,
           33.48830329661244,
           33.328649777568245,
           33.16899625852407,
           33.00934273947989,
           32.84968922043569,
           32.69003570139151,
           32.530382182347324,
           32.370728663303126,
           32.21107514425893,
           32.05142162521474,
           31.891768106170574,
           31.732114587126375,
           31.57246106808219,
           31.412807549038007,
           31.25315402999381,
           31.089002076548816,
           30.914815217299807,
           30.740628358050785,
           30.56644149880176,
           30.392254639552768,
           30.21806778030375,
           30.04388092105473,
           29.869694061805717,
           29.695507202556712,
           29.52132034330769,
           29.347133484058677,
           29.172946624809672,
           28.99875976556065,
           28.824572906311644,
           28.650386047062632,
           28.476199187813613,
           28.302012328564594,
           28.1278254693156,
           27.953638610066577,
           27.779451750817557,
           27.60526489156855,
           27.43107803231954,
           27.256891173070517,
           27.08270431382151,
           26.9085174545725,
           26.73433059532348,
           26.56014373607446,
           26.385956876825464,
           26.21177001757644,
           26.037583158327422,
           25.863396299078413,
           25.689209439829405,
           25.515022580580382,
           25.32281249267558,
           25.040486261491683,
           24.75816003030779,
           24.47583379912389,
           24.193507567940046,
           23.91118133675615,
           23.628855105572256,
           23.346528874388405,
           23.064202643204514,
           22.781876412020615,
           22.499550180836767,
           22.217223949652873,
           21.934897718468974,
           21.65257148728508,
           21.370245256101235,
           21.087919024917337,
           20.80559279373344,
           20.523266562549598,
           20.2409403313657,
           19.9586141001818,
           19.676287868997957,
           19.39396163781406,
           19.111635406630164,
           18.82930917544632,
           18.54698294426242,
           18.26465671307853,
           17.98233048189463,
           17.700004250710784,
           17.41767801952689,
           17.13535178834299,
           16.853025557159146,
           16.570699325975248,
           16.288373094791353,
           16.00604686360751,
           15.72372063242361,
           15.441394401239714,
           15.159068170055818,
           14.876741938871973,
           14.594415707688075,
           14.312089476504179,
           14.030157981440102,
           13.751367708850578,
           13.536493402127205,
           13.367008785496058,
           13.19298113719918,
           13.018953488902305,
           12.84492584060546,
           12.670898192308584,
           12.496870544011706,
           12.32284289571483,
           12.148815247417986,
           11.97478759912111,
           11.800759950824233,
           11.626732302527387,
           11.45270465423051,
           11.278677005933636,
           11.104649357636792,
           10.930621709339912,
           10.756594061043039,
           10.582566412746162,
           10.408538764449318,
           10.23451111615244,
           10.060483467855562,
           9.88645581955872,
           9.712428171261843,
           9.538400522964965,
           9.36437287466812,
           9.190345226371246,
           9.016317578074368,
           8.842289929777522,
           8.668262281480647,
           8.49423463318377,
           8.320206984886894,
           8.146179336590048,
           7.972151688293172,
           7.798124039996296,
           7.62409639169945,
           7.450068743402575,
           7.276041095105699,
           7.102013446808854,
           6.927985798511977,
           6.7539581502151,
           6.579930501918224,
           6.405902853621379
          ],
          [
           27.84216039864434,
           27.875523480412827,
           27.90888656218131,
           27.942249643949793,
           27.975612725718282,
           28.00897580748677,
           28.042338889255255,
           28.07570197102374,
           28.109065052792225,
           28.14242813456071,
           28.175791216329195,
           28.20915429809768,
           28.242517379866165,
           28.27588046163465,
           28.309243543403138,
           28.342606625171623,
           28.375969706940108,
           28.409332788708593,
           28.442695870477078,
           28.476058952245566,
           28.50942203401405,
           28.542785115782536,
           28.576148197551017,
           28.609511279319506,
           28.64287436108799,
           28.676237442856475,
           28.70960052462496,
           28.742963606393445,
           28.776326688161934,
           28.809689769930415,
           28.843052851698907,
           28.87641593346739,
           28.909779015235873,
           28.94314209700436,
           28.976505178772843,
           29.00986826054133,
           29.043231342309813,
           29.076594424078305,
           29.109957505846786,
           29.143320587615275,
           29.176683669383756,
           29.21004675115224,
           29.24340983292073,
           29.276772914689214,
           29.3101359964577,
           29.34270295399434,
           29.37367766250187,
           29.404652371009398,
           29.435627079516927,
           29.466601788024455,
           29.497576496531984,
           29.528551205039513,
           29.55952591354704,
           29.59050062205457,
           29.62147533056209,
           29.65245003906962,
           29.68342474757715,
           29.714399456084678,
           29.74537416459221,
           29.776348873099735,
           29.807323581607267,
           29.838298290114793,
           29.869272998622325,
           29.90024770712985,
           29.93122241563738,
           29.962197124144907,
           29.993171832652433,
           30.02414654115996,
           30.05512124966749,
           30.08609595817502,
           30.117070666682547,
           30.148045375190073,
           30.1790200836976,
           30.20999479220513,
           30.24096950071266,
           30.271944209220187,
           30.302918917727716,
           30.333893626235245,
           30.364868334742773,
           30.395843043250302,
           30.42681775175783,
           30.457792460265356,
           30.488767168772885,
           30.519741877280413,
           30.549921942338013,
           30.57994307870564,
           30.60996421507326,
           30.639985351440878,
           30.6700064878085,
           30.700027624176116,
           30.73004876054374,
           30.76006989691136,
           30.79009103327898,
           30.820112169646602,
           30.850133306014218,
           30.88015444238184,
           30.91017557874946,
           30.940196715117082,
           30.9702178514847,
           31.00023898785232,
           31.030260124219943,
           31.06028126058756,
           31.09030239695518,
           31.120323533322804,
           31.15034466969042,
           31.18036580605804,
           31.210386942425664,
           31.24040807879328,
           31.270429215160906,
           31.30045035152852,
           31.33047148789614,
           31.360492624263763,
           31.390513760631386,
           31.420534896999,
           31.450556033366624,
           31.480577169734246,
           31.510598306101862,
           31.540619442469485,
           31.570640578837107,
           31.600661715204723,
           31.630682851572345,
           31.660703987939968,
           31.69141690341343,
           31.723513376607276,
           31.755609849801125,
           31.787706322994964,
           31.819802796188817,
           31.851899269382663,
           31.88399574257651,
           31.916092215770355,
           31.9481886889642,
           31.980285162158047,
           32.01238163535189,
           32.04447810854574,
           32.076574581739585,
           32.10867105493343,
           32.140767528127284,
           32.17286400132113,
           32.20496047451498,
           32.23705694770882,
           32.26915342090267,
           32.301249894096514,
           32.33334636729036,
           32.36544284048421,
           32.39753931367805,
           32.4296357868719,
           32.461732260065745,
           32.49382873325959,
           32.52592520645344,
           32.55802167964728,
           32.59011815284113,
           32.622214626034975,
           32.65431109922882,
           32.68640757242267,
           32.71850404561652,
           32.75060051881036,
           32.782696992004205,
           32.81479346519806,
           32.846889938391904,
           32.87898641158574,
           32.91108288477959,
           32.943179357973435,
           32.97527583116728,
           33.00737230436113,
           33.03946877755497,
           33.07156525074882,
           33.103661723942665,
           33.137986790708965,
           33.17342615426148,
           33.20886551781399,
           33.2443048813665,
           33.279744244919016,
           33.315183608471536,
           33.35062297202405,
           33.38606233557656,
           33.42150169912908,
           33.456941062681594,
           33.49238042623411,
           33.52781978978662,
           33.56325915333913,
           33.598698516891645,
           33.634137880444165,
           33.66957724399668,
           33.70501660754919,
           33.74045597110171,
           33.77589533465422,
           33.811334698206736,
           33.84677406175924,
           33.88221342531176,
           33.917652788864274,
           33.95309215241679,
           33.988531515969306,
           34.02397087952182,
           34.05941024307433,
           34.094849606626845,
           34.130288970179365,
           34.16572833373188,
           34.20116769728439,
           34.2366070608369,
           34.272046424389416,
           34.30748578794193,
           34.34292515149445,
           34.378364515046954,
           34.41380387859948,
           34.449243242151994,
           34.4846826057045,
           34.52012196925702,
           34.55556133280953,
           34.591000696362045,
           34.62644005991456,
           34.66187942346707,
           34.69731878701958,
           34.7327581505721,
           34.76819751412462,
           34.803636877677135,
           34.83907624122965,
           34.87451560478216,
           34.909954968334674,
           34.94539433188719,
           34.9808336954397,
           35.01627305899222,
           35.05171242254473,
           35.08715178609724,
           35.12259114964976,
           35.15803051320228,
           35.19346987675479,
           35.2289092403073,
           35.264348603859816,
           35.29978796741233,
           35.33522733096484,
           35.37066669451736,
           35.406106058069874,
           35.441545421622386,
           35.47636867051692,
           35.51021640102766,
           35.5440641315384,
           35.57791186204914,
           35.61175959255988,
           35.64560732307062,
           35.679455053581364,
           35.7133027840921,
           35.74715051460284,
           35.78099824511358,
           35.814845975624316,
           35.848693706135066,
           35.8825414366458,
           35.916389167156545,
           35.95023689766728,
           35.984084628178024,
           36.01793235868876,
           36.056996177317274,
           36.10127608406356,
           36.14555599080983,
           36.189835897556115,
           36.2341158043024,
           36.278395711048674,
           36.32267561779496,
           36.36695552454124,
           36.41123543128752,
           36.4555153380338,
           36.49979524478008,
           36.544075151526364,
           36.58835505827264,
           36.632634965018916,
           36.6769148717652,
           36.72119477851148,
           36.76547468525776,
           36.80975459200404,
           36.85403449875032,
           36.898314405496606,
           36.94259431224289,
           36.98687421898917,
           37.03115412573545,
           37.07543403248172,
           37.11971393922801,
           37.16399384597428,
           37.208273752720565,
           37.252553659466855,
           37.296833566213124,
           37.34111347295941,
           37.38539337970568,
           37.42967328645197,
           37.47395319319825,
           37.51823309994453,
           37.56251300669081,
           37.60679291343709,
           37.651072820183366,
           37.69535272692965,
           37.73963263367593,
           37.78391254042221,
           37.8281924471685,
           37.872472353914766,
           37.91675226066105,
           37.96103216740733,
           38.005312074153615,
           38.04959198089989,
           38.093871887646166,
           38.13815179439245,
           38.18243170113873,
           38.22671160788501,
           38.27099151463129,
           38.315271421377574,
           38.35955132812385,
           38.40383123487014,
           38.44811114161642,
           38.49239104836269,
           38.536670955108974,
           38.58095086185526,
           38.62523076860154,
           38.669510675347816,
           38.7137905820941,
           38.75807048884038,
           38.80235039558666,
           38.84663030233294,
           38.89091020907922,
           38.9351901158255,
           38.97947002257178,
           39.023749929318065,
           39.06802983606433,
           39.112309742810616,
           39.1565896495569,
           39.200869556303175,
           39.245149463049465,
           39.28942936979575,
           39.333709276542024,
           39.378172065874864,
           39.422708011535136,
           39.467243957195414,
           39.51177990285568,
           39.55631584851595,
           39.60085179417623,
           39.6453877398365,
           39.68992368549677,
           39.65745218845668,
           39.47096580601592,
           39.284479423575156,
           39.09799304113438,
           38.911506658693625,
           38.730486805416874,
           38.55629994616785,
           38.38211308691882,
           38.20792622766983,
           38.03373936842081,
           37.859552509171785,
           37.68536564992278,
           37.511178790673775,
           37.33699193142475,
           37.16280507217574,
           36.98861821292673,
           36.81443135367771,
           36.64024449442871,
           36.4660576351797,
           36.291870775930676,
           36.11768391668165,
           35.94349705743265,
           35.76931019818364,
           35.59512333893461,
           35.42093647968561,
           35.246749620436596,
           35.072562761187584,
           34.89837590193857,
           34.72418904268957,
           34.55000218344054,
           34.37581532419152,
           34.20162846494253,
           34.02744160569351,
           33.85325474644448,
           33.67906788719548,
           33.50488102794647,
           33.33069416869745,
           33.15650730944844,
           32.982320450199424,
           32.808133590950405,
           32.6339467317014,
           32.459759872452395,
           32.28557301320337,
           32.11138615395435,
           31.937199294705337,
           31.763012435456336,
           31.588825576207313,
           31.414638716958308,
           31.240451857709296,
           31.066264998460273,
           30.89207813921127,
           30.71789127996226,
           30.543704420713237,
           30.369517561464214,
           30.195330702215223,
           30.021143842966197,
           29.846956983717178,
           29.672770124468173,
           29.498583265219168,
           29.324396405970138,
           29.150209546721133,
           28.976022687472128,
           28.801835828223105,
           28.6276489689741,
           28.453462109725088,
           28.27927525047607,
           28.105088391227046,
           27.930901531978055,
           27.756714672729032,
           27.582527813480013,
           27.408340954230994,
           27.234154094981996,
           27.059967235732966,
           26.885780376483964,
           26.71159351723496,
           26.537406657985933,
           26.363219798736907,
           26.189032939487916,
           26.0148460802389,
           25.840659220989874,
           25.66647236174087,
           25.49228550249186,
           25.318098643242838,
           25.125888555338033,
           24.843562324154135,
           24.56123609297024,
           24.278909861786342,
           23.996583630602498,
           23.7142573994186,
           23.43193116823471,
           23.14960493705086,
           22.867278705866966,
           22.584952474683064,
           22.302626243499223,
           22.020300012315328,
           21.737973781131426,
           21.455647549947532,
           21.17332131876369,
           20.890995087579793,
           20.608668856395894,
           20.32634262521205,
           20.044016394028155,
           19.761690162844253,
           19.47936393166041,
           19.197037700476514,
           18.91475594363123,
           18.635965671041763,
           18.357175398452235,
           18.078385125862717,
           17.79959485327319,
           17.52080458068372,
           17.2420143080942,
           16.963224035504673,
           16.684433762915205,
           16.40564349032568,
           16.12685321773616,
           15.848062945146687,
           15.569272672557164,
           15.29048239996764,
           15.011692127378119,
           14.732901854788647,
           14.454111582199126,
           14.175321309609602,
           13.89653103702013,
           13.617740764430607,
           13.402866457707233,
           13.23364641231684,
           13.064426366926414,
           12.89520632153599,
           12.725986276145598,
           12.556766230755173,
           12.387546185364744,
           12.218326139974321,
           12.049106094583927,
           11.879886049193502,
           11.710666003803077,
           11.54144595841268,
           11.372225913022255,
           11.20300586763183,
           11.033785822241436,
           10.864565776851013,
           10.695345731460586,
           10.526125686070161,
           10.356905640679766,
           10.186944796877894,
           10.012917148581016,
           9.838889500284171,
           9.664861851987297,
           9.49083420369042,
           9.316806555393574,
           9.142778907096698,
           8.968751258799822,
           8.794723610502977,
           8.6206959622061,
           8.446668313909225,
           8.272640665612348,
           8.098613017315504,
           7.924585369018625,
           7.7505577207217495,
           7.576530072424905,
           7.402502424128029,
           7.228474775831151,
           7.054447127534306,
           6.880419479237432,
           6.706391830940553,
           6.532364182643677,
           6.358336534346833
          ],
          [
           28.28279882191354,
           28.316161903682026,
           28.34952498545051,
           28.382888067218996,
           28.416251148987484,
           28.44961423075597,
           28.48297731252445,
           28.51634039429294,
           28.549703476061428,
           28.583066557829913,
           28.616429639598397,
           28.64979272136688,
           28.683155803135364,
           28.716518884903852,
           28.749881966672337,
           28.783245048440826,
           28.81660813020931,
           28.849971211977795,
           28.88333429374628,
           28.916697375514765,
           28.95006045728325,
           28.983423539051735,
           29.01678662082022,
           29.050149702588705,
           29.083512784357193,
           29.116875866125675,
           29.150238947894163,
           29.183602029662648,
           29.216965111431133,
           29.25032819319962,
           29.283691274968106,
           29.31705435673659,
           29.350417438505076,
           29.38378052027356,
           29.417143602042046,
           29.45050668381053,
           29.483869765579016,
           29.517232847347504,
           29.55059592911599,
           29.583959010884474,
           29.61732209265296,
           29.650685174421444,
           29.68404825618993,
           29.717411337958413,
           29.7507744197269,
           29.784137501495383,
           29.81750058326387,
           29.850863665032357,
           29.884226746800838,
           29.917589828569326,
           29.95095291033781,
           29.984315992106296,
           30.01767907387478,
           30.05104215564327,
           30.084405237411755,
           30.11776831918024,
           30.151131400948724,
           30.184494482717213,
           30.217857564485694,
           30.251220646254183,
           30.284583728022668,
           30.317946809791152,
           30.349319579395132,
           30.380294287902657,
           30.411268996410186,
           30.442243704917715,
           30.473218413425244,
           30.504193121932772,
           30.535167830440297,
           30.566142538947826,
           30.597117247455355,
           30.628091955962883,
           30.659066664470412,
           30.690041372977937,
           30.721016081485473,
           30.751990789992995,
           30.782965498500527,
           30.813940207008056,
           30.844914915515584,
           30.87588962402311,
           30.906864332530642,
           30.937839041038167,
           30.968813749545696,
           30.999788458053224,
           31.029968523110824,
           31.05998965947845,
           31.09001079584607,
           31.120031932213685,
           31.15005306858131,
           31.180074204948927,
           31.210095341316546,
           31.24011647768417,
           31.270137614051787,
           31.300158750419413,
           31.33017988678703,
           31.360201023154648,
           31.39022215952227,
           31.42024329588989,
           31.45026443225751,
           31.48028556862513,
           31.51030670499275,
           31.540327841360373,
           31.570348977727992,
           31.60037011409561,
           31.630391250463234,
           31.660412386830853,
           31.692162969585922,
           31.72425944277977,
           31.756355915973614,
           31.78845238916746,
           31.820548862361306,
           31.852645335555152,
           31.884741808749,
           31.91683828194285,
           31.948934755136698,
           31.981031228330544,
           32.01312770152438,
           32.04522417471823,
           32.077320647912074,
           32.10941712110592,
           32.141513594299774,
           32.17361006749362,
           32.205706540687466,
           32.23780301388131,
           32.26989948707516,
           32.301995960269004,
           32.33409243346285,
           32.366188906656696,
           32.398285379850535,
           32.430381853044395,
           32.462478326238234,
           32.49457479943209,
           32.526671272625926,
           32.55876774581977,
           32.59086421901362,
           32.622960692207464,
           32.65505716540131,
           32.68715363859516,
           32.71925011178901,
           32.751346584982855,
           32.7834430581767,
           32.81553953137055,
           32.84763600456439,
           32.87973247775824,
           32.911828950952085,
           32.94392542414593,
           32.97602189733978,
           33.00811837053362,
           33.04021484372747,
           33.072311316921315,
           33.10440779011516,
           33.13650426330901,
           33.16860073650285,
           33.2006972096967,
           33.232793682890545,
           33.26489015608439,
           33.29698662927824,
           33.32908310247208,
           33.36117957566593,
           33.393276048859775,
           33.42537252205362,
           33.45746899524747,
           33.48956546844132,
           33.52166194163516,
           33.55375841482901,
           33.58585488802286,
           33.617951361216704,
           33.652276427983,
           33.68771579153551,
           33.72315515508802,
           33.758594518640535,
           33.79403388219305,
           33.82947324574557,
           33.864912609298074,
           33.90035197285059,
           33.935791336403106,
           33.97123069995562,
           34.00667006350814,
           34.04210942706065,
           34.077548790613164,
           34.11298815416568,
           34.14842751771819,
           34.18386688127071,
           34.21930624482322,
           34.254745608375735,
           34.290184971928255,
           34.32562433548077,
           34.361063699033274,
           34.39650306258579,
           34.431942426138306,
           34.46738178969082,
           34.50282115324334,
           34.538260516795845,
           34.573699880348364,
           34.60913924390088,
           34.6445786074534,
           34.68001797100591,
           34.71545733455842,
           34.750896698110935,
           34.78633606166345,
           34.82177542521596,
           34.85721478876848,
           34.89265415232099,
           34.928093515873506,
           34.96353287942602,
           34.99897224297853,
           35.03441160653105,
           35.069850970083564,
           35.10529033363608,
           35.14072969718859,
           35.17616906074111,
           35.211608424293615,
           35.247047787846135,
           35.28248715139865,
           35.31792651495117,
           35.35336587850367,
           35.38880524205619,
           35.4242446056087,
           35.459683969161226,
           35.49512333271373,
           35.53056269626625,
           35.56600205981876,
           35.60144142337128,
           35.63688078692379,
           35.67232015047631,
           35.707759514028815,
           35.743198877581335,
           35.77863824113384,
           35.81407760468636,
           35.84951696823887,
           35.88495633179139,
           35.9203956953439,
           35.95583505889642,
           35.99127442244893,
           36.02681765357795,
           36.062776354704496,
           36.09873505583104,
           36.13469375695759,
           36.17065245808413,
           36.206611159210674,
           36.24256986033722,
           36.27852856146376,
           36.314487262590305,
           36.35044596371686,
           36.3864046648434,
           36.422363365969936,
           36.45832206709648,
           36.49428076822303,
           36.53023946934957,
           36.56619817047612,
           36.60698379851269,
           36.65259635345927,
           36.69820890840586,
           36.74382146335243,
           36.78943401829903,
           36.83504657324561,
           36.8806591281922,
           36.926271683138786,
           36.97188423808537,
           37.01749679303195,
           37.06310934797854,
           37.108721902925126,
           37.15342840159795,
           37.19796434725823,
           37.2425002929185,
           37.28703623857877,
           37.33157218423904,
           37.376108129899315,
           37.42064407555959,
           37.46518002121986,
           37.50971596688014,
           37.55425191254041,
           37.59878785820068,
           37.64332380386095,
           37.68785974952123,
           37.732395695181495,
           37.77693164084177,
           37.82146758650204,
           37.86600353216232,
           37.91053947782258,
           37.95507542348287,
           37.99961136914314,
           38.04414731480341,
           38.08868326046368,
           38.133219206123954,
           38.177755151784226,
           38.2222910974445,
           38.26682704310477,
           38.31136298876505,
           38.35589893442531,
           38.40043488008559,
           38.44497082574586,
           38.489506771406134,
           38.534042717066406,
           38.578578662726684,
           38.623114608386956,
           38.66765055404723,
           38.7121864997075,
           38.75672244536777,
           38.80125839102804,
           38.845794336688314,
           38.890330282348586,
           38.93486622800886,
           38.979402173669136,
           39.023938119329415,
           39.06847406498967,
           39.11301001064995,
           39.15754595631023,
           39.2020819019705,
           39.246617847630766,
           39.291153793291045,
           39.33568973895132,
           39.38022568461159,
           39.42476163027186,
           39.46929757593213,
           39.5138335215924,
           39.558369467252675,
           39.60290541291295,
           39.64744135857322,
           39.69197730423349,
           39.736513249893775,
           39.78104919555405,
           39.82558514121432,
           39.87012108687459,
           39.91465703253486,
           39.959192978195134,
           40.003728923855405,
           40.04826486951568,
           40.09280081517595,
           40.13733676083623,
           40.1818727064965,
           40.22640865215677,
           40.27094459781705,
           40.23847310077694,
           40.05198671833619,
           39.865500335895426,
           39.67901395345465,
           39.492527571013895,
           39.30604118857313,
           39.119554806132356,
           38.93306842369158,
           38.74658204125083,
           38.560095658810056,
           38.37360927636928,
           38.187122893928525,
           38.00063651148776,
           37.81415012904699,
           37.62766374660623,
           37.44117736416547,
           37.25469098172469,
           37.06820459928393,
           36.881718216843176,
           36.695231834402406,
           36.50874545196162,
           36.32225906952087,
           36.135772687080106,
           35.94928630463933,
           35.76279992219857,
           35.576313539757805,
           35.38982715731703,
           35.20334077487627,
           35.01685439243551,
           34.83036800999473,
           34.64388162755396,
           34.45739524511322,
           34.27090886267244,
           34.084422480231666,
           33.897936097790904,
           33.71144971535015,
           33.52496333290937,
           33.33847695046861,
           33.15199056802785,
           32.96550418558707,
           32.77901780314632,
           32.592531420705555,
           32.40604503826478,
           32.219558655824,
           32.03307227338324,
           31.846585890942478,
           31.66009950850171,
           31.47361312606094,
           31.287126743620185,
           31.10064036117941,
           30.91415397873865,
           30.72766759629789,
           30.541181213857115,
           30.354694831416335,
           30.168208448975594,
           29.98172206653482,
           29.795235684094038,
           29.608749301653283,
           29.422262919212525,
           29.235776536771745,
           29.049290154330983,
           28.862803771890228,
           28.67631738944945,
           28.48983100700869,
           28.30334462456793,
           28.116858242127154,
           27.930371859686378,
           27.743885477245637,
           27.559790735391488,
           27.385603876142465,
           27.21141701689346,
           27.03723015764445,
           26.86304329839543,
           26.68885643914642,
           26.514669579897415,
           26.34048272064839,
           26.166295861399373,
           25.99210900215038,
           25.817922142901356,
           25.643735283652333,
           25.469548424403325,
           25.29536156515432,
           25.121174705905293,
           24.928964618000496,
           24.646638386816594,
           24.364312155632696,
           24.0819859244488,
           23.799659693264957,
           23.520563633232896,
           23.24177336064337,
           22.9629830880539,
           22.684192815464375,
           22.405402542874853,
           22.12661227028538,
           21.84782199769586,
           21.56903172510634,
           21.290241452516817,
           21.011451179927345,
           20.73266090733782,
           20.4538706347483,
           20.175080362158827,
           19.896290089569305,
           19.61749981697978,
           19.33870954439031,
           19.059919271800787,
           18.781128999211262,
           18.502338726621794,
           18.22354845403227,
           17.944758181442747,
           17.665967908853222,
           17.38717763626375,
           17.108387363674233,
           16.829597091084707,
           16.550806818495236,
           16.27201654590571,
           15.993226273316191,
           15.714436000726721,
           15.435645728137196,
           15.156855455547673,
           14.87806518295815,
           14.59927491036868,
           14.320484637779154,
           14.041694365189633,
           13.762904092600163,
           13.484113820010638,
           13.269239513287266,
           13.100019467896871,
           12.930799422506446,
           12.761579377116021,
           12.592359331725628,
           12.423139286335203,
           12.253919240944777,
           12.084699195554354,
           11.915479150163957,
           11.746259104773532,
           11.577039059383106,
           11.407819013992711,
           11.238598968602288,
           11.06937892321186,
           10.900158877821468,
           10.730938832431043,
           10.561718787040617,
           10.392498741650192,
           10.223278696259799,
           10.054058650869372,
           9.884838605478947,
           9.715618560088553,
           9.546398514698126,
           9.377178469307703,
           9.207958423917308,
           9.038738378526883,
           8.869518333136456,
           8.700298287746062,
           8.531078242355637,
           8.361858196965212,
           8.192638151574787,
           8.023418106184392,
           7.8541980607939665,
           7.6849780154035425,
           7.515757970013148,
           7.346537924622723,
           7.177317879232297,
           7.006880808259763,
           6.832853159962886,
           6.658825511666008,
           6.484797863369133,
           6.310770215072289
          ],
          [
           28.72343724518275,
           28.756800326951236,
           28.790163408719717,
           28.823526490488202,
           28.85688957225669,
           28.89025265402518,
           28.92361573579366,
           28.956978817562145,
           28.990341899330634,
           29.02370498109912,
           29.057068062867604,
           29.09043114463609,
           29.123794226404573,
           29.157157308173062,
           29.190520389941547,
           29.22388347171003,
           29.257246553478517,
           29.290609635247,
           29.323972717015486,
           29.357335798783975,
           29.390698880552456,
           29.42406196232094,
           29.457425044089426,
           29.490788125857915,
           29.524151207626396,
           29.55751428939488,
           29.590877371163373,
           29.624240452931858,
           29.657603534700343,
           29.690966616468828,
           29.724329698237312,
           29.757692780005797,
           29.791055861774282,
           29.824418943542767,
           29.857782025311252,
           29.891145107079737,
           29.924508188848225,
           29.95787127061671,
           29.9912343523852,
           30.024597434153684,
           30.05796051592217,
           30.09132359769065,
           30.12468667945914,
           30.158049761227623,
           30.191412842996105,
           30.224775924764593,
           30.258139006533078,
           30.291502088301563,
           30.324865170070048,
           30.358228251838533,
           30.39159133360702,
           30.424954415375502,
           30.45831749714399,
           30.491680578912476,
           30.525043660680964,
           30.558406742449446,
           30.591769824217934,
           30.62513290598642,
           30.658495987754904,
           30.69185906952339,
           30.725222151291874,
           30.758585233060362,
           30.791948314828844,
           30.82531139659733,
           30.858674478365817,
           30.8920375601343,
           30.925400641902783,
           30.95876372367127,
           30.992126805439753,
           31.025489887208245,
           31.058852968976726,
           31.092216050745208,
           31.1255791325137,
           31.15894221428218,
           31.19230529605067,
           31.225668377819158,
           31.259031459587643,
           31.292394541356124,
           31.324961496288402,
           31.35593620479593,
           31.38691091330346,
           31.417885621810985,
           31.448860330318514,
           31.479835038826042,
           31.510015103883646,
           31.54003624025127,
           31.570057376618887,
           31.600078512986506,
           31.63009964935413,
           31.660812562564576,
           31.692909035758422,
           31.72500550895227,
           31.757101982146114,
           31.789198455339964,
           31.821294928533803,
           31.853391401727652,
           31.8854878749215,
           31.917584348115344,
           31.94968082130919,
           31.981777294503036,
           32.01387376769688,
           32.045970240890725,
           32.07806671408458,
           32.110163187278424,
           32.14225966047227,
           32.174356133666116,
           32.20645260685996,
           32.23854908005381,
           32.27064555324766,
           32.30274202644151,
           32.33483849963535,
           32.3669349728292,
           32.399031446023045,
           32.43112791921689,
           32.46322439241074,
           32.49532086560458,
           32.52741733879843,
           32.559513811992275,
           32.59161028518612,
           32.62370675837997,
           32.65580323157381,
           32.68789970476766,
           32.719996177961505,
           32.75209265115535,
           32.7841891243492,
           32.816285597543036,
           32.84838207073689,
           32.880478543930735,
           32.91257501712459,
           32.94467149031843,
           32.97676796351227,
           33.00886443670612,
           33.040960909899965,
           33.07305738309381,
           33.10515385628766,
           33.1372503294815,
           33.16934680267535,
           33.201443275869195,
           33.23353974906304,
           33.26563622225689,
           33.29773269545073,
           33.32982916864458,
           33.361925641838425,
           33.39402211503227,
           33.426118588226124,
           33.45821506141997,
           33.49031153461382,
           33.52240800780766,
           33.55450448100151,
           33.586600954195355,
           33.6186974273892,
           33.65079390058305,
           33.68289037377689,
           33.71498684697074,
           33.747083320164585,
           33.77917979335843,
           33.81127626655228,
           33.84337273974613,
           33.87546921293997,
           33.90756568613382,
           33.93966215932767,
           33.971758632521514,
           34.00385510571536,
           34.035951578909206,
           34.06804805210305,
           34.1001445252969,
           34.132240998490744,
           34.16656606525704,
           34.20200542880955,
           34.23744479236206,
           34.27288415591458,
           34.30832351946709,
           34.34376288301961,
           34.37920224657211,
           34.41464161012464,
           34.450080973677146,
           34.485520337229666,
           34.520959700782186,
           34.55639906433469,
           34.591838427887204,
           34.627277791439724,
           34.66271715499223,
           34.69815651854475,
           34.73359588209727,
           34.769450714299104,
           34.80540941542564,
           34.8413681165522,
           34.87732681767874,
           34.91328551880529,
           34.94924421993183,
           34.985202921058374,
           35.02116162218492,
           35.05712032331146,
           35.093079024438005,
           35.129037725564544,
           35.16499642669109,
           35.200955127817636,
           35.23691382894418,
           35.27287253007073,
           35.308831231197274,
           35.34478993232382,
           35.38074863345037,
           35.41670733457691,
           35.45266603570345,
           35.48862473682999,
           35.52458343795654,
           35.56054213908308,
           35.59650084020963,
           35.632459541336175,
           35.66841824246272,
           35.70437694358927,
           35.74033564471581,
           35.77629434584235,
           35.81225304696889,
           35.84821174809544,
           35.88417044922198,
           35.92012915034853,
           35.956087851475075,
           35.992046552601614,
           36.02800525372817,
           36.06396395485471,
           36.09992265598125,
           36.13588135710779,
           36.17184005823434,
           36.207798759360884,
           36.24375746048743,
           36.279716161613976,
           36.31567486274052,
           36.35163356386706,
           36.38759226499361,
           36.42355096612015,
           36.45950966724669,
           36.49546836837324,
           36.531427069499784,
           36.56738577062633,
           36.60334447175288,
           36.63930317287942,
           36.67526187400596,
           36.71122057513251,
           36.747179276259054,
           36.7831379773856,
           36.81909667851214,
           36.85505537963869,
           36.89101408076523,
           36.92697278189177,
           36.96293148301832,
           36.99889018414487,
           37.03484888527141,
           37.070807586397954,
           37.1067662875245,
           37.14755191556107,
           37.193164470507654,
           37.23877702545423,
           37.28438958040082,
           37.33000213534741,
           37.375614690293986,
           37.42122724524057,
           37.46683980018716,
           37.51245235513375,
           37.55806491008033,
           37.60367746502692,
           37.649290019973506,
           37.694902574920086,
           37.74051512986667,
           37.786127684813266,
           37.831740239759846,
           37.87735279470643,
           37.92296534965301,
           37.9685779045996,
           38.014190459546185,
           38.05980301449277,
           38.10541556943936,
           38.151028124385945,
           38.19664067933253,
           38.24225323427912,
           38.2878657892257,
           38.333478344172285,
           38.37909089911887,
           38.42470345406545,
           38.47031600901204,
           38.515928563958624,
           38.56154111890521,
           38.60715367385179,
           38.652766228798384,
           38.69837878374497,
           38.74399133869156,
           38.78960389363813,
           38.835216448584724,
           38.880829003531304,
           38.92644155847789,
           38.97205411342448,
           39.017666668371064,
           39.06327922331764,
           39.10889177826424,
           39.154504333210824,
           39.2001168881574,
           39.24572944310399,
           39.29134199805058,
           39.336954552997156,
           39.38227930334832,
           39.4268152490086,
           39.47135119466887,
           39.51588714032914,
           39.56042308598941,
           39.604959031649685,
           39.649494977309956,
           39.69403092297023,
           39.73856686863051,
           39.783102814290785,
           39.82763875995105,
           39.87217470561133,
           39.91671065127159,
           39.96124659693187,
           40.005782542592144,
           40.05031848825241,
           40.09485443391269,
           40.13939037957295,
           40.18392632523323,
           40.2284622708935,
           40.27299821655377,
           40.31753416221406,
           40.362070107874324,
           40.406606053534595,
           40.45114199919487,
           40.49567794485513,
           40.54021389051542,
           40.58474983617568,
           40.62928578183596,
           40.67382172749623,
           40.718357673156504,
           40.76289361881678,
           40.80742956447705,
           40.851965510137326,
           40.81949401309723,
           40.633007630656465,
           40.4465212482157,
           40.26003486577493,
           40.07354848333417,
           39.88706210089341,
           39.70057571845263,
           39.51408933601186,
           39.327602953571116,
           39.14111657113034,
           38.95463018868956,
           38.7681438062488,
           38.581657423808046,
           38.39517104136727,
           38.20868465892651,
           38.02219827648575,
           37.83571189404498,
           37.649225511604214,
           37.46273912916345,
           37.27625274672268,
           37.0897663642819,
           36.90327998184114,
           36.71679359940038,
           36.530307216959606,
           36.34382083451885,
           36.15733445207809,
           35.97084806963731,
           35.78436168719655,
           35.597875304755796,
           35.41138892231501,
           35.224902539874236,
           35.0384161574335,
           34.85192977499272,
           34.66544339255194,
           34.47895701011119,
           34.292470627670426,
           34.10598424522965,
           33.91949786278889,
           33.73301148034813,
           33.546525097907356,
           33.360038715466594,
           33.17355233302583,
           32.987065950585055,
           32.80057956814428,
           32.61409318570352,
           32.42382164900813,
           32.22135345003103,
           32.01888525105395,
           31.816417052076865,
           31.613948853099764,
           31.411480654122684,
           31.209012455145597,
           31.006544256168496,
           30.804076057191395,
           30.60160785821433,
           30.39913965923723,
           30.196671460260127,
           29.994203261283044,
           29.79173506230596,
           29.58926686332886,
           29.386798664351772,
           29.184330465374693,
           28.98186226639759,
           28.77939406742051,
           28.576925868443425,
           28.374457669466324,
           28.17198947048922,
           27.969521271512157,
           27.767053072535056,
           27.564584873557955,
           27.362116674580875,
           27.15964847560379,
           26.957180276626683,
           26.754712077649607,
           26.552243878672524,
           26.34977567969542,
           26.147307480718318,
           25.944839281741253,
           25.742371082764148,
           25.539902883787054,
           25.337434684809967,
           25.134966485832884,
           24.93249828685578,
           24.717456236091834,
           24.439544926393452,
           24.161633616695077,
           23.883722306996695,
           23.605810997298367,
           23.32789968759998,
           23.049988377901602,
           22.772077068203274,
           22.49416575850489,
           22.216254448806513,
           21.93834313910818,
           21.660431829409802,
           21.38252051971142,
           21.104609210013038,
           20.826697900314713,
           20.548786590616327,
           20.27087528091795,
           19.992963971219616,
           19.715052661521238,
           19.43714135182286,
           19.159230042124527,
           18.881318732426145,
           18.603407422727766,
           18.325496113029434,
           18.047584803331056,
           17.769673493632673,
           17.49176218393429,
           17.213850874235966,
           16.935939564537584,
           16.658028254839202,
           16.38011694514087,
           16.10220563544249,
           15.824294325744109,
           15.54638301604578,
           15.2684717063474,
           14.99056039664902,
           14.713466515839666,
           14.440246572292912,
           14.167026628746113,
           13.893806685199309,
           13.620586741652556,
           13.347366798105751,
           13.138442283353015,
           12.975443074881765,
           12.812443866410486,
           12.649444657939206,
           12.486445449467956,
           12.323446240996676,
           12.155201295094296,
           11.986916312345322,
           11.818631329596382,
           11.650346346847408,
           11.482061364098437,
           11.313776381349495,
           11.145491398600521,
           10.97720641585155,
           10.808921433102608,
           10.640636450353634,
           10.472351467604662,
           10.304066484855689,
           10.135781502106749,
           9.967496519357777,
           9.799211536608805,
           9.630926553859862,
           9.46264157111089,
           9.294356588361916,
           9.126071605612974,
           8.957786622864003,
           8.78950164011503,
           8.621216657366089,
           8.452931674617115,
           8.284646691868144,
           8.11636170911917,
           7.948076726370229,
           7.779791743621257,
           7.611506760872285,
           7.443221778123343,
           7.274936795374369,
           7.1066518126253975,
           6.938366829876456,
           6.770081847127484,
           6.601796864378511,
           6.433511881629539,
           6.265226898880597
          ],
          [
           29.158073369302286,
           29.19143645107077,
           29.224799532839253,
           29.258162614607738,
           29.291525696376226,
           29.32488877814471,
           29.358251859913196,
           29.39161494168168,
           29.424978023450166,
           29.45834110521865,
           29.49170418698714,
           29.525067268755624,
           29.55843035052411,
           29.591793432292597,
           29.625156514061082,
           29.658519595829567,
           29.69188267759805,
           29.725245759366537,
           29.758608841135022,
           29.79197192290351,
           29.82533500467199,
           29.858698086440477,
           29.89206116820896,
           29.92542424997745,
           29.95878733174593,
           29.992150413514416,
           30.025513495282908,
           30.058876577051386,
           30.092239658819878,
           30.125602740588363,
           30.158965822356848,
           30.192328904125333,
           30.22569198589381,
           30.259055067662306,
           30.292418149430787,
           30.325781231199272,
           30.35914431296776,
           30.392507394736242,
           30.425870476504734,
           30.459233558273212,
           30.492596640041704,
           30.52595972181018,
           30.559322803578674,
           30.592685885347155,
           30.626048967115636,
           30.65941204888413,
           30.69277513065261,
           30.726138212421098,
           30.759501294189583,
           30.792864375958064,
           30.826227457726553,
           30.859590539495038,
           30.892953621263526,
           30.92631670303201,
           30.9596797848005,
           30.99304286656898,
           31.02640594833747,
           31.059769030105954,
           31.093132111874436,
           31.126495193642924,
           31.15985827541141,
           31.193221357179898,
           31.22658443894838,
           31.259947520716864,
           31.293310602485352,
           31.326673684253834,
           31.36003676602232,
           31.393399847790807,
           31.42676292955929,
           31.46012601132778,
           31.49348909309626,
           31.526852174864743,
           31.560215256633235,
           31.595519280555838,
           31.631211495936935,
           31.666903711318035,
           31.70259592669913,
           31.73828814208023,
           31.77398035746133,
           31.809672572842427,
           31.845364788223524,
           31.88105700360462,
           31.916749218985718,
           31.952441434366815,
           31.986757875065976,
           32.02079916082876,
           32.054840446591534,
           32.08888173235431,
           32.122923018117085,
           32.15696430387986,
           32.191005589642636,
           32.22504687540542,
           32.259088161168194,
           32.29312944693097,
           32.327170732693745,
           32.359591339209004,
           32.39168781240285,
           32.423784285596696,
           32.45588075879054,
           32.48797723198439,
           32.520073705178234,
           32.55217017837208,
           32.584266651565926,
           32.61636312475978,
           32.64845959795362,
           32.68055607114747,
           32.71265254434132,
           32.74474901753516,
           32.77684549072901,
           32.808941963922855,
           32.8410384371167,
           32.87313491031055,
           32.90523138350439,
           32.93732785669824,
           32.969424329892085,
           33.00152080308593,
           33.03361727627978,
           33.06571374947362,
           33.09781022266747,
           33.129906695861315,
           33.16200316905516,
           33.19409964224901,
           33.22619611544285,
           33.25829258863671,
           33.29038906183055,
           33.3224855350244,
           33.354582008218244,
           33.38667848141209,
           33.41877495460594,
           33.45087142779978,
           33.48296790099363,
           33.515064374187475,
           33.54716084738132,
           33.57925732057517,
           33.61135379376901,
           33.64345026696286,
           33.675546740156705,
           33.70764321335055,
           33.7397396865444,
           33.77183615973824,
           33.80393263293209,
           33.836029106125935,
           33.86812557931978,
           33.90022205251363,
           33.93231852570747,
           33.96441499890132,
           33.99651147209517,
           34.02860794528902,
           34.06070441848286,
           34.09280089167671,
           34.124897364870556,
           34.1569938380644,
           34.18909031125825,
           34.221186784452094,
           34.25328325764594,
           34.28537973083978,
           34.31747620403363,
           34.34957267722748,
           34.381669150421324,
           34.41376562361517,
           34.445862096809016,
           34.47795857000286,
           34.510055043196715,
           34.542151516390554,
           34.57424798958441,
           34.60634446277825,
           34.6384409359721,
           34.67392198863929,
           34.71109533104317,
           34.74826867344704,
           34.78544201585092,
           34.822615358254794,
           34.85978870065867,
           34.896962043062544,
           34.93413538546642,
           34.971308727870294,
           35.00848207027417,
           35.045655412678045,
           35.08282875508191,
           35.12000209748579,
           35.15717543988966,
           35.19434878229354,
           35.23152212469741,
           35.26869546710129,
           35.30586880950516,
           35.34304215190903,
           35.380215494312914,
           35.41738883671678,
           35.453853635853655,
           35.489812336980194,
           35.52577103810674,
           35.561729739233286,
           35.59768844035983,
           35.63364714148638,
           35.669605842612924,
           35.70556454373946,
           35.74152324486601,
           35.77748194599255,
           35.813440647119094,
           35.84939934824564,
           35.885358049372186,
           35.92131675049873,
           35.95727545162528,
           35.99323415275182,
           36.02919285387836,
           36.0651515550049,
           36.10111025613145,
           36.137068957257995,
           36.17302765838454,
           36.20898635951109,
           36.24494506063763,
           36.28090376176418,
           36.316862462890725,
           36.35282116401726,
           36.3887798651438,
           36.42473856627035,
           36.460697267396895,
           36.49665596852344,
           36.53261466964999,
           36.568573370776534,
           36.60453207190308,
           36.640490773029626,
           36.676449474156165,
           36.71240817528271,
           36.74836687640925,
           36.7843255775358,
           36.82028427866234,
           36.85624297978889,
           36.892201680915434,
           36.92816038204198,
           36.96411908316853,
           37.000077784295065,
           37.03603648542161,
           37.07199518654816,
           37.1079538876747,
           37.14391258880124,
           37.17987128992779,
           37.215829991054335,
           37.251788692180874,
           37.28774739330742,
           37.323706094433966,
           37.35966479556052,
           37.39562349668706,
           37.431582197813604,
           37.46754089894015,
           37.50349960006669,
           37.539458301193235,
           37.575417002319774,
           37.61137570344632,
           37.64733440457287,
           37.68812003260943,
           37.73373258755602,
           37.779345142502606,
           37.82495769744919,
           37.87057025239577,
           37.91618280734236,
           37.96179536228894,
           38.00740791723553,
           38.05302047218212,
           38.0986330271287,
           38.144245582075285,
           38.18985813702187,
           38.23547069196846,
           38.281083246915045,
           38.32669580186163,
           38.37230835680821,
           38.4179209117548,
           38.46353346670138,
           38.509146021647965,
           38.55475857659456,
           38.600371131541145,
           38.645983686487725,
           38.69159624143431,
           38.7372087963809,
           38.782821351327485,
           38.828433906274064,
           38.87404646122065,
           38.91965901616724,
           38.965271571113824,
           39.01088412606041,
           39.05649668100699,
           39.102109235953584,
           39.147721790900164,
           39.19333434584675,
           39.23894690079334,
           39.284559455739924,
           39.33017201068651,
           39.3757845656331,
           39.42139712057968,
           39.467009675526256,
           39.51262223047285,
           39.55823478541943,
           39.603847340366016,
           39.6494598953126,
           39.69507245025919,
           39.740685005205776,
           39.78629756015236,
           39.83191011509894,
           39.87752267004553,
           39.923135224992116,
           39.9687477799387,
           40.01436033488528,
           40.05997288983187,
           40.105585444778455,
           40.15119799972505,
           40.19681055467162,
           40.242423109618215,
           40.2880356645648,
           40.33364821951139,
           40.37926077445796,
           40.424873329404555,
           40.47048588435114,
           40.51609843929772,
           40.56171099424431,
           40.607323549190895,
           40.65293610413747,
           40.69854865908406,
           40.74416121403065,
           40.78977376897723,
           40.835386323923814,
           40.8809988788704,
           40.92661143381699,
           40.97222398876357,
           41.01783654371016,
           41.06344909865675,
           41.109061653603334,
           41.15467420854992,
           41.2002867634965,
           41.24589931844309,
           41.29170115281364,
           41.338087277082344,
           41.38447340135105,
           41.43085952561975,
           41.39055278170214,
           41.17686030141199,
           40.963167821121836,
           40.74947534083166,
           40.53578286054151,
           40.32209038025135,
           40.10839789996118,
           39.90059466058658,
           39.69812646160952,
           39.49565826263242,
           39.29319006365531,
           39.09072186467823,
           38.88825366570115,
           38.68578546672404,
           38.48331726774696,
           38.280849068769875,
           38.07838086979278,
           37.875912670815694,
           37.67344447183861,
           37.47097627286151,
           37.26850807388441,
           37.066039874907325,
           36.863571675930245,
           36.661103476953144,
           36.45863527797606,
           36.25616707899898,
           36.05369888002187,
           35.85123068104478,
           35.64876248206771,
           35.44629428309061,
           35.2438260841135,
           35.04135788513644,
           34.83888968615934,
           34.63642148718223,
           34.43395328820515,
           34.23148508922807,
           34.02901689025097,
           33.826548691273885,
           33.624080492296805,
           33.4216122933197,
           33.21914409434261,
           33.01667589536554,
           32.814207696388436,
           32.61173949741133,
           32.40927129843425,
           32.20680309945717,
           32.00433490048006,
           31.80186670150298,
           31.599398502525897,
           31.396930303548796,
           31.19446210457171,
           30.99199390559463,
           30.789525706617532,
           30.587057507640424,
           30.384589308663365,
           30.18212110968626,
           29.97965291070916,
           29.777184711732083,
           29.574716512754993,
           29.372248313777888,
           29.169780114800812,
           28.96731191582373,
           28.764843716846624,
           28.56237551786954,
           28.35990731889246,
           28.157439119915356,
           27.95497092093826,
           27.75250272196119,
           27.550034522984088,
           27.347566324006984,
           27.145098125029904,
           26.94262992605282,
           26.74016172707572,
           26.537693528098632,
           26.335225329121553,
           26.13275713014445,
           25.930288931167347,
           25.727820732190285,
           25.52535253321318,
           25.322884334236083,
           25.120416135259003,
           24.917947936281916,
           24.71547973730481,
           24.500437686540867,
           24.222526376842488,
           23.944615067144106,
           23.666703757445728,
           23.3887924477474,
           23.110881138049017,
           22.832969828350635,
           22.555058518652302,
           22.277147208953927,
           21.999235899255545,
           21.721324589557213,
           21.443413279858834,
           21.165501970160456,
           20.887590660462074,
           20.60967935076374,
           20.33176804106536,
           20.05385673136698,
           19.775945421668652,
           19.49803411197027,
           19.222113073508073,
           18.94889312996132,
           18.675673186414514,
           18.402453242867715,
           18.12923329932096,
           17.85601335577416,
           17.582793412227357,
           17.30957346868055,
           17.036353525133798,
           16.763133581586995,
           16.489913638040193,
           16.216693694493443,
           15.94347375094664,
           15.670253807399838,
           15.397033863853085,
           15.123813920306283,
           14.850593976759479,
           14.577374033212678,
           14.304154089665925,
           14.030934146119122,
           13.75771420257232,
           13.484494259025567,
           13.211274315478764,
           13.002349800726027,
           12.839350592254778,
           12.676351383783496,
           12.513352175312217,
           12.350352966840966,
           12.187353758369689,
           12.024354549898407,
           11.861355341427128,
           11.698356132955878,
           11.535356924484596,
           11.372357716013317,
           11.209358507542067,
           11.046359299070788,
           10.883360090599508,
           10.72036088212826,
           10.55736167365698,
           10.394362465185697,
           10.231363256714417,
           10.068364048243168,
           9.90536483977189,
           9.742365631300608,
           9.579366422829358,
           9.416367214358077,
           9.249443712936916,
           9.081158730187974,
           8.912873747439,
           8.744588764690029,
           8.576303781941089,
           8.408018799192114,
           8.239733816443142,
           8.07144883369417,
           7.903163850945228,
           7.7348788681962555,
           7.566593885447283,
           7.398308902698342,
           7.230023919949369,
           7.061738937200397,
           6.893453954451456,
           6.725168971702483,
           6.55688398895351,
           6.3885990062045375,
           6.220314023455597
          ],
          [
           29.589708342870324,
           29.623071424638802,
           29.65643450640729,
           29.68979758817577,
           29.72316066994426,
           29.75652375171275,
           29.789886833481226,
           29.82324991524972,
           29.856612997018203,
           29.889976078786685,
           29.923339160555173,
           29.956702242323658,
           29.990065324092146,
           30.02342840586063,
           30.056791487629113,
           30.0901545693976,
           30.123517651166082,
           30.156880732934567,
           30.19024381470306,
           30.223606896471544,
           30.25696997824003,
           30.29033306000851,
           30.323696141776995,
           30.357059223545484,
           30.39042230531397,
           30.423785387082454,
           30.45714846885094,
           30.490511550619424,
           30.52387463238791,
           30.557237714156397,
           30.590600795924882,
           30.623963877693367,
           30.65732695946185,
           30.690690041230337,
           30.72405312299882,
           30.75741620476731,
           30.79077928653579,
           30.82414236830428,
           30.857505450072768,
           30.89086853184125,
           30.924231613609734,
           30.957594695378223,
           30.990957777146704,
           31.024320858915196,
           31.057683940683678,
           31.09104702245216,
           31.12441010422065,
           31.157773185989132,
           31.191136267757614,
           31.224499349526106,
           31.257862431294587,
           31.291225513063075,
           31.324588594831557,
           31.35795167660005,
           31.39131475836853,
           31.42467784013702,
           31.458817297637623,
           31.494509513018716,
           31.53020172839981,
           31.565893943780914,
           31.601586159162007,
           31.63727837454311,
           31.672970589924205,
           31.7086628053053,
           31.7443550206864,
           31.780047236067503,
           31.8157394514486,
           31.851431666829697,
           31.887123882210794,
           31.92281609759189,
           31.958508312972988,
           31.99420052835409,
           32.02989274373518,
           32.06558495911628,
           32.10127717449738,
           32.13696938987848,
           32.17266160525958,
           32.20835382064067,
           32.24404603602177,
           32.27973825140287,
           32.315430466783965,
           32.35112268216506,
           32.38681489754616,
           32.422507112927256,
           32.45682355362642,
           32.490864839389204,
           32.52490612515197,
           32.558947410914755,
           32.59298869667753,
           32.627029982440305,
           32.66107126820308,
           32.695112553965856,
           32.72915383972864,
           32.763195125491414,
           32.79723641125419,
           32.831277697016965,
           32.86531898277974,
           32.899360268542516,
           32.9334015543053,
           32.967442840068074,
           33.00148412583085,
           33.035525411593625,
           33.0695666973564,
           33.10360798311918,
           33.13764926888196,
           33.17169055464473,
           33.20573184040751,
           33.239773126170284,
           33.27381441193306,
           33.30785569769584,
           33.34189698345862,
           33.37528999657924,
           33.40738646977309,
           33.43948294296693,
           33.47157941616078,
           33.503675889354625,
           33.53577236254847,
           33.56786883574232,
           33.59996530893616,
           33.63206178213001,
           33.664158255323855,
           33.6962547285177,
           33.72835120171155,
           33.76044767490539,
           33.792544148099246,
           33.824640621293085,
           33.85673709448693,
           33.88883356768078,
           33.92093004087463,
           33.953026514068476,
           33.98512298726232,
           34.01721946045617,
           34.049315933650014,
           34.08141240684385,
           34.113508880037706,
           34.14560535323155,
           34.1777018264254,
           34.209798299619244,
           34.24189477281309,
           34.273991246006936,
           34.30608771920078,
           34.33818419239463,
           34.370280665588474,
           34.40237713878232,
           34.43447361197617,
           34.46657008517002,
           34.498666558363865,
           34.53076303155771,
           34.56285950475156,
           34.5949559779454,
           34.62705245113925,
           34.659148924333095,
           34.69124539752694,
           34.72334187072079,
           34.75543834391463,
           34.78753481710848,
           34.819631290302326,
           34.85172776349617,
           34.88382423669002,
           34.91592070988386,
           34.94801718307771,
           34.980113656271556,
           35.0122101294654,
           35.04430660265925,
           35.076403075853094,
           35.10849954904694,
           35.140596022240786,
           35.17607707490799,
           35.213250417311855,
           35.25042375971573,
           35.28759710211961,
           35.32477044452348,
           35.361943786927355,
           35.39911712933123,
           35.436290471735106,
           35.47346381413898,
           35.510637156542856,
           35.54781049894673,
           35.584983841350606,
           35.62215718375448,
           35.65933052615836,
           35.69650386856223,
           35.73367721096611,
           35.77085055336998,
           35.80802389577385,
           35.845197238177725,
           35.88237058058161,
           35.91954392298547,
           35.95671726538935,
           35.99389060779322,
           36.0310639501971,
           36.06823729260097,
           36.105410635004844,
           36.14258397740872,
           36.179757319812595,
           36.21693066221647,
           36.254104004620345,
           36.29127734702422,
           36.328450689428095,
           36.36562403183197,
           36.40279737423584,
           36.43997071663972,
           36.47714405904359,
           36.51431740144747,
           36.551490743851346,
           36.588664086255214,
           36.62583742865909,
           36.663010771062964,
           36.70018411346684,
           36.737357455870715,
           36.77453079827459,
           36.811704140678465,
           36.84887748308234,
           36.88605082548621,
           36.92322416789008,
           36.96039751029396,
           36.997570852697834,
           37.03474419510171,
           37.071917537505584,
           37.10909087990946,
           37.14510018895146,
           37.181058890078,
           37.21701759120455,
           37.25297629233109,
           37.28893499345764,
           37.324893694584176,
           37.36085239571072,
           37.39681109683727,
           37.432769797963815,
           37.46872849909035,
           37.5046872002169,
           37.540645901343446,
           37.57660460246999,
           37.61256330359654,
           37.648522004723084,
           37.68448070584962,
           37.72043940697617,
           37.756398108102715,
           37.79235680922926,
           37.82831551035581,
           37.864274211482346,
           37.90023291260889,
           37.93619161373543,
           37.972150314861985,
           38.00810901598852,
           38.04406771711507,
           38.080026418241616,
           38.115985119368155,
           38.1519438204947,
           38.18790252162125,
           38.22868814965781,
           38.2743007046044,
           38.31991325955099,
           38.365525814497566,
           38.41113836944416,
           38.45675092439074,
           38.50236347933732,
           38.54797603428391,
           38.59358858923049,
           38.63920114417708,
           38.68481369912367,
           38.73042625407026,
           38.77603880901684,
           38.821651363963426,
           38.86726391891001,
           38.9128764738566,
           38.95848902880318,
           39.004101583749765,
           39.04971413869635,
           39.09532669364293,
           39.140939248589525,
           39.18655180353611,
           39.232164358482684,
           39.27777691342928,
           39.323389468375865,
           39.36900202332245,
           39.41461457826903,
           39.46022713321562,
           39.505839688162204,
           39.55145224310879,
           39.59706479805538,
           39.642677353001964,
           39.688289907948544,
           39.73390246289513,
           39.77951501784172,
           39.825127572788304,
           39.870740127734884,
           39.91635268268148,
           39.961965237628064,
           40.00805510146796,
           40.05444122573667,
           40.10082735000538,
           40.14721347427409,
           40.19359959854279,
           40.239985722811504,
           40.286371847080204,
           40.33275797134892,
           40.379144095617626,
           40.425530219886326,
           40.471916344155034,
           40.51830246842374,
           40.56468859269245,
           40.61107471696115,
           40.657460841229856,
           40.70384696549857,
           40.75023308976727,
           40.796619214035985,
           40.843005338304685,
           40.88939146257339,
           40.9357775868421,
           40.9821637111108,
           41.02854983537951,
           41.074935959648215,
           41.12132208391693,
           41.16770820818563,
           41.21409433245433,
           41.260480456723045,
           41.30686658099175,
           41.35325270526045,
           41.39963882952916,
           41.446024953797874,
           41.492411078066574,
           41.538797202335275,
           41.58518332660398,
           41.631569450872696,
           41.6779555751414,
           41.724341699410104,
           41.77072782367881,
           41.81711394794752,
           41.863500072216226,
           41.90988619648493,
           41.95627232075364,
           42.00265844502234,
           41.96235170110474,
           41.74865922081458,
           41.534966740524425,
           41.321274260234254,
           41.1075817799441,
           40.89388929965394,
           40.68019681936377,
           40.466504339073595,
           40.25281185878346,
           40.03911937849329,
           39.82542689820312,
           39.61173441791296,
           39.39804193762281,
           39.18434945733263,
           38.97065697704248,
           38.756964496752325,
           38.543272016462154,
           38.329579536172,
           38.11588705588184,
           37.90219457559167,
           37.688502095301494,
           37.47480961501134,
           37.26111713472118,
           37.04742465443101,
           36.833732174140856,
           36.6200396938507,
           36.40634721356053,
           36.19265473327037,
           35.978962252980224,
           35.76526977269005,
           35.55157729239988,
           35.337884812109735,
           35.124192331819565,
           34.910499851529394,
           34.69680737123924,
           34.48311489094908,
           34.26942241065891,
           34.055729930368756,
           33.84203745007861,
           33.62834496978843,
           33.41465248949827,
           33.20096000920812,
           32.98726752891795,
           32.77357504862777,
           32.55988256833761,
           32.346190088047464,
           32.13249760775729,
           31.918805127467134,
           31.705112647176986,
           31.49142016688681,
           31.277727686596652,
           31.0640352063065,
           30.85034272601633,
           30.63665024572615,
           30.422957765436013,
           30.20926528514584,
           29.995572804855666,
           29.781880324565513,
           29.56818784427536,
           29.354495363985194,
           29.140802883695034,
           28.92711040340488,
           28.713417923114708,
           28.499725442824552,
           28.286032962534396,
           28.072340482244222,
           27.85864800195405,
           27.644955521663917,
           27.431263041373743,
           27.217570561083566,
           27.003878080793413,
           26.790185600503257,
           26.576493120213087,
           26.362800639922934,
           26.149108159632778,
           25.935415679342604,
           25.721723199052434,
           25.510802182639313,
           25.30833398366221,
           25.105865784685108,
           24.903397585708028,
           24.700929386730945,
           24.49846118775384,
           24.283419136989895,
           24.005507827291517,
           23.730759631176475,
           23.457539687629673,
           23.18431974408292,
           22.911099800536114,
           22.637879856989315,
           22.364659913442562,
           22.091439969895756,
           21.818220026348953,
           21.545000082802204,
           21.271780139255398,
           20.998560195708595,
           20.725340252161793,
           20.452120308615044,
           20.178900365068237,
           19.90568042152144,
           19.632460477974686,
           19.35924053442788,
           19.086020590881077,
           18.812800647334328,
           18.539580703787525,
           18.266360760240723,
           17.99314081669397,
           17.719920873147167,
           17.446700929600365,
           17.173480986053562,
           16.900261042506806,
           16.627041098960007,
           16.3538211554132,
           16.08060121186645,
           15.807381268319649,
           15.534161324772846,
           15.260941381226095,
           14.987721437679294,
           14.714501494132488,
           14.441281550585686,
           14.168061607038933,
           13.89484166349213,
           13.621621719945328,
           13.348401776398575,
           13.075181832851772,
           12.866257318099034,
           12.703258109627782,
           12.540258901156506,
           12.377259692685227,
           12.214260484213977,
           12.051261275742695,
           11.888262067271416,
           11.725262858800136,
           11.562263650328887,
           11.399264441857607,
           11.236265233386327,
           11.073266024915076,
           10.910266816443798,
           10.747267607972518,
           10.584268399501266,
           10.421269191029985,
           10.258269982558707,
           10.095270774087426,
           9.932271565616176,
           9.769272357144896,
           9.606273148673617,
           9.443273940202367,
           9.280274731731087,
           9.117275523259808,
           8.954276314788558,
           8.791277106317278,
           8.628277897845997,
           8.465278689374747,
           8.302279480903467,
           8.139280272432188,
           7.976281063960907,
           7.813281855489658,
           7.650282647018377,
           7.487283438547097,
           7.324284230075848,
           7.161285021604568,
           6.998285813133289,
           6.835286604662038,
           6.672287396190757,
           6.50928818771948,
           6.343686130779536,
           6.175401148030594
          ],
          [
           30.021343316438344,
           30.054706398206832,
           30.088069479975317,
           30.121432561743802,
           30.154795643512287,
           30.188158725280772,
           30.221521807049257,
           30.25488488881774,
           30.288247970586227,
           30.321611052354715,
           30.3549741341232,
           30.38833721589168,
           30.421700297660166,
           30.45506337942866,
           30.488426461197143,
           30.521789542965628,
           30.555152624734113,
           30.588515706502598,
           30.621878788271083,
           30.655241870039568,
           30.688604951808053,
           30.721968033576537,
           30.75533111534502,
           30.78869419711351,
           30.822057278881992,
           30.855420360650477,
           30.88878344241897,
           30.92214652418745,
           30.95550960595594,
           30.98887268772442,
           31.02223576949291,
           31.055598851261394,
           31.088961933029875,
           31.122325014798363,
           31.155688096566845,
           31.189051178335337,
           31.222414260103818,
           31.255777341872307,
           31.28914042364079,
           31.322503505409276,
           31.357807530100487,
           31.39349974548159,
           31.42919196086269,
           31.464884176243785,
           31.500576391624882,
           31.536268607005976,
           31.57196082238708,
           31.607653037768173,
           31.64334525314927,
           31.67903746853037,
           31.714729683911465,
           31.750421899292565,
           31.786114114673662,
           31.82180633005476,
           31.85749854543586,
           31.893190760816953,
           31.928882976198054,
           31.96457519157915,
           32.00026740696025,
           32.03595962234135,
           32.07165183772244,
           32.107344053103546,
           32.143036268484636,
           32.17872848386574,
           32.214420699246844,
           32.250112914627934,
           32.28580513000904,
           32.32149734539013,
           32.35718956077123,
           32.39288177615232,
           32.428573991533426,
           32.464266206914516,
           32.49995842229562,
           32.53565063767672,
           32.571342853057814,
           32.60703506843891,
           32.64272728382001,
           32.678419499201105,
           32.71411171458221,
           32.749803929963306,
           32.7854961453444,
           32.8211883607255,
           32.8568805761066,
           32.892572791487694,
           32.92688923218686,
           32.960930517949635,
           32.99497180371241,
           33.029013089475185,
           33.06305437523797,
           33.09709566100074,
           33.13113694676352,
           33.165178232526294,
           33.19921951828907,
           33.23326080405185,
           33.26730208981463,
           33.3013433755774,
           33.33538466134018,
           33.369425947102954,
           33.40346723286574,
           33.437508518628505,
           33.47154980439129,
           33.50559109015406,
           33.53963237591684,
           33.573673661679614,
           33.60771494744239,
           33.64175623320517,
           33.67579751896795,
           33.70983880473072,
           33.743880090493505,
           33.77792137625627,
           33.81196266201905,
           33.84600394778183,
           33.88004523354461,
           33.91408651930738,
           33.94812780507016,
           33.98216909083293,
           34.016210376595716,
           34.050251662358484,
           34.084292948121266,
           34.11833423388404,
           34.15237551964682,
           34.18641680540959,
           34.220458091172375,
           34.254499376935144,
           34.28854066269792,
           34.3225819484607,
           34.35662323422348,
           34.39066451998625,
           34.42308512714331,
           34.45518160033715,
           34.487278073530995,
           34.51937454672485,
           34.551471019918694,
           34.58356749311253,
           34.615663966306386,
           34.64776043950023,
           34.67985691269408,
           34.711953385887924,
           34.74404985908177,
           34.776146332275616,
           34.80824280546946,
           34.84033927866331,
           34.872435751857154,
           34.904532225051,
           34.936628698244846,
           34.96872517143869,
           35.00082164463254,
           35.032918117826384,
           35.06501459102023,
           35.09711106421408,
           35.12920753740793,
           35.16130401060177,
           35.193400483795614,
           35.22549695698946,
           35.25759343018331,
           35.28968990337716,
           35.321786376571005,
           35.35388284976485,
           35.3859793229587,
           35.41807579615254,
           35.45017226934639,
           35.482268742540235,
           35.51436521573408,
           35.54646168892793,
           35.57855816212177,
           35.61065463531562,
           35.642751108509465,
           35.678232161176666,
           35.71540550358054,
           35.75257884598442,
           35.78975218838829,
           35.82692553079216,
           35.86409887319604,
           35.90127221559992,
           35.93844555800379,
           35.97561890040766,
           36.012792242811535,
           36.04996558521541,
           36.08713892761929,
           36.12431227002316,
           36.16148561242703,
           36.19865895483091,
           36.235832297234786,
           36.27300563963866,
           36.31017898204253,
           36.347352324446405,
           36.38452566685028,
           36.421699009254155,
           36.45887235165803,
           36.496045694061905,
           36.53321903646578,
           36.570392378869656,
           36.607565721273524,
           36.644739063677406,
           36.68191240608128,
           36.719085748485156,
           36.75625909088903,
           36.7934324332929,
           36.830605775696775,
           36.86777911810065,
           36.904952460504525,
           36.9421258029084,
           36.979299145312275,
           37.01647248771615,
           37.053645830120026,
           37.090819172523894,
           37.12799251492777,
           37.165165857331644,
           37.20233919973552,
           37.239512542139394,
           37.27668588454327,
           37.313859226947145,
           37.35103256935102,
           37.388205911754895,
           37.42537925415877,
           37.46255259656264,
           37.49972593896652,
           37.53689928137039,
           37.57407262377426,
           37.61124596617814,
           37.648419308582014,
           37.68559265098589,
           37.722765993389764,
           37.75993933579364,
           37.797112678197514,
           37.83428602060139,
           37.871459363005265,
           37.90863270540913,
           37.94580604781301,
           37.98297939021688,
           38.02015273262076,
           38.05732607502463,
           38.09449941742851,
           38.131672759832384,
           38.16884610223626,
           38.206019444640134,
           38.243192787044,
           38.28036612944788,
           38.31753947185175,
           38.35471281425563,
           38.39188615665951,
           38.42905949906338,
           38.46623284146725,
           38.50340618387113,
           38.540579526275,
           38.57775286867887,
           38.61492621108275,
           38.65209955348662,
           38.6892728958905,
           38.72700429465196,
           38.769392631865564,
           38.81627377183648,
           38.86315491180739,
           38.90995354719711,
           38.95633967146582,
           39.00272579573453,
           39.049111920003234,
           39.09549804427194,
           39.14188416854065,
           39.18827029280936,
           39.23465641707806,
           39.28104254134677,
           39.32742866561547,
           39.37381478988418,
           39.420200914152886,
           39.466587038421586,
           39.512973162690294,
           39.559359286959,
           39.60574541122771,
           39.65213153549641,
           39.69851765976512,
           39.74490378403383,
           39.79128990830253,
           39.837676032571245,
           39.88406215683995,
           39.93044828110865,
           39.97683440537736,
           40.02322052964607,
           40.069606653914775,
           40.11599277818348,
           40.16237890245219,
           40.2087650267209,
           40.2551511509896,
           40.301537275258305,
           40.34792339952702,
           40.39430952379572,
           40.44069564806443,
           40.487081772333134,
           40.53346789660184,
           40.57985402087054,
           40.626240145139256,
           40.67262626940796,
           40.719012393676664,
           40.76539851794537,
           40.81178464221408,
           40.858170766482786,
           40.90455689075149,
           40.9509430150202,
           40.99732913928891,
           41.043715263557615,
           41.09010138782632,
           41.13648751209503,
           41.18287363636373,
           41.229259760632445,
           41.27564588490115,
           41.322032009169845,
           41.36841813343856,
           41.41480425770727,
           41.461190381975975,
           41.507576506244675,
           41.55396263051338,
           41.60034875478209,
           41.6467348790508,
           41.693121003319504,
           41.73950712758821,
           41.78589325185691,
           41.83227937612562,
           41.878665500394334,
           41.925051624663034,
           41.97143774893174,
           42.017823873200456,
           42.064209997469156,
           42.11059612173786,
           42.156982246006564,
           42.20336837027527,
           42.24975449454398,
           42.296140618812686,
           42.34252674308139,
           42.38891286735009,
           42.4352989916188,
           42.481685115887515,
           42.52807124015622,
           42.57445736442492,
           42.53415062050732,
           42.32045814021716,
           42.10676565992701,
           41.893073179636836,
           41.67938069934668,
           41.465688219056524,
           41.251995738766354,
           41.038303258476176,
           40.82461077818604,
           40.610918297895864,
           40.397225817605694,
           40.18353333731554,
           39.96984085702539,
           39.75614837673521,
           39.54245589644506,
           39.32876341615491,
           39.11507093586473,
           38.90137845557457,
           38.687685975284424,
           38.47399349499425,
           38.26030101470407,
           38.04660853441391,
           37.83291605412376,
           37.619223573833594,
           37.405531093543445,
           37.19183861325328,
           36.97814613296311,
           36.764453652672955,
           36.550761172382806,
           36.33706869209263,
           36.12337621180245,
           35.90968373151232,
           35.69599125122214,
           35.482298770931976,
           35.26860629064182,
           35.054913810351664,
           34.841221330061494,
           34.62752884977134,
           34.41383636948118,
           34.200143889191004,
           33.986451408900855,
           33.76507586476927,
           33.53404358298414,
           33.30301130119901,
           33.07197901941389,
           32.84094673762878,
           32.609914455843644,
           32.37888217405853,
           32.14784989227342,
           31.916817610488284,
           31.68578532870317,
           31.454753046918057,
           31.223720765132924,
           30.992688483347788,
           30.761656201562698,
           30.53062391977756,
           30.299591637992428,
           30.068559356207313,
           29.8375270744222,
           29.60649479263706,
           29.37546251085195,
           29.144430229066835,
           28.913397947281705,
           28.68236566549659,
           28.45133338371148,
           28.22030110192634,
           27.989268820141206,
           27.758236538356112,
           27.527204256570975,
           27.296171974785842,
           27.065139693000727,
           26.834107411215612,
           26.60307512943048,
           26.372042847645368,
           26.141010565860253,
           25.909978284075116,
           25.678946002289983,
           25.447913720504893,
           25.216881438719756,
           24.98584915693462,
           24.75481687514951,
           24.523784593364393,
           24.29275231157926,
           24.0548217039955,
           23.782399467418337,
           23.509977230841184,
           23.23755499426403,
           22.965132757686927,
           22.692710521109774,
           22.420288284532617,
           22.147866047955517,
           21.875443811378364,
           21.603021574801208,
           21.330599338224104,
           21.05817710164695,
           20.785754865069794,
           20.513332628492645,
           20.240910391915538,
           19.96848815533838,
           19.696065918761228,
           19.423643682184125,
           19.15122144560697,
           18.878799209029815,
           18.606376972452715,
           18.333954735875558,
           18.061532499298405,
           17.7891102627213,
           17.516688026144145,
           17.24426578956699,
           16.97184355298984,
           16.699421316412735,
           16.426999079835582,
           16.154576843258425,
           15.882154606681322,
           15.609732370104167,
           15.337310133527014,
           15.070195981948434,
           14.803350898419463,
           14.53650581489049,
           14.269660731361517,
           14.002815647832598,
           13.735970564303624,
           13.469125480774652,
           13.20228039724573,
           12.935435313716757,
           12.732985077888442,
           12.576531161846315,
           12.42007724580416,
           12.263623329762005,
           12.107169413719877,
           11.950715497677724,
           11.79426158163557,
           11.637807665593414,
           11.481353749551289,
           11.323663485541466,
           11.161456742119043,
           10.999249998696648,
           10.837043255274224,
           10.674836511851801,
           10.512629768429406,
           10.350423025006984,
           10.188216281584559,
           10.026009538162135,
           9.863802794739742,
           9.701596051317319,
           9.539389307894893,
           9.3771825644725,
           9.214975821050077,
           9.052769077627653,
           8.890562334205258,
           8.728355590782835,
           8.56614884736041,
           8.403942103938016,
           8.241735360515593,
           8.079528617093167,
           7.917321873670745,
           7.755115130248351,
           7.592908386825927,
           7.430701643403504,
           7.268494899981109,
           7.106288156558684,
           6.944081413136261,
           6.7818746697138685,
           6.619667926291443,
           6.457461182869019,
           6.2952544394465955,
           6.133047696024201
          ],
          [
           30.452978290006378,
           30.486341371774863,
           30.519704453543348,
           30.553067535311833,
           30.586430617080318,
           30.619793698848802,
           30.653156780617287,
           30.686519862385776,
           30.71988294415426,
           30.75324602592275,
           30.786609107691234,
           30.819972189459715,
           30.8533352712282,
           30.88669835299669,
           30.920061434765174,
           30.953424516533662,
           30.986787598302147,
           31.02015068007063,
           31.053513761839117,
           31.0868768436076,
           31.120239925376087,
           31.15360300714457,
           31.186966088913053,
           31.221105547182276,
           31.256797762563373,
           31.29248997794447,
           31.328182193325567,
           31.363874408706664,
           31.39956662408776,
           31.43525883946886,
           31.47095105484996,
           31.506643270231056,
           31.542335485612153,
           31.57802770099325,
           31.613719916374347,
           31.649412131755447,
           31.685104347136544,
           31.72079656251764,
           31.75648877789874,
           31.792180993279835,
           31.827873208660932,
           31.863565424042033,
           31.89925763942313,
           31.93494985480423,
           31.970642070185328,
           32.006334285566425,
           32.04202650094753,
           32.07771871632862,
           32.113410931709716,
           32.14910314709082,
           32.18479536247192,
           32.220487577853014,
           32.25617979323411,
           32.2918720086152,
           32.327564223996305,
           32.3632564393774,
           32.398948654758506,
           32.434640870139596,
           32.47033308552069,
           32.5060253009018,
           32.54171751628289,
           32.57740973166399,
           32.61310194704509,
           32.648794162426185,
           32.68448637780728,
           32.72017859318838,
           32.755870808569476,
           32.79156302395058,
           32.82725523933168,
           32.862947454712774,
           32.89863967009387,
           32.93433188547497,
           32.970024100856065,
           33.00571631623716,
           33.04140853161826,
           33.077100746999356,
           33.11279296238045,
           33.14848517776156,
           33.18417739314265,
           33.21986960852375,
           33.25556182390485,
           33.291254039285946,
           33.32694625466705,
           33.36263847004814,
           33.396954910747304,
           33.43099619651008,
           33.46503748227286,
           33.49907876803564,
           33.53312005379841,
           33.56716133956119,
           33.601202625323964,
           33.63524391108675,
           33.669285196849515,
           33.7033264826123,
           33.73736776837507,
           33.77140905413785,
           33.80545033990063,
           33.8394916256634,
           33.87353291142618,
           33.90757419718896,
           33.94161548295173,
           33.97565676871451,
           34.00969805447728,
           34.043739340240066,
           34.077780626002834,
           34.11182191176562,
           34.14586319752839,
           34.17990448329117,
           34.21394576905394,
           34.24798705481672,
           34.2820283405795,
           34.316069626342276,
           34.35011091210505,
           34.384152197867834,
           34.4181934836306,
           34.452234769393385,
           34.48627605515616,
           34.520317340918936,
           34.55435862668171,
           34.58839991244449,
           34.62244119820726,
           34.656482483970045,
           34.69052376973282,
           34.724565055495596,
           34.75860634125837,
           34.79264762702115,
           34.82668891278392,
           34.860730198546705,
           34.89477148430948,
           34.928812770072255,
           34.96285405583503,
           34.99689534159781,
           35.03093662736058,
           35.064977913123364,
           35.09901919888614,
           35.133060484648915,
           35.1671017704117,
           35.20114305617447,
           35.23518434193725,
           35.269225627700024,
           35.3032669134628,
           35.337308199225575,
           35.37134948498835,
           35.40539077075113,
           35.43878378451353,
           35.47088025770738,
           35.50297673090123,
           35.53507320409507,
           35.567169677288916,
           35.59926615048277,
           35.631362623676615,
           35.66345909687046,
           35.69555557006431,
           35.72765204325815,
           35.759748516452,
           35.791844989645845,
           35.82394146283969,
           35.85603793603354,
           35.88813440922738,
           35.92023088242123,
           35.952327355615076,
           35.98442382880892,
           36.01652030200277,
           36.048616775196614,
           36.08071324839046,
           36.112809721584306,
           36.14490619477815,
           36.18038724744535,
           36.21756058984923,
           36.2547339322531,
           36.29190727465698,
           36.32908061706085,
           36.36625395946473,
           36.403427301868604,
           36.44060064427248,
           36.47777398667635,
           36.51494732908022,
           36.5521206714841,
           36.58929401388798,
           36.62646735629185,
           36.66364069869572,
           36.7008140410996,
           36.73798738350347,
           36.77516072590735,
           36.81233406831122,
           36.8495074107151,
           36.88668075311897,
           36.92385409552284,
           36.96102743792672,
           36.99820078033059,
           37.03537412273447,
           37.07254746513834,
           37.10972080754222,
           37.14689414994609,
           37.18406749234997,
           37.22124083475385,
           37.25841417715772,
           37.295587519561586,
           37.33276086196547,
           37.369934204369336,
           37.407107546773204,
           37.44428088917709,
           37.48145423158096,
           37.51862757398484,
           37.55580091638871,
           37.59297425879259,
           37.63014760119646,
           37.66732094360033,
           37.70449428600421,
           37.74166762840808,
           37.77884097081196,
           37.81601431321583,
           37.853187655619706,
           37.89036099802358,
           37.927731301007995,
           37.96562683546428,
           38.003522369920574,
           38.04141790437686,
           38.07931343883314,
           38.11720897328943,
           38.15510450774572,
           38.19300004220201,
           38.2308955766583,
           38.268791111114574,
           38.30668664557086,
           38.344582180027146,
           38.382477714483436,
           38.42037324893972,
           38.458268783396,
           38.49616431785229,
           38.53405985230858,
           38.57195538676487,
           38.60985092122115,
           38.647746455677435,
           38.685641990133725,
           38.72353752459001,
           38.7614330590463,
           38.79932859350259,
           38.83722412795887,
           38.87511966241515,
           38.91301519687144,
           38.95091073132773,
           38.988806265784014,
           39.0267018002403,
           39.064597334696586,
           39.10249286915287,
           39.14038840360915,
           39.17828393806545,
           39.21617947252173,
           39.25407500697802,
           39.296463344191615,
           39.34334448416253,
           39.39022562413344,
           39.43710676410435,
           39.48398790407526,
           39.53086904404617,
           39.577750184017084,
           39.624631323988,
           39.671512463958905,
           39.71839360392981,
           39.765274743900726,
           39.81215588387164,
           39.85903702384255,
           39.90591816381346,
           39.952799303784374,
           39.99968044375528,
           40.046561583726195,
           40.09344272369711,
           40.140323863668016,
           40.18720500363893,
           40.234086143609844,
           40.28096728358076,
           40.32784842355166,
           40.37472956352257,
           40.421610703493485,
           40.4684918434644,
           40.5153729834353,
           40.56225412340622,
           40.609135263377134,
           40.65601640334803,
           40.702897543318954,
           40.749778683289875,
           40.79665982326077,
           40.84354096323168,
           40.8904221032026,
           40.9373032431735,
           40.98418438314442,
           41.03106552311533,
           41.07794666308624,
           41.12482780305716,
           41.171708943028065,
           41.21859008299898,
           41.265471222969886,
           41.3123523629408,
           41.359233502911714,
           41.40611464288261,
           41.45299578285353,
           41.49987692282444,
           41.54675806279536,
           41.59363920276627,
           41.64052034273718,
           41.68740148270808,
           41.734282622679,
           41.78116376264991,
           41.828044902620825,
           41.874926042591724,
           41.92180718256264,
           41.96868832253356,
           42.015569462504466,
           42.06245060247538,
           42.109331742446294,
           42.1562128824172,
           42.20309402238811,
           42.24997516235903,
           42.29685630232993,
           42.343737442300835,
           42.39061858227176,
           42.43749972224267,
           42.48438086221358,
           42.53126200218449,
           42.578143142155405,
           42.62502428212631,
           42.671905422097225,
           42.71878656206813,
           42.76566770203904,
           42.81254884200996,
           42.85942998198087,
           42.90631112195178,
           42.953192261922695,
           43.0000734018936,
           43.04728032719584,
           43.095627499521335,
           43.14397467184685,
           43.095847250190765,
           42.85477064057161,
           42.61369403095246,
           42.37261742133328,
           42.13154081171413,
           41.89046420209498,
           41.649387592475804,
           41.408310982856634,
           41.167234373237505,
           40.927413302267,
           40.69638102048186,
           40.46534873869674,
           40.23431645691163,
           40.003284175126495,
           39.77225189334138,
           39.54121961155627,
           39.31018732977114,
           39.07915504798602,
           38.84812276620091,
           38.61709048441577,
           38.386058202630636,
           38.155025920845524,
           37.92399363906041,
           37.69296135727528,
           37.46192907549016,
           37.23089679370505,
           36.99986451191991,
           36.7688322301348,
           36.53779994834969,
           36.306767666564554,
           36.07573538477942,
           35.84470310299432,
           35.61367082120919,
           35.38263853942406,
           35.151606257638946,
           34.92057397585383,
           34.689541694068694,
           34.458509412283576,
           34.22747713049847,
           33.99644484871334,
           33.76541256692822,
           33.5343802851431,
           33.30334800335797,
           33.072315721572835,
           32.84128343978772,
           32.61025115800261,
           32.37921887621747,
           32.14818659443236,
           31.91715431264725,
           31.686122030862116,
           31.455089749077004,
           31.224057467291885,
           30.993025185506752,
           30.761992903721616,
           30.530960621936526,
           30.29992834015139,
           30.068896058366253,
           29.837863776581138,
           29.606831494796026,
           29.375799213010893,
           29.14476693122578,
           28.913734649440666,
           28.68270236765553,
           28.45167008587042,
           28.220637804085307,
           27.98960552230017,
           27.758573240515034,
           27.52754095872994,
           27.29650867694481,
           27.06547639515967,
           26.83444411337456,
           26.603411831589447,
           26.37237954980431,
           26.141347268019196,
           25.910314986234084,
           25.67928270444895,
           25.44825042266381,
           25.21721814087872,
           24.986185859093588,
           24.755153577308455,
           24.524121295523337,
           24.293089013738225,
           24.062056731953092,
           23.824126124369325,
           23.55170388779217,
           23.279281651215015,
           23.006859414637862,
           22.73443717806076,
           22.462014941483602,
           22.18959270490645,
           21.917170468329346,
           21.644748231752192,
           21.37232599517504,
           21.099903758597936,
           20.82748152202078,
           20.555059285443626,
           20.282637048866473,
           20.01021481228937,
           19.737792575712213,
           19.468697063220983,
           19.201851979692062,
           18.935006896163088,
           18.668161812634118,
           18.401316729105197,
           18.134471645576223,
           17.867626562047253,
           17.60078147851833,
           17.333936394989358,
           17.067091311460388,
           16.800246227931414,
           16.533401144402493,
           16.26655606087352,
           15.999710977344549,
           15.732865893815628,
           15.466020810286654,
           15.199175726757684,
           14.93233064322876,
           14.665485559699789,
           14.398640476170817,
           14.131795392641845,
           13.864950309112924,
           13.59810522558395,
           13.33126014205498,
           13.064415058526057,
           12.797569974997085,
           12.595119739168767,
           12.438665823126643,
           12.282211907084486,
           12.125757991042333,
           11.969304075000206,
           11.812850158958051,
           11.656396242915898,
           11.499942326873743,
           11.343488410831617,
           11.187034494789463,
           11.030580578747308,
           10.874126662705184,
           10.717672746663025,
           10.561218830620872,
           10.404764914578745,
           10.24831099853659,
           10.091857082494437,
           9.93540316645228,
           9.778949250410156,
           9.622495334368,
           9.466041418325846,
           9.30958750228372,
           9.153133586241566,
           8.99667967019941,
           8.840225754157286,
           8.683771838115131,
           8.52403780245161,
           8.361831059029216,
           8.199624315606792,
           8.037417572184369,
           7.875210828761945,
           7.71300408533955,
           7.550797341917128,
           7.388590598494703,
           7.226383855072309,
           7.064177111649886,
           6.901970368227461,
           6.739763624805068,
           6.577556881382645,
           6.415350137960219,
           6.253143394537796,
           6.090936651115402
          ],
          [
           30.884613263574412,
           30.917976345342897,
           30.95133942711138,
           30.984702508879867,
           31.01806559064835,
           31.05142867241684,
           31.084791754185325,
           31.120095779645155,
           31.15578799502625,
           31.19148021040735,
           31.22717242578845,
           31.262864641169546,
           31.298556856550647,
           31.334249071931744,
           31.36994128731284,
           31.405633502693938,
           31.44132571807504,
           31.477017933456136,
           31.512710148837233,
           31.54840236421833,
           31.584094579599427,
           31.619786794980524,
           31.65547901036162,
           31.69117122574272,
           31.726863441123818,
           31.762555656504915,
           31.798247871886012,
           31.83394008726711,
           31.869632302648206,
           31.905324518029307,
           31.941016733410404,
           31.9767089487915,
           32.0124011641726,
           32.0480933795537,
           32.083785594934795,
           32.11947781031589,
           32.15517002569699,
           32.19086224107809,
           32.22655445645918,
           32.26224667184028,
           32.29793888722138,
           32.33363110260248,
           32.36932331798357,
           32.405015533364676,
           32.44070774874577,
           32.47639996412687,
           32.512092179507974,
           32.547784394889064,
           32.58347661027016,
           32.61916882565126,
           32.654861041032355,
           32.69055325641345,
           32.72624547179455,
           32.761937687175646,
           32.79762990255675,
           32.83332211793785,
           32.869014333318944,
           32.90470654870004,
           32.94039876408114,
           32.97609097946224,
           33.01178319484333,
           33.047475410224436,
           33.083167625605526,
           33.11885984098663,
           33.15455205636773,
           33.190244271748824,
           33.22593648712992,
           33.26162870251102,
           33.297320917892115,
           33.33301313327321,
           33.368705348654316,
           33.404397564035406,
           33.44008977941651,
           33.47578199479761,
           33.511474210178704,
           33.5471664255598,
           33.5828586409409,
           33.618550856322,
           33.6542430717031,
           33.6899352870842,
           33.725627502465294,
           33.76131971784639,
           33.79701193322749,
           33.832704148608585,
           33.86702058930775,
           33.901061875070525,
           33.9351031608333,
           33.969144446596076,
           34.00318573235885,
           34.037227018121634,
           34.07126830388441,
           34.105309589647185,
           34.13935087540996,
           34.173392161172735,
           34.20743344693551,
           34.241474732698286,
           34.27551601846107,
           34.309557304223844,
           34.34359858998663,
           34.377639875749395,
           34.41168116151218,
           34.44572244727495,
           34.47976373303773,
           34.51380501880051,
           34.54784630456328,
           34.58188759032606,
           34.61592887608884,
           34.64997016185161,
           34.68401144761439,
           34.718052733377164,
           34.75209401913994,
           34.786135304902714,
           34.82017659066549,
           34.85421787642827,
           34.88825916219105,
           34.92230044795383,
           34.9563417337166,
           34.990383019479374,
           35.02442430524216,
           35.05846559100493,
           35.09250687676771,
           35.12654816253048,
           35.160589448293265,
           35.194630734056034,
           35.228672019818816,
           35.26271330558159,
           35.29675459134437,
           35.33079587710714,
           35.364837162869925,
           35.3988784486327,
           35.432919734395476,
           35.46696102015825,
           35.50100230592103,
           35.5350435916838,
           35.569084877446585,
           35.60312616320935,
           35.637167448972136,
           35.67120873473491,
           35.70525002049769,
           35.73929130626047,
           35.77333259202324,
           35.80737387778602,
           35.841415163548795,
           35.87545644931157,
           35.90949773507435,
           35.94353902083713,
           35.977580306599904,
           36.01162159236268,
           36.045662878125455,
           36.07970416388824,
           36.113745449651006,
           36.14778673541379,
           36.181828021176564,
           36.21586930693933,
           36.249910592702115,
           36.28395187846489,
           36.317993164227666,
           36.35203444999044,
           36.38607573575322,
           36.42011702151599,
           36.45415830727877,
           36.48657891507761,
           36.51867538827146,
           36.55077186146531,
           36.58286833465915,
           36.614964807853,
           36.647061281046845,
           36.68254233371404,
           36.719715676117914,
           36.7568890185218,
           36.79406236092567,
           36.83123570332954,
           36.86840904573342,
           36.9055823881373,
           36.94275573054117,
           36.97992907294505,
           37.017102415348916,
           37.05427575775279,
           37.091449100156666,
           37.12862244256054,
           37.16635384182032,
           37.2042493762766,
           37.24214491073289,
           37.28004044518918,
           37.31793597964546,
           37.35583151410175,
           37.393727048558034,
           37.431622583014324,
           37.46951811747061,
           37.50741365192689,
           37.54530918638318,
           37.58320472083947,
           37.62110025529575,
           37.65899578975204,
           37.69689132420832,
           37.73478685866461,
           37.772682393120895,
           37.810577927577185,
           37.84847346203347,
           37.88636899648976,
           37.92426453094604,
           37.96216006540233,
           38.00005559985861,
           38.0379511343149,
           38.075846668771185,
           38.113742203227474,
           38.15163773768376,
           38.18953327214005,
           38.22742880659633,
           38.26532434105262,
           38.3032198755089,
           38.34111540996519,
           38.37901094442147,
           38.41690647887776,
           38.45480201333405,
           38.492697547790335,
           38.530593082246625,
           38.56848861670291,
           38.60638415115919,
           38.64427968561548,
           38.68217522007176,
           38.72007075452805,
           38.75796628898434,
           38.795861823440625,
           38.833757357896914,
           38.8716528923532,
           38.90954842680948,
           38.94744396126577,
           38.98533949572205,
           39.02323503017835,
           39.061130564634624,
           39.09902609909091,
           39.1369216335472,
           39.174817168003486,
           39.21271270245977,
           39.250608236916065,
           39.28850377137235,
           39.32639930582863,
           39.36429484028492,
           39.4021903747412,
           39.44008590919749,
           39.477981443653775,
           39.51587697811006,
           39.55377251256635,
           39.59166804702264,
           39.62956358147892,
           39.6674591159352,
           39.7053546503915,
           39.74325018484778,
           39.781145719304064,
           39.82353405651766,
           39.87041519648858,
           39.917296336459486,
           39.96417747643039,
           40.01105861640131,
           40.05793975637222,
           40.10482089634313,
           40.15170203631405,
           40.198583176284956,
           40.24546431625586,
           40.292345456226776,
           40.33922659619769,
           40.3861077361686,
           40.43298887613951,
           40.479870016110425,
           40.52675115608133,
           40.57363229605224,
           40.62051343602316,
           40.66739457599407,
           40.71427571596497,
           40.761156855935894,
           40.8080379959068,
           40.85491913587771,
           40.90180027584862,
           40.948681415819536,
           40.99556255579044,
           41.04244369576135,
           41.08932483573227,
           41.13620597570318,
           41.183087115674084,
           41.229968255645005,
           41.27684939561592,
           41.32373053558682,
           41.37061167555773,
           41.41749281552865,
           41.46437395549956,
           41.51125509547047,
           41.55813623544138,
           41.60501737541229,
           41.6518985153832,
           41.698779655354116,
           41.74566079532502,
           41.79254193529594,
           41.83942307526685,
           41.886304215237764,
           41.933185355208664,
           41.98006649517958,
           42.02694763515049,
           42.073828775121406,
           42.12070991509232,
           42.16759105506323,
           42.21447219503413,
           42.26135333500505,
           42.30823447497596,
           42.355115614946875,
           42.402035083994186,
           42.450382256319685,
           42.4987294286452,
           42.547076600970705,
           42.595423773296204,
           42.64377094562171,
           42.69211811794721,
           42.74046529027272,
           42.78881246259822,
           42.83715963492372,
           42.88550680724923,
           42.933853979574735,
           42.98220115190025,
           43.030548324225734,
           43.078895496551254,
           43.12724266887676,
           43.17558984120225,
           43.22393701352776,
           43.272284185853266,
           43.32063135817877,
           43.36897853050427,
           43.417325702829785,
           43.465672875155285,
           43.514020047480784,
           43.56236721980629,
           43.6107143921318,
           43.6590615644573,
           43.7074087367828,
           43.65928131512673,
           43.41820470550758,
           43.17712809588842,
           42.93605148626925,
           42.6949748766501,
           42.453898267030944,
           42.212821657411766,
           41.971745047792595,
           41.73066843817347,
           41.489591828554296,
           41.24851521893512,
           41.00743860931597,
           40.76636199969681,
           40.52528539007764,
           40.284208780458485,
           40.04313217083934,
           39.802055561220165,
           39.560978951601015,
           39.31990234198186,
           39.07882573236269,
           38.83774912274352,
           38.59667251312436,
           38.35559590350521,
           38.11451929388603,
           37.873442684266884,
           37.63236607464773,
           37.39128946502856,
           37.15021285540941,
           36.90913624579026,
           36.66805963617108,
           36.4269830265519,
           36.18590641693278,
           35.94482980731361,
           35.70375319769443,
           35.462676588075276,
           35.221599978456126,
           34.98052336883695,
           34.7394467592178,
           34.49837014959865,
           34.25729353997947,
           34.01621693036032,
           33.775140320741166,
           33.534063711121995,
           33.292987101502824,
           33.05191049188367,
           32.81083388226452,
           32.56975727264534,
           32.32868066302619,
           32.08760405340704,
           31.846527443787867,
           31.605450834168714,
           31.364374224549564,
           31.12329761493039,
           30.88222100531122,
           30.641144395692088,
           30.40006778607291,
           30.158991176453736,
           29.917914566834583,
           29.676837957215433,
           29.435761347596262,
           29.19468473797711,
           28.953608128357956,
           28.712531518738782,
           28.47145490911963,
           28.230378299500483,
           27.98930168988131,
           27.74822508026213,
           27.507148470643003,
           27.266071861023825,
           27.02499525140465,
           26.7839186417855,
           26.542842032166348,
           26.301765422547177,
           26.060688812928028,
           25.81961220330887,
           25.578535593689697,
           25.337458984070526,
           25.096382374451395,
           24.85530576483222,
           24.614229155213046,
           24.373152545593893,
           24.11437889879318,
           23.85468864949326,
           23.59391281981639,
           23.3277090882545,
           23.061505356692614,
           22.79530162513073,
           22.529097893568892,
           22.262894162007004,
           21.996690430445117,
           21.73048669888328,
           21.464282967321395,
           21.198079235759508,
           20.93187550419767,
           20.665057142146118,
           20.398212058617148,
           20.131366975088177,
           19.864521891559253,
           19.597676808030283,
           19.33083172450131,
           19.063986640972388,
           18.797141557443414,
           18.530296473914444,
           18.263451390385523,
           17.99660630685655,
           17.72976122332758,
           17.462916139798654,
           17.196071056269684,
           16.929225972740714,
           16.66238088921174,
           16.39553580568282,
           16.12869072215385,
           15.861845638624875,
           15.595000555095954,
           15.328155471566982,
           15.06131038803801,
           14.794465304509087,
           14.527620220980117,
           14.260775137451143,
           13.993930053922172,
           13.727084970393248,
           13.460239886864278,
           13.193394803335305,
           12.926549719806385,
           12.65970463627741,
           12.457254400449095,
           12.300800484406968,
           12.144346568364814,
           11.98789265232266,
           11.831438736280534,
           11.674984820238379,
           11.518530904196224,
           11.362076988154067,
           11.205623072111944,
           11.049169156069787,
           10.892715240027634,
           10.736261323985508,
           10.579807407943354,
           10.423353491901198,
           10.266899575859071,
           10.110445659816918,
           9.953991743774763,
           9.797537827732608,
           9.641083911690483,
           9.484629995648328,
           9.328176079606173,
           9.171722163564047,
           9.015268247521892,
           8.858814331479739,
           8.70236041543761,
           8.545906499395457,
           8.389452583353302,
           8.232998667311175,
           8.076544751269022,
           7.920090835226866,
           7.763636919184712,
           7.607313054749027,
           7.451483393524933,
           7.295653732300838,
           7.139824071076772,
           6.983994409852677,
           6.828164748628583,
           6.672335087404518,
           6.516505426180423,
           6.360675764956327,
           6.204846103732233,
           6.049016442508168
          ],
          [
           31.31088768432102,
           31.34876975814438,
           31.386651831967736,
           31.424533905791098,
           31.462415979614455,
           31.500298053437813,
           31.53818012726117,
           31.57606220108453,
           31.613944274907887,
           31.651826348731248,
           31.689708422554602,
           31.72613059018424,
           31.761822805565338,
           31.797515020946435,
           31.83320723632753,
           31.86889945170863,
           31.90459166708973,
           31.940283882470826,
           31.975976097851923,
           32.011668313233024,
           32.047360528614114,
           32.08305274399521,
           32.11874495937631,
           32.15443717475741,
           32.19012939013851,
           32.225821605519606,
           32.2615138209007,
           32.2972060362818,
           32.3328982516629,
           32.368590467043994,
           32.40428268242509,
           32.439974897806195,
           32.475667113187285,
           32.51135932856839,
           32.54705154394948,
           32.58274375933058,
           32.61843597471168,
           32.65412819009278,
           32.689820405473874,
           32.72551262085497,
           32.761204836236075,
           32.79689705161717,
           32.83258926699827,
           32.868281482379366,
           32.90397369776046,
           32.93966591314156,
           32.975358128522664,
           33.01105034390376,
           33.04674255928485,
           33.082434774665956,
           33.118126990047045,
           33.15381920542815,
           33.189511420809254,
           33.225203636190344,
           33.26089585157144,
           33.29658806695254,
           33.332280282333635,
           33.36797249771474,
           33.403664713095836,
           33.439356928476926,
           33.47504914385803,
           33.51074135923913,
           33.546433574620224,
           33.58212579000133,
           33.61781800538242,
           33.65351022076352,
           33.68920243614461,
           33.724894651525716,
           33.76058686690681,
           33.79627908228791,
           33.83197129766901,
           33.867663513050104,
           33.9033557284312,
           33.9390479438123,
           33.974740159193395,
           34.0104323745745,
           34.04612458995559,
           34.081816805336686,
           34.11750902071779,
           34.15320123609889,
           34.188893451479984,
           34.22458566686108,
           34.26027788224218,
           34.295970097623275,
           34.33028653832244,
           34.364327824085215,
           34.39836910984799,
           34.43241039561077,
           34.46645168137355,
           34.500492967136324,
           34.5345342528991,
           34.568575538661875,
           34.60261682442466,
           34.636658110187426,
           34.67069939595021,
           34.704740681712984,
           34.73878196747576,
           34.77282325323854,
           34.80686453900132,
           34.84090582476409,
           34.87494711052687,
           34.908988396289644,
           34.94302968205242,
           34.977070967815195,
           35.01111225357797,
           35.045153539340745,
           35.07919482510353,
           35.1132361108663,
           35.14727739662908,
           35.181318682391854,
           35.21535996815463,
           35.24940125391741,
           35.28344253968018,
           35.31748382544296,
           35.351525111205746,
           35.385566396968514,
           35.41960768273129,
           35.453648968494065,
           35.48769025425685,
           35.521731540019616,
           35.5557728257824,
           35.58981411154518,
           35.62385539730795,
           35.65789668307073,
           35.69193796883351,
           35.72597925459628,
           35.76002054035906,
           35.79406182612183,
           35.828103111884616,
           35.86214439764739,
           35.89618568341016,
           35.93022696917295,
           35.96426825493572,
           35.99830954069849,
           36.032350826461276,
           36.06639211222405,
           36.10043339798682,
           36.1344746837496,
           36.168515969512384,
           36.20255725527515,
           36.23659854103793,
           36.27063982680071,
           36.304681112563486,
           36.338722398326254,
           36.372763684089044,
           36.40680496985181,
           36.44084625561459,
           36.47488754137737,
           36.508928827140146,
           36.54297011290293,
           36.5770113986657,
           36.61105268442847,
           36.645093970191255,
           36.67913525595403,
           36.713176541716805,
           36.74721782747959,
           36.78125911324236,
           36.81710957418776,
           36.85296003560041,
           36.88881049701306,
           36.92466095842571,
           36.960511419838355,
           36.996361881251005,
           37.03221234266365,
           37.0680628040763,
           37.10391326548895,
           37.13976372690159,
           37.1775451518249,
           37.21629205850354,
           37.25503896518219,
           37.29378587186083,
           37.332532778539466,
           37.37127968521811,
           37.41002659189675,
           37.44877349857539,
           37.487520405254045,
           37.52626731193268,
           37.56501421861132,
           37.60376112528996,
           37.6425080319686,
           37.68125493864724,
           37.72000184532588,
           37.75874875200452,
           37.79749565868316,
           37.83624256536181,
           37.87498947204045,
           37.913736378719086,
           37.95248328539773,
           37.99123019207637,
           38.02997709875501,
           38.06872400543366,
           38.1074709121123,
           38.14621781879094,
           38.184964725469584,
           38.22371163214822,
           38.26185757099066,
           38.29975310544694,
           38.33764863990322,
           38.37554417435951,
           38.413439708815794,
           38.45133524327208,
           38.489230777728366,
           38.527126312184656,
           38.56502184664094,
           38.60291738109723,
           38.64081291555351,
           38.6787084500098,
           38.71660398446609,
           38.75449951892237,
           38.792395053378655,
           38.830290587834945,
           38.868186122291235,
           38.90608165674752,
           38.9439771912038,
           38.98187272566009,
           39.01976826011637,
           39.05766379457266,
           39.095559329028944,
           39.13345486348523,
           39.171350397941524,
           39.209245932397806,
           39.247141466854096,
           39.285037001310386,
           39.322932535766654,
           39.36082807022295,
           39.39872360467923,
           39.43661913913552,
           39.47451467359181,
           39.512410208048095,
           39.550305742504385,
           39.58820127696066,
           39.62609681141696,
           39.66399234587324,
           39.70188788032953,
           39.73978341478581,
           39.7776789492421,
           39.815574483698384,
           39.85347001815467,
           39.891365552610964,
           39.929261087067246,
           39.96715662152353,
           40.00505215597982,
           40.04294769043611,
           40.08084322489239,
           40.11873875934867,
           40.15663429380496,
           40.194529828261246,
           40.232425362717535,
           40.27032089717382,
           40.30821643163011,
           40.35060476884371,
           40.397485908814616,
           40.44436704878553,
           40.49124818875644,
           40.53812932872735,
           40.58501046869826,
           40.63189160866917,
           40.678772748640085,
           40.725653888611006,
           40.7725350285819,
           40.81941616855282,
           40.866297308523734,
           40.91317844849465,
           40.96005958846555,
           41.00694072843646,
           41.053821868407375,
           41.10070300837828,
           41.147584148349196,
           41.1944652883201,
           41.241346428291024,
           41.28822756826193,
           41.335108708232845,
           41.38198984820375,
           41.428870988174666,
           41.47575212814557,
           41.522633268116486,
           41.5695144080874,
           41.61639554805831,
           41.66327668802922,
           41.71015782800013,
           41.75703896797105,
           41.80513701311803,
           41.85348418544353,
           41.901831357769034,
           41.95017853009455,
           41.99852570242005,
           42.04687287474555,
           42.09522004707105,
           42.14356721939656,
           42.191914391722065,
           42.24026156404757,
           42.28860873637307,
           42.33695590869857,
           42.385303081024084,
           42.4336502533496,
           42.48199742567509,
           42.5303445980006,
           42.5786917703261,
           42.62703894265161,
           42.67538611497711,
           42.723733287302615,
           42.77208045962812,
           42.82042763195362,
           42.86877480427913,
           42.91712197660464,
           42.96546914893014,
           43.013816321255646,
           43.06216349358115,
           43.11051066590665,
           43.15885783823215,
           43.20720501055766,
           43.255552182883164,
           43.30389935520867,
           43.35224652753418,
           43.400593699859684,
           43.448940872185176,
           43.49728804451068,
           43.545635216836196,
           43.593982389161695,
           43.6423295614872,
           43.69067673381271,
           43.739023906138215,
           43.787371078463714,
           43.83571825078922,
           43.88406542311473,
           43.932412595440226,
           43.98075976776573,
           44.02910694009123,
           44.07745411241673,
           44.125801284742245,
           44.17414845706775,
           44.22249562939325,
           44.27084280171876,
           44.22271538006268,
           43.981638770443524,
           43.740562160824375,
           43.4994855512052,
           43.25840894158605,
           43.01733233196689,
           42.77625572234772,
           42.53517911272855,
           42.29410250310942,
           42.05302589349024,
           41.81194928387107,
           41.570872674251916,
           41.329796064632774,
           41.08871945501359,
           40.84764284539445,
           40.60656623577529,
           40.36548962615612,
           40.12441301653696,
           39.88333640691781,
           39.642259797298635,
           39.401183187679464,
           39.16010657806031,
           38.919029968441166,
           38.67795335882198,
           38.43687674920284,
           38.19580013958368,
           37.95472352996451,
           37.713646920345354,
           37.472570310726205,
           37.23149370110703,
           36.990417091487856,
           36.74934048186873,
           36.50826387224956,
           36.26718726263039,
           36.02611065301123,
           35.78503404339207,
           35.5439574337729,
           35.301470731726766,
           35.041780482426866,
           34.782090233126944,
           34.52239998382704,
           34.26270973452715,
           34.00301948522722,
           33.74332923592729,
           33.4836389866274,
           33.22394873732749,
           32.96425848802757,
           32.704568238727674,
           32.44487798942777,
           32.185187740127844,
           31.925497490827944,
           31.665807241528046,
           31.406116992228124,
           31.146426742928195,
           30.886736493628323,
           30.627046244328398,
           30.367355995028475,
           30.107665745728575,
           29.847975496428674,
           29.58828524712875,
           29.328594997828848,
           29.06890474852895,
           28.80921449922902,
           28.54952424992912,
           28.28983400062922,
           28.030143751329305,
           27.770453502029376,
           27.5107632527295,
           27.251073003429575,
           26.991382754129653,
           26.73169250482975,
           26.47200225552985,
           26.21231200622993,
           25.952621756930025,
           25.692931507630124,
           25.433241258330202,
           25.173551009030277,
           24.913860759730404,
           24.654170510430475,
           24.394480261130553,
           24.134790011830653,
           23.875099762530752,
           23.61540951323083,
           23.354633683553956,
           23.08842995199207,
           22.82222622043019,
           22.5560224888683,
           22.289818757306463,
           22.023615025744576,
           21.75741129418269,
           21.49120756262085,
           21.225003831058963,
           20.95880009949708,
           20.692596367935245,
           20.426392636373354,
           20.160188904811466,
           19.893985173249582,
           19.627781441687745,
           19.361577710125857,
           19.09537397856397,
           18.829170247002136,
           18.56296651544025,
           18.29676278387836,
           18.030559052316526,
           17.76435532075464,
           17.49815158919275,
           17.231947857630914,
           16.965744126069026,
           16.699540394507142,
           16.433336662945255,
           16.167132931383417,
           15.900929199821528,
           15.637669451930948,
           15.377687629106756,
           15.117705806282512,
           14.857723983458273,
           14.59774216063408,
           14.337760337809836,
           14.077778514985596,
           13.817796692161354,
           13.557814869337161,
           13.29783304651292,
           13.037851223688676,
           12.777869400864484,
           12.517887578040245,
           12.3222913985147,
           12.172684964202523,
           12.023078529890318,
           11.873472095578116,
           11.723865661265936,
           11.574259226953732,
           11.424652792641526,
           11.275046358329323,
           11.125439924017146,
           10.975833489704941,
           10.826227055392737,
           10.67662062108056,
           10.527014186768357,
           10.373091928442943,
           10.217262267218876,
           10.06143260599478,
           9.905602944770687,
           9.749773283546592,
           9.593943622322527,
           9.43811396109843,
           9.282284299874338,
           9.126454638650271,
           8.970624977426176,
           8.814795316202082,
           8.658965654978015,
           8.503135993753922,
           8.347306332529826,
           8.191476671305761,
           8.035647010081666,
           7.879817348857573,
           7.723987687633477,
           7.568158026409411,
           7.412328365185316,
           7.256498703961222,
           7.100669042737156,
           6.944839381513061,
           6.789009720288966,
           6.633180059064902,
           6.477350397840807,
           6.321520736616712,
           6.165691075392617,
           6.009861414168551
          ],
          [
           31.733963065181143,
           31.771845139004505,
           31.80972721282786,
           31.84760928665122,
           31.885491360474578,
           31.923373434297936,
           31.961255508121297,
           31.999137581944655,
           32.03701965576801,
           32.074901729591375,
           32.11278380341473,
           32.15066587723809,
           32.188547951061445,
           32.226430024884806,
           32.26431209870816,
           32.30219417253152,
           32.340076246354876,
           32.37795832017824,
           32.41584039400159,
           32.45372246782495,
           32.491604541648314,
           32.52948661547167,
           32.56736868929503,
           32.60525076311839,
           32.643132836941746,
           32.68101491076511,
           32.71889698458846,
           32.75641408180055,
           32.79210629718165,
           32.82779851256275,
           32.86349072794385,
           32.899182943324945,
           32.93487515870604,
           32.97056737408714,
           33.006259589468236,
           33.04195180484933,
           33.07764402023043,
           33.11333623561153,
           33.14902845099263,
           33.18472066637372,
           33.22041288175482,
           33.25610509713592,
           33.29179731251702,
           33.327489527898116,
           33.36318174327921,
           33.39887395866031,
           33.43456617404141,
           33.47025838942251,
           33.5059506048036,
           33.541642820184705,
           33.577335035565795,
           33.6130272509469,
           33.648719466328,
           33.68441168170909,
           33.72010389709019,
           33.75579611247129,
           33.791488327852385,
           33.82718054323348,
           33.862872758614586,
           33.89856497399568,
           33.93425718937678,
           33.96994940475788,
           34.005641620138974,
           34.04133383552007,
           34.077026050901175,
           34.11271826628227,
           34.14841048166336,
           34.184102697044466,
           34.219794912425556,
           34.25548712780666,
           34.291179343187764,
           34.326871558568854,
           34.36256377394996,
           34.39825598933105,
           34.43394820471215,
           34.46964042009324,
           34.505332635474346,
           34.54102485085544,
           34.57671706623654,
           34.61240928161764,
           34.648101496998734,
           34.68379371237983,
           34.71948592776093,
           34.755178143142025,
           34.78949458384119,
           34.823535869603965,
           34.85757715536674,
           34.89161844112952,
           34.92565972689229,
           34.95970101265507,
           34.99374229841785,
           35.027783584180625,
           35.0618248699434,
           35.095866155706176,
           35.12990744146896,
           35.16394872723173,
           35.19799001299451,
           35.232031298757285,
           35.26607258452007,
           35.30011387028284,
           35.33415515604562,
           35.368196441808394,
           35.40223772757117,
           35.436279013333944,
           35.47032029909672,
           35.5043615848595,
           35.53840287062228,
           35.57244415638505,
           35.60648544214783,
           35.640526727910604,
           35.67456801367338,
           35.70860929943616,
           35.74265058519893,
           35.77669187096171,
           35.810733156724496,
           35.844774442487264,
           35.87881572825004,
           35.912857014012815,
           35.9468982997756,
           35.98093958553837,
           36.01498087130115,
           36.04902215706392,
           36.0830634428267,
           36.11710472858948,
           36.15114601435226,
           36.18518730011503,
           36.21922858587781,
           36.25326987164058,
           36.287311157403366,
           36.32135244316614,
           36.35539372892892,
           36.38943501469169,
           36.42347630045447,
           36.45751758621724,
           36.49155887198002,
           36.5256001577428,
           36.559641443505576,
           36.59368272926835,
           36.62772401503113,
           36.66176530079391,
           36.69671117421289,
           36.73256163562554,
           36.76841209703819,
           36.80426255845083,
           36.84011301986348,
           36.87596348127613,
           36.911813942688774,
           36.947664404101424,
           36.98351486551407,
           37.01936532692672,
           37.05521578833937,
           37.09106624975201,
           37.12691671116466,
           37.16276717257731,
           37.198617633989954,
           37.234468095402605,
           37.270318556815255,
           37.3061690182279,
           37.34201947964055,
           37.37786994105319,
           37.41372040246584,
           37.44957086387849,
           37.485421325291135,
           37.52127178670378,
           37.55712224811643,
           37.592972709529086,
           37.62882317094173,
           37.66660459586504,
           37.70535150254367,
           37.74409840922232,
           37.782845315900964,
           37.821592222579596,
           37.860339129258236,
           37.89908603593688,
           37.93783294261552,
           37.97657984929416,
           38.01532675597281,
           38.05407366265145,
           38.092820569330094,
           38.13156747600873,
           38.17031438268737,
           38.20906128936601,
           38.24780819604465,
           38.2865551027233,
           38.32530200940194,
           38.364048916080584,
           38.40279582275922,
           38.44154272943786,
           38.4802896361165,
           38.51903654279514,
           38.55778344947379,
           38.59653035615243,
           38.63527726283107,
           38.67402416950971,
           38.712771076188346,
           38.75151798286699,
           38.79026488954563,
           38.82901179622428,
           38.86775870290292,
           38.90650560958156,
           38.9452525162602,
           38.983999422938844,
           39.02274632961748,
           39.06149323629612,
           39.10024014297477,
           39.13898704965341,
           39.17773395633205,
           39.21648086301069,
           39.25522776968933,
           39.29397467636797,
           39.33272158304661,
           39.37146848972526,
           39.4102153964039,
           39.44896230308254,
           39.48770920976117,
           39.52645611643982,
           39.56520302311846,
           39.603949929797096,
           39.642696836475736,
           39.68144374315439,
           39.72019064983303,
           39.75893755651167,
           39.79768446319031,
           39.83643136986895,
           39.87517827654759,
           39.91392518322623,
           39.95267208990487,
           39.99141899658351,
           40.03016590326215,
           40.0689128099408,
           40.10765971661944,
           40.14640662329808,
           40.18515352997672,
           40.22390043665536,
           40.262647343334,
           40.30139425001264,
           40.34014115669128,
           40.37888806336993,
           40.41763497004857,
           40.45633179939329,
           40.49422733384958,
           40.53212286830586,
           40.57001840276215,
           40.60791393721844,
           40.645809471674724,
           40.683705006131014,
           40.721600540587296,
           40.759496075043586,
           40.79739160949987,
           40.83528714395615,
           40.87767548116975,
           40.92455662114067,
           40.971437761111574,
           41.01831890108249,
           41.0652000410534,
           41.11208118102431,
           41.15989176991638,
           41.20823894224188,
           41.256586114567384,
           41.30493328689288,
           41.3532804592184,
           41.4016276315439,
           41.44997480386941,
           41.49832197619491,
           41.54666914852042,
           41.595016320845914,
           41.64336349317142,
           41.69171066549693,
           41.740057837822434,
           41.78840501014794,
           41.83675218247344,
           41.885099354798946,
           41.933446527124445,
           41.98179369944995,
           42.03014087177546,
           42.07848804410096,
           42.126835216426464,
           42.17518238875198,
           42.22352956107748,
           42.271876733402976,
           42.32022390572848,
           42.36857107805399,
           42.416918250379496,
           42.465265422705,
           42.51361259503051,
           42.561959767356015,
           42.610306939681514,
           42.65865411200702,
           42.70700128433252,
           42.75534845665803,
           42.80369562898353,
           42.85204280130903,
           42.90038997363454,
           42.94873714596004,
           42.99708431828555,
           43.04543149061105,
           43.09377866293656,
           43.142125835262064,
           43.19047300758757,
           43.23882017991308,
           43.28716735223858,
           43.33551452456408,
           43.38386169688958,
           43.43218171370249,
           43.48049041579658,
           43.528799117890664,
           43.57710781998475,
           43.62541652207883,
           43.67372522417292,
           43.722033926267,
           43.7703426283611,
           43.81865133045518,
           43.86696003254927,
           43.915268734643355,
           43.96357743673744,
           44.01188613883153,
           44.060194840925625,
           44.10850354301971,
           44.15681224511379,
           44.205120947207874,
           44.25342964930197,
           44.301738351396054,
           44.35004705349014,
           44.39835575558423,
           44.44666445767831,
           44.4949731597724,
           44.54328186186649,
           44.59159056396057,
           44.63989926605466,
           44.688207968148745,
           44.736516670242835,
           44.784825372336925,
           44.83313407443101,
           44.77584688012013,
           44.50736789299943,
           44.23888890587873,
           43.970409918758016,
           43.701930931637314,
           43.43345194451662,
           43.1649729573959,
           42.89649397027517,
           42.6280149831545,
           42.35953599603378,
           42.091057008913054,
           41.82257802179236,
           41.55444782796208,
           41.29475757866216,
           41.035067329362256,
           40.775377080062356,
           40.515686830762434,
           40.25599658146253,
           39.99630633216263,
           39.7366160828627,
           39.47692583356278,
           39.21723558426288,
           38.95754533496299,
           38.69785508566306,
           38.43816483636316,
           38.17847458706326,
           37.91878433776333,
           37.65909408846343,
           37.399403839163526,
           37.139713589863604,
           36.88002334056369,
           36.62033309126381,
           36.36064284196389,
           36.100952592663965,
           35.84126234336406,
           35.581572094064164,
           35.321881844764235,
           35.062191595464334,
           34.80250134616443,
           34.54281109686451,
           34.28312084756461,
           34.02343059826471,
           33.76374034896479,
           33.504050099664866,
           33.244359850364965,
           32.98466960106506,
           32.72497935176514,
           32.465289102465235,
           32.20559885316534,
           31.945908603865412,
           31.68621835456551,
           31.42652810526561,
           31.166837855965692,
           30.90714760666576,
           30.64745735736589,
           30.38776710806596,
           30.12807685876604,
           29.868386609466143,
           29.608696360166242,
           29.349006110866316,
           29.089315861566416,
           28.82962561226652,
           28.56993536296659,
           28.310245113666696,
           28.050554864366788,
           27.790864615066866,
           27.531174365766944,
           27.271484116467068,
           27.011793867167142,
           26.75210361786722,
           26.492413368567313,
           26.23272311926742,
           25.973032869967497,
           25.713342620667593,
           25.453652371367692,
           25.19396212206777,
           24.934271872767845,
           24.674581623467972,
           24.414891374168043,
           24.155201124868118,
           23.89551087556822,
           23.63582062626832,
           23.376130376968394,
           23.115354547291528,
           22.84915081572964,
           22.58294708416775,
           22.316743352605865,
           22.05053962104403,
           21.784335889482144,
           21.518132157920256,
           21.25192842635842,
           20.985724694796534,
           20.719520963234647,
           20.45331723167281,
           20.187113500110925,
           19.92090976854903,
           19.65815093636156,
           19.398169113537367,
           19.138187290713127,
           18.878205467888883,
           18.61822364506469,
           18.358241822240448,
           18.098259999416207,
           17.838278176592016,
           17.578296353767772,
           17.318314530943532,
           17.058332708119337,
           16.798350885295097,
           16.538369062470856,
           16.278387239646612,
           16.018405416822418,
           15.758423593998177,
           15.498441771173935,
           15.238459948349742,
           14.978478125525504,
           14.718496302701261,
           14.458514479877067,
           14.198532657052827,
           13.938550834228586,
           13.678569011404342,
           13.41858718858015,
           13.158605365755909,
           12.898623542931666,
           12.638641720107472,
           12.378659897283232,
           12.183063717757687,
           12.033457283445511,
           11.883850849133308,
           11.734244414821104,
           11.584637980508926,
           11.435031546196722,
           11.285425111884516,
           11.135818677572312,
           10.986212243260134,
           10.836605808947931,
           10.686999374635725,
           10.53739294032355,
           10.387786506011345,
           10.238180071699139,
           10.088573637386963,
           9.938967203074757,
           9.789360768762553,
           9.639754334450348,
           9.490147900138172,
           9.340541465825966,
           9.190935031513762,
           9.041328597201584,
           8.89172216288938,
           8.742115728577176,
           8.592509294264998,
           8.442902859952795,
           8.29329642564059,
           8.143689991328412,
           7.994083557016206,
           7.840662320517954,
           7.6848326592938605,
           7.529002998069795,
           7.373173336845699,
           7.217343675621605,
           7.061514014397539,
           6.905684353173445,
           6.74985469194935,
           6.594025030725284,
           6.438195369501189,
           6.282365708277095,
           6.126536047053,
           5.970706385828935
          ],
          [
           32.15703844604126,
           32.194920519864624,
           32.23280259368798,
           32.27068466751133,
           32.308566741334694,
           32.346448815158055,
           32.38433088898141,
           32.42221296280477,
           32.46009503662813,
           32.49797711045149,
           32.53585918427485,
           32.5737412580982,
           32.611623331921564,
           32.649505405744925,
           32.68738747956829,
           32.72526955339164,
           32.763151627214995,
           32.80103370103836,
           32.83891577486172,
           32.87679784868507,
           32.914679922508434,
           32.952561996331795,
           32.99044407015515,
           33.02832614397851,
           33.066208217801865,
           33.10409029162522,
           33.14197236544858,
           33.17985443927194,
           33.217736513095296,
           33.25561858691866,
           33.29350066074202,
           33.33138273456538,
           33.369264808388735,
           33.40714688221209,
           33.44502895603545,
           33.48291102985881,
           33.520793103682166,
           33.55867517750552,
           33.59655725132889,
           33.63443932515224,
           33.6723213989756,
           33.71020347279896,
           33.74808554662232,
           33.785967620445675,
           33.822389788797956,
           33.85808200417906,
           33.89377421956016,
           33.929466434941254,
           33.96515865032235,
           34.00085086570345,
           34.036543081084545,
           34.07223529646564,
           34.107927511846746,
           34.14361972722784,
           34.17931194260894,
           34.21500415799004,
           34.250696373371134,
           34.28638858875223,
           34.32208080413333,
           34.357773019514426,
           34.39346523489553,
           34.42915745027663,
           34.464849665657724,
           34.50054188103882,
           34.53623409641992,
           34.57192631180102,
           34.60761852718211,
           34.643310742563216,
           34.679002957944306,
           34.71469517332541,
           34.75038738870651,
           34.786079604087604,
           34.8217718194687,
           34.8574640348498,
           34.893156250230895,
           34.92884846561199,
           34.96454068099309,
           35.000232896374186,
           35.03592511175529,
           35.07161732713639,
           35.107309542517484,
           35.14300175789858,
           35.17869397327968,
           35.214386188660775,
           35.24870262935994,
           35.282743915122715,
           35.31678520088549,
           35.350826486648266,
           35.38486777241104,
           35.418909058173824,
           35.45295034393659,
           35.486991629699375,
           35.52103291546215,
           35.555074201224926,
           35.58911548698771,
           35.62315677275048,
           35.65719805851326,
           35.691239344276035,
           35.72528063003882,
           35.759321915801586,
           35.79336320156437,
           35.827404487327144,
           35.86144577308992,
           35.895487058852694,
           35.92952834461547,
           35.96356963037825,
           35.99761091614103,
           36.0316522019038,
           36.06569348766658,
           36.099734773429354,
           36.13377605919213,
           36.16781734495491,
           36.20185863071768,
           36.23589991648046,
           36.26994120224324,
           36.303982488006014,
           36.33802377376879,
           36.372065059531565,
           36.40610634529435,
           36.44014763105712,
           36.4741889168199,
           36.50823020258267,
           36.54227148834545,
           36.57631277423802,
           36.61216323565067,
           36.648013697063305,
           36.68386415847596,
           36.719714619888606,
           36.755565081301256,
           36.79141554271391,
           36.82726600412655,
           36.8631164655392,
           36.89896692695184,
           36.93481738836449,
           36.97066784977714,
           37.00651831118979,
           37.04236877260243,
           37.07821923401508,
           37.11406969542773,
           37.14992015684038,
           37.185770618253024,
           37.221621079665674,
           37.25747154107832,
           37.29332200249097,
           37.32917246390362,
           37.36502292531626,
           37.40087338672891,
           37.436723848141554,
           37.472574309554204,
           37.508424770966855,
           37.5442752323795,
           37.58012569379215,
           37.6159761552048,
           37.65182661661744,
           37.68767707803009,
           37.723527539442735,
           37.759378000855385,
           37.79522846226803,
           37.83107892368068,
           37.86692938509333,
           37.90277984650597,
           37.93863030791863,
           37.974480769331265,
           38.01033123074391,
           38.046181692156566,
           38.08203215356921,
           38.11788261498186,
           38.15566403990516,
           38.1944109465838,
           38.23315785326245,
           38.271904759941094,
           38.310651666619734,
           38.34939857329838,
           38.38814547997702,
           38.42689238665565,
           38.4656392933343,
           38.50438620001294,
           38.54313310669158,
           38.581880013370224,
           38.62062692004886,
           38.6593738267275,
           38.69812073340614,
           38.73686764008478,
           38.77561454676342,
           38.81436145344206,
           38.85310836012071,
           38.891855266799354,
           38.93060217347799,
           38.96934908015663,
           39.00809598683527,
           39.04684289351392,
           39.08558980019255,
           39.1243367068712,
           39.163083613549844,
           39.201830520228484,
           39.24057742690712,
           39.27932433358576,
           39.3180712402644,
           39.35681814694305,
           39.39556505362168,
           39.434311960300334,
           39.473058866978974,
           39.51180577365761,
           39.55055268033625,
           39.58929958701489,
           39.62804649369353,
           39.66679340037217,
           39.70554030705082,
           39.744287213729464,
           39.783034120408104,
           39.82178102708674,
           39.86052793376538,
           39.89927484044402,
           39.93802174712266,
           39.976768653801315,
           40.015515560479955,
           40.054262467158594,
           40.09300937383723,
           40.13175628051587,
           40.17050318719451,
           40.20925009387315,
           40.2479970005518,
           40.286743907230445,
           40.32549081390908,
           40.364237720587724,
           40.40298462726636,
           40.441731533945,
           40.48047844062364,
           40.51922534730228,
           40.557972253980935,
           40.59715837704404,
           40.63681508481107,
           40.6764717925781,
           40.71612850034512,
           40.75578520811215,
           40.79544191587918,
           40.83509862364621,
           40.87475533141323,
           40.91441203918026,
           40.95406874694729,
           40.99372545471432,
           41.033382162481345,
           41.073038870248375,
           41.11269557801539,
           41.15235228578243,
           41.19200899354945,
           41.23166570131648,
           41.2713224090835,
           41.31097911685053,
           41.35063582461757,
           41.395276635880364,
           41.44490155063893,
           41.49452646539751,
           41.54415138015608,
           41.593776294914655,
           41.643401209673236,
           41.6930261244318,
           41.74265103919038,
           41.79227595394895,
           41.84190086870752,
           41.89152578346609,
           41.941150698224675,
           41.99077561298324,
           42.04040052774181,
           42.0900254425004,
           42.139650357258965,
           42.18927527201754,
           42.238900186776114,
           42.28852510153469,
           42.338150016293255,
           42.38777493105184,
           42.43739984581041,
           42.48702476056897,
           42.53664967532755,
           42.586075500897934,
           42.63438420299202,
           42.6826929050861,
           42.73100160718019,
           42.77931030927428,
           42.82761901136836,
           42.87592771346245,
           42.92423641555654,
           42.97254511765062,
           43.020853819744715,
           43.06916252183879,
           43.11747122393289,
           43.165779926026964,
           43.21408862812106,
           43.262397330215144,
           43.31070603230923,
           43.35901473440332,
           43.40732343649741,
           43.45563213859149,
           43.50394084068557,
           43.55224954277967,
           43.600558244873746,
           43.64886694696784,
           43.69717564906193,
           43.745484351156016,
           43.7937930532501,
           43.84210175534419,
           43.89041045743827,
           43.938719159532354,
           43.98702786162645,
           44.035336563720534,
           44.083645265814624,
           44.1319539679087,
           44.1802626700028,
           44.22857137209688,
           44.27688007419097,
           44.32518877628506,
           44.37349747837914,
           44.421806180473226,
           44.470114882567316,
           44.518423584661406,
           44.56673228675549,
           44.615040988849586,
           44.66334969094367,
           44.71165839303775,
           44.75996709513184,
           44.80827579722593,
           44.856584499320014,
           44.9048932014141,
           44.95320190350819,
           45.00151060560228,
           45.04981930769636,
           45.09812800979044,
           45.14643671188453,
           45.194745413978616,
           45.243054116072706,
           45.291362818166796,
           45.33967152026088,
           45.38798022235497,
           45.330693028044095,
           45.062214040923394,
           44.79373505380269,
           44.525256066681976,
           44.256777079561274,
           43.98829809244057,
           43.71981910531986,
           43.45134011819913,
           43.182861131078454,
           42.91438214395774,
           42.645903156837015,
           42.37742416971632,
           42.10894518259562,
           41.8404661954749,
           41.5719872083542,
           41.3035082212335,
           41.035029234112784,
           40.76655024699208,
           40.49807125987138,
           40.229592272750665,
           39.961113285629935,
           39.69263429850925,
           39.424155311388546,
           39.15567632426782,
           38.88719733714713,
           38.61871835002643,
           38.35023936290571,
           38.08176037578501,
           37.81328138866431,
           37.544802401543585,
           37.27632341442286,
           37.00784442730219,
           36.73936544018147,
           36.47088645306074,
           36.202407465940055,
           35.933928478819354,
           35.66544949169863,
           35.396970504577936,
           35.128491517457235,
           34.86001253033651,
           34.59153354321581,
           34.323054556095116,
           34.05457556897439,
           33.78609658185367,
           33.517617594732975,
           33.249138607612274,
           32.98065962049155,
           32.71218063337085,
           32.443701646250155,
           32.17522265912943,
           31.906743672008734,
           31.638264684888043,
           31.36978569776732,
           31.101306710646593,
           30.832827723525924,
           30.5643487364052,
           30.295869749284474,
           30.02739076216378,
           29.75891177504308,
           29.490432787922355,
           29.221953800801657,
           28.953474813680963,
           28.68499582656024,
           28.41651683943954,
           28.148037852318847,
           27.879558865198124,
           27.611079878077405,
           27.342600890956728,
           27.07412190383601,
           26.805642916715282,
           26.537163929594584,
           26.268684942473886,
           26.000205955353167,
           25.73172696823247,
           25.46324798111177,
           25.177511260055315,
           24.889249008464347,
           24.600986756873425,
           24.312724505282453,
           24.02446225369148,
           23.736200002100535,
           23.44793775050959,
           23.159675498918613,
           22.876200168392053,
           22.616659443187224,
           22.357118717982395,
           22.097577992777566,
           21.838037267572783,
           21.578496542367954,
           21.318955817163125,
           21.059415091958343,
           20.799874366753517,
           20.54033364154869,
           20.280792916343906,
           20.021252191139077,
           19.761711465934244,
           19.50217074072942,
           19.242630015524636,
           18.983089290319807,
           18.723548565114974,
           18.464007839910195,
           18.204467114705366,
           17.944926389500537,
           17.685385664295758,
           17.425844939090926,
           17.1663042138861,
           16.906763488681317,
           16.64722276347649,
           16.387682038271656,
           16.128141313066827,
           15.868600587862048,
           15.609059862657217,
           15.34951913745239,
           15.089978412247607,
           14.830437687042778,
           14.57089696183795,
           14.311356236633168,
           14.051815511428337,
           13.792274786223508,
           13.532734061018678,
           13.273193335813898,
           13.013652610609068,
           12.75411188540424,
           12.494571160199458,
           12.236436203105566,
           12.047953594379791,
           11.899073422830565,
           11.749901574704094,
           11.60072972657762,
           11.451557878451176,
           11.302386030324703,
           11.153214182198232,
           11.00404233407176,
           10.854870485945314,
           10.705698637818845,
           10.556526789692374,
           10.407354941565925,
           10.258183093439456,
           10.109011245312983,
           9.95983939718654,
           9.810667549060067,
           9.661495700933596,
           9.512323852807123,
           9.36315200468068,
           9.213980156554207,
           9.064808308427736,
           8.91563646030129,
           8.76646461217482,
           8.617292764048347,
           8.468120915921904,
           8.318949067795433,
           8.16977721966896,
           8.020605371542514,
           7.871433523416043,
           7.7222616752895705,
           7.573089827163099,
           7.423917979036656,
           7.274746130910183,
           7.125574282783711,
           6.976402434657268,
           6.827230586530796,
           6.6780587384043235,
           6.52888689027788,
           6.379715042151408,
           6.230543194024935,
           6.0813713458984635,
           5.932199497772019
          ],
          [
           32.58011382690138,
           32.617995900724736,
           32.65587797454809,
           32.69376004837145,
           32.73164212219481,
           32.76952419601817,
           32.80740626984152,
           32.84528834366489,
           32.883170417488245,
           32.921052491311606,
           32.95893456513496,
           32.99681663895832,
           33.034698712781676,
           33.07258078660504,
           33.1104628604284,
           33.14834493425175,
           33.18622700807511,
           33.22410908189847,
           33.26199115572183,
           33.299873229545184,
           33.337755303368546,
           33.37563737719191,
           33.41351945101526,
           33.45140152483862,
           33.489283598661984,
           33.52716567248534,
           33.56504774630869,
           33.602929820132054,
           33.640811893955416,
           33.67869396777877,
           33.71657604160213,
           33.75445811542549,
           33.79234018924885,
           33.83022226307221,
           33.86810433689557,
           33.905986410718924,
           33.94386848454228,
           33.98175055836564,
           34.019632632189,
           34.057514706012356,
           34.09539677983572,
           34.13327885365908,
           34.17116092748243,
           34.20904300130579,
           34.24692507512915,
           34.2848071489525,
           34.322689222775864,
           34.360571296599225,
           34.39845337042258,
           34.43633544424594,
           34.4742175180693,
           34.51209959189266,
           34.54998166571602,
           34.58786373953937,
           34.625745813362734,
           34.66362788718609,
           34.70150996100945,
           34.73939203483282,
           34.777274108656165,
           34.815156182479534,
           34.852673280414265,
           34.88836549579536,
           34.92405771117646,
           34.959749926557556,
           34.99544214193865,
           35.03113435731975,
           35.066826572700855,
           35.10251878808195,
           35.13821100346305,
           35.173903218844146,
           35.20959543422524,
           35.24528764960634,
           35.28097986498744,
           35.316672080368534,
           35.35236429574964,
           35.388056511130735,
           35.42374872651183,
           35.45944094189292,
           35.495133157274026,
           35.53082537265512,
           35.56651758803622,
           35.60220980341732,
           35.637902018798414,
           35.67359423417951,
           35.707910674878676,
           35.74195196064146,
           35.77599324640423,
           35.810034532167,
           35.844075817929784,
           35.87811710369256,
           35.912158389455335,
           35.94619967521811,
           35.980240960980886,
           36.01428224674367,
           36.048323532506444,
           36.08236481826922,
           36.116406104032,
           36.15044738979477,
           36.18448867555755,
           36.21852996132033,
           36.252571247083104,
           36.28661253284588,
           36.32065381860866,
           36.35469510437144,
           36.38873639013421,
           36.42277767589698,
           36.45681896165976,
           36.491764835675774,
           36.52761529708843,
           36.56346575850107,
           36.599316219913725,
           36.63516668132637,
           36.67101714273901,
           36.70686760415167,
           36.74271806556431,
           36.77856852697696,
           36.814418988389605,
           36.850269449802255,
           36.8861199112149,
           36.92197037262755,
           36.95782083404019,
           36.99367129545284,
           37.02952175686549,
           37.065372218278135,
           37.10122267969078,
           37.13707314110343,
           37.17292360251608,
           37.20877406392873,
           37.24462452534137,
           37.280474986754015,
           37.316325448166666,
           37.352175909579316,
           37.388026370991966,
           37.42387683240461,
           37.45972729381726,
           37.49557775522991,
           37.53142821664255,
           37.5672786780552,
           37.60312913946785,
           37.638979600880496,
           37.67483006229314,
           37.71068052370579,
           37.74653098511844,
           37.78238144653109,
           37.81823190794373,
           37.85408236935638,
           37.88993283076903,
           37.92578329218168,
           37.96163375359432,
           37.99748421500697,
           38.033334676419614,
           38.069185137832264,
           38.105035599244914,
           38.140886060657564,
           38.17673652207021,
           38.21258698348286,
           38.2484374448955,
           38.28428790630815,
           38.320138367720794,
           38.35598882913344,
           38.39183929054609,
           38.42768975195874,
           38.46354021337139,
           38.49939067478403,
           38.53524113619668,
           38.571091597609325,
           38.606942059021975,
           38.644723483945285,
           38.683470390623924,
           38.72221729730257,
           38.76096420398122,
           38.79971111065985,
           38.838458017338496,
           38.877204924017136,
           38.91595183069578,
           38.95469873737442,
           38.993445644053054,
           39.0321925507317,
           39.07093945741035,
           39.10968636408899,
           39.148433270767626,
           39.187180177446265,
           39.225927084124905,
           39.26467399080355,
           39.30342089748219,
           39.34216780416084,
           39.38091471083948,
           39.419661617518116,
           39.458408524196756,
           39.497155430875395,
           39.535902337554035,
           39.574649244232674,
           39.61339615091131,
           39.65214305758996,
           39.69088996426861,
           39.729636870947246,
           39.768383777625886,
           39.807130684304525,
           39.84587759098317,
           39.88462449766181,
           39.92337140434046,
           39.9621183110191,
           40.000865217697736,
           40.039612124376376,
           40.07895510912134,
           40.11861181688837,
           40.1582685246554,
           40.19792523242242,
           40.23758194018946,
           40.27723864795648,
           40.3168953557235,
           40.35655206349053,
           40.396208771257555,
           40.435865479024585,
           40.47552218679162,
           40.515178894558645,
           40.554835602325674,
           40.5944923100927,
           40.63414901785973,
           40.67380572562675,
           40.71346243339378,
           40.753119141160816,
           40.79277584892783,
           40.83243255669486,
           40.87208926446189,
           40.91174597222892,
           40.95140267999595,
           40.991059387762974,
           41.030716095529996,
           41.07037280329703,
           41.110029511064056,
           41.14968621883108,
           41.189342926598115,
           41.22899963436514,
           41.26865634213216,
           41.3083130498992,
           41.34796975766622,
           41.38762646543324,
           41.42728317320028,
           41.4669398809673,
           41.50659658873433,
           41.54625329650136,
           41.585910004268385,
           41.625566712035415,
           41.665223419802444,
           41.70488012756947,
           41.7445368353365,
           41.78419354310352,
           41.82385025087055,
           41.86350695863758,
           41.90814776990038,
           41.95777268465895,
           42.00739759941753,
           42.0570225141761,
           42.10664742893468,
           42.156272343693246,
           42.20589725845181,
           42.255522173210394,
           42.30514708796897,
           42.354772002727536,
           42.40439691748611,
           42.45402183224469,
           42.50364674700326,
           42.553271661761826,
           42.60289657652041,
           42.652521491278975,
           42.70214640603755,
           42.751771320796124,
           42.8013962355547,
           42.85102115031327,
           42.90064606507185,
           42.95027097983042,
           42.99989589458899,
           43.04952080934756,
           43.099145724106144,
           43.14877063886471,
           43.198395553623286,
           43.24802046838186,
           43.297645383140434,
           43.347270297898994,
           43.396895212657576,
           43.44652012741615,
           43.49614504217472,
           43.5457699569333,
           43.59539487169188,
           43.64501978645045,
           43.694644701209015,
           43.744269615967596,
           43.79389453072616,
           43.84351944548473,
           43.89314436024331,
           43.942769275001886,
           43.992394189760454,
           44.04201910451903,
           44.09164401927761,
           44.14126893403617,
           44.190893848794744,
           44.240518763553325,
           44.29014367831189,
           44.33976859307047,
           44.38939350782904,
           44.439018422587615,
           44.48864333734619,
           44.538268252104764,
           44.587893166863346,
           44.637518081621906,
           44.68680011583265,
           44.73510881792675,
           44.78341752002083,
           44.831726222114916,
           44.880034924209006,
           44.928343626303096,
           44.97665232839717,
           45.02496103049127,
           45.07326973258535,
           45.121578434679435,
           45.169887136773525,
           45.218195838867615,
           45.26650454096169,
           45.31481324305578,
           45.36312194514987,
           45.41143064724396,
           45.45973934933805,
           45.50804805143214,
           45.556356753526224,
           45.60466545562031,
           45.6529741577144,
           45.70128285980848,
           45.74959156190257,
           45.79790026399665,
           45.84620896609075,
           45.894517668184825,
           45.94282637027892,
           45.885539175968034,
           45.61706018884735,
           45.348581201726645,
           45.08010221460592,
           44.81162322748522,
           44.543144240364526,
           44.2746652532438,
           44.00618626612308,
           43.73770727900241,
           43.469228291881684,
           43.20074930476096,
           42.93227031764027,
           42.66379133051957,
           42.39531234339885,
           42.126833356278155,
           41.85835436915745,
           41.58987538203673,
           41.321396394916036,
           41.05291740779533,
           40.78443842067461,
           40.51595943355389,
           40.247480446433194,
           39.97900145931249,
           39.710522472191776,
           39.442043485071075,
           39.17356449795037,
           38.90508551082966,
           38.63660652370895,
           38.36812753658826,
           38.09964854946753,
           37.831169562346815,
           37.562690575226135,
           37.29421158810542,
           37.025732600984696,
           36.75241307777112,
           36.46415082618018,
           36.17588857458921,
           35.88762632299826,
           35.599364071407315,
           35.31110181981634,
           35.02283956822539,
           34.73457731663445,
           34.44631506504348,
           34.15805281345251,
           33.86979056186156,
           33.58152831027061,
           33.293266058679635,
           33.0050038070887,
           32.71674155549775,
           32.428479303906784,
           32.140217052315826,
           31.851954800724883,
           31.563692549133908,
           31.27543029754294,
           30.987168045952018,
           30.69890579436105,
           30.410643542770075,
           30.122381291179128,
           29.83411903958818,
           29.54585678799721,
           29.257594536406263,
           28.96933228481532,
           28.681070033224348,
           28.3928077816334,
           28.10454553004245,
           27.816283278451483,
           27.528021026860507,
           27.23975877526959,
           26.95149652367862,
           26.663234272087646,
           26.3749720204967,
           26.08670976890575,
           25.79844751731478,
           25.510185265723834,
           25.22192301413289,
           24.933660762541916,
           24.645398510950944,
           24.357136259360022,
           24.068874007769054,
           23.780611756178075,
           23.49234950458713,
           23.20408725299619,
           22.915825001405214,
           22.632349670878654,
           22.372808945673825,
           22.113268220468996,
           21.853727495264167,
           21.594186770059387,
           21.334646044854555,
           21.075105319649726,
           20.815564594444943,
           20.556023869240118,
           20.296483144035285,
           20.036942418830506,
           19.777401693625674,
           19.517860968420845,
           19.258320243216016,
           18.998779518011233,
           18.739238792806404,
           18.47969806760158,
           18.220157342396796,
           17.960616617191967,
           17.701075891987138,
           17.441535166782355,
           17.181994441577526,
           16.922453716372697,
           16.662912991167914,
           16.403372265963085,
           16.143831540758256,
           15.88939358444707,
           15.63653484091525,
           15.383676097383383,
           15.130817353851514,
           14.877958610319691,
           14.625099866787822,
           14.372241123255957,
           14.119382379724135,
           13.866523636192268,
           13.613664892660399,
           13.36080614912853,
           13.107947405596708,
           12.85508866206484,
           12.602229918532974,
           12.349371175001153,
           12.096512431469282,
           11.90802982274351,
           11.765530167450672,
           11.62303051215781,
           11.480530856864945,
           11.338031201572107,
           11.195531546279245,
           11.05303189098638,
           10.910532235693516,
           10.768032580400678,
           10.625532925107814,
           10.483033269814952,
           10.340533614522114,
           10.19803395922925,
           10.055534303936385,
           9.913034648643547,
           9.770534993350683,
           9.625346406623942,
           9.476174558497469,
           9.327002710371026,
           9.177830862244555,
           9.028659014118082,
           8.879487165991637,
           8.730315317865166,
           8.581143469738695,
           8.43197162161225,
           8.28279977348578,
           8.133627925359306,
           7.984456077232862,
           7.835284229106389,
           7.6861123809799174,
           7.536940532853446,
           7.387768684727002,
           7.2385968366005295,
           7.089424988474057,
           6.940253140347614,
           6.791081292221142,
           6.6419094440946695,
           6.492737595968226,
           6.343565747841755,
           6.194393899715282,
           6.0452220515888095,
           5.896050203462366
          ],
          [
           33.00318920776149,
           33.04107128158485,
           33.0789533554082,
           33.11683542923156,
           33.15471750305492,
           33.19259957687828,
           33.230481650701634,
           33.268363724524995,
           33.30624579834836,
           33.34412787217171,
           33.38200994599507,
           33.419892019818434,
           33.45777409364179,
           33.49565616746515,
           33.53353824128851,
           33.571420315111865,
           33.60930238893522,
           33.64718446275858,
           33.68506653658194,
           33.7229486104053,
           33.76083068422866,
           33.79871275805202,
           33.836594831875374,
           33.87447690569873,
           33.91235897952208,
           33.95024105334545,
           33.988123127168805,
           34.02600520099216,
           34.06388727481553,
           34.10176934863888,
           34.13965142246224,
           34.177533496285605,
           34.21541557010896,
           34.253297643932314,
           34.291179717755675,
           34.329061791579036,
           34.36694386540239,
           34.404825939225745,
           34.442708013049106,
           34.48059008687247,
           34.51847216069582,
           34.55635423451918,
           34.594236308342545,
           34.6321183821659,
           34.67000045598926,
           34.707882529812615,
           34.745764603635976,
           34.78364667745933,
           34.82152875128269,
           34.859410825106046,
           34.89729289892941,
           34.93517497275277,
           34.97305704657613,
           35.010939120399485,
           35.04882119422284,
           35.0867032680462,
           35.12458534186956,
           35.16246741569292,
           35.20034948951628,
           35.23823156333964,
           35.27611363716299,
           35.31399571098635,
           35.35187778480971,
           35.38975985863307,
           35.427641932456424,
           35.465524006279786,
           35.50340608010314,
           35.5412881539265,
           35.57917022774986,
           35.61705230157322,
           35.65493437539658,
           35.69281644921993,
           35.7306985230433,
           35.768580596866656,
           35.80646267069001,
           35.84434474451337,
           35.882226818336726,
           35.918648987411665,
           35.95434120279276,
           35.99003341817386,
           36.025725633554956,
           36.06141784893605,
           36.09711006431716,
           36.132802279698254,
           36.16711872039741,
           36.201160006160194,
           36.23520129192297,
           36.269242577685745,
           36.30328386344852,
           36.337325149211296,
           36.37136643570089,
           36.407216897113535,
           36.443067358526186,
           36.47891781993883,
           36.51476828135148,
           36.55061874276413,
           36.58646920417677,
           36.62231966558942,
           36.65817012700207,
           36.694020588414716,
           36.729871049827366,
           36.76572151124002,
           36.80157197265266,
           36.83742243406531,
           36.87327289547795,
           36.9091233568906,
           36.944973818303254,
           36.9808242797159,
           37.01667474112855,
           37.05252520254119,
           37.08837566395384,
           37.12422612536649,
           37.160076586779134,
           37.195927048191784,
           37.23177750960443,
           37.26762797101708,
           37.30347843242973,
           37.33932889384237,
           37.37517935525502,
           37.411029816667664,
           37.446880278080314,
           37.482730739492965,
           37.51858120090561,
           37.55443166231825,
           37.5902821237309,
           37.62613258514355,
           37.6619830465562,
           37.69783350796885,
           37.7336839693815,
           37.769534430794145,
           37.80538489220679,
           37.84123535361944,
           37.87708581503209,
           37.91293627644473,
           37.94878673785738,
           37.984637199270026,
           38.020487660682676,
           38.056338122095326,
           38.09218858350797,
           38.12803904492062,
           38.16388950633326,
           38.19973996774591,
           38.23559042915856,
           38.271440890571206,
           38.30729135198386,
           38.3431418133965,
           38.37899227480915,
           38.4148427362218,
           38.45069319763445,
           38.48654365904709,
           38.522394120459744,
           38.55824458187239,
           38.59409504328504,
           38.62994550469768,
           38.66579596611034,
           38.70164642752298,
           38.737496888935624,
           38.773347350348274,
           38.809197811760924,
           38.84504827317357,
           38.88089873458622,
           38.91674919599886,
           38.95259965741151,
           38.988450118824154,
           39.024300580236805,
           39.060151041649455,
           39.0960015030621,
           39.133782927985415,
           39.17252983466405,
           39.211276741342694,
           39.25002364802133,
           39.28877055469997,
           39.32751746137862,
           39.36626436805726,
           39.4050112747359,
           39.44375818141454,
           39.48250508809318,
           39.52125199477182,
           39.56075184119864,
           39.60040854896567,
           39.6400652567327,
           39.67972196449973,
           39.71937867226675,
           39.75903538003378,
           39.7986920878008,
           39.83834879556783,
           39.87800550333486,
           39.91766221110189,
           39.95731891886892,
           39.996975626635944,
           40.036632334402974,
           40.076289042169996,
           40.115945749937026,
           40.155602457704056,
           40.19525916547108,
           40.234915873238116,
           40.27457258100513,
           40.31422928877217,
           40.35388599653919,
           40.39354270430621,
           40.43319941207324,
           40.47285611984027,
           40.512512827607296,
           40.55216953537433,
           40.591826243141355,
           40.63148295090838,
           40.67113965867541,
           40.71079636644244,
           40.75045307420946,
           40.79010978197649,
           40.82976648974352,
           40.86942319751054,
           40.90907990527757,
           40.9487366130446,
           40.98839332081163,
           41.028050028578654,
           41.067706736345684,
           41.10736344411271,
           41.14702015187974,
           41.18667685964677,
           41.22633356741379,
           41.265990275180826,
           41.30564698294785,
           41.34530369071487,
           41.38496039848191,
           41.42461710624893,
           41.46427381401596,
           41.50393052178299,
           41.54358722955001,
           41.583243937317036,
           41.622900645084066,
           41.662557352851096,
           41.702214060618125,
           41.741870768385155,
           41.781527476152185,
           41.8211841839192,
           41.86084089168624,
           41.90049759945326,
           41.9401543072203,
           41.97981101498732,
           42.01946772275435,
           42.05912443052137,
           42.0987811382884,
           42.138437846055425,
           42.17809455382245,
           42.21775126158948,
           42.25740796935651,
           42.29706467712354,
           42.336721384890566,
           42.37637809265759,
           42.42101890392039,
           42.470643818678965,
           42.52026873343754,
           42.56989364819611,
           42.61951856295469,
           42.66914347771326,
           42.71876839247183,
           42.768393307230404,
           42.81801822198898,
           42.867643136747546,
           42.91726805150613,
           42.96689296626471,
           43.016517881023276,
           43.06614279578184,
           43.115767710540425,
           43.16539262529899,
           43.21501754005756,
           43.26464245481614,
           43.314267369574715,
           43.36389228433329,
           43.41351719909186,
           43.46314211385044,
           43.512767028609005,
           43.56239194336757,
           43.612016858126154,
           43.66164177288473,
           43.7112666876433,
           43.76089160240187,
           43.810516517160444,
           43.860141431919004,
           43.90976634667759,
           43.95939126143617,
           44.009016176194734,
           44.05864109095331,
           44.10826600571188,
           44.157890920470464,
           44.207515835229025,
           44.257140749987606,
           44.30676566474618,
           44.35639057950475,
           44.40601549426332,
           44.455640409021896,
           44.50526532378047,
           44.55489023853904,
           44.60451515329762,
           44.654140068056186,
           44.70376498281476,
           44.753389897573335,
           44.80301481233191,
           44.852639727090484,
           44.90226464184906,
           44.951889556607625,
           45.0015144713662,
           45.051139386124774,
           45.100764300883355,
           45.15038921564192,
           45.2000141304005,
           45.24963904515907,
           45.29926395991764,
           45.34888887467622,
           45.398513789434794,
           45.44813870419336,
           45.49776361895194,
           45.54738853371051,
           45.597013448469085,
           45.64663836322765,
           45.696263277986226,
           45.745888192744815,
           45.795513107503375,
           45.84513802226195,
           45.89476293702053,
           45.94438785177909,
           45.994012766537665,
           46.04363768129625,
           46.09326259605482,
           46.142935012184104,
           46.19301121001523,
           46.243087407846346,
           46.29316360567747,
           46.343239803508595,
           46.39331600133971,
           46.44339219917084,
           46.49346839700196,
           46.42830106122246,
           46.132646658221866,
           45.836992255221254,
           45.54133785222063,
           45.24568344922002,
           44.950029046219406,
           44.65437464321877,
           44.35872024021813,
           44.06306583721756,
           43.767411434216925,
           43.471757031216285,
           43.17610262821567,
           42.880448225215076,
           42.584793822214436,
           42.289139419213825,
           41.99348501621323,
           41.69783061321258,
           41.40902085730399,
           41.120758605713036,
           40.83249635412207,
           40.54423410253111,
           40.255971850940156,
           39.967709599349206,
           39.67944734775824,
           39.39118509616729,
           39.10292284457634,
           38.81466059298537,
           38.526398341394426,
           38.238136089803476,
           37.949873838212504,
           37.66161158662153,
           37.37334933503061,
           37.085087083439646,
           36.79682483184867,
           36.50856258025772,
           36.220300328666774,
           35.9320380770758,
           35.643775825484866,
           35.355513573893916,
           35.06725132230294,
           34.778989070711994,
           34.49072681912105,
           34.20246456753008,
           33.91420231593911,
           33.62594006434816,
           33.337677812757214,
           33.04941556116624,
           32.76115330957529,
           32.47289105798435,
           32.18462880639338,
           31.896366554802427,
           31.608104303211483,
           31.319842051620512,
           31.03157980002954,
           30.74331754843862,
           30.455055296847647,
           30.166793045256668,
           29.878530793665725,
           29.59026854207478,
           29.30200629048381,
           29.01374403889286,
           28.725481787301916,
           28.437219535710945,
           28.148957284119998,
           27.860695032529055,
           27.572432780938083,
           27.284170529347115,
           26.995908277756186,
           26.707646026165218,
           26.41938377457424,
           26.131121522983296,
           25.842859271392353,
           25.55459701980138,
           25.266334768210434,
           24.978072516619488,
           24.689810265028516,
           24.401548013437544,
           24.113285761846623,
           23.82502351025565,
           23.536761258664676,
           23.248499007073733,
           22.960236755482786,
           22.67197450389181,
           22.38849917336525,
           22.128958448160425,
           21.869417722955593,
           21.609876997750767,
           21.350336272545984,
           21.090795547341152,
           20.831254822136323,
           20.571714096931544,
           20.312173371726715,
           20.052632646521882,
           19.795209709320492,
           19.542350965788625,
           19.289492222256754,
           19.036633478724887,
           18.783774735193067,
           18.5309159916612,
           18.27805724812933,
           18.02519850459751,
           17.77233976106564,
           17.519481017533774,
           17.26662227400195,
           17.013763530470083,
           16.760904786938216,
           16.50804604340639,
           16.255187299874528,
           16.002328556342654,
           15.74946981281079,
           15.496611069278966,
           15.2437523257471,
           14.990893582215232,
           14.738034838683411,
           14.485176095151541,
           14.232317351619674,
           13.979458608087853,
           13.726599864555984,
           13.473741121024116,
           13.220882377492249,
           12.968023633960428,
           12.715164890428559,
           12.46230614689669,
           12.20944740336487,
           11.956588659833002,
           11.768106051107228,
           11.62560639581439,
           11.483106740521528,
           11.340607085228664,
           11.198107429935826,
           11.055607774642963,
           10.913108119350099,
           10.770608464057235,
           10.628108808764397,
           10.485609153471534,
           10.343109498178668,
           10.20060984288583,
           10.058110187592968,
           9.915610532300104,
           9.773110877007266,
           9.630611221714403,
           9.488111566421539,
           9.345611911128675,
           9.203112255835837,
           9.060612600542974,
           8.918112945250108,
           8.775613289957272,
           8.633113634664408,
           8.490613979371544,
           8.348114324078706,
           8.205614668785843,
           8.063115013492979,
           7.920615358200141,
           7.778115702907277,
           7.6356160476144135,
           7.493116392321548,
           7.3506167370287105,
           7.2024475422908765,
           7.053275694164405,
           6.90410384603796,
           6.754931997911488,
           6.6057601497850165,
           6.456588301658573,
           6.307416453532101,
           6.158244605405628,
           6.0090727572791565,
           5.859900909152712
          ],
          [
           33.421222036266705,
           33.461116011803014,
           33.50100998733933,
           33.54090396287564,
           33.58079793841195,
           33.620691913948264,
           33.66058588948457,
           33.70047986502089,
           33.7403738405572,
           33.78026781609351,
           33.81949115886573,
           33.857373232689085,
           33.895255306512446,
           33.93313738033581,
           33.97101945415916,
           34.00890152798252,
           34.04678360180588,
           34.08466567562924,
           34.1225477494526,
           34.16042982327595,
           34.198311897099316,
           34.23619397092267,
           34.27407604474603,
           34.311958118569386,
           34.34984019239275,
           34.3877222662161,
           34.42560434003946,
           34.463486413862825,
           34.50136848768618,
           34.53925056150954,
           34.5771326353329,
           34.615014709156256,
           34.65289678297961,
           34.69077885680298,
           34.72866093062633,
           34.766543004449694,
           34.80442507827305,
           34.84230715209641,
           34.880189225919764,
           34.918071299743126,
           34.95595337356648,
           34.99383544738984,
           35.031717521213196,
           35.069599595036564,
           35.10748166885992,
           35.14536374268328,
           35.183245816506634,
           35.221127890329996,
           35.25900996415335,
           35.296892037976704,
           35.334774111800066,
           35.37265618562343,
           35.41053825944679,
           35.44842033327014,
           35.486302407093504,
           35.52418448091686,
           35.56206655474022,
           35.599948628563574,
           35.637830702386935,
           35.67571277621029,
           35.71359485003365,
           35.75147692385701,
           35.78935899768037,
           35.82724107150373,
           35.86512314532709,
           35.903005219150444,
           35.9408872929738,
           35.97876936679716,
           36.01665144062052,
           36.05453351444388,
           36.09241558826724,
           36.1302976620906,
           36.16817973591395,
           36.206061809737314,
           36.24394388356067,
           36.28182595738403,
           36.319708031207384,
           36.357590105030745,
           36.39547217885411,
           36.43335425267746,
           36.47123632650082,
           36.509118400324176,
           36.54700047414754,
           36.5848825479709,
           36.621071611451995,
           36.656922072864646,
           36.69277253427729,
           36.72862299568994,
           36.76447345710258,
           36.80032391851523,
           36.83617437992788,
           36.872024841340526,
           36.90787530275317,
           36.94372576416582,
           36.97957622557847,
           37.01542668699111,
           37.05127714840377,
           37.087127609816406,
           37.12297807122906,
           37.15882853264171,
           37.19467899405436,
           37.23052945546701,
           37.26637991687965,
           37.3022303782923,
           37.33808083970494,
           37.373931301117594,
           37.409781762530244,
           37.44563222394289,
           37.48148268535553,
           37.51733314676818,
           37.55318360818083,
           37.58903406959348,
           37.624884531006124,
           37.660734992418774,
           37.69658545383142,
           37.73243591524407,
           37.76828637665672,
           37.80413683806936,
           37.83998729948201,
           37.875837760894655,
           37.911688222307305,
           37.947538683719955,
           37.9833891451326,
           38.01923960654525,
           38.05509006795789,
           38.09094052937054,
           38.12679099078319,
           38.162641452195835,
           38.198491913608486,
           38.23434237502113,
           38.27019283643378,
           38.30604329784643,
           38.34189375925907,
           38.37774422067172,
           38.413594682084366,
           38.449445143497016,
           38.485295604909666,
           38.52114606632231,
           38.55699652773496,
           38.59284698914761,
           38.62869745056025,
           38.6645479119729,
           38.70039837338555,
           38.7362488347982,
           38.77209929621085,
           38.80794975762349,
           38.84380021903614,
           38.87965068044879,
           38.915501141861434,
           38.951351603274084,
           38.987202064686734,
           39.02305252609937,
           39.05890298751203,
           39.09475344892467,
           39.13060391033732,
           39.166454371749964,
           39.20230483316262,
           39.23871118923642,
           39.27622933179711,
           39.313747474357804,
           39.3512656169185,
           39.38878375947919,
           39.42630190203988,
           39.46382004460057,
           39.50133818716126,
           39.53885632972195,
           39.576374472282644,
           39.61564937240976,
           39.6558026513201,
           39.69595593023045,
           39.73610920914078,
           39.77626248805112,
           39.816415766961455,
           39.856569045871794,
           39.89672232478213,
           39.93687560369247,
           39.977028882602816,
           40.01718216151315,
           40.057335440423486,
           40.097488719333825,
           40.13764199824416,
           40.1777952771545,
           40.21794855606485,
           40.25810183497518,
           40.29825511388552,
           40.338408392795856,
           40.3785616717062,
           40.41871495061654,
           40.45886822952688,
           40.49902150843722,
           40.53917478734755,
           40.579328066257894,
           40.61948134516823,
           40.65963462407857,
           40.6997879029889,
           40.73994118189925,
           40.78009446080958,
           40.82024773971992,
           40.860401018630256,
           40.9005542975406,
           40.94070757645093,
           40.98086085536127,
           41.02101413427161,
           41.06116741318195,
           41.10132069209229,
           41.14147397100263,
           41.18162724991297,
           41.2217805288233,
           41.26193380773365,
           41.30208708664398,
           41.34224036555433,
           41.38229433153056,
           41.42195103929758,
           41.46160774706461,
           41.50126445483165,
           41.54092116259867,
           41.5805778703657,
           41.620234578132724,
           41.65989128589975,
           41.69954799366678,
           41.739204701433806,
           41.778861409200836,
           41.818518116967866,
           41.85817482473489,
           41.89783153250192,
           41.93748824026894,
           41.97714494803598,
           42.016801655803,
           42.05645836357002,
           42.09611507133705,
           42.135771779104076,
           42.175428486871105,
           42.215085194638135,
           42.254741902405165,
           42.294398610172195,
           42.33405531793922,
           42.37371202570625,
           42.41336873347328,
           42.45302544124031,
           42.49268214900733,
           42.53233885677436,
           42.57199556454138,
           42.61165227230842,
           42.65130898007544,
           42.69096568784247,
           42.730622395609494,
           42.77027910337652,
           42.80993581114355,
           42.84959251891058,
           42.889249226677606,
           42.9338900379404,
           42.98351495269898,
           43.03313986745755,
           43.082764782216124,
           43.1323896969747,
           43.18201461173327,
           43.23163952649184,
           43.281264441250414,
           43.330889356008996,
           43.38051427076756,
           43.430139185526144,
           43.47976410028471,
           43.52938901504329,
           43.57901392980186,
           43.62863884456043,
           43.67826375931901,
           43.727888674077576,
           43.77751358883616,
           43.827138503594725,
           43.87676341835329,
           43.92638833311187,
           43.97601324787045,
           44.02563816262902,
           44.075263077387596,
           44.124887992146164,
           44.17453072058621,
           44.22460691841734,
           44.27468311624847,
           44.324759314079586,
           44.3748355119107,
           44.424911709741835,
           44.47498790757295,
           44.52506410540407,
           44.5751403032352,
           44.62521650106633,
           44.67529269889745,
           44.72536889672857,
           44.77544509455969,
           44.82552129239082,
           44.875597490221935,
           44.92567368805306,
           44.975749885884184,
           45.0258260837153,
           45.07590228154643,
           45.12597847937755,
           45.176054677208676,
           45.2261308750398,
           45.276207072870925,
           45.32628327070204,
           45.37635946853317,
           45.42643566636429,
           45.476511864195416,
           45.52658806202653,
           45.576664259857665,
           45.62674045768878,
           45.6768166555199,
           45.726892853351025,
           45.77696905118216,
           45.82704524901327,
           45.87712144684439,
           45.92719764467552,
           45.97727384250665,
           46.027350040337765,
           46.07742623816889,
           46.127502436000015,
           46.17757863383113,
           46.22765483166226,
           46.27773102949338,
           46.327807227324506,
           46.37788342515563,
           46.427959622986755,
           46.47803582081787,
           46.528112018649,
           46.57818821648012,
           46.62826441431124,
           46.67834061214236,
           46.72841680997348,
           46.77849300780461,
           46.82856920563573,
           46.878645403466855,
           46.92872160129799,
           46.978797799129104,
           47.02887399696023,
           46.96370666118073,
           46.668052258180126,
           46.372397855179514,
           46.076743452178874,
           45.78108904917827,
           45.485434646177666,
           45.189780243177026,
           44.8941258401764,
           44.59847143717582,
           44.302817034175185,
           44.00716263117455,
           43.71150822817394,
           43.41585382517333,
           43.1201994221727,
           42.82454501917209,
           42.52889061617148,
           42.23323621317085,
           41.937581810170244,
           41.64192740716963,
           41.346273004169,
           41.05061860116837,
           40.754964198167755,
           40.45930979516715,
           40.16365539216652,
           39.86800098916591,
           39.572346586165295,
           39.27669218316467,
           38.98103778016406,
           38.68538337716345,
           38.38972897416282,
           38.09407457116218,
           37.7984201681616,
           37.502765765160966,
           37.20711136216033,
           36.91145695915972,
           36.61580255615912,
           36.320148153158485,
           36.02449375015787,
           35.72883934715727,
           35.43318494415662,
           35.137530541156025,
           34.84187613815541,
           34.546221735154774,
           34.25056733215414,
           33.95491292915354,
           33.659258526152925,
           33.36360412315229,
           33.06794972015168,
           32.77229531715108,
           32.476640914150444,
           32.18098651114983,
           31.88533210814923,
           31.589677705148592,
           31.29402330214796,
           30.99836889914738,
           30.702714496146744,
           30.40706009314611,
           30.111405690145503,
           29.81575128714489,
           29.52009688414426,
           29.22444248114365,
           28.928788078143043,
           28.63313367514241,
           28.337479272141803,
           28.041824869141195,
           27.746170466140562,
           27.450516063139926,
           27.154861660139343,
           26.85920725713871,
           26.56183855917144,
           26.245612938345968,
           25.929387317520487,
           25.61316169669498,
           25.296936075869507,
           24.980710455044026,
           24.664484834218523,
           24.348259213393018,
           24.03203359256757,
           23.715807971742063,
           23.39958235091656,
           23.083356730091083,
           22.767131109265605,
           22.4509054884401,
           22.145278026920487,
           21.892641361929975,
           21.640004696939457,
           21.38736803194894,
           21.134731366958476,
           20.88209470196796,
           20.62945803697745,
           20.376821371986985,
           20.124184706996466,
           19.871548042005955,
           19.618911377015486,
           19.36627471202497,
           19.113638047034456,
           18.861001382043945,
           18.608364717053476,
           18.35572805206296,
           18.103091387072446,
           17.85045472208198,
           17.59781805709147,
           17.345181392100955,
           17.092544727110486,
           16.83990806211997,
           16.587271397129456,
           16.33463473213899,
           16.081998067148476,
           15.829361402157964,
           15.57672473716745,
           15.324088072176982,
           15.07145140718647,
           14.818814742195954,
           14.566178077205487,
           14.313541412214974,
           14.060904747224457,
           13.80826808223399,
           13.555631417243479,
           13.302994752252964,
           13.050358087262449,
           12.797721422271984,
           12.550635314831558,
           12.305063007007533,
           12.059490699183556,
           11.813918391359529,
           11.632687799815457,
           11.497415577042792,
           11.362143354270103,
           11.226871131497411,
           11.088931117210977,
           10.946655964600795,
           10.80438081199061,
           10.662105659380428,
           10.51983050677027,
           10.377555354160084,
           10.235280201549902,
           10.093005048939744,
           9.950729896329559,
           9.808454743719377,
           9.66617959110922,
           9.523904438499036,
           9.38162928588885,
           9.239354133278669,
           9.097078980668512,
           8.954803828058328,
           8.812528675448142,
           8.670253522837985,
           8.527978370227801,
           8.385703217617618,
           8.24342806500746,
           8.101152912397275,
           7.958877759787093,
           7.816602607176935,
           7.67432745456675,
           7.532052301956567,
           7.389777149346383,
           7.247501996736226,
           7.105226844126042,
           6.962951691515858,
           6.8206765389057,
           6.678401386295516,
           6.536126233685334,
           6.393851081075176,
           6.251575928464992,
           6.109300775854807,
           5.9670256232446235,
           5.824750470634467
          ],
          [
           33.83569030231892,
           33.87558427785524,
           33.91547825339154,
           33.95537222892786,
           33.99526620446417,
           34.03516018000048,
           34.07505415553679,
           34.114948131073106,
           34.15484210660942,
           34.19473608214573,
           34.23463005768205,
           34.274524033218356,
           34.31441800875467,
           34.35431198429098,
           34.39420595982729,
           34.434099935363605,
           34.47399391089992,
           34.51388788643623,
           34.55378186197254,
           34.593675837508854,
           34.63356981304517,
           34.67346378858148,
           34.71335776411779,
           34.753251739654104,
           34.79314571519041,
           34.83303969072672,
           34.87293366626304,
           34.91115105851074,
           34.9490331323341,
           34.986915206157455,
           35.02479727998082,
           35.06267935380417,
           35.10056142762753,
           35.138443501450894,
           35.17632557527425,
           35.21420764909761,
           35.252089722920964,
           35.289971796744325,
           35.32785387056768,
           35.36573594439105,
           35.4036180182144,
           35.44150009203776,
           35.479382165861125,
           35.51726423968448,
           35.555146313507834,
           35.593028387331195,
           35.63091046115455,
           35.66879253497791,
           35.706674608801265,
           35.744556682624626,
           35.78243875644799,
           35.82032083027134,
           35.8582029040947,
           35.896084977918065,
           35.93396705174142,
           35.97184912556478,
           36.009731199388135,
           36.047613273211496,
           36.08549534703485,
           36.12337742085821,
           36.16125949468157,
           36.19914156850493,
           36.23702364232829,
           36.27490571615164,
           36.312787789975005,
           36.350669863798366,
           36.38855193762172,
           36.42643401144508,
           36.464316085268436,
           36.5021981590918,
           36.54008023291516,
           36.57796230673851,
           36.615844380561875,
           36.653726454385236,
           36.69160852820858,
           36.729490602031944,
           36.767372675855306,
           36.80525474967866,
           36.84313682350202,
           36.88101889732538,
           36.91890097114874,
           36.9567830449721,
           36.99466511879545,
           37.032547192618814,
           37.06873625609991,
           37.10458671751256,
           37.14043717892521,
           37.17628764033786,
           37.212138101750504,
           37.24798856316315,
           37.2838390245758,
           37.31968948598845,
           37.35553994740109,
           37.391390408813734,
           37.427240870226385,
           37.463091331639035,
           37.498941793051685,
           37.53479225446433,
           37.570642715876986,
           37.60649317728962,
           37.64234363870227,
           37.67819410011492,
           37.71404456152757,
           37.74989502294022,
           37.785745484352866,
           37.82159594576551,
           37.85744640717816,
           37.89329686859081,
           37.92914733000345,
           37.964997791416096,
           38.000848252828746,
           38.036698714241396,
           38.07254917565404,
           38.10839963706669,
           38.14425009847934,
           38.18010055989198,
           38.21595102130463,
           38.251801482717276,
           38.287651944129934,
           38.32350240554257,
           38.35935286695522,
           38.39520332836787,
           38.43105378978052,
           38.46690425119317,
           38.502754712605814,
           38.53860517401846,
           38.57445563543111,
           38.61030609684376,
           38.6461565582564,
           38.68200701966905,
           38.717857481081694,
           38.753707942494344,
           38.78955840390699,
           38.825408865319645,
           38.86125932673228,
           38.89710978814493,
           38.93296024955758,
           38.968810710970224,
           39.00466117238288,
           39.040511633795525,
           39.076362095208175,
           39.11360229213117,
           39.151120434691855,
           39.18863857725255,
           39.22615671981324,
           39.26367486237393,
           39.301193004934625,
           39.33871114749532,
           39.37622929005601,
           39.4137474326167,
           39.45126557517739,
           39.48878371773808,
           39.526301860298766,
           39.56382000285946,
           39.60133814542016,
           39.63885628798084,
           39.676374430541536,
           39.71389257310223,
           39.75141071566292,
           39.78892885822361,
           39.8264470007843,
           39.863965143345,
           39.901483285905684,
           39.93900142846638,
           39.97651957102707,
           40.01403771358776,
           40.051555856148454,
           40.09083075627558,
           40.13098403518591,
           40.171137314096256,
           40.211290593006595,
           40.25144387191693,
           40.29159715082727,
           40.33175042973761,
           40.37190370864794,
           40.41205698755829,
           40.45221026646862,
           40.492363545378964,
           40.5325168242893,
           40.57267010319964,
           40.61282338210998,
           40.65297666102032,
           40.69312993993066,
           40.733283218840995,
           40.773436497751334,
           40.81358977666167,
           40.85374305557201,
           40.89389633448235,
           40.934049613392695,
           40.974202892303026,
           41.014356171213365,
           41.05450945012371,
           41.09466272903405,
           41.13481600794438,
           41.17496928685472,
           41.215122565765064,
           41.2552758446754,
           41.295429123585734,
           41.33558240249607,
           41.37573568140641,
           41.41588896031675,
           41.456042239227095,
           41.496195518137434,
           41.536348797047765,
           41.57650207595811,
           41.61665535486844,
           41.65680863377878,
           41.69696191268912,
           41.73711519159946,
           41.777268470509796,
           41.81742174942014,
           41.85757502833047,
           41.89772830724082,
           41.93788158615116,
           41.97803486506149,
           42.018188143971834,
           42.05834142288217,
           42.09849470179251,
           42.13864798070285,
           42.17880125961318,
           42.218954538523526,
           42.25910781743387,
           42.2992610963442,
           42.33941437525454,
           42.37956765416488,
           42.41972093307522,
           42.45987421198556,
           42.5000274908959,
           42.54018076980623,
           42.58033404871657,
           42.62048732762692,
           42.66064060653725,
           42.70079388544758,
           42.74094716435793,
           42.78110044326827,
           42.821253722178604,
           42.86140700108895,
           42.90156027999928,
           42.94171355890962,
           42.98186683781996,
           43.02292517936271,
           43.06416453221334,
           43.10540388506399,
           43.14664323791464,
           43.187882590765284,
           43.22912194361593,
           43.270361296466575,
           43.31160064931723,
           43.35284000216787,
           43.39407935501852,
           43.44003219879088,
           43.49069853348496,
           43.541364868179045,
           43.59203120287312,
           43.64269753756721,
           43.69336387226129,
           43.744030206955365,
           43.794696541649444,
           43.84536287634353,
           43.89602921103761,
           43.94669554573169,
           43.99736188042577,
           44.04802821511986,
           44.098694549813935,
           44.14936088450801,
           44.200027219202084,
           44.25069355389617,
           44.301359888590255,
           44.35202622328433,
           44.40269255797841,
           44.4533588926725,
           44.504025227366576,
           44.554691562060654,
           44.60535789675474,
           44.65602423144882,
           44.706690566142896,
           44.75735690083698,
           44.80802323553107,
           44.85868957022514,
           44.909355904919224,
           44.9600222396133,
           45.01039350753124,
           45.06046970536235,
           45.11054590319348,
           45.1606221010246,
           45.210698298855725,
           45.26077449668685,
           45.310850694517974,
           45.3609268923491,
           45.411003090180216,
           45.46107928801134,
           45.511155485842465,
           45.56123168367358,
           45.611307881504715,
           45.66138407933584,
           45.71146027716695,
           45.76153647499808,
           45.811612672829206,
           45.86168887066032,
           45.91176506849145,
           45.961841266322566,
           46.0119174641537,
           46.061993661984815,
           46.112069859815946,
           46.162146057647064,
           46.21222225547818,
           46.262298453309306,
           46.31237465114043,
           46.362450848971555,
           46.41252704680268,
           46.462603244633804,
           46.51267944246493,
           46.56275564029605,
           46.612831838127164,
           46.662908035958296,
           46.71298423378941,
           46.76306043162054,
           46.81313662945166,
           46.86321282728278,
           46.91328902511391,
           46.963365222945036,
           47.013441420776154,
           47.06351761860728,
           47.1135938164384,
           47.16367001426953,
           47.21374621210064,
           47.26382240993178,
           47.31389860776289,
           47.36397480559401,
           47.41405100342514,
           47.46412720125626,
           47.514203399087386,
           47.5642795969185,
           47.49911226113902,
           47.20345785813841,
           46.907803455137795,
           46.61214905213716,
           46.31649464913656,
           46.02084024613595,
           45.72518584313532,
           45.42953144013468,
           45.1338770371341,
           44.838222634133466,
           44.54256823113283,
           44.24691382813223,
           43.95125942513162,
           43.655605022130985,
           43.35995061913037,
           43.06429621612976,
           42.768641813129136,
           42.472987410128525,
           42.17733300712792,
           41.88167860412727,
           41.58602420112665,
           41.29036979812604,
           40.99471539512544,
           40.6990609921248,
           40.40340658912419,
           40.107752186123584,
           39.812097783122944,
           39.51644338012234,
           39.220788977121735,
           38.925134574121095,
           38.62948017112046,
           38.33314002623769,
           38.01691440541218,
           37.70068878458668,
           37.384463163761204,
           37.06823754293573,
           36.75201192211023,
           36.43578630128475,
           36.119560680459266,
           35.80333505963377,
           35.48710943880829,
           35.170883817982805,
           34.854658197157306,
           34.5384325763318,
           34.22220695550632,
           33.905981334680845,
           33.58975571385534,
           33.27353009302987,
           32.957304472204385,
           32.641078851378886,
           32.32485323055341,
           32.00862760972793,
           31.692401988902425,
           31.376176368076923,
           31.059950747251474,
           30.74372512642597,
           30.427499505600462,
           30.111273884774988,
           29.79504826394951,
           29.478822643124005,
           29.16259702229853,
           28.84637140147305,
           28.530145780647548,
           28.21392015982207,
           27.89769453899659,
           27.581468918171087,
           27.265243297345577,
           26.949017676520135,
           26.63279205569463,
           26.316566434869124,
           26.000340814043646,
           25.684115193218172,
           25.367889572392663,
           25.05166395156719,
           24.735438330741715,
           24.41921270991621,
           24.102987089090703,
           23.786761468265254,
           23.47053584743975,
           23.154310226614243,
           22.838084605788765,
           22.52185898496329,
           22.205633364137785,
           21.90000590261817,
           21.647369237627657,
           21.394732572637142,
           21.142095907646627,
           20.88945924265616,
           20.636822577665647,
           20.38418591267513,
           20.131549247684667,
           19.878912582694152,
           19.626275917703637,
           19.37363925271317,
           19.121002587722657,
           18.868365922732142,
           18.615729257741627,
           18.363092592751162,
           18.110455927760647,
           17.857819262770132,
           17.605182597779667,
           17.352545932789152,
           17.099909267798637,
           16.84727260280817,
           16.594635937817657,
           16.34199927282714,
           16.095333668916346,
           15.849761361092323,
           15.604189053268296,
           15.358616745444271,
           15.113044437620292,
           14.867472129796266,
           14.621899821972242,
           14.376327514148262,
           14.130755206324238,
           13.885182898500211,
           13.63961059067623,
           13.394038282852208,
           13.14846597502818,
           12.902893667204157,
           12.657321359380179,
           12.411749051556152,
           12.166176743732127,
           11.92060443590815,
           11.675032128084123,
           11.493801536540051,
           11.358529313767386,
           11.223257090994696,
           11.087984868222005,
           10.95271264544934,
           10.81744042267665,
           10.682168199903959,
           10.546895977131268,
           10.411623754358603,
           10.276351531585911,
           10.14107930881322,
           10.005807086040555,
           9.870534863267864,
           9.735262640495174,
           9.599990417722509,
           9.464718194949818,
           9.329445972177126,
           9.194173749404435,
           9.05890152663177,
           8.921378359433401,
           8.779103206823216,
           8.63682805421306,
           8.494552901602875,
           8.352277748992691,
           8.210002596382534,
           8.06772744377235,
           7.925452291162166,
           7.783177138552009,
           7.6409019859418255,
           7.498626833331642,
           7.356351680721457,
           7.214076528111301,
           7.071801375501115,
           6.929526222890933,
           6.7872510702807745,
           6.644975917670591,
           6.502700765060407,
           6.360425612450249,
           6.218150459840066,
           6.0758753072298815,
           5.933600154619699,
           5.79132500200954
          ],
          [
           34.25015856837112,
           34.290052543907436,
           34.32994651944375,
           34.36984049498005,
           34.40973447051637,
           34.449628446052685,
           34.489522421588994,
           34.5294163971253,
           34.56931037266162,
           34.609204348197935,
           34.64909832373424,
           34.68899229927055,
           34.72888627480687,
           34.768780250343184,
           34.80867422587949,
           34.8485682014158,
           34.88846217695212,
           34.928356152488426,
           34.968250128024735,
           35.00814410356105,
           35.04803807909737,
           35.087932054633676,
           35.127826030169985,
           35.1677200057063,
           35.207613981242616,
           35.24750795677892,
           35.28740193231524,
           35.32729590785155,
           35.367189883387866,
           35.40708385892417,
           35.44697783446048,
           35.4868718099968,
           35.52676578553311,
           35.566659761069424,
           35.60655373660573,
           35.64644771214205,
           35.686341687678365,
           35.726235663214666,
           35.76612963875098,
           35.8060236142873,
           35.84591758982361,
           35.885811565359916,
           35.92570554089623,
           35.96492888433238,
           36.002810958155735,
           36.040693031979096,
           36.07857510580245,
           36.11645717962581,
           36.154339253449166,
           36.19222132727252,
           36.23010340109588,
           36.26798547491924,
           36.305867548742604,
           36.34374962256596,
           36.38163169638932,
           36.419513770212674,
           36.457395844036036,
           36.4952779178594,
           36.53315999168275,
           36.57104206550611,
           36.608924139329474,
           36.64680621315283,
           36.68468828697619,
           36.722570360799544,
           36.760452434622906,
           36.79833450844626,
           36.83621658226962,
           36.874098656092976,
           36.91198072991634,
           36.94986280373969,
           36.98774487756305,
           37.025626951386414,
           37.063509025209775,
           37.10139109903313,
           37.139273172856484,
           37.177155246679845,
           37.2150373205032,
           37.25291939432656,
           37.29080146814992,
           37.32868354197328,
           37.36656561579663,
           37.40444768962,
           37.44232976344335,
           37.480211837266715,
           37.51640090074781,
           37.55225136216046,
           37.58810182357311,
           37.623952284985755,
           37.6598027463984,
           37.69565320781105,
           37.7315036692237,
           37.76735413063634,
           37.80320459204899,
           37.83905505346164,
           37.87490551487429,
           37.910755976286936,
           37.946606437699586,
           37.98245689911223,
           38.01830736052488,
           38.05415782193752,
           38.09000828335017,
           38.12585874476282,
           38.161709206175466,
           38.197559667588116,
           38.23341012900076,
           38.26926059041341,
           38.30511105182606,
           38.3409615132387,
           38.37681197465135,
           38.412662436064,
           38.44851289747665,
           38.4843633588893,
           38.52021382030194,
           38.55606428171459,
           38.591914743127234,
           38.627765204539884,
           38.663615665952534,
           38.69946612736518,
           38.73531658877783,
           38.77116705019047,
           38.80701751160312,
           38.84286797301577,
           38.87871843442842,
           38.914568895841064,
           38.950975252465206,
           38.9884933950259,
           39.02601153758659,
           39.063529680147276,
           39.10104782270796,
           39.13856596526866,
           39.176084107829354,
           39.21360225039004,
           39.25112039295073,
           39.288638535511424,
           39.32615667807212,
           39.36367482063281,
           39.4011929631935,
           39.438711105754194,
           39.47622924831489,
           39.51374739087558,
           39.55126553343627,
           39.58878367599696,
           39.62630181855765,
           39.66381996111834,
           39.701338103679035,
           39.73885624623973,
           39.77637438880042,
           39.81389253136111,
           39.851410673921805,
           39.88892881648249,
           39.92644695904319,
           39.963965101603875,
           40.00148324416456,
           40.03900138672525,
           40.076519529285946,
           40.114037671846646,
           40.15155581440733,
           40.18907395696802,
           40.226592099528716,
           40.26411024208941,
           40.3016283846501,
           40.33914652721079,
           40.376664669771486,
           40.41418281233217,
           40.45170095489287,
           40.48921909745356,
           40.526737240014256,
           40.566012140141375,
           40.60616541905171,
           40.64631869796205,
           40.68647197687239,
           40.72662525578273,
           40.76677853469307,
           40.806931813603406,
           40.847085092513744,
           40.88723837142408,
           40.92739165033442,
           40.96754492924476,
           41.0076982081551,
           41.047851487065444,
           41.08800476597578,
           41.12815804488612,
           41.16831132379645,
           41.2084646027068,
           41.24861788161713,
           41.28877116052747,
           41.32892443943781,
           41.36907771834814,
           41.40923099725849,
           41.44938427616882,
           41.48953755507917,
           41.529690833989505,
           41.569844112899844,
           41.609997391810175,
           41.65015067072052,
           41.69030394963086,
           41.7304572285412,
           41.770610507451536,
           41.810763786361875,
           41.85091706527221,
           41.89107034418255,
           41.93122362309289,
           41.97137690200323,
           42.01153018091357,
           42.051683459823906,
           42.091836738734244,
           42.13199001764458,
           42.17214329655492,
           42.21229657546526,
           42.2524498543756,
           42.29260313328594,
           42.332756412196275,
           42.372909691106614,
           42.41306297001695,
           42.45321624892729,
           42.49336952783763,
           42.53352280674797,
           42.573676085658306,
           42.613829364568645,
           42.65497821250206,
           42.6962175653527,
           42.73745691820336,
           42.778696271054,
           42.81993562390464,
           42.861174976755294,
           42.90241432960593,
           42.943653682456585,
           42.98489303530722,
           43.026132388157876,
           43.06737174100852,
           43.10861109385917,
           43.14985044670982,
           43.19108979956046,
           43.23232915241111,
           43.27356850526176,
           43.3148078581124,
           43.356047210963055,
           43.397286563813694,
           43.43852591666435,
           43.479765269514985,
           43.52100462236564,
           43.562243975216276,
           43.60348332806693,
           43.644722680917575,
           43.68596203376822,
           43.727201386618866,
           43.76844073946951,
           43.80968009232016,
           43.8509194451708,
           43.892158798021455,
           43.93811164179381,
           43.988777976487896,
           44.03944431118198,
           44.09011064587605,
           44.14077698057014,
           44.191443315264216,
           44.242109649958294,
           44.29277598465238,
           44.343442319346465,
           44.39410865404054,
           44.44477498873462,
           44.49544132342871,
           44.546107658122786,
           44.596773992816864,
           44.64744032751095,
           44.69810666220502,
           44.7487729968991,
           44.799439331593184,
           44.85010566628726,
           44.90077200098135,
           44.95143833567543,
           45.002104670369505,
           45.05277100506359,
           45.10343733975767,
           45.15410367445175,
           45.20477000914583,
           45.25543634383991,
           45.306102678533996,
           45.356769013228075,
           45.40743534792216,
           45.45810168261623,
           45.50876801731032,
           45.55943435200439,
           45.61010068669847,
           45.66076702139256,
           45.711433356086644,
           45.762099690780715,
           45.8127660254748,
           45.86343236016887,
           45.91409869486296,
           45.96476502955704,
           46.01543136425112,
           46.0660976989452,
           46.116764033639285,
           46.16743036833336,
           46.218096703027435,
           46.26876303772151,
           46.3194293724156,
           46.370095707109684,
           46.420762041803755,
           46.47142837649784,
           46.522094711191926,
           46.572761045886004,
           46.62342738058008,
           46.67409371527417,
           46.72476004996824,
           46.775426384662325,
           46.82609271935641,
           46.876759054050495,
           46.92742538874457,
           46.97809172343865,
           47.02875805813272,
           47.07942439282681,
           47.130090727520894,
           47.180757062214965,
           47.231423396909044,
           47.282089731603136,
           47.332756066297215,
           47.383422400991286,
           47.43408873568538,
           47.48475507037946,
           47.53542140507353,
           47.58608773976761,
           47.6367540744617,
           47.68742040915577,
           47.738086743849856,
           47.78875307854394,
           47.83941941323801,
           47.89009302042044,
           47.940787405995195,
           47.99148179156997,
           48.042176177144725,
           48.0928705627195,
           48.019297436012536,
           47.69718928474226,
           47.37508113347199,
           47.052972982201695,
           46.730864830931424,
           46.40875667966115,
           46.086648528390846,
           45.76454037712055,
           45.44243222585031,
           45.12032407458001,
           44.79821592330972,
           44.476107772039434,
           44.15399962076917,
           43.83189146949887,
           43.50978331822861,
           43.187675166958336,
           42.86556701568803,
           42.54345886441775,
           42.221350713147494,
           41.899242561877195,
           41.57713441060689,
           41.25502625933662,
           40.933898489364765,
           40.61767286853925,
           40.30144724771378,
           39.985221626888304,
           39.66899600606279,
           39.35277038523732,
           39.03654476441184,
           38.72031914358634,
           38.40409352276083,
           38.08786790193538,
           37.77164228110988,
           37.45541666028437,
           37.13919103945889,
           36.82296541863342,
           36.50673979780792,
           36.19051417698243,
           35.87428855615696,
           35.558062935331456,
           35.24183731450598,
           34.92561169368051,
           34.609386072855,
           34.29316045202949,
           33.97693483120402,
           33.66070921037854,
           33.344483589553036,
           33.02825796872756,
           32.71203234790208,
           32.395806727076575,
           32.0795811062511,
           31.763355485425624,
           31.44712986460012,
           31.130904243774616,
           30.814678622949167,
           30.498453002123664,
           30.182227381298155,
           29.866001760472678,
           29.549776139647204,
           29.2335505188217,
           28.917324897996224,
           28.601099277170746,
           28.28487365634524,
           27.968648035519763,
           27.652422414694286,
           27.33619679386878,
           27.019971173043274,
           26.703745552217825,
           26.387519931392326,
           26.07129431056682,
           25.755068689741343,
           25.438843068915865,
           25.12261744809036,
           24.806391827264882,
           24.490166206439405,
           24.173940585613902,
           23.857714964788396,
           23.541489343962947,
           23.22526372313744,
           22.90903810231194,
           22.59281248148646,
           22.276586860660984,
           21.96036123983548,
           21.65473377831586,
           21.40209711332535,
           21.149460448334835,
           20.896823783344324,
           20.644187118353855,
           20.391550453363337,
           20.138913788372825,
           19.88627712338236,
           19.640032023001094,
           19.39445971517707,
           19.148887407353087,
           18.903315099529063,
           18.65774279170504,
           18.412170483881017,
           18.166598176057036,
           17.92102586823301,
           17.675453560408986,
           17.429881252585005,
           17.184308944760982,
           16.938736636936955,
           16.693164329112975,
           16.44759202128895,
           16.202019713464924,
           15.956447405640946,
           15.710875097816922,
           15.465302789992895,
           15.21973048216887,
           14.97415817434489,
           14.728585866520866,
           14.483013558696841,
           14.237441250872862,
           13.991868943048836,
           13.746296635224809,
           13.500724327400828,
           13.255152019576808,
           13.009579711752782,
           12.764007403928757,
           12.518435096104776,
           12.27286278828075,
           12.027290480456726,
           11.781718172632747,
           11.536145864808722,
           11.354915273264652,
           11.219643050491985,
           11.084370827719294,
           10.949098604946602,
           10.81382638217394,
           10.678554159401248,
           10.543281936628556,
           10.408009713855865,
           10.2727374910832,
           10.13746526831051,
           10.002193045537819,
           9.866920822765154,
           9.731648599992463,
           9.596376377219771,
           9.461104154447106,
           9.325831931674415,
           9.190559708901725,
           9.055287486129034,
           8.920015263356367,
           8.784743040583677,
           8.649470817810986,
           8.514198595038321,
           8.378926372265632,
           8.24365414949294,
           8.108381926720275,
           7.973109703947584,
           7.837837481174894,
           7.702565258402227,
           7.567293035629536,
           7.432020812856845,
           7.296748590084155,
           7.161476367311488,
           7.026204144538798,
           6.890931921766108,
           6.7538256016558496,
           6.611550449045666,
           6.469275296435482,
           6.327000143825324,
           6.18472499121514,
           6.0424498386049565,
           5.900174685994773,
           5.757899533384616
          ],
          [
           34.66462683442332,
           34.70452080995963,
           34.74441478549595,
           34.78430876103226,
           34.82420273656857,
           34.86409671210489,
           34.9039906876412,
           34.943884663177506,
           34.98377863871382,
           35.02367261425013,
           35.06356658978645,
           35.103460565322756,
           35.14335454085907,
           35.18324851639538,
           35.223142491931696,
           35.263036467468005,
           35.302930443004314,
           35.34282441854063,
           35.38271839407694,
           35.422612369613255,
           35.46250634514956,
           35.50240032068588,
           35.54229429622219,
           35.582188271758504,
           35.62208224729481,
           35.66197622283113,
           35.701870198367445,
           35.741764173903746,
           35.78165814944006,
           35.82155212497638,
           35.86144610051269,
           35.901340076048996,
           35.94123405158531,
           35.98112802712163,
           36.021022002657936,
           36.06091597819425,
           36.10080995373056,
           36.14070392926687,
           36.180597904803186,
           36.220491880339495,
           36.26038585587581,
           36.30027983141212,
           36.340173806948435,
           36.380067782484744,
           36.41996175802106,
           36.45985573355737,
           36.49974970909368,
           36.53964368462999,
           36.5795376601663,
           36.61943163570262,
           36.65932561123893,
           36.69921958677524,
           36.73911356231156,
           36.77900753784787,
           36.81890151338418,
           36.85879548892049,
           36.8986894644568,
           36.93858343999312,
           36.978477415529426,
           37.01837139106574,
           37.056588783977375,
           37.09447085780073,
           37.13235293162409,
           37.170235005447445,
           37.20811707927081,
           37.24599915309417,
           37.28388122691752,
           37.32176330074088,
           37.35964537456424,
           37.39752744838759,
           37.43540952221096,
           37.473291596034315,
           37.511173669857676,
           37.54905574368103,
           37.586937817504385,
           37.624819891327746,
           37.6627019651511,
           37.70058403897446,
           37.73846611279782,
           37.776348186621185,
           37.81423026044454,
           37.8521123342679,
           37.889994408091255,
           37.927876481914616,
           37.96406554539571,
           37.99991600680836,
           38.03576646822101,
           38.071616929633656,
           38.107467391046306,
           38.14331785245895,
           38.1791683138716,
           38.21501877528424,
           38.25086923669689,
           38.28671969810954,
           38.32257015952219,
           38.35842062093484,
           38.39427108234749,
           38.43012154376013,
           38.46597200517278,
           38.50182246658543,
           38.537672927998074,
           38.573523389410724,
           38.60937385082337,
           38.64522431223602,
           38.68107477364866,
           38.71692523506131,
           38.752775696473954,
           38.788626157886604,
           38.825866355359935,
           38.86338449792062,
           38.90090264048132,
           38.938420783042005,
           38.97593892560269,
           39.01345706816339,
           39.05097521072408,
           39.088493353284775,
           39.12601149584547,
           39.16352963840616,
           39.201047780966846,
           39.238565923527545,
           39.27608406608823,
           39.31360220864892,
           39.351120351209616,
           39.38863849377031,
           39.426156636331,
           39.46367477889169,
           39.501192921452386,
           39.53871106401307,
           39.576229206573764,
           39.61374734913446,
           39.65126549169515,
           39.68878363425584,
           39.726301776816534,
           39.76381991937723,
           39.80133806193791,
           39.838856204498605,
           39.8763743470593,
           39.91389248961999,
           39.95141063218068,
           39.988928774741375,
           40.02644691730207,
           40.06396505986275,
           40.10148320242345,
           40.13900134498414,
           40.17651948754484,
           40.21403763010552,
           40.251555772666215,
           40.28907391522691,
           40.32659205778759,
           40.36411020034829,
           40.40162834290898,
           40.43914648546968,
           40.47666462803036,
           40.514182770591056,
           40.55170091315175,
           40.589219055712434,
           40.626737198273126,
           40.66425534083382,
           40.70177348339452,
           40.739291625955204,
           40.776809768515896,
           40.81432791107659,
           40.85184605363729,
           40.889364196197974,
           40.92688233875866,
           40.96440048131936,
           41.001918623880044,
           41.04119352400717,
           41.08134680291751,
           41.121500081827854,
           41.161653360738185,
           41.201806639648524,
           41.24195991855886,
           41.2821131974692,
           41.32226647637954,
           41.36241975528988,
           41.402573034200216,
           41.44272631311056,
           41.4828795920209,
           41.52303287093123,
           41.56318614984157,
           41.603339428751916,
           41.643492707662254,
           41.68364598657259,
           41.72379926548293,
           41.76395254439327,
           41.80410582330361,
           41.84425910221394,
           41.884412381124285,
           41.92456566003462,
           41.96471893894496,
           42.0048722178553,
           42.04502549676564,
           42.08517877567598,
           42.12533205458631,
           42.165485333496655,
           42.20563861240699,
           42.24579189279077,
           42.287031245641415,
           42.32827059849206,
           42.36950995134271,
           42.41074930419336,
           42.451988657044005,
           42.49322800989465,
           42.53446736274529,
           42.57570671559594,
           42.61694606844659,
           42.65818542129723,
           42.699424774147886,
           42.740664126998524,
           42.78190347984918,
           42.823142832699816,
           42.86438218555047,
           42.90562153840112,
           42.94686089125176,
           42.98810024410241,
           43.02933959695305,
           43.0705789498037,
           43.11181830265434,
           43.153057655504995,
           43.19429700835563,
           43.235536361206286,
           43.276775714056924,
           43.31801506690758,
           43.35925441975822,
           43.40049377260887,
           43.44173312545952,
           43.48297247831016,
           43.524211831160805,
           43.56545118401146,
           43.606690536862104,
           43.64792988971275,
           43.689169242563395,
           43.73040859541405,
           43.771647948264686,
           43.81288730111534,
           43.85412665396598,
           43.89536600681662,
           43.93660535966727,
           43.97784471251792,
           44.019084065368574,
           44.06032341821921,
           44.10156277106986,
           44.142802123920504,
           44.18404147677116,
           44.225280829621795,
           44.26652018247245,
           44.307759535323086,
           44.34899888817374,
           44.39023824102438,
           44.43619108479675,
           44.48685741949083,
           44.53752375418491,
           44.58819008887899,
           44.63885642357307,
           44.68952275826715,
           44.74018909296123,
           44.790855427655316,
           44.841521762349394,
           44.89218809704347,
           44.94285443173755,
           44.99352076643164,
           45.044187101125715,
           45.09485343581979,
           45.145519770513886,
           45.19618610520796,
           45.246852439902035,
           45.29751877459612,
           45.3481851092902,
           45.39885144398427,
           45.44951777867837,
           45.50018411337244,
           45.55085044806652,
           45.6015167827606,
           45.65218311745468,
           45.70284945214876,
           45.75351578684284,
           45.804182121536925,
           45.854848456231004,
           45.90551479092508,
           45.95618112561917,
           46.00684746031325,
           46.057513795007324,
           46.10818012970141,
           46.15884646439549,
           46.20951279908957,
           46.260179133783645,
           46.31084546847773,
           46.361511803171815,
           46.41217813786589,
           46.462844472559965,
           46.51351080725405,
           46.56417714194813,
           46.614843476642214,
           46.66550981133629,
           46.716176146030364,
           46.76684248072445,
           46.81750881541853,
           46.86817515011262,
           46.91884148480669,
           46.96951820873261,
           47.020212594307374,
           47.07090697988213,
           47.1216013654569,
           47.17229575103167,
           47.22299013660642,
           47.27368452218119,
           47.32437890775596,
           47.375073293330715,
           47.42576767890548,
           47.476462064480245,
           47.52715645005501,
           47.57785083562977,
           47.62854522120453,
           47.6792396067793,
           47.729933992354056,
           47.78062837792882,
           47.83132276350359,
           47.88201714907835,
           47.932711534653116,
           47.98340592022788,
           48.03410030580264,
           48.084794691377404,
           48.13548907695217,
           48.186183462526934,
           48.23687784810169,
           48.28757223367646,
           48.33826661925122,
           48.38896100482599,
           48.439655390400745,
           48.49034977597552,
           48.541044161550275,
           48.59173854712504,
           48.518165420418086,
           48.19605726914781,
           47.873949117877544,
           47.551840966607244,
           47.22973281533697,
           46.9076246640667,
           46.585516512796396,
           46.2634083615261,
           45.94130021025586,
           45.61919205898556,
           45.29708390771527,
           44.97497575644499,
           44.65286760517472,
           44.33075945390442,
           44.008651302634156,
           43.686543151363885,
           43.36443500009358,
           43.04232684882331,
           42.720218697553044,
           42.39811054628274,
           42.07600239501244,
           41.75389424374217,
           41.4317860924719,
           41.109677941201596,
           40.787569789931325,
           40.46546163866106,
           40.14335348739076,
           39.82124533612049,
           39.49913718485022,
           39.17702903357992,
           38.854920882309614,
           38.53281273103938,
           38.21070457976908,
           37.88859642849878,
           37.5664882772285,
           37.24438012595824,
           36.92227197468794,
           36.60016382341767,
           36.278055672147396,
           35.955947520877096,
           35.633839369606825,
           35.31173121833656,
           34.989623067066255,
           34.667514915795955,
           34.34540676452569,
           34.02329861325541,
           33.70119046198512,
           33.37908231071485,
           33.05697415944458,
           32.73486600817427,
           32.41275785690401,
           32.09064970563374,
           31.76854155436343,
           31.44643340309314,
           31.124325251822896,
           30.802217100552593,
           30.480108949282297,
           30.158000798012022,
           29.835892646741755,
           29.51378449547145,
           29.191676344201184,
           28.869568192930913,
           28.547460041660614,
           28.22535189039034,
           27.90324373912007,
           27.56650959185702,
           27.22363779734121,
           26.880766002825453,
           26.537894208309634,
           26.19502241379382,
           25.85215061927803,
           25.509278824762248,
           25.166407030246425,
           24.823535235730645,
           24.48066344121486,
           24.137791646699043,
           23.794919852183227,
           23.452048057667472,
           23.109176263151653,
           22.766304468635838,
           22.42343267412005,
           22.080560879604263,
           21.737689085088448,
           21.412234327449006,
           21.17386475419108,
           20.935495180933152,
           20.697125607675222,
           20.458756034417338,
           20.220386461159407,
           19.982016887901484,
           19.7436473146436,
           19.50261959455805,
           19.257047286734025,
           19.01147497891004,
           18.765902671086018,
           18.520330363261994,
           18.27475805543797,
           18.02918574761399,
           17.783613439789963,
           17.53804113196594,
           17.292468824141956,
           17.046896516317933,
           16.80132420849391,
           16.55575190066993,
           16.310179592845905,
           16.06460728502188,
           15.819034977197898,
           15.573462669373875,
           15.327890361549848,
           15.082318053725823,
           14.836745745901844,
           14.591173438077817,
           14.345601130253794,
           14.100028822429813,
           13.85445651460579,
           13.608884206781763,
           13.363311898957782,
           13.117739591133759,
           12.872167283309736,
           12.626594975485709,
           12.38102266766173,
           12.135450359837703,
           11.889878052013678,
           11.644305744189701,
           11.398733436365674,
           11.217502844821606,
           11.08223062204894,
           10.946958399276248,
           10.81168617650356,
           10.676413953730894,
           10.541141730958202,
           10.40586950818551,
           10.27059728541282,
           10.135325062640154,
           10.000052839867463,
           9.864780617094771,
           9.729508394322108,
           9.594236171549415,
           9.458963948776725,
           9.32369172600406,
           9.18841950323137,
           9.053147280458678,
           8.917875057685988,
           8.782602834913323,
           8.647330612140632,
           8.51205838936794,
           8.376786166595275,
           8.241513943822586,
           8.106241721049894,
           7.9709694982772294,
           7.835697275504536,
           7.7004250527318465,
           7.56515282995918,
           7.429880607186489,
           7.294608384413799,
           7.159336161641109,
           7.0240639388684425,
           6.888791716095752,
           6.753519493323061,
           6.623809092653475,
           6.495509894247939,
           6.367210695842404,
           6.238911497436892,
           6.110612299031357,
           5.98231310062582,
           5.854013902220284,
           5.7257147038147735
          ],
          [
           35.07909510047554,
           35.11898907601186,
           35.158883051548166,
           35.198777027084475,
           35.23867100262079,
           35.2785649781571,
           35.31845895369341,
           35.358352929229724,
           35.39824690476604,
           35.43814088030235,
           35.478034855838665,
           35.517928831374974,
           35.55782280691128,
           35.5977167824476,
           35.637610757983914,
           35.67750473352022,
           35.71739870905653,
           35.75729268459285,
           35.797186660129164,
           35.83708063566547,
           35.87697461120178,
           35.9168685867381,
           35.956762562274406,
           35.99665653781072,
           36.03655051334703,
           36.07644448888335,
           36.116338464419655,
           36.156232439955964,
           36.19612641549228,
           36.23602039102859,
           36.275914366564905,
           36.31580834210122,
           36.35570231763753,
           36.395596293173845,
           36.435490268710154,
           36.47538424424647,
           36.51527821978278,
           36.55517219531909,
           36.595066170855404,
           36.63496014639171,
           36.67485412192803,
           36.71474809746434,
           36.75464207300065,
           36.79453604853696,
           36.83443002407328,
           36.87432399960959,
           36.9142179751459,
           36.95411195068221,
           36.99400592621852,
           37.033899901754836,
           37.073793877291145,
           37.11368785282746,
           37.15358182836377,
           37.193475803900085,
           37.2333697794364,
           37.27326375497271,
           37.31315773050902,
           37.353051706045335,
           37.392945681581644,
           37.43283965711796,
           37.47273363265427,
           37.512627608190584,
           37.55252158372689,
           37.5924155592632,
           37.63230953479952,
           37.672203510335834,
           37.71209748587214,
           37.75199146140845,
           37.79188543694477,
           37.831779412481076,
           37.87167338801739,
           37.9115673635537,
           37.95146133909002,
           37.991355314626325,
           38.03124929016264,
           38.07114326569895,
           38.11036660979902,
           38.14824868362238,
           38.18613075744574,
           38.2240128312691,
           38.261894905092454,
           38.299776978915816,
           38.33765905273917,
           38.37554112656254,
           38.411730190043635,
           38.447580651456285,
           38.48343111286893,
           38.51928157428158,
           38.55513203569422,
           38.59098249710687,
           38.626832958519515,
           38.663239315693986,
           38.700757458254685,
           38.73827560081538,
           38.775793743376056,
           38.813311885936756,
           38.85083002849745,
           38.88834817105814,
           38.92586631361883,
           38.96338445617952,
           39.00090259874022,
           39.038420741300904,
           39.075938883861596,
           39.11345702642229,
           39.150975168982974,
           39.188493311543674,
           39.226011454104366,
           39.26352959666505,
           39.301047739225744,
           39.33856588178644,
           39.37608402434713,
           39.41360216690782,
           39.451120309468514,
           39.48863845202921,
           39.52615659458989,
           39.56367473715059,
           39.60119287971128,
           39.63871102227197,
           39.67622916483266,
           39.713747307393355,
           39.75126544995405,
           39.78878359251474,
           39.82630173507543,
           39.86381987763612,
           39.90133802019682,
           39.9388561627575,
           39.9763743053182,
           40.01389244787889,
           40.05141059043957,
           40.08892873300027,
           40.126446875560966,
           40.16396501812166,
           40.20148316068234,
           40.23900130324304,
           40.27651944580373,
           40.31403758836443,
           40.351555730925114,
           40.389073873485806,
           40.4265920160465,
           40.464110158607184,
           40.501628301167884,
           40.53914644372857,
           40.57666458628926,
           40.614182728849954,
           40.651700871410654,
           40.68921901397134,
           40.72673715653204,
           40.764255299092724,
           40.80177344165342,
           40.83929158421411,
           40.8768097267748,
           40.914327869335494,
           40.95184601189618,
           40.989364154456865,
           41.026882297017565,
           41.06440043957825,
           41.10191858213894,
           41.13943672469964,
           41.17695486726033,
           41.21447300982102,
           41.25199115238171,
           41.28950929494241,
           41.327027437503105,
           41.36454558006378,
           41.40206372262448,
           41.439581865185176,
           41.47710000774586,
           41.51637490787299,
           41.55652818678332,
           41.59668146569366,
           41.63683474460401,
           41.67698802351434,
           41.71714130242468,
           41.757294581335024,
           41.797447860245356,
           41.837601139155694,
           41.87784492593015,
           41.91908427878079,
           41.96032363163145,
           42.00156298448209,
           42.04280233733274,
           42.08404169018338,
           42.12528104303403,
           42.166520395884675,
           42.20775974873531,
           42.24899910158596,
           42.29023845443661,
           42.33147780728726,
           42.37271716013791,
           42.41395651298855,
           42.455195865839194,
           42.49643521868985,
           42.53767457154049,
           42.57891392439114,
           42.62015327724178,
           42.66139263009243,
           42.70263198294308,
           42.74387133579372,
           42.785110688644366,
           42.82635004149502,
           42.86758939434566,
           42.90882874719631,
           42.950068100046956,
           42.9913074528976,
           43.03254680574824,
           43.07378615859889,
           43.11502551144954,
           43.156264864300184,
           43.19750421715083,
           43.23874357000148,
           43.27998292285212,
           43.32122227570277,
           43.36246162855342,
           43.403700981404064,
           43.44494033425472,
           43.48617968710536,
           43.52741903995601,
           43.568658392806654,
           43.6098977456573,
           43.65113709850794,
           43.692376451358584,
           43.733615804209236,
           43.77485515705988,
           43.81609450991053,
           43.85733386276117,
           43.89857321561182,
           43.93981256846247,
           43.98105192131311,
           44.02229127416376,
           44.06353062701441,
           44.104769979865054,
           44.1460093327157,
           44.187248685566345,
           44.228488038417,
           44.269727391267644,
           44.31096674411829,
           44.35220609696893,
           44.39344544981957,
           44.434684802670226,
           44.47592415552087,
           44.51716350837152,
           44.55840286122216,
           44.599642214072816,
           44.640881566923454,
           44.6821209197741,
           44.723360272624745,
           44.7645996254754,
           44.80583897832604,
           44.84707833117669,
           44.888317684027335,
           44.9342705277997,
           44.98493686249378,
           45.03560319718786,
           45.08626953188194,
           45.136935866576025,
           45.1876022012701,
           45.23826853596418,
           45.28893487065827,
           45.33960120535235,
           45.39026754004642,
           45.4409338747405,
           45.49160020943459,
           45.542266544128665,
           45.59293287882275,
           45.643599213516836,
           45.694265548210915,
           45.744931882904986,
           45.79559821759907,
           45.84626455229315,
           45.89693088698723,
           45.94759722168132,
           45.9982635563754,
           46.048943397044795,
           46.09963778261955,
           46.15033216819432,
           46.20102655376908,
           46.25172093934385,
           46.30241532491861,
           46.35310971049338,
           46.40380409606814,
           46.4544984816429,
           46.50519286721767,
           46.55588725279243,
           46.606581638367196,
           46.65727602394196,
           46.707970409516726,
           46.758664795091484,
           46.80935918066625,
           46.860053566241014,
           46.91074795181577,
           46.96144233739054,
           47.012136722965295,
           47.06283110854007,
           47.11352549411483,
           47.164219879689604,
           47.214914265264355,
           47.26560865083912,
           47.31630303641389,
           47.36699742198866,
           47.417691807563415,
           47.46838619313817,
           47.51908057871294,
           47.5697749642877,
           47.62046934986247,
           47.67116373543723,
           47.72185812101199,
           47.772552506586756,
           47.82324689216153,
           47.87394127773629,
           47.92463566331105,
           47.97533004888581,
           48.026024434460574,
           48.07671882003534,
           48.12741320561011,
           48.17810759118487,
           48.22880197675963,
           48.2794963623344,
           48.330190747909164,
           48.380885133483915,
           48.43157951905869,
           48.482273904633445,
           48.5329682902082,
           48.583662675782975,
           48.63435706135774,
           48.685051446932505,
           48.73574583250726,
           48.78644021808203,
           48.83713460365679,
           48.88782898923155,
           48.93852337480632,
           48.98921776038108,
           49.039912145955846,
           49.090606531530604,
           49.01703340482365,
           48.69492525355337,
           48.372817102283115,
           48.05070895101281,
           47.72860079974254,
           47.40649264847227,
           47.08438449720197,
           46.762276345931674,
           46.440168194661425,
           46.118060043391125,
           45.79595189212083,
           45.47384374085056,
           45.15173558958029,
           44.829627438309984,
           44.50751928703972,
           44.18541113576945,
           43.86330298449916,
           43.54119483322888,
           43.21908668195861,
           42.89697853068831,
           42.57487037941801,
           42.25276222814774,
           41.930654076877474,
           41.608545925607174,
           41.286437774336896,
           40.96432962306663,
           40.64222147179633,
           40.32011332052606,
           39.998005169255784,
           39.66538459429414,
           39.32251279977832,
           38.979641005262565,
           38.636769210746756,
           38.29389741623094,
           37.951025621715154,
           37.60815382719937,
           37.265282032683544,
           36.922410238167764,
           36.57953844365198,
           36.23666664913616,
           35.893794854620374,
           35.55092306010459,
           35.20805126558877,
           34.865179471072956,
           34.52230767655717,
           34.17943588204138,
           33.836564087525566,
           33.49369229300978,
           33.15082049849399,
           32.807948703978184,
           32.46507690946239,
           32.12220511494661,
           31.779333320430794,
           31.43646152591497,
           31.09358973139922,
           30.750717936883404,
           30.407846142367585,
           30.064974347851802,
           29.722102553336015,
           29.3792307588202,
           29.03635896430441,
           28.693487169788625,
           28.35061537527281,
           28.007743580757023,
           27.66487178624124,
           27.32199999172542,
           26.979128197209604,
           26.636256402693846,
           26.29338460817803,
           25.95051281366222,
           25.607641019146428,
           25.264769224630644,
           24.921897430114825,
           24.57902563559904,
           24.236153841083254,
           23.893282046567435,
           23.55041025205162,
           23.20753845753587,
           22.86466666302005,
           22.52179486850423,
           22.178923073988447,
           21.83605127947266,
           21.493179484956844,
           21.167724727317406,
           20.929355154059472,
           20.690985580801545,
           20.452616007543618,
           20.214246434285734,
           19.975876861027807,
           19.737507287769876,
           19.499137714511992,
           19.260768141254065,
           19.022398567996134,
           18.78402899473825,
           18.545659421480323,
           18.307289848222396,
           18.068920274964466,
           17.83055070170658,
           17.592181128448654,
           17.353811555190724,
           17.11544198193284,
           16.877072408674913,
           16.638702835416986,
           16.4003332621591,
           16.16196368890117,
           15.923594115643242,
           15.68299512743375,
           15.437422819609727,
           15.191850511785702,
           14.946278203961676,
           14.700705896137697,
           14.455133588313672,
           14.209561280489647,
           13.963988972665668,
           13.71841666484164,
           13.472844357017618,
           13.227272049193637,
           12.981699741369612,
           12.736127433545587,
           12.490555125721563,
           12.244982817897583,
           11.999410510073556,
           11.753838202249533,
           11.508265894425554,
           11.262693586601527,
           11.081462995057457,
           10.94619077228479,
           10.8109185495121,
           10.675646326739411,
           10.540374103966744,
           10.405101881194055,
           10.269829658421363,
           10.134557435648674,
           9.999285212876007,
           9.864012990103316,
           9.728740767330626,
           9.59346854455796,
           9.45819632178527,
           9.322924099012578,
           9.187651876239912,
           9.052379653467222,
           8.917107430694532,
           8.78183520792184,
           8.646562985149174,
           8.517267643203578,
           8.388968444798044,
           8.260669246392531,
           8.132370047986997,
           8.00407084958146,
           7.875771651175949,
           7.747472452770413,
           7.619173254364878,
           7.490874055959366,
           7.362574857553829,
           7.2342756591482935,
           7.105976460742759,
           6.977677262337247,
           6.849378063931711,
           6.7210788655261755,
           6.592779667120663,
           6.464480468715128,
           6.336181270309593,
           6.207882071904081,
           6.079582873498545,
           5.951283675093009,
           5.822984476687474,
           5.694685278281963
          ],
          [
           35.48844706332472,
           35.52834103886103,
           35.56823501439734,
           35.608128989933654,
           35.64802296546996,
           35.68791694100628,
           35.72781091654259,
           35.7677048920789,
           35.80759886761521,
           35.84749284315153,
           35.88738681868784,
           35.92728079422415,
           35.96717476976046,
           36.00706874529678,
           36.04696272083309,
           36.086856696369395,
           36.12675067190571,
           36.16664464744203,
           36.20653862297833,
           36.246432598514644,
           36.28632657405096,
           36.326220549587276,
           36.36611452512358,
           36.4060085006599,
           36.4459024761962,
           36.48579645173252,
           36.525690427268835,
           36.56558440280514,
           36.60547837834146,
           36.64537235387777,
           36.685266329414084,
           36.72516030495039,
           36.7650542804867,
           36.80494825602302,
           36.84484223155933,
           36.88473620709565,
           36.92463018263196,
           36.96452415816826,
           37.00441813370458,
           37.044312109240884,
           37.08420608477721,
           37.124100060313516,
           37.16399403584983,
           37.20388801138614,
           37.24378198692245,
           37.283675962458766,
           37.323569937995074,
           37.36346391353139,
           37.4033578890677,
           37.443251864604015,
           37.483145840140324,
           37.52303981567664,
           37.56293379121295,
           37.602827766749265,
           37.64272174228557,
           37.68261571782189,
           37.7225096933582,
           37.762403668894514,
           37.80229764443082,
           37.84219161996713,
           37.88208559550345,
           37.92197957103976,
           37.96187354657607,
           38.00176752211238,
           38.0416614976487,
           38.08155547318501,
           38.12144944872132,
           38.16134342425763,
           38.201237399793946,
           38.241131375330255,
           38.28102535086657,
           38.32091932640288,
           38.360813301939196,
           38.400707277475504,
           38.44060125301181,
           38.48203812174958,
           38.52378356689622,
           38.565529012042866,
           38.607274457189504,
           38.64901990233614,
           38.69076534748279,
           38.73251079262943,
           38.77425623777607,
           38.8160016829227,
           38.85548883709441,
           38.89452433307114,
           38.93355982904786,
           38.972595325024585,
           39.01163082100131,
           39.05066631697803,
           39.08970181295476,
           39.12873730893148,
           39.1677728049082,
           39.20554384122885,
           39.24306198378954,
           39.28058012635023,
           39.31809826891092,
           39.355616411471615,
           39.393134554032315,
           39.430652696593,
           39.4681708391537,
           39.505688981714385,
           39.54320712427508,
           39.58072526683577,
           39.61824340939646,
           39.655761551957156,
           39.69327969451785,
           39.73079783707853,
           39.768315979639226,
           39.80583412219992,
           39.84335226476061,
           39.880870407321304,
           39.918388549881996,
           39.95590669244269,
           39.993424835003374,
           40.03094297756407,
           40.06846112012476,
           40.10597926268545,
           40.143497405246144,
           40.18101554780684,
           40.218533690367536,
           40.25605183292822,
           40.29356997548891,
           40.33108811804961,
           40.36860626061029,
           40.406124403170985,
           40.44364254573168,
           40.48116068829237,
           40.51867883085306,
           40.55619697341376,
           40.59371511597445,
           40.63123325853513,
           40.66875140109583,
           40.70626954365652,
           40.74378768621721,
           40.7813058287779,
           40.818823971338595,
           40.85634211389929,
           40.89386025645998,
           40.93137839902067,
           40.96889654158136,
           41.00641468414205,
           41.04393282670274,
           41.081450969263436,
           41.11896911182413,
           41.15648725438482,
           41.194005396945514,
           41.231523539506206,
           41.2690416820669,
           41.30655982462759,
           41.344077967188284,
           41.38159610974897,
           41.41911425230967,
           41.456632394870354,
           41.49415053743105,
           41.53166867999174,
           41.569186822552425,
           41.606704965113124,
           41.64422310767381,
           41.6817412502345,
           41.719259392795195,
           41.75677753535589,
           41.79429567791658,
           41.83181382047727,
           41.869331963037965,
           41.90685010559865,
           41.94436824815934,
           41.985222018080975,
           42.02774360168307,
           42.07026518528516,
           42.112786768887254,
           42.15530835248934,
           42.19782993609144,
           42.24035151969353,
           42.28287310329563,
           42.32539468689773,
           42.36791627049982,
           42.40944890615328,
           42.45074884657274,
           42.492048786992214,
           42.533348727411685,
           42.57464866783115,
           42.61594860825062,
           42.65724854867008,
           42.698548489089546,
           42.739848429509024,
           42.78114836992849,
           42.82244831034796,
           42.86374825076743,
           42.90504819118689,
           42.94634813160637,
           42.987648072025834,
           43.0289480124453,
           43.07024795286477,
           43.11154789328424,
           43.15284783370371,
           43.19414777412318,
           43.235447714542644,
           43.27674765496211,
           43.318047595381586,
           43.35934753580105,
           43.40064747622052,
           43.44194741663999,
           43.483247357059454,
           43.524547297478925,
           43.565847237898396,
           43.60714717831786,
           43.64844711873733,
           43.6897470591568,
           43.731046999576265,
           43.772346939995735,
           43.813646880415206,
           43.85494682083467,
           43.89624676125413,
           43.93754670167361,
           43.978846642093075,
           44.02014658251255,
           44.061446522932016,
           44.10274646335148,
           44.14404640377095,
           44.18534634419042,
           44.22664628460989,
           44.267946225029355,
           44.309246165448826,
           44.35054610586829,
           44.39184604628776,
           44.43314598670723,
           44.474445927126695,
           44.515745867546165,
           44.557045807965636,
           44.59834574838511,
           44.63964568880457,
           44.68094562922404,
           44.72224556964351,
           44.76354551006298,
           44.804845450482446,
           44.84614539090192,
           44.88744533132137,
           44.928745271740844,
           44.970045212160315,
           45.011345152579786,
           45.05264509299925,
           45.09394503341872,
           45.13524497383819,
           45.17654491425766,
           45.21784485467713,
           45.259144795096596,
           45.30044473551607,
           45.34174467593553,
           45.383044616354994,
           45.42835477395942,
           45.47767514874879,
           45.52699552353815,
           45.57631589832751,
           45.62563627311687,
           45.67495664790623,
           45.724966152666916,
           45.77567491942943,
           45.826383686191924,
           45.87709245295442,
           45.92780121971692,
           45.97850998647942,
           46.02921875324193,
           46.07992752000443,
           46.13063628676693,
           46.181345053529434,
           46.232053820291924,
           46.282762587054435,
           46.33347135381693,
           46.38418012057944,
           46.434888887341934,
           46.485597654104446,
           46.536306420866936,
           46.58701518762944,
           46.637723954391944,
           46.68843272115444,
           46.739141487916946,
           46.78985025467944,
           46.84055902144195,
           46.89126778820445,
           46.94197655496695,
           46.992685321729454,
           47.043394088491944,
           47.094102855254455,
           47.14481162201695,
           47.19552038877946,
           47.246229155541954,
           47.29693792230446,
           47.34764668906696,
           47.39835545582946,
           47.449064222591964,
           47.49977298935446,
           47.55048175611695,
           47.60119052287946,
           47.651899289641975,
           47.702608056404465,
           47.75331682316697,
           47.80402558992948,
           47.85473435669197,
           47.905443123454475,
           47.95615189021698,
           48.00686065697948,
           48.057569423741974,
           48.10827819050448,
           48.15898695726698,
           48.20969572402948,
           48.260404490791984,
           48.31111325755449,
           48.361822024316986,
           48.41253079107949,
           48.46323955784199,
           48.51394832460449,
           48.56465709136699,
           48.61536585812949,
           48.66607462489199,
           48.716783391654495,
           48.767492158417,
           48.8182009251795,
           48.868909691941994,
           48.9196184587045,
           48.970327225467,
           49.0210359922295,
           49.071744758992,
           49.12245352575451,
           49.173162292517006,
           49.2238710592795,
           49.27457982604201,
           49.325288592804505,
           49.37599735956701,
           49.426706126329506,
           49.47741489309202,
           49.528123659854515,
           49.57883242661702,
           49.49689565545255,
           49.14966780843427,
           48.802439961416,
           48.45521211439769,
           48.107984267379415,
           47.76075642036114,
           47.41352857334283,
           47.06630072632453,
           46.71907287930629,
           46.37184503228798,
           46.024617185269676,
           45.6773893382514,
           45.33016149123313,
           44.982933644214825,
           44.63570579719655,
           44.288477950178276,
           43.94125010315997,
           43.5940222561417,
           43.24679440912342,
           42.899566562105115,
           42.552338715086805,
           42.20511086806854,
           41.85788302105026,
           41.51065517403196,
           41.16342732701368,
           40.816199479995404,
           40.4689716329771,
           40.121743785958834,
           39.77451593894055,
           39.42728809192225,
           39.08006024490394,
           38.73513140513097,
           38.39225961061516,
           38.04938781609934,
           37.70651602158356,
           37.36364422706777,
           37.02077243255195,
           36.677900638036164,
           36.335028843520384,
           35.99215704900457,
           35.64928525448879,
           35.306413459973,
           34.96354166545718,
           34.620669870941356,
           34.277798076425576,
           33.93492628190979,
           33.59205448739397,
           33.24918269287819,
           32.9063108983624,
           32.563439103846584,
           32.2205673093308,
           31.877695514815017,
           31.5348237202992,
           31.19195192578338,
           30.849080131267627,
           30.506208336751808,
           30.16333654223599,
           29.82046474772021,
           29.47759295320442,
           29.134721158688606,
           28.79184936417282,
           28.448977569657032,
           28.106105775141213,
           27.76323398062543,
           27.420362186109646,
           27.077490391593823,
           26.734618597078008,
           26.391746802562253,
           26.048875008046437,
           25.70600321353062,
           25.363131419014834,
           25.020259624499047,
           24.677387829983232,
           24.334516035467445,
           23.991644240951665,
           23.648772446435842,
           23.305900651920027,
           22.96302885740427,
           22.620157062888456,
           22.277285268372637,
           21.93441347385685,
           21.59154167934107,
           21.248669884825247,
           20.92321512718581,
           20.684845553927882,
           20.446475980669952,
           20.208106407412025,
           19.96973683415414,
           19.731367260896214,
           19.492997687638283,
           19.254628114380395,
           19.016258541122472,
           18.777888967864545,
           18.53951939460666,
           18.30114982134873,
           18.0627802480908,
           17.824410674832873,
           17.58604110157499,
           17.347671528317058,
           17.10930195505913,
           16.870932381801246,
           16.632562808543316,
           16.394193235285385,
           16.155823662027505,
           15.917454088769578,
           15.679084515511647,
           15.440714942253763,
           15.202345368995836,
           14.963975795737907,
           14.725606222479978,
           14.487236649222094,
           14.248867075964164,
           14.010497502706238,
           13.772127929448352,
           13.533758356190425,
           13.295388782932495,
           13.057019209674609,
           12.81864963641668,
           12.580280063158753,
           12.341910489900826,
           12.10354091664294,
           11.863370660309416,
           11.61779835248539,
           11.372226044661414,
           11.126653736837387,
           10.945423145293317,
           10.81015092252065,
           10.67487869974796,
           10.53960647697527,
           10.410726193753709,
           10.282426995348173,
           10.154127796942637,
           10.025828598537101,
           9.89752940013159,
           9.769230201726055,
           9.640931003320517,
           9.512631804915006,
           9.38433260650947,
           9.256033408103937,
           9.127734209698424,
           8.999435011292888,
           8.871135812887353,
           8.742836614481817,
           8.614537416076304,
           8.486238217670769,
           8.357939019265235,
           8.229639820859722,
           8.101340622454188,
           7.973041424048651,
           7.844742225643139,
           7.716443027237603,
           7.588143828832067,
           7.459844630426556,
           7.33154543202102,
           7.203246233615484,
           7.074947035209949,
           6.946647836804438,
           6.818348638398902,
           6.690049439993366,
           6.561750241587854,
           6.433451043182319,
           6.305151844776783,
           6.176852646371271,
           6.048553447965736,
           5.9202542495602,
           5.791955051154664,
           5.6636558527491525
          ],
          [
           35.89353544152806,
           35.93342941706437,
           35.97332339260068,
           36.01321736813699,
           36.05311134367331,
           36.09300531920962,
           36.13289929474593,
           36.17279327028224,
           36.21268724581855,
           36.252581221354866,
           36.29247519689118,
           36.33236917242749,
           36.3722631479638,
           36.412157123500116,
           36.452051099036424,
           36.49194507457274,
           36.53183905010905,
           36.571733025645365,
           36.61162700118168,
           36.65152097671799,
           36.6914149522543,
           36.731308927790614,
           36.77120290332692,
           36.81109687886324,
           36.85099085439954,
           36.89088482993586,
           36.93077880547217,
           36.97067278100849,
           37.0105667565448,
           37.050460732081106,
           37.09035470761742,
           37.13024868315374,
           37.17014265869004,
           37.21003663422636,
           37.24993060976267,
           37.28982458529899,
           37.329718560835296,
           37.369612536371605,
           37.40950651190792,
           37.44940048744422,
           37.489294462980546,
           37.529188438516854,
           37.56908241405316,
           37.60897638958948,
           37.64887036512579,
           37.688764340662104,
           37.72865831619841,
           37.76855229173473,
           37.80844626727104,
           37.84834024280735,
           37.88823421834366,
           37.92812819387998,
           37.96802216941629,
           38.007916144952596,
           38.04781012048891,
           38.08770409602523,
           38.127598071561536,
           38.167492047097845,
           38.208003180021,
           38.24974862516765,
           38.291494070314286,
           38.333239515460924,
           38.37498496060756,
           38.41673040575421,
           38.45847585090085,
           38.500221296047485,
           38.54196674119412,
           38.58371218634077,
           38.62545763148741,
           38.667203076634046,
           38.70894852178069,
           38.75069396692733,
           38.792439412073975,
           38.83418485722061,
           38.87593030236725,
           38.91767574751389,
           38.95942119266053,
           39.001166637807174,
           39.04291208295382,
           39.08465752810045,
           39.126402973247096,
           39.168148418393734,
           39.20989386354038,
           39.25163930868702,
           39.29112646285873,
           39.330161958835454,
           39.36919745481217,
           39.4082329507889,
           39.44726844676562,
           39.486303942742346,
           39.525339438719065,
           39.56437493469579,
           39.60341043067252,
           39.64244592664924,
           39.68148142262596,
           39.720516918602684,
           39.7595524145794,
           39.79858791055614,
           39.837623406532856,
           39.87665890250958,
           39.9156943984863,
           39.95472989446302,
           39.99376539043975,
           40.032800886416474,
           40.071836382393194,
           40.11087187836992,
           40.14990737434664,
           40.188942870323366,
           40.22797836630009,
           40.26650807850147,
           40.30402622106216,
           40.34154436362285,
           40.379062506183544,
           40.41658064874424,
           40.45409879130492,
           40.491616933865615,
           40.52913507642631,
           40.566653218987,
           40.60417136154769,
           40.641689504108385,
           40.67920764666908,
           40.71672578922976,
           40.754243931790455,
           40.79176207435115,
           40.82928021691184,
           40.866798359472526,
           40.904316502033225,
           40.94183464459392,
           40.97935278715461,
           41.0168709297153,
           41.054389072275995,
           41.09190721483668,
           41.12942535739737,
           41.166943499958066,
           41.20446164251876,
           41.24197978507945,
           41.279497927640136,
           41.317016070200836,
           41.35453421276153,
           41.392052355322214,
           41.42957049788291,
           41.46708864044359,
           41.50460678300429,
           41.54212492556498,
           41.57964306812568,
           41.61716121068637,
           41.65467935324706,
           41.69219749580775,
           41.72971563836845,
           41.76723378092913,
           41.804751923489825,
           41.84227006605052,
           41.87978820861121,
           41.9173063511719,
           41.954824493732595,
           41.99234263629329,
           42.02986077885397,
           42.067378921414665,
           42.10489706397536,
           42.14241520653604,
           42.17993334909674,
           42.21745149165743,
           42.25496963421812,
           42.29248777677881,
           42.330005919339506,
           42.3675240619002,
           42.40504220446089,
           42.445895974382516,
           42.48841755798461,
           42.53093914158671,
           42.573460725188795,
           42.61598230879089,
           42.658503892392986,
           42.70102547599508,
           42.74354705959718,
           42.786068643199265,
           42.82859022680135,
           42.87111181040346,
           42.913633394005544,
           42.95615497760764,
           42.998676561209734,
           43.04119814481183,
           43.083719728413925,
           43.12624131201602,
           43.168762895618116,
           43.211284479220204,
           43.2538060628223,
           43.29632764642439,
           43.33884923002649,
           43.38137081362858,
           43.423892397230674,
           43.46641398083277,
           43.50893556443486,
           43.55145714803696,
           43.59397873163905,
           43.635598626699846,
           43.67689856711931,
           43.71819850753877,
           43.75949844795825,
           43.800798388377714,
           43.84209832879718,
           43.88339826921665,
           43.92469820963612,
           43.96599815005559,
           44.007298090475054,
           44.048598030894524,
           44.089897971313995,
           44.13119791173345,
           44.17249785215293,
           44.2137977925724,
           44.255097732991864,
           44.296397673411334,
           44.3376976138308,
           44.37899755425027,
           44.42029749466974,
           44.4615974350892,
           44.50289737550868,
           44.544197315928145,
           44.58549725634761,
           44.62679719676708,
           44.66809713718655,
           44.70939707760602,
           44.750697018025484,
           44.791996958444955,
           44.833296898864425,
           44.87459683928388,
           44.91589677970336,
           44.95719672012283,
           44.998496660542294,
           45.039796600961765,
           45.08109654138123,
           45.122396481800706,
           45.16369642222018,
           45.20499636263964,
           45.24629630305911,
           45.287596243478575,
           45.32889618389804,
           45.370196124317516,
           45.41149606473699,
           45.45279600515644,
           45.49409594557592,
           45.535395885995385,
           45.57669582641485,
           45.617995766834326,
           45.65929570725379,
           45.70059564767326,
           45.741895588092724,
           45.783195528512195,
           45.824495468931666,
           45.865795409351136,
           45.911105566955555,
           45.960425941744916,
           46.009746316534276,
           46.059066691323636,
           46.108387066112996,
           46.157707440902364,
           46.207027815691724,
           46.256348190481084,
           46.30566856527045,
           46.35498894005981,
           46.40430931484918,
           46.45362968963854,
           46.5029500644279,
           46.55227043921726,
           46.60159081400663,
           46.65091118879599,
           46.70023156358535,
           46.74955193837471,
           46.798872313164075,
           46.848192687953436,
           46.897513062742796,
           46.94683343753216,
           46.99615381232152,
           47.04547418711089,
           47.09479456190026,
           47.14411493668962,
           47.19343531147897,
           47.24275568626834,
           47.292076061057706,
           47.34139643584706,
           47.39071681063643,
           47.440037185425794,
           47.489357560215154,
           47.538677935004515,
           47.58910294438151,
           47.63981171114401,
           47.69052047790651,
           47.741229244669015,
           47.79193801143151,
           47.84264677819401,
           47.89335554495652,
           47.94406431171902,
           47.994773078481515,
           48.04548184524402,
           48.09619061200653,
           48.14689937876902,
           48.19760814553153,
           48.24831691229403,
           48.29902567905653,
           48.349734445819024,
           48.400443212581536,
           48.45115197934403,
           48.50186074610653,
           48.552569512869034,
           48.60327827963154,
           48.653987046394036,
           48.70469581315654,
           48.755404579919045,
           48.80611334668154,
           48.85682211344404,
           48.90753088020655,
           48.95823964696905,
           49.008948413731545,
           49.05965718049405,
           49.11036594725654,
           49.161074714019044,
           49.21178348078155,
           49.26249224754406,
           49.31320101430655,
           49.363909781069054,
           49.41461854783156,
           49.465327314594056,
           49.51603608135656,
           49.56674484811906,
           49.617453614881555,
           49.66816238164406,
           49.71887114840656,
           49.76957991516906,
           49.82028868193156,
           49.87099744869406,
           49.92170621545657,
           49.97241498221907,
           50.02312374898157,
           49.941186977817104,
           49.59395913079882,
           49.24673128378055,
           48.899503436762245,
           48.55227558974397,
           48.2050477427257,
           47.857819895707394,
           47.51059204868909,
           47.163364201670845,
           46.81613635465254,
           46.46890850763423,
           46.12168066061596,
           45.77445281359768,
           45.42722496657938,
           45.079997119561106,
           44.73276927254283,
           44.38554142552452,
           44.03831357850625,
           43.69108573148798,
           43.34385788446968,
           42.99663003745137,
           42.64940219043309,
           42.30217434341482,
           41.95494649639651,
           41.60771864937824,
           41.26049080235997,
           40.91326295534165,
           40.56603510832338,
           40.21880726130511,
           39.8715794142868,
           39.524351567268496,
           39.17712372025025,
           38.829895873231955,
           38.482668026213645,
           38.13544017919537,
           37.788212332177096,
           37.44098448515879,
           37.09375663814052,
           36.746528791122245,
           36.39930094410394,
           36.05207309708566,
           35.704845250067386,
           35.35761740304908,
           35.01038955603077,
           34.6631617090125,
           34.315933861994225,
           33.96870601497592,
           33.62147816795765,
           33.27425032093938,
           32.92702247392107,
           32.579794626902796,
           32.23256677988452,
           31.88533893286622,
           31.53811108584791,
           31.19088323882967,
           30.843655391811364,
           30.496427544793058,
           30.149199697774783,
           29.80197185075651,
           29.454744003738206,
           29.10751615671993,
           28.743461797582086,
           28.3759698028309,
           28.008477808079753,
           27.640985813328612,
           27.27349381857743,
           26.90600182382625,
           26.538509829075142,
           26.171017834323962,
           25.80352583957278,
           25.436033844821637,
           25.06854185007049,
           24.701049855319308,
           24.333557860568163,
           23.966065865817015,
           23.598573871065838,
           23.231081876314658,
           22.86358988156355,
           22.496097886812365,
           22.128605892061188,
           21.76111389731004,
           21.393621902558895,
           21.026129907807714,
           20.681385880451643,
           20.450381690070678,
           20.219377499689717,
           19.988373309308756,
           19.757369118927834,
           19.526364928546872,
           19.295360738165908,
           19.06435654778499,
           18.833352357404028,
           18.602348167023063,
           18.371343976642144,
           18.134897080709784,
           17.89676576225025,
           17.658634443790714,
           17.420503125331223,
           17.18237180687169,
           16.944240488412156,
           16.70610916995266,
           16.467977851493124,
           16.22984653303359,
           15.991715214574098,
           15.753583896114565,
           15.51545257765503,
           15.277321259195539,
           15.039189940736001,
           14.801058622276468,
           14.562927303816931,
           14.32479598535744,
           14.086664666897907,
           13.84853334843837,
           13.610402029978879,
           13.372270711519342,
           13.134139393059808,
           12.896008074600317,
           12.65787675614078,
           12.419745437681245,
           12.18161411922171,
           11.943482800762219,
           11.705351482302683,
           11.467220163843148,
           11.229088845383657,
           10.990957526924122,
           10.817018476983215,
           10.688931047412762,
           10.560843617842284,
           10.432756188271807,
           10.304668758701354,
           10.176581329130876,
           10.048493899560398,
           9.920406469989922,
           9.79231904041947,
           9.664231610848992,
           9.536144181278514,
           9.408056751708061,
           9.279969322137584,
           9.151881892567108,
           9.023794462996655,
           8.895707033426175,
           8.7676196038557,
           8.639532174285222,
           8.511444744714769,
           8.383357315144291,
           8.255269885573814,
           8.12718245600336,
           7.999095026432885,
           7.871007596862407,
           7.742920167291954,
           7.614832737721476,
           7.486745308150999,
           7.358657878580546,
           7.230570449010068,
           7.102483019439592,
           6.974395589869115,
           6.848965312302822,
           6.727471209661976,
           6.605977107021129,
           6.484483004380306,
           6.3629889017394605,
           6.241494799098614,
           6.120000696457791,
           5.998506593816944,
           5.877012491176098,
           5.755518388535252,
           5.63402428589443
          ],
          [
           36.298623819731404,
           36.338517795267705,
           36.37841177080402,
           36.41830574634034,
           36.458199721876646,
           36.49809369741296,
           36.53798767294927,
           36.57788164848559,
           36.617775624021895,
           36.657669599558204,
           36.69756357509452,
           36.73745755063083,
           36.77735152616714,
           36.817245501703454,
           36.85713947723977,
           36.897033452776085,
           36.93692742831239,
           36.9768214038487,
           37.01671537938502,
           37.05660935492133,
           37.09650333045764,
           37.13639730599395,
           37.17629128153027,
           37.21618525706658,
           37.256079232602886,
           37.2959732081392,
           37.33586718367552,
           37.37576115921183,
           37.415655134748135,
           37.45554911028445,
           37.49544308582077,
           37.535337061357076,
           37.575231036893385,
           37.6151250124297,
           37.65501898796601,
           37.694912963502325,
           37.734806939038634,
           37.77470091457495,
           37.81459489011126,
           37.85448886564757,
           37.894382841183884,
           37.93427681672019,
           37.97571368343906,
           38.0174591285857,
           38.059204573732345,
           38.10095001887898,
           38.14269546402562,
           38.18444090917227,
           38.226186354318905,
           38.26793179946554,
           38.30967724461219,
           38.35142268975883,
           38.393168134905466,
           38.43491358005211,
           38.47665902519874,
           38.51840447034539,
           38.56014991549203,
           38.60189536063867,
           38.64364080578531,
           38.685386250931955,
           38.72713169607859,
           38.76887714122523,
           38.81062258637187,
           38.852368031518516,
           38.894113476665154,
           38.93585892181179,
           38.97760436695843,
           39.01934981210508,
           39.061095257251715,
           39.10284070239836,
           39.144586147545,
           39.18633159269163,
           39.228077037838275,
           39.269822482984914,
           39.31156792813156,
           39.3533133732782,
           39.39505881842484,
           39.436804263571474,
           39.47854970871812,
           39.520295153864765,
           39.562040599011404,
           39.60378604415804,
           39.64553148930468,
           39.687276934451326,
           39.72676408862303,
           39.76579958459976,
           39.80483508057648,
           39.8438705765532,
           39.88290607252993,
           39.921941568506654,
           39.96097706448337,
           40.00001256046009,
           40.039048056436826,
           40.078083552413545,
           40.117119048390265,
           40.15615454436699,
           40.19519004034372,
           40.23422553632044,
           40.273261032297164,
           40.31229652827388,
           40.35133202425061,
           40.39036752022733,
           40.42940301620406,
           40.46843851218078,
           40.5074740081575,
           40.54650950413423,
           40.58554500011095,
           40.624580496087674,
           40.66361599206439,
           40.70265148804112,
           40.741686984017846,
           40.780722479994566,
           40.819757975971285,
           40.85879347194802,
           40.897828967924745,
           40.936864463901465,
           40.975899959878184,
           41.0149354558549,
           41.05397095183164,
           41.093006447808364,
           41.13204194378508,
           41.1710774397618,
           41.21011293573852,
           41.24914843171525,
           41.288183927691975,
           41.327219423668694,
           41.364990458334766,
           41.40250860089545,
           41.44002674345615,
           41.47754488601684,
           41.51506302857753,
           41.55258117113823,
           41.590099313698914,
           41.627617456259614,
           41.6651355988203,
           41.70265374138099,
           41.740171883941684,
           41.77769002650238,
           41.81520816906306,
           41.852726311623755,
           41.89024445418445,
           41.92776259674514,
           41.96528073930584,
           42.002798881866525,
           42.04031702442721,
           42.0778351669879,
           42.1153533095486,
           42.152871452109295,
           42.19038959466998,
           42.22790773723068,
           42.265425879791366,
           42.30294402235206,
           42.34046216491275,
           42.37798030747344,
           42.415498450034136,
           42.45301659259482,
           42.49053473515552,
           42.528052877716206,
           42.565571020276906,
           42.60308916283759,
           42.640607305398284,
           42.678125447958976,
           42.71564359051967,
           42.75316173308036,
           42.79067987564105,
           42.828198018201746,
           42.86571616076243,
           42.90656993068406,
           42.94909151428615,
           42.99161309788825,
           43.03413468149034,
           43.07665626509243,
           43.11917784869453,
           43.16169943229662,
           43.20422101589872,
           43.246742599500806,
           43.2892641831029,
           43.331785766704996,
           43.37430735030709,
           43.41682893390919,
           43.45935051751128,
           43.50187210111337,
           43.544393684715466,
           43.58691526831756,
           43.62943685191966,
           43.671958435521745,
           43.71448001912384,
           43.757001602725936,
           43.79952318632803,
           43.842044769930126,
           43.88456635353222,
           43.9270879371343,
           43.9696095207364,
           44.01213110433849,
           44.05465268794059,
           44.097174271542684,
           44.13969585514478,
           44.18221743874687,
           44.22473902234897,
           44.26726060595105,
           44.30978218955315,
           44.35230377315525,
           44.39482535675734,
           44.43734694035943,
           44.47986852396153,
           44.52239010756362,
           44.56491169116571,
           44.60743327476781,
           44.649954858369895,
           44.69247644197199,
           44.734998025574086,
           44.77751960917618,
           44.82004119277828,
           44.861748347246404,
           44.90304828766587,
           44.94434822808534,
           44.98564816850481,
           45.02694810892427,
           45.068248049343744,
           45.109547989763215,
           45.15084793018268,
           45.19214787060215,
           45.23344781102161,
           45.27474775144108,
           45.316047691860554,
           45.357347632280025,
           45.398647572699495,
           45.43994751311896,
           45.48124745353843,
           45.5225473939579,
           45.56384733437737,
           45.605147274796835,
           45.646447215216305,
           45.68774715563577,
           45.72904709605524,
           45.7703470364747,
           45.811646976894174,
           45.852946917313645,
           45.894246857733116,
           45.93554679815258,
           45.97684673857204,
           46.01814667899151,
           46.05944661941099,
           46.100746559830455,
           46.14204650024992,
           46.183346440669396,
           46.22464638108886,
           46.26594632150833,
           46.3072462619278,
           46.34854620234726,
           46.39385635995168,
           46.443176734741044,
           46.492497109530404,
           46.541817484319765,
           46.59113785910914,
           46.64045823389849,
           46.68977860868785,
           46.73909898347722,
           46.78841935826658,
           46.83773973305594,
           46.88706010784531,
           46.93638048263467,
           46.98570085742403,
           47.035021232213396,
           47.08434160700276,
           47.133661981792116,
           47.18298235658148,
           47.232302731370844,
           47.281623106160204,
           47.33094348094957,
           47.380263855738924,
           47.4295842305283,
           47.47890460531765,
           47.52822498010702,
           47.57754535489639,
           47.62686572968575,
           47.67618610447511,
           47.72550647926447,
           47.774826854053835,
           47.824147228843195,
           47.87346760363256,
           47.92278797842192,
           47.97210835321128,
           48.02142872800064,
           48.07074910279002,
           48.12006947757937,
           48.16938985236874,
           48.2187102271581,
           48.26803060194746,
           48.31735097673682,
           48.36667135152619,
           48.415991726315546,
           48.465312101104914,
           48.514632475894274,
           48.563952850683634,
           48.613273225472994,
           48.66259360026237,
           48.71191397505173,
           48.76123434984108,
           48.81055472463045,
           48.85987509941981,
           48.90919547420917,
           48.95851584899854,
           49.007836223787905,
           49.057156598577265,
           49.10647697336662,
           49.155797348155986,
           49.20511772294536,
           49.25443809773472,
           49.30375847252408,
           49.35307884731344,
           49.4025309693336,
           49.45323973609611,
           49.503948502858606,
           49.5546572696211,
           49.6053660363836,
           49.65607480314611,
           49.70678356990861,
           49.757492336671106,
           49.8082011034336,
           49.858909870196115,
           49.90961863695861,
           49.96032740372112,
           50.011036170483614,
           50.06174493724612,
           50.11245370400861,
           50.16316247077111,
           50.21387123753362,
           50.26458000429612,
           50.31528877105862,
           50.36599753782112,
           50.41670630458363,
           50.467415071346124,
           50.38547830018166,
           50.038250453163386,
           49.69102260614511,
           49.3437947591268,
           48.99656691210853,
           48.64933906509025,
           48.30211121807195,
           47.95488337105364,
           47.60765552403541,
           47.26042767701709,
           46.91319982999879,
           46.565971982980514,
           46.21874413596224,
           45.87151628894394,
           45.524288441925655,
           45.17706059490738,
           44.829832747889085,
           44.48260490087081,
           44.13537705385254,
           43.788149206834234,
           43.44092135981592,
           43.09369351279764,
           42.74646566577937,
           42.39923781876107,
           42.052009971742805,
           41.70478212472453,
           41.357554277706214,
           40.99585204883269,
           40.62836005408154,
           40.26086805933037,
           39.893376064579186,
           39.52588406982808,
           39.1583920750769,
           38.79090008032572,
           38.42340808557457,
           38.05591609082342,
           37.68842409607225,
           37.3209321013211,
           36.95344010656996,
           36.58594811181877,
           36.21845611706763,
           35.85096412231648,
           35.48347212756531,
           35.11598013281412,
           34.74848813806298,
           34.38099614331183,
           34.013504148560656,
           33.64601215380951,
           33.27852015905836,
           32.91102816430718,
           32.543536169556035,
           32.176044174804886,
           31.808552180053706,
           31.441060185302533,
           31.073568190551416,
           30.70607619580024,
           30.33858420104906,
           29.97109220629791,
           29.60360021154677,
           29.236108216795586,
           28.868616222044437,
           28.501124227293296,
           28.13363223254212,
           27.76614023779097,
           27.398648243039823,
           27.031156248288646,
           26.663664253537462,
           26.296172258786356,
           25.928680264035172,
           25.561188269283992,
           25.19369627453285,
           24.826204279781702,
           24.45871228503052,
           24.091220290279374,
           23.723728295528232,
           23.356236300777052,
           22.98874430602587,
           22.621252311274752,
           22.25376031652358,
           21.8862683217724,
           21.51877632702125,
           21.1512843322701,
           20.783792337518936,
           20.439048310162853,
           20.208044119781892,
           19.97703992940093,
           19.74603573901997,
           19.515031548639044,
           19.284027358258086,
           19.05302316787712,
           18.822018977496203,
           18.591014787115242,
           18.360010596734277,
           18.129006406353355,
           17.898002215972394,
           17.66699802559143,
           17.435993835210468,
           17.204989644829546,
           16.973985454448584,
           16.742981264067623,
           16.5119770736867,
           16.28097288330574,
           16.04996869292478,
           15.818964502543857,
           15.587960312162895,
           15.35695612178193,
           15.12595193140101,
           14.894947741020049,
           14.663943550639086,
           14.431439936695313,
           14.193308618235818,
           13.955177299776285,
           13.717045981316748,
           13.478914662857257,
           13.240783344397723,
           13.002652025938186,
           12.764520707478695,
           12.526389389019158,
           12.288258070559625,
           12.05012675210009,
           11.811995433640597,
           11.573864115181062,
           11.335732796721526,
           11.097601478262035,
           10.859470159802498,
           10.685531109861593,
           10.55744368029114,
           10.429356250720664,
           10.301268821150186,
           10.173181391579734,
           10.045093962009254,
           9.917006532438776,
           9.7889191028683,
           9.660831673297848,
           9.532744243727372,
           9.404656814156894,
           9.27656938458644,
           9.148481955015964,
           9.020394525445486,
           8.892307095875033,
           8.764219666304555,
           8.642437330383151,
           8.520943227742306,
           8.399449125101484,
           8.277955022460638,
           8.156460919819791,
           8.034966817178967,
           7.913472714538121,
           7.791978611897276,
           7.670484509256452,
           7.548990406615605,
           7.42749630397476,
           7.306002201333936,
           7.18450809869309,
           7.063013996052243,
           6.941519893411399,
           6.8200257907705755,
           6.698531688129729,
           6.577037585488884,
           6.455543482848061,
           6.3340493802072135,
           6.212555277566368,
           6.091061174925544,
           5.969567072284699,
           5.848072969643852,
           5.726578867003006,
           5.605084764362184
          ],
          [
           36.703712197934756,
           36.743606173471065,
           36.783500149007374,
           36.82339412454369,
           36.86328810008,
           36.903182075616314,
           36.94307605115263,
           36.98297002668893,
           37.02286400222525,
           37.062757977761564,
           37.10265195329788,
           37.14254592883419,
           37.1824399043705,
           37.22233387990681,
           37.26222785544312,
           37.30212183097944,
           37.34201580651575,
           37.38190978205206,
           37.42180375758837,
           37.46169773312468,
           37.501591708660996,
           37.54148568419731,
           37.581379659733614,
           37.62127363526994,
           37.661167610806245,
           37.701678741710495,
           37.74342418685714,
           37.78516963200377,
           37.82691507715042,
           37.868660522297056,
           37.910405967443694,
           37.95215141259034,
           37.99389685773697,
           38.03564230288362,
           38.07738774803026,
           38.1191331931769,
           38.16087863832354,
           38.202624083470184,
           38.24436952861682,
           38.28611497376346,
           38.327860418910106,
           38.369605864056744,
           38.41135130920338,
           38.45309675435003,
           38.49484219949666,
           38.536587644643305,
           38.57833308978994,
           38.62007853493658,
           38.66182398008323,
           38.703569425229865,
           38.745314870376504,
           38.78706031552315,
           38.828805760669795,
           38.870551205816426,
           38.912296650963064,
           38.95404209610971,
           38.99578754125635,
           39.037532986402994,
           39.07927843154963,
           39.12102387669627,
           39.162769321842916,
           39.20451476698955,
           39.24626021213619,
           39.28800565728284,
           39.32975110242947,
           39.371496547576115,
           39.41324199272275,
           39.45498743786939,
           39.49673288301604,
           39.538478328162675,
           39.58022377330932,
           39.62196921845596,
           39.6637146636026,
           39.705460108749236,
           39.74720555389588,
           39.78895099904252,
           39.83069644418915,
           39.8724418893358,
           39.91418733448244,
           39.95593277962908,
           39.997678224775726,
           40.03942366992236,
           40.08116911506901,
           40.12291456021564,
           40.16240171438735,
           40.20143721036408,
           40.240472706340796,
           40.27950820231752,
           40.31854369829425,
           40.35757919427097,
           40.396614690247695,
           40.43565018622442,
           40.47468568220114,
           40.51372117817786,
           40.55275667415459,
           40.59179217013131,
           40.63082766610803,
           40.669863162084766,
           40.708898658061486,
           40.747934154038205,
           40.786969650014925,
           40.82600514599166,
           40.86504064196838,
           40.904076137945104,
           40.94311163392182,
           40.98214712989855,
           41.02118262587527,
           41.06021812185199,
           41.09925361782872,
           41.13828911380544,
           41.17732460978216,
           41.21636010575889,
           41.255395601735614,
           41.294431097712334,
           41.33346659368906,
           41.37250208966579,
           41.411537585642506,
           41.45057308161923,
           41.48960857759595,
           41.52864407357268,
           41.5676795695494,
           41.606715065526124,
           41.64575056150285,
           41.68478605747957,
           41.7238215534563,
           41.762857049433016,
           41.801892545409736,
           41.84092804138646,
           41.87996353736319,
           41.918999033339915,
           41.958034529316635,
           41.99707002529336,
           42.03610552127008,
           42.07514101724681,
           42.11417651322353,
           42.15321200920025,
           42.19224750517698,
           42.2312830011537,
           42.27031849713042,
           42.309353993107145,
           42.34838948908387,
           42.3874249850606,
           42.425954695607395,
           42.46347283816809,
           42.50099098072879,
           42.53850912328947,
           42.57602726585016,
           42.61354540841085,
           42.65106355097154,
           42.688581693532235,
           42.72609983609293,
           42.76361797865362,
           42.80113612121431,
           42.838654263775005,
           42.8761724063357,
           42.91369054889638,
           42.951208691457076,
           42.98872683401777,
           43.02624497657846,
           43.06376311913915,
           43.101281261699846,
           43.13879940426054,
           43.17631754682124,
           43.213835689381916,
           43.25135383194261,
           43.2888719745033,
           43.326390117063994,
           43.36724388698562,
           43.409765470587715,
           43.45228705418981,
           43.4948086377919,
           43.537330221393994,
           43.57985180499609,
           43.622373388598184,
           43.66489497220028,
           43.70741655580237,
           43.74993813940446,
           43.79245972300656,
           43.834981306608654,
           43.87750289021074,
           43.920024473812845,
           43.962546057414926,
           44.005067641017035,
           44.04758922461912,
           44.09011080822122,
           44.13263239182331,
           44.1751539754254,
           44.21767555902749,
           44.26019714262959,
           44.30271872623169,
           44.34524030983378,
           44.38776189343587,
           44.43028347703796,
           44.472805060640056,
           44.51532664424215,
           44.55784822784425,
           44.600369811446335,
           44.64289139504843,
           44.685412978650525,
           44.72793456225262,
           44.770456145854716,
           44.81297772945681,
           44.8554993130589,
           44.898020896660995,
           44.94054248026308,
           44.98306406386518,
           45.02558564746728,
           45.06810723106936,
           45.110628814671465,
           45.15315039827355,
           45.19567198187565,
           45.238193565477744,
           45.28071514907984,
           45.32323673268192,
           45.36575831628403,
           45.40827989988612,
           45.45080148348821,
           45.4933230670903,
           45.5358446506924,
           45.57836623429449,
           45.62088781789659,
           45.66340940149868,
           45.70593098510077,
           45.74845256870287,
           45.79097415230496,
           45.83349573590705,
           45.876017319509145,
           45.91853890311124,
           45.961060486713336,
           46.00358207031543,
           46.04610365391751,
           46.08789806779298,
           46.12919800821245,
           46.17049794863192,
           46.21179788905139,
           46.25309782947086,
           46.294397769890324,
           46.335697710309795,
           46.376997650729265,
           46.41829759114873,
           46.4595975315682,
           46.50089747198766,
           46.542197412407134,
           46.583497352826605,
           46.62479729324607,
           46.66609723366554,
           46.70739717408501,
           46.74869711450447,
           46.78999705492395,
           46.831296995343415,
           46.876607152947834,
           46.9259275277372,
           46.975247902526554,
           47.02456827731592,
           47.07388865210528,
           47.12320902689464,
           47.172529401683995,
           47.22184977647337,
           47.27117015126273,
           47.32049052605208,
           47.36981090084146,
           47.41913127563082,
           47.468451650420185,
           47.517772025209545,
           47.567092399998906,
           47.61641277478827,
           47.665733149577626,
           47.71505352436699,
           47.764373899156354,
           47.813694273945714,
           47.86301464873509,
           47.91233502352445,
           47.96165539831381,
           48.01097577310317,
           48.06029614789254,
           48.1096165226819,
           48.15893689747126,
           48.208257272260624,
           48.257577647049985,
           48.306898021839345,
           48.356218396628705,
           48.40553877141808,
           48.454859146207426,
           48.5041795209968,
           48.55349989578616,
           48.60282027057552,
           48.65214064536488,
           48.70146102015425,
           48.75078139494361,
           48.800101769732976,
           48.849422144522336,
           48.898742519311696,
           48.94806289410106,
           48.99738326889042,
           49.046703643679784,
           49.09602401846914,
           49.145344393258505,
           49.19466476804787,
           49.24398514283724,
           49.29330551762659,
           49.34262589241597,
           49.39194626720533,
           49.44126664199469,
           49.49058701678406,
           49.53990739157342,
           49.58922776636277,
           49.638548141152135,
           49.6878685159415,
           49.73718889073086,
           49.78650926552022,
           49.83582964030959,
           49.88515001509896,
           49.934470389888304,
           49.98379076467767,
           50.03311113946703,
           50.0824315142564,
           50.131751889045766,
           50.181072263835134,
           50.23039263862449,
           50.279097601325795,
           50.326718246100846,
           50.37433889087589,
           50.421959535650934,
           50.46958018042598,
           50.51720082520102,
           50.56482146997606,
           50.61244211475111,
           50.660062759526156,
           50.70768340430119,
           50.755304049076244,
           50.802924693851296,
           50.85054533862634,
           50.89816598340138,
           50.80644519760834,
           50.43604155067926,
           50.0656379037502,
           49.6952342568211,
           49.32483060989203,
           48.95442696296297,
           48.584023316033864,
           48.213619669104766,
           47.84321602217573,
           47.472812375246626,
           47.10240872831753,
           46.73200508138846,
           46.361601434459395,
           45.99119778753029,
           45.62079414060122,
           45.25039049367216,
           44.87998684674305,
           44.50958319981399,
           44.13917955288491,
           43.76877590595582,
           43.398372259026715,
           43.027968612097645,
           42.65756496516858,
           42.28716131823947,
           41.91675767131041,
           41.546354024381344,
           41.17595037745224,
           40.805546730523176,
           40.4351430835941,
           40.064739436665,
           39.6943357897359,
           39.32393214280687,
           38.95352849587776,
           38.583124848948664,
           38.212721202019594,
           37.84231755509053,
           37.471913908161426,
           37.101510261232356,
           36.731106614303286,
           36.36070296737419,
           35.99029932044511,
           35.61989567351605,
           35.24949202658695,
           34.879088379657844,
           34.50868473272878,
           34.13865857302304,
           33.77116657827186,
           33.403674583520704,
           33.03618258876956,
           32.668690594018386,
           32.30119859926724,
           31.93370660451609,
           31.566214609764913,
           31.198722615013736,
           30.831230620262616,
           30.463738625511443,
           30.096246630760263,
           29.728754636009114,
           29.361262641257973,
           28.99377064650679,
           28.626278651755644,
           28.2587866570045,
           27.891294662253323,
           27.52380266750217,
           27.156310672751022,
           26.788818677999846,
           26.421326683248665,
           26.05383468849756,
           25.686342693746376,
           25.318850698995192,
           24.95135870424405,
           24.583866709492902,
           24.216374714741722,
           23.848882719990577,
           23.481390725239432,
           23.113898730488252,
           22.74640673573707,
           22.378914740985962,
           22.011422746234782,
           21.643930751483598,
           21.27643875673245,
           20.908946761981312,
           20.54145476723013,
           20.196710739874057,
           19.965706549493095,
           19.73470235911213,
           19.50369816873117,
           19.27269397835025,
           19.04168978796929,
           18.810685597588325,
           18.579681407207403,
           18.34867721682644,
           18.11767302644548,
           17.88666883606456,
           17.655664645683594,
           17.424660455302632,
           17.193656264921668,
           16.96265207454075,
           16.73164788415979,
           16.500643693778827,
           16.269639503397904,
           16.038635313016943,
           15.80763112263598,
           15.57662693225506,
           15.345622741874097,
           15.114618551493134,
           14.883614361112215,
           14.652610170731252,
           14.42160598035029,
           14.190601789969326,
           13.959597599588408,
           13.728593409207443,
           13.497589218826482,
           13.266585028445562,
           13.035580838064599,
           12.804576647683634,
           12.573572457302715,
           12.342568266921754,
           12.111564076540791,
           11.880559886159826,
           11.649555695778908,
           11.418551505397945,
           11.187547315016982,
           10.956543124636061,
           10.725538934255098,
           10.557403451104326,
           10.435909348463504,
           10.314415245822659,
           10.192921143181811,
           10.071427040540986,
           9.949932937900142,
           9.828438835259297,
           9.706944732618451,
           9.585450629977627,
           9.463956527336778,
           9.342462424695935,
           9.22096832205511,
           9.099474219414265,
           8.97798011677342,
           8.856486014132596,
           8.73499191149175,
           8.613497808850905,
           8.492003706210058,
           8.370509603569236,
           8.24901550092839,
           8.127521398287543,
           8.006027295646719,
           7.884533193005874,
           7.763039090365028,
           7.641544987724204,
           7.520050885083359,
           7.398556782442512,
           7.2770626798016895,
           7.155568577160843,
           7.034074474519997,
           6.912580371879151,
           6.791086269238328,
           6.669592166597482,
           6.548098063956636,
           6.426603961315813,
           6.305109858674967,
           6.183615756034121,
           6.062121653393298,
           5.940627550752452,
           5.8191334481116055,
           5.69763934547076,
           5.576145242829937
          ],
          [
           37.108800576138094,
           37.1486945516744,
           37.18858852721072,
           37.22848250274703,
           37.26837647828334,
           37.30827045381965,
           37.34816442935596,
           37.38805840489228,
           37.427952380428586,
           37.46938924512855,
           37.5111346902752,
           37.55288013542183,
           37.594625580568476,
           37.636371025715114,
           37.67811647086175,
           37.7198619160084,
           37.76160736115503,
           37.80335280630167,
           37.84509825144832,
           37.88684369659495,
           37.9285891417416,
           37.97033458688824,
           38.01208003203487,
           38.05382547718152,
           38.09557092232816,
           38.137316367474796,
           38.17906181262144,
           38.22080725776808,
           38.26255270291472,
           38.30429814806136,
           38.346043593208,
           38.38778903835464,
           38.42953448350128,
           38.471279928647924,
           38.51302537379456,
           38.55477081894121,
           38.59651626408784,
           38.638261709234484,
           38.68000715438113,
           38.72175259952776,
           38.76349804467441,
           38.805243489821045,
           38.84698893496768,
           38.88873438011433,
           38.93047982526096,
           38.972225270407606,
           39.01397071555425,
           39.05571616070088,
           39.09746160584753,
           39.13920705099417,
           39.180952496140804,
           39.22269794128745,
           39.264443386434095,
           39.30618883158073,
           39.34793427672737,
           39.38967972187401,
           39.43142516702065,
           39.473170612167294,
           39.51491605731393,
           39.55666150246057,
           39.59840694760722,
           39.640152392753855,
           39.68189783790049,
           39.72364328304714,
           39.76538872819378,
           39.807134173340415,
           39.84887961848706,
           39.8906250636337,
           39.93237050878034,
           39.974115953926976,
           40.01586139907362,
           40.05760684422026,
           40.099352289366905,
           40.141097734513544,
           40.18284317966019,
           40.22458862480683,
           40.26633406995346,
           40.308079515100104,
           40.34982496024675,
           40.39157040539339,
           40.43331585054003,
           40.475061295686665,
           40.51680674083331,
           40.55855218597995,
           40.59803934015166,
           40.637074836128384,
           40.676110332105104,
           40.71514582808183,
           40.75418132405855,
           40.79321682003527,
           40.832252316012,
           40.87128781198872,
           40.91032330796544,
           40.94935880394217,
           40.98839429991889,
           41.027429795895614,
           41.06646529187233,
           41.10550078784907,
           41.144536283825786,
           41.183571779802506,
           41.22260727577924,
           41.26164277175596,
           41.30067826773268,
           41.339713763709405,
           41.37874925968613,
           41.41778475566285,
           41.45682025163957,
           41.4958557476163,
           41.53489124359302,
           41.57392673956974,
           41.61296223554647,
           41.651997731523196,
           41.691033227499915,
           41.730068723476634,
           41.76910421945336,
           41.80813971543009,
           41.84717521140681,
           41.88621070738353,
           41.92524620336026,
           41.96428169933698,
           42.0033171953137,
           42.04235269129043,
           42.08138818726715,
           42.12042368324387,
           42.1594591792206,
           42.19849467519732,
           42.23753017117404,
           42.27656566715076,
           42.31560116312749,
           42.354636659104216,
           42.393672155080935,
           42.43270765105766,
           42.47174314703439,
           42.51077864301111,
           42.549814138987834,
           42.588849634964554,
           42.62788513094128,
           42.666920626918,
           42.70595612289473,
           42.74499161887145,
           42.78402711484817,
           42.8230626108249,
           42.86209810680162,
           42.901133602778344,
           42.94016909875507,
           42.9792045947318,
           43.01824009070852,
           43.05727558668524,
           43.09631108266196,
           43.13534657863869,
           43.17438207461541,
           43.213417570592135,
           43.252453066568854,
           43.29148856254558,
           43.33052405852231,
           43.36955955449903,
           43.40859505047575,
           43.44763054645247,
           43.48666604242919,
           43.524437075440694,
           43.56195521800139,
           43.59947336056208,
           43.63699150312277,
           43.67450964568346,
           43.71202778824415,
           43.74954593080484,
           43.787064073365535,
           43.82791784328717,
           43.87043942688926,
           43.91296101049135,
           43.95548259409344,
           43.998004177695535,
           44.04052576129764,
           44.08304734489973,
           44.12556892850182,
           44.168090512103916,
           44.210612095706004,
           44.25313367930811,
           44.295655262910195,
           44.3381768465123,
           44.38069843011438,
           44.423220013716474,
           44.46574159731857,
           44.508263180920665,
           44.55078476452276,
           44.593306348124855,
           44.63582793172694,
           44.67834951532903,
           44.720871098931134,
           44.76339268253323,
           44.80591426613532,
           44.84843584973741,
           44.8909574333395,
           44.933479016941604,
           44.9760006005437,
           45.018522184145795,
           45.061043767747876,
           45.10356535134997,
           45.146086934952066,
           45.18860851855416,
           45.23113010215626,
           45.273651685758345,
           45.31617326936045,
           45.35869485296254,
           45.40121643656463,
           45.44373802016673,
           45.486259603768815,
           45.52878118737091,
           45.571302770973,
           45.6138243545751,
           45.65634593817719,
           45.69886752177929,
           45.74138910538138,
           45.783910688983475,
           45.82643227258556,
           45.86895385618766,
           45.911475439789754,
           45.95399702339185,
           45.99651860699394,
           46.03904019059603,
           46.08156177419813,
           46.124083357800224,
           46.16660494140231,
           46.20912652500441,
           46.2516481086065,
           46.29416969220859,
           46.33669127581069,
           46.37921285941278,
           46.42173444301488,
           46.46425602661697,
           46.50677761021906,
           46.549299193821156,
           46.59182077742325,
           46.63434236102535,
           46.67686394462744,
           46.71938552822953,
           46.761907111831626,
           46.804428695433714,
           46.84695027903581,
           46.88947186263791,
           46.93199344624,
           46.974515029842095,
           47.01703661344419,
           47.05955819704628,
           47.102079780648374,
           47.14460136425046,
           47.187122947852565,
           47.22964453145466,
           47.27216611505675,
           47.31404778833954,
           47.359357945943955,
           47.40867832073333,
           47.45799869552268,
           47.50731907031204,
           47.555291393450304,
           47.602912038225355,
           47.6505326830004,
           47.698153327775444,
           47.745773972550495,
           47.79339461732554,
           47.841015262100576,
           47.88863590687563,
           47.93625655165067,
           47.98387719642571,
           48.03149784120076,
           48.0791184859758,
           48.12673913075084,
           48.17435977552589,
           48.22198042030094,
           48.26960106507598,
           48.317221709851026,
           48.36484235462608,
           48.412462999401114,
           48.46008364417616,
           48.5077042889512,
           48.55532493372625,
           48.60294557850129,
           48.65056622327634,
           48.69818686805139,
           48.74580751282643,
           48.79342815760148,
           48.84104880237652,
           48.88866944715156,
           48.93629009192661,
           48.983910736701645,
           49.0315313814767,
           49.079152026251734,
           49.126772671026785,
           49.17439331580182,
           49.222013960576874,
           49.269634605351925,
           49.31725525012697,
           49.364875894902006,
           49.41249653967705,
           49.4601171844521,
           49.50773782922714,
           49.55535847400218,
           49.60297911877724,
           49.65059976355228,
           49.698220408327316,
           49.745841053102374,
           49.79346169787742,
           49.841082342652456,
           49.8887029874275,
           49.93632363220255,
           49.98394427697759,
           50.03156492175263,
           50.079185566527684,
           50.12680621130272,
           50.17442685607777,
           50.222047500852824,
           50.26966814562786,
           50.317288790402905,
           50.36490943517795,
           50.412530079952994,
           50.46015072472804,
           50.507771369503075,
           50.555392014278134,
           50.60301265905317,
           50.650633303828215,
           50.698253948603266,
           50.74587459337831,
           50.793495238153355,
           50.84111588292839,
           50.88873652770344,
           50.93635717247848,
           50.98397781725353,
           51.031598462028576,
           51.07921910680361,
           51.126839751578665,
           51.174460396353716,
           51.22208104112876,
           51.2697016859038,
           51.177980900110754,
           50.807577253181684,
           50.43717360625262,
           50.06676995932352,
           49.696366312394446,
           49.32596266546538,
           48.95555901853629,
           48.58515537160718,
           48.21475172467815,
           47.844348077749046,
           47.47394443081994,
           47.10354078389088,
           46.733137136961815,
           46.36273349003271,
           45.99232984310365,
           45.62192619617457,
           45.25152254924547,
           44.8811189023164,
           44.51071525538734,
           44.140311608458234,
           43.76990796152913,
           43.399504314600065,
           43.029100667671,
           42.6586970207419,
           42.28829337381283,
           41.917889726883764,
           41.54748607995466,
           41.17708243302559,
           40.806678786096526,
           40.43627513916742,
           40.065871492238315,
           39.69546784530929,
           39.32506419838018,
           38.954660551451084,
           38.58425690452202,
           38.213853257592945,
           37.84344961066384,
           37.473045963734776,
           37.10264231680571,
           36.7322386698766,
           36.36183502294754,
           35.99143137601847,
           35.62102772908936,
           35.25062408216027,
           34.8802204352312,
           34.50981678830213,
           34.139413141373026,
           33.769009494443964,
           33.398605847514894,
           33.028202200585795,
           32.657798553656725,
           32.287394906727656,
           31.916991259798557,
           31.546587612869452,
           31.17618396594042,
           30.80578031901132,
           30.435376672082214,
           30.05477784060101,
           29.6653789123162,
           29.275979984031345,
           28.886581055746532,
           28.49718212746172,
           28.107783199176865,
           27.718384270892052,
           27.32898534260724,
           26.939586414322385,
           26.550187486037537,
           26.16078855775276,
           25.771389629467905,
           25.381990701183057,
           24.992591772898244,
           24.60319284461343,
           24.213793916328576,
           23.824394988043764,
           23.43499605975895,
           23.045597131474096,
           22.65619820318925,
           22.26679927490447,
           21.877400346619616,
           21.48800141833477,
           21.098602490049956,
           20.70920356176514,
           20.319804633480288,
           19.958064682474834,
           19.73461961786593,
           19.511174553257025,
           19.28772948864812,
           19.064284424039258,
           18.840839359430355,
           18.61739429482145,
           18.393949230212588,
           18.170504165603685,
           17.947059100994775,
           17.723614036385914,
           17.500168971777008,
           17.276723907168105,
           17.0532788425592,
           16.822896072075608,
           16.592383535904318,
           16.361870999733018,
           16.13135846356177,
           15.900845927390478,
           15.670333391219184,
           15.439820855047932,
           15.20930831887664,
           14.978795782705342,
           14.748283246534093,
           14.517770710362798,
           14.287258174191505,
           14.056745638020214,
           13.82623310184896,
           13.595720565677667,
           13.365208029506373,
           13.134695493335123,
           12.904182957163828,
           12.673670420992535,
           12.443157884821284,
           12.212645348649989,
           11.982132812478696,
           11.751620276307403,
           11.521107740136152,
           11.290595203964857,
           11.060082667793564,
           10.829570131622312,
           10.599057595451018,
           10.432377173460536,
           10.311291118742064,
           10.190205064023566,
           10.069119009305073,
           9.948032954586603,
           9.826946899868105,
           9.705860845149612,
           9.58477479043112,
           9.463688735712646,
           9.342602680994151,
           9.221516626275656,
           9.100430571557185,
           8.97934451683869,
           8.858258462120196,
           8.737172407401724,
           8.61608635268323,
           8.495000297964737,
           8.37391424324624,
           8.252828188527769,
           8.131742133809274,
           8.01065607909078,
           7.889570024372308,
           7.768483969653813,
           7.647397914935318,
           7.526311860216847,
           7.405225805498351,
           7.2841397507798575,
           7.163053696061385,
           7.04310259476697,
           6.928150506829732,
           6.813198418892494,
           6.698246330955277,
           6.583294243018038,
           6.4683421550808,
           6.353390067143582,
           6.238437979206344,
           6.123485891269105,
           6.008533803331888,
           5.8935817153946495,
           5.778629627457411,
           5.663677539520172,
           5.548725451582956
          ],
          [
           37.50869535054463,
           37.552160137361824,
           37.59562492417902,
           37.63908971099622,
           37.68255449781341,
           37.72601928463061,
           37.769484071447806,
           37.812948858265,
           37.85641364508219,
           37.89873220177549,
           37.94047764692213,
           37.982223092068764,
           38.02396853721541,
           38.06571398236205,
           38.10745942750869,
           38.14920487265533,
           38.19095031780197,
           38.23269576294861,
           38.274441208095254,
           38.316186653241886,
           38.35793209838853,
           38.39967754353518,
           38.44142298868181,
           38.48316843382845,
           38.52491387897509,
           38.56665932412173,
           38.608404769268375,
           38.650150214415014,
           38.69189565956166,
           38.7336411047083,
           38.775386549854936,
           38.81713199500158,
           38.85887744014821,
           38.900622885294865,
           38.9423683304415,
           38.98411377558814,
           39.02585922073478,
           39.06760466588142,
           39.109350111028064,
           39.151095556174695,
           39.19284100132134,
           39.234586446467986,
           39.276331891614625,
           39.31807733676126,
           39.3598227819079,
           39.40156822705454,
           39.443313672201185,
           39.485059117347824,
           39.52680456249446,
           39.56855000764111,
           39.610295452787746,
           39.652040897934384,
           39.69378634308103,
           39.73553178822767,
           39.777277233374306,
           39.81902267852095,
           39.86076812366759,
           39.90251356881423,
           39.944259013960874,
           39.98600445910751,
           40.02774990425415,
           40.069495349400796,
           40.111240794547435,
           40.15298623969407,
           40.19473168484072,
           40.23647712998735,
           40.278222575133995,
           40.31996802028063,
           40.36171346542727,
           40.40345891057391,
           40.445204355720556,
           40.486949800867194,
           40.52869524601384,
           40.57044069116048,
           40.612186136307116,
           40.653931581453755,
           40.6956770266004,
           40.73742247174704,
           40.77916791689368,
           40.820913362040315,
           40.86265880718696,
           40.9044042523336,
           40.946149697480244,
           40.987895142626876,
           41.02851560415148,
           41.06891106895167,
           41.109306533751855,
           41.14970199855204,
           41.190097463352224,
           41.230492928152415,
           41.2708883929526,
           41.311283857752784,
           41.35099933628754,
           41.39003483226426,
           41.42907032824098,
           41.46810582421771,
           41.50714132019443,
           41.546176816171155,
           41.58521231214789,
           41.62424780812461,
           41.663283304101334,
           41.70231880007806,
           41.74135429605477,
           41.7803897920315,
           41.819425288008226,
           41.858460783984945,
           41.89749627996167,
           41.93653177593839,
           41.97556727191512,
           42.01460276789184,
           42.053638263868564,
           42.09267375984529,
           42.13170925582201,
           42.170744751798736,
           42.209780247775456,
           42.24881574375218,
           42.2878512397289,
           42.32688673570563,
           42.365922231682354,
           42.40495772765907,
           42.4439932236358,
           42.48302871961252,
           42.52206421558924,
           42.56109971156597,
           42.60013520754269,
           42.63917070351941,
           42.678206199496145,
           42.717241695472865,
           42.75627719144959,
           42.79531268742631,
           42.83434818340303,
           42.87338367937976,
           42.912419175356476,
           42.95145467133321,
           42.99049016730993,
           43.02952566328665,
           43.068561159263375,
           43.107596655240094,
           43.14663215121682,
           43.18566764719354,
           43.224703143170274,
           43.26373863914699,
           43.30277413512372,
           43.34180963110044,
           43.380845127077166,
           43.419880623053885,
           43.45891611903061,
           43.49795161500734,
           43.53698711098406,
           43.576022606960784,
           43.6150581029375,
           43.65409359891423,
           43.69312909489095,
           43.73216459086768,
           43.7712000868444,
           43.81023558282113,
           43.84927107879785,
           43.888306574774575,
           43.927342070751294,
           43.96637756672802,
           44.00541306270475,
           44.04444855868147,
           44.08348405465819,
           44.12251955063491,
           44.16155504661163,
           44.20059054258836,
           44.239626038565085,
           44.281664734576246,
           44.325205030604636,
           44.36874532663303,
           44.412285622661415,
           44.45582591868981,
           44.49936621471819,
           44.54290651074658,
           44.586446806774966,
           44.62998710280336,
           44.67352739883175,
           44.717067694860134,
           44.759904090999754,
           44.802458929227974,
           44.845013767456194,
           44.88756860568442,
           44.93012344391266,
           44.97267828214088,
           45.01523312036911,
           45.05778795859734,
           45.10034279682556,
           45.14289763505379,
           45.18545247328201,
           45.22800731151024,
           45.27056214973847,
           45.313116987966694,
           45.35567182619492,
           45.39822666442315,
           45.440781502651376,
           45.4833363408796,
           45.52589117910783,
           45.56844601733605,
           45.61100085556428,
           45.653555693792505,
           45.69611053202073,
           45.73866537024896,
           45.78122020847718,
           45.823775046705414,
           45.866329884933634,
           45.90888472316186,
           45.95143956139009,
           45.993994399618316,
           46.03654923784654,
           46.07910407607478,
           46.121658914303,
           46.164213752531225,
           46.20676859075945,
           46.24932342898768,
           46.29187826721591,
           46.334433105444134,
           46.37698794367236,
           46.41954278190059,
           46.462097620128816,
           46.504652458357036,
           46.54720729658526,
           46.58976213481348,
           46.63231697304172,
           46.67487181126994,
           46.71742664949817,
           46.75998148772639,
           46.80253632595462,
           46.845091164182854,
           46.887646002411074,
           46.9302008406393,
           46.97275567886752,
           47.015310517095756,
           47.05786535532398,
           47.10042019355221,
           47.14297503178044,
           47.185529870008665,
           47.22808470823689,
           47.27063954646512,
           47.31319438469335,
           47.35574922292157,
           47.3983040611498,
           47.440858899378014,
           47.483413737606256,
           47.525968575834476,
           47.5685234140627,
           47.61107825229092,
           47.65363309051915,
           47.69618792874738,
           47.738742766975605,
           47.78129760520383,
           47.82540445499731,
           47.871063316356036,
           47.91672217771476,
           47.96238103907349,
           48.008039900432216,
           48.05369876179093,
           48.09935762314966,
           48.14501648450839,
           48.190675345867106,
           48.23633420722583,
           48.281993068584555,
           48.327651929943286,
           48.37331079130202,
           48.41896965266074,
           48.464628514019466,
           48.51028737537819,
           48.555946236736915,
           48.60160509809564,
           48.647263959454364,
           48.692922820813095,
           48.73858168217182,
           48.784240543530544,
           48.82989940488927,
           48.87555826624799,
           48.921217127606724,
           48.96687598896544,
           49.012534850324165,
           49.0581937116829,
           49.10385257304162,
           49.14951143440034,
           49.19517029575907,
           49.2408291571178,
           49.28648801847652,
           49.33214687983525,
           49.37780574119398,
           49.4234646025527,
           49.469123463911416,
           49.51478232527015,
           49.56044118662888,
           49.606100047987596,
           49.65175890934633,
           49.697417770705044,
           49.743076632063776,
           49.7887354934225,
           49.834394354781224,
           49.88005321613994,
           49.92689417650461,
           49.97451482127966,
           50.0221354660547,
           50.06975611082974,
           50.117376755604795,
           50.16499740037984,
           50.212618045154876,
           50.26023868992992,
           50.30785933470497,
           50.35547997948001,
           50.40310062425506,
           50.450721269030105,
           50.49834191380515,
           50.54596255858019,
           50.59358320335523,
           50.641203848130274,
           50.68882449290532,
           50.73644513768037,
           50.78406578245542,
           50.831686427230466,
           50.8793070720055,
           50.926927716780554,
           50.97454836155559,
           51.02216900633064,
           51.06978965110568,
           51.117410295880724,
           51.16503094065577,
           51.21265158543083,
           51.26027223020587,
           51.30789287498091,
           51.35551351975595,
           51.403134164531,
           51.45075480930604,
           51.498375454081085,
           51.54599609885613,
           51.59361674363117,
           51.64123738840622,
           51.54951660261317,
           51.179112955684104,
           50.80870930875504,
           50.438305661825936,
           50.06790201489687,
           49.6974983679678,
           49.3270947210387,
           48.9566910741096,
           48.586287427180565,
           48.21588378025147,
           47.84548013332237,
           47.4750764863933,
           47.10467283946423,
           46.73426919253513,
           46.36386554560606,
           45.993461898677,
           45.62305825174789,
           45.25265460481883,
           44.88225095788975,
           44.51184731096066,
           44.141443664031556,
           43.77104001710249,
           43.400636370173416,
           43.03023272324432,
           42.659829076315255,
           42.27617163546949,
           41.88677270718463,
           41.49737377889983,
           41.10797485061501,
           40.71857592233015,
           40.3291769940453,
           39.93977806576053,
           39.55037913747568,
           39.160980209190825,
           38.77158128090601,
           38.3821823526212,
           37.992783424336345,
           37.60338449605153,
           37.21398556776672,
           36.824586639481865,
           36.43518771119705,
           36.04578878291224,
           35.65638985462739,
           35.26699092634254,
           34.87759199805772,
           34.488193069772905,
           34.09879414148806,
           33.709395213203244,
           33.319996284918425,
           32.93059735663358,
           32.541198428348764,
           32.15179950006395,
           31.762400571779096,
           31.37300164349425,
           30.98360271520947,
           30.594203786924624,
           30.204804858639765,
           29.815405930354956,
           29.426007002070143,
           29.03660807378529,
           28.647209145500476,
           28.257810217215663,
           27.868411288930808,
           27.479012360645996,
           27.08961343236118,
           26.70021450407633,
           26.310815575791477,
           25.921416647506703,
           25.532017719221848,
           25.142618790937,
           24.753219862652188,
           24.36382093436737,
           23.97442200608252,
           23.585023077797707,
           23.19562414951289,
           22.80622522122804,
           22.416826292943192,
           22.02742736465841,
           21.63802843637356,
           21.24862950808871,
           20.859230579803896,
           20.46983165151908,
           20.08043272323423,
           19.718692772228774,
           19.49524770761987,
           19.271802643010968,
           19.048357578402065,
           18.8249125137932,
           18.601467449184295,
           18.37802238457539,
           18.15457731996653,
           17.931132255357625,
           17.70768719074872,
           17.484242126139858,
           17.26079706153095,
           17.037351996922048,
           16.813906932313145,
           16.59046186770428,
           16.367016803095375,
           16.14357173848647,
           15.920126673877611,
           15.696681609268705,
           15.4732365446598,
           15.249791480050938,
           15.026346415442031,
           14.802901350833128,
           14.579456286224264,
           14.356011221615361,
           14.132566157006458,
           13.909121092397552,
           13.685676027788688,
           13.462230963179785,
           13.238785898570882,
           13.00897212820631,
           12.778459592035013,
           12.54794705586372,
           12.317434519692469,
           12.086921983521176,
           11.856409447349883,
           11.62589691117859,
           11.395384375007337,
           11.164871838836042,
           10.934359302664749,
           10.703846766493498,
           10.473334230322205,
           10.306653808331722,
           10.18556775361325,
           10.064481698894756,
           9.94339564417626,
           9.822309589457788,
           9.701223534739292,
           9.580137480020799,
           9.459051425302306,
           9.337965370583833,
           9.216879315865338,
           9.095793261146843,
           8.974707206428372,
           8.85524994904939,
           8.740297861112152,
           8.625345773174937,
           8.510393685237698,
           8.39544159730046,
           8.280489509363221,
           8.165537421426004,
           8.050585333488765,
           7.935633245551526,
           7.82068115761431,
           7.705729069677071,
           7.5907769817398325,
           7.475824893802615,
           7.360872805865378,
           7.245920717928138,
           7.130968629990922,
           7.016016542053684,
           6.901064454116445,
           6.786112366179206,
           6.671160278241989,
           6.55620819030475,
           6.441256102367512,
           6.3263040144302956,
           6.211351926493057,
           6.0963998385558185,
           5.981447750618601,
           5.866495662681363,
           5.751543574744124,
           5.636591486806886,
           5.521639398869668
          ],
          [
           37.90350039144549,
           37.94696517826269,
           37.990429965079876,
           38.03389475189707,
           38.077359538714276,
           38.12082432553147,
           38.164289112348655,
           38.20775389916586,
           38.251218685983055,
           38.29468347280025,
           38.33814825961745,
           38.38161304643464,
           38.425077833251834,
           38.46854262006903,
           38.51200740688623,
           38.55547219370342,
           38.59893698052062,
           38.642401767337816,
           38.68586655415501,
           38.72933134097221,
           38.7727961277894,
           38.816260914606595,
           38.859725701423784,
           38.903190488240995,
           38.94665527505818,
           38.98983350287044,
           39.03157894801708,
           39.07332439316372,
           39.11506983831036,
           39.156815283457,
           39.198560728603645,
           39.240306173750284,
           39.28205161889693,
           39.32379706404356,
           39.365542509190206,
           39.40728795433685,
           39.44903339948348,
           39.49077884463013,
           39.53252428977677,
           39.574269734923405,
           39.61601518007005,
           39.65776062521669,
           39.69950607036333,
           39.74125151550997,
           39.782996960656604,
           39.82474240580325,
           39.866487850949895,
           39.90823329609653,
           39.94997874124317,
           39.99172418638981,
           40.03346963153645,
           40.075215076683094,
           40.11696052182974,
           40.15870596697638,
           40.200451412123016,
           40.242196857269654,
           40.28394230241629,
           40.32568774756294,
           40.367433192709576,
           40.409178637856215,
           40.45092408300286,
           40.4926695281495,
           40.53441497329614,
           40.57616041844278,
           40.61790586358942,
           40.65965130873606,
           40.7013967538827,
           40.74314219902934,
           40.78488764417598,
           40.82663308932262,
           40.868378534469265,
           40.9101239796159,
           40.95186942476254,
           40.99361486990919,
           41.035360315055826,
           41.077105760202464,
           41.1188512053491,
           41.16059665049575,
           41.20234209564239,
           41.244087540789025,
           41.28583298593567,
           41.32757843108231,
           41.369323876228954,
           41.411069321375585,
           41.45168978290018,
           41.49208524770037,
           41.53248071250056,
           41.57287617730074,
           41.61327164210093,
           41.65366710690112,
           41.6940625717013,
           41.734458036501486,
           41.77485350130168,
           41.81524896610186,
           41.85564443090205,
           41.89603989570223,
           41.93643536050243,
           41.976830825302606,
           42.017226290102805,
           42.05762175490299,
           42.098017219703166,
           42.13841268450335,
           42.17880814930354,
           42.219203614103726,
           42.25959907890391,
           42.2999945437041,
           42.340390008504286,
           42.38078547330447,
           42.42118093647536,
           42.46021643245208,
           42.499251928428805,
           42.53828742440553,
           42.57732292038225,
           42.61635841635898,
           42.6553939123357,
           42.69442940831242,
           42.73346490428915,
           42.77250040026587,
           42.81153589624259,
           42.85057139221932,
           42.88960688819604,
           42.92864238417276,
           42.967677880149495,
           43.006713376126214,
           43.04574887210293,
           43.08478436807965,
           43.12381986405639,
           43.162855360033106,
           43.20189085600983,
           43.24092635198655,
           43.27996184796327,
           43.31899734394,
           43.35803283991672,
           43.39706833589345,
           43.43610383187017,
           43.47513932784689,
           43.514174823823616,
           43.55321031980034,
           43.59224581577706,
           43.63128131175378,
           43.670316807730515,
           43.709352303707234,
           43.74838779968396,
           43.78742329566068,
           43.82645879163741,
           43.865494287614126,
           43.90452978359085,
           43.94356527956758,
           43.9826007755443,
           44.021636271521025,
           44.060671767497745,
           44.09970726347447,
           44.13874275945119,
           44.17777825542791,
           44.21681375140464,
           44.25584924738136,
           44.29488474335809,
           44.33392023933481,
           44.37295573531153,
           44.411991231288255,
           44.45102672726498,
           44.49006222324171,
           44.52909771921843,
           44.56813321519515,
           44.60716871117187,
           44.6462042071486,
           44.685239703125326,
           44.72727839913649,
           44.77081869516488,
           44.81435899119327,
           44.857899287221656,
           44.901439583250045,
           44.944979879278435,
           44.988520175306824,
           45.03206047133521,
           45.0756007673636,
           45.119141063391986,
           45.16268135942038,
           45.20622165544877,
           45.249761951477154,
           45.29330224750555,
           45.33684254353393,
           45.380382839562316,
           45.42392313559071,
           45.467463431619095,
           45.511003727647484,
           45.554544023675874,
           45.59808431970426,
           45.64162461573265,
           45.68516491176104,
           45.72870520778943,
           45.77224550381782,
           45.8157857998462,
           45.85932609587459,
           45.90286639190299,
           45.94640668793137,
           45.98994698395977,
           46.03348727998815,
           46.07702757601655,
           46.120539715465874,
           46.1630945536941,
           46.20564939192232,
           46.24820423015055,
           46.290759068378776,
           46.333313906607,
           46.37586874483523,
           46.41842358306346,
           46.460978421291685,
           46.50353325951992,
           46.54608809774814,
           46.588642935976374,
           46.63119777420459,
           46.673752612432814,
           46.71630745066105,
           46.758862288889276,
           46.8014171271175,
           46.84397196534573,
           46.88652680357395,
           46.92908164180218,
           46.97163648003041,
           47.014191318258625,
           47.05674615648685,
           47.09930099471508,
           47.14185583294331,
           47.18441067117154,
           47.22696550939976,
           47.269520347627996,
           47.312075185856216,
           47.354630024084436,
           47.39718486231267,
           47.4397397005409,
           47.482294538769125,
           47.524849376997345,
           47.56740421522558,
           47.6099590534538,
           47.65251389168203,
           47.695068729910254,
           47.73762356813848,
           47.78017840636671,
           47.822733244594936,
           47.86528808282317,
           47.90784292105139,
           47.95039775927962,
           47.99295259750784,
           48.035507435736065,
           48.07806227396429,
           48.12061711219252,
           48.16317195042075,
           48.205726788648974,
           48.2482816268772,
           48.29238847667067,
           48.3380473380294,
           48.38370619938813,
           48.429365060746846,
           48.47502392210558,
           48.52068278346431,
           48.56634164482303,
           48.61200050618176,
           48.657659367540475,
           48.70331822889921,
           48.748977090257924,
           48.79463595161666,
           48.84029481297539,
           48.885953674334104,
           48.931612535692835,
           48.97727139705155,
           49.022930258410284,
           49.06858911976901,
           49.11424798112773,
           49.15990684248645,
           49.20556570384518,
           49.25122456520391,
           49.29688342656263,
           49.34254228792136,
           49.388201149280086,
           49.43386001063881,
           49.479518871997534,
           49.52517773335626,
           49.57083659471499,
           49.61649545607371,
           49.662154317432446,
           49.70781317879117,
           49.75347204014989,
           49.79913090150862,
           49.84478976286734,
           49.89044862422607,
           49.936107485584785,
           49.981766346943516,
           50.02742520830224,
           50.073084069660965,
           50.11874293101969,
           50.16440179237841,
           50.21006065373713,
           50.25571951509587,
           50.30137837645459,
           50.34703723781331,
           50.39269609917204,
           50.43835496053077,
           50.48401382188949,
           50.529672683248215,
           50.57533154460694,
           50.620990405965664,
           50.66664926732439,
           50.71230812868313,
           50.75796699004185,
           50.80362585140057,
           50.84928471275929,
           50.894943574118024,
           50.94060243547674,
           50.986261296835465,
           51.03192015819419,
           51.07757901955293,
           51.12323788091165,
           51.16889674227038,
           51.2145556036291,
           51.26021446498782,
           51.30587332634654,
           51.351532187705274,
           51.39719104906399,
           51.44284991042272,
           51.488508771781454,
           51.53416763314018,
           51.5798264944989,
           51.62548535585763,
           51.67114421721635,
           51.71680307857507,
           51.757184004571414,
           51.79712512171118,
           51.83706623885096,
           51.87700735599073,
           51.9169484731305,
           51.95688959027027,
           51.99683070741004,
           51.893109441968654,
           51.50206341136509,
           51.111017380761524,
           50.71997135015793,
           50.328925319554365,
           49.937879288950796,
           49.5468332583472,
           49.15578722774361,
           48.764741197140076,
           48.37369516653648,
           47.982649135932874,
           47.59160310532931,
           47.200557074725744,
           46.809511044122154,
           46.41846501351859,
           46.02741898291502,
           45.636372952311426,
           45.245326921707864,
           44.8542808911043,
           44.4632348605007,
           44.0721888298971,
           43.68114279929354,
           43.29009676868998,
           42.89905073808638,
           42.50800470748282,
           42.11695867687925,
           41.725912646275646,
           41.334866615672084,
           40.94382058506853,
           40.552774554464925,
           40.16172852386133,
           39.7706824932578,
           39.379636462654204,
           38.9885904320506,
           38.59754440144704,
           38.20649837084348,
           37.81545234023988,
           37.42440630963631,
           37.03336027903275,
           36.64231424842915,
           36.25126821782559,
           35.86022218722203,
           35.469176156618424,
           35.07813012601483,
           34.687084095411265,
           34.2960380648077,
           33.9049920342041,
           33.51394600360054,
           33.122899972996976,
           32.73185394239337,
           32.34080791178982,
           31.949761881186255,
           31.55871585058265,
           31.167669819979054,
           30.776623789375527,
           30.385577758771927,
           29.994531728168326,
           29.603485697564768,
           29.212439666961203,
           28.821393636357605,
           28.43034760575404,
           28.039301575150475,
           27.648255544546878,
           27.257209513943316,
           26.86616348333975,
           26.475117452736153,
           26.084071422132553,
           25.693025391529027,
           25.301979360925426,
           24.910933330321825,
           24.519887299718263,
           24.1288412691147,
           23.7377952385111,
           23.346749207907543,
           22.956252239266824,
           22.566853310981973,
           22.177454382697128,
           21.788055454412344,
           21.398656526127493,
           21.009257597842645,
           20.61985866955783,
           20.230459741273016,
           19.841060812988164,
           19.47932086198271,
           19.255875797373804,
           19.0324307327649,
           18.808985668155998,
           18.585540603547134,
           18.362537126199513,
           18.13984907929828,
           17.917161032397086,
           17.694472985495853,
           17.47178493859462,
           17.249096891693426,
           17.026408844792194,
           16.80372079789096,
           16.581032750989728,
           16.358344704088537,
           16.1356566571873,
           15.912968610286068,
           15.690280563384878,
           15.467592516483645,
           15.244904469582412,
           15.022216422681218,
           14.799528375779985,
           14.57684032887875,
           14.354152281977559,
           14.131464235076326,
           13.908776188175093,
           13.68608814127386,
           13.46340009437267,
           13.240712047471437,
           13.018024000570202,
           12.79533595366901,
           12.572647906767777,
           12.349959859866544,
           12.12727181296535,
           11.904583766064118,
           11.681895719162885,
           11.459207672261652,
           11.23651962536046,
           11.013831578459227,
           10.791143531557994,
           10.568455484656802,
           10.345767437755567,
           10.186266909996228,
           10.071900324481101,
           9.957533738965955,
           9.843167153450805,
           9.728800567935679,
           9.61443398242053,
           9.500067396905385,
           9.385700811390237,
           9.27133422587511,
           9.156967640359962,
           9.042601054844814,
           8.928234469329688,
           8.81386788381454,
           8.699501298299392,
           8.585134712784267,
           8.47076812726912,
           8.356401541753971,
           8.242034956238824,
           8.127668370723697,
           8.013301785208549,
           7.898935199693401,
           7.784568614178275,
           7.670202028663127,
           7.555835443147979,
           7.441468857632852,
           7.327102272117704,
           7.212735686602557,
           7.098369101087431,
           6.984002515572282,
           6.869635930057134,
           6.755269344541988,
           6.640902759026861,
           6.526536173511713,
           6.412169587996565,
           6.297803002481439,
           6.183436416966291,
           6.069069831451143,
           5.954361697905313,
           5.839409609968074,
           5.724457522030836,
           5.609505434093597,
           5.494553346156381
          ],
          [
           38.29830543234633,
           38.34177021916353,
           38.38523500598072,
           38.428699792797914,
           38.47216457961511,
           38.51562936643231,
           38.559094153249504,
           38.6025589400667,
           38.6460237268839,
           38.68948851370109,
           38.73295330051829,
           38.776418087335486,
           38.81988287415268,
           38.86334766096988,
           38.906812447787075,
           38.95027723460427,
           38.99374202142146,
           39.03720680823866,
           39.080671595055854,
           39.12413638187305,
           39.16760116869024,
           39.211065955507436,
           39.25453074232463,
           39.297995529141836,
           39.341460315959026,
           39.38492510277622,
           39.42838988959342,
           39.47185467641061,
           39.51531946322781,
           39.558784250045,
           39.6022490368622,
           39.6457138236794,
           39.68917861049658,
           39.732643397313794,
           39.776108184130976,
           39.81957297094817,
           39.863037757765376,
           39.906502544582565,
           39.94996733139977,
           39.99343211821696,
           40.036896905034155,
           40.08036169185135,
           40.12268024911202,
           40.16442569425867,
           40.2061711394053,
           40.247916584551945,
           40.28966202969858,
           40.33140747484522,
           40.37315291999187,
           40.414898365138505,
           40.456643810285144,
           40.49838925543179,
           40.54013470057843,
           40.581880145725066,
           40.623625590871704,
           40.66537103601835,
           40.70711648116499,
           40.74886192631163,
           40.79060737145827,
           40.83235281660491,
           40.87409826175155,
           40.91584370689819,
           40.95758915204483,
           40.99933459719147,
           41.041080042338116,
           41.082825487484754,
           41.12457093263139,
           41.16631637777803,
           41.20806182292468,
           41.249807268071315,
           41.29155271321796,
           41.33329815836459,
           41.37504360351124,
           41.416789048657876,
           41.45853449380452,
           41.50027993895116,
           41.54202538409779,
           41.58377082924444,
           41.62551627439108,
           41.66726171953772,
           41.70900716468436,
           41.750752609831,
           41.79249805497764,
           41.83424350012428,
           41.87486396164887,
           41.91525942644906,
           41.955654891249246,
           41.99605035604944,
           42.03644582084962,
           42.076841285649806,
           42.11723675044999,
           42.157632215250175,
           42.198027680050366,
           42.23842314485055,
           42.27881860965074,
           42.319214074450926,
           42.359609539251124,
           42.400005004051295,
           42.44040046885149,
           42.48079593365168,
           42.52119139845186,
           42.561586863252046,
           42.60198232805223,
           42.642377792852415,
           42.6827732576526,
           42.72316872245279,
           42.76356418725298,
           42.803959652053166,
           42.84435511685335,
           42.884750581653535,
           42.92514604645372,
           42.96554151125391,
           43.00593697605409,
           43.046332440854286,
           43.08672790565447,
           43.127123370454655,
           43.16751883525484,
           43.20791430005502,
           43.24830976485522,
           43.28870522965539,
           43.32910069445559,
           43.369496159255775,
           43.40989162405596,
           43.45028708885615,
           43.49068255365633,
           43.53039803263988,
           43.56943352861661,
           43.60846902459333,
           43.64750452057005,
           43.68654001654678,
           43.7255755125235,
           43.764611008500225,
           43.803646504476944,
           43.84268200045367,
           43.8817174964304,
           43.92075299240712,
           43.959788488383836,
           43.99882398436056,
           44.03785948033729,
           44.07689497631401,
           44.115930472290735,
           44.15496596826746,
           44.19400146424418,
           44.2330369602209,
           44.27207245619763,
           44.31110795217435,
           44.35014344815108,
           44.3891789441278,
           44.42821444010452,
           44.46724993608125,
           44.50628543205797,
           44.54532092803469,
           44.58435642401142,
           44.62339191998814,
           44.66242741596487,
           44.70146291194159,
           44.74049840791831,
           44.779533903895036,
           44.818569399871755,
           44.85760489584848,
           44.89664039182521,
           44.93567588780193,
           44.974711383778654,
           45.013746879755374,
           45.0527823757321,
           45.09181787170882,
           45.13085336768555,
           45.172892063696715,
           45.216432359725104,
           45.259972655753494,
           45.30351295178188,
           45.347053247810265,
           45.39059354383866,
           45.434133839867044,
           45.47767413589544,
           45.52121443192382,
           45.56475472795221,
           45.6082950239806,
           45.651835320008985,
           45.69537561603738,
           45.73891591206577,
           45.78245620809416,
           45.82599650412254,
           45.86953680015093,
           45.91307709617932,
           45.95661739220771,
           46.0001576882361,
           46.04369798426448,
           46.08723828029288,
           46.13077857632127,
           46.17431887234966,
           46.21785916837804,
           46.26139946440642,
           46.30493976043482,
           46.34848005646321,
           46.3920203524916,
           46.43556064851999,
           46.47910094454838,
           46.52264124057677,
           46.56618153660516,
           46.60972183263354,
           46.653262128661936,
           46.69680242469032,
           46.74034272071871,
           46.7838830167471,
           46.82742331277548,
           46.870963608803876,
           46.91450390483226,
           46.95804420086065,
           47.00158449688904,
           47.045124792917434,
           47.08866508894582,
           47.132205384974206,
           47.17574568100259,
           47.21928597703098,
           47.262826273059375,
           47.30636656908776,
           47.349906865116154,
           47.393447161144536,
           47.436987457172926,
           47.480527753201315,
           47.523730178160214,
           47.566285016388434,
           47.60883985461666,
           47.65139469284489,
           47.693949531073116,
           47.736504369301336,
           47.77905920752957,
           47.82161404575779,
           47.864168883986025,
           47.906723722214245,
           47.94927856044247,
           47.99183339867069,
           48.03438823689893,
           48.07694307512715,
           48.119497913355374,
           48.1620527515836,
           48.20460758981183,
           48.247162428040056,
           48.28971726626828,
           48.332272104496504,
           48.37482694272474,
           48.41738178095296,
           48.459936619181185,
           48.50249145740942,
           48.54504629563765,
           48.587601133865874,
           48.6301559720941,
           48.67271081032232,
           48.715265648550556,
           48.75937249834402,
           48.80503135970275,
           48.85069022106147,
           48.8963490824202,
           48.942007943778925,
           48.98766680513765,
           49.033325666496374,
           49.0789845278551,
           49.12464338921383,
           49.17030225057255,
           49.21596111193128,
           49.26161997329,
           49.30727883464873,
           49.35293769600745,
           49.39859655736618,
           49.44425541872491,
           49.489914280083624,
           49.535573141442356,
           49.58123200280108,
           49.626890864159805,
           49.672549725518536,
           49.71820858687726,
           49.76386744823598,
           49.80952630959471,
           49.85518517095343,
           49.900844032312165,
           49.946502893670875,
           49.99216175502961,
           50.03782061638833,
           50.08347947774706,
           50.129138339105786,
           50.17479720046451,
           50.220456061823235,
           50.26611492318196,
           50.31177378454069,
           50.357432645899415,
           50.40309150725814,
           50.44875036861687,
           50.49440922997559,
           50.54006809133431,
           50.58572695269304,
           50.63138581405176,
           50.677044675410485,
           50.72065099843485,
           50.760592115574624,
           50.8005332327144,
           50.84047434985417,
           50.880415466993945,
           50.920356584133714,
           50.96029770127349,
           51.00023881841326,
           51.04017993555303,
           51.0801210526928,
           51.12006216983258,
           51.16000328697235,
           51.19994440411212,
           51.23988552125189,
           51.27982663839167,
           51.31976775553144,
           51.359708872671206,
           51.39964998981098,
           51.43959110695076,
           51.47953222409052,
           51.519473341230295,
           51.55941445837007,
           51.59935557550985,
           51.639296692649616,
           51.67923780978939,
           51.71917892692916,
           51.75912004406893,
           51.799061161208705,
           51.839002278348474,
           51.87894339548825,
           51.918884512628026,
           51.9588256297678,
           51.99876674690756,
           52.03870786404734,
           52.078648981187115,
           52.118590098326884,
           52.15853121546666,
           52.19847233260643,
           52.238413449746204,
           52.27835456688597,
           52.17463330144458,
           51.78358727084102,
           51.392541240237456,
           51.00149520963385,
           50.6104491790303,
           50.21940314842673,
           49.82835711782313,
           49.437311087219534,
           49.04626505661601,
           48.655219026012404,
           48.264172995408806,
           47.87312696480525,
           47.482080934201676,
           47.091034903598086,
           46.69998887299452,
           46.30894284239096,
           45.91789681178735,
           45.526850781183796,
           45.135804750580235,
           44.74475871997663,
           44.35371268937303,
           43.96266665876947,
           43.5716206281659,
           43.180574597562305,
           42.789528566958744,
           42.398482536355175,
           42.00743650575158,
           41.616390475148016,
           41.225344444544454,
           40.83429841394085,
           40.44325238333725,
           40.05220635273373,
           39.66116032213013,
           39.27011429152653,
           38.87906826092297,
           38.4880222303194,
           38.096976199715805,
           37.70593016911224,
           37.31488413850868,
           36.923838107905084,
           36.532792077301515,
           36.14174604669795,
           35.750700016094356,
           35.35965398549075,
           34.9686079548872,
           34.577561924283636,
           34.18651589368003,
           33.79546986307647,
           33.4044238324729,
           33.013377801869304,
           32.62233177126575,
           32.23128574066218,
           31.840239710058583,
           31.44919367945498,
           31.04319075017134,
           30.63523294937605,
           30.227275148580752,
           29.819317347785493,
           29.41135954699024,
           29.003401746194942,
           28.595443945399687,
           28.187486144604428,
           27.77952834380913,
           27.371570543013874,
           26.963612742218615,
           26.555654941423324,
           26.147697140628026,
           25.73973933983281,
           25.33178153903751,
           24.923823738242216,
           24.51586593744696,
           24.1079081366517,
           23.699950335856407,
           23.291992535061148,
           22.884034734265892,
           22.476076933470598,
           22.068119132675303,
           21.660161331880083,
           21.25220353108479,
           20.844245730289494,
           20.436287929494235,
           20.028330128698975,
           19.62037232790368,
           19.244458248813928,
           19.02876277825142,
           18.813067307688915,
           18.59737183712641,
           18.38167636656394,
           18.165980896001436,
           17.950285425438928,
           17.734589954876462,
           17.518894484313954,
           17.30319901375145,
           17.08750354318898,
           16.871808072626475,
           16.656112602063967,
           16.440417131501462,
           16.224721660938993,
           16.00902619037649,
           15.793300047258327,
           15.570612000357135,
           15.347923953455902,
           15.125235906554671,
           14.902547859653478,
           14.679859812752245,
           14.457171765851012,
           14.23448371894982,
           14.011795672048585,
           13.789107625147352,
           13.56641957824612,
           13.343731531344927,
           13.121043484443696,
           12.898355437542463,
           12.67566739064127,
           12.452979343740036,
           12.230291296838804,
           12.00760324993761,
           11.784915203036379,
           11.562227156135144,
           11.339539109233911,
           11.116851062332719,
           10.894163015431484,
           10.671474968530251,
           10.448786921629061,
           10.226098874727828,
           10.066598346968487,
           9.95223176145336,
           9.837865175938212,
           9.723498590423066,
           9.609132004907938,
           9.494765419392792,
           9.380398833877642,
           9.266032248362496,
           9.15166566284737,
           9.037299077332221,
           8.922932491817075,
           8.808565906301947,
           8.6941993207868,
           8.579832735271651,
           8.465466149756525,
           8.351099564241379,
           8.23673297872623,
           8.122366393211083,
           8.007999807695956,
           7.893633222180808,
           7.7792666366656595,
           7.664900051150534,
           7.550533465635385,
           7.436166880120239,
           7.321800294605112,
           7.208353166102001,
           7.099652440578556,
           6.990951715055131,
           6.882250989531685,
           6.7735502640082395,
           6.664849538484795,
           6.55614881296137,
           6.447448087437925,
           6.338747361914479,
           6.230046636391053,
           6.121345910867609,
           6.012645185344163,
           5.903944459820738,
           5.795243734297293,
           5.686543008773848,
           5.577842283250403,
           5.469141557726977
          ],
          [
           38.693110473247174,
           38.73657526006437,
           38.78004004688157,
           38.82350483369876,
           38.86696962051596,
           38.910434407333156,
           38.953899194150345,
           38.99736398096754,
           39.040828767784745,
           39.084293554601935,
           39.12775834141913,
           39.17122312823633,
           39.214687915053524,
           39.25815270187072,
           39.30161748868792,
           39.34508227550511,
           39.3885470623223,
           39.432011849139506,
           39.475476635956696,
           39.51894142277389,
           39.56240620959109,
           39.605870996408285,
           39.649335783225474,
           39.69280057004268,
           39.73626535685987,
           39.779730143677064,
           39.82319493049426,
           39.86665971731145,
           39.91012450412865,
           39.95358929094585,
           39.997054077763046,
           40.040518864580235,
           40.083983651397425,
           40.12744843821463,
           40.170913225031825,
           40.21437801184902,
           40.25784279866622,
           40.30130758548341,
           40.34477237230061,
           40.3882371591178,
           40.431701945934996,
           40.47516673275219,
           40.51863151956939,
           40.562096306386586,
           40.605561093203775,
           40.64902588002097,
           40.69249066683817,
           40.73595545365537,
           40.77942024047256,
           40.82288502728976,
           40.866349814106954,
           40.90981460092415,
           40.95327938774134,
           40.996744174558536,
           41.04020896137573,
           41.08367374819293,
           41.127138535010126,
           41.17060332182732,
           41.21378155020696,
           41.2555269953536,
           41.29727244050024,
           41.33901788564688,
           41.38076333079352,
           41.42250877594016,
           41.4642542210868,
           41.505999666233436,
           41.54774511138008,
           41.58949055652672,
           41.631236001673365,
           41.67298144682,
           41.71472689196665,
           41.75647233711328,
           41.798217782259925,
           41.839963227406564,
           41.88170867255321,
           41.92345411769985,
           41.965199562846486,
           42.006945007993124,
           42.04869045313977,
           42.09043589828641,
           42.132181343433054,
           42.173926788579685,
           42.21567223372633,
           42.25741767887297,
           42.298038140397566,
           42.33843360519776,
           42.37882906999794,
           42.419224534798126,
           42.45961999959831,
           42.500015464398494,
           42.540410929198686,
           42.58080639399887,
           42.62120185879906,
           42.66159732359924,
           42.70199278839944,
           42.742388253199614,
           42.782783717999806,
           42.82317918279999,
           42.86357464760018,
           42.903970112400366,
           42.94436557720055,
           42.984761042000734,
           43.025156506800926,
           43.06555197160111,
           43.105947436401294,
           43.146342901201486,
           43.18673836600167,
           43.227133830801854,
           43.26752929560204,
           43.30792476040223,
           43.348320225202414,
           43.3887156900026,
           43.42911115480278,
           43.469506619602974,
           43.50990208440316,
           43.55029754920335,
           43.590693014003534,
           43.63108847880372,
           43.67148394360391,
           43.71187940840409,
           43.752274873204286,
           43.79267033800446,
           43.833065802804654,
           43.87346126760484,
           43.91385673240502,
           43.95425219720521,
           43.9946476620054,
           44.03504312680558,
           44.075438591605774,
           44.11583405640596,
           44.15622952120614,
           44.19662498600633,
           44.23702045080652,
           44.2774159156067,
           44.31781138040689,
           44.35820684520707,
           44.39860231000726,
           44.43899777480745,
           44.47939323960764,
           44.51978870440782,
           44.56018416920801,
           44.60057963282769,
           44.63961512880441,
           44.67865062478113,
           44.717686120757854,
           44.75672161673458,
           44.79575711271131,
           44.834792608688026,
           44.873828104664746,
           44.91286360064148,
           44.9518990966182,
           44.99093459259492,
           45.029970088571645,
           45.069005584548364,
           45.1080410805251,
           45.14707657650182,
           45.18611207247854,
           45.22514756845526,
           45.26418306443198,
           45.30321856040871,
           45.342254056385435,
           45.381289552362155,
           45.42032504833888,
           45.4593605443156,
           45.49839604029233,
           45.53743153626905,
           45.57646703224577,
           45.618505728256935,
           45.66204602428533,
           45.705586320313714,
           45.7491266163421,
           45.79266691237049,
           45.83620720839889,
           45.87974750442727,
           45.92328780045566,
           45.96682809648405,
           46.01036839251243,
           46.05390868854083,
           46.09744898456922,
           46.1409892805976,
           46.18452957662599,
           46.22806987265437,
           46.27161016868277,
           46.31515046471116,
           46.35869076073955,
           46.40223105676793,
           46.44577135279632,
           46.48931164882471,
           46.5328519448531,
           46.57639224088149,
           46.61993253690988,
           46.66347283293826,
           46.70701312896665,
           46.75055342499505,
           46.79409372102343,
           46.837634017051826,
           46.881174313080216,
           46.924714609108605,
           46.96825490513699,
           47.011795201165384,
           47.05533549719375,
           47.09887579322215,
           47.14241608925054,
           47.185956385278935,
           47.22949668130732,
           47.27303697733571,
           47.316577273364096,
           47.36011756939248,
           47.40365786542087,
           47.447198161449265,
           47.490738457477654,
           47.534278753506044,
           47.577819049534426,
           47.621359345562816,
           47.664899641591205,
           47.708439937619595,
           47.751980233647984,
           47.795520529676374,
           47.83906082570476,
           47.88260112173315,
           47.926141417761535,
           47.969681713789925,
           48.013222009818314,
           48.056762305846696,
           48.100302601875086,
           48.14384289790348,
           48.18738319393187,
           48.230923489960254,
           48.274463785988644,
           48.31800408201704,
           48.36154437804543,
           48.40508467407381,
           48.4486249701022,
           48.492165266130584,
           48.53570556215898,
           48.57924585818737,
           48.62278615421575,
           48.66632645024414,
           48.70986674627254,
           48.75340704230093,
           48.79694733832931,
           48.8404876343577,
           48.88402793038609,
           48.92692064085453,
           48.96947547908276,
           49.01203031731099,
           49.054585155539215,
           49.09713999376744,
           49.13969483199567,
           49.1822496702239,
           49.22635652001737,
           49.27201538137609,
           49.317674242734824,
           49.363333104093556,
           49.40899196545228,
           49.454650826811,
           49.50030968816973,
           49.54596854952845,
           49.59162741088718,
           49.637286272245895,
           49.682945133604626,
           49.724059109438066,
           49.76400022657784,
           49.803941343717604,
           49.84388246085739,
           49.883823577997155,
           49.923764695136924,
           49.96370581227671,
           50.003646929416476,
           50.04358804655625,
           50.083529163696014,
           50.12347028083579,
           50.16341139797556,
           50.20335251511533,
           50.2432936322551,
           50.28323474939488,
           50.323175866534655,
           50.36311698367442,
           50.4030581008142,
           50.44299921795397,
           50.482940335093744,
           50.52288145223351,
           50.56282256937328,
           50.60276368651306,
           50.64270480365283,
           50.6826459207926,
           50.72258703793238,
           50.76252815507215,
           50.80246927221192,
           50.84241038935169,
           50.88235150649146,
           50.922292623631236,
           50.962233740771005,
           51.00217485791078,
           51.04211597505055,
           51.082057092190325,
           51.1219982093301,
           51.16193932646988,
           51.20188044360964,
           51.241821560749415,
           51.28176267788919,
           51.32170379502895,
           51.36164491216873,
           51.401586029308504,
           51.44152714644828,
           51.48146826358804,
           51.52140938072782,
           51.5613504978676,
           51.60129161500736,
           51.64123273214713,
           51.68117384928691,
           51.72111496642668,
           51.76105608356645,
           51.800997200706234,
           51.840938317845996,
           51.88087943498577,
           51.92082055212554,
           51.96076166926532,
           52.000702786405085,
           52.040643903544854,
           52.08058502068463,
           52.120526137824406,
           52.160467254964175,
           52.20040837210395,
           52.24034948924373,
           52.28029060638349,
           52.320231723523264,
           52.36017284066304,
           52.400113957802816,
           52.440055074942585,
           52.47999619208235,
           52.51993730922213,
           52.559878426361905,
           52.456157160920505,
           52.06511113031695,
           51.67406509971338,
           51.28301906910978,
           50.891973038506215,
           50.50092700790265,
           50.109880977299056,
           49.71883494669545,
           49.32778891609193,
           48.93674288548833,
           48.54569685488473,
           48.15465082428117,
           47.76360479367761,
           47.37255876307401,
           46.98151273247044,
           46.59046670186687,
           46.19942067126328,
           45.80837464065972,
           45.41732861005616,
           45.02628257945255,
           44.63523654884896,
           44.2441905182454,
           43.85314448764183,
           43.45382441358366,
           43.0458666127884,
           42.63790881199315,
           42.229951011197855,
           41.821993210402596,
           41.41403540960734,
           41.00607760881204,
           40.59811980801675,
           40.19016200722153,
           39.782204206426236,
           39.374246405630934,
           38.966288604835675,
           38.55833080404042,
           38.15037300324513,
           37.74241520244988,
           37.33445740165461,
           36.926499600859316,
           36.518541800064064,
           36.110583999268805,
           35.70262619847351,
           35.294668397678215,
           34.886710596882956,
           34.4787527960877,
           34.0707949952924,
           33.66283719449714,
           33.25487939370189,
           32.8469215929066,
           32.43896379211134,
           32.03100599131608,
           31.623048190520784,
           31.21509038972549,
           30.807132588930266,
           30.399174788134975,
           29.99121698733968,
           29.58325918654442,
           29.175301385749165,
           28.76734358495387,
           28.35938578415861,
           27.95142798336336,
           27.543470182568058,
           27.135512381772802,
           26.727554580977543,
           26.31959678018225,
           25.911638979386957,
           25.503681178591734,
           25.09572337779644,
           24.687765577001144,
           24.279807776205885,
           23.87184997541063,
           23.463892174615335,
           23.05593437382008,
           22.64797657302482,
           22.240018772229526,
           21.83206097143423,
           21.424103170639007,
           21.016145369843713,
           20.608187569048418,
           20.200229768253163,
           19.792271967457907,
           19.384314166662612,
           19.008400087572856,
           18.792704617010347,
           18.57700914644784,
           18.361313675885334,
           18.14561820532287,
           17.92992273476036,
           17.714227264197852,
           17.498531793635387,
           17.28283632307288,
           17.067140852510374,
           16.851445381947908,
           16.635749911385403,
           16.420054440822895,
           16.20435897026039,
           15.988663499697921,
           15.772968029135416,
           15.55727255857291,
           15.341577088010443,
           15.125881617447934,
           14.910186146885428,
           14.694490676322962,
           14.478795205760456,
           14.26309973519795,
           14.047404264635482,
           13.831708794072977,
           13.616013323510469,
           13.400317852947962,
           13.184622382385497,
           12.968926911822988,
           12.753231441260484,
           12.537535970698016,
           12.32184050013551,
           12.106145029573002,
           11.88793468690987,
           11.665246640008638,
           11.442558593107403,
           11.21987054620617,
           10.997182499304978,
           10.774494452403747,
           10.551806405502512,
           10.32911835860132,
           10.106430311700088,
           9.946929783940746,
           9.832563198425621,
           9.718196612910472,
           9.603830027395325,
           9.489463441880199,
           9.375096856365051,
           9.260730270849903,
           9.146363685334757,
           9.031997099819629,
           8.922202964214366,
           8.813502238690917,
           8.704801513167494,
           8.596100787644048,
           8.487400062120603,
           8.378699336597178,
           8.269998611073733,
           8.161297885550287,
           8.052597160026842,
           7.943896434503417,
           7.835195708979972,
           7.726494983456527,
           7.6177942579331015,
           7.509093532409657,
           7.400392806886211,
           7.291692081362786,
           7.1829913558393415,
           7.074290630315895,
           6.96558990479247,
           6.856889179269024,
           6.748188453745579,
           6.639487728222134,
           6.530787002698709,
           6.422086277175264,
           6.313385551651818,
           6.204684826128394,
           6.095984100604948,
           5.987283375081503,
           5.878582649558077,
           5.7698819240346335,
           5.661181198511187,
           5.5524804729877415,
           5.443779747464317
          ],
          [
           39.087915514148015,
           39.13138030096521,
           39.1748450877824,
           39.218309874599605,
           39.2617746614168,
           39.305239448234,
           39.34870423505119,
           39.39216902186838,
           39.43563380868558,
           39.47909859550278,
           39.52256338231997,
           39.56602816913716,
           39.609492955954366,
           39.65295774277156,
           39.69642252958875,
           39.739887316405955,
           39.783352103223145,
           39.82681689004034,
           39.87028167685754,
           39.913746463674734,
           39.95721125049192,
           40.00067603730912,
           40.04414082412632,
           40.08760561094352,
           40.13107039776071,
           40.174535184577906,
           40.2179999713951,
           40.2614647582123,
           40.304929545029495,
           40.348394331846684,
           40.39185911866388,
           40.43532390548108,
           40.478788692298274,
           40.52225347911546,
           40.56571826593266,
           40.609183052749856,
           40.65264783956705,
           40.69611262638425,
           40.739577413201445,
           40.78304220001864,
           40.82650698683584,
           40.869971773653035,
           40.91343656047023,
           40.95690134728743,
           41.00036613410462,
           41.04383092092181,
           41.08729570773901,
           41.130760494556206,
           41.1742252813734,
           41.21769006819059,
           41.26115485500779,
           41.304619641824985,
           41.34808442864218,
           41.39154921545938,
           41.435014002276574,
           41.47847878909377,
           41.52194357591097,
           41.565408362728164,
           41.60887314954536,
           41.65233793636256,
           41.695802723179746,
           41.73926750999694,
           41.78273229681414,
           41.82619708363133,
           41.869661870448525,
           41.91312665726572,
           41.95659144408292,
           42.000056230900114,
           42.04352101771731,
           42.08698580453451,
           42.1304505913517,
           42.1739153781689,
           42.21738016498609,
           42.260844951803286,
           42.30430973862048,
           42.346628296448536,
           42.388373741595174,
           42.43011918674182,
           42.47186463188846,
           42.513610077035096,
           42.55535552218174,
           42.59710096732838,
           42.638846412475026,
           42.680591857621664,
           42.72121231914626,
           42.761607783946445,
           42.80200324874664,
           42.84239871354682,
           42.882794178347,
           42.92318964314719,
           42.96358510794738,
           43.003980572747565,
           43.04437603754775,
           43.08477150234794,
           43.12516696714812,
           43.1655624319483,
           43.205957896748494,
           43.24635336154868,
           43.28674882634887,
           43.327144291149054,
           43.367539755949245,
           43.40793522074943,
           43.44833068554962,
           43.488726150349805,
           43.52912161514999,
           43.569517079950174,
           43.60991254475036,
           43.65030800955055,
           43.690703474350734,
           43.731098939150925,
           43.77149440395111,
           43.811889868751294,
           43.85228533355148,
           43.89268079835167,
           43.933076263151854,
           43.973471727952045,
           44.01386719275223,
           44.054262657552414,
           44.0946581223526,
           44.13505358715278,
           44.17544905195297,
           44.21584451675315,
           44.25623998155335,
           44.296635446353534,
           44.33703091115372,
           44.3774263759539,
           44.41782184075409,
           44.45821730555428,
           44.49861277035446,
           44.539008235154654,
           44.57940369995484,
           44.61979916475502,
           44.66019462955521,
           44.7005900943554,
           44.74098555915558,
           44.78138102395577,
           44.82177648875596,
           44.86217195355614,
           44.90256741835633,
           44.94296288315651,
           44.9833583479567,
           45.02375381275689,
           45.06414927755707,
           45.104544742357255,
           45.14494020715745,
           45.18533567195763,
           45.225731136757815,
           45.26612660155801,
           45.30652206635819,
           45.34691753115838,
           45.38731299595857,
           45.42770846075875,
           45.46810392555894,
           45.50849939035912,
           45.54889485515931,
           45.589290319959495,
           45.62968578475969,
           45.67008124955987,
           45.7097967289922,
           45.74883222496892,
           45.787867720945655,
           45.826903216922375,
           45.8659387128991,
           45.90497420887582,
           45.94400970485254,
           45.98304520082927,
           46.02208069680599,
           46.06411939281716,
           46.107659688845544,
           46.15119998487394,
           46.19474028090233,
           46.23828057693072,
           46.2818208729591,
           46.32536116898749,
           46.36890146501588,
           46.41244176104427,
           46.45598205707266,
           46.49952235310105,
           46.54306264912944,
           46.58660294515783,
           46.63014324118622,
           46.6736835372146,
           46.717223833243,
           46.76076412927139,
           46.80430442529977,
           46.84784472132815,
           46.89138501735655,
           46.93492531338494,
           46.97846560941333,
           47.022005905441716,
           47.065546201470106,
           47.10908649749849,
           47.15262679352688,
           47.196167089555274,
           47.239707385583664,
           47.28324768161205,
           47.326787977640436,
           47.37032827366882,
           47.413868569697215,
           47.457408865725604,
           47.50094916175398,
           47.544489457782376,
           47.588029753810765,
           47.63157004983916,
           47.675165055660564,
           47.71878057761459,
           47.76239609956862,
           47.80601162152263,
           47.84962714347665,
           47.89324266543068,
           47.9368581873847,
           47.980473709338725,
           48.024089231292734,
           48.06770475324676,
           48.11132027520078,
           48.154935797154806,
           48.19855131910883,
           48.24216684106285,
           48.285782363016864,
           48.32939788497089,
           48.37301340692492,
           48.41662892887895,
           48.46024445083296,
           48.503859972786984,
           48.54747549474101,
           48.591091016695025,
           48.634706538649056,
           48.67832206060307,
           48.72193758255709,
           48.76555310451111,
           48.80916862646514,
           48.85278414841916,
           48.89639967037318,
           48.9400151923272,
           48.983630714281226,
           49.02724623623526,
           49.07086175818927,
           49.11447728014329,
           49.15809280209731,
           49.20170832405133,
           49.24532384600536,
           49.28893936795938,
           49.3325548899134,
           49.37617041186742,
           49.419785933821444,
           49.46340145577547,
           49.507016977729485,
           49.55063249968351,
           49.59424802163753,
           49.63786354359155,
           49.674302120081066,
           49.7035637511061,
           49.73282538213111,
           49.76208701315614,
           49.79134864418117,
           49.820610275206185,
           49.84987190623121,
           49.87913353725622,
           49.90839516828126,
           49.93765679930628,
           49.9669184303313,
           49.99618006135633,
           50.02544169238134,
           50.054703323406365,
           50.083964954431394,
           50.11322658545641,
           50.14357261262367,
           50.184039796535984,
           50.2245069804483,
           50.26497416436061,
           50.305441348272915,
           50.34590853218522,
           50.38637571609752,
           50.42684290000983,
           50.46731008392214,
           50.507777267834456,
           50.54824445174676,
           50.588711635659074,
           50.62917881957138,
           50.66964600348368,
           50.710113187396,
           50.7505803713083,
           50.791047555220615,
           50.83151473913293,
           50.87198192304524,
           50.91244910695754,
           50.95291629086985,
           50.993383474782156,
           51.03385065869446,
           51.074317842606774,
           51.11478502651907,
           51.155252210431385,
           51.1957193943437,
           51.23618657825601,
           51.276653762168316,
           51.31712094608062,
           51.35758812999293,
           51.398055313905246,
           51.43852249781755,
           51.47898968172986,
           51.51945686564217,
           51.55992404955447,
           51.60039123346678,
           51.64085841737909,
           51.681325601291405,
           51.721792785203704,
           51.762259969116016,
           51.80272715302833,
           51.843194336940634,
           51.88366152085294,
           51.92412870476525,
           51.96459588867756,
           52.00506307258986,
           52.045530256502175,
           52.08599744041448,
           52.126464624326786,
           52.1669318082391,
           52.20739899215141,
           52.24786617606372,
           52.28833335997602,
           52.32880054388833,
           52.36926772780064,
           52.409734911712945,
           52.45020209562526,
           52.49066927953757,
           52.53113646344987,
           52.57160364736218,
           52.61207083127449,
           52.65253801518679,
           52.69300519909911,
           52.73347238301142,
           52.77393956692372,
           52.81440675083603,
           52.70518154465346,
           52.29657155828131,
           51.88796157190916,
           51.47935158553696,
           51.070741599164805,
           50.66213161279265,
           50.253521626420465,
           49.84491164004827,
           49.43630165367615,
           49.02769166730396,
           48.619081680931764,
           48.21047169455961,
           47.80186170818745,
           47.393251721815254,
           46.984641735443105,
           46.57603174907095,
           46.16742176269875,
           45.758811776326596,
           45.35020178995445,
           44.941591803582256,
           44.53298181721006,
           44.12437183083791,
           43.715761844465746,
           43.30715185809356,
           42.8985418717214,
           42.48993188534924,
           42.081321898977045,
           41.672711912604896,
           41.26410192623273,
           40.855491939860556,
           40.44688195348836,
           40.03827196711624,
           39.629661980744046,
           39.22105199437185,
           38.81244200799969,
           38.40383202162754,
           37.995222035255345,
           37.58661204888319,
           37.178002062511034,
           36.76939207613884,
           36.36078208976669,
           35.95217210339453,
           35.54356211702235,
           35.13495213065015,
           34.72634214427799,
           34.31773215790584,
           33.909122171533646,
           33.50051218516149,
           33.091902198789334,
           32.68329221241714,
           32.27468222604498,
           31.86607223967283,
           31.457462253300633,
           31.048852266928442,
           30.64024228055633,
           30.23163229418413,
           29.82302230781194,
           29.414412321439784,
           29.005802335067628,
           28.597192348695437,
           28.18858236232328,
           27.779972375951125,
           27.371362389578934,
           26.96275240320678,
           26.554142416834623,
           26.14553243046243,
           25.73692244409024,
           25.32831245771812,
           24.919702471345925,
           24.51109248497373,
           24.102482498601574,
           23.69387251222942,
           23.285262525857227,
           22.87665253948507,
           22.46804255311292,
           22.059432566740725,
           21.650822580368533,
           21.242212593996413,
           20.833602607624222,
           20.424992621252024,
           20.00613975813896,
           19.583513179737306,
           19.16088660133561,
           18.77407331072138,
           18.566326459044035,
           18.358160526311526,
           18.143498921082728,
           17.928837315853965,
           17.714175710625163,
           17.49951410539636,
           17.284852500167602,
           17.070190894938797,
           16.855529289709995,
           16.640867684481236,
           16.426206079252434,
           16.211544474023633,
           15.996882868794831,
           15.782221263566067,
           15.567559658337267,
           15.352898053108465,
           15.138236447879704,
           14.9235748426509,
           14.708913237422099,
           14.49425163219334,
           14.279590026964534,
           14.064928421735736,
           13.850266816506972,
           13.635605211278172,
           13.42094360604937,
           13.206282000820568,
           12.991620395591806,
           12.776958790363004,
           12.562297185134202,
           12.347635579905441,
           12.132973974676638,
           11.918312369447838,
           11.703650764219075,
           11.488989158990275,
           11.274327553761474,
           11.05966594853267,
           10.84500434330391,
           10.630342738075107,
           10.415681132846306,
           10.201019527617545,
           9.986357922388743,
           9.833940105710921,
           9.725982137998086,
           9.618024170285231,
           9.510066202572377,
           9.402108234859542,
           9.294150267146687,
           9.18619229943383,
           9.078234331720978,
           8.970276364008145,
           8.862318396295288,
           8.754360428582434,
           8.6464024608696,
           8.538444493156744,
           8.43048652544389,
           8.322528557731054,
           8.2145705900182,
           8.106612622305345,
           7.998654654592491,
           7.8906966868796555,
           7.782738719166802,
           7.674780751453946,
           7.566822783741112,
           7.458864816028257,
           7.350906848315404,
           7.242948880602569,
           7.134990912889712,
           7.027032945176859,
           6.919074977464024,
           6.81111700975117,
           6.7031590420383145,
           6.595201074325461,
           6.487243106612626,
           6.379285138899771,
           6.271327171186916,
           6.1633692034740815,
           6.055411235761227,
           5.947453268048372,
           5.839495300335537,
           5.731537332622683,
           5.6241308954426295,
           5.521373108790611,
           5.418615322138612
          ],
          [
           39.4774795553011,
           39.5209443421183,
           39.56440912893549,
           39.60787391575269,
           39.65133870256989,
           39.694803489387084,
           39.73826827620427,
           39.78173306302147,
           39.825197849838666,
           39.86866263665586,
           39.91212742347306,
           39.95559221029025,
           39.99905699710745,
           40.04252178392464,
           40.08598657074184,
           40.12945135755904,
           40.17291614437623,
           40.21638093119343,
           40.259845718010624,
           40.30331050482782,
           40.34677529164501,
           40.390240078462206,
           40.4337048652794,
           40.4771696520966,
           40.520634438913795,
           40.56409922573099,
           40.60756401254818,
           40.651028799365385,
           40.694493586182574,
           40.73795837299977,
           40.78142315981697,
           40.824887946634156,
           40.86835273345136,
           40.91181752026855,
           40.955282307085746,
           40.99874709390294,
           41.04221188072014,
           41.085676667537335,
           41.12914145435453,
           41.17260624117173,
           41.216071027988924,
           41.25953581480612,
           41.30300060162332,
           41.346465388440514,
           41.3899301752577,
           41.4333949620749,
           41.476859748892096,
           41.52032453570929,
           41.56378932252648,
           41.60725410934368,
           41.650718896160875,
           41.69418368297807,
           41.73764846979527,
           41.781113256612464,
           41.82457804342966,
           41.86804283024686,
           41.91150761706405,
           41.95497240388125,
           41.998437190698446,
           42.041901977515636,
           42.08536676433283,
           42.12883155115003,
           42.172296337967225,
           42.215761124784414,
           42.25922591160161,
           42.30269069841881,
           42.346155485236004,
           42.3896202720532,
           42.4330850588704,
           42.47654984568759,
           42.52001463250479,
           42.56347941932198,
           42.606944206139175,
           42.65040899295637,
           42.69387377977357,
           42.737338566590765,
           42.781615653235264,
           42.82670504145529,
           42.87179442967531,
           42.91688381789533,
           42.96197320611535,
           43.00706259433537,
           43.052151982555394,
           43.097241370775414,
           43.138419156145574,
           43.17881462094576,
           43.21921008574595,
           43.259605550546134,
           43.30000101534632,
           43.3403964801465,
           43.380791944946694,
           43.42118740974688,
           43.46158287454706,
           43.501978339347254,
           43.54237380414743,
           43.58276926894763,
           43.623164733747814,
           43.663560198548,
           43.70395566334818,
           43.74435112814837,
           43.78474659294856,
           43.82514205774874,
           43.865537522548934,
           43.90593298734912,
           43.9463284521493,
           43.98672391694949,
           44.02711938174967,
           44.06751484654986,
           44.10791031135005,
           44.14830577615024,
           44.18870124095042,
           44.22909670575061,
           44.26949217055079,
           44.30988763535098,
           44.35028310015117,
           44.39067856495136,
           44.43107402975154,
           44.47146949455173,
           44.51186495935191,
           44.552260424152095,
           44.592655888952294,
           44.63305135375248,
           44.67344681855266,
           44.71384228335285,
           44.75423774815303,
           44.794633212953215,
           44.8350286777534,
           44.87542414255359,
           44.91581960735378,
           44.95621507215397,
           44.99661053695415,
           45.037006001754335,
           45.07740146655452,
           45.11779693135471,
           45.158192396154895,
           45.19858786095508,
           45.23898332575527,
           45.279378790555455,
           45.31977425535564,
           45.360169720155824,
           45.400565184956015,
           45.4409606497562,
           45.481356114556384,
           45.521751579356575,
           45.56214704415676,
           45.602542508956944,
           45.64293797375713,
           45.68333343855732,
           45.72372890335751,
           45.764124368157695,
           45.80451983295788,
           45.844915297758064,
           45.885310762558255,
           45.92570622735843,
           45.966101692158624,
           46.00649715695881,
           46.046892621759,
           46.087288086559184,
           46.12768355135937,
           46.168477761733136,
           46.210069465184944,
           46.25166116863676,
           46.29325287208856,
           46.33484457554037,
           46.37643627899218,
           46.41802798244398,
           46.459619685895795,
           46.503070550775675,
           46.54745099636959,
           46.591831441963514,
           46.63621188755743,
           46.68059233315135,
           46.724972778745276,
           46.76935322433918,
           46.8137336699331,
           46.85811411552702,
           46.90249456112094,
           46.94687500671486,
           46.99125545230877,
           47.0355812598237,
           47.079196781777725,
           47.12281230373174,
           47.16642782568577,
           47.21004334763979,
           47.253658869593814,
           47.29727439154783,
           47.340889913501854,
           47.384505435455885,
           47.42812095740991,
           47.471736479363926,
           47.51535200131795,
           47.55896752327197,
           47.60258304522599,
           47.64619856718001,
           47.68981408913403,
           47.733429611088056,
           47.77704513304207,
           47.820660654996104,
           47.86427617695012,
           47.90789169890414,
           47.95150722085816,
           47.995122742812185,
           48.03873826476621,
           48.08235378672023,
           48.12596930867426,
           48.169584830628274,
           48.21320035258229,
           48.256815874536315,
           48.30043139649034,
           48.34404691844436,
           48.38766244039839,
           48.43127796235241,
           48.47489348430643,
           48.518509006260444,
           48.562124528214476,
           48.60574005016849,
           48.649355572122516,
           48.69297109407653,
           48.73658661603055,
           48.78020213798458,
           48.8238176599386,
           48.86743318189262,
           48.91104870384664,
           48.95466422580067,
           48.99827974775468,
           49.041895269708704,
           49.085510791662735,
           49.12912631361676,
           49.172741835570775,
           49.2163573575248,
           49.25997287947882,
           49.30358840143285,
           49.347203923386864,
           49.39081944534088,
           49.434434967294905,
           49.47805048924893,
           49.52166601120295,
           49.56528153315698,
           49.608897055111,
           49.65251257706502,
           49.696128099019035,
           49.73974362097306,
           49.78335914292708,
           49.82697466488111,
           49.87059018683512,
           49.91420570878914,
           49.95782123074317,
           50.00143675269719,
           50.04505227465121,
           50.088667796605236,
           50.12510637309475,
           50.154368004119775,
           50.1836296351448,
           50.21289126616983,
           50.24215289719485,
           50.271414528219864,
           50.30067615924489,
           50.32993779026991,
           50.359199421294946,
           50.388461052319954,
           50.41772268334498,
           50.446984314370006,
           50.47624594539502,
           50.505507576420044,
           50.53476920744507,
           50.56403083847009,
           50.59329246949511,
           50.622554100520134,
           50.651815731545156,
           50.681077362570186,
           50.7103389935952,
           50.73960062462024,
           50.76886225564525,
           50.79812388667027,
           50.8273855176953,
           50.85664714872031,
           50.88590877974534,
           50.915170410770365,
           50.94443204179539,
           50.9736936728204,
           51.00295530384543,
           51.03221693487046,
           51.06147856589548,
           51.09074019692049,
           51.120001827945515,
           51.149263458970545,
           51.178525089995574,
           51.20778672102058,
           51.237048352045605,
           51.26630998307063,
           51.29557161409565,
           51.33170115844866,
           51.372168342360965,
           51.41263552627328,
           51.45310271018559,
           51.49356989409789,
           51.5340370780102,
           51.57450426192251,
           51.61497144583482,
           51.655438629747124,
           51.69590581365944,
           51.73637299757175,
           51.77684018148405,
           51.81730736539636,
           51.85777454930867,
           51.89824173322097,
           51.93870891713328,
           51.9791761010456,
           52.0196432849579,
           52.060110468870214,
           52.10057765278252,
           52.141044836694824,
           52.18151202060714,
           52.22197920451945,
           52.262446388431755,
           52.30291357234406,
           52.34338075625637,
           52.383847940168685,
           52.424315124080984,
           52.464782307993296,
           52.50524949190561,
           52.545716675817914,
           52.58618385973022,
           52.62665104364254,
           52.66711822755484,
           52.70758541146714,
           52.74805259537945,
           52.78851977929177,
           52.82898696320407,
           52.869454147116386,
           52.9099213310287,
           52.950388514941,
           52.99085569885331,
           52.88163049267074,
           52.47302050629858,
           52.064410519926426,
           51.65580053355424,
           51.24719054718208,
           50.83858056080992,
           50.42997057443773,
           50.021360588065534,
           49.61275060169342,
           49.20414061532123,
           48.79553062894904,
           48.38692064257687,
           47.97831065620472,
           47.56970066983253,
           47.16109068346037,
           46.75248069708822,
           46.343870710716025,
           45.93526072434388,
           45.526650737971714,
           45.11804075159953,
           44.70943076522733,
           44.30082077885518,
           43.89221079248301,
           43.48360080611083,
           43.074990819738666,
           42.66638083336652,
           42.257770846994326,
           41.84916086062217,
           41.440550874250015,
           41.03194088787782,
           40.623330901505625,
           40.21472091513351,
           39.80611092876132,
           39.397500942389115,
           38.98889095601696,
           38.58028096964481,
           38.17167098327262,
           37.763060996900464,
           37.35445101052831,
           36.94584102415612,
           36.53723103778396,
           36.1286210514118,
           35.720011065039614,
           35.31140107866742,
           34.90279109229527,
           34.494181105923104,
           34.08557111955092,
           33.676961133178764,
           33.26835114680661,
           32.85974116043441,
           32.45113117406226,
           32.0295828083902,
           31.606956229988505,
           31.18432965158681,
           30.761703073185192,
           30.339076494783498,
           29.9164499163818,
           29.493823337980146,
           29.071196759578488,
           28.64857018117679,
           28.225943602775136,
           27.803317024373477,
           27.380690445971783,
           26.958063867570125,
           26.535437289168467,
           26.112810710766773,
           25.690184132365076,
           25.267557553963456,
           24.84493097556176,
           24.422304397160065,
           23.999677818758407,
           23.577051240356752,
           23.154424661955055,
           22.7317980835534,
           22.309171505151745,
           21.886544926750048,
           21.46391834834835,
           21.04129176994673,
           20.618665191545038,
           20.196038613143344,
           19.773412034741686,
           19.350785456340027,
           18.928158877938333,
           18.541345587324106,
           18.33359873564676,
           18.125851883969418,
           17.918105032292072,
           17.710358180614765,
           17.50261132893742,
           17.29486447726007,
           17.087117625582767,
           16.87937077390542,
           16.67162392222808,
           16.46387707055077,
           16.256130218873423,
           16.048383367196077,
           15.840636515518732,
           15.632889663841425,
           15.42514281216408,
           15.217395960486735,
           15.009649108809429,
           14.801902257132083,
           14.594155405454739,
           14.380803408751476,
           14.16614180352267,
           13.951480198293872,
           13.736818593065108,
           13.522156987836308,
           13.307495382607506,
           13.092833777378704,
           12.878172172149942,
           12.66351056692114,
           12.448848961692338,
           12.234187356463577,
           12.019525751234774,
           11.804864146005976,
           11.590202540777211,
           11.375540935548411,
           11.16087933031961,
           10.946217725090806,
           10.731556119862047,
           10.516894514633243,
           10.302232909404442,
           10.087571304175679,
           9.872909698946877,
           9.720491882269057,
           9.612533914556222,
           9.504575946843369,
           9.396617979130513,
           9.288660011417678,
           9.180702043704823,
           9.07274407599197,
           8.964786108279114,
           8.85682814056628,
           8.748870172853426,
           8.64091220514057,
           8.532954237427736,
           8.42499626971488,
           8.317038302002025,
           8.209080334289192,
           8.101122366576337,
           7.993164398863481,
           7.8852064311506265,
           7.777248463437793,
           7.669290495724937,
           7.561332528012082,
           7.453374560299249,
           7.347268169281438,
           7.24451038262942,
           7.141752595977419,
           7.0389948093254,
           6.936237022673381,
           6.833479236021381,
           6.730721449369362,
           6.627963662717343,
           6.525205876065324,
           6.422448089413324,
           6.319690302761305,
           6.216932516109286,
           6.114174729457286,
           6.011416942805266,
           5.908659156153249,
           5.805901369501249,
           5.703143582849229,
           5.60038579619721,
           5.497628009545191,
           5.394870222893191
          ],
          [
           39.86100505236213,
           39.90446983917933,
           39.947934625996524,
           39.99139941281372,
           40.03486419963092,
           40.07832898644811,
           40.1217937732653,
           40.1652585600825,
           40.208723346899696,
           40.25218813371689,
           40.29565292053409,
           40.33911770735128,
           40.382582494168474,
           40.42604728098567,
           40.46951206780287,
           40.512976854620064,
           40.55644164143726,
           40.59990642825446,
           40.64337121507165,
           40.68683600188885,
           40.73030078870604,
           40.773765575523235,
           40.81723036234043,
           40.86069514915763,
           40.904159935974825,
           40.94762472279202,
           40.99108950960921,
           41.03455429642641,
           41.0780190832436,
           41.1214838700608,
           41.164948656877996,
           41.208413443695186,
           41.25187823051239,
           41.29534301732958,
           41.338807804146775,
           41.38227259096397,
           41.42573737778117,
           41.469202164598364,
           41.51266695141556,
           41.55613173823276,
           41.59959652504995,
           41.64306131186715,
           41.68652609868434,
           41.729990885501536,
           41.77345567231873,
           41.81692045913593,
           41.860385245953125,
           41.90385003277032,
           41.94731481958752,
           41.99077960640471,
           42.034244393221904,
           42.0777091800391,
           42.1211739668563,
           42.16463875367349,
           42.20810354049068,
           42.25156832730788,
           42.295033114125076,
           42.33849790094227,
           42.38196268775947,
           42.425427474576665,
           42.470516862190635,
           42.51560625041066,
           42.56069563863068,
           42.6057850268507,
           42.650874415070724,
           42.695963803290745,
           42.741053191510765,
           42.786142579730786,
           42.83123196795081,
           42.87632135617083,
           42.92141074439085,
           42.96650013261087,
           43.01158952083089,
           43.05667890905091,
           43.10176829727094,
           43.14685768549096,
           43.19194707371098,
           43.23703646193099,
           43.28212585015102,
           43.32721523837104,
           43.37230462659106,
           43.41739401481108,
           43.4624834030311,
           43.50757279125112,
           43.54875057662129,
           43.58914604142147,
           43.629541506221656,
           43.66993697102184,
           43.710332435822025,
           43.75072790062221,
           43.7911233654224,
           43.83151883022259,
           43.871914295022776,
           43.91230975982296,
           43.952705224623145,
           43.993100689423336,
           44.03349615422352,
           44.073891619023705,
           44.114287083823896,
           44.15468254862408,
           44.195078013424265,
           44.235473478224456,
           44.27586894302464,
           44.31626440782483,
           44.356659872625016,
           44.3970553374252,
           44.437450802225385,
           44.47784626702557,
           44.51824173182576,
           44.558637196625945,
           44.599032661426136,
           44.63942812622632,
           44.679823591026505,
           44.720219055826696,
           44.76061452062687,
           44.801009985427065,
           44.84140545022725,
           44.88180091502744,
           44.922196379827625,
           44.96259184462781,
           45.00298730942799,
           45.043382774228185,
           45.08377823902837,
           45.124173703828546,
           45.16456916862874,
           45.20496463342892,
           45.24536009822911,
           45.285755563029305,
           45.32615102782949,
           45.36654649262967,
           45.40694195742986,
           45.44733742223005,
           45.48773288703023,
           45.528128351830425,
           45.56852381663061,
           45.60891928143079,
           45.64931474623098,
           45.68971021103117,
           45.73010567583135,
           45.77050114063154,
           45.81089660543172,
           45.851292070231914,
           45.8916875350321,
           45.933079864929056,
           45.97467156838086,
           46.01626327183266,
           46.05785497528448,
           46.099446678736285,
           46.14103838218809,
           46.1826300856399,
           46.224221789091715,
           46.265813492543515,
           46.30740519599533,
           46.34899689944714,
           46.390588602898944,
           46.43218030635076,
           46.47377200980256,
           46.51536371325437,
           46.55695541670618,
           46.59854712015799,
           46.640138823609796,
           46.6817305270616,
           46.72332223051341,
           46.764913933965225,
           46.80650563741703,
           46.84809734086883,
           46.88968904432065,
           46.93313990920053,
           46.97752035479445,
           47.021900800388366,
           47.06628124598228,
           47.1106616915762,
           47.15504213717012,
           47.199422582764036,
           47.24380302835795,
           47.288183473951875,
           47.33256391954579,
           47.37694436513971,
           47.42132481073362,
           47.465705256327546,
           47.51008570192146,
           47.55446614751538,
           47.5988465931093,
           47.64322703870321,
           47.68760748429714,
           47.73198792989105,
           47.776368375484964,
           47.82074882107889,
           47.8651292666728,
           47.909509712266726,
           47.95389015786064,
           47.99827060345455,
           48.04265104904848,
           48.087031494642396,
           48.13141194023631,
           48.175792385830235,
           48.220172831424144,
           48.26455327701807,
           48.30893372261198,
           48.3533141682059,
           48.397694613799814,
           48.44207505939374,
           48.48645550498765,
           48.530835950581576,
           48.575216396175485,
           48.61959684176941,
           48.66397728736332,
           48.70762012754997,
           48.751235649504004,
           48.79485117145802,
           48.83846669341205,
           48.882082215366076,
           48.92569773732009,
           48.96931325927412,
           49.01292878122814,
           49.05654430318215,
           49.100159825136174,
           49.1437753470902,
           49.18739086904422,
           49.23100639099824,
           49.27462191295227,
           49.31823743490629,
           49.361852956860304,
           49.405468478814335,
           49.44908400076835,
           49.492699522722376,
           49.5363150446764,
           49.57993056663042,
           49.62354608858444,
           49.667161610538464,
           49.71077713249249,
           49.754392654446505,
           49.79800817640053,
           49.84162369835455,
           49.88523922030857,
           49.9288547422626,
           49.97247026421662,
           50.016085786170635,
           50.05970130812466,
           50.10331683007868,
           50.14693235203271,
           50.19054787398672,
           50.23416339594075,
           50.27777891789477,
           50.32139443984879,
           50.36500996180281,
           50.408625483756836,
           50.45224100571086,
           50.495856527664884,
           50.5394720496189,
           50.575910626108424,
           50.60517225713345,
           50.63443388815847,
           50.663695519183484,
           50.692957150208514,
           50.722218781233536,
           50.75148041225856,
           50.78074204328358,
           50.810003674308604,
           50.83926530533362,
           50.86852693635865,
           50.89778856738367,
           50.92705019840869,
           50.956311829433716,
           50.98557346045874,
           51.01483509148376,
           51.04409672250878,
           51.073358353533806,
           51.10261998455883,
           51.13188161558385,
           51.16114324660887,
           51.190404877633895,
           51.21966650865891,
           51.24892813968394,
           51.27818977070896,
           51.307451401733985,
           51.336713032759,
           51.36597466378403,
           51.39523629480905,
           51.42449792583407,
           51.453759556859104,
           51.48302118788412,
           51.51228281890914,
           51.54154444993416,
           51.57080608095919,
           51.60006771198421,
           51.62932934300923,
           51.658590974034254,
           51.68785260505928,
           51.71711423608429,
           51.74637586710932,
           51.775637498134344,
           51.80489912915936,
           51.83416076018439,
           51.86342239120941,
           51.89268402223443,
           51.92194565325945,
           51.95120728428448,
           51.9804689153095,
           52.00973054633452,
           52.038992177359546,
           52.06825380838456,
           52.097515439409584,
           52.12677707043461,
           52.156038701459636,
           52.18530033248466,
           52.214561963509674,
           52.243823594534696,
           52.273085225559726,
           52.30234685658474,
           52.33160848760977,
           52.360870118634786,
           52.390131749659815,
           52.41939338068484,
           52.44865501170986,
           52.47936252036133,
           52.51982970427364,
           52.560296888185945,
           52.60076407209825,
           52.64123125601056,
           52.68169843992287,
           52.722165623835174,
           52.76263280774749,
           52.80309999165979,
           52.843567175572105,
           52.8840343594844,
           52.924501543396715,
           52.96496872730903,
           53.00543591122133,
           53.045903095133646,
           53.08637027904595,
           53.126837462958264,
           53.16730464687057,
           53.058079440688005,
           52.64946945431585,
           52.24085946794369,
           51.8322494815715,
           51.42363949519935,
           51.01502950882718,
           50.606419522455006,
           50.1978095360828,
           49.78919954971069,
           49.38058956333849,
           48.971979576966305,
           48.563369590594135,
           48.154759604221994,
           47.74614961784979,
           47.33753963147764,
           46.928929645105484,
           46.52031965873329,
           46.11170967236114,
           45.70309968598898,
           45.29448969961679,
           44.8858797132446,
           44.47565243704307,
           44.05302585864141,
           43.630399280239715,
           43.20777270183806,
           42.785146123436405,
           42.36251954503471,
           41.93989296663305,
           41.5172663882314,
           41.0946398098297,
           40.672013231428004,
           40.249386653026384,
           39.82676007462469,
           39.404133496223,
           38.981506917821335,
           38.55888033941968,
           38.13625376101798,
           37.71362718261633,
           37.29100060421467,
           36.868374025812976,
           36.445747447411314,
           36.02312086900966,
           35.60049429060796,
           35.17786771220627,
           34.7552411338046,
           34.332614555402955,
           33.90998797700125,
           33.4873613985996,
           33.06473482019794,
           32.64210824179625,
           32.21948166339459,
           31.796855084992934,
           31.374228506591237,
           30.951601928189543,
           30.528975349787924,
           30.10634877138623,
           29.68372219298453,
           29.261095614582874,
           28.83846903618122,
           28.415842457779522,
           27.993215879377868,
           27.57058930097621,
           27.147962722574515,
           26.72533614417286,
           26.3027095657712,
           25.880082987369505,
           25.457456408967808,
           25.034829830566192,
           24.612203252164495,
           24.189576673762797,
           23.766950095361143,
           23.344323516959488,
           22.92169693855779,
           22.499070360156136,
           22.076443781754477,
           21.65381720335278,
           21.231190624951086,
           20.808564046549467,
           20.385937468147773,
           19.963310889746076,
           19.54068431134442,
           19.118057732942763,
           18.695431154541065,
           18.30861786392684,
           18.100871012249495,
           17.89312416057215,
           17.685377308894807,
           17.477630457217497,
           17.26988360554015,
           17.062136753862806,
           16.854389902185503,
           16.646643050508157,
           16.43889619883081,
           16.231149347153504,
           16.023402495476155,
           15.815655643798811,
           15.607908792121465,
           15.400161940444159,
           15.192415088766813,
           14.984668237089469,
           14.776921385412162,
           14.569174533734817,
           14.361427682057471,
           14.153680830380164,
           13.945933978702818,
           13.738187127025473,
           13.530440275348166,
           13.322693423670822,
           13.114946571993476,
           12.90719972031613,
           12.699452868638824,
           12.491706016961478,
           12.283959165284132,
           12.076212313606826,
           11.868465461929482,
           11.660718610252136,
           11.452971758574828,
           11.245224906897484,
           11.037478055220136,
           10.829731203542792,
           10.618107896420186,
           10.403446291191385,
           10.188784685962583,
           9.974123080733822,
           9.759461475505018,
           9.607043658827196,
           9.499085691114361,
           9.391127723401508,
           9.283169755688654,
           9.175211787975819,
           9.070405443120245,
           8.967647656468227,
           8.864889869816206,
           8.762132083164209,
           8.65937429651219,
           8.55661650986017,
           8.453858723208171,
           8.35110093655615,
           8.248343149904132,
           8.145585363252133,
           8.042827576600114,
           7.940069789948095,
           7.837312003296075,
           7.734554216644075,
           7.631796429992057,
           7.529038643340037,
           7.426280856688037,
           7.3235230700360185,
           7.220765283383999,
           7.118007496732,
           7.015249710079981,
           6.912491923427961,
           6.809734136775961,
           6.706976350123942,
           6.604218563471923,
           6.501460776819904,
           6.398702990167904,
           6.2959452035158865,
           6.193187416863868,
           6.090429630211866,
           5.987671843559848,
           5.884914056907829,
           5.782156270255829,
           5.67939848360381,
           5.576640696951791,
           5.473882910299771,
           5.371125123647771
          ],
          [
           40.24453054942316,
           40.28799533624036,
           40.33146012305755,
           40.37492490987474,
           40.418389696691946,
           40.46185448350914,
           40.505319270326325,
           40.54878405714353,
           40.592248843960725,
           40.635713630777914,
           40.67917841759511,
           40.72264320441231,
           40.766107991229504,
           40.8095727780467,
           40.8530375648639,
           40.89650235168109,
           40.93996713849829,
           40.983431925315486,
           41.02689671213268,
           41.07036149894988,
           41.11382628576707,
           41.15729107258427,
           41.200755859401454,
           41.24422064621865,
           41.28768543303585,
           41.33115021985304,
           41.37461500667024,
           41.418079793487436,
           41.46154458030463,
           41.50500936712183,
           41.548474153939026,
           41.591938940756215,
           41.63540372757342,
           41.67886851439061,
           41.722333301207804,
           41.765798088025,
           41.80926287484219,
           41.852727661659394,
           41.89619244847658,
           41.93965723529379,
           41.983122022110976,
           42.02658680892817,
           42.07005159574537,
           42.114328682925986,
           42.159418071146014,
           42.204507459366035,
           42.249596847586055,
           42.294686235806076,
           42.339775624026096,
           42.38486501224612,
           42.42995440046614,
           42.475043788686165,
           42.52013317690618,
           42.5652225651262,
           42.610311953346226,
           42.65540134156624,
           42.70049072978627,
           42.74558011800629,
           42.7906695062263,
           42.83575889444633,
           42.88084828266635,
           42.92593767088637,
           42.97102705910639,
           43.01611644732641,
           43.06120583554643,
           43.10629522376645,
           43.15138461198647,
           43.19647400020649,
           43.24156338842652,
           43.28665277664654,
           43.33174216486656,
           43.37683155308658,
           43.4219209413066,
           43.46701032952663,
           43.51209971774665,
           43.55718910596667,
           43.60227849418669,
           43.64736788240671,
           43.69245727062673,
           43.73754665884675,
           43.782636047066774,
           43.827725435286794,
           43.872814823506815,
           43.917904211726835,
           43.95908199709699,
           43.99947746189718,
           44.03987292669736,
           44.080268391497555,
           44.12066385629774,
           44.16105932109792,
           44.20145478589811,
           44.24185025069829,
           44.28224571549849,
           44.32264118029866,
           44.36303664509885,
           44.40343210989904,
           44.44382757469923,
           44.48422303949942,
           44.524618504299596,
           44.56501396909978,
           44.60540943389998,
           44.64580489870016,
           44.68620036350035,
           44.72659582830054,
           44.766991293100716,
           44.80738675790091,
           44.84778222270109,
           44.88817768750128,
           44.92857315230147,
           44.96896861710165,
           45.009364081901836,
           45.04975954670203,
           45.09015501150221,
           45.1305504763024,
           45.17094594110259,
           45.21134140590277,
           45.25173687070296,
           45.29213233550315,
           45.332527800303325,
           45.37292326510352,
           45.4133187299037,
           45.45371419470389,
           45.494109659504076,
           45.53450512430426,
           45.57490058910445,
           45.615296053904636,
           45.65609026467316,
           45.69768196812497,
           45.739273671576775,
           45.78086537502858,
           45.8224570784804,
           45.8640487819322,
           45.90564048538401,
           45.94723218883582,
           45.98882389228763,
           46.030415595739434,
           46.07200729919124,
           46.11359900264305,
           46.155190706094864,
           46.19678240954667,
           46.23837411299848,
           46.279965816450286,
           46.32155751990209,
           46.3631492233539,
           46.404740926805715,
           46.44633263025752,
           46.48792433370933,
           46.52951603716114,
           46.571107740612945,
           46.61269944406475,
           46.65429114751657,
           46.695882850968374,
           46.73747455442019,
           46.77906625787199,
           46.820657961323796,
           46.862249664775604,
           46.90384136822741,
           46.945433071679226,
           46.98702477513103,
           47.02861647858285,
           47.070208182034655,
           47.11179988548646,
           47.15339158893826,
           47.19498329239008,
           47.23657499584189,
           47.27816669929369,
           47.3197584027455,
           47.363209267625386,
           47.407589713219295,
           47.45197015881322,
           47.49635060440714,
           47.54073105000106,
           47.58511149559497,
           47.62949194118889,
           47.673872386782804,
           47.71825283237672,
           47.762633277970636,
           47.807013723564566,
           47.85139416915848,
           47.8957746147524,
           47.940155060346314,
           47.98453550594023,
           48.028915951534145,
           48.07329639712807,
           48.11767684272199,
           48.16205728831591,
           48.20643773390982,
           48.25081817950374,
           48.295198625097655,
           48.33957907069157,
           48.38395951628549,
           48.42833996187941,
           48.472720407473325,
           48.51710085306725,
           48.56148129866116,
           48.60586174425508,
           48.650242189849,
           48.69462263544292,
           48.73900308103683,
           48.78338352663075,
           48.82776397222467,
           48.87214441781859,
           48.916524863412505,
           48.96090530900642,
           49.00528575460034,
           49.04966620019426,
           49.094046645788175,
           49.13842709138209,
           49.18280753697601,
           49.22718798256993,
           49.27156842816385,
           49.31594887375776,
           49.360329319351685,
           49.4047097649456,
           49.44909021053952,
           49.49347065613344,
           49.537851101727355,
           49.58223154732127,
           49.626611992915194,
           49.6709924385091,
           49.715372884103026,
           49.75975332969694,
           49.804133775290865,
           49.84851422088478,
           49.892894666478696,
           49.93727511207261,
           49.981655557666535,
           50.026036003260444,
           50.070416448854374,
           50.11479689444829,
           50.15917734004221,
           50.20355778563612,
           50.24793823123004,
           50.29231867682396,
           50.336043473322235,
           50.379658995276266,
           50.42327451723028,
           50.46689003918431,
           50.51050556113833,
           50.55412108309235,
           50.59773660504637,
           50.64135212700039,
           50.68496764895442,
           50.72858317090843,
           50.77219869286246,
           50.81581421481648,
           50.85942973677051,
           50.90304525872452,
           50.94666078067855,
           50.990276302632566,
           51.026714879122096,
           51.05597651014711,
           51.08523814117214,
           51.11449977219715,
           51.14376140322218,
           51.1730230342472,
           51.202284665272224,
           51.231546296297246,
           51.26080792732227,
           51.29006955834729,
           51.319331189372306,
           51.348592820397336,
           51.37785445142236,
           51.40711608244738,
           51.4363777134724,
           51.46563934449743,
           51.49490097552245,
           51.52416260654747,
           51.55342423757249,
           51.58268586859752,
           51.611947499622545,
           51.64120913064757,
           51.67047076167258,
           51.6997323926976,
           51.72899402372263,
           51.75825565474765,
           51.787517285772665,
           51.81677891679769,
           51.84604054782272,
           51.87530217884773,
           51.90456380987276,
           51.933825440897785,
           51.96308707192281,
           51.99234870294782,
           52.02161033397286,
           52.050871964997874,
           52.0801335960229,
           52.10939522704792,
           52.13865685807294,
           52.16791848909796,
           52.19718012012299,
           52.22644175114801,
           52.255703382173024,
           52.284965013198054,
           52.314226644223076,
           52.34348827524809,
           52.372749906273114,
           52.402011537298144,
           52.431273168323166,
           52.46053479934818,
           52.48979643037322,
           52.519058061398226,
           52.54831969242325,
           52.57758132344827,
           52.606842954473294,
           52.63610458549832,
           52.66536621652334,
           52.693598133140206,
           52.7187408868237,
           52.74388364050721,
           52.7690263941907,
           52.79416914787421,
           52.81931190155772,
           52.84445465524122,
           52.86959740892472,
           52.89474016260822,
           52.919882916291726,
           52.94502566997522,
           52.97016842365873,
           52.99531117734223,
           53.02045393102574,
           53.045596684709245,
           53.070739438392735,
           53.095882192076246,
           53.12102494575974,
           53.14616769944325,
           53.17131045312674,
           53.196453206810254,
           53.22159596049376,
           53.24673871417726,
           53.27188146786076,
           53.29702422154426,
           53.322166975227766,
           53.19474604245912,
           52.76219773678634,
           52.32964943111356,
           51.897101125440734,
           51.46455281976796,
           51.03200451409517,
           50.59945620842235,
           50.166907902749536,
           49.73792124641583,
           49.31529466801413,
           48.89266808961243,
           48.47004151121078,
           48.047414932809126,
           47.62478835440743,
           47.20216177600577,
           46.77953519760411,
           46.356908619202414,
           45.93428204080076,
           45.5116554623991,
           45.08902888399741,
           44.66640230559571,
           44.243775727194055,
           43.821149148792394,
           43.3985225703907,
           42.97589599198904,
           42.553269413587394,
           42.13064283518569,
           41.70801625678404,
           41.28538967838238,
           40.86276309998069,
           40.44013652157899,
           40.017509943177366,
           39.594883364775676,
           39.17225678637398,
           38.749630207972324,
           38.32700362957066,
           37.90437705116897,
           37.48175047276731,
           37.059123894365655,
           36.63649731596396,
           36.2138707375623,
           35.79124415916065,
           35.36861758075895,
           34.94599100235725,
           34.5233644239556,
           34.100737845553944,
           33.67811126715225,
           33.25548468875059,
           32.83285811034893,
           32.41023153194724,
           31.987604953545578,
           31.564978375143923,
           31.142351796742226,
           30.719725218340532,
           30.297098639938913,
           29.87447206153722,
           29.45184548313552,
           29.029218904733867,
           28.60659232633221,
           28.183965747930515,
           27.761339169528856,
           27.338712591127198,
           26.916086012725504,
           26.493459434323846,
           26.07083285592219,
           25.648206277520494,
           25.225579699118796,
           24.80295312071718,
           24.380326542315483,
           23.95769996391379,
           23.53507338551213,
           23.112446807110473,
           22.68982022870878,
           22.26719365030712,
           21.844567071905466,
           21.42194049350377,
           20.999313915102075,
           20.576687336700456,
           20.15406075829876,
           19.731434179897064,
           19.308807601495406,
           18.886181023093748,
           18.463554444692054,
           18.078102790680447,
           17.878525758618842,
           17.67894872655723,
           17.479371694495626,
           17.279794662434053,
           17.078323303462675,
           16.871900872897527,
           16.665478442332414,
           16.459056011767267,
           16.25263358120212,
           16.046211150637006,
           15.83978872007186,
           15.63336628950671,
           15.426943858941563,
           15.220521428376452,
           15.014098997811304,
           14.807676567246157,
           14.601254136681046,
           14.394831706115898,
           14.18840927555075,
           13.981986844985641,
           13.775564414420492,
           13.569141983855346,
           13.362719553290235,
           13.156297122725087,
           12.949874692159938,
           12.74345226159479,
           12.53702983102968,
           12.330607400464531,
           12.124184969899382,
           11.917762539334275,
           11.711340108769125,
           11.504917678203977,
           11.298495247638868,
           11.092072817073719,
           10.88565038650857,
           10.679227955943423,
           10.472805525378313,
           10.266383094813165,
           10.059960664248015,
           9.853538233682906,
           9.647115803117757,
           9.501676753160526,
           9.399797260780383,
           9.297917768400218,
           9.196038276020056,
           9.094158783639912,
           8.992279291259749,
           8.890399798879587,
           8.788520306499423,
           8.686640814119277,
           8.584761321739116,
           8.482881829358952,
           8.381002336978808,
           8.279122844598644,
           8.17724335221848,
           8.075363859838337,
           7.973484367458175,
           7.871604875078011,
           7.769725382697849,
           7.667845890317704,
           7.56596639793754,
           7.464086905557377,
           7.3622074131772335,
           7.260327920797069,
           7.158448428416907,
           7.056568936036763,
           6.9546894436566,
           6.852809951276436,
           6.750930458896292,
           6.649050966516129,
           6.547171474135967,
           6.445291981755803,
           6.343412489375658,
           6.241532996995495,
           6.139653504615332,
           6.037774012235188,
           5.935894519855025,
           5.8340150274748614,
           5.736353684921255,
           5.639214023849888,
           5.542074362778521,
           5.4449347017071545,
           5.3477950406358055
          ],
          [
           40.6280560464842,
           40.6715208333014,
           40.71498562011859,
           40.758450406935786,
           40.80191519375298,
           40.84537998057017,
           40.88884476738737,
           40.932309554204565,
           40.97577434102176,
           41.01923912783896,
           41.062703914656154,
           41.10616870147335,
           41.14963348829055,
           41.193098275107744,
           41.23656306192494,
           41.28002784874214,
           41.323492635559326,
           41.36695742237653,
           41.41042220919372,
           41.453886996010915,
           41.497351782828105,
           41.54081656964531,
           41.5842813564625,
           41.627746143279694,
           41.67121093009689,
           41.71467571691409,
           41.75814050373128,
           41.80322989188138,
           41.8483192801014,
           41.89340866832142,
           41.93849805654144,
           41.98358744476146,
           42.02867683298148,
           42.0737662212015,
           42.11885560942153,
           42.16394499764154,
           42.20903438586157,
           42.254123774081584,
           42.29921316230161,
           42.34430255052163,
           42.389391938741646,
           42.434481326961674,
           42.47957071518169,
           42.524660103401715,
           42.569749491621735,
           42.61483887984175,
           42.659928268061776,
           42.7050176562818,
           42.75010704450182,
           42.79519643272184,
           42.84028582094186,
           42.885375209161886,
           42.930464597381906,
           42.97555398560192,
           43.02064337382195,
           43.06573276204196,
           43.110822150261995,
           43.15591153848201,
           43.20100092670202,
           43.24609031492206,
           43.29117970314206,
           43.3362690913621,
           43.38135847958211,
           43.42644786780213,
           43.47153725602216,
           43.51662664424218,
           43.5617160324622,
           43.60680542068222,
           43.65189480890224,
           43.69698419712226,
           43.74207358534228,
           43.78716297356231,
           43.832252361782324,
           43.87734175000235,
           43.922431138222365,
           43.9675205264424,
           44.01260991466241,
           44.057699302882426,
           44.102788691102454,
           44.14787807932247,
           44.1929674675425,
           44.238056855762515,
           44.283146243982536,
           44.32823563220256,
           44.369413417572716,
           44.40980888237291,
           44.45020434717309,
           44.49059981197327,
           44.53099527677347,
           44.571390741573644,
           44.611786206373836,
           44.65218167117402,
           44.692577135974204,
           44.732972600774396,
           44.77336806557458,
           44.813763530374764,
           44.854158995174956,
           44.89455445997514,
           44.934949924775324,
           44.97534538957551,
           45.0157408543757,
           45.05613631917589,
           45.096531783976076,
           45.13692724877626,
           45.177322713576444,
           45.21771817837663,
           45.25811364317681,
           45.298509107977004,
           45.33890457277719,
           45.37930003757737,
           45.42069236786909,
           45.4622840713209,
           45.50387577477271,
           45.54546747822452,
           45.587059181676324,
           45.62865088512813,
           45.67024258857994,
           45.71183429203175,
           45.75342599548355,
           45.79501769893537,
           45.836609402387175,
           45.87820110583899,
           45.9197928092908,
           45.961384512742605,
           46.00297621619441,
           46.04456791964621,
           46.08615962309803,
           46.12775132654984,
           46.16934303000164,
           46.210934733453456,
           46.252526436905256,
           46.29411814035707,
           46.33570984380888,
           46.377301547260686,
           46.4188932507125,
           46.4604849541643,
           46.502076657616115,
           46.54366836106792,
           46.58526006451973,
           46.626851767971544,
           46.668443471423345,
           46.71003517487516,
           46.75162687832697,
           46.79321858177877,
           46.83481028523059,
           46.87640198868239,
           46.9179936921342,
           46.959585395586004,
           47.00117709903781,
           47.042768802489626,
           47.08436050594143,
           47.12595220939324,
           47.16754391284505,
           47.209135616296855,
           47.25072731974866,
           47.29231902320048,
           47.333910726652284,
           47.37550243010409,
           47.4170941335559,
           47.45868583700771,
           47.500277540459514,
           47.54186924391132,
           47.583460947363136,
           47.625052650814936,
           47.66664435426675,
           47.70823605771856,
           47.74982776117037,
           47.79327862605025,
           47.83765907164417,
           47.88203951723809,
           47.92641996283201,
           47.970800408425916,
           48.01518085401984,
           48.05956129961376,
           48.10394174520768,
           48.14832219080159,
           48.19270263639551,
           48.237083081989425,
           48.28146352758335,
           48.325843973177264,
           48.37022441877119,
           48.4146048643651,
           48.45898530995902,
           48.50336575555294,
           48.547746201146865,
           48.59212664674077,
           48.63650709233469,
           48.680887537928605,
           48.72526798352253,
           48.769648429116444,
           48.81402887471036,
           48.858409320304276,
           48.9027897658982,
           48.94717021149212,
           48.99155065708603,
           49.035931102679946,
           49.08031154827387,
           49.124691993867785,
           49.1690724394617,
           49.213452885055624,
           49.25783333064953,
           49.302213776243455,
           49.34659422183738,
           49.390974667431294,
           49.43535511302521,
           49.479735558619126,
           49.52411600421304,
           49.56849644980696,
           49.61287689540088,
           49.6572573409948,
           49.70163778658871,
           49.74601823218264,
           49.79039867777656,
           49.83477912337047,
           49.87915956896438,
           49.9235400145583,
           49.96792046015222,
           50.01230090574614,
           50.05668135134005,
           50.10106179693397,
           50.14544224252789,
           50.189822688121815,
           50.23420313371573,
           50.278583579309654,
           50.32296402490357,
           50.367344470497486,
           50.4117249160914,
           50.45610536168532,
           50.50048580727923,
           50.544866252873156,
           50.58924669846707,
           50.63362714406098,
           50.678007589654904,
           50.722410059001575,
           50.76688961153191,
           50.81136916406222,
           50.85584871659256,
           50.90032826912288,
           50.94480782165321,
           50.98928737418354,
           51.03376692671387,
           51.0782464792442,
           51.12272603177452,
           51.167205584304845,
           51.21168513683518,
           51.2561646893655,
           51.30064424189583,
           51.34512379442616,
           51.38960334695649,
           51.43408289948682,
           51.46416080208959,
           51.4798370547648,
           51.49551330744002,
           51.511189560115234,
           51.52686581279045,
           51.54254206546567,
           51.55821831814088,
           51.573894570816094,
           51.589570823491314,
           51.60524707616653,
           51.62092332884174,
           51.636599581516954,
           51.652275834192174,
           51.66795208686739,
           51.6836283395426,
           51.699304592217814,
           51.7227709934458,
           51.747913747129296,
           51.7730565008128,
           51.79819925449631,
           51.82334200817981,
           51.84848476186331,
           51.87362751554681,
           51.89877026923031,
           51.923913022913815,
           51.94905577659732,
           51.97419853028082,
           51.99934128396433,
           52.024484037647824,
           52.04962679133133,
           52.07476954501483,
           52.099912298698335,
           52.12505505238184,
           52.150197806065336,
           52.17534055974885,
           52.20048331343235,
           52.22562606711584,
           52.25076882079935,
           52.275911574482855,
           52.30105432816635,
           52.326197081849855,
           52.35133983553336,
           52.37648258921686,
           52.40162534290036,
           52.42676809658388,
           52.45191085026737,
           52.47705360395088,
           52.502196357634375,
           52.527339111317886,
           52.55248186500138,
           52.577624618684894,
           52.60276737236839,
           52.627910126051894,
           52.6530528797354,
           52.6781956334189,
           52.70333838710239,
           52.7284811407859,
           52.75362389446941,
           52.77876664815291,
           52.803909401836414,
           52.82905215551992,
           52.85419490920342,
           52.879337662886925,
           52.90448041657042,
           52.92962317025392,
           52.95476592393743,
           52.979908677620934,
           53.00505143130443,
           53.03019418498793,
           53.05533693867144,
           53.08047969235494,
           53.10562244603844,
           53.130765199721935,
           53.155907953405446,
           53.18105070708894,
           53.206193460772454,
           53.23133621445596,
           53.256478968139454,
           53.28162172182296,
           53.30676447550647,
           53.331907229189966,
           53.35704998287346,
           53.382192736556966,
           53.25477180378832,
           52.82222349811554,
           52.389675192442766,
           51.95712688676994,
           51.52457858109716,
           51.09203027542438,
           50.65948196975155,
           50.22693366407874,
           49.794385358406,
           49.36183705273318,
           48.929288747060355,
           48.49674044138757,
           48.06419213571479,
           47.63164383004198,
           47.19909552436919,
           46.76654721869642,
           46.33399891302359,
           45.90145060735081,
           45.468902301678035,
           45.03635399600521,
           44.60380569033239,
           44.17125738465961,
           43.73870907898683,
           43.30616077331401,
           42.87361246764122,
           42.44106416196844,
           42.008515856295624,
           41.57596755062284,
           41.14341924495007,
           40.71087093927724,
           40.278322633604425,
           39.845774327931686,
           39.41322602225886,
           38.980677716586044,
           38.54812941091326,
           38.11558110524048,
           37.683032799567656,
           37.25213811586231,
           36.829511537460654,
           36.40688495905896,
           35.9842583806573,
           35.56163180225564,
           35.13900522385395,
           34.71637864545225,
           34.29375206705059,
           33.871125488648936,
           33.44849891024724,
           33.025872331845584,
           32.60324575344393,
           32.18061917504223,
           31.757992596640577,
           31.335366018238922,
           30.912739439837225,
           30.490112861435527,
           30.06748628303391,
           29.644859704632214,
           29.222233126230517,
           28.799606547828862,
           28.376979969427204,
           27.95435339102551,
           27.53172681262385,
           27.109100234222197,
           26.6864736558205,
           26.263847077418845,
           25.841220499017183,
           25.418593920615493,
           24.995967342213795,
           24.573340763812176,
           24.15071418541048,
           23.72808760700878,
           23.305461028607127,
           22.882834450205472,
           22.460207871803775,
           22.03758129340212,
           21.614954715000458,
           21.192328136598768,
           20.76970155819707,
           20.34707497979545,
           19.924448401393757,
           19.50182182299206,
           19.0791952445904,
           18.656568666188747,
           18.23394208778705,
           17.84849043377545,
           17.648913401713838,
           17.44933636965223,
           17.249759337590618,
           17.05018230552905,
           16.85060527346744,
           16.651028241405832,
           16.451451209344256,
           16.251874177282648,
           16.05229714522104,
           15.852720113159467,
           15.65314308109786,
           15.453566049036251,
           15.25398901697464,
           15.054411984913065,
           14.85483495285146,
           14.655257920789849,
           14.455680888728278,
           14.256103856666668,
           14.05652682460506,
           13.856949792543487,
           13.657372760481877,
           13.457795728420269,
           13.25564628416921,
           13.049223853604062,
           12.842801423038912,
           12.636378992473764,
           12.429956561908654,
           12.223534131343506,
           12.017111700778358,
           11.810689270213249,
           11.6042668396481,
           11.397844409082952,
           11.191421978517845,
           10.984999547952693,
           10.778577117387545,
           10.572154686822396,
           10.365732256257287,
           10.15930982569214,
           9.95288739512699,
           9.74646496456188,
           9.540042533996733,
           9.394603484039502,
           9.292723991659358,
           9.190844499279194,
           9.088965006899032,
           8.987085514518887,
           8.885206022138723,
           8.783326529758561,
           8.681447037378398,
           8.579567544998254,
           8.47768805261809,
           8.375808560237926,
           8.273929067857782,
           8.17204957547762,
           8.070170083097455,
           7.968290590717313,
           7.866411098337149,
           7.764531605956986,
           7.662652113576822,
           7.560772621196679,
           7.462641764729849,
           7.365502103658482,
           7.268362442587133,
           7.171222781515766,
           7.074083120444398,
           6.97694345937305,
           6.879803798301684,
           6.7826641372303165,
           6.685524476158968,
           6.588384815087601,
           6.491245154016234,
           6.394105492944868,
           6.2969658318735195,
           6.199826170802153,
           6.102686509730786,
           6.005546848659437,
           5.90840718758807,
           5.811267526516703,
           5.714127865445354,
           5.616988204373988,
           5.51984854330262,
           5.4227088822312535,
           5.325569221159905
          ],
          [
           41.01158154354523,
           41.05504633036243,
           41.09851111717962,
           41.141975903996816,
           41.18544069081402,
           41.22890547763121,
           41.2723702644484,
           41.315835051265594,
           41.3592998380828,
           41.402764624899994,
           41.44704171261673,
           41.49213110083675,
           41.53722048905677,
           41.58230987727679,
           41.62739926549681,
           41.67248865371683,
           41.717578041936854,
           41.762667430156874,
           41.807756818376895,
           41.852846206596915,
           41.89793559481694,
           41.943024983036956,
           41.98811437125698,
           42.033203759477004,
           42.07829314769702,
           42.123382535917045,
           42.168471924137066,
           42.213561312357086,
           42.25865070057711,
           42.30374008879713,
           42.34882947701715,
           42.39391886523717,
           42.43900825345719,
           42.48409764167721,
           42.52918702989724,
           42.57427641811726,
           42.61936580633728,
           42.6644551945573,
           42.70954458277732,
           42.75463397099734,
           42.79972335921736,
           42.84481274743738,
           42.8899021356574,
           42.93499152387743,
           42.98008091209745,
           43.02517030031746,
           43.07025968853749,
           43.11534907675751,
           43.160438464977524,
           43.20552785319755,
           43.25061724141757,
           43.29570662963759,
           43.34079601785761,
           43.385885406077634,
           43.430974794297654,
           43.476064182517675,
           43.5211535707377,
           43.566242958957716,
           43.611332347177736,
           43.656421735397764,
           43.70151112361778,
           43.746600511837805,
           43.791689900057825,
           43.83677928827784,
           43.88186867649787,
           43.92695806471789,
           43.97204745293791,
           44.017136841157935,
           44.062226229377956,
           44.107315617597976,
           44.152405005818,
           44.19749439403802,
           44.24258378225804,
           44.28767317047806,
           44.33276255869808,
           44.3778519469181,
           44.42294133513812,
           44.46803072335814,
           44.51312011157816,
           44.55820949979818,
           44.60329888801821,
           44.64838827623822,
           44.69347766445824,
           44.73856705267827,
           44.77974483804843,
           44.820140302848614,
           44.8605357676488,
           44.90093123244899,
           44.941326697249174,
           44.98172216204936,
           45.022117626849536,
           45.062513091649734,
           45.10290855644991,
           45.143702767613206,
           45.18529447106501,
           45.22688617451682,
           45.26847787796863,
           45.31006958142044,
           45.35166128487224,
           45.39325298832405,
           45.434844691775865,
           45.47643639522767,
           45.51802809867948,
           45.55961980213129,
           45.601211505583095,
           45.642803209034895,
           45.68439491248671,
           45.725986615938524,
           45.76757831939033,
           45.80917002284214,
           45.850761726293946,
           45.892353429745754,
           45.933945133197554,
           45.97553683664937,
           46.017128540101176,
           46.05872024355298,
           46.1003119470048,
           46.1419036504566,
           46.18349535390841,
           46.22508705736021,
           46.26667876081203,
           46.30827046426384,
           46.34986216771564,
           46.39145387116746,
           46.433045574619264,
           46.47463727807107,
           46.51622898152288,
           46.557820684974686,
           46.5994123884265,
           46.6410040918783,
           46.682595795330116,
           46.72418749878192,
           46.76577920223373,
           46.80737090568554,
           46.848962609137345,
           46.89055431258916,
           46.93214601604096,
           46.973737719492775,
           47.01532942294458,
           47.05692112639639,
           47.0985128298482,
           47.140104533300004,
           47.18169623675182,
           47.223287940203626,
           47.26487964365543,
           47.306471347107234,
           47.34806305055904,
           47.389654754010856,
           47.43124645746266,
           47.47283816091448,
           47.514429864366285,
           47.55602156781809,
           47.5976132712699,
           47.63920497472171,
           47.68079667817352,
           47.72238838162533,
           47.76398008507714,
           47.80557178852894,
           47.84716349198075,
           47.88875519543256,
           47.93034689888437,
           47.97193860233618,
           48.01353030578798,
           48.055122009239795,
           48.0967137126916,
           48.13830541614341,
           48.17989711959522,
           48.223347984475105,
           48.26772843006902,
           48.312108875662936,
           48.35648932125685,
           48.400869766850775,
           48.44525021244469,
           48.48963065803861,
           48.53401110363252,
           48.578391549226446,
           48.62277199482036,
           48.667152440414284,
           48.7115328860082,
           48.755913331602116,
           48.80029377719603,
           48.844674222789955,
           48.88905466838387,
           48.93343511397779,
           48.97781555957171,
           49.022196005165625,
           49.06657645075954,
           49.11095689635345,
           49.15533734194738,
           49.19971778754129,
           49.24409823313521,
           49.28851722034639,
           49.332996772876726,
           49.37747632540706,
           49.42195587793738,
           49.46643543046771,
           49.51091498299804,
           49.555394535528364,
           49.59987408805869,
           49.64435364058902,
           49.68883319311935,
           49.73331274564967,
           49.777792298179996,
           49.82227185071033,
           49.866751403240656,
           49.91123095577098,
           49.955710508301316,
           50.00019006083164,
           50.04466961336197,
           50.089149165892294,
           50.13362871842263,
           50.178108270952954,
           50.22258782348328,
           50.26706737601361,
           50.31154692854394,
           50.35602648107426,
           50.40050603360459,
           50.44498558613492,
           50.489465138665246,
           50.53394469119558,
           50.578424243725905,
           50.62290379625624,
           50.667383348786565,
           50.711862901316884,
           50.75634245384721,
           50.800822006377544,
           50.84530155890788,
           50.8897811114382,
           50.934260663968516,
           50.97874021649885,
           51.02321976902918,
           51.0676993215595,
           51.112178874089835,
           51.15665842662016,
           51.20113797915049,
           51.24561753168082,
           51.29009708421114,
           51.334576636741474,
           51.3790561892718,
           51.423535741802134,
           51.46801529433246,
           51.512494846862786,
           51.55697439939311,
           51.60145395192344,
           51.645933504453765,
           51.69041305698409,
           51.73489260951442,
           51.77937216204475,
           51.823851714575085,
           51.868331267105404,
           51.898409169708174,
           51.914085422383394,
           51.92976167505861,
           51.94543792773382,
           51.961114180409034,
           51.976790433084254,
           51.99246668575947,
           52.00814293843468,
           52.0238191911099,
           52.039495443785114,
           52.05517169646033,
           52.07084794913555,
           52.08652420181076,
           52.102200454485974,
           52.11787670716119,
           52.13355295983641,
           52.14922921251162,
           52.164905465186834,
           52.180581717862054,
           52.19625797053727,
           52.21193422321249,
           52.22761047588771,
           52.243286728562914,
           52.25896298123813,
           52.27463923391335,
           52.29031548658856,
           52.305991739263774,
           52.321667991938995,
           52.33734424461421,
           52.35302049728943,
           52.36869674996464,
           52.38437300263986,
           52.40004925531507,
           52.41572550799028,
           52.4314017606655,
           52.447078013340715,
           52.462754266015935,
           52.47843051869115,
           52.49410677136637,
           52.50978302404158,
           52.5254592767168,
           52.541135529392015,
           52.55681178206722,
           52.57248803474245,
           52.58816428741766,
           52.60384054009287,
           52.61951679276808,
           52.63519304544331,
           52.65086929811852,
           52.666545550793735,
           52.682221803468956,
           52.69789805614416,
           52.71357430881938,
           52.72925056149459,
           52.74492681416981,
           52.763364148431606,
           52.7885069021151,
           52.8136496557986,
           52.83879240948211,
           52.86393516316562,
           52.88907791684911,
           52.914220670532615,
           52.939363424216126,
           52.96450617789963,
           52.989648931583126,
           53.01479168526662,
           53.03993443895013,
           53.06507719263364,
           53.090219946317134,
           53.11536270000064,
           53.14050545368414,
           53.165648207367646,
           53.19079096105114,
           53.215933714734646,
           53.24107646841816,
           53.266219222101654,
           53.29136197578515,
           53.31650472946866,
           53.34164748315216,
           53.36679023683566,
           53.391932990519166,
           53.41707574420266,
           53.44221849788617,
           53.31479756511752,
           52.88224925944474,
           52.449700953771966,
           52.01715264809914,
           51.58460434242636,
           51.15205603675358,
           50.71950773108076,
           50.28695942540794,
           49.854411119735204,
           49.42186281406238,
           48.989314508389555,
           48.55676620271677,
           48.124217897044,
           47.69166959137118,
           47.2591212856984,
           46.82657298002562,
           46.3940246743528,
           45.96147636868001,
           45.528928063007235,
           45.09637975733442,
           44.66383145166159,
           44.231283145988805,
           43.79873484031603,
           43.366186534643205,
           42.93363822897042,
           42.50108992329765,
           42.06854161762483,
           41.63599331195205,
           41.20344500627927,
           40.77089670060644,
           40.33834839493363,
           39.905800089260886,
           39.47325178358807,
           39.040703477915244,
           38.60815517224246,
           38.17560686656969,
           37.74305856089686,
           37.31051025522408,
           36.877961949551306,
           36.44541364387848,
           36.0128653382057,
           35.58031703253292,
           35.14776872686009,
           34.71522042118728,
           34.282672115514494,
           33.85012380984172,
           33.417575504168894,
           32.98502719849611,
           32.55247889282334,
           32.11993058715051,
           31.68738228147773,
           31.254833975804956,
           30.822285670132132,
           30.389737364459315,
           29.95718905878657,
           29.52464075311375,
           29.092092447440933,
           28.659544141768144,
           28.22699583609537,
           27.79444753042255,
           27.361899224749767,
           26.929350919076985,
           26.496802613404167,
           26.06425430773138,
           25.631706002058607,
           25.199157696385782,
           24.766609390712965,
           24.343728406907182,
           23.921101828505485,
           23.49847525010379,
           23.075848671702133,
           22.653222093300478,
           22.23059551489878,
           21.807968936497126,
           21.385342358095468,
           20.962715779693774,
           20.540089201292076,
           20.117462622890457,
           19.694836044488763,
           19.272209466087066,
           18.84958288768541,
           18.426956309283753,
           18.004329730882056,
           17.618878076870452,
           17.419301044808844,
           17.219724012747236,
           17.02014698068563,
           16.820569948624055,
           16.620992916562443,
           16.421415884500835,
           16.221838852439262,
           16.022261820377654,
           15.822684788316046,
           15.623107756254473,
           15.423530724192863,
           15.223953692131255,
           15.024376660069645,
           14.824799628008073,
           14.625222595946465,
           14.425645563884856,
           14.226068531823282,
           14.026491499761674,
           13.826914467700064,
           13.627337435638493,
           13.427760403576883,
           13.228183371515273,
           13.028606339453702,
           12.829029307392094,
           12.629452275330483,
           12.429875243268874,
           12.230298211207302,
           12.030721179145694,
           11.831144147084084,
           11.631567115022511,
           11.431990082960903,
           11.232413050899293,
           11.03283601883772,
           10.833258986776114,
           10.633681954714506,
           10.434104922652896,
           10.234527890591322,
           10.034950858529712,
           9.835373826468105,
           9.63579679440653,
           9.43296926487571,
           9.28753021491848,
           9.18892984453846,
           9.091790183467095,
           8.994650522395727,
           8.89751086132438,
           8.800371200253013,
           8.703231539181646,
           8.606091878110279,
           8.50895221703893,
           8.411812555967563,
           8.314672894896196,
           8.217533233824847,
           8.12039357275348,
           8.023253911682113,
           7.926114250610765,
           7.828974589539397,
           7.731834928468031,
           7.634695267396664,
           7.537555606325315,
           7.44041594525395,
           7.343276284182582,
           7.246136623111234,
           7.148996962039867,
           7.0518573009685,
           6.954717639897151,
           6.857577978825784,
           6.760438317754417,
           6.663298656683069,
           6.566158995611701,
           6.469019334540334,
           6.371879673468968,
           6.27474001239762,
           6.1776003513262525,
           6.080460690254886,
           5.9833210291835375,
           5.88618136811217,
           5.789041707040803,
           5.691902045969455,
           5.594762384898088,
           5.497622723826721,
           5.400483062755354,
           5.303343401684005
          ],
          [
           41.390038592531674,
           41.435127980751695,
           41.480217368971715,
           41.525306757191736,
           41.570396145411756,
           41.61548553363178,
           41.660574921851804,
           41.705664310071825,
           41.750753698291845,
           41.795843086511866,
           41.840932474731886,
           41.88602186295191,
           41.93111125117193,
           41.97620063939195,
           42.02129002761197,
           42.06637941583199,
           42.11146880405201,
           42.15655819227204,
           42.20164758049206,
           42.24673696871208,
           42.2918263569321,
           42.33691574515212,
           42.38200513337214,
           42.42709452159216,
           42.47218390981218,
           42.5172732980322,
           42.56236268625222,
           42.60745207447225,
           42.65254146269227,
           42.69763085091229,
           42.74272023913231,
           42.78780962735233,
           42.83289901557235,
           42.87798840379237,
           42.92307779201239,
           42.96816718023241,
           43.013256568452434,
           43.058345956672454,
           43.103435344892475,
           43.148524733112495,
           43.193614121332516,
           43.238703509552536,
           43.28379289777256,
           43.32888228599258,
           43.3739716742126,
           43.41906106243262,
           43.464150450652646,
           43.50923983887266,
           43.55432922709268,
           43.599418615312715,
           43.64450800353273,
           43.689597391752756,
           43.73468677997277,
           43.77977616819279,
           43.82486555641282,
           43.86995494463283,
           43.91504433285286,
           43.96013372107288,
           44.00522310929289,
           44.05031249751292,
           44.09540188573293,
           44.14049127395296,
           44.18558066217298,
           44.230670050393,
           44.27575943861302,
           44.32084882683304,
           44.36593821505307,
           44.41102760327309,
           44.45611699149311,
           44.50120637971313,
           44.54629576793315,
           44.59138515615317,
           44.63647454437319,
           44.681563932593214,
           44.72665332081324,
           44.77174270903326,
           44.816832097253275,
           44.863208867124804,
           44.90984311279467,
           44.956477358464525,
           45.00311160413439,
           45.04974584980425,
           45.09638009547411,
           45.143014341143974,
           45.18544646829879,
           45.2270381717506,
           45.26862987520241,
           45.310221578654215,
           45.35181328210602,
           45.39340498555784,
           45.43499668900964,
           45.47658839246145,
           45.51818009591325,
           45.559771799365066,
           45.60136350281688,
           45.64295520626868,
           45.684546909720495,
           45.726138613172296,
           45.76773031662411,
           45.809322020075925,
           45.850913723527725,
           45.89250542697954,
           45.93409713043135,
           45.975688833883154,
           46.017280537334955,
           46.05887224078677,
           46.100463944238584,
           46.142055647690384,
           46.1836473511422,
           46.225239054594,
           46.26683075804581,
           46.308422461497614,
           46.35001416494943,
           46.39160586840124,
           46.43319757185304,
           46.47478927530486,
           46.51638097875666,
           46.55797268220847,
           46.59956438566028,
           46.64115608911209,
           46.6827477925639,
           46.7243394960157,
           46.76593119946751,
           46.807522902919324,
           46.84911460637113,
           46.89070630982294,
           46.932298013274746,
           46.97388971672655,
           47.01548142017836,
           47.057073123630175,
           47.098664827081976,
           47.14025653053379,
           47.18184823398559,
           47.223439937437405,
           47.26503164088921,
           47.30662334434103,
           47.348215047792834,
           47.389806751244635,
           47.43139845469645,
           47.472990158148264,
           47.514581861600064,
           47.55617356505187,
           47.59776526850368,
           47.63935697195548,
           47.68094867540731,
           47.72254037885911,
           47.764132082310915,
           47.80572378576272,
           47.84731548921452,
           47.88890719266634,
           47.930498896118145,
           47.97209059956997,
           48.013682303021774,
           48.055274006473574,
           48.09686570992538,
           48.13845741337719,
           48.18004911682901,
           48.22164082028081,
           48.26323252373262,
           48.304824227184426,
           48.347101162986576,
           48.38972071452148,
           48.432340266056386,
           48.47495981759129,
           48.517579369126196,
           48.5601989206611,
           48.602818472196006,
           48.64705099408563,
           48.692090001152614,
           48.73712900821959,
           48.78216801528657,
           48.827207022353555,
           48.87224602942054,
           48.91728503648751,
           48.962324043554496,
           49.00736305062148,
           49.052402057688454,
           49.09744106475544,
           49.14248007182242,
           49.1875190788894,
           49.23255808595638,
           49.27759709302336,
           49.32244961519204,
           49.366929167722375,
           49.411408720252695,
           49.45588827278303,
           49.50036782531335,
           49.54484737784368,
           49.58932693037401,
           49.63380648290433,
           49.67828603543466,
           49.722765587964986,
           49.76724514049532,
           49.81172469302565,
           49.85620424555597,
           49.900683798086305,
           49.94516335061663,
           49.98964290314696,
           50.034122455677284,
           50.07860200820761,
           50.123081560737944,
           50.16756111326827,
           50.2120406657986,
           50.25652021832892,
           50.30099977085925,
           50.34547932338958,
           50.3899588759199,
           50.434438428450235,
           50.478917980980555,
           50.52339753351089,
           50.567877086041214,
           50.61235663857154,
           50.65683619110187,
           50.70131574363219,
           50.74579529616253,
           50.790274848692846,
           50.83475440122319,
           50.879233953753506,
           50.92371350628383,
           50.968193058814165,
           51.01267261134449,
           51.05715216387482,
           51.10163171640515,
           51.14611126893547,
           51.190590821465804,
           51.23507037399612,
           51.27954992652646,
           51.32402947905679,
           51.36850903158711,
           51.41298858411744,
           51.45746813664777,
           51.501947689178095,
           51.54642724170843,
           51.59090679423875,
           51.63538634676908,
           51.679865899299415,
           51.724345451829734,
           51.76882500436007,
           51.813304556890394,
           51.85778410942072,
           51.90226366195105,
           51.94674321448137,
           51.99122276701169,
           52.035702319542025,
           52.08018187207236,
           52.12466142460268,
           52.16914097713301,
           52.21362052966334,
           52.258100082193664,
           52.302579634724,
           52.33265753732676,
           52.34833379000198,
           52.364010042677194,
           52.37968629535241,
           52.39536254802762,
           52.41103880070284,
           52.42671505337806,
           52.442391306053274,
           52.45806755872849,
           52.47374381140371,
           52.48942006407892,
           52.505096316754134,
           52.520772569429354,
           52.53644882210457,
           52.55212507477978,
           52.567801327455,
           52.583477580130214,
           52.59915383280543,
           52.61483008548065,
           52.630506338155854,
           52.646182590831074,
           52.661858843506295,
           52.6775350961815,
           52.69321134885672,
           52.70888760153194,
           52.72456385420715,
           52.74024010688237,
           52.75591635955759,
           52.771592612232794,
           52.787268864908015,
           52.802945117583235,
           52.818621370258455,
           52.83429762293366,
           52.84997387560888,
           52.86565012828409,
           52.88132638095931,
           52.89700263363453,
           52.912678886309735,
           52.928355138984955,
           52.944031391660175,
           52.95970764433539,
           52.9753838970106,
           52.99106014968581,
           53.00673640236104,
           53.02241265503625,
           53.038088907711455,
           53.053765160386675,
           53.069441413061895,
           53.08511766573711,
           53.10079391841232,
           53.11647017108754,
           53.13214642376275,
           53.14782267643797,
           53.16349892911319,
           53.1791751817884,
           53.194851434463615,
           53.210527687138836,
           53.226203939814056,
           53.24188019248926,
           53.25755644516448,
           53.2732326978397,
           53.28890895051491,
           53.30458520319013,
           53.32026145586535,
           53.335937708540555,
           53.351613961215776,
           53.367290213890996,
           53.3829664665662,
           53.398642719241415,
           53.41431897191664,
           53.42999522459186,
           53.44567147726707,
           53.45422912945358,
           53.45709183730952,
           53.459954545165466,
           53.462817253021406,
           53.465679960877345,
           53.468542668733285,
           53.47140537658923,
           53.474268084445164,
           53.47713079230111,
           53.47999350015706,
           53.482856208013,
           53.338586972566375,
           52.900053850514794,
           52.461520728463206,
           52.0229876064116,
           51.584454484360016,
           51.14592136230843,
           50.70738824025681,
           50.26885511820519,
           49.83032199615365,
           49.393856025937815,
           48.96085511036972,
           48.527854194801655,
           48.09485327923359,
           47.66185236366549,
           47.22885144809743,
           46.79585053252936,
           46.362849616961256,
           45.9298487013932,
           45.49684778582514,
           45.06384687025704,
           44.63084595468894,
           44.19784503912087,
           43.764844123552805,
           43.33184320798471,
           42.89884229241664,
           42.46584137684859,
           42.03284046128048,
           41.59983954571242,
           41.166838630144355,
           40.733837714576254,
           40.30083679900816,
           39.86783588344012,
           39.434834967872035,
           39.00183405230393,
           38.56883313673587,
           38.1358322211678,
           37.7028313055997,
           37.269830390031636,
           36.83682947446358,
           36.40382855889548,
           35.97082764332741,
           35.53782672775935,
           35.10482581219125,
           34.67182489662315,
           34.238823981055084,
           33.805823065487026,
           33.372822149918925,
           32.93982123435086,
           32.5068203187828,
           32.07381940321469,
           31.640818487646634,
           31.207817572078575,
           30.77481665651047,
           30.34181574094237,
           29.908814825374346,
           29.475813909806245,
           29.04281299423814,
           28.609812078670082,
           28.17681116310202,
           27.743810247533915,
           27.310809331965856,
           26.877808416397794,
           26.44480750082969,
           26.01180658526163,
           25.578805669693566,
           25.145804754125464,
           24.712803838557363,
           24.27980292298934,
           23.84680200742124,
           23.413801091853138,
           22.980800176285076,
           22.547799260717014,
           22.114798345148913,
           21.681797429580847,
           21.248796514012785,
           20.815795598444684,
           20.382794682876586,
           19.94979376730856,
           19.51679285174046,
           19.08379193617236,
           18.650791020604295,
           18.217790105036233,
           17.78478918946813,
           17.392088368765183,
           17.200888022387527,
           17.009687676009875,
           16.81848732963222,
           16.6272869832546,
           16.436086636876944,
           16.24488629049929,
           16.053685944121675,
           15.860633566359894,
           15.662686522509073,
           15.46473947865829,
           15.266792434807472,
           15.068845390956652,
           14.870898347105834,
           14.672951303255052,
           14.475004259404233,
           14.277057215553416,
           14.07911017170263,
           13.881163127851813,
           13.683216084000993,
           13.48526904015021,
           13.287321996299392,
           13.089374952448575,
           12.891427908597791,
           12.693480864746972,
           12.495533820896153,
           12.297586777045334,
           12.09963973319455,
           11.901692689343733,
           11.703745645492914,
           11.505798601642132,
           11.307851557791313,
           11.109904513940494,
           10.911957470089712,
           10.714010426238891,
           10.516063382388072,
           10.318116338537253,
           10.120169294686471,
           9.922222250835652,
           9.724275206984831,
           9.52632816313405,
           9.328381119283232,
           9.189817679980036,
           9.093671101068004,
           8.997524522155953,
           8.9013779432439,
           8.805231364331867,
           8.709084785419815,
           8.612938206507764,
           8.516791627595712,
           8.42064504868368,
           8.324498469771628,
           8.228351890859576,
           8.132205311947542,
           8.03605873303549,
           7.939912154123439,
           7.843765575211406,
           7.747618996299355,
           7.651472417387303,
           7.555325838475253,
           7.45917925956322,
           7.363032680651168,
           7.266886101739116,
           7.170739522827082,
           7.074592943915031,
           6.978446365002979,
           6.882299786090947,
           6.786153207178894,
           6.690006628266843,
           6.593860049354809,
           6.497713470442758,
           6.401566891530707,
           6.305420312618655,
           6.209273733706622,
           6.11312715479457,
           6.016980575882518,
           5.92466739187849,
           5.832817582984902,
           5.740967774091311,
           5.649117965197738,
           5.557268156304149,
           5.465418347410559,
           5.3735685385169685,
           5.281718729623397
          ],
          [
           41.76161703378718,
           41.8067064220072,
           41.85179581022722,
           41.896885198447244,
           41.941974586667264,
           41.98706397488729,
           42.03215336310731,
           42.07724275132733,
           42.12233213954735,
           42.167421527767374,
           42.212510915987394,
           42.257600304207415,
           42.302689692427435,
           42.347779080647456,
           42.392868468867476,
           42.4379578570875,
           42.48304724530752,
           42.52813663352754,
           42.57322602174756,
           42.61831540996758,
           42.66340479818761,
           42.70849418640763,
           42.753583574627655,
           42.798672962847675,
           42.843762351067696,
           42.888851739287716,
           42.93394112750774,
           42.97903051572776,
           43.02411990394778,
           43.0692092921678,
           43.11429868038782,
           43.15938806860784,
           43.20447745682786,
           43.24956684504788,
           43.2946562332679,
           43.33974562148792,
           43.38483500970794,
           43.42992439792796,
           43.47501378614798,
           43.520103174368,
           43.565192562588024,
           43.610281950808044,
           43.655371339028065,
           43.70046072724809,
           43.74555011546811,
           43.79063950368814,
           43.83572889190816,
           43.880818280128175,
           43.925907668348195,
           43.97099705656822,
           44.01608644478824,
           44.061175833008264,
           44.106265221228284,
           44.151354609448305,
           44.19644399766833,
           44.241533385888346,
           44.28662277410837,
           44.33171216232839,
           44.37680155054841,
           44.421890938768435,
           44.467495280169935,
           44.514129525839806,
           44.560763771509656,
           44.60739801717952,
           44.654032262849384,
           44.70066650851925,
           44.74730075418911,
           44.79393499985897,
           44.84056924552883,
           44.88720349119869,
           44.933837736868554,
           44.98047198253842,
           45.027106228208275,
           45.07374047387814,
           45.120374719547996,
           45.16700896521786,
           45.213643210887724,
           45.26027745655759,
           45.306911702227445,
           45.35354594789731,
           45.40018019356717,
           45.44681443923703,
           45.49344868490689,
           45.54008293057675,
           45.58251505773157,
           45.62410676118338,
           45.665698464635184,
           45.70729016808699,
           45.7488818715388,
           45.790473574990614,
           45.832065278442414,
           45.87365698189423,
           45.915248685346036,
           45.95684038879784,
           45.99843209224966,
           46.04002379570146,
           46.08161549915327,
           46.12320720260508,
           46.16479890605689,
           46.2063906095087,
           46.2479823129605,
           46.28957401641232,
           46.331165719864124,
           46.37275742331593,
           46.41434912676773,
           46.45594083021955,
           46.49753253367136,
           46.53912423712316,
           46.580715940574976,
           46.622307644026776,
           46.66389934747859,
           46.7054910509304,
           46.747082754382205,
           46.78867445783402,
           46.83026616128582,
           46.871857864737635,
           46.91344956818944,
           46.95504127164124,
           46.99663297509306,
           47.038224678544864,
           47.07981638199668,
           47.121408085448486,
           47.16299978890029,
           47.2045914923521,
           47.24618319580391,
           47.287774899255716,
           47.32936660270752,
           47.37095830615934,
           47.41255000961114,
           47.454141713062945,
           47.49573341651476,
           47.53732511996657,
           47.578916823418375,
           47.62050852687018,
           47.66210023032199,
           47.7036919337738,
           47.745283637225604,
           47.78687534067742,
           47.828467044129226,
           47.87005874758104,
           47.91165045103284,
           47.953242154484656,
           47.99483385793646,
           48.03659686986666,
           48.07921642140157,
           48.121835972936466,
           48.16445552447137,
           48.207075076006284,
           48.24969462754118,
           48.292314179076094,
           48.33493373061099,
           48.377553282145904,
           48.4201728336808,
           48.46279238521571,
           48.50541193675061,
           48.54803148828552,
           48.59065103982042,
           48.63327059135533,
           48.67589014289023,
           48.71850969442514,
           48.76112924596004,
           48.80374879749495,
           48.846368349029845,
           48.88898790056476,
           48.931607452099655,
           48.97422700363457,
           49.016846555169465,
           49.0610790770591,
           49.106118084126074,
           49.15115709119305,
           49.19619609826003,
           49.241235105327014,
           49.286274112394,
           49.33131311946097,
           49.37635212652795,
           49.42139113359494,
           49.46643014066191,
           49.5114691477289,
           49.55650815479588,
           49.60154716186286,
           49.64658616892984,
           49.69162517599682,
           49.7366641830638,
           49.781703190130784,
           49.82674219719776,
           49.87178120426474,
           49.916820211331725,
           49.9618592183987,
           50.00689822546568,
           50.051937232532666,
           50.09697623959965,
           50.142015246666624,
           50.187054253733606,
           50.23209326080059,
           50.277132267867565,
           50.32217127493455,
           50.36721028200153,
           50.41224928906851,
           50.45728829613549,
           50.50232730320247,
           50.54736631026945,
           50.59240531733643,
           50.637444324403404,
           50.6824833314704,
           50.72752233853737,
           50.77256134560435,
           50.817600352671334,
           50.86263935973832,
           50.9076783668053,
           50.952717373872275,
           50.99775638093926,
           51.04279538800624,
           51.08783439507322,
           51.1328734021402,
           51.177912409207174,
           51.222951416274164,
           51.267990423341146,
           51.31302943040812,
           51.357961873902426,
           51.40244142643276,
           51.446920978963085,
           51.49140053149342,
           51.535880084023745,
           51.580359636554064,
           51.6248391890844,
           51.669318741614724,
           51.71379829414505,
           51.758277846675384,
           51.8027573992057,
           51.84723695173603,
           51.891716504266356,
           51.93619605679669,
           51.980675609327015,
           52.02515516185734,
           52.06963471438767,
           52.114114266918,
           52.15859381944833,
           52.203073371978654,
           52.24755292450899,
           52.292032477039314,
           52.33651202956964,
           52.380991582099966,
           52.425471134630286,
           52.469950687160626,
           52.51443023969095,
           52.55890979222127,
           52.603389344751605,
           52.647868897281924,
           52.69234844981226,
           52.73682800234259,
           52.766905904945354,
           52.78258215762057,
           52.79825841029579,
           52.81393466297101,
           52.829610915646214,
           52.845287168321434,
           52.86096342099664,
           52.87663967367186,
           52.89231592634708,
           52.907992179022294,
           52.923668431697514,
           52.93934468437273,
           52.95502093704795,
           52.970697189723154,
           52.986373442398374,
           53.00204969507359,
           53.0177259477488,
           53.03340220042402,
           53.049078453099234,
           53.064754705774455,
           53.08043095844967,
           53.09610721112488,
           53.111783463800094,
           53.127459716475315,
           53.143135969150535,
           53.15881222182575,
           53.17448847450096,
           53.19016472717618,
           53.20584097985139,
           53.22151723252661,
           53.23719348520182,
           53.25286973787704,
           53.268545990552255,
           53.284222243227475,
           53.28850871380756,
           53.2913714216635,
           53.294234129519445,
           53.297096837375385,
           53.299959545231324,
           53.30282225308727,
           53.3056849609432,
           53.30854766879916,
           53.31141037665509,
           53.314273084511036,
           53.31713579236698,
           53.31999850022292,
           53.32286120807886,
           53.3257239159348,
           53.32858662379075,
           53.33144933164668,
           53.334312039502635,
           53.33717474735857,
           53.340037455214514,
           53.34290016307045,
           53.3457628709264,
           53.34862557878234,
           53.351488286638286,
           53.35435099449422,
           53.357213702350165,
           53.360076410206105,
           53.362939118062044,
           53.365801825917984,
           53.36866453377393,
           53.37152724162987,
           53.37438994948582,
           53.37725265734176,
           53.380115365197696,
           53.382978073053636,
           53.385840780909575,
           53.38870348876553,
           53.39156619662146,
           53.39442890447741,
           53.39729161233335,
           53.40015432018929,
           53.40301702804523,
           53.405879735901166,
           53.40874244375711,
           53.41160515161306,
           53.41446785946899,
           53.41733056732494,
           53.42019327518088,
           53.42305598303682,
           53.425918690892765,
           53.28164945544614,
           52.84311633339456,
           52.40458321134298,
           51.966050089291365,
           51.527516967239784,
           51.0889838451882,
           50.650450723136586,
           50.21191760108496,
           49.773384479033425,
           49.3348513569818,
           48.89631823493018,
           48.457785112878604,
           48.019251990827016,
           47.5807188687754,
           47.142185746723825,
           46.70365262467224,
           46.26511950262062,
           45.82658638056904,
           45.38805325851746,
           44.94952013646584,
           44.51098701441421,
           44.07245389236264,
           43.63392077031105,
           43.195387648259434,
           42.75685452620786,
           42.31832140415627,
           41.879788282104656,
           41.441255160053075,
           41.002722038001494,
           40.56418891594988,
           40.125655793898254,
           39.687122671846716,
           39.2485895497951,
           38.810056427743476,
           38.37152330569189,
           37.932990183640314,
           37.4944570615887,
           37.05592393953711,
           36.61739081748553,
           36.17885769543391,
           35.74457783197029,
           35.311576916402224,
           34.878576000834116,
           34.445575085266015,
           34.012574169697956,
           33.57957325412989,
           33.14657233856179,
           32.713571422993724,
           32.280570507425665,
           31.84756959185756,
           31.4145686762895,
           30.98156776072144,
           30.548566845153335,
           30.115565929585234,
           29.682565014017214,
           29.24956409844911,
           28.81656318288101,
           28.383562267312946,
           27.950561351744884,
           27.517560436176783,
           27.08455952060872,
           26.65155860504066,
           26.21855768947256,
           25.785556773904496,
           25.352555858336434,
           24.919554942768332,
           24.486554027200228,
           24.053553111632205,
           23.620552196064104,
           23.187551280496002,
           22.754550364927944,
           22.32154944935988,
           21.888548533791777,
           21.45554761822371,
           21.022546702655653,
           20.58954578708755,
           20.15654487151945,
           19.723543955951428,
           19.290543040383323,
           18.857542124815225,
           18.42454120924716,
           17.9915402936791,
           17.558539378110996,
           17.165838557408048,
           16.974638211030392,
           16.78343786465274,
           16.592237518275084,
           16.401037171897467,
           16.20983682551981,
           16.018636479142156,
           15.82743613276454,
           15.636235786386884,
           15.44503544000923,
           15.253835093631611,
           15.06263474725396,
           14.871434400876304,
           14.680234054498648,
           14.48903370812103,
           14.297833361743374,
           14.10663301536572,
           13.915432668988101,
           13.724232322610447,
           13.533031976232794,
           13.341831629855175,
           13.150631283477521,
           12.959430937099867,
           12.768230590722247,
           12.577030244344595,
           12.38582989796694,
           12.194629551589284,
           11.99889834175756,
           11.800951297906742,
           11.603004254055922,
           11.40505721020514,
           11.207110166354319,
           11.009163122503502,
           10.81121607865272,
           10.6132690348019,
           10.415321990951082,
           10.217374947100263,
           10.01942790324948,
           9.821480859398662,
           9.623533815547841,
           9.42558677169706,
           9.22763972784624,
           9.089076288543046,
           8.99292970963101,
           8.89678313071896,
           8.800636551806909,
           8.704489972894876,
           8.608343393982823,
           8.512196815070773,
           8.416050236158721,
           8.319903657246687,
           8.223757078334636,
           8.127610499422584,
           8.03146392051055,
           7.9353173415985,
           7.839170762686448,
           7.743024183774415,
           7.649004931672819,
           7.557155122779228,
           7.465305313885641,
           7.373455504992068,
           7.281605696098477,
           7.189755887204888,
           7.097906078311315,
           7.0060562694177255,
           6.914206460524136,
           6.822356651630562,
           6.730506842736974,
           6.6386570338433835,
           6.54680722494981,
           6.45495741605622,
           6.363107607162631,
           6.2712577982690405,
           6.179407989375468,
           6.087558180481879,
           5.995708371588289,
           5.903858562694715,
           5.812008753801125,
           5.720158944907536,
           5.628309136013963,
           5.536459327120373,
           5.444609518226783,
           5.352759709333194,
           5.260909900439621
          ],
          [
           42.13319547504271,
           42.17828486326274,
           42.22337425148276,
           42.26846363970277,
           42.3135530279228,
           42.358642416142814,
           42.40373180436284,
           42.44882119258286,
           42.49391058080288,
           42.53899996902291,
           42.584089357242924,
           42.629178745462944,
           42.674268133682965,
           42.719357521902985,
           42.76444691012301,
           42.809536298343026,
           42.854625686563054,
           42.899715074783074,
           42.944804463003095,
           42.989893851223115,
           43.034983239443136,
           43.08007262766316,
           43.12516201588318,
           43.1702514041032,
           43.21534079232322,
           43.26043018054324,
           43.30551956876326,
           43.35060895698328,
           43.3956983452033,
           43.44078773342332,
           43.48587712164334,
           43.53096650986337,
           43.57605589808339,
           43.62114528630341,
           43.66623467452344,
           43.71132406274346,
           43.75641345096348,
           43.8015028391835,
           43.84659222740352,
           43.89168161562354,
           43.93677100384356,
           43.98186039206358,
           44.0269497802836,
           44.07203916850362,
           44.11841593888495,
           44.165050184554815,
           44.21168443022468,
           44.258318675894536,
           44.30495292156439,
           44.35158716723426,
           44.39822141290412,
           44.444855658573985,
           44.49148990424384,
           44.5381241499137,
           44.58475839558356,
           44.63139264125343,
           44.67802688692329,
           44.724661132593155,
           44.771295378263005,
           44.81792962393287,
           44.86456386960273,
           44.9111981152726,
           44.95783236094246,
           45.00446660661232,
           45.051100852282175,
           45.09773509795204,
           45.144369343621904,
           45.19100358929177,
           45.23763783496163,
           45.28427208063149,
           45.330906326301346,
           45.37754057197121,
           45.424174817641074,
           45.47080906331094,
           45.517443308980795,
           45.56407755465066,
           45.610711800320516,
           45.65734604599038,
           45.703980291660244,
           45.7506145373301,
           45.79724878299996,
           45.84388302866982,
           45.890517274339686,
           45.93715152000955,
           45.97958364716436,
           46.021175350616176,
           46.062767054067976,
           46.10435875751979,
           46.14595046097159,
           46.187542164423405,
           46.229133867875206,
           46.27072557132702,
           46.31231727477883,
           46.353908978230635,
           46.39550068168245,
           46.43709238513425,
           46.478684088586064,
           46.52027579203787,
           46.561867495489686,
           46.60345919894149,
           46.6450509023933,
           46.68664260584511,
           46.728234309296916,
           46.76982601274872,
           46.81141771620053,
           46.85300941965234,
           46.89460112310415,
           46.93619282655595,
           46.97778453000776,
           47.019376233459575,
           47.06096793691138,
           47.1025596403632,
           47.144151343815,
           47.185743047266804,
           47.22733475071861,
           47.268926454170426,
           47.310518157622234,
           47.35210986107404,
           47.39370156452585,
           47.43529326797765,
           47.47688497142947,
           47.51847667488128,
           47.560068378333085,
           47.60166008178489,
           47.64325178523669,
           47.68484348868851,
           47.72643519214032,
           47.76871212828166,
           47.81133167981656,
           47.85395123135147,
           47.89657078288638,
           47.93919033442128,
           47.98180988595619,
           48.02442943749109,
           48.06704898902599,
           48.1096685405609,
           48.1522880920958,
           48.19490764363071,
           48.23752719516561,
           48.28014674670052,
           48.32276629823542,
           48.36538584977033,
           48.40800540130523,
           48.45062495284013,
           48.49324450437504,
           48.53586405590994,
           48.57848360744485,
           48.62110315897975,
           48.663722710514655,
           48.70634226204956,
           48.748961813584465,
           48.79158136511937,
           48.834200916654275,
           48.87682046818917,
           48.919440019724085,
           48.96205957125899,
           49.004679122793895,
           49.0472986743288,
           49.0899182258637,
           49.13253777739861,
           49.17515732893351,
           49.21777688046842,
           49.26039643200332,
           49.30301598353823,
           49.34563553507313,
           49.38825508660804,
           49.43087463814294,
           49.475107160032564,
           49.52014616709955,
           49.56518517416653,
           49.610224181233505,
           49.65526318830049,
           49.70030219536747,
           49.745341202434446,
           49.790380209501436,
           49.83541921656841,
           49.88045822363539,
           49.925497230702376,
           49.97053623776935,
           50.015575244836334,
           50.06061425190332,
           50.10565325897029,
           50.150692266037275,
           50.19573127310426,
           50.24077028017123,
           50.28580928723821,
           50.3308482943052,
           50.375887301372174,
           50.42092630843916,
           50.46596531550614,
           50.51100432257312,
           50.5560433296401,
           50.60108233670709,
           50.646121343774055,
           50.69116035084104,
           50.73619935790802,
           50.781238364974996,
           50.826277372041986,
           50.87131637910896,
           50.916355386175944,
           50.96139439324293,
           51.00643340030991,
           51.051472407376885,
           51.09651141444386,
           51.14155042151084,
           51.186589428577825,
           51.23162843564481,
           51.27666744271179,
           51.321706449778766,
           51.366745456845756,
           51.41178446391273,
           51.45682347097971,
           51.50186247804669,
           51.54690148511367,
           51.591940492180655,
           51.63697949924763,
           51.68201850631462,
           51.727057513381595,
           51.77209652044857,
           51.81713552751556,
           51.862174534582536,
           51.90721354164952,
           51.9522525487165,
           51.99729155578348,
           52.04233056285046,
           52.087369569917435,
           52.132408576984425,
           52.17744758405141,
           52.22248659111838,
           52.267525598185365,
           52.31256460525234,
           52.35760361231932,
           52.402642619386306,
           52.44768162645328,
           52.49272063352027,
           52.537759640587254,
           52.58279864765422,
           52.62783765472121,
           52.67287666178819,
           52.71791566885516,
           52.76295467592215,
           52.80799368298913,
           52.85303269005611,
           52.89807169712309,
           52.94311070419007,
           52.98814971125705,
           53.033214368301735,
           53.07836025117094,
           53.12350613404015,
           53.168652016909355,
           53.19034461537156,
           53.18858392942674,
           53.18682324348194,
           53.18506255753713,
           53.18330187159233,
           53.18154118564752,
           53.17978049970271,
           53.178019813757906,
           53.1762591278131,
           53.174498441868295,
           53.172737755923485,
           53.170977069978676,
           53.169216384033874,
           53.17145433171255,
           53.174317039568486,
           53.17717974742443,
           53.18004245528037,
           53.18290516313631,
           53.18576787099225,
           53.188630578848205,
           53.19149328670414,
           53.194355994560084,
           53.19721870241602,
           53.20008141027196,
           53.2029441181279,
           53.20580682598385,
           53.20866953383979,
           53.21153224169573,
           53.214394949551675,
           53.217257657407615,
           53.220120365263554,
           53.2229830731195,
           53.22584578097545,
           53.22870848883139,
           53.23157119668733,
           53.234433904543266,
           53.237296612399206,
           53.24015932025515,
           53.243022028111085,
           53.24588473596704,
           53.24874744382298,
           53.25161015167892,
           53.25447285953486,
           53.2573355673908,
           53.26019827524675,
           53.26306098310269,
           53.26592369095863,
           53.26878639881457,
           53.27164910667051,
           53.27451181452645,
           53.277374522382395,
           53.28023723023834,
           53.28309993809428,
           53.28596264595022,
           53.28882535380616,
           53.2916880616621,
           53.29455076951805,
           53.29741347737398,
           53.30027618522993,
           53.30313889308587,
           53.30600160094181,
           53.30886430879775,
           53.31172701665369,
           53.31458972450964,
           53.31745243236558,
           53.320315140221524,
           53.323177848077464,
           53.3260405559334,
           53.32890326378934,
           53.3317659716453,
           53.33462867950122,
           53.337491387357176,
           53.34035409521311,
           53.34321680306905,
           53.346079510924994,
           53.348942218780934,
           53.35180492663688,
           53.35466763449282,
           53.35753034234876,
           53.360393050204706,
           53.363255758060646,
           53.36611846591659,
           53.36898117377253,
           53.22471193832591,
           52.78617881627433,
           52.34764569422275,
           51.90911257217113,
           51.470579450119544,
           51.03204632806798,
           50.59351320601635,
           50.15498008396473,
           49.71644696191319,
           49.27791383986157,
           48.839380717809945,
           48.400847595758364,
           47.96231447370678,
           47.52378135165516,
           47.085248229603586,
           46.646715107552005,
           46.20818198550039,
           45.76964886344881,
           45.33111574139723,
           44.8925826193456,
           44.45404949729398,
           44.01551637524241,
           43.57698325319082,
           43.1384501311392,
           42.69991700908763,
           42.26138388703604,
           41.822850764984416,
           41.38431764293284,
           40.94578452088126,
           40.50725139882964,
           40.06871827677802,
           39.630185154726476,
           39.19165203267486,
           38.753118910623236,
           38.314585788571655,
           37.87605266652008,
           37.43751954446846,
           36.99898642241688,
           36.560453300365296,
           36.12192017831368,
           35.6833870562621,
           35.24485393421052,
           34.8063208121589,
           34.36778769010728,
           33.92925456805569,
           33.490721446004116,
           33.05218832395249,
           32.61365520190091,
           32.17512207984934,
           31.73658895779771,
           31.298055835746133,
           30.859522713694552,
           30.42098959164293,
           29.982456469591312,
           29.54392334753977,
           29.10539022548815,
           28.666857103436534,
           28.22832398138495,
           27.789790859333372,
           27.351257737281756,
           26.912724615230175,
           26.47419149317859,
           26.03565837112697,
           25.597125249075393,
           25.158592127023805,
           24.720059004972185,
           24.281525882920565,
           23.842992760869027,
           23.404459638817407,
           22.965926516765787,
           22.5283005535708,
           22.095299638002736,
           21.662298722434638,
           21.22929780686657,
           20.79629689129851,
           20.363295975730406,
           19.930295060162308,
           19.497294144594285,
           19.06429322902618,
           18.631292313458083,
           18.198291397890017,
           17.765290482321955,
           17.33228956675385,
           16.939588746050905,
           16.748388399673253,
           16.557188053295594,
           16.36598770691794,
           16.174787360540325,
           15.98358701416267,
           15.792386667785017,
           15.601186321407397,
           15.409985975029743,
           15.218785628652089,
           15.027585282274469,
           14.836384935896817,
           14.645184589519161,
           14.453984243141505,
           14.262783896763889,
           14.071583550386233,
           13.880383204008577,
           13.689182857630959,
           13.497982511253305,
           13.306782164875653,
           13.115581818498033,
           12.924381472120379,
           12.733181125742725,
           12.541980779365106,
           12.350780432987452,
           12.159580086609797,
           11.968379740232141,
           11.777179393854524,
           11.585979047476869,
           11.414584991722107,
           11.274575684270992,
           11.13456637681985,
           10.99455706936871,
           10.854547761917594,
           10.714538454466453,
           10.574529147015312,
           10.43451983956417,
           10.294510532113053,
           10.154501224661912,
           10.014491917210773,
           9.874482609759657,
           9.734473302308515,
           9.594463994857374,
           9.454454687406258,
           9.314445379955117,
           9.174436072503974,
           9.03442676505286,
           8.894417457601717,
           8.754408150150576,
           8.614398842699435,
           8.47438953524832,
           8.33438022779718,
           8.194370920346037,
           8.054361612894922,
           7.914352305443781,
           7.8118957202762065,
           7.720045911382633,
           7.628196102489043,
           7.536346293595453,
           7.444496484701865,
           7.352646675808291,
           7.260796866914703,
           7.1689470580211125,
           7.07709724912754,
           6.98524744023395,
           6.89339763134036,
           6.8015478224467865,
           6.709698013553197,
           6.617848204659607,
           6.525998395766035,
           6.434148586872444,
           6.342298777978854,
           6.250448969085266,
           6.158599160191692,
           6.066749351298103,
           5.974899542404513,
           5.883049733510941,
           5.7911999246173504,
           5.69935011572376,
           5.607500306830188,
           5.515650497936599,
           5.423800689043008,
           5.331950880149417,
           5.240101071255846
          ],
          [
           42.50477391629823,
           42.54986330451824,
           42.59495269273827,
           42.64004208095829,
           42.68513146917831,
           42.730220857398336,
           42.77531024561835,
           42.82039963383837,
           42.8654890220584,
           42.91057841027842,
           42.95566779849843,
           43.00075718671845,
           43.04584657493847,
           43.0909359631585,
           43.13602535137852,
           43.18111473959854,
           43.22620412781856,
           43.27129351603858,
           43.3163829042586,
           43.361472292478624,
           43.406561680698644,
           43.451651068918665,
           43.496740457138685,
           43.541829845358706,
           43.586919233578726,
           43.63200862179875,
           43.677098010018774,
           43.72270235193009,
           43.769336597599946,
           43.81597084326981,
           43.862605088939674,
           43.90923933460953,
           43.955873580279395,
           44.00250782594925,
           44.049142071619116,
           44.09577631728898,
           44.14241056295884,
           44.1890448086287,
           44.23567905429856,
           44.28231329996842,
           44.32894754563828,
           44.37558179130814,
           44.42221603697801,
           44.46885028264787,
           44.51548452831773,
           44.56211877398759,
           44.60875301965745,
           44.65538726532732,
           44.70202151099717,
           44.748655756667034,
           44.7952900023369,
           44.841924248006755,
           44.888558493676626,
           44.935192739346476,
           44.98182698501634,
           45.028461230686204,
           45.07509547635606,
           45.12172972202593,
           45.16836396769579,
           45.21499821336565,
           45.26163245903551,
           45.30826670470537,
           45.35490095037524,
           45.4015351960451,
           45.44816944171495,
           45.49480368738482,
           45.54143793305468,
           45.588072178724545,
           45.6347064243944,
           45.681340670064266,
           45.72797491573412,
           45.77460916140399,
           45.821243407073844,
           45.86787765274371,
           45.91451189841357,
           45.961146144083436,
           46.00778038975329,
           46.05441463542315,
           46.101048881093014,
           46.14768312676288,
           46.19431737243274,
           46.2409516181026,
           46.28758586377246,
           46.33422010944232,
           46.37665223659714,
           46.418243940048946,
           46.45983564350075,
           46.50142734695257,
           46.54301905040437,
           46.58461075385618,
           46.62620245730798,
           46.66779416075979,
           46.709385864211605,
           46.75097756766341,
           46.79256927111522,
           46.83416097456703,
           46.87575267801884,
           46.91734438147064,
           46.95893608492246,
           47.00052778837427,
           47.04211949182608,
           47.083711195277886,
           47.12530289872969,
           47.1668946021815,
           47.20848630563331,
           47.250078009085115,
           47.29166971253693,
           47.33326141598873,
           47.37485311944054,
           47.41644482289235,
           47.45820783516174,
           47.50082738669665,
           47.54344693823155,
           47.58606648976646,
           47.62868604130136,
           47.67130559283627,
           47.713925144371174,
           47.75654469590607,
           47.79916424744098,
           47.84178379897588,
           47.884403350510794,
           47.9270229020457,
           47.9696424535806,
           48.0122620051155,
           48.054881556650415,
           48.09750110818531,
           48.140120659720225,
           48.18274021125512,
           48.22535976279002,
           48.26797931432493,
           48.31059886585984,
           48.35321841739474,
           48.39583796892965,
           48.438457520464546,
           48.48107707199945,
           48.523696623534356,
           48.56631617506926,
           48.608935726604166,
           48.65155527813907,
           48.694174829673976,
           48.73679438120888,
           48.779413932743786,
           48.82203348427869,
           48.86465303581359,
           48.9072725873485,
           48.9498921388834,
           48.99251169041831,
           49.035131241953216,
           49.07775079348812,
           49.12037034502303,
           49.162989896557924,
           49.20560944809283,
           49.248228999627734,
           49.29084855116264,
           49.333468102697545,
           49.37608765423245,
           49.41870720576736,
           49.46132675730226,
           49.50394630883716,
           49.54656586037207,
           49.58918541190697,
           49.63180496344188,
           49.67442451497678,
           49.71704406651168,
           49.759663618046595,
           49.80228316958149,
           49.8449027211164,
           49.889135243006024,
           49.934174250073,
           49.97921325713998,
           50.024252264206964,
           50.06929127127395,
           50.11433027834093,
           50.15936928540791,
           50.20440829247489,
           50.24944729954187,
           50.294486306608846,
           50.339525313675836,
           50.38456432074281,
           50.429603327809794,
           50.474642334876776,
           50.51968134194375,
           50.56472034901074,
           50.60975935607772,
           50.65479836314469,
           50.699837370211675,
           50.74487637727866,
           50.78991538434563,
           50.83495439141262,
           50.8799933984796,
           50.92503240554658,
           50.970071412613564,
           51.01511041968054,
           51.06014942674752,
           51.10518843381449,
           51.150227440881494,
           51.19526644794847,
           51.240305455015445,
           51.28534446208242,
           51.3303834691494,
           51.375422476216386,
           51.42046148328337,
           51.465500490350344,
           51.51053949741733,
           51.55557850448431,
           51.600617511551285,
           51.64565651861827,
           51.69069552568524,
           51.73573453275223,
           51.78077353981921,
           51.82581254688619,
           51.87085155395317,
           51.91589056102015,
           51.96092956808713,
           52.005968575154114,
           52.05100758222109,
           52.09611071471552,
           52.14125659758473,
           52.186402480453935,
           52.23154836332314,
           52.27669424619235,
           52.321840129061556,
           52.366986011930756,
           52.41213189479997,
           52.45727777766918,
           52.50242366053838,
           52.54756954340759,
           52.5927154262768,
           52.637861309146004,
           52.683007192015204,
           52.72815307488441,
           52.773298957753624,
           52.818444840622824,
           52.86359072349203,
           52.90873660636124,
           52.953882489230445,
           52.99902837209966,
           53.044174254968866,
           53.089320137838065,
           53.13446602070728,
           53.17961190357648,
           53.224757786445686,
           53.2699036693149,
           53.31504955218411,
           53.36019543505331,
           53.40534131792252,
           53.45048720079173,
           53.495633083660934,
           53.54077896653014,
           53.58592484939935,
           53.607617447861536,
           53.60585676191674,
           53.60409607597193,
           53.60233539002712,
           53.60057470408232,
           53.59881401813751,
           53.5970533321927,
           53.59529264624789,
           53.59353196030308,
           53.59177127435827,
           53.59001058841347,
           53.58824990246866,
           53.58648921652385,
           53.58472853057904,
           53.58296784463424,
           53.58120715868943,
           53.57944647274463,
           53.57768578679982,
           53.57592510085502,
           53.57416441491021,
           53.5724037289654,
           53.57064304302059,
           53.568882357075786,
           53.56712167113098,
           53.565360985186175,
           53.56360029924136,
           53.561839613296556,
           53.560078927351746,
           53.55831824140694,
           53.55655755546213,
           53.55479686951733,
           53.553036183572516,
           53.55127549762771,
           53.5495148116829,
           53.547754125738095,
           53.54599343979329,
           53.544232753848476,
           53.542472067903674,
           53.54071138195887,
           53.538950696014055,
           53.53719001006925,
           53.53542932412444,
           53.533668638179634,
           53.53190795223483,
           53.53014726629002,
           53.52838658034521,
           53.52662589440041,
           53.524865208455594,
           53.52310452251079,
           53.52134383656599,
           53.51958315062118,
           53.51782246467637,
           53.516061778731554,
           53.51430109278675,
           53.51254040684195,
           53.51077972089714,
           53.50901903495233,
           53.50725834900753,
           53.50549766306273,
           53.50373697711791,
           53.50197629117311,
           53.500215605228306,
           53.49845491928349,
           53.49669423333868,
           53.494933547393885,
           53.49317286144907,
           53.491412175504266,
           53.489651489559456,
           53.487890803614654,
           53.486130117669845,
           53.48436943172503,
           53.482608745780226,
           53.480848059835424,
           53.47908737389061,
           53.477326687945805,
           53.475566002000996,
           53.45358131276441,
           53.4276131681853,
           53.401645023606186,
           53.37567687902707,
           53.34970873444796,
           53.32374058986884,
           53.29777244528972,
           53.13350827476351,
           52.69265205234324,
           52.25179582992298,
           51.810939607502675,
           51.37008338508241,
           50.92922716266215,
           50.488370940241836,
           50.047514717821535,
           49.606658495401305,
           49.165802272981004,
           48.72546494802769,
           48.28640962224655,
           47.84735429646541,
           47.408298970684235,
           46.96924364490309,
           46.530188319121955,
           46.091132993340764,
           45.65207766755964,
           45.2130223417785,
           44.77396701599732,
           44.33491169021614,
           43.895856364435,
           43.456801038653865,
           43.01774571287268,
           42.57869038709154,
           42.1396350613104,
           41.700579735529224,
           41.26152440974809,
           40.82246908396695,
           40.38341375818576,
           39.94435843240459,
           39.50530310662349,
           39.06624778084232,
           38.627192455061135,
           38.18813712928,
           37.749081803498854,
           37.31002647771767,
           36.87097115193654,
           36.4319158261554,
           35.99286050037422,
           35.55380517459308,
           35.11474984881194,
           34.675694523030764,
           34.23663919724958,
           33.79758387146845,
           33.35852854568731,
           32.91947321990612,
           32.48041789412498,
           32.04136256834385,
           31.602307242562667,
           31.16325191678153,
           30.72419659100039,
           30.285141265219213,
           29.84608593943803,
           29.407030613656932,
           28.967975287875753,
           28.528919962094577,
           28.08986463631344,
           27.6508093105323,
           27.21175398475112,
           26.77269865896998,
           26.33364333318884,
           25.894588007407663,
           25.455532681626522,
           25.01647735584539,
           24.577422030064206,
           24.138366704283023,
           23.699311378501932,
           23.26025605272075,
           22.821200726939573,
           22.382145401158432,
           21.94309007537729,
           21.504034749596116,
           21.064979423814975,
           20.62592409803384,
           20.18686877225266,
           19.747813446471476,
           19.308758120690378,
           18.869702794909198,
           18.430647469128022,
           17.99159214334688,
           17.55253681756574,
           17.113481491784565,
           16.71715471173872,
           16.53447066036903,
           16.351786608999348,
           16.169102557629657,
           15.986418506260005,
           15.803734454890318,
           15.621050403520634,
           15.43836635215098,
           15.255682300781293,
           15.072998249411606,
           14.890314198041954,
           14.708791334639926,
           14.568782027188785,
           14.428772719737646,
           14.28876341228653,
           14.148754104835387,
           14.008744797384246,
           13.86873548993313,
           13.728726182481989,
           13.588716875030848,
           13.448707567579733,
           13.30869826012859,
           13.16868895267745,
           13.028679645226333,
           12.888670337775192,
           12.748661030324051,
           12.60865172287291,
           12.468642415421794,
           12.328633107970653,
           12.188623800519512,
           12.048614493068396,
           11.908605185617255,
           11.768595878166114,
           11.628586570714997,
           11.488577263263856,
           11.348567955812715,
           11.208558648361572,
           11.068549340910458,
           10.928540033459317,
           10.788530726008176,
           10.64852141855706,
           10.508512111105919,
           10.368502803654778,
           10.228493496203662,
           10.088484188752522,
           9.948474881301381,
           9.808465573850265,
           9.668456266399124,
           9.528446958947981,
           9.38843765149684,
           9.248428344045724,
           9.108419036594583,
           8.968409729143442,
           8.828400421692326,
           8.688391114241186,
           8.548381806790044,
           8.408372499338927,
           8.268363191887786,
           8.128353884436645,
           7.988344576985504,
           7.848335269534389,
           7.708325962083248,
           7.568316654632107,
           7.428307347180991,
           7.28829803972985,
           7.148288732278709,
           7.0082794248275935,
           6.868270117376452,
           6.7282608099253105,
           6.588251502474195,
           6.448242195023054,
           6.308232887571913,
           6.175633953514626,
           6.088762181640108,
           6.001890409765576,
           5.915018637891044,
           5.828146866016527,
           5.7412750941419946,
           5.654403322267463,
           5.567531550392945,
           5.480659778518414,
           5.393788006643881,
           5.306916234769348,
           5.2200444628948315
          ],
          [
           42.876352357553735,
           42.921441745773755,
           42.96653113399378,
           43.011620522213796,
           43.05670991043382,
           43.101799298653845,
           43.146888686873865,
           43.191978075093886,
           43.237067463313906,
           43.28215685153393,
           43.32724623975395,
           43.373623010645076,
           43.42025725631494,
           43.466891501984804,
           43.51352574765466,
           43.560159993324525,
           43.60679423899439,
           43.65342848466425,
           43.70006273033412,
           43.74669697600397,
           43.79333122167383,
           43.839965467343696,
           43.88659971301356,
           43.93323395868342,
           43.97986820435328,
           44.02650245002314,
           44.073136695693,
           44.119770941362866,
           44.16640518703272,
           44.21303943270258,
           44.259673678372444,
           44.30630792404231,
           44.35294216971217,
           44.39957641538203,
           44.44621066105189,
           44.49284490672176,
           44.539479152391614,
           44.58611339806148,
           44.632747643731335,
           44.6793818894012,
           44.726016135071056,
           44.77265038074092,
           44.819284626410784,
           44.86591887208065,
           44.912553117750505,
           44.95918736342036,
           45.005821609090226,
           45.05245585476009,
           45.099090100429954,
           45.14572434609981,
           45.19235859176967,
           45.23899283743953,
           45.2856270831094,
           45.33226132877925,
           45.378895574449125,
           45.425529820118975,
           45.472164065788846,
           45.5187983114587,
           45.56543255712857,
           45.61206680279843,
           45.65870104846828,
           45.70533529413815,
           45.75196953980801,
           45.798603785477866,
           45.84523803114774,
           45.8918722768176,
           45.93850652248746,
           45.985140768157315,
           46.03177501382718,
           46.07840925949704,
           46.12504350516691,
           46.171677750836764,
           46.21831199650663,
           46.264946242176485,
           46.31158048784635,
           46.35821473351621,
           46.40484897918607,
           46.451483224855934,
           46.49811747052579,
           46.544751716195655,
           46.59138596186552,
           46.63802020753538,
           46.68465445320524,
           46.731288698875105,
           46.773720826029916,
           46.81531252948172,
           46.85690423293353,
           46.89849593638534,
           46.94008763983715,
           46.98167934328896,
           47.02327104674076,
           47.064862750192574,
           47.10645445364438,
           47.148046157096196,
           47.19032309357672,
           47.23294264511163,
           47.27556219664653,
           47.31818174818144,
           47.36080129971634,
           47.40342085125125,
           47.44604040278615,
           47.48865995432105,
           47.53127950585596,
           47.57389905739087,
           47.61651860892577,
           47.65913816046067,
           47.701757711995576,
           47.74437726353048,
           47.786996815065386,
           47.82961636660029,
           47.872235918135196,
           47.91485546967011,
           47.957475021205006,
           48.00009457273992,
           48.042714124274816,
           48.08533367580973,
           48.12795322734463,
           48.17057277887953,
           48.21319233041444,
           48.25581188194934,
           48.298431433484254,
           48.34105098501915,
           48.38367053655405,
           48.42629008808896,
           48.468909639623874,
           48.51152919115877,
           48.554148742693684,
           48.59676829422858,
           48.63938784576348,
           48.68200739729839,
           48.7246269488333,
           48.7672465003682,
           48.80986605190311,
           48.852485603438005,
           48.89510515497291,
           48.937724706507815,
           48.98034425804272,
           49.022963809577625,
           49.06558336111253,
           49.10820291264744,
           49.15082246418234,
           49.19344201571724,
           49.23606156725215,
           49.27868111878705,
           49.32130067032196,
           49.36392022185686,
           49.40653977339177,
           49.449159324926676,
           49.49177887646158,
           49.534398427996486,
           49.57701797953139,
           49.619637531066296,
           49.662257082601194,
           49.7048766341361,
           49.747496185671004,
           49.79011573720591,
           49.832735288740814,
           49.87535484027572,
           49.917974391810624,
           49.96059394334553,
           50.003213494880434,
           50.04583304641534,
           50.088452597950244,
           50.13107214948515,
           50.17369170102005,
           50.21631125255495,
           50.25893080408986,
           50.30316332597948,
           50.348202333046466,
           50.39324134011344,
           50.438280347180424,
           50.483319354247406,
           50.52835836131439,
           50.57339736838137,
           50.61843637544834,
           50.66347538251533,
           50.70851438958231,
           50.753553396649295,
           50.79859240371626,
           50.84363141078325,
           50.888670417850236,
           50.93370942491721,
           50.978748431984194,
           51.023787439051176,
           51.06882644611816,
           51.11386545318514,
           51.1590070611293,
           51.2041529439985,
           51.249298826867715,
           51.29444470973692,
           51.33959059260613,
           51.38473647547534,
           51.42988235834454,
           51.47502824121375,
           51.520174124082956,
           51.56532000695216,
           51.61046588982137,
           51.65561177269058,
           51.700757655559784,
           51.74590353842899,
           51.7910494212982,
           51.836195304167404,
           51.88134118703661,
           51.92648706990582,
           51.971632952775025,
           52.01677883564423,
           52.06192471851344,
           52.10707060138264,
           52.15221648425185,
           52.19736236712106,
           52.242508249990266,
           52.28765413285947,
           52.33280001572868,
           52.377945898597886,
           52.42309178146709,
           52.4682376643363,
           52.51338354720551,
           52.558529430074714,
           52.60367531294392,
           52.64882119581313,
           52.693967078682334,
           52.73911296155154,
           52.78425884442075,
           52.829404727289955,
           52.87455061015916,
           52.91969649302837,
           52.964842375897575,
           53.009988258766775,
           53.05513414163599,
           53.100280024505196,
           53.1454259073744,
           53.19057179024361,
           53.235717673112816,
           53.28086355598202,
           53.32600943885123,
           53.37115532172044,
           53.416301204589644,
           53.46144708745885,
           53.506592970328064,
           53.551738853197264,
           53.59688473606648,
           53.64203061893568,
           53.687176501804885,
           53.73232238467409,
           53.7774682675433,
           53.822614150412505,
           53.867760033281705,
           53.91290591615092,
           53.95805179902013,
           54.00319768188934,
           54.02489028035153,
           54.023129594406726,
           54.021368908461916,
           54.019608222517114,
           54.017847536572305,
           54.0160868506275,
           54.014326164682686,
           54.012565478737876,
           54.010804792793074,
           54.009044106848265,
           54.00728342090346,
           54.00552273495865,
           54.003762049013844,
           54.00200136306904,
           54.00024067712423,
           53.99847999117942,
           53.99671930523461,
           53.99495861928981,
           53.993197933345,
           53.9914372474002,
           53.98967656145538,
           53.98791587551058,
           53.986155189565764,
           53.98439450362096,
           53.98263381767616,
           53.98087313173134,
           53.97911244578654,
           53.97735175984174,
           53.97559107389692,
           53.97383038795213,
           53.97206970200732,
           53.970309016062515,
           53.9685483301177,
           53.96678764417289,
           53.96502695822808,
           53.96326627228328,
           53.96150558633846,
           53.95974490039366,
           53.95798421444886,
           53.95622352850405,
           53.95446284255924,
           53.952702156614436,
           53.950941470669626,
           53.94918078472482,
           53.94742009878001,
           53.9456594128352,
           53.943898726890396,
           53.94213804094559,
           53.94037735500078,
           53.938616669055975,
           53.93685598311117,
           53.935095297166356,
           53.91265097411126,
           53.88668282953215,
           53.860714684953024,
           53.834746540373914,
           53.808778395794796,
           53.782810251215686,
           53.75684210663656,
           53.73087396205746,
           53.70490581747834,
           53.678937672899224,
           53.6529695283201,
           53.62700138374099,
           53.60103323916188,
           53.57506509458276,
           53.549096950003644,
           53.523128805424534,
           53.49716066084541,
           53.4711925162663,
           53.44522437168718,
           53.419256227108065,
           53.393288082528954,
           53.36731993794984,
           53.34135179337072,
           53.31538364879161,
           53.289415504212485,
           53.263447359633375,
           53.237479215054265,
           53.21151107047514,
           53.18554292589602,
           53.15957478131691,
           53.133606636737795,
           52.96934246621158,
           52.52848624379132,
           52.08763002137105,
           51.64677379895075,
           51.20591757653048,
           50.765061354110216,
           50.324205131689915,
           49.88334890926961,
           49.442492686849384,
           49.00163646442908,
           48.560780242008775,
           48.11992401958851,
           47.679067797168244,
           47.23821157474794,
           46.79735535232768,
           46.35649912990741,
           45.91564290748711,
           45.474786685066846,
           45.03393046264658,
           44.59307424022627,
           44.152218017805964,
           43.711361795385706,
           43.27050557296545,
           42.82964935054514,
           42.388793128124874,
           41.94793690570461,
           41.50708068328431,
           41.066224460864035,
           40.62536823844377,
           40.18451201602347,
           39.74365579360317,
           39.302799571182945,
           38.861943348762644,
           38.421087126342336,
           37.98023090392206,
           37.539374681501805,
           37.098518459081504,
           36.65766223666124,
           36.21680601424097,
           35.775949791820665,
           35.3350935694004,
           34.894237346980134,
           34.453610047536905,
           34.01455472175573,
           33.57549939597459,
           33.13644407019346,
           32.69738874441227,
           32.25833341863114,
           31.81927809285,
           31.38022276706882,
           30.941167441287682,
           30.50211211550654,
           30.063056789725366,
           29.624001463944182,
           29.184946138163085,
           28.745890812381905,
           28.306835486600725,
           27.86778016081959,
           27.42872483503845,
           26.98966950925727,
           26.55061418347613,
           26.11155885769499,
           25.67250353191382,
           25.233448206132675,
           24.794392880351538,
           24.355337554570358,
           23.91628222878918,
           23.47722690300808,
           23.0381715772269,
           22.59911625144572,
           22.16006092566458,
           21.721005599883444,
           21.281950274102265,
           20.842894948321128,
           20.403839622539987,
           19.96478429675881,
           19.525728970977624,
           19.08667364519653,
           18.647618319415347,
           18.208562993634175,
           17.769507667853034,
           17.33045234207189,
           16.891397016290718,
           16.495070236244867,
           16.31238618487518,
           16.129702133505496,
           15.947018082135807,
           15.764334030766156,
           15.58164997939647,
           15.398965928026783,
           15.216281876657128,
           15.033597825287444,
           14.85091377391776,
           14.668229722548105,
           14.485545671178418,
           14.30286161980873,
           14.120177568439047,
           13.937493517069392,
           13.754809465699706,
           13.572125414330019,
           13.389441362960367,
           13.20675731159068,
           13.024073260220993,
           12.841389208851341,
           12.658705157481656,
           12.476021106111968,
           12.293337054742315,
           12.110653003372628,
           11.927968952002942,
           11.745284900633255,
           11.562600849263601,
           11.379916797893916,
           11.197232746524232,
           11.014548695154579,
           10.860241875846311,
           10.720232568395172,
           10.580223260944056,
           10.440213953492913,
           10.300204646041772,
           10.16019533859063,
           10.020186031139513,
           9.880176723688374,
           9.740167416237233,
           9.600158108786117,
           9.460148801334975,
           9.320139493883834,
           9.180130186432718,
           9.040120878981575,
           8.900111571530434,
           8.76010226407932,
           8.620092956628179,
           8.480083649177038,
           8.340074341725897,
           8.20006503427478,
           8.06005572682364,
           7.920046419372499,
           7.806696275969379,
           7.719824504094847,
           7.632952732220313,
           7.5460809603457975,
           7.459209188471265,
           7.372337416596732,
           7.2854656447221995,
           7.198593872847683,
           7.111722100973151,
           7.024850329098618,
           6.937978557224102,
           6.85110678534957,
           6.764235013475037,
           6.677363241600521,
           6.590491469725988,
           6.503619697851455,
           6.416747925976939,
           6.329876154102406,
           6.243004382227873,
           6.1561326103533425,
           6.069260838478825,
           5.982389066604293,
           5.8955172947297605,
           5.808645522855244,
           5.721773750980711,
           5.6349019791061785,
           5.548030207231664,
           5.46115843535713,
           5.374286663482597,
           5.287414891608065,
           5.200543119733549
          ],
          [
           43.24338433259992,
           43.291446707592414,
           43.339509082584904,
           43.387571457577394,
           43.435633832569884,
           43.48369620756237,
           43.53175858255486,
           43.57886887253096,
           43.62550311820082,
           43.67213736387068,
           43.718771609540546,
           43.7654058552104,
           43.81204010088027,
           43.858674346550124,
           43.90530859221999,
           43.95194283788985,
           43.99857708355972,
           44.04521132922957,
           44.09184557489944,
           44.138479820569295,
           44.18511406623916,
           44.23174831190902,
           44.27838255757888,
           44.32501680324874,
           44.3716510489186,
           44.418285294588465,
           44.46491954025833,
           44.511553785928186,
           44.55818803159805,
           44.60482227726791,
           44.65145652293777,
           44.698090768607635,
           44.7447250142775,
           44.791359259947356,
           44.83799350561721,
           44.88462775128708,
           44.93126199695694,
           44.977896242626805,
           45.02453048829666,
           45.07116473396652,
           45.11779897963638,
           45.16443322530625,
           45.21106747097611,
           45.25770171664597,
           45.304335962315825,
           45.35097020798569,
           45.39760445365556,
           45.44423869932542,
           45.490872944995274,
           45.53750719066514,
           45.58414143633499,
           45.63077568200487,
           45.67740992767472,
           45.72404417334458,
           45.770678419014445,
           45.81731266468431,
           45.86394691035417,
           45.91058115602402,
           45.95721540169389,
           46.00384964736375,
           46.050483893033615,
           46.09711813870348,
           46.14375238437333,
           46.19038663004319,
           46.23702087571306,
           46.283655121382914,
           46.330289367052785,
           46.37692361272264,
           46.4235578583925,
           46.47019210406236,
           46.51682634973223,
           46.563460595402084,
           46.61009484107195,
           46.656729086741805,
           46.70336333241167,
           46.74999757808153,
           46.79663182375139,
           46.843266069421254,
           46.88990031509112,
           46.936534560760975,
           46.98316880643084,
           47.0298030521007,
           47.07643729777056,
           47.123071543440425,
           47.16707693513827,
           47.210556556041716,
           47.25403617694516,
           47.297515797848604,
           47.34099541875205,
           47.38447503965549,
           47.427524626596565,
           47.47014417813147,
           47.512763729666375,
           47.55538328120128,
           47.598002832736185,
           47.64062238427108,
           47.68324193580599,
           47.72586148734089,
           47.7684810388758,
           47.8111005904107,
           47.85372014194561,
           47.89633969348051,
           47.93895924501542,
           47.98157879655032,
           48.02419834808523,
           48.06681789962013,
           48.10943745115504,
           48.15205700268994,
           48.19467655422485,
           48.237296105759754,
           48.27991565729466,
           48.32253520882957,
           48.36515476036447,
           48.407774311899374,
           48.45039386343427,
           48.493013414969184,
           48.535632966504096,
           48.578252518038994,
           48.6208720695739,
           48.663491621108804,
           48.70611117264371,
           48.748730724178614,
           48.79135027571351,
           48.833969827248424,
           48.87658937878333,
           48.919208930318234,
           48.96182848185314,
           49.004448033388044,
           49.04706758492294,
           49.089687136457854,
           49.13230668799275,
           49.174926239527665,
           49.21754579106256,
           49.260165342597475,
           49.30278489413237,
           49.34540444566728,
           49.38802399720218,
           49.43064354873709,
           49.47326310027199,
           49.51588265180689,
           49.5585022033418,
           49.6011217548767,
           49.64374130641161,
           49.68636085794651,
           49.72898040948142,
           49.77159996101632,
           49.81421951255123,
           49.85683906408614,
           49.89945861562104,
           49.94207816715595,
           49.98469771869085,
           50.02731727022575,
           50.069936821760656,
           50.11255637329556,
           50.155175924830466,
           50.19779547636537,
           50.24041502790027,
           50.283034579435174,
           50.32565413097008,
           50.368273682504984,
           50.41089323403989,
           50.453512785574794,
           50.4961323371097,
           50.538751888644605,
           50.58137144017951,
           50.62399099171442,
           50.66661054324932,
           50.71115759537482,
           50.756668397795615,
           50.802179200216415,
           50.84769000263721,
           50.893200805058,
           50.9387116074788,
           50.984222409899594,
           51.029733212320394,
           51.07524401474119,
           51.12075481716198,
           51.16626561958278,
           51.21177642200358,
           51.25728722442437,
           51.30279802684517,
           51.34830882926596,
           51.39381963168676,
           51.43933043410755,
           51.484841236528354,
           51.53035203894915,
           51.57586284136995,
           51.62137364379074,
           51.666571659357714,
           51.71171754222692,
           51.75686342509613,
           51.802009307965335,
           51.84715519083454,
           51.89230107370375,
           51.937446956572956,
           51.98259283944218,
           52.02773872231137,
           52.072884605180576,
           52.11803048804978,
           52.16317637091899,
           52.2083222537882,
           52.2534681366574,
           52.29861401952661,
           52.34375990239582,
           52.388905785265024,
           52.43405166813423,
           52.47919755100344,
           52.524343433872644,
           52.56948931674185,
           52.61463519961106,
           52.659781082480265,
           52.70492696534947,
           52.75007284821868,
           52.795218731087886,
           52.84036461395709,
           52.8855104968263,
           52.930656379695506,
           52.97580226256471,
           53.02094814543392,
           53.06609402830313,
           53.11123991117233,
           53.15638579404154,
           53.20153167691075,
           53.246677559779954,
           53.29182344264917,
           53.336969325518375,
           53.382115208387575,
           53.42726109125679,
           53.472406974125995,
           53.5175528569952,
           53.5626987398644,
           53.60784462273361,
           53.652990505602816,
           53.69813638847202,
           53.74328227134123,
           53.788428154210436,
           53.83357403707966,
           53.878719919948864,
           53.92386580281807,
           53.96901168568727,
           54.01415756855648,
           54.059303451425684,
           54.10444933429489,
           54.1495952171641,
           54.194741100033305,
           54.23988698290251,
           54.28503286577171,
           54.330178748640925,
           54.37532463151013,
           54.420470514379346,
           54.442163112841534,
           54.44040242689673,
           54.43864174095192,
           54.43688105500711,
           54.435120369062304,
           54.4333596831175,
           54.43159899717269,
           54.42983831122788,
           54.42807762528308,
           54.426316939338264,
           54.42455625339346,
           54.42279556744865,
           54.42103488150384,
           54.41927419555904,
           54.41751350961423,
           54.41575282366943,
           54.41399213772461,
           54.41223145177981,
           54.41047076583501,
           54.4087100798902,
           54.40694939394539,
           54.40518870800059,
           54.40342802205578,
           54.40166733611097,
           54.39990665016616,
           54.39814596422136,
           54.39638527827654,
           54.39462459233174,
           54.371720635458104,
           54.34575249087898,
           54.31978434629987,
           54.293816201720745,
           54.267848057141634,
           54.241879912562524,
           54.2159117679834,
           54.18994362340429,
           54.163975478825165,
           54.138007334246055,
           54.112039189666945,
           54.08607104508782,
           54.06010290050871,
           54.0341347559296,
           54.00816661135048,
           53.982198466771365,
           53.95623032219224,
           53.93026217761313,
           53.90429403303402,
           53.87832588845491,
           53.852357743875785,
           53.826389599296675,
           53.80042145471756,
           53.77445331013844,
           53.74848516555932,
           53.72251702098021,
           53.696548876401096,
           53.670580731821985,
           53.64461258724286,
           53.61864444266375,
           53.592676298084626,
           53.566708153505516,
           53.5407400089264,
           53.51477186434728,
           53.48880371976817,
           53.46283557518905,
           53.43686743060994,
           53.41089928603083,
           53.384931141451716,
           53.35896299687259,
           53.33299485229348,
           53.307026707714364,
           53.28105856313525,
           53.25509041855614,
           53.22912227397702,
           53.2031541293979,
           53.177185984818784,
           53.151217840239674,
           53.12524969566055,
           53.09928155108144,
           53.07331340650233,
           53.04734526192321,
           53.021377117344095,
           52.99540897276498,
           52.96944082818587,
           52.80517665765964,
           52.36432043523938,
           51.92346421281911,
           51.48260799039881,
           51.04175176797855,
           50.60089554555829,
           50.16003932313797,
           49.71918310071768,
           49.27832687829745,
           48.83747065587715,
           48.39661443345684,
           47.95575821103657,
           47.51490198861631,
           47.07404576619601,
           46.63318954377574,
           46.19233332135548,
           45.751477098935176,
           45.31062087651491,
           44.869764654094645,
           44.42890843167434,
           43.988052209254036,
           43.54719598683377,
           43.106339764413505,
           42.665483541993204,
           42.224627319572946,
           41.78377109715267,
           41.34291487473237,
           40.90205865231211,
           40.46120242989184,
           40.02034620747154,
           39.57948998505123,
           39.13863376263101,
           38.69777754021071,
           38.2569213177904,
           37.816065095370135,
           37.37520887294987,
           36.93435265052957,
           36.4934964281093,
           36.05264020568904,
           35.61178398326872,
           35.170927760848464,
           34.7300715384282,
           34.28921531600789,
           33.84835909358759,
           33.407502871167324,
           32.96664664874706,
           32.52579042632676,
           32.08493420390649,
           31.64407798148623,
           31.203221759065922,
           30.76236553664566,
           30.321509314225395,
           29.88065309180509,
           29.439796869384786,
           28.998940646964563,
           28.558084424544255,
           28.117228202123954,
           27.67637197970369,
           27.235515757283423,
           26.79465953486312,
           26.353803312442857,
           25.91294709002259,
           25.472090867602287,
           25.031234645182025,
           24.590378422761756,
           24.14952220034145,
           23.70866597792115,
           23.267809755500924,
           22.82695353308062,
           22.38609731066031,
           21.945241088240053,
           21.504384865819787,
           21.06352864339948,
           20.622672420979217,
           20.181816198558952,
           19.74269982126495,
           19.30364449548377,
           18.864589169702676,
           18.42553384392149,
           17.986478518140316,
           17.547423192359176,
           17.108367866578035,
           16.66931254079686,
           16.27298576075101,
           16.090301709381322,
           15.907617658011636,
           15.724933606641951,
           15.5422495552723,
           15.35956550390261,
           15.176881452532925,
           14.994197401163273,
           14.811513349793586,
           14.628829298423899,
           14.446145247054247,
           14.26346119568456,
           14.080777144314876,
           13.898093092945189,
           13.715409041575535,
           13.532724990205848,
           13.35004093883616,
           13.214128897584544,
           13.081059196705176,
           12.947989495825807,
           12.814919794946462,
           12.681850094067094,
           12.548780393187725,
           12.41571069230838,
           12.282640991429012,
           12.149571290549645,
           12.016501589670277,
           11.883431888790932,
           11.750362187911565,
           11.617292487032193,
           11.48422278615285,
           11.351153085273483,
           11.218083384394111,
           11.085013683514768,
           10.9519439826354,
           10.81887428175603,
           10.685804580876662,
           10.552734879997319,
           10.41966517911795,
           10.286595478238581,
           10.153525777359237,
           10.020456076479869,
           9.8873863756005,
           9.754316674721155,
           9.621246973841787,
           9.48817727296242,
           9.355107572083075,
           9.222037871203707,
           9.088968170324337,
           8.955898469444968,
           8.822828768565625,
           8.689759067686255,
           8.556689366806886,
           8.423619665927543,
           8.290549965048175,
           8.157480264168806,
           8.024410563289461,
           7.891340862410092,
           7.758271161530724,
           7.625201460651354,
           7.492131759772011,
           7.3590620588926425,
           7.225992358013274,
           7.092922657133929,
           6.9598529562545615,
           6.826783255375192,
           6.693713554495848,
           6.570990126564704,
           6.484118354690171,
           6.397246582815654,
           6.310374810941122,
           6.223503039066589,
           6.136631267192058,
           6.0497594953175415,
           5.962887723443009,
           5.876015951568476,
           5.78914417969396,
           5.702272407819427,
           5.615400635944895,
           5.528528864070379,
           5.441657092195846,
           5.354785320321313,
           5.2679135484467805,
           5.181041776572265
          ],
          [
           43.60311803490278,
           43.65118040989527,
           43.69924278488776,
           43.74730515988025,
           43.79536753487274,
           43.84342990986522,
           43.89149228485772,
           43.93955465985022,
           43.98761703484269,
           44.03567940983518,
           44.08374178482768,
           44.13180415982017,
           44.17986653481266,
           44.22792890980515,
           44.275991284797634,
           44.324053659790124,
           44.372116034782614,
           44.420178409775104,
           44.468240784767595,
           44.516303159760085,
           44.564365534752575,
           44.612427909745065,
           44.660490284737556,
           44.70831463859633,
           44.75494888426619,
           44.80158312993605,
           44.84821737560591,
           44.89485162127577,
           44.941485866945634,
           44.98812011261549,
           45.034754358285355,
           45.08138860395522,
           45.12802284962508,
           45.17465709529494,
           45.221291340964804,
           45.26792558663467,
           45.314559832304525,
           45.36119407797439,
           45.407828323644246,
           45.45446256931411,
           45.50109681498397,
           45.54773106065383,
           45.594365306323695,
           45.64099955199356,
           45.687633797663416,
           45.73426804333327,
           45.78090228900314,
           45.827536534673,
           45.87417078034285,
           45.92080502601272,
           45.96743927168258,
           46.01407351735245,
           46.06070776302231,
           46.10734200869217,
           46.15397625436203,
           46.200610500031885,
           46.24724474570175,
           46.29387899137161,
           46.34051323704148,
           46.387147482711335,
           46.43378172838119,
           46.48041597405106,
           46.52705021972092,
           46.573684465390784,
           46.62031871106065,
           46.66695295673051,
           46.71358720240037,
           46.760221448070226,
           46.80685569374009,
           46.853489939409954,
           46.90012418507982,
           46.946758430749675,
           46.99339267641954,
           47.040026922089396,
           47.08666116775926,
           47.13329541342912,
           47.17992965909898,
           47.226563904768845,
           47.2731981504387,
           47.319832396108566,
           47.36646664177843,
           47.41310088744829,
           47.45973513311815,
           47.506369378788015,
           47.55037477048586,
           47.5938543913893,
           47.63733401229275,
           47.680813633196195,
           47.724293254099635,
           47.767772875003075,
           47.81125249590652,
           47.85473211680997,
           47.89821173771341,
           47.94169135861686,
           47.985170979520305,
           48.02865060042375,
           48.07213022132719,
           48.11560984223064,
           48.15908946313409,
           48.20256908403752,
           48.24604870494097,
           48.289528325844415,
           48.33300794674786,
           48.37648756765131,
           48.41996718855475,
           48.4634468094582,
           48.506926430361645,
           48.54954598214952,
           48.59216553368442,
           48.63478508521933,
           48.67740463675423,
           48.72002418828913,
           48.762643739824036,
           48.80526329135894,
           48.847882842893846,
           48.89050239442875,
           48.933121945963656,
           48.97574149749856,
           49.018361049033466,
           49.06098060056837,
           49.103600152103276,
           49.14621970363818,
           49.188839255173086,
           49.23145880670799,
           49.27407835824289,
           49.316697909777794,
           49.359317461312706,
           49.401937012847604,
           49.44455656438251,
           49.48717611591742,
           49.52979566745232,
           49.57241521898723,
           49.61503477052213,
           49.65765432205704,
           49.70027387359194,
           49.742893425126844,
           49.78551297666175,
           49.828132528196655,
           49.87075207973156,
           49.913371631266465,
           49.95599118280137,
           49.998610734336275,
           50.04123028587118,
           50.08384983740608,
           50.12646938894099,
           50.16908894047589,
           50.2117084920108,
           50.254328043545705,
           50.29694759508061,
           50.339567146615515,
           50.38218669815041,
           50.42480624968532,
           50.46742580122023,
           50.51004535275513,
           50.55266490429003,
           50.59528445582494,
           50.63790400735984,
           50.68052355889475,
           50.723143110429646,
           50.76576266196456,
           50.80838221349946,
           50.85100176503437,
           50.89362131656927,
           50.93624086810418,
           50.97886041963908,
           51.02147997117399,
           51.06409952270889,
           51.108646574834395,
           51.15415737725519,
           51.19966817967598,
           51.24517898209678,
           51.29068978451758,
           51.336200586938375,
           51.38171138935917,
           51.42722219177997,
           51.472732994200754,
           51.518243796621555,
           51.563754599042355,
           51.60926540146315,
           51.65477620388394,
           51.70028700630475,
           51.74579780872554,
           51.791308611146334,
           51.83681941356713,
           51.88233021598792,
           51.92784101840872,
           51.97335182082952,
           52.01886262325031,
           52.064373425671114,
           52.1098842280919,
           52.15539503051271,
           52.20090583293349,
           52.24641663535429,
           52.29192743777509,
           52.33743824019588,
           52.38294904261669,
           52.42845984503748,
           52.473970647458266,
           52.519481449879066,
           52.56499225229987,
           52.61050305472065,
           52.65601385714145,
           52.70152465956225,
           52.747035461983046,
           52.792546264403846,
           52.83805706682463,
           52.883567869245425,
           52.92907867166623,
           52.974589474087026,
           53.02010027650782,
           53.06561107892862,
           53.11112188134942,
           53.15663268377021,
           53.202143486191005,
           53.2476542886118,
           53.29316509103259,
           53.3386758934534,
           53.38418669587419,
           53.42969749829498,
           53.47520830071578,
           53.52071910313658,
           53.56622990555737,
           53.61174070797817,
           53.657251510398964,
           53.70276231281976,
           53.74827311524055,
           53.79378391766135,
           53.839294720082144,
           53.884805522502944,
           53.930316324923744,
           53.97582712734454,
           54.02133792976532,
           54.06684873218613,
           54.112359534606924,
           54.15787033702772,
           54.20338113944852,
           54.24889194186931,
           54.2944027442901,
           54.33991354671091,
           54.385424349131696,
           54.43093515155249,
           54.4764459539733,
           54.52172216678488,
           54.56686804965409,
           54.6120139325233,
           54.6571598153925,
           54.7023056982617,
           54.74745158113091,
           54.792597464000124,
           54.83774334686933,
           54.85943594533152,
           54.85767525938672,
           54.85591457344191,
           54.854153887497105,
           54.83079029680494,
           54.804822152225825,
           54.77885400764671,
           54.75288586306759,
           54.72691771848848,
           54.70094957390936,
           54.674981429330245,
           54.649013284751135,
           54.62304514017202,
           54.59707699559291,
           54.57110885101378,
           54.54514070643467,
           54.51917256185556,
           54.49320441727644,
           54.46723627269733,
           54.44126812811821,
           54.41529998353909,
           54.38933183895997,
           54.363363694380865,
           54.33739554980174,
           54.31142740522263,
           54.28545926064351,
           54.25916617429081,
           54.23264813850206,
           54.20613010271331,
           54.17961206692456,
           54.15309403113582,
           54.12657599534705,
           54.10005795955831,
           54.07353992376956,
           54.047021887980804,
           54.02050385219205,
           53.9939858164033,
           53.967467780614555,
           53.9409497448258,
           53.914431709037046,
           53.88791367324829,
           53.86139563745955,
           53.8348776016708,
           53.80835956588204,
           53.78184153009329,
           53.75532349430455,
           53.728805458515794,
           53.70228742272704,
           53.675769386938285,
           53.64925135114954,
           53.62273331536078,
           53.596215279572036,
           53.56969724378329,
           53.54317920799454,
           53.51666117220578,
           53.49014313641703,
           53.46362510062828,
           53.43710706483952,
           53.410589029050776,
           53.38407099326203,
           53.35755295747328,
           53.33103492168452,
           53.30451688589577,
           53.277998850107025,
           53.25148081431828,
           53.22496277852953,
           53.19844474274077,
           53.17192670695202,
           53.14540867116327,
           53.11889063537451,
           53.092372599585765,
           53.06585456379702,
           53.03933652800826,
           53.01281849221951,
           52.98630045643076,
           52.959782420642014,
           52.93326438485326,
           52.906746349064505,
           52.88022831327575,
           52.853710277487004,
           52.82719224169825,
           52.800674205909495,
           52.774156170120754,
           52.609852960777246,
           52.16997940432439,
           51.73010584787154,
           51.29023229141864,
           50.850358734965795,
           50.41048517851293,
           49.97061162206004,
           49.530738065607146,
           49.09086450915433,
           48.650990952701434,
           48.21111739624853,
           47.771137316504934,
           47.330029539848724,
           46.88892176319245,
           46.44781398653623,
           46.00670620988,
           45.56559843322374,
           45.12449065656752,
           44.683382879911285,
           44.24227510325503,
           43.801167326598765,
           43.36005954994254,
           42.91895177328631,
           42.47784399663005,
           42.036736219973825,
           41.5956284433176,
           41.15452066666134,
           40.71341289000512,
           40.27230511334889,
           39.83119733669263,
           39.39008956003636,
           38.94898178338018,
           38.50787400672391,
           38.06676623006766,
           37.625658453411425,
           37.1845506767552,
           36.74344290009894,
           36.30233512344272,
           35.86122734678649,
           35.420119570130225,
           34.979011793474,
           34.53790401681778,
           34.09679624016152,
           33.65568846350525,
           33.214580686849025,
           32.7734729101928,
           32.332365133536534,
           31.89125735688031,
           31.45014958022409,
           31.009041803567825,
           30.5679340269116,
           30.126826250255377,
           29.685718473599113,
           29.244610696942846,
           28.803502920286665,
           28.3623951436304,
           27.921287366974138,
           27.480179590317913,
           27.03907181366169,
           26.597964037005426,
           26.1568562603492,
           25.715748483692977,
           25.27464070703671,
           24.83353293038049,
           24.392425153724265,
           23.951317377068,
           23.510209600411734,
           23.069101823755553,
           22.62799404709929,
           22.186886270443026,
           21.7457784937868,
           21.304670717130577,
           20.86356294047431,
           20.42245516381809,
           19.981347387161865,
           19.540239610505598,
           19.099131833849334,
           18.658024057193153,
           18.216916280536886,
           17.775808503880622,
           17.334700727224398,
           16.893592950568177,
           16.45248517391191,
           16.05587941318166,
           15.881783732081008,
           15.707688050980355,
           15.533592369879702,
           15.359496688779082,
           15.185401007678426,
           15.011305326577773,
           14.837209645477154,
           14.663113964376498,
           14.489018283275847,
           14.314922602175226,
           14.140826921074572,
           13.96673123997392,
           13.792635558873265,
           13.618539877772644,
           13.465102642903858,
           13.33203294202449,
           13.198963241145146,
           13.065893540265776,
           12.932823839386408,
           12.799754138507065,
           12.666684437627698,
           12.533614736748326,
           12.400545035868983,
           12.267475334989616,
           12.134405634110246,
           12.001335933230877,
           11.868266232351534,
           11.735196531472166,
           11.602126830592795,
           11.469057129713452,
           11.335987428834084,
           11.202917727954713,
           11.06984802707537,
           10.936778326196002,
           10.803708625316633,
           10.670638924437265,
           10.53756922355792,
           10.40449952267855,
           10.271429821799183,
           10.138360120919838,
           10.00529042004047,
           9.8722207191611,
           9.739151018281756,
           9.606081317402388,
           9.47301161652302,
           9.339941915643676,
           9.206872214764307,
           9.073802513884939,
           8.940732813005571,
           8.807663112126225,
           8.674593411246857,
           8.541523710367489,
           8.408454009488144,
           8.275384308608775,
           8.142314607729407,
           8.009244906850062,
           7.876175205970694,
           7.743105505091325,
           7.6100358042119565,
           7.476966103332612,
           7.343896402453244,
           7.210826701573875,
           7.077757000694531,
           6.944687299815163,
           6.811617598935794,
           6.6785478980564505,
           6.545478197177081,
           6.412408496297713,
           6.313078127393147,
           6.230888012056891,
           6.148697896720634,
           6.066507781384379,
           5.984317666048137,
           5.902127550711882,
           5.819937435375626,
           5.737747320039385,
           5.65555720470313,
           5.573367089366874,
           5.491176974030633,
           5.408986858694377,
           5.326796743358122,
           5.244606628021866,
           5.162416512685625
          ],
          [
           43.96285173720564,
           44.01091411219813,
           44.05897648719062,
           44.1070388621831,
           44.15510123717559,
           44.20316361216808,
           44.25122598716058,
           44.299288362153064,
           44.347350737145554,
           44.395413112138044,
           44.44347548713054,
           44.49153786212303,
           44.539600237115515,
           44.587662612108005,
           44.635724987100495,
           44.683787362092986,
           44.731849737085476,
           44.779912112077966,
           44.827974487070456,
           44.87603686206294,
           44.92409923705543,
           44.97216161204793,
           45.02022398704041,
           45.06828636203291,
           45.11634873702539,
           45.16441111201788,
           45.21247348701037,
           45.26053586200286,
           45.30859823699535,
           45.35666061198784,
           45.40472298698033,
           45.45278536197282,
           45.50084773696531,
           45.548910111957795,
           45.59697248695029,
           45.645034861942776,
           45.69309723693527,
           45.741159611927756,
           45.78922198692025,
           45.83728436191274,
           45.88439465033156,
           45.931028896001415,
           45.97766314167127,
           46.024297387341136,
           46.070931633011,
           46.117565878680864,
           46.16420012435073,
           46.210834370020585,
           46.25746861569044,
           46.304102861360306,
           46.35073710703017,
           46.397371352700034,
           46.44400559836989,
           46.49063984403975,
           46.53727408970961,
           46.583908335379476,
           46.63054258104934,
           46.6771768267192,
           46.723811072389054,
           46.770445318058925,
           46.81707956372878,
           46.86371380939865,
           46.91034805506851,
           46.95698230073836,
           47.003616546408225,
           47.05025079207809,
           47.09688503774795,
           47.14351928341782,
           47.19015352908767,
           47.23678777475753,
           47.283422020427395,
           47.33005626609726,
           47.37669051176712,
           47.42332475743698,
           47.46995900310684,
           47.5165932487767,
           47.563227494446565,
           47.60986174011642,
           47.656495985786286,
           47.70313023145614,
           47.74976447712601,
           47.79639872279587,
           47.843032968465735,
           47.88966721413559,
           47.93367260583344,
           47.97715222673689,
           48.02063184764033,
           48.06411146854377,
           48.107591089447226,
           48.151070710350666,
           48.194550331254106,
           48.23802995215756,
           48.281509573061,
           48.32498919396444,
           48.36846881486789,
           48.411948435771336,
           48.455428056674776,
           48.498907677578224,
           48.54238729848167,
           48.58586691938511,
           48.629346540288566,
           48.672826161192006,
           48.71630578209545,
           48.7597854029989,
           48.803265023902334,
           48.84674464480578,
           48.89022426570923,
           48.93370388661267,
           48.977183507516116,
           49.020663128419564,
           49.06414274932301,
           49.10762237022645,
           49.1511019911299,
           49.194581612033346,
           49.23806123293678,
           49.28154085384023,
           49.325020474743674,
           49.36850009564712,
           49.41197971655056,
           49.45545933745401,
           49.498938958357456,
           49.542418579260904,
           49.585898200164344,
           49.62894778616756,
           49.67156733770247,
           49.714186889237375,
           49.75680644077229,
           49.799425992307185,
           49.84204554384209,
           49.884665095376995,
           49.92728464691189,
           49.969904198446805,
           50.0125237499817,
           50.055143301516615,
           50.09776285305152,
           50.140382404586425,
           50.18300195612133,
           50.22562150765623,
           50.26824105919114,
           50.31086061072604,
           50.35348016226095,
           50.39609971379585,
           50.438719265330754,
           50.48133881686566,
           50.523958368400564,
           50.56657791993547,
           50.609197471470374,
           50.65181702300528,
           50.694436574540184,
           50.73705612607509,
           50.779675677609994,
           50.8222952291449,
           50.8649147806798,
           50.9075343322147,
           50.95015388374961,
           50.99277343528451,
           51.03539298681942,
           51.07801253835433,
           51.12063208988923,
           51.163251641424125,
           51.20587119295904,
           51.24849074449394,
           51.29111029602885,
           51.333729847563745,
           51.37634939909866,
           51.418968950633555,
           51.46158850216847,
           51.50613555429396,
           51.55164635671476,
           51.59715715913556,
           51.64266796155635,
           51.68817876397715,
           51.73368956639794,
           51.779200368818735,
           51.82471117123954,
           51.870221973660335,
           51.91573277608113,
           51.96124357850192,
           52.00675438092272,
           52.052265183343515,
           52.097775985764315,
           52.14328678818511,
           52.18879759060591,
           52.23430839302671,
           52.2798191954475,
           52.325329997868295,
           52.37084080028909,
           52.41635160270988,
           52.46186240513069,
           52.507373207551474,
           52.552884009972274,
           52.59839481239307,
           52.64390561481386,
           52.68941641723465,
           52.73492721965546,
           52.780438022076254,
           52.82594882449705,
           52.87145962691784,
           52.91697042933864,
           52.96248123175944,
           53.00799203418023,
           53.05350283660103,
           53.09901363902182,
           53.14452444144263,
           53.19003524386342,
           53.235546046284206,
           53.281056848705006,
           53.3265676511258,
           53.37207845354659,
           53.417589255967385,
           53.463100058388186,
           53.508610860808986,
           53.554121663229786,
           53.59963246565058,
           53.64514326807137,
           53.69065407049217,
           53.736164872912966,
           53.78167567533376,
           53.82718647775455,
           53.87269728017535,
           53.91820808259615,
           53.963718885016945,
           54.00922968743774,
           54.05474048985854,
           54.10025129227933,
           54.145762094700125,
           54.191272897120925,
           54.23678369954172,
           54.28229450196252,
           54.32780530438331,
           54.373381806005185,
           54.418992721368326,
           54.46460363673148,
           54.51021455209463,
           54.55582546745778,
           54.60143638282093,
           54.64704729818408,
           54.692658213547226,
           54.738269128910375,
           54.78388004427352,
           54.82949095963667,
           54.875101874999814,
           54.92071279036297,
           54.96632370572611,
           55.01193462108927,
           55.05754553645241,
           55.10315645181556,
           55.148767367178706,
           55.194378282541855,
           55.239989197905004,
           55.23963933204796,
           55.19332868497071,
           55.14701803789347,
           55.100707390816225,
           55.05439674373898,
           55.008086096661735,
           54.96177544958449,
           54.915464802507245,
           54.869154155429996,
           54.82284350835277,
           54.77653286127551,
           54.73022221419828,
           54.68391156712103,
           54.637600920043795,
           54.591290272966546,
           54.5449796258893,
           54.49866897881206,
           54.452358331734814,
           54.40604768465757,
           54.35973703758033,
           54.31342639050308,
           54.26711574342583,
           54.2208050963486,
           54.17449444927135,
           54.12818380219411,
           54.08187315511687,
           54.03556250803962,
           53.98925186096238,
           53.94710805101361,
           53.92059001522486,
           53.894071979436106,
           53.86755394364736,
           53.84103590785861,
           53.81451787206986,
           53.787999836281095,
           53.761481800492355,
           53.73496376470359,
           53.70844572891485,
           53.6819276931261,
           53.65540965733736,
           53.62889162154859,
           53.60237358575984,
           53.575855549971095,
           53.54933751418234,
           53.522819478393586,
           53.496301442604846,
           53.46978340681609,
           53.44326537102734,
           53.41674733523858,
           53.39022929944983,
           53.36371126366109,
           53.33719322787233,
           53.31067519208358,
           53.28415715629484,
           53.25763912050608,
           53.23112108471733,
           53.204603048928576,
           53.17808501313983,
           53.151566977351074,
           53.125048941562326,
           53.09853090577357,
           53.072012869984825,
           53.04549483419607,
           53.018976798407316,
           52.99245876261857,
           52.96594072682982,
           52.93942269104107,
           52.91290465525232,
           52.886386619463565,
           52.85986858367481,
           52.83335054788607,
           52.80683251209731,
           52.780314476308554,
           52.75379644051981,
           52.72727840473106,
           52.700760368942305,
           52.67424233315355,
           52.64772429736481,
           52.62120626157605,
           52.594688225787294,
           52.56817018999855,
           52.5416521542098,
           52.51513411842105,
           52.350830909077544,
           51.910957352624685,
           51.47108379617183,
           51.031210239718945,
           50.59133668326609,
           50.15146312681323,
           49.71158957036034,
           49.271716013907444,
           48.83184245745463,
           48.39196890100173,
           47.95209534454883,
           47.51222178809598,
           47.07234823164312,
           46.63247467519023,
           46.19260111873737,
           45.75272756228452,
           45.312854005831625,
           44.87298044937877,
           44.43310689292591,
           43.993233336473025,
           43.55335978002013,
           43.11348622356727,
           42.67361266711441,
           42.23373911066152,
           41.79386555420867,
           41.353991997755806,
           40.91411844130292,
           40.474244884850066,
           40.0343713283972,
           39.59449777194431,
           39.15462421549142,
           38.7147506590386,
           38.274877102585705,
           37.83500354613281,
           37.39512998967996,
           36.9552564332271,
           36.515382876774204,
           36.07550932032135,
           35.63563576386849,
           35.1957622074156,
           34.755888650962746,
           34.31601509450989,
           33.876141538057,
           33.4362679816041,
           32.99639442515125,
           32.556271088863,
           32.11516331220673,
           31.674055535550508,
           31.232947758894284,
           30.791839982238017,
           30.350732205581796,
           29.909624428925575,
           29.46851665226931,
           29.02740887561304,
           28.586301098956863,
           28.145193322300596,
           27.704085545644332,
           27.262977768988108,
           26.821869992331884,
           26.380762215675624,
           25.939654439019396,
           25.49854666236317,
           25.057438885706908,
           24.616331109050684,
           24.17522333239446,
           23.734115555738196,
           23.293007779081933,
           22.851900002425747,
           22.410792225769484,
           21.969684449113224,
           21.528576672456996,
           21.08746889580077,
           20.646361119144508,
           20.205253342488284,
           19.76414556583206,
           19.323037789175796,
           18.88193001251953,
           18.440822235863347,
           17.999714459207084,
           17.55860668255082,
           17.117498905894596,
           16.67639112923837,
           16.23528335258211,
           15.838677591851857,
           15.664581910751204,
           15.49048622965055,
           15.316390548549897,
           15.142294867449277,
           14.968199186348622,
           14.79410350524797,
           14.620007824147347,
           14.445912143046694,
           14.271816461946042,
           14.097720780845421,
           13.923625099744767,
           13.749529418644114,
           13.575433737543461,
           13.401338056442839,
           13.227242375342186,
           13.053146694241534,
           12.879051013140911,
           12.704955332040258,
           12.530859650939604,
           12.356763969838983,
           12.18266828873833,
           12.008572607637676,
           11.834476926537056,
           11.660381245436401,
           11.486285564335748,
           11.312189883235096,
           11.138094202134475,
           10.96399852103382,
           10.78990283993317,
           10.615807158832546,
           10.441711477731895,
           10.26761579663124,
           10.09352011553062,
           9.919424434429967,
           9.758349428145388,
           9.62527972726602,
           9.492210026386676,
           9.359140325507306,
           9.226070624627939,
           9.093000923748596,
           8.959931222869226,
           8.826861521989859,
           8.693791821110514,
           8.560722120231144,
           8.427652419351775,
           8.294582718472432,
           8.161513017593062,
           8.028443316713695,
           7.938585156444044,
           7.856395041107803,
           7.774204925771547,
           7.692014810435291,
           7.60982469509905,
           7.527634579762795,
           7.445444464426538,
           7.3632543490902975,
           7.2810642337540425,
           7.198874118417786,
           7.116684003081531,
           7.03449388774529,
           6.952303772409033,
           6.870113657072778,
           6.787923541736538,
           6.705733426400281,
           6.623543311064025,
           6.541353195727785,
           6.459163080391528,
           6.376972965055273,
           6.294782849719033,
           6.212592734382777,
           6.130402619046521,
           6.048212503710264,
           5.966022388374025,
           5.8838322730377675,
           5.801642157701512,
           5.719452042365272,
           5.637261927029016,
           5.555071811692759,
           5.472881696356518,
           5.3906915810202625,
           5.308501465684007,
           5.2263113503477525,
           5.144121235011511
          ],
          [
           44.322585439508494,
           44.370647814500984,
           44.418710189493474,
           44.466772564485964,
           44.514834939478455,
           44.562897314470945,
           44.610959689463435,
           44.659022064455925,
           44.707084439448415,
           44.755146814440906,
           44.80320918943339,
           44.85127156442588,
           44.89933393941837,
           44.94739631441086,
           44.99545868940335,
           45.04352106439584,
           45.09158343938833,
           45.13964581438082,
           45.18770818937331,
           45.23577056436581,
           45.28383293935829,
           45.331895314350774,
           45.37995768934327,
           45.428020064335755,
           45.47608243932825,
           45.52414481432074,
           45.572207189313225,
           45.620269564305715,
           45.6683319392982,
           45.716394314290696,
           45.76445668928319,
           45.812519064275676,
           45.860581439268174,
           45.90864381426066,
           45.95670618925315,
           46.00476856424563,
           46.05283093923812,
           46.10089331423062,
           46.1489556892231,
           46.1970180642156,
           46.24508043920809,
           46.29314281420057,
           46.34120518919306,
           46.389267564185545,
           46.437329939178035,
           46.485392314170525,
           46.53345468916302,
           46.581517064155506,
           46.629579439147996,
           46.67764181414049,
           46.725704189132976,
           46.773766564125474,
           46.82182893911796,
           46.86989131411045,
           46.917953689102944,
           46.96601606409543,
           47.013840416396924,
           47.06047466206678,
           47.107108907736645,
           47.15374315340651,
           47.200377399076366,
           47.24701164474623,
           47.29364589041609,
           47.34028013608595,
           47.386914381755815,
           47.43354862742568,
           47.480182873095536,
           47.52681711876539,
           47.57345136443526,
           47.62008561010512,
           47.666719855774986,
           47.71335410144484,
           47.7599883471147,
           47.806622592784564,
           47.85325683845443,
           47.89989108412429,
           47.94652532979415,
           47.99315957546401,
           48.03979382113387,
           48.086428066803734,
           48.1330623124736,
           48.179696558143455,
           48.22633080381332,
           48.272965049483176,
           48.31697044118102,
           48.36045006208447,
           48.40392968298791,
           48.44740930389136,
           48.4908889247948,
           48.53436854569824,
           48.57784816660169,
           48.62132778750514,
           48.66480740840858,
           48.708287029312025,
           48.75176665021547,
           48.79524627111891,
           48.83872589202237,
           48.88220551292581,
           48.92568513382925,
           48.969164754732695,
           49.01264437563614,
           49.05612399653958,
           49.09960361744303,
           49.14308323834648,
           49.18656285924992,
           49.230042480153365,
           49.27352210105681,
           49.31700172196025,
           49.3604813428637,
           49.40396096376715,
           49.44744058467059,
           49.490920205574035,
           49.53439982647748,
           49.57787944738092,
           49.62135906828436,
           49.66483868918781,
           49.70831831009126,
           49.7517979309947,
           49.795277551898145,
           49.83875717280159,
           49.88223679370504,
           49.92571641460849,
           49.96919603551192,
           50.01267565641537,
           50.05615527731881,
           50.09963489822226,
           50.1431145191257,
           50.18659414002915,
           50.2300737609326,
           50.27355338183604,
           50.31703300273948,
           50.36051262364293,
           50.40399224454637,
           50.44747186544981,
           50.49095148635326,
           50.53443110725671,
           50.57791072816015,
           50.621390349063596,
           50.66486996996704,
           50.70834959018561,
           50.75096914172052,
           50.79358869325542,
           50.83620824479033,
           50.87882779632523,
           50.92144734786014,
           50.96406689939504,
           51.00668645092994,
           51.049306002464846,
           51.09192555399975,
           51.134545105534656,
           51.17716465706956,
           51.219784208604466,
           51.26240376013938,
           51.305023311674276,
           51.34764286320919,
           51.390262414744086,
           51.432881966279,
           51.475501517813896,
           51.51812106934881,
           51.560740620883706,
           51.60336017241861,
           51.645979723953516,
           51.68859927548842,
           51.731218827023326,
           51.77383837855823,
           51.81645793009314,
           51.859077481628034,
           51.903624533753536,
           51.94913533617433,
           51.99464613859513,
           52.04015694101592,
           52.08566774343672,
           52.13117854585752,
           52.17668934827831,
           52.22220015069911,
           52.2677109531199,
           52.313221755540695,
           52.358732557961496,
           52.404243360382296,
           52.44975416280309,
           52.49526496522388,
           52.54077576764468,
           52.586286570065475,
           52.631797372486275,
           52.67730817490707,
           52.72281897732786,
           52.76832977974866,
           52.813840582169455,
           52.859351384590255,
           52.90486218701105,
           52.95037298943184,
           52.99588379185264,
           53.04139459427343,
           53.08690539669423,
           53.13241619911503,
           53.17792700153583,
           53.22343780395662,
           53.26894860637741,
           53.314459408798214,
           53.359970211219014,
           53.4054810136398,
           53.4509918160606,
           53.496502618481394,
           53.542013420902194,
           53.58752422332299,
           53.63303502574378,
           53.67858337047744,
           53.72419428584058,
           53.76980520120374,
           53.81541611656688,
           53.86102703193003,
           53.90663794729318,
           53.95224886265633,
           53.997859778019475,
           54.04347069338263,
           54.08908160874577,
           54.13469252410893,
           54.18030343947207,
           54.22591435483522,
           54.27152527019837,
           54.31713618556152,
           54.362747100924665,
           54.40835801628782,
           54.45396893165096,
           54.49957984701411,
           54.54519076237726,
           54.590801677740416,
           54.63641259310355,
           54.6820235084667,
           54.72763442382984,
           54.773245339193,
           54.81885625455615,
           54.864467169919294,
           54.91007808528245,
           54.95568900064559,
           55.00129991600875,
           55.04691083137189,
           55.09252174673504,
           55.13813266209819,
           55.18374357746134,
           55.229354492824484,
           55.27496540818763,
           55.32057632355078,
           55.36618723891393,
           55.41179815427708,
           55.45740906964022,
           55.50301998500338,
           55.548630900366526,
           55.594241815729674,
           55.639852731092816,
           55.63950286523577,
           55.59319221815852,
           55.546881571081286,
           55.50057092400404,
           55.45426027692679,
           55.407949629849554,
           55.361638982772305,
           55.315328335695064,
           55.269017688617815,
           55.22270704154059,
           55.17639639446333,
           55.13008574738609,
           55.08377510030885,
           55.03746445323161,
           54.99115380615436,
           54.94484315907712,
           54.898532511999875,
           54.852221864922626,
           54.80591121784539,
           54.75960057076815,
           54.7132899236909,
           54.66697927661366,
           54.62066862953641,
           54.574357982459176,
           54.52804733538193,
           54.48173668830468,
           54.435426041227444,
           54.389115394150195,
           54.34280474707295,
           54.29649409999571,
           54.25018345291846,
           54.203872805841215,
           54.15756215876398,
           54.11125151168673,
           54.06494086460948,
           54.01863021753225,
           53.972319570455,
           53.926008923377765,
           53.879698276300516,
           53.833387629223274,
           53.787076982146026,
           53.740766335068784,
           53.69445568799154,
           53.6481450409143,
           53.60183439383705,
           53.55552374675981,
           53.50921309968257,
           53.46290245260532,
           53.416591805528086,
           53.37028115845084,
           53.32397051137359,
           53.277659864296346,
           53.231349217219105,
           53.185038570141856,
           53.13872792306461,
           53.09241727598737,
           53.046106628910124,
           52.999795981832875,
           52.95348533475564,
           52.9071746876784,
           52.86086404060116,
           52.81455339352391,
           52.78647278249637,
           52.75995474670761,
           52.733436710918866,
           52.70691867513012,
           52.680400639341364,
           52.65388260355262,
           52.62736456776386,
           52.60084653197511,
           52.574328496186354,
           52.54781046039761,
           52.52129242460886,
           52.494774388820105,
           52.46825635303135,
           52.44173831724261,
           52.41522028145385,
           52.3887022456651,
           52.362184209876354,
           52.3356661740876,
           52.309148138298845,
           52.28263010251009,
           52.25611206672134,
           52.09180885737784,
           51.65193530092498,
           51.21206174447214,
           50.772188188019236,
           50.33231463156638,
           49.892441075113524,
           49.452567518660636,
           49.01269396220774,
           48.572820405754925,
           48.13294684930203,
           47.693073292849135,
           47.25319973639628,
           46.81332617994342,
           46.37345262349053,
           45.93357906703766,
           45.49370551058481,
           45.05383195413192,
           44.61395839767907,
           44.17408484122621,
           43.73421128477332,
           43.29433772832042,
           42.85446417186757,
           42.41459061541471,
           41.974717058961815,
           41.53484350250896,
           41.0949699460561,
           40.655096389603216,
           40.215222833150364,
           39.775349276697504,
           39.33547572024461,
           38.895602163791715,
           38.4557286073389,
           38.015855050886,
           37.57598149443311,
           37.136107937980256,
           36.6962343815274,
           36.2563608250745,
           35.81648726862165,
           35.37661371216879,
           34.936740155715896,
           34.49686659926304,
           34.056993042810184,
           33.61711948635729,
           33.1772459299044,
           32.73737237345154,
           32.29749881699869,
           31.857625260545795,
           31.41775170409294,
           30.977878147640084,
           30.53800459118719,
           30.098131034734337,
           29.658257478281477,
           29.218383921828586,
           28.778510365375688,
           28.33863680892287,
           27.89876325246998,
           27.45888969601708,
           27.01901613956423,
           26.579142583111373,
           26.13926902665848,
           25.699395470205623,
           25.25952191375277,
           24.819648357299876,
           24.37977480084702,
           23.939901244394164,
           23.50002768794127,
           23.060154131488375,
           22.620280575035558,
           22.180407018582663,
           21.74053346212977,
           21.30065990567691,
           20.860786349224057,
           20.420912792771166,
           19.98103923631831,
           19.541165679865454,
           19.10129212341256,
           18.661418566959664,
           18.22154501050685,
           17.781671454053953,
           17.341404861221015,
           16.90029708456479,
           16.459189307908563,
           16.018081531252303,
           15.621475770522053,
           15.4473800894214,
           15.273284408320746,
           15.099188727220092,
           14.925093046119471,
           14.750997365018819,
           14.576901683918166,
           14.43669261123889,
           14.31043657318341,
           14.18418053512793,
           14.057924497072475,
           13.931668459016997,
           13.805412420961519,
           13.679156382906042,
           13.552900344850586,
           13.426644306795108,
           13.30038826873963,
           13.174132230684172,
           13.047876192628696,
           12.921620154573215,
           12.79536411651776,
           12.669108078462282,
           12.542852040406805,
           12.41659600235135,
           12.290339964295871,
           12.164083926240393,
           12.037827888184914,
           11.911571850129457,
           11.785315812073978,
           11.6590597740185,
           11.532803735963045,
           11.406547697907566,
           11.28029165985209,
           11.154035621796634,
           11.027779583741156,
           10.901523545685677,
           10.775267507630199,
           10.649011469574743,
           10.522755431519263,
           10.396499393463785,
           10.27024335540833,
           10.14398731735285,
           10.01773127929737,
           9.891475241241915,
           9.76521920318644,
           9.63896316513096,
           9.512707127075505,
           9.386451089020028,
           9.26019505096455,
           9.13393901290907,
           9.007682974853614,
           8.881426936798135,
           8.755170898742657,
           8.628914860687201,
           8.502658822631725,
           8.376402784576245,
           8.25014674652079,
           8.12389070846531,
           7.997634670409831,
           7.871378632354354,
           7.745122594298898,
           7.61886655624342,
           7.492610518187942,
           7.366354480132486,
           7.240098442077008,
           7.113842404021529,
           6.987586365966074,
           6.861330327910595,
           6.735074289855116,
           6.608818251799661,
           6.482562213744182,
           6.356306175688705,
           6.230050137633226,
           6.103794099577771,
           5.977538061522292,
           5.851282023466814,
           5.725025985411358,
           5.618966649354902,
           5.536776534018646,
           5.454586418682405,
           5.37239630334615,
           5.290206188009893,
           5.208016072673638,
           5.125825957337397
          ],
          [
           44.68231914181137,
           44.73038151680386,
           44.77844389179635,
           44.82650626678884,
           44.87456864178133,
           44.92263101677382,
           44.97069339176631,
           45.018755766758794,
           45.06681814175129,
           45.114880516743774,
           45.162942891736265,
           45.21100526672876,
           45.25906764172125,
           45.307130016713735,
           45.355192391706225,
           45.403254766698716,
           45.451317141691206,
           45.499379516683696,
           45.547441891676186,
           45.59550426666867,
           45.64356664166116,
           45.69162901665365,
           45.73969139164614,
           45.78775376663863,
           45.83581614163112,
           45.88387851662361,
           45.9319408916161,
           45.98000326660859,
           46.02806564160108,
           46.07612801659357,
           46.124190391586055,
           46.17225276657855,
           46.220315141571035,
           46.26837751656353,
           46.316439891556016,
           46.36450226654851,
           46.412564641540996,
           46.460627016533486,
           46.50868939152598,
           46.55675176651847,
           46.60481414151096,
           46.65287651650345,
           46.70093889149594,
           46.74900126648843,
           46.79706364148092,
           46.84512601647341,
           46.8931883914659,
           46.94125076645839,
           46.98931314145088,
           47.03737551644336,
           47.08543789143586,
           47.13350026642834,
           47.18156264142084,
           47.22962501641332,
           47.27768739140582,
           47.3257497663983,
           47.3738121413908,
           47.42187451638328,
           47.469936891375774,
           47.517999266368264,
           47.566061641360754,
           47.614124016353244,
           47.662186391345735,
           47.710248766338225,
           47.75831114133071,
           47.806373516323205,
           47.85443589131569,
           47.90249826630818,
           47.95056064130067,
           47.99862301629316,
           48.04668539128565,
           48.09474776627814,
           48.14281014127063,
           48.18992042813217,
           48.236554673802026,
           48.28318891947189,
           48.32982316514175,
           48.37645741081161,
           48.423091656481475,
           48.46972590215134,
           48.516360147821196,
           48.56299439349106,
           48.60962863916092,
           48.65626288483078,
           48.70026827652862,
           48.74374789743207,
           48.78722751833551,
           48.83070713923896,
           48.8741867601424,
           48.91766638104585,
           48.961146001949295,
           49.004625622852735,
           49.04810524375618,
           49.09158486465963,
           49.13506448556308,
           49.17854410646652,
           49.22202372736997,
           49.26550334827341,
           49.30898296917685,
           49.3524625900803,
           49.39594221098375,
           49.43942183188719,
           49.482901452790635,
           49.52638107369408,
           49.56986069459752,
           49.61334031550096,
           49.65681993640442,
           49.70029955730786,
           49.743779178211305,
           49.787258799114745,
           49.83073842001819,
           49.87421804092163,
           49.91769766182508,
           49.96117728272853,
           50.00465690363197,
           50.04813652453541,
           50.09161614543886,
           50.1350957663423,
           50.17857538724574,
           50.2220550081492,
           50.26553462905264,
           50.309014249956086,
           50.352493870859526,
           50.39597349176297,
           50.43945311266641,
           50.48293273356986,
           50.52641235447331,
           50.56989197537675,
           50.613371596280196,
           50.65685121718364,
           50.70033083808708,
           50.74381045899053,
           50.78729007989398,
           50.830769700797426,
           50.87424932170087,
           50.91772894260431,
           50.96120856350776,
           51.00468818441121,
           51.04816780531465,
           51.091647426218096,
           51.13512704712154,
           51.17860666802498,
           51.22208628892842,
           51.26556590983187,
           51.30904553073532,
           51.35252515163876,
           51.396004772542206,
           51.43948439344565,
           51.48296401434909,
           51.52644363525254,
           51.56992325615598,
           51.61340287705943,
           51.656882497962876,
           51.700362118866316,
           51.74384173976976,
           51.78732136067321,
           51.83037094573858,
           51.872990497273484,
           51.91561004880839,
           51.958229600343294,
           52.0008491518782,
           52.043468703413104,
           52.08608825494801,
           52.128707806482915,
           52.17132735801782,
           52.213946909552725,
           52.25656646108763,
           52.301113513213124,
           52.34662431563392,
           52.39213511805472,
           52.43764592047551,
           52.483156722896304,
           52.528667525317104,
           52.5741783277379,
           52.6196891301587,
           52.66519993257948,
           52.710710735000276,
           52.756221537421084,
           52.80173233984188,
           52.84724314226268,
           52.89275394468347,
           52.93826474710426,
           52.9837849349497,
           53.02939585031285,
           53.075006765676,
           53.12061768103915,
           53.166228596402306,
           53.211839511765454,
           53.2574504271286,
           53.303061342491745,
           53.3486722578549,
           53.39428317321804,
           53.43989408858119,
           53.48550500394434,
           53.53111591930748,
           53.57672683467064,
           53.62233775003378,
           53.66794866539693,
           53.71355958076008,
           53.759170496123225,
           53.804781411486374,
           53.85039232684952,
           53.89600324221268,
           53.94161415757582,
           53.98722507293897,
           54.032835988302125,
           54.078446903665274,
           54.124057819028415,
           54.169668734391564,
           54.21527964975471,
           54.26089056511786,
           54.30650148048102,
           54.35211239584416,
           54.397723311207315,
           54.44333422657045,
           54.48894514193361,
           54.53455605729675,
           54.5801669726599,
           54.62577788802305,
           54.6713888033862,
           54.71699971874934,
           54.7626106341125,
           54.80822154947565,
           54.85383246483879,
           54.89944338020194,
           54.945054295565086,
           54.990665210928235,
           55.03627612629138,
           55.08188704165453,
           55.12749795701769,
           55.17310887238084,
           55.21871978774398,
           55.26433070310713,
           55.309941618470276,
           55.355552533833425,
           55.401163449196574,
           55.44677436455973,
           55.49238527992287,
           55.53799619528601,
           55.58360711064917,
           55.62921802601231,
           55.674828941375466,
           55.720439856738615,
           55.766050772101764,
           55.81166168746491,
           55.85727260282806,
           55.9028835181912,
           55.94849443355436,
           55.9941053489175,
           56.039716264280656,
           56.039366398423596,
           55.99305575134635,
           55.94674510426911,
           55.900434457191864,
           55.85412381011463,
           55.80781316303738,
           55.761502515960146,
           55.7151918688829,
           55.66888122180565,
           55.62257057472841,
           55.576259927651165,
           55.529949280573916,
           55.48363863349668,
           55.43732798641943,
           55.39101733934219,
           55.34470669226495,
           55.29839604518771,
           55.25208539811046,
           55.20577475103321,
           55.15946410395598,
           55.113153456878734,
           55.066842809801486,
           55.02053216272425,
           54.974221515647,
           54.927910868569754,
           54.88160022149251,
           54.83528957441527,
           54.78897892733802,
           54.74266828026078,
           54.696357633183545,
           54.6500469861063,
           54.60373633902905,
           54.55742569195181,
           54.511115044874565,
           54.46480439779732,
           54.418493750720074,
           54.37218310364283,
           54.325872456565584,
           54.27956180948835,
           54.23325116241111,
           54.18694051533386,
           54.14062986825662,
           54.094319221179376,
           54.048008574102134,
           54.001697927024885,
           53.955387279947644,
           53.909076632870395,
           53.86276598579315,
           53.816455338715905,
           53.77014469163867,
           53.72383404456142,
           53.67752339748418,
           53.63121275040693,
           53.58490210332968,
           53.53859145625245,
           53.492280809175206,
           53.44597016209796,
           53.39965951502071,
           53.353348867943474,
           53.30703822086623,
           53.260727573788984,
           53.21441692671174,
           53.1681062796345,
           53.12179563255725,
           53.07548498548001,
           53.029174338402775,
           52.98286369132553,
           52.923876754075636,
           52.86176948219525,
           52.799662210314835,
           52.737554938434435,
           52.675447666554035,
           52.61334039467363,
           52.55123312279323,
           52.48912585091283,
           52.42701857903243,
           52.36491130715202,
           52.30280403527163,
           52.24069676339123,
           52.17858949151083,
           52.11648221963041,
           52.05437494775002,
           51.99226767586962,
           51.80553473010863,
           51.36955043658661,
           50.93356614306458,
           50.49758184954252,
           50.06159755602049,
           49.62561326249847,
           49.1896289689764,
           48.75364467545433,
           48.31766038193235,
           47.88167608841029,
           47.44569179488821,
           47.0097075013662,
           46.573723207844175,
           46.13505202454201,
           45.69547769117906,
           45.2559033578161,
           44.81632902445311,
           44.376754691090156,
           43.93718035772719,
           43.497606024364195,
           43.058031691001204,
           42.61845735763825,
           42.178883024275294,
           41.739308690912296,
           41.29973435754934,
           40.86016002418638,
           40.42058569082339,
           39.98101135746043,
           39.541437024097476,
           39.10186269073448,
           38.66228835737148,
           38.22271402400857,
           37.78313969064557,
           37.34356535728257,
           36.90399102391962,
           36.46441669055666,
           36.02484235719366,
           35.58526802383071,
           35.14569369046775,
           34.70611935710476,
           34.2665450237418,
           33.82697069037884,
           33.387396357015845,
           32.947822023652854,
           32.50824769028989,
           32.068673356926936,
           31.629099023563942,
           31.189524690200987,
           30.749950356838028,
           30.310376023475033,
           29.870801690112074,
           29.431227356749122,
           28.991653023386128,
           28.55207869002313,
           28.112504356660214,
           27.672930023297216,
           27.23335568993422,
           26.793781356571266,
           26.35420702320831,
           25.914632689845313,
           25.475058356482357,
           25.035484023119402,
           24.595909689756404,
           24.15633535639345,
           23.716761023030493,
           23.277186689667495,
           22.8376123563045,
           22.398038022941584,
           21.958463689578586,
           21.518889356215592,
           21.079315022852633,
           20.63974068948968,
           20.200166356126683,
           19.760592022763728,
           19.32101768940077,
           18.881443356037774,
           18.44186902267478,
           18.002294689311864,
           17.56272035594887,
           17.12314602258587,
           16.683571689222916,
           16.24399735585996,
           15.804423022496962,
           15.410528771670103,
           15.245034933523444,
           15.079541095376786,
           14.91404725723013,
           14.7485534190835,
           14.583059580936842,
           14.417565742790185,
           14.252071904643556,
           14.0865780664969,
           13.921084228350239,
           13.755590390203613,
           13.590096552056952,
           13.424602713910295,
           13.259108875763637,
           13.093615037617008,
           12.92812119947035,
           12.762627361323695,
           12.597133523177066,
           12.431639685030408,
           12.292304371285878,
           12.166048333230423,
           12.039792295174943,
           11.913536257119466,
           11.78728021906401,
           11.661024181008532,
           11.534768142953054,
           11.408512104897577,
           11.28225606684212,
           11.156000028786641,
           11.029743990731163,
           10.903487952675707,
           10.777231914620229,
           10.65097587656475,
           10.524719838509295,
           10.398463800453817,
           10.272207762398338,
           10.145951724342858,
           10.019695686287404,
           9.893439648231926,
           9.767183610176447,
           9.640927572120992,
           9.514671534065513,
           9.388415496010035,
           9.26215945795458,
           9.135903419899101,
           9.009647381843623,
           8.883391343788167,
           8.757135305732689,
           8.63087926767721,
           8.504623229621732,
           8.378367191566277,
           8.252111153510798,
           8.12585511545532,
           7.999599077399864,
           7.873343039344385,
           7.747087001288907,
           7.620830963233452,
           7.494574925177973,
           7.368318887122495,
           7.242062849067016,
           7.115806811011561,
           6.989550772956083,
           6.863294734900604,
           6.737038696845149,
           6.610782658789669,
           6.508758596142534,
           6.430966486691115,
           6.3531743772396805,
           6.275382267788248,
           6.197590158336829,
           6.1197980488853965,
           6.042005939433963,
           5.964213829982531,
           5.886421720531112,
           5.80862961107968,
           5.730837501628247,
           5.6530453921768276,
           5.575253282725394,
           5.497461173273962,
           5.419669063822543,
           5.341876954371109,
           5.264084844919677,
           5.186292735468244,
           5.108500626016825
          ],
          [
           45.03807957735301,
           45.0874066863838,
           45.13673379541458,
           45.18606090444537,
           45.23538801347616,
           45.284715122506945,
           45.33362065144723,
           45.38168302643972,
           45.42974540143221,
           45.4778077764247,
           45.525870151417195,
           45.573932526409685,
           45.62199490140217,
           45.67005727639466,
           45.71811965138715,
           45.76618202637964,
           45.81424440137213,
           45.86230677636462,
           45.91036915135711,
           45.95843152634959,
           46.00649390134208,
           46.05455627633458,
           46.10261865132706,
           46.15068102631956,
           46.19874340131204,
           46.246805776304534,
           46.294868151297024,
           46.342930526289514,
           46.390992901282004,
           46.439055276274495,
           46.48711765126698,
           46.53518002625947,
           46.58324240125196,
           46.63130477624445,
           46.67936715123694,
           46.72742952622943,
           46.77549190122192,
           46.82355427621441,
           46.8716166512069,
           46.91967902619939,
           46.96774140119187,
           47.01580377618437,
           47.06386615117685,
           47.11192852616935,
           47.159990901161834,
           47.20805327615433,
           47.256115651146814,
           47.30417802613931,
           47.352240401131795,
           47.400302776124285,
           47.448365151116775,
           47.49642752610926,
           47.544489901101755,
           47.59255227609424,
           47.64061465108673,
           47.68867702607923,
           47.73673940107171,
           47.784801776064214,
           47.8328641510567,
           47.88092652604918,
           47.92898890104168,
           47.97705127603416,
           48.02511365102666,
           48.07317602601914,
           48.12123840101163,
           48.16930077600412,
           48.21736315099661,
           48.2654255259891,
           48.3134879009816,
           48.36155027597408,
           48.40961265096657,
           48.45767502595906,
           48.50573740095155,
           48.55379977594404,
           48.601862150936526,
           48.64992452592902,
           48.69798690092151,
           48.746049275914,
           48.794111650906494,
           48.84217402589898,
           48.89023640089147,
           48.93829877588395,
           48.98636115087645,
           49.03442352586894,
           49.07866693912056,
           49.12214656002401,
           49.16562618092744,
           49.20910580183089,
           49.252585422734334,
           49.296065043637775,
           49.33954466454122,
           49.38302428544467,
           49.42650390634811,
           49.46998352725156,
           49.513463148155,
           49.55694276905844,
           49.60042238996189,
           49.64390201086533,
           49.68738163176879,
           49.73086125267223,
           49.774340873575674,
           49.817820494479115,
           49.86130011538256,
           49.90477973628601,
           49.94825935718946,
           49.9917389780929,
           50.03521859899634,
           50.07869821989978,
           50.12217784080323,
           50.16565746170667,
           50.20913708261012,
           50.25261670351357,
           50.29609632441701,
           50.339575945320455,
           50.383055566223895,
           50.42653518712734,
           50.47001480803078,
           50.51349442893422,
           50.55697404983768,
           50.60045367074112,
           50.64393329164457,
           50.68741291254801,
           50.73089253345145,
           50.7743721543549,
           50.81785177525834,
           50.86133139616179,
           50.904811017065235,
           50.94829063796868,
           50.99177025887212,
           51.03524987977557,
           51.07872950067902,
           51.12220912158246,
           51.165688742485905,
           51.20916836338935,
           51.25264798429279,
           51.29612760519624,
           51.33960722609969,
           51.38308684700313,
           51.426566467906575,
           51.47004608881002,
           51.51352570971347,
           51.55700533061692,
           51.60048495152035,
           51.6439645724238,
           51.687444193327245,
           51.730923814230685,
           51.77440343513413,
           51.81788305603758,
           51.86136267694102,
           51.90484229784447,
           51.94832191874791,
           51.991801539651355,
           52.0352811605548,
           52.07876078145825,
           52.1222404023617,
           52.16572002326514,
           52.209199644168585,
           52.25267926507203,
           52.29615888597547,
           52.33963850687891,
           52.38311812778236,
           52.42682885541854,
           52.47100179993721,
           52.51517474445589,
           52.559347688974576,
           52.603520633493254,
           52.647693578011925,
           52.69294439477926,
           52.738734147670925,
           52.78452390056258,
           52.83031365345425,
           52.876103406345905,
           52.92189315923756,
           52.96768291212922,
           53.013472665020885,
           53.05926241791254,
           53.1050521708042,
           53.150841923695864,
           53.19663167658752,
           53.24242142947918,
           53.288211182370844,
           53.33400093526251,
           53.379790688154166,
           53.425580441045824,
           53.47137019393748,
           53.517159946829146,
           53.562949699720804,
           53.60873945261247,
           53.654529205504126,
           53.70031895839578,
           53.74610871128745,
           53.7918984641791,
           53.83768821707076,
           53.88347796996242,
           53.92926772285408,
           53.97505747574575,
           54.0208472286374,
           54.066636981529065,
           54.11242673442074,
           54.158216487312394,
           54.20400624020405,
           54.24979599309571,
           54.295585745987374,
           54.34137549887903,
           54.38708860612678,
           54.43269952148994,
           54.478310436853086,
           54.52392135221623,
           54.56953226757938,
           54.61514318294253,
           54.66075409830568,
           54.70636501366883,
           54.75197592903197,
           54.79758684439512,
           54.843197759758276,
           54.888808675121425,
           54.93441959048457,
           54.980030505847715,
           55.025641421210864,
           55.07125233657401,
           55.11686325193717,
           55.1624741673003,
           55.20808508266346,
           55.25369599802661,
           55.29930691338975,
           55.344917828752905,
           55.390528744116054,
           55.4361396594792,
           55.48175057484235,
           55.5273614902055,
           55.57297240556865,
           55.6185833209318,
           55.66419423629494,
           55.709805151658095,
           55.75541606702124,
           55.801026982384386,
           55.84663789774753,
           55.89224881311068,
           55.93785972847383,
           55.98347064383698,
           56.02908155920013,
           56.07469247456328,
           56.12030338992643,
           56.165914305289576,
           56.211525220652724,
           56.25713613601587,
           56.30274705137903,
           56.34835796674217,
           56.39396888210532,
           56.43957979746847,
           56.439229931611415,
           56.392919284534166,
           56.346608637456924,
           56.30029799037968,
           56.25398734330244,
           56.20767669622519,
           56.16136604914796,
           56.11505540207071,
           56.06874475499347,
           56.022434107916226,
           55.97612346083898,
           55.92981281376173,
           55.883502166684494,
           55.837191519607245,
           55.79088087253,
           55.74457022545276,
           55.69825957837552,
           55.65194893129827,
           55.60563828422104,
           55.559327637143795,
           55.502680924158796,
           55.44057365227839,
           55.378466380397995,
           55.31635910851759,
           55.254251836637195,
           55.192144564756795,
           55.13003729287639,
           55.06793002099599,
           55.00582274911559,
           54.94371547723519,
           54.88160820535478,
           54.81950093347437,
           54.75739366159398,
           54.69528638971357,
           54.63317911783318,
           54.57107184595277,
           54.508964574072365,
           54.44685730219197,
           54.38475003031157,
           54.32264275843117,
           54.26053548655077,
           54.19842821467037,
           54.136320942789965,
           54.07421367090957,
           54.012106399029165,
           53.94999912714877,
           53.887891855268364,
           53.82578458338796,
           53.763677311507564,
           53.70157003962716,
           53.639462767746764,
           53.57735549586636,
           53.515248223985964,
           53.45314095210556,
           53.39103368022515,
           53.328926408344756,
           53.26681913646435,
           53.20471186458395,
           53.14260459270355,
           53.080497320823156,
           53.01839004894274,
           52.95628277706235,
           52.89417550518195,
           52.83206823330155,
           52.76996096142114,
           52.70785368954074,
           52.645746417660334,
           52.583639145779934,
           52.52153187389954,
           52.45942460201913,
           52.39731733013873,
           52.335210058258326,
           52.27310278637793,
           52.210995514497526,
           52.14888824261713,
           52.08678097073673,
           52.024673698856326,
           51.962566426975926,
           51.900459155095525,
           51.838351883215125,
           51.77624461133472,
           51.714137339454325,
           51.65203006757392,
           51.465297121812924,
           51.029312828290905,
           50.59332853476887,
           50.15734424124682,
           49.72135994772479,
           49.28537565420277,
           48.8493913606807,
           48.41340706715863,
           47.97742277363665,
           47.54143848011458,
           47.10545418659252,
           46.6694698930705,
           46.23348559954847,
           45.797501306026405,
           45.36151701250438,
           44.92553271898235,
           44.48954842546029,
           44.053564131938266,
           43.61757983841624,
           43.18159554489417,
           42.74561125137211,
           42.309626957850085,
           41.87364266432806,
           41.437658370806,
           41.001674077283965,
           40.56568978376194,
           40.12970549023988,
           39.69372119671785,
           39.25773690319583,
           38.821752609673766,
           38.3857683161517,
           37.949784022629714,
           37.51379972910765,
           37.07781543558558,
           36.64183114206356,
           36.20584684854154,
           35.76986255501947,
           35.333878261497446,
           34.89789396797543,
           34.46190967445335,
           34.02592538093133,
           33.58994108740931,
           33.15395679388724,
           32.71797250036518,
           32.28198820684315,
           31.846003913321127,
           31.41001961979906,
           30.974035326277036,
           30.538051032755014,
           30.098668611628355,
           29.6590942782654,
           29.21951994490244,
           28.779945611539446,
           28.34037127817645,
           27.900796944813532,
           27.461222611450538,
           27.02164827808754,
           26.582073944724584,
           26.14249961136163,
           25.70292527799863,
           25.263350944635675,
           24.82377661127272,
           24.38420227790973,
           23.94462794454677,
           23.50505361118381,
           23.065479277820813,
           22.625904944457822,
           22.186330611094903,
           21.746756277731908,
           21.307181944368914,
           20.867607611005955,
           20.428033277643,
           19.988458944280005,
           19.54888461091705,
           19.10931027755409,
           18.669735944191096,
           18.230161610828098,
           17.790587277465185,
           17.351012944102187,
           16.91143861073919,
           16.471864277376234,
           16.03228994401328,
           15.592715610650282,
           15.198821359823423,
           15.033327521676764,
           14.867833683530105,
           14.702339845383449,
           14.53684600723682,
           14.371352169090162,
           14.205858330943505,
           14.040364492796877,
           13.87487065465022,
           13.70937681650356,
           13.543882978356933,
           13.378389140210274,
           13.212895302063616,
           13.047401463916957,
           12.88190762577033,
           12.71641378762367,
           12.550919949477013,
           12.385426111330386,
           12.219932273183726,
           12.05443843503707,
           11.888944596890441,
           11.723450758743784,
           11.557956920597125,
           11.392463082450497,
           11.226969244303838,
           11.06147540615718,
           10.895981568010521,
           10.730487729863894,
           10.564993891717236,
           10.399500053570579,
           10.23400621542395,
           10.06851237727729,
           9.903018539130635,
           9.737524700984007,
           9.572030862837348,
           9.406537024690689,
           9.241043186544033,
           9.075549348397402,
           8.910055510250745,
           8.744561672104089,
           8.601956624411685,
           8.475700586356206,
           8.349444548300728,
           8.223188510245272,
           8.125203006137015,
           8.047410896685582,
           7.969618787234164,
           7.891826677782731,
           7.814034568331298,
           7.736242458879865,
           7.658450349428447,
           7.580658239977013,
           7.50286613052558,
           7.4250740210741615,
           7.347281911622729,
           7.269489802171297,
           7.1916976927198775,
           7.113905583268444,
           7.036113473817013,
           6.958321364365578,
           6.88052925491416,
           6.802737145462727,
           6.724945036011294,
           6.647152926559874,
           6.569360817108443,
           6.491568707657009,
           6.413776598205591,
           6.335984488754158,
           6.258192379302725,
           6.180400269851306,
           6.102608160399873,
           6.02481605094844,
           5.947023941497007,
           5.869231832045588,
           5.7914397225941565,
           5.713647613142724,
           5.635855503691305,
           5.558063394239872,
           5.480271284788438,
           5.40247917533702,
           5.324687065885587,
           5.246894956434154,
           5.16910284698272,
           5.091310737531303
          ],
          [
           45.386244058263784,
           45.43557116729457,
           45.48489827632535,
           45.53422538535614,
           45.583552494386936,
           45.63287960341772,
           45.6822067124485,
           45.73153382147929,
           45.78086093051008,
           45.830188039540865,
           45.879515148571656,
           45.92884225760244,
           45.978169366633225,
           46.02749647566401,
           46.0768235846948,
           46.126150693725585,
           46.175477802756376,
           46.22480491178716,
           46.274132020817945,
           46.32345912984873,
           46.37278623887952,
           46.422113347910305,
           46.47144045694108,
           46.519713619070906,
           46.56777599406339,
           46.61583836905588,
           46.66390074404838,
           46.71196311904087,
           46.76002549403335,
           46.80808786902584,
           46.85615024401832,
           46.90421261901082,
           46.95227499400331,
           47.00033736899581,
           47.048399743988284,
           47.09646211898078,
           47.144524493973265,
           47.19258686896576,
           47.24064924395825,
           47.288711618950735,
           47.336773993943225,
           47.384836368935716,
           47.432898743928206,
           47.4809611189207,
           47.529023493913186,
           47.57708586890568,
           47.62514824389817,
           47.67321061889066,
           47.72127299388315,
           47.76933536887564,
           47.81739774386813,
           47.86546011886061,
           47.91352249385311,
           47.96158486884559,
           48.00964724383809,
           48.05770961883057,
           48.10577199382307,
           48.15383436881555,
           48.20189674380804,
           48.24995911880053,
           48.29802149379302,
           48.34608386878551,
           48.394146243778,
           48.44220861877049,
           48.49027099376298,
           48.538333368755474,
           48.58639574374796,
           48.634458118740454,
           48.682520493732945,
           48.730582868725435,
           48.77864524371792,
           48.82670761871041,
           48.8747699937029,
           48.922832368695396,
           48.97089474368788,
           49.01895711868037,
           49.06701949367286,
           49.11508186866534,
           49.16314424365784,
           49.21120661865033,
           49.25926899364282,
           49.30733136863531,
           49.3553937436278,
           49.403456118620284,
           49.447699531871905,
           49.49117915277535,
           49.53465877367879,
           49.57813839458224,
           49.62161801548568,
           49.66509763638912,
           49.708577257292575,
           49.752056878196015,
           49.795536499099455,
           49.83901612000291,
           49.88249574090635,
           49.92597536180979,
           49.969454982713245,
           50.012934603616685,
           50.05641422452014,
           50.09989384542358,
           50.14337346632702,
           50.18685308723046,
           50.230332708133915,
           50.273812329037355,
           50.317291949940795,
           50.36077157084425,
           50.40425119174769,
           50.44773081265113,
           50.491210433554585,
           50.534690054458025,
           50.578169675361465,
           50.62164929626491,
           50.66512891716836,
           50.7086085380718,
           50.75208815897525,
           50.795567779878695,
           50.839047400782135,
           50.88252702168558,
           50.92600664258903,
           50.96948626349247,
           51.012965884395925,
           51.056445505299365,
           51.099925126202805,
           51.14340474710625,
           51.18688436800969,
           51.23036398891313,
           51.27384360981658,
           51.31732323072003,
           51.360802851623475,
           51.404282472526916,
           51.44776209343036,
           51.49124171433381,
           51.53472133523725,
           51.5782009561407,
           51.621680577044145,
           51.665160197947586,
           51.70863981885103,
           51.75211943975448,
           51.79559906065793,
           51.83907868156137,
           51.882558302464815,
           51.92603792336826,
           51.969517544271696,
           52.01299716517514,
           52.05647678607859,
           52.10053417563678,
           52.144707120155466,
           52.188880064674144,
           52.23305300919283,
           52.27722595371151,
           52.32139889823018,
           52.365571842748864,
           52.409744787267535,
           52.45391773178621,
           52.4980906763049,
           52.54226362082357,
           52.58643656534225,
           52.630609509860925,
           52.67478245437961,
           52.71895539889829,
           52.76312834341696,
           52.807301287935644,
           52.85147423245432,
           52.895647176973,
           52.93982012149168,
           52.983993066010356,
           53.028166010529034,
           53.07341682729637,
           53.11920658018802,
           53.164996333079685,
           53.21078608597135,
           53.256575838863014,
           53.302365591754665,
           53.34815534464633,
           53.393945097537994,
           53.43973485042965,
           53.48552460332131,
           53.531314356212974,
           53.577104109104624,
           53.62289386199629,
           53.668683614887954,
           53.71447336777961,
           53.76026312067127,
           53.80605287356293,
           53.85184262645459,
           53.89763237934625,
           53.94342213223791,
           53.98921188512957,
           54.035001638021235,
           54.08079139091289,
           54.12658114380455,
           54.172370896696215,
           54.21816064958788,
           54.26395040247953,
           54.30974015537119,
           54.35552990826285,
           54.40131966115452,
           54.447109414046174,
           54.49289916693783,
           54.53868891982949,
           54.584478672721154,
           54.63026842561281,
           54.676058178504476,
           54.721847931396134,
           54.767637684287784,
           54.81342743717945,
           54.859217190071114,
           54.90500694296278,
           54.950796695854436,
           54.996586448746086,
           55.04237620163776,
           55.088165954529416,
           55.13395570742107,
           55.17974546031273,
           55.225535213204395,
           55.27132496609605,
           55.31711471898771,
           55.362904471879375,
           55.40869422477104,
           55.4544839776627,
           55.50027373055435,
           55.54606348344602,
           55.591853236337684,
           55.637642989229334,
           55.683432742121,
           55.729222495012664,
           55.775012247904314,
           55.82080200079598,
           55.86659175368763,
           55.912381506579294,
           55.95817125947096,
           56.00396101236261,
           56.04975076525428,
           56.09554051814594,
           56.141330271037596,
           56.18712002392926,
           56.232909776820925,
           56.27869952971258,
           56.32448928260424,
           56.3703376876308,
           56.41620913455801,
           56.46208058148522,
           56.507952028412426,
           56.553823475339634,
           56.599694922266856,
           56.64556636919406,
           56.691437816121265,
           56.73730926304848,
           56.78318070997569,
           56.829052156902904,
           56.81570018652639,
           56.743124798846175,
           56.67054941116596,
           56.59797402348574,
           56.525398635805516,
           56.452823248125306,
           56.38024786044509,
           56.30767247276487,
           56.23509708508464,
           56.162521697404436,
           56.08994630972422,
           56.017370922044,
           55.944795534363784,
           55.87222014668357,
           55.79964475900334,
           55.72706937132313,
           55.65449398364292,
           55.5819185959627,
           55.50934320828249,
           55.43676782060227,
           55.364192432922046,
           55.29161704524182,
           55.21904165756162,
           55.1464662698814,
           55.073890882201184,
           55.001315494520966,
           54.92874010684074,
           54.856164719160525,
           54.78358933148031,
           54.711013943800104,
           54.63843855611987,
           54.56586316843966,
           54.493287780759445,
           54.42071239307923,
           54.348137005399,
           54.27556161771879,
           54.202986230038576,
           54.13041084235836,
           54.05783545467814,
           53.985260066997924,
           53.92029787825507,
           53.85819060637468,
           53.79608333449427,
           53.73397606261386,
           53.67186879073346,
           53.60976151885307,
           53.54765424697267,
           53.48554697509226,
           53.42343970321186,
           53.36133243133146,
           53.29922515945106,
           53.23711788757066,
           53.175010615690255,
           53.11290334380986,
           53.050796071929454,
           52.988688800049054,
           52.926581528168654,
           52.864474256288254,
           52.802366984407854,
           52.740259712527454,
           52.67815244064705,
           52.616045168766654,
           52.553937896886254,
           52.491830625005846,
           52.42972335312544,
           52.367616081245046,
           52.30550880936464,
           52.24340153748423,
           52.18129426560384,
           52.11918699372344,
           52.05707972184303,
           51.99497244996263,
           51.93286517808224,
           51.87075790620183,
           51.80865063432143,
           51.74654336244103,
           51.684436090560624,
           51.622328818680224,
           51.56022154679982,
           51.49811427491943,
           51.436007003039016,
           51.373899731158616,
           51.311792459278216,
           51.12505951351722,
           50.6890752199952,
           50.25309092647318,
           49.81710663295111,
           49.38112233942909,
           48.94513804590706,
           48.509153752385004,
           48.07316945886293,
           47.63718516534095,
           47.201200871818884,
           46.765216578296815,
           46.3292322847748,
           45.893247991252764,
           45.4572636977307,
           45.02127940420868,
           44.58529511068666,
           44.14931081716459,
           43.713326523642564,
           43.27734223012054,
           42.84135793659847,
           42.405373643076416,
           41.96938934955438,
           41.533405056032365,
           41.09742076251029,
           40.66143646898827,
           40.225452175466245,
           39.789467881944184,
           39.35348358842216,
           38.917499294900125,
           38.48151500137807,
           38.045530707855995,
           37.60954641433402,
           37.17356212081195,
           36.73757782728988,
           36.30159353376786,
           35.86560924024583,
           35.42962494672377,
           34.993640653201744,
           34.557656359679726,
           34.12167206615766,
           33.68568777263563,
           33.249703479113606,
           32.81371918559154,
           32.377734892069476,
           31.94175059854745,
           31.505766305025425,
           31.069782011503357,
           30.633797717981334,
           30.197813424459312,
           29.761829130937247,
           29.325844837415225,
           28.8898605438932,
           28.453876250371135,
           28.01789195684907,
           27.58190766332708,
           27.14592336980502,
           26.70993907628295,
           26.273954782760924,
           25.837970489238906,
           25.401986195716837,
           24.96600190219481,
           24.53001760867279,
           24.094033315150725,
           23.658049021628695,
           23.222064728106673,
           22.78608043458461,
           22.350096141062544,
           21.91411184754056,
           21.478127554018496,
           21.04214326049643,
           20.606158966974405,
           20.170174673452383,
           19.734190379930318,
           19.298206086408292,
           18.862221792886267,
           18.4262374993642,
           17.990253205842134,
           17.554268912320154,
           17.118284618798082,
           16.682300325276017,
           16.247143343426675,
           15.812222751836053,
           15.377302160245398,
           14.988712772250532,
           14.851824744083036,
           14.7322320208391,
           14.612639297595164,
           14.493046574351249,
           14.373453851107312,
           14.253861127863379,
           14.134268404619464,
           14.014675681375527,
           13.895082958131592,
           13.775490234887677,
           13.65589751164374,
           13.536304788399804,
           13.416712065155867,
           13.297119341911953,
           13.177526618668017,
           13.05793389542408,
           12.938341172180166,
           12.81874844893623,
           12.699155725692293,
           12.57956300244838,
           12.459970279204445,
           12.340377555960506,
           12.220784832716593,
           12.101192109472656,
           11.98159938622872,
           11.862006662984784,
           11.742413939740869,
           11.622821216496932,
           11.503228493252998,
           11.383635770009082,
           11.264043046765146,
           11.144450323521209,
           11.024857600277295,
           10.905264877033359,
           10.785672153789422,
           10.666079430545487,
           10.546486707301574,
           10.426893984057635,
           10.307301260813698,
           10.187708537569785,
           10.068115814325846,
           9.948523091081912,
           9.828930367837996,
           9.709337644594061,
           9.589744921350125,
           9.47015219810621,
           9.350559474862273,
           9.230966751618336,
           9.111374028374401,
           8.991781305130488,
           8.872188581886551,
           8.752595858642614,
           8.633003135398699,
           8.513410412154764,
           8.39381768891083,
           8.274224965666914,
           8.154632242422977,
           8.03503951917904,
           7.915446795935104,
           7.79585407269119,
           7.676261349447254,
           7.556668626203317,
           7.437075902959403,
           7.317483179715467,
           7.19789045647153,
           7.0782977332276165,
           6.95870500998368,
           6.839112286739743,
           6.719519563495829,
           6.599926840251893,
           6.480334117007956,
           6.3607413937640205,
           6.241148670520106,
           6.121555947276169,
           6.001963224032234,
           5.882370500788319,
           5.762777777544383,
           5.643185054300447,
           5.523592331056532,
           5.403999607812596,
           5.284406884568659,
           5.164814161324723,
           5.074147625712663
          ],
          [
           45.73440853917457,
           45.78373564820535,
           45.833062757236135,
           45.88238986626692,
           45.93171697529771,
           45.981044084328495,
           46.03037119335929,
           46.07969830239007,
           46.129025411420855,
           46.17835252045164,
           46.22767962948243,
           46.277006738513215,
           46.32633384754401,
           46.37566095657479,
           46.424988065605575,
           46.47431517463636,
           46.523642283667144,
           46.57296939269794,
           46.62229650172873,
           46.67162361075951,
           46.720950719790295,
           46.77027782882108,
           46.819604937851864,
           46.86893204688266,
           46.91825915591345,
           46.96758626494423,
           47.016913373975015,
           47.0662404830058,
           47.11556759203659,
           47.16489470106738,
           47.21422181009817,
           47.26354891912895,
           47.312876028159735,
           47.36220313719052,
           47.41153024622131,
           47.460857355252095,
           47.51018446428289,
           47.55951157331367,
           47.608838682344455,
           47.6577442117021,
           47.70580658669459,
           47.75386896168709,
           47.80193133667958,
           47.84999371167206,
           47.898056086664546,
           47.94611846165704,
           47.994180836649534,
           48.04224321164203,
           48.09030558663451,
           48.138367961627,
           48.186430336619495,
           48.234492711611985,
           48.282555086604475,
           48.33061746159696,
           48.37867983658945,
           48.42674221158194,
           48.47480458657443,
           48.52286696156692,
           48.57092933655941,
           48.6189917115519,
           48.66705408654438,
           48.71511646153688,
           48.76317883652937,
           48.81124121152186,
           48.85930358651435,
           48.907365961506834,
           48.955428336499324,
           49.00349071149182,
           49.051553086484304,
           49.0996154614768,
           49.147677836469285,
           49.195740211461775,
           49.243802586454265,
           49.291864961446755,
           49.339927336439246,
           49.387989711431736,
           49.436052086424226,
           49.484114461416716,
           49.53217683640921,
           49.58023921140169,
           49.62830158639419,
           49.67636396138667,
           49.72442633637917,
           49.77248871137165,
           49.81673212462327,
           49.86021174552671,
           49.90369136643015,
           49.94717098733361,
           49.99065060823705,
           50.034130229140494,
           50.07760985004394,
           50.12108947094738,
           50.16456909185082,
           50.20804871275427,
           50.25152833365772,
           50.29500795456116,
           50.33848757546461,
           50.38196719636805,
           50.4254468172715,
           50.46892643817495,
           50.51240605907839,
           50.555885679981834,
           50.59936530088528,
           50.64284492178872,
           50.68632454269216,
           50.72980416359561,
           50.77328378449906,
           50.8167634054025,
           50.860243026305945,
           50.90372264720939,
           50.94720226811283,
           50.99068188901628,
           51.03416150991973,
           51.077641130823174,
           51.121120751726615,
           51.16460037263006,
           51.2080799935335,
           51.25155961443694,
           51.2950392353404,
           51.33851885624384,
           51.381998477147285,
           51.425478098050725,
           51.468957718954165,
           51.51243733985761,
           51.55591696076105,
           51.59939658166451,
           51.642876202567955,
           51.686355823471395,
           51.730066551336364,
           51.77423949585505,
           51.81841244037373,
           51.86258538489241,
           51.90675832941108,
           51.95093127392976,
           51.99510421844844,
           52.03927716296712,
           52.083450107485795,
           52.12762305200448,
           52.17179599652315,
           52.21596894104184,
           52.260141885560515,
           52.30431483007919,
           52.348487774597864,
           52.39266071911654,
           52.43683366363523,
           52.481006608153905,
           52.52517955267258,
           52.56935249719126,
           52.61352544170994,
           52.65769838622862,
           52.701871330747295,
           52.74604427526597,
           52.79021721978465,
           52.83439016430333,
           52.87856310882201,
           52.922736053340685,
           52.96690899785936,
           53.01108194237804,
           53.05525488689672,
           53.0994278314154,
           53.143600775934075,
           53.18777372045275,
           53.23194666497143,
           53.27611960949011,
           53.32029255400879,
           53.36446549852747,
           53.408638443046144,
           53.45388925981349,
           53.499679012705144,
           53.54546876559681,
           53.591258518488466,
           53.637048271380124,
           53.68283802427179,
           53.72862777716345,
           53.77441753005511,
           53.82020728294677,
           53.86599703583842,
           53.91178678873008,
           53.95757654162175,
           54.00336629451341,
           54.04915604740507,
           54.09494580029673,
           54.14073555318839,
           54.18652530608005,
           54.232315058971714,
           54.27810481186337,
           54.32389456475502,
           54.36968431764669,
           54.41547407053835,
           54.46126382343001,
           54.50705357632167,
           54.552843329213324,
           54.59863308210498,
           54.64442283499665,
           54.69021258788831,
           54.73600234077997,
           54.781792093671626,
           54.82758184656329,
           54.873371599454956,
           54.91916135234661,
           54.96495110523827,
           55.010740858129935,
           55.056530611021586,
           55.10232036391325,
           55.148110116804915,
           55.193899869696565,
           55.23968962258823,
           55.28547937547989,
           55.331269128371545,
           55.37705888126322,
           55.42284863415487,
           55.46863838704653,
           55.51442813993819,
           55.56021789282985,
           55.60600764572152,
           55.651797398613176,
           55.697587151504834,
           55.7433769043965,
           55.78916665728816,
           55.83497107319418,
           55.880842520121384,
           55.92671396704861,
           55.972585413975814,
           56.01845686090303,
           56.064328307830245,
           56.110199754757446,
           56.15607120168466,
           56.20194264861187,
           56.24781409553907,
           56.293685542466285,
           56.3395569893935,
           56.38542843632071,
           56.43129988324792,
           56.47717133017513,
           56.52304277710235,
           56.568914224029555,
           56.61478567095676,
           56.66065711788397,
           56.70652856481118,
           56.7524000117384,
           56.79827145866561,
           56.84414290559282,
           56.890014352520026,
           56.935885799447234,
           56.98175724637446,
           57.02762869330166,
           57.073500140228866,
           57.11937158715608,
           57.16524303408329,
           57.211114481010505,
           57.19776251063399,
           57.125187122953776,
           57.05261173527356,
           56.98003634759334,
           56.90746095991312,
           56.834885572232906,
           56.762310184552696,
           56.68973479687247,
           56.61715940919225,
           56.54458402151204,
           56.47200863383182,
           56.3994332461516,
           56.326857858471385,
           56.25428247079117,
           56.18170708311095,
           56.10913169543073,
           56.036556307750516,
           55.9639809200703,
           55.89140553239008,
           55.818830144709864,
           55.74625475702965,
           55.67367936934943,
           55.60110398166922,
           55.528528593988995,
           55.45595320630878,
           55.38337781862856,
           55.31080243094835,
           55.238227043268125,
           55.16565165558791,
           55.093076267907705,
           55.02050088022747,
           54.94792549254726,
           54.87535010486705,
           54.802774717186836,
           54.730199329506604,
           54.65762394182639,
           54.58504855414618,
           54.512473166465966,
           54.43989777878574,
           54.36732239110553,
           54.2947470034253,
           54.22217161574509,
           54.14959622806488,
           54.07702084038466,
           54.00444545270443,
           53.93187006502423,
           53.859294677344,
           53.78671928966379,
           53.71414390198357,
           53.64156851430336,
           53.56899312662314,
           53.496417738942924,
           53.42384235126271,
           53.35126696358249,
           53.27869157590227,
           53.206116188222055,
           53.13354080054183,
           53.06096541286162,
           52.9883900251814,
           52.915814637501185,
           52.84323924982096,
           52.77066386214075,
           52.69808847446053,
           52.625513086780316,
           52.552937699100106,
           52.48036231141989,
           52.407786923739664,
           52.33521153605945,
           52.26263614837924,
           52.19006076069901,
           52.117485373018795,
           52.04490998533858,
           51.97233459765837,
           51.88831901083758,
           51.78662295638165,
           51.68492690192572,
           51.58323084746979,
           51.48153479301387,
           51.379838738557936,
           51.27814268410201,
           51.17644662964607,
           51.07475057519014,
           50.97305452073421,
           50.76205469165607,
           50.332447313333624,
           49.90283993501117,
           49.473232556688686,
           49.043625178366234,
           48.6140178000438,
           48.1844104217213,
           47.75480304339882,
           47.325195665076414,
           46.895588286753934,
           46.46598090843143,
           46.03637353010899,
           45.60676615178655,
           45.177158773464065,
           44.74622307578132,
           44.3113024841907,
           43.87638189260004,
           43.441461301009426,
           43.00654070941881,
           42.571620117828154,
           42.136699526237486,
           41.701778934646875,
           41.26685834305625,
           40.831937751465595,
           40.39701715987498,
           39.962096568284366,
           39.5271759766937,
           39.09225538510309,
           38.65733479351246,
           38.22241420192181,
           37.78749361033115,
           37.352573018740564,
           36.91765242714991,
           36.48273183555925,
           36.04781124396863,
           35.61289065237801,
           35.17797006078735,
           34.74304946919674,
           34.308128877606116,
           33.873208286015455,
           33.438287694424844,
           33.00336710283422,
           32.568446511243565,
           32.133525919652904,
           31.698605328062285,
           31.263684736471667,
           30.828764144881006,
           30.39384355329039,
           29.958922961699777,
           29.524002370109116,
           29.089081778518498,
           28.654161186927873,
           28.21924059533722,
           27.784320003746558,
           27.34939941215598,
           26.91447882056532,
           26.479558228974664,
           26.044637637384042,
           25.609717045793428,
           25.174796454202767,
           24.73987586261215,
           24.30495527102153,
           23.870034679430873,
           23.435114087840255,
           23.000193496249633,
           22.565272904658976,
           22.130352313068318,
           21.69543172147774,
           21.260511129887085,
           20.82559053829642,
           20.390669946705806,
           19.955749355115188,
           19.520828763524527,
           19.08590817193391,
           18.650987580343287,
           18.21606698875263,
           17.781146397161976,
           17.346225805571397,
           16.91130521398074,
           16.476384622390075,
           16.04146403079946,
           15.60654343920884,
           15.171622847618185,
           14.783033459623319,
           14.626100089606929,
           14.46916671959054,
           14.31223334957415,
           14.155299979557793,
           13.998366609541403,
           13.841433239525013,
           13.684499869508656,
           13.527566499492266,
           13.370633129475875,
           13.213699759459516,
           13.056766389443126,
           12.899833019426739,
           12.742899649410347,
           12.585966279393988,
           12.4290329093776,
           12.27209953936121,
           12.115166169344851,
           11.958232799328464,
           11.801299429312074,
           11.644366059295713,
           11.487432689279323,
           11.330499319262934,
           11.191223161332092,
           11.071630438088155,
           10.952037714844218,
           10.832444991600283,
           10.712852268356368,
           10.593259545112433,
           10.473666821868497,
           10.354074098624581,
           10.234481375380645,
           10.11488865213671,
           9.995295928892794,
           9.875703205648858,
           9.756110482404921,
           9.636517759160986,
           9.516925035917073,
           9.397332312673136,
           9.2777395894292,
           9.158146866185286,
           9.038554142941349,
           8.91896141969741,
           8.799368696453497,
           8.679775973209562,
           8.560183249965625,
           8.44059052672171,
           8.320997803477773,
           8.201405080233837,
           8.081812356989902,
           7.962219633745987,
           7.842626910502052,
           7.723034187258115,
           7.6034414640142005,
           7.483848740770263,
           7.364256017526328,
           7.244663294282413,
           7.125070571038477,
           7.005477847794541,
           6.8858851245506045,
           6.76629240130669,
           6.67856307541961,
           6.604896378692256,
           6.531229681964917,
           6.457562985237564,
           6.383896288510211,
           6.31022959178287,
           6.236562895055518,
           6.1628961983281645,
           6.089229501600824,
           6.015562804873471,
           5.941896108146118,
           5.868229411418765,
           5.794562714691426,
           5.720896017964073,
           5.64722932123672,
           5.57356262450938,
           5.499895927782026,
           5.4262292310546725,
           5.352562534327333,
           5.278895837599981,
           5.205229140872627,
           5.131562444145274,
           5.057895747417934
          ],
          [
           46.082573020085334,
           46.13190012911612,
           46.1812272381469,
           46.23055434717769,
           46.27988145620848,
           46.32920856523926,
           46.378535674270054,
           46.42786278330084,
           46.47718989233163,
           46.526517001362414,
           46.575844110393206,
           46.62517121942398,
           46.674498328454774,
           46.72382543748556,
           46.77315254651634,
           46.822479655547134,
           46.87180676457792,
           46.92113387360871,
           46.970460982639494,
           47.019788091670286,
           47.06911520070106,
           47.118442309731854,
           47.16776941876264,
           47.21709652779343,
           47.266423636824214,
           47.315750745855,
           47.36507785488578,
           47.414404963916574,
           47.463732072947366,
           47.51305918197815,
           47.562386291008934,
           47.61171340003972,
           47.6610405090705,
           47.71036761810129,
           47.75969472713208,
           47.80902183616286,
           47.858348945193654,
           47.90767605422444,
           47.95700316325524,
           48.006330272286014,
           48.0556573813168,
           48.10498449034759,
           48.154311599378374,
           48.20363870840916,
           48.25296581743994,
           48.30229292647073,
           48.35162003550152,
           48.4009471445323,
           48.450274253563094,
           48.49960136259388,
           48.54892847162466,
           48.598255580655454,
           48.64758268968624,
           48.69690979871702,
           48.746236907747814,
           48.7955640167786,
           48.843837179325774,
           48.89189955431827,
           48.93996192931076,
           48.988024304303245,
           49.03608667929574,
           49.08414905428823,
           49.132211429280716,
           49.18027380427321,
           49.228336179265696,
           49.276398554258186,
           49.32446092925068,
           49.37252330424317,
           49.42058567923566,
           49.46864805422814,
           49.51671042922064,
           49.56477280421312,
           49.61283517920562,
           49.66089755419811,
           49.7089599291906,
           49.75702230418308,
           49.80508467917557,
           49.85314705416806,
           49.90120942916055,
           49.94927180415304,
           49.99733417914553,
           50.04539655413802,
           50.093458929130506,
           50.141521304123,
           50.185764717374624,
           50.229244338278065,
           50.27272395918151,
           50.31620358008496,
           50.3596832009884,
           50.40316282189184,
           50.44664244279529,
           50.490122063698735,
           50.533601684602175,
           50.57708130550562,
           50.62056092640907,
           50.66404054731251,
           50.707520168215964,
           50.750999789119405,
           50.79447941002285,
           50.8379590309263,
           50.88143865182974,
           50.92491827273318,
           50.96839789363663,
           51.011877514540075,
           51.055357135443515,
           51.09883675634696,
           51.14231637725041,
           51.18579599815384,
           51.2292756190573,
           51.27275523996074,
           51.316234860864185,
           51.359714481767625,
           51.403771871554625,
           51.4479448160733,
           51.49211776059198,
           51.53629070511066,
           51.58046364962934,
           51.62463659414801,
           51.668809538666686,
           51.71298248318537,
           51.757155427704056,
           51.80132837222273,
           51.845501316741405,
           51.88967426126008,
           51.93384720577876,
           51.97802015029744,
           52.02219309481613,
           52.0663660393348,
           52.11053898385347,
           52.15471192837215,
           52.19888487289083,
           52.243057817409515,
           52.28723076192819,
           52.33140370644687,
           52.37557665096555,
           52.41974959548422,
           52.4639225400029,
           52.50809548452158,
           52.55226842904026,
           52.596441373558946,
           52.64061431807762,
           52.684787262596295,
           52.72896020711497,
           52.77313315163365,
           52.817306096152336,
           52.86147904067101,
           52.90565198518969,
           52.94982492970837,
           52.99399787422705,
           53.038170818745726,
           53.082343763264404,
           53.12651670778308,
           53.17068965230176,
           53.21486259682044,
           53.25903554133912,
           53.30320848585779,
           53.34738143037647,
           53.39155437489515,
           53.43572731941383,
           53.47990026393251,
           53.524073208451185,
           53.56824615296986,
           53.61241909748854,
           53.65659204200722,
           53.7007649865259,
           53.744937931044575,
           53.78911087556325,
           53.83436169233059,
           53.88015144522225,
           53.92594119811391,
           53.97173095100557,
           54.01752070389722,
           54.063310456788884,
           54.10910020968055,
           54.15488996257221,
           54.20067971546386,
           54.24646946835552,
           54.29225922124719,
           54.33804897413885,
           54.38383872703051,
           54.42962847992217,
           54.47541823281383,
           54.521207985705495,
           54.56699773859715,
           54.61278749148882,
           54.658577244380474,
           54.70436699727213,
           54.75015675016378,
           54.795946503055454,
           54.841736255947104,
           54.88752600883876,
           54.93331576173043,
           54.979105514622084,
           55.024895267513756,
           55.07068502040542,
           55.11647477329708,
           55.162264526188736,
           55.208054279080386,
           55.25384403197206,
           55.299633784863715,
           55.345475905684765,
           55.39134735261198,
           55.43721879953919,
           55.483090246466396,
           55.52896169339361,
           55.57483314032082,
           55.62070458724803,
           55.666576034175236,
           55.712447481102444,
           55.75831892802965,
           55.804190374956875,
           55.85006182188408,
           55.895933268811284,
           55.9418047157385,
           55.98767616266572,
           56.03354760959292,
           56.07941905652014,
           56.125290503447346,
           56.171161950374554,
           56.21703339730177,
           56.26290484422897,
           56.30877629115619,
           56.3546477380834,
           56.40051918501061,
           56.44639063193783,
           56.492262078865025,
           56.53813352579225,
           56.584004972719455,
           56.629876419646656,
           56.67574786657387,
           56.72161931350108,
           56.767490760428295,
           56.8133622073555,
           56.85923365428272,
           56.90510510120993,
           56.95097654813714,
           56.99684799506434,
           57.04271944199155,
           57.08859088891877,
           57.13446233584598,
           57.18033378277319,
           57.2262052297004,
           57.27207667662761,
           57.317948123554814,
           57.363819570482036,
           57.409691017409244,
           57.455562464336445,
           57.50143391126366,
           57.54730535819087,
           57.59317680511809,
           57.57982483474157,
           57.507249447061355,
           57.43467405938114,
           57.36209867170092,
           57.2895232840207,
           57.216947896340486,
           57.14437250866028,
           57.07179712098005,
           56.999221733299834,
           56.92664634561963,
           56.854070957939406,
           56.78149557025918,
           56.70892018257897,
           56.63634479489876,
           56.56376940721854,
           56.49119401953832,
           56.418618631858095,
           56.34604324417789,
           56.273467856497675,
           56.20089246881746,
           56.12831708113723,
           56.05574169345702,
           55.983166305776805,
           55.91059091809659,
           55.838015530416364,
           55.765440142736146,
           55.692864755055936,
           55.620289367375705,
           55.54771397969549,
           55.475138592015284,
           55.40256320433506,
           55.32998781665485,
           55.25741242897463,
           55.184837041294415,
           55.11226165361419,
           55.03968626593398,
           54.96711087825376,
           54.894535490573546,
           54.82196010289333,
           54.74938471521311,
           54.676809327532894,
           54.604233939852676,
           54.53165855217247,
           54.45908316449224,
           54.386507776812024,
           54.31393238913181,
           54.226796722977,
           54.12510066852106,
           54.02340461406514,
           53.921708559609215,
           53.82001250515328,
           53.71831645069735,
           53.61662039624142,
           53.51492434178549,
           53.41322828732956,
           53.31153223287364,
           53.2098361784177,
           53.108140123961775,
           53.00644406950583,
           52.90474801504992,
           52.803051960593976,
           52.70135590613805,
           52.59965985168213,
           52.49796379722619,
           52.39626774277026,
           52.29457168831434,
           52.19287563385841,
           52.091179579402464,
           51.98948352494655,
           51.88778747049062,
           51.78609141603469,
           51.68439536157876,
           51.58269930712283,
           51.481003252666895,
           51.37930719821097,
           51.27761114375504,
           51.17591508929911,
           51.07421903484319,
           50.97252298038726,
           50.870826925931325,
           50.76913087147539,
           50.66743481701946,
           50.565738762563534,
           50.35473893348538,
           49.925131555162935,
           49.49552417684049,
           49.065916798518,
           48.63630942019556,
           48.206702041873115,
           47.77709466355063,
           47.34748728522814,
           46.91787990690574,
           46.488272528583245,
           46.058665150260765,
           45.629057771938314,
           45.19945039361587,
           44.769843015293375,
           44.34023563697093,
           43.91062825864849,
           43.481020880326,
           43.051413502003555,
           42.62180612368111,
           42.192198745358624,
           41.76259136703614,
           41.332983988713686,
           40.903376610391234,
           40.47376923206875,
           40.0441618537463,
           39.61455447542386,
           39.18494709710137,
           38.75533971877893,
           38.325732340456476,
           37.896124962133996,
           37.46651758381151,
           37.0369102054891,
           36.60730282716661,
           36.177695448844126,
           35.748088070521675,
           35.31848069219923,
           34.88887331387674,
           34.4592659355543,
           34.029658557231855,
           33.60005117890936,
           33.17044380058691,
           32.740836422264465,
           32.31122904394198,
           31.88162166561949,
           31.452014287297047,
           31.0224069089746,
           30.592799530652115,
           30.163192152329664,
           29.73358477400722,
           29.303977395684733,
           28.87437001736229,
           28.444762639039837,
           28.013561282710008,
           27.578640691119354,
           27.14372009952877,
           26.708799507938117,
           26.273878916347464,
           25.838958324756838,
           25.404037733166227,
           24.96911714157556,
           24.534196549984948,
           24.099275958394326,
           23.66435536680367,
           23.22943477521305,
           22.794514183622432,
           22.35959359203177,
           21.924673000441114,
           21.489752408850535,
           21.05483181725988,
           20.61991122566922,
           20.1849906340786,
           19.750070042487984,
           19.315149450897323,
           18.880228859306705,
           18.445308267716083,
           18.01038767612543,
           17.575467084534772,
           17.140546492944193,
           16.70562590135353,
           16.27070530976287,
           15.835784718172256,
           15.40086412658164,
           14.96594353499098,
           14.577354146996115,
           14.420420776979725,
           14.263487406963334,
           14.106554036946948,
           13.949620666930587,
           13.792687296914197,
           13.635753926897808,
           13.47882055688145,
           13.321887186865059,
           13.164953816848671,
           13.00802044683231,
           12.851087076815922,
           12.694153706799531,
           12.537220336783143,
           12.380286966766784,
           12.223353596750396,
           12.066420226734007,
           11.909486856717646,
           11.75255348670126,
           11.595620116684868,
           11.438686746668509,
           11.28175337665212,
           11.12482000663573,
           10.96788663661937,
           10.810953266602983,
           10.654019896586593,
           10.497086526570204,
           10.340153156553844,
           10.183219786537455,
           10.026286416521065,
           9.869353046504706,
           9.712419676488317,
           9.555486306471927,
           9.398552936455566,
           9.24161956643918,
           9.08468619642279,
           8.962285314032764,
           8.84918154104365,
           8.736077768054514,
           8.622973995065378,
           8.509870222076264,
           8.396766449087128,
           8.283662676097991,
           8.170558903108876,
           8.05745513011974,
           7.944351357130606,
           7.83124758414149,
           7.718143811152355,
           7.6199782545804196,
           7.546311557853067,
           7.472644861125727,
           7.398978164398374,
           7.325311467671021,
           7.251644770943681,
           7.177978074216327,
           7.104311377488975,
           7.030644680761634,
           6.956977984034282,
           6.883311287306928,
           6.809644590579574,
           6.735977893852235,
           6.6623111971248825,
           6.588644500397529,
           6.514977803670188,
           6.441311106942837,
           6.367644410215482,
           6.293977713488143,
           6.22031101676079,
           6.146644320033436,
           6.072977623306096,
           5.999310926578744,
           5.92564422985139,
           5.851977533124037,
           5.778310836396698,
           5.704644139669345,
           5.630977442941991,
           5.557310746214652,
           5.483644049487298,
           5.409977352759945,
           5.336310656032606,
           5.262643959305253,
           5.1889772625778985,
           5.115310565850546,
           5.041643869123206
          ],
          [
           46.4307375009961,
           46.48006461002689,
           46.52939171905767,
           46.57871882808846,
           46.62804593711925,
           46.67737304615004,
           46.726700155180815,
           46.776027264211606,
           46.8253543732424,
           46.87468148227319,
           46.924008591303966,
           46.97333570033476,
           47.02266280936554,
           47.07198991839633,
           47.12131702742712,
           47.17064413645791,
           47.219971245488686,
           47.26929835451948,
           47.31862546355026,
           47.36795257258105,
           47.41727968161184,
           47.46660679064263,
           47.515933899673406,
           47.5652610087042,
           47.61458811773498,
           47.663915226765766,
           47.71324233579656,
           47.76256944482734,
           47.81189655385813,
           47.86122366288892,
           47.9105507719197,
           47.959877880950486,
           48.00920498998127,
           48.05853209901206,
           48.10785920804285,
           48.15718631707364,
           48.20651342610442,
           48.255840535135206,
           48.305167644166005,
           48.35449475319679,
           48.40382186222757,
           48.45314897125836,
           48.50247608028914,
           48.551803189319926,
           48.60113029835072,
           48.6504574073815,
           48.699784516412294,
           48.74911162544308,
           48.79843873447386,
           48.84776584350465,
           48.89709295253544,
           48.94642006156622,
           48.995747170597014,
           49.0450742796278,
           49.09440138865858,
           49.14372849768937,
           49.19305560672016,
           49.24238271575095,
           49.291709824781734,
           49.34103693381252,
           49.3903640428433,
           49.439691151874094,
           49.48901826090488,
           49.53834536993566,
           49.587672478966454,
           49.63699958799724,
           49.68632669702802,
           49.73565380605881,
           49.7849809150896,
           49.83430802412038,
           49.883635133151174,
           49.93296224218196,
           49.98186777195696,
           50.029930146949454,
           50.077992521941944,
           50.12605489693443,
           50.17411727192692,
           50.22217964691941,
           50.2702420219119,
           50.318304396904395,
           50.36636677189688,
           50.414429146889375,
           50.46249152188186,
           50.51055389687435,
           50.55479731012597,
           50.59827693102942,
           50.64175655193286,
           50.685236172836305,
           50.72871579373975,
           50.772195414643186,
           50.81567503554663,
           50.85915465645008,
           50.90263427735352,
           50.94611389825697,
           50.989593519160415,
           51.033304247254186,
           51.077477191772864,
           51.12165013629155,
           51.16582308081023,
           51.209996025328905,
           51.254168969847576,
           51.29834191436626,
           51.34251485888494,
           51.38668780340362,
           51.430860747922296,
           51.475033692440974,
           51.51920663695965,
           51.56337958147833,
           51.60755252599701,
           51.651725470515686,
           51.695898415034364,
           51.74007135955304,
           51.78424430407173,
           51.828417248590405,
           51.872590193109076,
           51.91676313762776,
           51.96093608214644,
           52.00510902666511,
           52.04928197118379,
           52.09345491570247,
           52.13762786022115,
           52.18180080473983,
           52.225973749258515,
           52.27014669377719,
           52.31431963829586,
           52.35849258281455,
           52.40266552733323,
           52.446838471851905,
           52.491011416370576,
           52.53518436088926,
           52.57935730540794,
           52.62353024992662,
           52.667703194445295,
           52.71187613896397,
           52.75604908348265,
           52.80022202800133,
           52.84439497252001,
           52.888567917038685,
           52.93274086155736,
           52.97691380607604,
           53.02108675059472,
           53.0652596951134,
           53.109432639632075,
           53.15360558415075,
           53.19777852866943,
           53.24195147318811,
           53.28612441770679,
           53.330297362225465,
           53.37447030674414,
           53.41864325126283,
           53.4628161957815,
           53.506989140300185,
           53.551162084818856,
           53.595335029337534,
           53.63950797385621,
           53.6836809183749,
           53.72785386289357,
           53.772026807412246,
           53.81619975193093,
           53.86037269644961,
           53.90454564096828,
           53.948718585486965,
           53.99289153000564,
           54.03706447452433,
           54.081237419043006,
           54.12541036356168,
           54.169583308080355,
           54.21483412484769,
           54.260623877739356,
           54.30641363063101,
           54.35220338352268,
           54.39799313641433,
           54.44378288930599,
           54.48957264219766,
           54.53536239508931,
           54.58115214798097,
           54.62694190087263,
           54.672731653764295,
           54.71852140665595,
           54.76431115954762,
           54.81010929124814,
           54.85598073817535,
           54.90185218510256,
           54.94772363202977,
           54.993595078956986,
           55.039466525884194,
           55.08533797281141,
           55.13120941973862,
           55.177080866665825,
           55.222952313593034,
           55.26882376052025,
           55.31469520744746,
           55.360566654374665,
           55.40643810130188,
           55.45230954822908,
           55.4981809951563,
           55.54405244208351,
           55.58992388901072,
           55.63579533593793,
           55.681666782865136,
           55.72753822979235,
           55.77340967671956,
           55.819281123646775,
           55.86515257057398,
           55.91102401750119,
           55.9568954644284,
           56.002766911355614,
           56.04863835828283,
           56.09450980521004,
           56.140381252137246,
           56.186252699064454,
           56.232124145991676,
           56.27799559291887,
           56.32386703984608,
           56.3697384867733,
           56.41560993370051,
           56.461481380627724,
           56.507352827554925,
           56.55322427448213,
           56.599095721409356,
           56.644967168336564,
           56.69083861526377,
           56.73671006219098,
           56.78258150911819,
           56.82845295604541,
           56.87432440297261,
           56.92019584989983,
           56.966067296827035,
           57.01193874375424,
           57.05781019068146,
           57.103681637608666,
           57.149553084535874,
           57.19542453146309,
           57.2412959783903,
           57.28716742531751,
           57.33303887224472,
           57.37891031917193,
           57.424781766099144,
           57.47065321302635,
           57.51652465995357,
           57.562396106880776,
           57.608267553807984,
           57.6541390007352,
           57.70001044766241,
           57.745881894589616,
           57.791753341516824,
           57.83762478844403,
           57.88349623537124,
           57.92936768229846,
           57.97523912922567,
           57.961887158849166,
           57.88931177116894,
           57.81673638348873,
           57.744160995808514,
           57.67158560812829,
           57.59901022044808,
           57.52643483276786,
           57.453859445087645,
           57.38128405740742,
           57.30870866972721,
           57.23613328204699,
           57.16355789436677,
           57.09098250668656,
           57.01840711900634,
           56.945831731326116,
           56.8732563436459,
           56.80068095596569,
           56.72810556828547,
           56.655530180605254,
           56.56527443511642,
           56.463578380660486,
           56.36188232620455,
           56.26018627174864,
           56.158490217292695,
           56.056794162836766,
           55.95509810838084,
           55.85340205392492,
           55.75170599946898,
           55.65000994501305,
           55.54831389055713,
           55.4466178361012,
           55.344921781645255,
           55.24322572718934,
           55.1415296727334,
           55.03983361827746,
           54.938137563821535,
           54.83644150936562,
           54.73474545490968,
           54.63304940045376,
           54.531353345997815,
           54.4296572915419,
           54.32796123708596,
           54.22626518263004,
           54.1245691281741,
           54.02287307371817,
           53.92117701926226,
           53.81948096480632,
           53.71778491035038,
           53.61608885589446,
           53.51439280143853,
           53.41269674698259,
           53.311000692526676,
           53.20930463807075,
           53.107608583614805,
           53.00591252915887,
           52.90421647470296,
           52.80252042024702,
           52.700824365791085,
           52.599128311335164,
           52.497432256879236,
           52.3957362024233,
           52.29404014796738,
           52.19234409351145,
           52.09064803905551,
           51.98895198459958,
           51.88725593014367,
           51.78555987568772,
           51.68386382123179,
           51.58216776677587,
           51.48047171231994,
           51.378775657864,
           51.277079603408076,
           51.175383548952155,
           51.07368749449621,
           50.97199144004029,
           50.870295385584356,
           50.76859933112843,
           50.66690327667251,
           50.56520722221658,
           50.46351116776064,
           50.36181511330471,
           50.26011905884878,
           50.15842300439285,
           49.947423175314704,
           49.51781579699226,
           49.08820841866981,
           48.65860104034732,
           48.22899366202488,
           47.79938628370243,
           47.36977890537994,
           46.94017152705746,
           46.51056414873504,
           46.08095677041256,
           45.65134939209008,
           45.22174201376763,
           44.79213463544519,
           44.36252725712271,
           43.93291987880025,
           43.503312500477804,
           43.07370512215532,
           42.64409774383287,
           42.21449036551042,
           41.784882987187935,
           41.355275608865455,
           40.925668230543,
           40.49606085222056,
           40.06645347389807,
           39.63684609557562,
           39.207238717253176,
           38.77763133893069,
           38.348023960608245,
           37.91841658228579,
           37.488809203963314,
           37.05920182564082,
           36.62959444731842,
           36.19998706899593,
           35.770379690673444,
           35.340772312351,
           34.91116493402855,
           34.48155755570606,
           34.05195017738362,
           33.62234279906117,
           33.19273542073868,
           32.763128042416234,
           32.33352066409378,
           31.903913285771303,
           31.474305907448812,
           31.044698529126364,
           30.61509115080392,
           30.185483772481433,
           29.75587639415898,
           29.326269015836537,
           28.896661637514054,
           28.467054259191606,
           28.037446880869155,
           27.60783950254667,
           27.178232124224188,
           26.74862474590178,
           26.319017367579292,
           25.889409989256805,
           25.459802610934357,
           25.03019523261191,
           24.600587854289426,
           24.170980475966978,
           23.74137309764453,
           23.311765719322043,
           22.8821583409996,
           22.452752043208022,
           22.02511897125192,
           21.597485899295812,
           21.169852827339792,
           20.742219755383687,
           20.314586683427585,
           19.886953611471522,
           19.45932053951546,
           19.031687467559358,
           18.604054395603296,
           18.176421323647233,
           17.748788251691128,
           17.32115517973503,
           16.893522107779003,
           16.465889035822904,
           16.038255963866796,
           15.610622891910733,
           15.182989819954674,
           14.755356747998567,
           14.374251153810603,
           14.22578294846284,
           14.077314743115078,
           13.928846537767315,
           13.780737772252756,
           13.667633999263622,
           13.554530226274485,
           13.44142645328537,
           13.328322680296235,
           13.2152189073071,
           13.102115134317984,
           12.98901136132885,
           12.875907588339713,
           12.762803815350576,
           12.649700042361461,
           12.536596269372327,
           12.423492496383192,
           12.310388723394077,
           12.19728495040494,
           12.084181177415804,
           11.971077404426689,
           11.857973631437552,
           11.744869858448418,
           11.631766085459303,
           11.518662312470166,
           11.40555853948103,
           11.292454766491895,
           11.17935099350278,
           11.066247220513644,
           10.953143447524507,
           10.840039674535394,
           10.726935901546257,
           10.613832128557123,
           10.500728355568008,
           10.387624582578871,
           10.274520809589735,
           10.161417036600598,
           10.048313263611483,
           9.93520949062235,
           9.822105717633214,
           9.709001944644099,
           9.595898171654962,
           9.482794398665826,
           9.36969062567671,
           9.256586852687574,
           9.14348307969844,
           9.030379306709325,
           8.917275533720188,
           8.804171760731052,
           8.691067987741917,
           8.577964214752802,
           8.464860441763665,
           8.35175666877453,
           8.238652895785416,
           8.12554912279628,
           8.012445349807145,
           7.8993415768180295,
           7.786237803828894,
           7.673134030839758,
           7.560030257850622,
           7.446926484861508,
           7.3338227118723704,
           7.220718938883236,
           7.107615165894121,
           6.994511392904984,
           6.88140761991585,
           6.768303846926734,
           6.655200073937598,
           6.542096300948462,
           6.428992527959347,
           6.315888754970212,
           6.202784981981075,
           6.08968120899194,
           5.976577436002825,
           5.863473663013689,
           5.750369890024554,
           5.637266117035439,
           5.524162344046303,
           5.411058571057167,
           5.304731652854059,
           5.234929695210907,
           5.1651277375677545,
           5.095325779924602,
           5.025523822281463
          ],
          [
           46.77550918504886,
           46.824836294079645,
           46.87416340311043,
           46.92349051214122,
           46.97281762117201,
           47.0221447302028,
           47.07147183923358,
           47.120798948264365,
           47.17012605729515,
           47.21945316632594,
           47.26878027535673,
           47.31810738438752,
           47.3674344934183,
           47.416761602449085,
           47.46608871147988,
           47.51541582051067,
           47.564742929541445,
           47.61407003857224,
           47.66339714760302,
           47.712724256633805,
           47.76205136566459,
           47.81137847469538,
           47.860705583726165,
           47.91003269275696,
           47.95935980178774,
           48.008686910818525,
           48.058014019849324,
           48.107341128880094,
           48.15666823791089,
           48.20599534694168,
           48.25532245597246,
           48.304649565003245,
           48.35397667403403,
           48.40330378306483,
           48.45263089209561,
           48.5019580011264,
           48.55128511015718,
           48.600612219187965,
           48.649939328218764,
           48.69926643724954,
           48.748593546280325,
           48.79792065531112,
           48.8472477643419,
           48.896574873372685,
           48.94590198240347,
           48.99522909143426,
           49.04455620046505,
           49.09388330949584,
           49.14321041852662,
           49.192537527557405,
           49.2418646365882,
           49.29119174561898,
           49.34051885464977,
           49.38984596368056,
           49.43917307271135,
           49.488500181742126,
           49.53782729077292,
           49.58715439980371,
           49.63648150883449,
           49.68580861786528,
           49.73513572689606,
           49.78446283592685,
           49.83378994495764,
           49.88311705398842,
           49.93244416301921,
           49.981771272050004,
           50.03109838108078,
           50.08042549011157,
           50.12975259914236,
           50.17907970817314,
           50.22840681720393,
           50.27773392623472,
           50.32706103526551,
           50.376388144296286,
           50.42571525332708,
           50.47504236235787,
           50.52436947138865,
           50.57369658041944,
           50.62302368945023,
           50.67322674907432,
           50.72360499984865,
           50.77398325062297,
           50.8243615013973,
           50.87473975217163,
           50.920388335551515,
           50.96509098545252,
           51.00979363535352,
           51.05449628525452,
           51.09919893515552,
           51.14346016347137,
           51.18763310799005,
           51.23180605250873,
           51.27597899702741,
           51.32015194154609,
           51.364324886064765,
           51.40849783058344,
           51.45267077510212,
           51.496843719620806,
           51.54101666413948,
           51.585189608658155,
           51.62936255317683,
           51.67353549769552,
           51.717708442214196,
           51.76188138673287,
           51.806054331251545,
           51.85022727577023,
           51.89440022028891,
           51.93857316480758,
           51.98274610932626,
           52.02691905384494,
           52.07109199836362,
           52.1152649428823,
           52.159437887400976,
           52.20361083191966,
           52.24778377643833,
           52.29195672095702,
           52.336129665475696,
           52.38030260999437,
           52.424475554513045,
           52.46864849903173,
           52.51282144355041,
           52.556994388069086,
           52.601167332587764,
           52.64534027710644,
           52.68951322162512,
           52.7336861661438,
           52.777859110662476,
           52.822032055181154,
           52.86620499969983,
           52.91037794421851,
           52.95455088873719,
           52.998723833255866,
           53.042896777774544,
           53.08706972229323,
           53.1312426668119,
           53.17541561133058,
           53.219588555849256,
           53.263761500367934,
           53.30793444488661,
           53.3521073894053,
           53.39628033392397,
           53.44045327844265,
           53.48462622296133,
           53.52879916748001,
           53.572972111998695,
           53.61714505651736,
           53.661318001036044,
           53.70549094555473,
           53.74966389007339,
           53.793836834592085,
           53.83800977911076,
           53.882182723629434,
           53.92635566814812,
           53.9705286126668,
           54.014701557185475,
           54.05887450170415,
           54.103047446222824,
           54.14722039074151,
           54.19139333526018,
           54.23556627977886,
           54.27973922429754,
           54.32391216881622,
           54.3680851133349,
           54.41225805785358,
           54.456431002372256,
           54.500603946890934,
           54.54477689140961,
           54.59011333273475,
           54.636031522463114,
           54.68194971219148,
           54.72786790191984,
           54.77378609164821,
           54.81970428137658,
           54.865586515065964,
           54.91145796199317,
           54.95732940892038,
           55.00320085584759,
           55.0490723027748,
           55.09494374970202,
           55.14081519662923,
           55.186686643556435,
           55.23255809048364,
           55.27842953741086,
           55.324300984338066,
           55.37017243126528,
           55.41604387819249,
           55.4619153251197,
           55.507786772046906,
           55.55365821897412,
           55.59952966590132,
           55.64540111282854,
           55.69127255975575,
           55.73714400668296,
           55.78301545361017,
           55.82888690053738,
           55.87475834746459,
           55.92062979439181,
           55.966501241319015,
           56.012372688246224,
           56.05824413517343,
           56.10411558210065,
           56.149987029027855,
           56.19585847595507,
           56.24172992288228,
           56.28760136980949,
           56.333472816736695,
           56.37934426366391,
           56.42521571059112,
           56.471087157518326,
           56.51695860444554,
           56.56283005137275,
           56.608701498299965,
           56.654572945227166,
           56.70044439215438,
           56.746315839081596,
           56.792187286008804,
           56.83805873293601,
           56.88393017986322,
           56.92980162679043,
           56.97567307371765,
           57.021544520644845,
           57.067415967572074,
           57.113287414499275,
           57.159158861426484,
           57.205030308353706,
           57.2509017552809,
           57.29677320220812,
           57.34264464913533,
           57.38851609606254,
           57.43438754298975,
           57.48025898991696,
           57.52613043684417,
           57.572001883771385,
           57.61787333069859,
           57.6637447776258,
           57.70961622455302,
           57.755487671480225,
           57.80135911840743,
           57.84723056533464,
           57.89310201226186,
           57.93897345918907,
           57.98484490611628,
           58.03071635304349,
           58.076587799970696,
           58.12245924689791,
           58.16833069382512,
           58.21420214075233,
           58.260073587679535,
           58.30594503460675,
           58.351816481533966,
           58.309537790945896,
           58.179108962842555,
           58.04868013473923,
           57.91825130663591,
           57.78782247853256,
           57.65739365042924,
           57.526964822325915,
           57.396535994222575,
           57.266107166119234,
           57.15827215676025,
           57.05652005149182,
           56.9547679462234,
           56.853015840954974,
           56.75126373568655,
           56.649511630418125,
           56.54775952514971,
           56.44600741988128,
           56.34425531461285,
           56.242503209344434,
           56.14075110407602,
           56.038998998807585,
           55.93724689353916,
           55.83549478827074,
           55.73374268300231,
           55.63199057773389,
           55.53023847246547,
           55.428486367197046,
           55.32673426192862,
           55.224982156660204,
           55.12323005139177,
           55.021477946123355,
           54.919725840854916,
           54.817973735586506,
           54.71622163031808,
           54.61446952504965,
           54.51271741978123,
           54.41096531451281,
           54.30921320924438,
           54.207461103975966,
           54.10570899870754,
           54.00395689343911,
           53.90220478817069,
           53.800452682902275,
           53.69870057763384,
           53.59694847236541,
           53.495196367096995,
           53.39344426182858,
           53.291692156560146,
           53.18994005129173,
           53.088187946023304,
           52.98643584075488,
           52.88468373548646,
           52.78293163021803,
           52.68117952494961,
           52.57942741968118,
           52.477675314412764,
           52.37592320914433,
           52.274171103875915,
           52.17241899860748,
           52.070666893339066,
           51.968914788070634,
           51.86716268280222,
           51.7654105775338,
           51.66365847226537,
           51.56190636699695,
           51.46015426172853,
           51.358402156460095,
           51.25665005119168,
           51.15489794592326,
           51.05314584065483,
           50.951393735386404,
           50.84964163011798,
           50.747889524849555,
           50.64613741958114,
           50.54438531431271,
           50.44263320904429,
           50.34088110377587,
           50.23912899850744,
           50.13737689323902,
           50.0356247879706,
           49.933872682702166,
           49.83212057743375,
           49.73036847216533,
           49.522146820230034,
           49.10098607496115,
           48.679825329692264,
           48.25866458442333,
           47.837503839154444,
           47.41634309388556,
           46.99518234861662,
           46.574021603347695,
           46.15286085807885,
           45.731700112809925,
           45.310539367541,
           44.88937862227211,
           44.46821787700322,
           44.0470571317343,
           43.625896386465406,
           43.20473564119652,
           42.7799485714739,
           42.35231549951783,
           41.92468242756177,
           41.497049355605675,
           41.06941628364957,
           40.6417832116935,
           40.21415013973744,
           39.78651706778134,
           39.35888399582527,
           38.931250923869214,
           38.50361785191311,
           38.07598477995705,
           37.64835170800099,
           37.220718636044886,
           36.79308556408877,
           36.36545249213275,
           35.93781942017665,
           35.51018634822054,
           35.082553276264484,
           34.65492020430842,
           34.22728713235232,
           33.79965406039626,
           33.3720209884402,
           32.9443879164841,
           32.51675484452803,
           32.08912177257197,
           31.661488700615863,
           31.233855628659757,
           30.806222556703695,
           30.378589484747636,
           29.95095641279153,
           29.523323340835468,
           29.0956902688794,
           28.6680571969233,
           28.240424124967237,
           27.812791053011175,
           27.385157981055073,
           26.95752490909897,
           26.529891837142948,
           26.102258765186843,
           25.67462569323074,
           25.24699262127468,
           24.819359549318612,
           24.39172647736251,
           23.96409340540645,
           23.536460333450385,
           23.108827261494284,
           22.681194189538225,
           22.25356111758216,
           21.825928045626057,
           21.398294973669948,
           20.97066190171393,
           20.543028829757823,
           20.11539575780172,
           19.68776268584566,
           19.260129613889596,
           18.832496541933494,
           18.404863469977432,
           17.97723039802137,
           17.549597326065264,
           17.121964254109166,
           16.694331182153142,
           16.26669811019704,
           15.839065038240935,
           15.411431966284871,
           14.983798894328814,
           14.556165822372707,
           14.175060228184739,
           14.026592022836976,
           13.878123817489216,
           13.729655612141455,
           13.581187406793719,
           13.432719201445957,
           13.284250996098198,
           13.135782790750461,
           12.987314585402702,
           12.838846380054937,
           12.690378174707202,
           12.541909969359441,
           12.393441764011678,
           12.244973558663917,
           12.096505353316184,
           11.94803714796842,
           11.79956894262066,
           11.651100737272925,
           11.502632531925164,
           11.354164326577402,
           11.205696121229668,
           11.057227915881906,
           10.908759710534145,
           10.76029150518641,
           10.611823299838647,
           10.463355094490886,
           10.314886889143121,
           10.166418683795388,
           10.04871467669455,
           9.935610903705411,
           9.822507130716298,
           9.709403357727162,
           9.596299584738025,
           9.48319581174891,
           9.370092038759774,
           9.256988265770637,
           9.143884492781503,
           9.030780719792388,
           8.917676946803253,
           8.804573173814116,
           8.691469400825001,
           8.578365627835867,
           8.46526185484673,
           8.352158081857615,
           8.23905430886848,
           8.125950535879344,
           8.012846762890229,
           7.8997429899010925,
           7.786639216911957,
           7.673535443922821,
           7.560431670933706,
           7.447327897944571,
           7.334224124955435,
           7.22112035196632,
           7.108016578977184,
           6.994912805988048,
           6.89465873756688,
           6.824856779923728,
           6.755054822280576,
           6.685252864637423,
           6.615450906994285,
           6.545648949351133,
           6.47584699170798,
           6.406045034064841,
           6.336243076421688,
           6.266441118778536,
           6.196639161135398,
           6.126837203492245,
           6.057035245849093,
           5.987233288205953,
           5.917431330562801,
           5.847629372919649,
           5.777827415276498,
           5.708025457633358,
           5.638223499990206,
           5.5684215423470524,
           5.498619584703913,
           5.428817627060762,
           5.35901566941761,
           5.289213711774471,
           5.219411754131318,
           5.149609796488166,
           5.079807838845014,
           5.010005881201874
          ],
          [
           47.112477434384935,
           47.16180454341571,
           47.2111316524465,
           47.26045876147729,
           47.30978587050808,
           47.359112979538864,
           47.40844008856965,
           47.45776719760043,
           47.507094306631224,
           47.556421415662015,
           47.6057485246928,
           47.655075633723584,
           47.70440274275437,
           47.75372985178516,
           47.803056960815944,
           47.852384069846735,
           47.90171117887752,
           47.951038287908304,
           48.00036539693909,
           48.04969250596988,
           48.099019615000664,
           48.14834672403145,
           48.19767383306223,
           48.247000942093024,
           48.29632805112381,
           48.34565516015459,
           48.39498226918539,
           48.444309378216175,
           48.49363648724696,
           48.542963596277744,
           48.59229070530853,
           48.64161781433931,
           48.6909449233701,
           48.740272032400895,
           48.78959914143168,
           48.838926250462464,
           48.88825335949325,
           48.93758046852403,
           48.98690757755483,
           49.03623468658561,
           49.08556179561639,
           49.134888904647184,
           49.18421601367797,
           49.23354312270875,
           49.282870231739544,
           49.33219734077033,
           49.38152444980112,
           49.430851558831904,
           49.48017866786269,
           49.52950577689348,
           49.578832885924264,
           49.62815999495505,
           49.67748710398584,
           49.726814213016624,
           49.776141322047415,
           49.82546843107819,
           49.874795540108984,
           49.924122649139775,
           49.97344975817056,
           50.022776867201344,
           50.072103976232135,
           50.12143108526292,
           50.17110857418867,
           50.221486824963,
           50.27186507573734,
           50.32224332651167,
           50.372621577286,
           50.42299982806033,
           50.473378078834656,
           50.52375632960899,
           50.57413458038332,
           50.624512831157645,
           50.674891081931975,
           50.725269332706304,
           50.775647583480634,
           50.82602583425496,
           50.87640408502929,
           50.92678233580362,
           50.97716058657796,
           51.02753883735229,
           51.07791708812662,
           51.12829533890095,
           51.17867358967528,
           51.22905184044961,
           51.27470042382949,
           51.3194030737305,
           51.364105723631496,
           51.408808373532494,
           51.45351102343349,
           51.49821367333449,
           51.54291632323549,
           51.587618973136486,
           51.632321623037484,
           51.677024272938496,
           51.72172692283949,
           51.76642957274049,
           51.81113222264149,
           51.85583487254249,
           51.900537522443486,
           51.945240172344484,
           51.98994282224548,
           52.03464547214648,
           52.07934812204748,
           52.12405077194848,
           52.16875342184948,
           52.213279502943905,
           52.25745244746258,
           52.301625391981254,
           52.34579833649993,
           52.38997128101861,
           52.43414422553729,
           52.47831717005596,
           52.52249011457465,
           52.56666305909333,
           52.61083600361201,
           52.655008948130686,
           52.699181892649364,
           52.743354837168035,
           52.78752778168671,
           52.8317007262054,
           52.875873670724076,
           52.920046615242754,
           52.96421955976143,
           53.00839250428011,
           53.05256544879879,
           53.096738393317466,
           53.14091133783615,
           53.18508428235482,
           53.2292572268735,
           53.27343017139218,
           53.317603115910856,
           53.36177606042954,
           53.40594900494821,
           53.4501219494669,
           53.49429489398557,
           53.538467838504246,
           53.582640783022924,
           53.62681372754161,
           53.67098667206028,
           53.715159616578966,
           53.75933256109764,
           53.80350550561632,
           53.84767845013499,
           53.89185139465368,
           53.93602433917236,
           53.980197283691034,
           54.02437022820972,
           54.0685431727284,
           54.11271611724707,
           54.15688906176575,
           54.20106200628443,
           54.24523495080311,
           54.28940789532178,
           54.333580839840465,
           54.377753784359136,
           54.421926728877814,
           54.4660996733965,
           54.51027261791518,
           54.55444556243385,
           54.59861850695253,
           54.64279145147121,
           54.68696439598989,
           54.73113734050857,
           54.775310285027246,
           54.819483229545924,
           54.8636561740646,
           54.90782911858328,
           54.95316555990842,
           54.99908374963679,
           55.04500193936514,
           55.09092012909352,
           55.13683831882188,
           55.18275650855024,
           55.22867469827861,
           55.27459288800697,
           55.32051107773535,
           55.36642926746371,
           55.41234745719207,
           55.45826564692044,
           55.5041838366488,
           55.55010202637717,
           55.596020216105536,
           55.641938405833905,
           55.687856595562266,
           55.73377478529063,
           55.779692975018996,
           55.825611164747365,
           55.871529354475726,
           55.917447544204094,
           55.96336573393245,
           56.009283923660824,
           56.05520211338919,
           56.1011059207113,
           56.146977367638506,
           56.192848814565714,
           56.23872026149293,
           56.28459170842014,
           56.33046315534735,
           56.37633460227456,
           56.42220604920177,
           56.468077496128984,
           56.51394894305619,
           56.5598203899834,
           56.60569183691061,
           56.651563283837824,
           56.69743473076503,
           56.74330617769225,
           56.789177624619455,
           56.83504907154666,
           56.88092051847387,
           56.92679196540109,
           56.9726634123283,
           57.01853485925551,
           57.06440630618272,
           57.110277753109926,
           57.156149200037135,
           57.20202064696436,
           57.247892093891565,
           57.29376354081877,
           57.33963498774598,
           57.38550643467319,
           57.43137788160041,
           57.477249328527606,
           57.52312077545483,
           57.568992222382036,
           57.614863669309244,
           57.66073511623645,
           57.706606563163675,
           57.75247801009087,
           57.79834945701809,
           57.8442209039453,
           57.89009235087251,
           57.93596379779972,
           57.98183524472693,
           58.027706691654146,
           58.073578138581354,
           58.11944958550856,
           58.16532103243577,
           58.21119247936298,
           58.25706392629019,
           58.30293537321741,
           58.34880682014461,
           58.394678267071825,
           58.44054971399903,
           58.48642116092625,
           58.532292607853456,
           58.578164054780665,
           58.62403550170787,
           58.66990694863509,
           58.7157783955623,
           58.67349970497423,
           58.54307087687089,
           58.412642048767566,
           58.28221322066423,
           58.1517843925609,
           58.021355564457565,
           57.89092673635425,
           57.76049790825091,
           57.63006908014757,
           57.49964025204426,
           57.36921142394091,
           57.23878259583758,
           57.10835376773424,
           56.97792493963093,
           56.84749611152759,
           56.71706728342426,
           56.58663845532094,
           56.456209627217596,
           56.32578079911427,
           56.19535197101094,
           56.0649231429076,
           55.93449431480427,
           55.80406548670095,
           55.673636658597616,
           55.543207830494275,
           55.412779002390955,
           55.28235017428762,
           55.15192134618428,
           55.02149251808096,
           54.891063689977635,
           54.760634861874294,
           54.63020603377095,
           54.49977720566764,
           54.3693483775643,
           54.23891954946096,
           54.10849072135764,
           53.978061893254306,
           53.848719321157716,
           53.746967215889285,
           53.64521511062087,
           53.543463005352436,
           53.44171090008402,
           53.3399587948156,
           53.23820668954716,
           53.136454584278745,
           53.03470247901033,
           52.932950373741896,
           52.83119826847347,
           52.729446163205054,
           52.62769405793662,
           52.5259419526682,
           52.42418984739978,
           52.322437742131356,
           52.220685636862925,
           52.11893353159451,
           52.01718142632609,
           51.91542932105766,
           51.813677215789234,
           51.711925110520816,
           51.61017300525239,
           51.50842089998396,
           51.40666879471554,
           51.304916689447126,
           51.20316458417869,
           51.10141247891028,
           50.99966037364185,
           50.89790826837342,
           50.79615616310499,
           50.69440405783658,
           50.59265195256815,
           50.49089984729972,
           50.38914774203131,
           50.28739563676288,
           50.18564353149445,
           50.08389142622604,
           49.98213932095762,
           49.88038721568918,
           49.778635110420765,
           49.676883005152355,
           49.575130899883916,
           49.473378794615485,
           49.371626689347075,
           49.26987458407865,
           49.06165293214336,
           48.64049218687447,
           48.21933144160558,
           47.798170696336655,
           47.37700995106777,
           46.95584920579888,
           46.53468846052995,
           46.11352771526103,
           45.69236696999218,
           45.271206224723244,
           44.85004547945432,
           44.42888473418543,
           44.007723988916545,
           43.58656324364762,
           43.165402498378725,
           42.74424175310985,
           42.32308100784091,
           41.901920262572034,
           41.48075951730314,
           41.05959877203422,
           40.638438026765286,
           40.2172772814964,
           39.796116536227515,
           39.37495579095859,
           38.9537950456897,
           38.53263430042081,
           38.11147355515188,
           37.690312809883,
           37.269152064614104,
           36.847991319345184,
           36.42683057407625,
           36.0056698288074,
           35.58450908353848,
           35.16334833826955,
           34.742187593000665,
           34.32102684773177,
           33.89986610246285,
           33.47870535719396,
           33.05754461192507,
           32.63638386665614,
           32.215223121387254,
           31.79406237611836,
           31.372901630849437,
           30.951740885580506,
           30.53058014031162,
           30.109419395042735,
           29.688258649773807,
           29.26709790450492,
           28.84593715923603,
           28.424776413967102,
           28.003615668698217,
           27.582454923429328,
           27.1612941781604,
           26.740133432891472,
           26.318972687622626,
           25.897811942353698,
           25.475434767604874,
           25.04780169564881,
           24.62016862369275,
           24.192535551736643,
           23.76490247978058,
           23.337269407824518,
           22.909636335868413,
           22.482003263912354,
           22.054370191956288,
           21.626737120000186,
           21.19910404804408,
           20.77147097608806,
           20.343837904131956,
           19.91620483217585,
           19.48857176021979,
           19.06093868826373,
           18.633305616307624,
           18.205672544351565,
           17.7780394723955,
           17.350406400439397,
           16.922773328483295,
           16.49514025652727,
           16.06750718457117,
           15.639874112615065,
           15.212241040659002,
           14.784607968702943,
           14.356974896746836,
           13.97586930255887,
           13.827401097211109,
           13.678932891863344,
           13.530464686515584,
           13.38199648116785,
           13.233528275820088,
           13.085060070472327,
           12.93659186512459,
           12.788123659776831,
           12.639655454429068,
           12.491187249081332,
           12.34271904373357,
           12.19425083838581,
           12.045782633038048,
           11.897314427690313,
           11.748846222342552,
           11.60037801699479,
           11.451909811647056,
           11.303441606299295,
           11.154973400951532,
           11.006505195603797,
           10.858036990256036,
           10.709568784908274,
           10.561100579560538,
           10.412632374212777,
           10.264164168865015,
           10.115695963517254,
           9.99673425632633,
           9.8899223114669,
           9.783110366607474,
           9.676298421748067,
           9.569486476888638,
           9.462674532029212,
           9.355862587169803,
           9.249050642310376,
           9.14223869745095,
           9.035426752591519,
           8.928614807732112,
           8.821802862872683,
           8.714990918013257,
           8.608178973153848,
           8.501367028294421,
           8.394555083434993,
           8.287743138575586,
           8.180931193716159,
           8.07411924885673,
           7.967307303997322,
           7.860495359137895,
           7.753683414278466,
           7.64687146941904,
           7.5400595245596325,
           7.433247579700204,
           7.3264356348407755,
           7.219623689981368,
           7.11281174512194,
           7.005999800262512,
           6.899187855403104,
           6.809338838844139,
           6.739536881200986,
           6.669734923557835,
           6.599932965914696,
           6.530131008271543,
           6.460329050628391,
           6.390527092985251,
           6.320725135342099,
           6.250923177698947,
           6.181121220055807,
           6.111319262412656,
           6.0415173047695045,
           5.971715347126365,
           5.901913389483212,
           5.83211143184006,
           5.762309474196908,
           5.692507516553769,
           5.622705558910616,
           5.552903601267463,
           5.483101643624325,
           5.413299685981173,
           5.34349772833802,
           5.273695770694881,
           5.203893813051728,
           5.134091855408577,
           5.064289897765425,
           4.994487940122285
          ],
          [
           47.44944568372098,
           47.498772792751765,
           47.54809990178255,
           47.59742701081334,
           47.64675411984413,
           47.69608122887492,
           47.7454083379057,
           47.794735446936485,
           47.84406255596728,
           47.89338966499807,
           47.94271677402885,
           47.99204388305964,
           48.04137099209042,
           48.09069810112121,
           48.140025210152004,
           48.18935231918279,
           48.23867942821357,
           48.28800653724436,
           48.33733364627515,
           48.386660755305925,
           48.43598786433672,
           48.48531497336751,
           48.53464208239829,
           48.583969191429084,
           48.63329630045986,
           48.68262340949065,
           48.731950518521444,
           48.78127762755222,
           48.83060473658301,
           48.8799318456138,
           48.92925895464459,
           48.97858606367537,
           49.02791317270616,
           49.07724028173694,
           49.126567390767725,
           49.17589449979852,
           49.22522160882931,
           49.27454871786009,
           49.323875826890884,
           49.37320293592167,
           49.42253004495245,
           49.47185715398324,
           49.52118426301402,
           49.57051137204481,
           49.6198384810756,
           49.66916559010639,
           49.71936865007735,
           49.76974690085168,
           49.820125151626,
           49.870503402400345,
           49.92088165317467,
           49.971259903949004,
           50.021638154723334,
           50.072016405497656,
           50.12239465627199,
           50.172772907046316,
           50.22315115782065,
           50.27352940859498,
           50.32390765936931,
           50.37428591014364,
           50.42466416091796,
           50.47504241169231,
           50.52542066246663,
           50.57579891324096,
           50.626177164015296,
           50.676555414789625,
           50.726933665563955,
           50.77731191633828,
           50.82769016711261,
           50.87806841788694,
           50.92844666866128,
           50.97882491943561,
           51.02920317020993,
           51.07958142098426,
           51.12995967175859,
           51.18033792253292,
           51.23071617330725,
           51.28109442408159,
           51.33147267485592,
           51.381850925630246,
           51.432229176404576,
           51.482607427178905,
           51.532985677953235,
           51.583363928727564,
           51.62901251210745,
           51.67371516200845,
           51.71841781190945,
           51.763120461810445,
           51.80782311171144,
           51.85252576161245,
           51.897228411513446,
           51.941931061414444,
           51.98663371131545,
           52.03133636121645,
           52.076039011117444,
           52.12074166101844,
           52.16544431091945,
           52.210146960820445,
           52.25484961072144,
           52.29955226062244,
           52.34425491052344,
           52.38895756042444,
           52.433660210325435,
           52.47836286022644,
           52.52306551012744,
           52.567768160028436,
           52.612470809929434,
           52.65717345983044,
           52.70187610973144,
           52.746578759632435,
           52.79128140953343,
           52.83598405943443,
           52.88068670933543,
           52.925389359236426,
           52.97009200913743,
           53.01479465903842,
           53.059497308939434,
           53.104199958840425,
           53.14890260874143,
           53.19360525864242,
           53.238307908543426,
           53.283010558444424,
           53.327271786935086,
           53.371444731453764,
           53.41561767597244,
           53.45979062049112,
           53.503963565009805,
           53.54813650952848,
           53.59230945404716,
           53.63648239856584,
           53.68065534308451,
           53.724828287603195,
           53.76900123212187,
           53.81317417664056,
           53.85734712115923,
           53.90152006567791,
           53.94569301019658,
           53.98986595471526,
           54.03403889923394,
           54.07821184375263,
           54.122384788271305,
           54.16655773278998,
           54.21073067730865,
           54.25490362182733,
           54.29907656634602,
           54.343249510864695,
           54.38742245538337,
           54.43159539990205,
           54.47576834442073,
           54.51994128893941,
           54.564114233458085,
           54.60828717797676,
           54.65246012249544,
           54.69663306701412,
           54.7408060115328,
           54.784978956051475,
           54.82915190057015,
           54.87332484508883,
           54.91749778960751,
           54.96167073412619,
           55.005843678644865,
           55.05001662316354,
           55.09418956768222,
           55.1383625122009,
           55.18253545671958,
           55.22670840123826,
           55.27088134575693,
           55.316217787082074,
           55.36213597681044,
           55.408054166538804,
           55.453972356267165,
           55.49989054599554,
           55.54580873572391,
           55.591726925452264,
           55.63764511518063,
           55.68356330490899,
           55.72948149463736,
           55.77539968436572,
           55.82131787409409,
           55.86723606382245,
           55.91315425355082,
           55.95907244327918,
           56.00499063300756,
           56.05090882273592,
           56.09682701246429,
           56.14274520219265,
           56.18866339192102,
           56.23458158164939,
           56.28049977137775,
           56.3264179611061,
           56.37233615083448,
           56.41825434056284,
           56.464172530291215,
           56.510090720019576,
           56.55600890974794,
           56.60192709947631,
           56.64784528920467,
           56.693763478933036,
           56.739681668661405,
           56.78559985838976,
           56.831518048118134,
           56.877436237846496,
           56.92335442757487,
           56.96927261730323,
           57.0151908070316,
           57.06110899675997,
           57.107027186488324,
           57.15294537621669,
           57.198863565945054,
           57.24478175567342,
           57.29069994540179,
           57.336618135130145,
           57.382496773283826,
           57.428368220211034,
           57.47423966713825,
           57.52011111406546,
           57.565982560992666,
           57.61185400791988,
           57.65772545484709,
           57.703596901774304,
           57.74946834870151,
           57.79533979562872,
           57.84121124255593,
           57.887082689483144,
           57.93295413641035,
           57.97882558333757,
           58.024697030264775,
           58.07056847719198,
           58.11643992411919,
           58.16231137104641,
           58.208182817973615,
           58.25405426490083,
           58.29992571182804,
           58.345797158755246,
           58.39166860568246,
           58.43754005260967,
           58.483411499536885,
           58.52928294646409,
           58.5751543933913,
           58.62102584031851,
           58.66689728724572,
           58.71276873417293,
           58.75864018110014,
           58.804511628027356,
           58.850383074954564,
           58.89625452188177,
           58.94212596880898,
           58.987997415736196,
           59.03386886266341,
           59.07974030959062,
           59.03746161900255,
           58.907032790899216,
           58.77660396279589,
           58.646175134692555,
           58.51574630658922,
           58.385317478485895,
           58.25488865038257,
           58.124459822279235,
           57.994030994175894,
           57.86360216607258,
           57.73317333796925,
           57.6027445098659,
           57.47231568176258,
           57.34188685365925,
           57.211458025555906,
           57.08102919745258,
           56.95060036934926,
           56.82017154124592,
           56.68974271314259,
           56.55931388503927,
           56.428885056935925,
           56.29845622883259,
           56.16802740072927,
           56.03759857262594,
           55.9071697445226,
           55.776740916419264,
           55.64631208831594,
           55.51588326021261,
           55.38545443210927,
           55.25502560400595,
           55.12459677590262,
           54.994167947799276,
           54.86373911969596,
           54.73331029159263,
           54.60288146348928,
           54.472452635385956,
           54.34202380728264,
           54.211594979179296,
           54.08116615107596,
           53.95073732297264,
           53.820308494869295,
           53.689879666765975,
           53.55945083866265,
           53.42902201055931,
           53.298593182455974,
           53.168164354352655,
           53.037735526249314,
           52.90730669814598,
           52.776877870042654,
           52.64644904193932,
           52.51602021383599,
           52.38559138573266,
           52.25516255762933,
           52.124733729526,
           51.99430490142266,
           51.86387607331935,
           51.73344724521601,
           51.603018417112665,
           51.47258958900933,
           51.34216076090602,
           51.21173193280268,
           51.08130310469935,
           50.950874276596025,
           50.820445448492684,
           50.69001662038936,
           50.55958779228603,
           50.43741438028677,
           50.335662275018336,
           50.23391016974993,
           50.1321580644815,
           50.03040595921307,
           49.92865385394465,
           49.826901748676235,
           49.7251496434078,
           49.623397538139386,
           49.52164543287096,
           49.41989332760253,
           49.31814122233411,
           49.21638911706569,
           49.114637011797264,
           49.01288490652883,
           48.911132801260415,
           48.809380695992,
           48.6011590440567,
           48.179998298787815,
           47.758837553518916,
           47.33767680825,
           46.91651606298111,
           46.495355317712225,
           46.07419457244329,
           45.65303382717437,
           45.23187308190552,
           44.8107123366366,
           44.38955159136766,
           43.96839084609878,
           43.54723010082989,
           43.12606935556097,
           42.70490861029207,
           42.28374786502319,
           41.86258711975427,
           41.441426374485374,
           41.02026562921649,
           40.59910488394756,
           40.17794413867863,
           39.75678339340974,
           39.335622648140856,
           38.91446190287193,
           38.49330115760304,
           38.07214041233415,
           37.65097966706522,
           37.22981892179634,
           36.80865817652745,
           36.387497431258524,
           35.966336685989596,
           35.545175940720746,
           35.124015195451825,
           34.70285445018289,
           34.281693704914005,
           33.86053295964512,
           33.43937221437619,
           33.0182114691073,
           32.597050723838414,
           32.17588997856949,
           31.754729233300594,
           31.33356848803171,
           30.912407742762777,
           30.491246997493853,
           30.070086252224964,
           29.64892550695608,
           29.227764761687148,
           28.806604016418262,
           28.385443271149374,
           27.96428252588045,
           27.54312178061156,
           27.12196103534267,
           26.700800290073744,
           26.279780881977747,
           25.86158829604967,
           25.443395710121536,
           25.02520312419339,
           24.607010538265286,
           24.188817952337182,
           23.770625366409035,
           23.35243278048093,
           22.934240194552828,
           22.51604760862468,
           22.09785502269658,
           21.679662436768474,
           21.26146985084033,
           20.84327726491219,
           20.42508467898412,
           20.00689209305598,
           19.588699507127835,
           19.17050692119973,
           18.752314335271627,
           18.334121749343485,
           17.915929163415377,
           17.497736577487274,
           17.07954399155913,
           16.661351405630988,
           16.24315881970292,
           15.824966233774777,
           15.406773647846634,
           14.98858106191853,
           14.570388475990425,
           14.15219589006228,
           13.780344219197701,
           13.640197123650461,
           13.500050028103217,
           13.359902932555974,
           13.219755837008758,
           13.079608741461517,
           12.939461645914275,
           12.799314550367058,
           12.663227536007351,
           12.556415591147925,
           12.449603646288516,
           12.342791701429089,
           12.235979756569662,
           12.129167811710232,
           12.022355866850825,
           11.915543921991397,
           11.80873197713197,
           11.701920032272563,
           11.595108087413132,
           11.488296142553706,
           11.381484197694297,
           11.274672252834872,
           11.167860307975442,
           11.061048363116035,
           10.954236418256608,
           10.84742447339718,
           10.740612528537753,
           10.633800583678344,
           10.526988638818917,
           10.420176693959489,
           10.313364749100081,
           10.206552804240653,
           10.099740859381225,
           9.992928914521817,
           9.88611696966239,
           9.77930502480296,
           9.672493079943536,
           9.565681135084127,
           9.4588691902247,
           9.352057245365271,
           9.245245300505863,
           9.138433355646436,
           9.031621410787007,
           8.9248094659276,
           8.81799752106817,
           8.711185576208745,
           8.604373631349336,
           8.497561686489908,
           8.390749741630481,
           8.283937796771054,
           8.177125851911645,
           8.070313907052219,
           7.96350196219279,
           7.856690017333382,
           7.749878072473955,
           7.643066127614528,
           7.536254182755118,
           7.4294422378956915,
           7.322630293036263,
           7.215818348176835,
           7.109006403317428,
           7.002194458458001,
           6.895382513598572,
           6.788570568739164,
           6.681758623879737,
           6.574946679020309,
           6.468134734160902,
           6.361322789301473,
           6.254510844442046,
           6.147698899582638,
           6.040886954723211,
           5.934075009863783,
           5.827263065004355,
           5.720451120144947,
           5.6136391752855195,
           5.508650081287764,
           5.442462505953447,
           5.376274930619116,
           5.310087355284786,
           5.243899779950467,
           5.177712204616137,
           5.1115246292818055,
           5.045337053947476,
           4.979149478613158
          ],
          [
           47.78641393305704,
           47.835741042087825,
           47.88506815111861,
           47.9343952601494,
           47.983722369180185,
           48.03304947821097,
           48.082376587241754,
           48.131703696272545,
           48.18103080530333,
           48.23035791433412,
           48.279685023364905,
           48.32901213239569,
           48.378339241426474,
           48.427666350457265,
           48.47699345948806,
           48.52632056851884,
           48.575647677549625,
           48.62497478658042,
           48.6743018956112,
           48.72362900464199,
           48.77295611367277,
           48.82228322270356,
           48.871610331734345,
           48.92093744076513,
           48.970264549795914,
           49.019591658826705,
           49.0689187678575,
           49.11824587688828,
           49.167572985919065,
           49.2172504751917,
           49.26762872596603,
           49.31800697674036,
           49.368385227514686,
           49.41876347828902,
           49.469141729063345,
           49.51951997983768,
           49.56989823061201,
           49.62027648138634,
           49.67065473216067,
           49.721032982935,
           49.77141123370933,
           49.82178948448365,
           49.87216773525799,
           49.92254598603232,
           49.97292423680665,
           50.02330248758097,
           50.073680738355314,
           50.12405898912964,
           50.174437239903966,
           50.22481549067831,
           50.275193741452625,
           50.32557199222697,
           50.37595024300129,
           50.426328493775614,
           50.47670674454996,
           50.52708499532427,
           50.57746324609862,
           50.62784149687293,
           50.67821974764727,
           50.728597998421606,
           50.77897624919593,
           50.829354499970265,
           50.87973275074459,
           50.93011100151892,
           50.98048925229325,
           51.03086750306758,
           51.08124575384191,
           51.13162400461624,
           51.18200225539057,
           51.2323805061649,
           51.28275875693923,
           51.33313700771356,
           51.38351525848789,
           51.43389350926222,
           51.48427176003655,
           51.534650010810886,
           51.58502826158521,
           51.63540651235954,
           51.68578476313387,
           51.736163013908204,
           51.786541264682526,
           51.836919515456856,
           51.887297766231185,
           51.93767601700552,
           51.98332460038541,
           52.028027250286414,
           52.072729900187404,
           52.11743255008841,
           52.16213519998941,
           52.206837849890405,
           52.2515404997914,
           52.2962431496924,
           52.3409457995934,
           52.3856484494944,
           52.4303510993954,
           52.47505374929641,
           52.5197563991974,
           52.5644590490984,
           52.6091616989994,
           52.6538643489004,
           52.6985669988014,
           52.743269648702395,
           52.7879722986034,
           52.832674948504405,
           52.877377598405396,
           52.9220802483064,
           52.9667828982074,
           53.011485548108396,
           53.056188198009394,
           53.1008908479104,
           53.14559349781139,
           53.190296147712395,
           53.234998797613386,
           53.27970144751439,
           53.32440409741539,
           53.36910674731639,
           53.41380939721739,
           53.45851204711839,
           53.50321469701939,
           53.547917346920386,
           53.59261999682139,
           53.63732264672238,
           53.68202529662339,
           53.72672794652438,
           53.77143059642538,
           53.81613324632638,
           53.860835896227385,
           53.905538546128376,
           53.95024119602938,
           53.99494384593038,
           54.03964649583138,
           54.08434914573238,
           54.12905179563337,
           54.17375444553438,
           54.21845709543537,
           54.26315974533638,
           54.30786239523737,
           54.35256504513838,
           54.397091126407595,
           54.44126407092628,
           54.48543701544495,
           54.529609959963636,
           54.573782904482314,
           54.617955849000985,
           54.66212879351967,
           54.70630173803834,
           54.75047468255703,
           54.794647627075705,
           54.83882057159438,
           54.88299351611306,
           54.92716646063174,
           54.97133940515042,
           55.015512349669095,
           55.05968529418777,
           55.10385823870646,
           55.14803118322513,
           55.19220412774381,
           55.236377072262485,
           55.28055001678117,
           55.32472296129984,
           55.36889590581852,
           55.413068850337204,
           55.457241794855875,
           55.50141473937455,
           55.54558768389324,
           55.589760628411916,
           55.63393357293059,
           55.679270014255735,
           55.725188203984096,
           55.77110639371246,
           55.81702458344082,
           55.862942773169195,
           55.908860962897556,
           55.954779152625925,
           56.000697342354286,
           56.046615532082654,
           56.092533721811016,
           56.13845191153938,
           56.184370101267746,
           56.23028829099612,
           56.27620648072448,
           56.322124670452844,
           56.36804286018121,
           56.413961049909574,
           56.45987923963794,
           56.505797429366304,
           56.55171561909467,
           56.59763380882305,
           56.6435519985514,
           56.68947018827977,
           56.73538837800814,
           56.78130656773649,
           56.82722475746487,
           56.87314294719323,
           56.91906113692159,
           56.96497932664997,
           57.01089751637833,
           57.0568157061067,
           57.10273389583506,
           57.14865208556341,
           57.194570275291795,
           57.24048846502015,
           57.28640665474852,
           57.33232484447689,
           57.378243034205255,
           57.42416122393362,
           57.47007941366198,
           57.515997603390346,
           57.56191579311871,
           57.60783398284708,
           57.65375217257544,
           57.6996703623038,
           57.745588552032174,
           57.791506741760536,
           57.837424931488904,
           57.883343121217266,
           57.92926131094564,
           57.975179500674,
           58.021097690402364,
           58.06701588013074,
           58.112934069859094,
           58.15885225958746,
           58.20477044931583,
           58.25068863904419,
           58.29660682877257,
           58.34252501850092,
           58.38844320822929,
           58.43436139795766,
           58.48027958768603,
           58.52619777741438,
           58.57211596714275,
           58.61801617892915,
           58.66388762585636,
           58.70975907278357,
           58.755630519710785,
           58.801501966638,
           58.84737341356521,
           58.893244860492416,
           58.939116307419624,
           58.98498775434683,
           59.03085920127404,
           59.07673064820125,
           59.12260209512847,
           59.16847354205568,
           59.21434498898289,
           59.260216435910095,
           59.3060878828373,
           59.35195932976451,
           59.39783077669173,
           59.443702223618935,
           59.40142353303088,
           59.27099470492753,
           59.14056587682421,
           59.010137048720885,
           58.879708220617545,
           58.74927939251422,
           58.61885056441089,
           58.48842173630755,
           58.357992908204224,
           58.2275640801009,
           58.097135251997564,
           57.96670642389422,
           57.8362775957909,
           57.70584876768757,
           57.575419939584236,
           57.4449911114809,
           57.31456228337758,
           57.18413345527424,
           57.053704627170916,
           56.92327579906758,
           56.792846970964256,
           56.66241814286091,
           56.53198931475759,
           56.40156048665426,
           56.27113165855092,
           56.140702830447594,
           56.01027400234427,
           55.87984517424093,
           55.7494163461376,
           55.618987518034274,
           55.48855868993093,
           55.35812986182761,
           55.22770103372429,
           55.09727220562094,
           54.966843377517606,
           54.83641454941427,
           54.70598572131095,
           54.57555689320762,
           54.445128065104285,
           54.314699237000966,
           54.18427040889762,
           54.0538415807943,
           53.923412752690965,
           53.79298392458763,
           53.66255509648428,
           53.53212626838098,
           53.401697440277644,
           53.271268612174296,
           53.14083978407097,
           53.01041095596765,
           52.87998212786431,
           52.74955329976098,
           52.619124471657656,
           52.48869564355432,
           52.35826681545098,
           52.22783798734767,
           52.09740915924432,
           51.96698033114099,
           51.83586798458509,
           51.691086052759374,
           51.54630412093364,
           51.40152218910793,
           51.2567402572822,
           51.111958325456484,
           50.96717639363076,
           50.82239446180504,
           50.677612529979314,
           50.53283059815358,
           50.38804866632788,
           50.24326673450215,
           50.098484802676424,
           49.953702870850705,
           49.808920939024986,
           49.66413900719925,
           49.51935707537354,
           49.37457514354782,
           49.22979321172209,
           49.08501127989638,
           48.94022934807066,
           48.795447416244926,
           48.6506654844192,
           48.50588355259349,
           48.36110162076777,
           48.12756612631302,
           47.71652350660033,
           47.30548088688766,
           46.894438267174934,
           46.48339564746226,
           46.07235302774958,
           45.661310408036854,
           45.250267788324145,
           44.8392251686115,
           44.42818254889878,
           44.017139929186065,
           43.606097309473384,
           43.19505468976071,
           42.784012070047986,
           42.372969450335304,
           41.96192683062263,
           41.550884210909906,
           41.139841591197225,
           40.72422191427867,
           40.30602932835052,
           39.88783674242238,
           39.469644156494276,
           39.05145157056617,
           38.63325898463803,
           38.21506639870992,
           37.796873812781826,
           37.37868122685367,
           36.96048864092556,
           36.542296054997465,
           36.12410346906932,
           35.70591088314118,
           35.28771829721311,
           34.869525711284965,
           34.451333125356825,
           34.03314053942872,
           33.61494795350062,
           33.19675536757247,
           32.77856278164437,
           32.360370195716264,
           31.942177609788118,
           31.523985023860014,
           31.10579243793191,
           30.687599852003768,
           30.269407266075625,
           29.85121468014752,
           29.433022094219414,
           29.014829508291268,
           28.59663692236317,
           28.178444336435064,
           27.760251750506917,
           27.342059164578817,
           26.923866578650706,
           26.505673992722564,
           26.08748140679442,
           25.669288820866356,
           25.25109623493821,
           24.83290364901007,
           24.41471106308197,
           23.99651847715386,
           23.578325891225717,
           23.160133305297617,
           22.741940719369506,
           22.32374813344137,
           21.905555547513266,
           21.487362961585156,
           21.069170375657016,
           20.65097778972887,
           20.232785203800802,
           19.814592617872663,
           19.396400031944516,
           18.978207446016416,
           18.56001486008831,
           18.141822274160166,
           17.723629688232062,
           17.305437102303955,
           16.887244516375812,
           16.46905193044767,
           16.0508593445196,
           15.63266675859146,
           15.214474172663316,
           14.796281586735214,
           14.378089000807108,
           13.959896414878964,
           13.588044744014383,
           13.447897648467142,
           13.307750552919899,
           13.167603457372655,
           13.02745636182544,
           12.887309266278198,
           12.747162170730956,
           12.607015075183739,
           12.466867979636497,
           12.326720884089255,
           12.18657378854204,
           12.046426692994798,
           11.906279597447556,
           11.766132501900312,
           11.625985406353097,
           11.485838310805853,
           11.345691215258613,
           11.205544119711396,
           11.065397024164152,
           10.92524992861691,
           10.785102833069695,
           10.644955737522453,
           10.504808641975211,
           10.364661546427996,
           10.224514450880754,
           10.08436735533351,
           9.944220259786269,
           9.804073164239053,
           9.663926068691811,
           9.52377897314457,
           9.383631877597352,
           9.24348478205011,
           9.103337686502869,
           8.989687805274473,
           8.882875860415046,
           8.776063915555618,
           8.66925197069619,
           8.562440025836782,
           8.455628080977355,
           8.348816136117927,
           8.24200419125852,
           8.135192246399091,
           8.028380301539665,
           7.921568356680256,
           7.814756411820829,
           7.707944466961401,
           7.601132522101992,
           7.494320577242565,
           7.387508632383137,
           7.28069668752371,
           7.173884742664302,
           7.082176677345652,
           7.015989102011322,
           6.949801526677004,
           6.8836139513426735,
           6.817426376008342,
           6.751238800674025,
           6.685051225339693,
           6.618863650005364,
           6.552676074671034,
           6.486488499336716,
           6.420300924002386,
           6.354113348668054,
           6.287925773333736,
           6.221738197999406,
           6.155550622665075,
           6.089363047330757,
           6.023175471996426,
           5.956987896662096,
           5.890800321327777,
           5.824612745993448,
           5.758425170659117,
           5.692237595324787,
           5.626050019990469,
           5.559862444656138,
           5.493674869321809,
           5.42748729398749,
           5.361299718653159,
           5.295112143318828,
           5.22892456798451,
           5.1627369926501805,
           5.096549417315849,
           5.030361841981519,
           4.964174266647201
          ],
          [
           48.12338218239311,
           48.1727092914239,
           48.22203640045468,
           48.27136350948547,
           48.32069061851626,
           48.370017727547044,
           48.41934483657783,
           48.46867194560861,
           48.517999054639404,
           48.567326163670195,
           48.61665327270098,
           48.665980381731764,
           48.71530749076255,
           48.765510551080396,
           48.815888801854726,
           48.866267052629055,
           48.916645303403385,
           48.967023554177715,
           49.017401804952044,
           49.067780055726374,
           49.1181583065007,
           49.16853655727504,
           49.21891480804936,
           49.2692930588237,
           49.31967130959803,
           49.37004956037235,
           49.42042781114669,
           49.47080606192102,
           49.52118431269534,
           49.57156256346967,
           49.621940814244006,
           49.67231906501833,
           49.722697315792665,
           49.773075566567,
           49.823453817341324,
           49.87383206811566,
           49.92421031888998,
           49.97458856966431,
           50.02496682043864,
           50.07534507121298,
           50.12572332198731,
           50.17610157276164,
           50.22647982353597,
           50.2768580743103,
           50.32723632508463,
           50.37761457585895,
           50.427992826633286,
           50.478371077407616,
           50.528749328181945,
           50.579127578956275,
           50.629505829730604,
           50.679884080504934,
           50.73026233127926,
           50.78064058205359,
           50.83101883282792,
           50.88139708360225,
           50.93177533437659,
           50.98215358515091,
           51.03253183592524,
           51.082910086699584,
           51.1332883374739,
           51.18366658824824,
           51.234044839022566,
           51.28442308979689,
           51.33480134057123,
           51.38517959134556,
           51.43555784211989,
           51.48593609289422,
           51.53631434366855,
           51.58669259444288,
           51.63707084521721,
           51.68744909599153,
           51.73782734676587,
           51.7882055975402,
           51.83858384831453,
           51.88896209908886,
           51.93934034986319,
           51.98971860063752,
           52.040096851411846,
           52.090475102186176,
           52.14085335296051,
           52.191231603734835,
           52.24160985450917,
           52.2919881052835,
           52.33763668866339,
           52.38233933856439,
           52.42704198846538,
           52.47174463836639,
           52.516447288267386,
           52.561149938168384,
           52.60585258806938,
           52.65055523797038,
           52.69525788787138,
           52.739960537772376,
           52.78466318767338,
           52.82936583757437,
           52.874068487475384,
           52.91877113737637,
           52.96347378727738,
           53.00817643717838,
           53.052879087079376,
           53.09758173698037,
           53.14228438688138,
           53.18698703678238,
           53.23168968668337,
           53.27639233658437,
           53.32109498648537,
           53.36579763638637,
           53.41050028628737,
           53.45520293618837,
           53.49990558608937,
           53.54460823599037,
           53.589310885891365,
           53.63401353579236,
           53.67871618569336,
           53.72341883559436,
           53.768121485495364,
           53.81282413539636,
           53.85752678529736,
           53.902229435198365,
           53.94693208509936,
           53.99163473500036,
           54.03633738490136,
           54.081040034802356,
           54.125742684703354,
           54.17044533460436,
           54.21514798450536,
           54.25985063440636,
           54.30455328430736,
           54.34925593420836,
           54.393958584109356,
           54.438661234010354,
           54.48336388391136,
           54.52806653381236,
           54.572769183713355,
           54.61747183361435,
           54.66217448351535,
           54.706877133416356,
           54.751579783317354,
           54.79628243321835,
           54.84098508311935,
           54.88568773302035,
           54.930390382921345,
           54.97509303282234,
           55.019795682723355,
           55.064498332624346,
           55.10920098252535,
           55.15390363242635,
           55.19860628232735,
           55.243308932228345,
           55.28801158212934,
           55.33271423203034,
           55.377416881931346,
           55.422119531832344,
           55.46682218173334,
           55.511083410398804,
           55.55525635491748,
           55.59942929943617,
           55.64360224395484,
           55.687775188473516,
           55.731948132992194,
           55.77612107751088,
           55.82029402202956,
           55.86446696654823,
           55.90863991106691,
           55.95281285558559,
           55.99698580010426,
           56.042322241429396,
           56.08824043115777,
           56.13415862088613,
           56.180076810614494,
           56.22599500034286,
           56.271913190071224,
           56.317831379799586,
           56.363749569527954,
           56.40966775925633,
           56.455585948984684,
           56.50150413871306,
           56.547422328441414,
           56.59334051816979,
           56.63925870789815,
           56.68517689762652,
           56.73109508735489,
           56.77701327708324,
           56.82293146681161,
           56.86884965653998,
           56.91476784626835,
           56.9606860359967,
           57.00660422572507,
           57.05252241545344,
           57.09844060518181,
           57.14435879491017,
           57.19027698463853,
           57.2361951743669,
           57.28211336409526,
           57.328031553823635,
           57.373949743552,
           57.419867933280365,
           57.465786123008726,
           57.511704312737095,
           57.55762250246546,
           57.60354069219382,
           57.649458881922186,
           57.695377071650555,
           57.741295261378916,
           57.78721345110728,
           57.83313164083565,
           57.879049830564014,
           57.92496802029238,
           57.97088621002075,
           58.01680439974912,
           58.06272258947749,
           58.10864077920586,
           58.15455896893421,
           58.20047715866258,
           58.246395348390934,
           58.2923135381193,
           58.33823172784767,
           58.38414991757604,
           58.4300681073044,
           58.47598629703276,
           58.52190448676113,
           58.56782267648949,
           58.61374086621787,
           58.65965905594623,
           58.70557724567459,
           58.751495435402965,
           58.79741362513133,
           58.843331814859695,
           58.889250004588064,
           58.935168194316425,
           58.98108638404478,
           59.027004573773155,
           59.07292276350152,
           59.11884095322989,
           59.164759142958246,
           59.210677332686615,
           59.256595522414976,
           59.30251371214334,
           59.348431901871706,
           59.39435009160007,
           59.44026828132844,
           59.486186471056804,
           59.53210466078517,
           59.57802285051354,
           59.6239410402419,
           59.669859229970264,
           59.7156624816768,
           59.76141976048828,
           59.80717703929975,
           59.749525580919766,
           59.588465385348314,
           59.44301440245627,
           59.29823247063055,
           59.15345053880482,
           59.00866860697911,
           58.86388667515339,
           58.71910474332766,
           58.57432281150193,
           58.429540879676225,
           58.2847589478505,
           58.13997701602476,
           57.99519508419905,
           57.850413152373335,
           57.7056312205476,
           57.56084928872188,
           57.416067356896164,
           57.271285425070445,
           57.126503493244726,
           56.98172156141901,
           56.836939629593275,
           56.69215769776755,
           56.547375765941844,
           56.40259383411612,
           56.25781190229038,
           56.113029970464666,
           55.968248038638954,
           55.82346610681322,
           55.6786841749875,
           55.53390224316179,
           55.38912031133605,
           55.244338379510324,
           55.09955644768462,
           54.954774515858894,
           54.80999258403316,
           54.66521065220744,
           54.52042872038173,
           54.37564678855601,
           54.23086485673029,
           54.08608292490456,
           53.94130099307884,
           53.79651906125312,
           53.6517371294274,
           53.50695519760168,
           53.36217326577594,
           53.217391333950246,
           53.07260940212451,
           52.92782747029878,
           52.78304553847306,
           52.63826360664734,
           52.493481674821616,
           52.348699742995905,
           52.203917811170186,
           52.05913587934445,
           51.91435394751873,
           51.769572015693015,
           51.624790083867296,
           51.48000815204156,
           51.335226220215844,
           51.190444288390125,
           51.04566235656439,
           50.90088042473867,
           50.75609849291296,
           50.611316561087236,
           50.46653462926152,
           50.321752697435805,
           50.17697076561007,
           50.03218883378434,
           49.887406901958634,
           49.74262497013291,
           49.59784303830718,
           49.453061106481464,
           49.308279174655745,
           49.16349724283001,
           49.0187153110043,
           48.87393337917859,
           48.72915144735285,
           48.584369515527136,
           48.43958758370142,
           48.294805651875684,
           48.15002372004996,
           48.00524178822424,
           47.86045985639852,
           47.62692436194378,
           47.2158817422311,
           46.804839122518416,
           46.39379650280569,
           45.98275388309301,
           45.57171126338034,
           45.16066864366762,
           44.7496260239549,
           44.33858340424226,
           43.92754078452954,
           43.516498164816824,
           43.10545554510415,
           42.69441292539146,
           42.283370305678744,
           41.87232768596606,
           41.46128506625338,
           41.050242446540665,
           40.63919982682799,
           40.2281572071153,
           39.817114587402585,
           39.40607196768986,
           38.99502934797718,
           38.583986728264506,
           38.17294410855179,
           37.76190148883911,
           37.35085886912643,
           36.93981624941371,
           36.52877362970103,
           36.11773100998835,
           35.70668839027563,
           35.29564577056291,
           34.88460315085027,
           34.47356053113755,
           34.062517911424834,
           33.65147529171215,
           33.24043267199947,
           32.829390052286755,
           32.41834743257407,
           32.00730481286139,
           31.596262193148675,
           31.185219573435994,
           30.774176953723313,
           30.363134334010596,
           29.95209171429788,
           29.541049094585198,
           29.13000647487252,
           28.7189638551598,
           28.307921235447118,
           27.896878615734437,
           27.485835996021724,
           27.074793376309042,
           26.663750756596357,
           26.25270813688364,
           25.841665517170927,
           25.430622897458285,
           25.019580277745565,
           24.608537658032844,
           24.197495038320167,
           23.78645241860749,
           23.37540979889477,
           22.964367179182087,
           22.549641244186184,
           22.131448658258037,
           21.71325607232994,
           21.29506348640183,
           20.876870900473687,
           20.458678314545544,
           20.040485728617476,
           19.622293142689333,
           19.20410055676119,
           18.785907970833094,
           18.367715384904983,
           17.949522798976837,
           17.531330213048737,
           17.11313762712063,
           16.694945041192486,
           16.276752455264344,
           15.858559869336277,
           15.440367283408134,
           15.02217469747999,
           14.603982111551888,
           14.18578952562378,
           13.767596939695634,
           13.395745268831059,
           13.255598173283815,
           13.115451077736573,
           12.975303982189331,
           12.835156886642114,
           12.695009791094872,
           12.55486269554763,
           12.414715600000413,
           12.274568504453171,
           12.13442140890593,
           11.994274313358712,
           11.85412721781147,
           11.713980122264228,
           11.573833026716986,
           11.43368593116977,
           11.29353883562253,
           11.153391740075287,
           11.013244644528069,
           10.873097548980827,
           10.74305541118996,
           10.642317815207424,
           10.54158021922487,
           10.440842623242318,
           10.340105027259783,
           10.239367431277229,
           10.138629835294674,
           10.037892239312121,
           9.937154643329587,
           9.836417047347034,
           9.73567945136448,
           9.634941855381946,
           9.534204259399392,
           9.433466663416837,
           9.332729067434302,
           9.231991471451748,
           9.131253875469195,
           9.03051627948664,
           8.929778683504107,
           8.829041087521553,
           8.728303491538998,
           8.627565895556463,
           8.52682829957391,
           8.426090703591356,
           8.325353107608821,
           8.224615511626267,
           8.123877915643714,
           8.023140319661179,
           7.9224027236786245,
           7.821665127696072,
           7.720927531713517,
           7.620189935730984,
           7.51945233974843,
           7.418714743765876,
           7.317977147783341,
           7.2172395518007875,
           7.116501955818233,
           7.015764359835698,
           6.915026763853144,
           6.814289167870591,
           6.713551571888037,
           6.612813975905501,
           6.512076379922949,
           6.411338783940395,
           6.310601187957859,
           6.2098635919753065,
           6.140575410699118,
           6.074387835364799,
           6.008200260030469,
           5.942012684696138,
           5.87582510936182,
           5.809637534027491,
           5.74344995869316,
           5.67726238335883,
           5.611074808024512,
           5.544887232690181,
           5.47869965735585,
           5.412512082021532,
           5.346324506687202,
           5.280136931352871,
           5.213949356018552,
           5.147761780684222,
           5.081574205349892,
           5.015386630015562,
           4.949199054681244
          ],
          [
           48.45743858355185,
           48.50862337348658,
           48.55980816342131,
           48.61099295335604,
           48.66217774329077,
           48.712824840457685,
           48.76320309123201,
           48.813581342006344,
           48.863959592780674,
           48.91433784355501,
           48.96471609432933,
           49.01509434510366,
           49.06547259587799,
           49.11585084665232,
           49.16622909742665,
           49.21660734820098,
           49.26698559897532,
           49.31736384974965,
           49.36774210052398,
           49.418120351298306,
           49.46849860207263,
           49.518876852846965,
           49.56925510362129,
           49.61963335439563,
           49.67001160516996,
           49.72038985594428,
           49.77076810671861,
           49.82114635749294,
           49.87152460826727,
           49.9219028590416,
           49.97228110981594,
           50.02265936059027,
           50.0730376113646,
           50.12341586213893,
           50.17379411291326,
           50.224172363687586,
           50.274550614461916,
           50.324928865236245,
           50.375307116010575,
           50.425685366784904,
           50.476063617559234,
           50.52644186833356,
           50.57682011910789,
           50.62719836988222,
           50.67757662065655,
           50.72795487143088,
           50.77833312220522,
           50.82871137297954,
           50.87908962375387,
           50.92946787452821,
           50.97984612530254,
           51.030224376076866,
           51.080602626851196,
           51.130980877625525,
           51.18135912839986,
           51.231737379174184,
           51.28211562994852,
           51.33249388072284,
           51.38287213149717,
           51.43325038227151,
           51.48362863304583,
           51.534006883820176,
           51.5843851345945,
           51.63476338536882,
           51.68514163614316,
           51.73551988691749,
           51.78589813769182,
           51.836276388466146,
           51.886654639240476,
           51.937032890014805,
           51.98741114078914,
           52.03778939156347,
           52.0881676423378,
           52.13854589311213,
           52.18892414388646,
           52.23930239466079,
           52.28968064543511,
           52.34005889620944,
           52.39043714698378,
           52.44081539775811,
           52.49119364853244,
           52.54157189930677,
           52.5919501500811,
           52.642328400855426,
           52.688286020016704,
           52.73335951285539,
           52.778433005694055,
           52.82350649853274,
           52.868394569905234,
           52.91309721980623,
           52.95779986970723,
           53.00250251960823,
           53.047205169509226,
           53.091907819410224,
           53.13661046931123,
           53.18131311921222,
           53.22601576911323,
           53.27071841901422,
           53.31542106891523,
           53.360123718816226,
           53.404826368717224,
           53.44952901861823,
           53.49423166851923,
           53.538934318420225,
           53.58363696832122,
           53.62833961822222,
           53.67304226812322,
           53.717744918024216,
           53.76244756792522,
           53.80715021782622,
           53.85185286772722,
           53.896555517628215,
           53.94125816752921,
           53.98596081743021,
           54.030663467331216,
           54.07536611723222,
           54.120068767133205,
           54.16477141703421,
           54.209474066935215,
           54.25417671683621,
           54.29887936673721,
           54.34358201663821,
           54.38828466653921,
           54.43298731644021,
           54.4776899663412,
           54.5223926162422,
           54.567095266143205,
           54.61179791604421,
           54.65650056594521,
           54.701203215846206,
           54.745905865747204,
           54.7906085156482,
           54.8353111655492,
           54.8800138154502,
           54.9247164653512,
           54.9694191152522,
           55.0141217651532,
           55.0588244150542,
           55.1035270649552,
           55.1482297148562,
           55.1929323647572,
           55.237635014658196,
           55.28233766455919,
           55.32704031446019,
           55.37174296436119,
           55.41644561426219,
           55.46114826416319,
           55.5058509140642,
           55.55055356396519,
           55.59525621386619,
           55.63995886376719,
           55.68466151366819,
           55.72936416356919,
           55.774066813470185,
           55.81876946337119,
           55.86347211327219,
           55.908174763173186,
           55.952877413074184,
           55.99758006297518,
           56.04228271287619,
           56.086985362777185,
           56.13168801267819,
           56.17639066257919,
           56.221093312480185,
           56.26579596238118,
           56.31049861228218,
           56.35520126218318,
           56.400615353059166,
           56.44638516442264,
           56.49215497578612,
           56.5379247871496,
           56.58369459851308,
           56.62946440987656,
           56.67522873824866,
           56.720986017060135,
           56.76674329587161,
           56.812500574683085,
           56.858257853494564,
           56.90401513230603,
           56.94977241111751,
           56.995529689928986,
           57.041286968740444,
           57.08704424755193,
           57.1328015263634,
           57.178558805174866,
           57.22431608398635,
           57.27007336279782,
           57.315830641609296,
           57.361587920420774,
           57.407345199232246,
           57.45310247804372,
           57.49885975685519,
           57.54461703566667,
           57.59037431447814,
           57.63613159328961,
           57.68188887210109,
           57.727646150912555,
           57.773403429724034,
           57.819160708535506,
           57.864917987346985,
           57.91067526615845,
           57.95643254496993,
           58.0021898237814,
           58.04794710259288,
           58.09370438140435,
           58.13946166021583,
           58.185218939027294,
           58.23097621783877,
           58.27673349665025,
           58.32249077546173,
           58.368248054273195,
           58.414005333084674,
           58.45976261189614,
           58.50551989070762,
           58.551277169519096,
           58.59703444833056,
           58.64279172714204,
           58.68854900595352,
           58.73430628476498,
           58.78006356357646,
           58.82582084238794,
           58.871578121199406,
           58.917335400010884,
           58.963092678822356,
           59.008849957633835,
           59.05460723644531,
           59.10036451525678,
           59.14612179406825,
           59.19187907287972,
           59.23763635169121,
           59.28339363050267,
           59.32915090931415,
           59.37490818812562,
           59.420665466937095,
           59.466422745748574,
           59.51218002456005,
           59.55793730337152,
           59.603694582182996,
           59.64945186099447,
           59.69520913980594,
           59.74096641861742,
           59.78672369742888,
           59.83248097624036,
           59.87823825505183,
           59.923995533863305,
           59.96975281267478,
           60.01551009148625,
           60.06126737029773,
           60.107024649109206,
           60.15278192792068,
           60.09513046954069,
           59.93407027396924,
           59.7730100783978,
           59.61194988282636,
           59.450889687254914,
           59.28982949168348,
           59.12876929611203,
           58.96770910054059,
           58.80664890496913,
           58.645588709397714,
           58.48452851382626,
           58.32346831825481,
           58.162408122683374,
           58.00134792711193,
           57.84028773154048,
           57.67922753596905,
           57.51816734039761,
           57.35710714482615,
           57.196046949254715,
           57.034986753683285,
           56.87392655811183,
           56.71286636254038,
           56.55180616696896,
           56.39074597139751,
           56.22968577582605,
           56.06862558025462,
           55.90756538468318,
           55.74650518911172,
           55.58544499354029,
           55.424384797968855,
           55.263324602397404,
           55.10226440682595,
           54.94120421125453,
           54.78014401568308,
           54.619083820111626,
           54.45802362454019,
           54.29696342896875,
           54.13590323339729,
           53.97484303782586,
           53.81378284225442,
           53.65272264668297,
           53.49166245111154,
           53.3306022555401,
           53.169542059968634,
           53.00848186439719,
           52.847421668825774,
           52.686361473254316,
           52.525301277682864,
           52.36424108211143,
           52.20318088653998,
           52.04212069096854,
           51.88106049539711,
           51.720000299825664,
           51.558940104254205,
           51.4137121831495,
           51.26893025132379,
           51.12414831949807,
           50.97936638767234,
           50.834584455846624,
           50.689802524020905,
           50.54502059219517,
           50.40023866036946,
           50.255456728543734,
           50.11067479671801,
           49.96589286489229,
           49.82111093306658,
           49.676329001240845,
           49.53154706941511,
           49.38676513758941,
           49.24198320576368,
           49.097201273937955,
           48.952419342112236,
           48.80763741028652,
           48.66285547846079,
           48.51807354663507,
           48.37329161480936,
           48.22850968298362,
           48.08372775115791,
           47.93894581933219,
           47.79416388750647,
           47.64938195568073,
           47.50460002385501,
           47.35981809202929,
           47.12628259757455,
           46.71523997786187,
           46.30419735814919,
           45.89315473843647,
           45.48211211872379,
           45.07106949901112,
           44.66002687929839,
           44.248984259585676,
           43.83794163987304,
           43.42689902016032,
           43.015856400447596,
           42.604813780734915,
           42.19377116102224,
           41.782728541309524,
           41.371685921596836,
           40.960643301884154,
           40.549600682171445,
           40.138558062458756,
           39.72751544274608,
           39.316472823033365,
           38.90543020332064,
           38.49438758360796,
           38.08334496389528,
           37.67230234418257,
           37.26125972446988,
           36.8502171047572,
           36.43917448504449,
           36.0281318653318,
           35.61708924561913,
           35.20604662590641,
           34.795004006193686,
           34.38396138648104,
           33.97291876676833,
           33.56187614705561,
           33.150833527342925,
           32.73979090763025,
           32.32874828791753,
           31.917705668204853,
           31.50666304849217,
           31.09562042877945,
           30.684577809066766,
           30.273535189354092,
           29.862492569641375,
           29.451449949928655,
           29.04040733021597,
           28.630390396863298,
           28.223339661455164,
           27.816288926047076,
           27.40923819063898,
           27.00218745523085,
           26.595136719822754,
           26.188085984414663,
           25.781035249006532,
           25.373984513598398,
           24.966933778190345,
           24.55988304278221,
           24.152832307374084,
           23.74578157196599,
           23.338730836557893,
           22.93168010114977,
           22.524629365741674,
           22.11757863033358,
           21.71052789492545,
           21.303477159517353,
           20.896426424109258,
           20.48937568870113,
           20.082324953292996,
           19.67527421788494,
           19.268223482476813,
           18.861172747068682,
           18.454122011660587,
           18.04707127625249,
           17.64002054084436,
           17.23296980543627,
           16.825919070028178,
           16.418868334620043,
           16.011817599211916,
           15.604766863803858,
           15.197716128395726,
           14.790665392987597,
           14.383614657579502,
           13.97656392217141,
           13.569513186763276,
           13.208301791359608,
           13.076287095977795,
           12.944272400595981,
           12.81225770521417,
           12.680243009832381,
           12.54822831445057,
           12.41621361906876,
           12.28419892368697,
           12.15218422830516,
           12.020169532923347,
           11.88815483754156,
           11.756140142159747,
           11.624125446777935,
           11.517540984611909,
           11.416803388629374,
           11.31606579264682,
           11.215328196664267,
           11.114590600681732,
           11.013853004699177,
           10.913115408716623,
           10.812377812734088,
           10.711640216751535,
           10.61090262076898,
           10.510165024786446,
           10.409427428803893,
           10.308689832821338,
           10.207952236838784,
           10.10721464085625,
           10.006477044873698,
           9.905739448891143,
           9.805001852908607,
           9.704264256926054,
           9.6035266609435,
           9.502789064960965,
           9.402051468978412,
           9.301313872995857,
           9.200576277013305,
           9.09983868103077,
           8.999101085048217,
           8.898363489065662,
           8.797625893083127,
           8.696888297100573,
           8.59615070111802,
           8.495413105135484,
           8.39467550915293,
           8.293937913170378,
           8.193200317187843,
           8.092462721205289,
           7.991725125222735,
           7.890987529240181,
           7.7902499332576465,
           7.689512337275093,
           7.588774741292539,
           7.488037145310004,
           7.387299549327451,
           7.286561953344896,
           7.185824357362361,
           7.085086761379808,
           6.984349165397254,
           6.8836115694147,
           6.7828739734321655,
           6.682136377449612,
           6.581398781467058,
           6.480661185484523,
           6.37992358950197,
           6.279185993519416,
           6.178448397536881,
           6.077710801554327,
           5.976973205571773,
           5.876235609589239,
           5.7754980136066845,
           5.68817085306883,
           5.625358238092113,
           5.56254562311541,
           5.499733008138693,
           5.4369203931619765,
           5.374107778185271,
           5.311295163208555,
           5.248482548231838,
           5.1856699332551335,
           5.122857318278417,
           5.0600447033017,
           4.997232088324983,
           4.934419473348278
          ],
          [
           48.783319410889455,
           48.834504200824185,
           48.885688990758915,
           48.93687378069364,
           48.988058570628375,
           49.0392433605631,
           49.09042815049783,
           49.14161294043256,
           49.192797730367296,
           49.24398252030202,
           49.29516731023675,
           49.34635210017148,
           49.39753689010621,
           49.44872168004094,
           49.49990646997567,
           49.55109125991039,
           49.60227604984513,
           49.653460839779854,
           49.70464562971459,
           49.755830419649314,
           49.807015209584044,
           49.85806557646424,
           49.908443827238564,
           49.9588220780129,
           50.00920032878723,
           50.05957857956155,
           50.10995683033589,
           50.16033508111022,
           50.21071333188455,
           50.26109158265888,
           50.31146983343321,
           50.36184808420754,
           50.41222633498187,
           50.462604585756196,
           50.512982836530526,
           50.563361087304855,
           50.613739338079185,
           50.664117588853514,
           50.714495839627844,
           50.764874090402174,
           50.8152523411765,
           50.86563059195083,
           50.91600884272517,
           50.9663870934995,
           51.01676534427383,
           51.06714359504815,
           51.117521845822495,
           51.16790009659682,
           51.21827834737115,
           51.26865659814549,
           51.319034848919806,
           51.36941309969414,
           51.41979135046847,
           51.4701696012428,
           51.52054785201714,
           51.57092610279146,
           51.6213043535658,
           51.67168260434012,
           51.72206085511445,
           51.772439105888786,
           51.82281735666311,
           51.873195607437445,
           51.92357385821177,
           51.9739521089861,
           52.02433035976043,
           52.074708610534756,
           52.125086861309086,
           52.175465112083415,
           52.22584336285775,
           52.27622161363208,
           52.32659986440641,
           52.37697811518074,
           52.42735636595507,
           52.4777346167294,
           52.52811286750373,
           52.57849111827806,
           52.62886936905239,
           52.679247619826725,
           52.729625870601055,
           52.780004121375384,
           52.830382372149714,
           52.880760622924036,
           52.931138873698366,
           52.981517124472695,
           53.02747474363399,
           53.07254823647266,
           53.11762172931133,
           53.16269522215001,
           53.20776871498869,
           53.252842207827356,
           53.29791570066604,
           53.34298919350471,
           53.38806268634338,
           53.43313617918206,
           53.47820967202073,
           53.52328316485941,
           53.568356657698075,
           53.61343015053676,
           53.65850364337543,
           53.70357713621411,
           53.74865062905278,
           53.79372412189145,
           53.838797614730126,
           53.8838711075688,
           53.928944600407476,
           53.97364725037232,
           54.01834990027332,
           54.06305255017432,
           54.10775520007532,
           54.152457849976315,
           54.19716049987732,
           54.24186314977832,
           54.286565799679316,
           54.33126844958032,
           54.37597109948132,
           54.42067374938232,
           54.465376399283315,
           54.51007904918431,
           54.55478169908531,
           54.59948434898631,
           54.64418699888732,
           54.68888964878831,
           54.73359229868931,
           54.778294948590315,
           54.822997598491305,
           54.86770024839231,
           54.91240289829331,
           54.957105548194306,
           55.001808198095304,
           55.0465108479963,
           55.0912134978973,
           55.13591614779831,
           55.18061879769931,
           55.22532144760031,
           55.270024097501306,
           55.314726747402304,
           55.3594293973033,
           55.4041320472043,
           55.4488346971053,
           55.4935373470063,
           55.53823999690731,
           55.582942646808306,
           55.6276452967093,
           55.6723479466103,
           55.7170505965113,
           55.7617532464123,
           55.806455896313295,
           55.8511585462143,
           55.89586119611529,
           55.940563846016296,
           55.985266495917294,
           56.02996914581829,
           56.0746717957193,
           56.11937444562029,
           56.16407709552129,
           56.20877974542229,
           56.25348239532329,
           56.29818504522429,
           56.342887695125285,
           56.38759034502628,
           56.432292994927295,
           56.47699564482829,
           56.52169829472929,
           56.56640094463029,
           56.611103594531286,
           56.655806244432284,
           56.70050889433328,
           56.74592298520927,
           56.79169279657274,
           56.837462607936224,
           56.8832324192997,
           56.92900223066319,
           56.97477204202666,
           57.02054185339014,
           57.06631166475361,
           57.1120814761171,
           57.15785128748057,
           57.20362109884405,
           57.249390910207524,
           57.29516072157101,
           57.34093053293448,
           57.386700344297964,
           57.43247015566144,
           57.47823996702492,
           57.5240097783884,
           57.569779589751874,
           57.61554940111536,
           57.66131921247883,
           57.707089023842315,
           57.752858835205785,
           57.79862864656927,
           57.84439845793274,
           57.89016826929622,
           57.9359380806597,
           57.98170789202317,
           58.02747770338666,
           58.073247514750136,
           58.11900831834496,
           58.16476559715643,
           58.210522875967904,
           58.256280154779375,
           58.30203743359085,
           58.347794712402326,
           58.393551991213805,
           58.43930927002528,
           58.48506654883675,
           58.53082382764822,
           58.5765811064597,
           58.62233838527118,
           58.66809566408265,
           58.71385294289412,
           58.75961022170559,
           58.805367500517065,
           58.85112477932854,
           58.896882058140015,
           58.94263933695149,
           58.98839661576296,
           59.03415389457444,
           59.07991117338591,
           59.12566845219739,
           59.17142573100885,
           59.21718300982033,
           59.26294028863181,
           59.30869756744328,
           59.354454846254754,
           59.40021212506623,
           59.4459694038777,
           59.491726682689176,
           59.537483961500655,
           59.58324124031213,
           59.628998519123606,
           59.67475579793506,
           59.72051307674654,
           59.76627035555802,
           59.8120276343695,
           59.857784913180964,
           59.903542191992436,
           59.949299470803915,
           59.995056749615394,
           60.040814028426865,
           60.086571307238344,
           60.1323285860498,
           60.17808586486128,
           60.22384314367276,
           60.26960042248423,
           60.31535770129571,
           60.361114980107175,
           60.40687225891865,
           60.45262953773013,
           60.498386816541604,
           60.44073535816161,
           60.279675162590166,
           60.11861496701872,
           59.95755477144729,
           59.79649457587583,
           59.63543438030439,
           59.47437418473296,
           59.31331398916151,
           59.152253793590056,
           58.99119359801864,
           58.83013340244718,
           58.66907320687574,
           58.50801301130429,
           58.346952815732855,
           58.18589262016141,
           58.024832424589974,
           57.86377222901853,
           57.702712033447085,
           57.54165183787565,
           57.3805916423042,
           57.21953144673275,
           57.05847125116131,
           56.897411055589885,
           56.73635086001843,
           56.57529066444698,
           56.414230468875544,
           56.25317027330411,
           56.09211007773265,
           55.93104988216122,
           55.76998968658978,
           55.60892949101832,
           55.447869295446864,
           55.286809099875455,
           55.12574890430399,
           54.964688708732545,
           54.803628513161115,
           54.64256831758967,
           54.48150812201822,
           54.32044792644679,
           54.15938773087535,
           53.99832753530389,
           53.83726733973245,
           53.67620714416102,
           53.51514694858956,
           53.35408675301811,
           53.1930265574467,
           53.031966361875234,
           52.87090616630378,
           52.70984597073235,
           52.54878577516091,
           52.38772557958946,
           52.22666538401803,
           52.06560518844658,
           51.90454499287514,
           51.74348479730369,
           51.58242460173226,
           51.421364406160805,
           51.26030421058936,
           51.099244015017916,
           50.938183819446486,
           50.77712362387503,
           50.6160634283036,
           50.45500323273215,
           50.29394303716071,
           50.13288284158927,
           49.971822646017834,
           49.810762450446376,
           49.649702254874924,
           49.48864205930351,
           49.32758186373206,
           49.14671812184349,
           48.95756449114948,
           48.768410860455475,
           48.57925722976145,
           48.39010359906744,
           48.200949968373436,
           48.01179633767941,
           47.82264270698539,
           47.63348907629138,
           47.44433544559736,
           47.25518181490334,
           47.06602818420932,
           46.87687455351532,
           46.6175608113882,
           46.217926846395,
           45.8182928814018,
           45.41865891640856,
           45.01902495141537,
           44.619390986422175,
           44.21975702142893,
           43.820123056435705,
           43.42048909144253,
           43.020855126449305,
           42.62122116145607,
           42.22158719646286,
           41.821953231469664,
           41.42231926647643,
           41.022685301483236,
           40.623051336490036,
           40.2234173714968,
           39.823783406503594,
           39.4241494415104,
           39.02451547651716,
           38.62162536066539,
           38.2145746252573,
           37.8075238898492,
           37.40047315444107,
           36.99342241903298,
           36.58637168362488,
           36.17932094821675,
           35.77227021280866,
           35.36521947740056,
           34.95816874199244,
           34.551118006584296,
           34.14406727117624,
           33.73701653576812,
           33.329965800359986,
           32.92291506495189,
           32.5158643295438,
           32.10881359413567,
           31.70176285872757,
           31.294712123319478,
           30.887661387911347,
           30.48061065250326,
           30.073559917095164,
           29.66650918168703,
           29.2594584462789,
           28.852407710870807,
           28.445356975462712,
           28.03830624005458,
           27.631255504646486,
           27.224204769238394,
           26.817154033830267,
           26.410103298422168,
           26.003052563014077,
           25.596001827605946,
           25.18895109219781,
           24.781900356789762,
           24.374849621381628,
           23.967798885973494,
           23.56074815056541,
           23.15369741515731,
           22.74664667974918,
           22.339595944341088,
           21.93254520893299,
           21.525494473524866,
           21.11844373811677,
           20.71139300270867,
           20.304342267300548,
           19.897291531892414,
           19.49024079648436,
           19.08319006107623,
           18.676139325668096,
           18.269088590259997,
           17.86203785485191,
           17.454987119443775,
           17.047936384035687,
           16.640885648627588,
           16.233834913219457,
           15.826784177811332,
           15.41973344240327,
           15.012682706995138,
           14.605631971587016,
           14.198581236178914,
           13.79153050077083,
           13.384479765362693,
           13.02326836995902,
           12.89125367457721,
           12.759238979195397,
           12.627224283813586,
           12.495209588431798,
           12.363194893049986,
           12.231180197668174,
           12.099165502286386,
           11.967150806904574,
           11.835136111522761,
           11.703121416140974,
           11.571106720759165,
           11.439092025377349,
           11.307077329995538,
           11.175062634613752,
           11.04304793923194,
           10.911033243850127,
           10.77901854846834,
           10.647003853086527,
           10.514989157704715,
           10.382974462322927,
           10.250959766941115,
           10.118945071559304,
           9.986930376177515,
           9.854915680795706,
           9.722900985413892,
           9.590886290032081,
           9.458871594650294,
           9.326856899268481,
           9.194842203886669,
           9.062827508504881,
           8.930812813123069,
           8.798798117741256,
           8.666783422359469,
           8.534768726977658,
           8.402754031595846,
           8.270739336214033,
           8.138724640832246,
           8.012063611221853,
           7.9113260152392995,
           7.810588419256764,
           7.70985082327421,
           7.609113227291656,
           7.5083756313091214,
           7.407638035326567,
           7.306900439344014,
           7.243917078378842,
           7.181104463402125,
           7.118291848425408,
           7.0554792334486915,
           6.992666618471988,
           6.929854003495271,
           6.867041388518555,
           6.804228773541849,
           6.741416158565133,
           6.678603543588416,
           6.615790928611712,
           6.552978313634995,
           6.490165698658278,
           6.427353083681561,
           6.364540468704856,
           6.30172785372814,
           6.238915238751424,
           6.176102623774719,
           6.1132900087980016,
           6.050477393821286,
           5.987664778844581,
           5.924852163867864,
           5.862039548891147,
           5.799226933914443,
           5.736414318937726,
           5.67360170396101,
           5.610789088984293,
           5.547976474007588,
           5.485163859030871,
           5.4223512440541555,
           5.35953862907745,
           5.2967260141007335,
           5.233913399124017,
           5.1711007841473124,
           5.108288169170596,
           5.045475554193879,
           4.982662939217162,
           4.919850324240458
          ],
          [
           49.10920023822705,
           49.16038502816178,
           49.211569818096514,
           49.26275460803124,
           49.313939397965974,
           49.3651241879007,
           49.41630897783543,
           49.46749376777016,
           49.518678557704895,
           49.56986334763962,
           49.62104813757434,
           49.67223292750908,
           49.7234177174438,
           49.77460250737854,
           49.82578729731327,
           49.87697208724799,
           49.92815687718272,
           49.97934166711745,
           50.03052645705218,
           50.08171124698691,
           50.13289603692164,
           50.18408082685637,
           50.235265616791104,
           50.286450406725834,
           50.33763519666056,
           50.388819986595294,
           50.44000477653002,
           50.491189566464755,
           50.54237435639948,
           50.593559146334215,
           50.64474393626894,
           50.695928726203675,
           50.7471135161384,
           50.798298306073136,
           50.84948309600786,
           50.90066788594259,
           50.95185267587732,
           51.00303746581204,
           51.05368456324512,
           51.10406281401946,
           51.15444106479379,
           51.204819315568116,
           51.255197566342446,
           51.305575817116775,
           51.355954067891105,
           51.40633231866543,
           51.456710569439764,
           51.507088820214086,
           51.557467070988416,
           51.60784532176275,
           51.65822357253708,
           51.70860182331141,
           51.75898007408574,
           51.80935832486007,
           51.85973657563441,
           51.91011482640873,
           51.96049307718307,
           52.01087132795739,
           52.06124957873172,
           52.111627829506055,
           52.16200608028038,
           52.212384331054714,
           52.26276258182904,
           52.31314083260337,
           52.36351908337771,
           52.41389733415204,
           52.46427558492636,
           52.51465383570069,
           52.56503208647503,
           52.61541033724936,
           52.66578858802369,
           52.71616683879802,
           52.76654508957235,
           52.816923340346676,
           52.867301591121006,
           52.917679841895335,
           52.968058092669665,
           53.018436343443994,
           53.068814594218324,
           53.119192844992654,
           53.16957109576698,
           53.21994934654131,
           53.27032759731564,
           53.32070584808997,
           53.36666346725126,
           53.41173696008993,
           53.45681045292861,
           53.50188394576728,
           53.54695743860596,
           53.592030931444626,
           53.63710442428331,
           53.682177917121976,
           53.72725140996066,
           53.772324902799326,
           53.81739839563801,
           53.862471888476676,
           53.90754538131535,
           53.95261887415403,
           53.9976923669927,
           54.04276585983138,
           54.08783935267005,
           54.13291284550873,
           54.177986338347395,
           54.22305983118607,
           54.268133324024745,
           54.31320681686342,
           54.3582803097021,
           54.40335380254077,
           54.448427295379446,
           54.493500788218114,
           54.538574281056796,
           54.58364777389547,
           54.628721266734146,
           54.67379475957282,
           54.71886825241149,
           54.76394174525017,
           54.80901523808884,
           54.854088730927515,
           54.89916222376619,
           54.944235716604865,
           54.98930920944354,
           55.034197280938415,
           55.07889993083941,
           55.12360258074042,
           55.16830523064141,
           55.213007880542406,
           55.25771053044341,
           55.302413180344416,
           55.347115830245414,
           55.39181848014641,
           55.43652113004741,
           55.48122377994841,
           55.525926429849406,
           55.570629079750404,
           55.61533172965141,
           55.66003437955241,
           55.704737029453405,
           55.7494396793544,
           55.79414232925541,
           55.838844979156406,
           55.883547629057404,
           55.9282502789584,
           55.9729529288594,
           56.0176555787604,
           56.062358228661395,
           56.10706087856239,
           56.1517635284634,
           56.1964661783644,
           56.241168828265394,
           56.2858714781664,
           56.3305741280674,
           56.375276777968395,
           56.41997942786939,
           56.46468207777039,
           56.509384727671396,
           56.554087377572394,
           56.59879002747339,
           56.64349267737439,
           56.68819532727539,
           56.73289797717639,
           56.77760062707739,
           56.82230327697839,
           56.86700592687939,
           56.911708576780384,
           56.95641122668139,
           57.00111387658239,
           57.045816526483385,
           57.09123061735937,
           57.13700042872284,
           57.18277024008633,
           57.22854005144981,
           57.27430986281328,
           57.32007967417677,
           57.36584948554024,
           57.41161929690372,
           57.45738910826719,
           57.50315891963068,
           57.548928730994156,
           57.594698542357634,
           57.64046835372111,
           57.68623816508459,
           57.73200797644806,
           57.777777787811544,
           57.823547599175015,
           57.8693174105385,
           57.91508722190198,
           57.960857033265455,
           58.006626844628926,
           58.05239665599241,
           58.098166467355895,
           58.14393627871937,
           58.18970609008285,
           58.23547590144632,
           58.281245712809806,
           58.32701552417328,
           58.37278533553676,
           58.41855514690023,
           58.4643249582637,
           58.51009476962719,
           58.55586458099067,
           58.60163439235414,
           58.64740420371763,
           58.6931740150811,
           58.73894382644458,
           58.78471363780806,
           58.83048344917153,
           58.876253260535016,
           58.922023071898494,
           58.967792883261964,
           59.01356269462545,
           59.05933250598892,
           59.10510231735241,
           59.15087212871589,
           59.19664194007936,
           59.24241175144283,
           59.288181562806315,
           59.3339513741698,
           59.37972118553327,
           59.425490996896755,
           59.47126080826023,
           59.51703061962371,
           59.56278789844125,
           59.608545177252736,
           59.65430245606421,
           59.70005973487568,
           59.74581701368716,
           59.79157429249862,
           59.8373315713101,
           59.883088850121574,
           59.928846128933046,
           59.974603407744524,
           60.02036068655599,
           60.06611796536747,
           60.11187524417895,
           60.15763252299041,
           60.20338980180189,
           60.249147080613355,
           60.294904359424834,
           60.34066163823631,
           60.38641891704779,
           60.43217619585926,
           60.477933474670735,
           60.52369075348221,
           60.569448032293685,
           60.61520531110516,
           60.66096258991663,
           60.7067198687281,
           60.75247714753957,
           60.79823442635105,
           60.84399170516252,
           60.78634024678253,
           60.62528005121108,
           60.46421985563965,
           60.303159660068204,
           60.14209946449676,
           59.981039268925315,
           59.81997907335388,
           59.65891887778243,
           59.49785868221098,
           59.33679848663956,
           59.1757382910681,
           59.01467809549666,
           58.85361789992522,
           58.692557704353774,
           58.53149750878233,
           58.370437313210886,
           58.209377117639455,
           58.048316922068004,
           57.88725672649657,
           57.72619653092513,
           57.56513633535368,
           57.40407613978222,
           57.243015944210796,
           57.08195574863935,
           56.92089555306789,
           56.75983535749647,
           56.598775161925026,
           56.43771496635358,
           56.27665477078214,
           56.1155945752107,
           55.954534379639256,
           55.7934741840678,
           55.63241398849638,
           55.47135379292492,
           55.31029359735347,
           55.14923340178204,
           54.9881732062106,
           54.827113010639145,
           54.66605281506771,
           54.48219548749849,
           54.293041856804464,
           54.10388822611046,
           53.91473459541645,
           53.725580964722425,
           53.536427334028396,
           53.34727370333441,
           53.158120072640386,
           52.96896644194636,
           52.77981281125234,
           52.59065918055833,
           52.40150554986431,
           52.2123519191703,
           52.023198288476294,
           51.83404465778227,
           51.64489102708824,
           51.455737396394255,
           51.266583765700226,
           51.077430135006196,
           50.88827650431219,
           50.69912287361818,
           50.50996924292416,
           50.32081561223015,
           50.13166198153614,
           49.94250835084212,
           49.75335472014811,
           49.564201089454095,
           49.375047458760065,
           49.18589382806604,
           48.99674019737205,
           48.807586566678026,
           48.618432935984,
           48.429279305289995,
           48.24012567459599,
           48.05097204390196,
           47.861818413207956,
           47.672664782513934,
           47.48351115181991,
           47.2943575211259,
           47.105203890431895,
           46.916050259737865,
           46.726896629043836,
           46.537742998349835,
           46.348589367655826,
           46.089275625528714,
           45.689641660535514,
           45.290007695542315,
           44.89037373054907,
           44.49073976555587,
           44.09110580056268,
           43.691471835569445,
           43.29183787057621,
           42.892203905583045,
           42.4925699405898,
           42.092935975596575,
           41.693302010603375,
           41.293668045610175,
           40.89403408061695,
           40.49440011562374,
           40.09476615063055,
           39.695132185637306,
           39.295498220644106,
           38.895864255650906,
           38.49623029065767,
           38.096596325664436,
           37.696962360671236,
           37.297328395678036,
           36.89769443068481,
           36.49806046569161,
           36.09842650069841,
           35.698792535705174,
           35.29915857071197,
           34.899524605718774,
           34.49989064072554,
           34.100256675732304,
           33.70062271073914,
           33.300988745745904,
           32.90135478075267,
           32.50172081575947,
           32.10208685076627,
           31.702452885773035,
           31.302818920779842,
           30.90318495578664,
           30.5035509907934,
           30.1039170258002,
           29.704283060807,
           29.304649095813765,
           28.90501513082053,
           28.50538116582733,
           28.10574720083413,
           27.706113235840895,
           27.306479270847696,
           26.906845305854496,
           26.507211340861264,
           26.10757737586806,
           25.707943410874865,
           25.308309445881626,
           24.90867548088839,
           24.509041515895234,
           24.109407550901995,
           23.70977358590876,
           23.31013962091556,
           22.910505655922364,
           22.51087169092913,
           22.11123772593593,
           21.71160376094273,
           21.311969795949494,
           20.912335830956295,
           20.5127018659631,
           20.11306790096986,
           19.712258110491824,
           19.305207375083775,
           18.89815663967564,
           18.49110590426751,
           18.084055168859415,
           17.67700443345132,
           17.269953698043192,
           16.8629029626351,
           16.455852227227005,
           16.048801491818878,
           15.641750756410744,
           15.23470002100269,
           14.827649285594557,
           14.420598550186426,
           14.013547814778333,
           13.606497079370241,
           13.199446343962105,
           12.838234948558437,
           12.706220253176623,
           12.57420555779481,
           12.442190862413002,
           12.310176167031212,
           12.1781614716494,
           12.04614677626759,
           11.914132080885802,
           11.782117385503991,
           11.650102690122177,
           11.51808799474039,
           11.386073299358578,
           11.254058603976768,
           11.148997583206281,
           11.054099343001468,
           10.959201102796635,
           10.864302862591805,
           10.769404622386993,
           10.67450638218216,
           10.579608141977332,
           10.484709901772517,
           10.389811661567684,
           10.294913421362855,
           10.20001518115804,
           10.105116940953211,
           10.010218700748378,
           9.915320460543548,
           9.820422220338735,
           9.725523980133904,
           9.630625739929071,
           9.53572749972426,
           9.440829259519427,
           9.345931019314598,
           9.251032779109783,
           9.15613453890495,
           9.061236298700122,
           8.966338058495289,
           8.871439818290476,
           8.776541578085647,
           8.681643337880814,
           8.586745097676001,
           8.49184685747117,
           8.396948617266338,
           8.302050377061526,
           8.207152136856694,
           8.112253896651863,
           8.01735565644705,
           7.922457416242218,
           7.827559176037387,
           7.732660935832556,
           7.6377626956277425,
           7.542864455422912,
           7.447966215218081,
           7.353067975013267,
           7.258169734808437,
           7.163271494603606,
           7.068373254398793,
           6.97347501419396,
           6.87857677398913,
           6.783678533784299,
           6.688780293579486,
           6.593882053374655,
           6.498983813169823,
           6.404085572965009,
           6.309187332760178,
           6.214289092555347,
           6.119390852350534,
           6.024492612145703,
           5.929594371940872,
           5.834696131736059,
           5.739797891531227,
           5.659032554853189,
           5.596219939876473,
           5.533407324899768,
           5.470594709923051,
           5.407782094946334,
           5.344969479969629,
           5.2821568649929125,
           5.219344250016196,
           5.156531635039491,
           5.093719020062775,
           5.030906405086059,
           4.968093790109342,
           4.905281175132637
          ],
          [
           49.43508106556466,
           49.4862658554994,
           49.53745064543413,
           49.58863543536885,
           49.63982022530359,
           49.69100501523831,
           49.74218980517304,
           49.79337459510777,
           49.84455938504251,
           49.89574417497723,
           49.94692896491196,
           49.99811375484669,
           50.049298544781415,
           50.10048333471615,
           50.15166812465088,
           50.202852914585606,
           50.25403770452034,
           50.305222494455066,
           50.356407284389796,
           50.407592074324526,
           50.45877686425926,
           50.50996165419399,
           50.561146444128724,
           50.61233123406345,
           50.66351602399817,
           50.71470081393291,
           50.76588560386763,
           50.81707039380237,
           50.8682551837371,
           50.91943997367183,
           50.97062476360655,
           51.02180955354129,
           51.07299434347601,
           51.12417913341075,
           51.17536392334547,
           51.2265487132802,
           51.27773350321493,
           51.32891829314966,
           51.38010308308439,
           51.43128787301912,
           51.48247266295385,
           51.533657452888576,
           51.58484224282331,
           51.63602703275804,
           51.68721182269277,
           51.7383966126275,
           51.789581402562234,
           51.84076619249696,
           51.89195098243168,
           51.94313577236642,
           51.99432056230114,
           52.04550535223588,
           52.09669014217061,
           52.14787493210534,
           52.1989252992517,
           52.24930355002602,
           52.29968180080036,
           52.35006005157469,
           52.400438302349016,
           52.450816553123346,
           52.501194803897675,
           52.551573054672005,
           52.601951305446335,
           52.652329556220664,
           52.702707806994994,
           52.75308605776932,
           52.80346430854365,
           52.85384255931798,
           52.90422081009231,
           52.95459906086664,
           53.00497731164098,
           53.0553555624153,
           53.10573381318963,
           53.15611206396396,
           53.206490314738296,
           53.256868565512626,
           53.307246816286955,
           53.357625067061285,
           53.408003317835615,
           53.45838156860995,
           53.50875981938428,
           53.5591380701586,
           53.60951632093293,
           53.65989457170727,
           53.70585219086854,
           53.750925683707216,
           53.79599917654589,
           53.841072669384566,
           53.88614616222324,
           53.931219655061916,
           53.97629314790059,
           54.02136664073927,
           54.06644013357794,
           54.11151362641661,
           54.15658711925529,
           54.20166061209396,
           54.24673410493264,
           54.29180759777131,
           54.33688109060999,
           54.38195458344866,
           54.427028076287336,
           54.47210156912601,
           54.51717506196469,
           54.56224855480336,
           54.60732204764203,
           54.65239554048071,
           54.69746903331938,
           54.74254252615806,
           54.78761601899674,
           54.832689511835405,
           54.87776300467409,
           54.92283649751275,
           54.96790999035143,
           55.012983483190105,
           55.05805697602878,
           55.103130468867455,
           55.14820396170613,
           55.1932774545448,
           55.23835094738348,
           55.28342444022215,
           55.328497933060824,
           55.373571425899506,
           55.41864491873817,
           55.46371841157685,
           55.508791904415524,
           55.55386539725419,
           55.598938890092874,
           55.64401238293155,
           55.689085875770225,
           55.73415936860889,
           55.77923286144756,
           55.82430635428624,
           55.869379847124925,
           55.914453339963586,
           55.95952683280227,
           56.004600325640936,
           56.04967381847962,
           56.0947473113183,
           56.13944996140552,
           56.18415261130652,
           56.228855261207514,
           56.273557911108526,
           56.31826056100952,
           56.36296321091052,
           56.40766586081152,
           56.45236851071252,
           56.497071160613515,
           56.54177381051452,
           56.58647646041552,
           56.631179110316516,
           56.675881760217514,
           56.72058441011851,
           56.76528706001952,
           56.80998970992051,
           56.85469235982151,
           56.89939500972251,
           56.94409765962351,
           56.98880030952451,
           57.033502959425505,
           57.0782056093265,
           57.1229082592275,
           57.16761090912851,
           57.21231355902951,
           57.25701620893051,
           57.30171885883151,
           57.346421508732504,
           57.3911241586335,
           57.43653824950949,
           57.48230806087297,
           57.52807787223644,
           57.57384768359992,
           57.61961749496339,
           57.66538730632688,
           57.71115711769036,
           57.75692692905383,
           57.80269674041732,
           57.84846655178079,
           57.89423636314427,
           57.940006174507744,
           57.98577598587123,
           58.031545797234706,
           58.07731560859818,
           58.123085419961654,
           58.16885523132514,
           58.21462504268861,
           58.260394854052095,
           58.306164665415565,
           58.35193447677905,
           58.397704288142535,
           58.443474099506005,
           58.48924391086949,
           58.53501372223297,
           58.58078353359643,
           58.626553344959916,
           58.6723231563234,
           58.71809296768688,
           58.763862779050356,
           58.80963259041383,
           58.85540240177731,
           58.90117221314078,
           58.94694202450426,
           58.99271183586774,
           59.038481647231215,
           59.0842514585947,
           59.13002126995817,
           59.17579108132165,
           59.22156089268513,
           59.26733070404861,
           59.31310051541208,
           59.358870326775566,
           59.40464013813904,
           59.45040994950252,
           59.496179760866,
           59.54194957222948,
           59.587719383592955,
           59.63348919495643,
           59.67925900631992,
           59.72502881768339,
           59.770798629046865,
           59.81656844041035,
           59.86233825177382,
           59.9081080631373,
           59.953877874500776,
           59.999647685864254,
           60.04541749722773,
           60.09118730859121,
           60.13695711995469,
           60.18272693131817,
           60.22849674268165,
           60.27426655404513,
           60.320036365408605,
           60.36580617677208,
           60.41157598813556,
           60.45734579949904,
           60.503115610862515,
           60.54888542222599,
           60.59465523358947,
           60.64042504495295,
           60.68619485631643,
           60.731964667679904,
           60.77773447904339,
           60.82350429040686,
           60.869274101770344,
           60.91504391313382,
           60.9608101997261,
           61.00656747853756,
           61.05232475734904,
           61.09808203616051,
           61.143839314971984,
           61.18959659378346,
           61.13194513540347,
           60.970884939832025,
           60.80982474426058,
           60.648764548689144,
           60.48770435311769,
           60.326644157546255,
           60.16558396197482,
           60.004523766403366,
           59.81767285315344,
           59.62851922245945,
           59.43936559176542,
           59.25021196107139,
           59.06105833037739,
           58.871904699683384,
           58.682751068989354,
           58.493597438295346,
           58.30444380760134,
           58.11529017690731,
           57.9261365462133,
           57.73698291551929,
           57.54782928482527,
           57.35867565413124,
           57.16952202343725,
           56.98036839274323,
           56.7912147620492,
           56.602061131355185,
           56.41290750066118,
           56.223753869967155,
           56.034600239273146,
           55.84544660857913,
           55.656292977885116,
           55.467139347191086,
           55.2779857164971,
           55.08883208580307,
           54.89967845510904,
           54.71052482441504,
           54.52137119372102,
           54.332217563027,
           54.14306393233299,
           53.953910301638984,
           53.764756670944955,
           53.575603040250954,
           53.38644940955694,
           53.197295778862916,
           53.008142148168886,
           52.81898851747489,
           52.62983488678087,
           52.44068125608684,
           52.25152762539283,
           52.06237399469883,
           51.873220364004794,
           51.6840667333108,
           51.494913102616785,
           51.30575947192276,
           51.11660584122873,
           50.92745221053474,
           50.738298579840716,
           50.54914494914669,
           50.35999131845268,
           50.17083768775867,
           49.98168405706464,
           49.79253042637063,
           49.603376795676624,
           49.4142231649826,
           49.225069534288586,
           49.03591590359458,
           48.846762272900556,
           48.657608642206526,
           48.46845501151254,
           48.27930138081851,
           48.09014775012449,
           47.90099411943048,
           47.71184048873647,
           47.52268685804245,
           47.33353322734843,
           47.14437959665443,
           46.9552259659604,
           46.766072335266394,
           46.57691870457238,
           46.387765073878356,
           46.19861144318433,
           46.009457812490325,
           45.82030418179631,
           45.5609904396692,
           45.161356474676,
           44.7617225096828,
           44.36208854468957,
           43.96245457969637,
           43.56282061470316,
           43.16318664970993,
           42.7635526847167,
           42.363918719723536,
           41.9642847547303,
           41.56465078973706,
           41.16501682474386,
           40.765382859750666,
           40.36574889475743,
           39.96611492976423,
           39.56648096477103,
           39.16684699977779,
           38.7672130347846,
           38.367579069791404,
           37.96794510479816,
           37.568311139804926,
           37.16867717481173,
           36.769043209818534,
           36.3694092448253,
           35.9697752798321,
           35.5701413148389,
           35.17050734984566,
           34.770873384852464,
           34.371239419859265,
           33.97160545486603,
           33.57197148987279,
           33.17233752487963,
           32.772703559886395,
           32.37306959489316,
           31.97343562989996,
           31.57380166490676,
           31.174167699913525,
           30.774533734920325,
           30.374899769927126,
           29.97847185899123,
           29.583831961160463,
           29.1891920633297,
           28.7945521654989,
           28.399912267668096,
           28.005272369837332,
           27.610632472006568,
           27.21599257417577,
           26.821352676345004,
           26.426712778514236,
           26.032072880683437,
           25.637432982852673,
           25.24279308502191,
           24.848153187191105,
           24.45351328936031,
           24.058873391529577,
           23.664233493698777,
           23.269593595867978,
           22.87495369803721,
           22.480313800206446,
           22.085673902375646,
           21.691034004544882,
           21.296394106714118,
           20.901754208883318,
           20.50711431105255,
           20.112474413221786,
           19.717834515390983,
           19.323194617560183,
           18.928554719729455,
           18.533914821898655,
           18.139274924067855,
           17.74463502623709,
           17.349995128406327,
           16.955355230575528,
           16.56071533274476,
           16.166075434913996,
           15.771435537083194,
           15.376795639252393,
           14.982155741421664,
           14.587515843590865,
           14.192875945760063,
           13.798236047929299,
           13.403596150098533,
           13.008956252267732,
           12.6594034947617,
           12.535286438879059,
           12.41116938299642,
           12.287052327113779,
           12.162935271231163,
           12.038818215348524,
           11.914701159465883,
           11.790584103583269,
           11.666467047700628,
           11.54234999181799,
           11.418232935935372,
           11.29411588005273,
           11.169998824170094,
           11.045881768287453,
           10.921764712404835,
           10.797647656522196,
           10.673530600639557,
           10.549761363695204,
           10.454863123490375,
           10.359964883285544,
           10.26506664308073,
           10.170168402875898,
           10.075270162671066,
           9.980371922466254,
           9.885473682261422,
           9.790575442056591,
           9.69567720185176,
           9.600778961646947,
           9.505880721442114,
           9.410982481237285,
           9.31608424103247,
           9.22118600082764,
           9.126287760622809,
           9.031389520417996,
           8.936491280213163,
           8.841593040008332,
           8.746694799803501,
           8.651796559598688,
           8.556898319393857,
           8.462000079189027,
           8.367101838984214,
           8.272203598779381,
           8.17730535857455,
           8.082407118369737,
           7.987508878164906,
           7.892610637960075,
           7.797712397755262,
           7.702814157550431,
           7.607915917345599,
           7.513017677140769,
           7.418119436935956,
           7.323221196731124,
           7.228322956526293,
           7.133424716321479,
           7.038526476116648,
           6.943628235911818,
           6.848729995707004,
           6.753831755502173,
           6.658933515297342,
           6.564035275092511,
           6.469137034887698,
           6.374238794682867,
           6.279340554478036,
           6.184442314273221,
           6.089544074068391,
           5.99464583386356,
           5.9052017851125385,
           5.845545824894545,
           5.785889864676552,
           5.726233904458571,
           5.666577944240577,
           5.606921984022584,
           5.547266023804591,
           5.48761006358661,
           5.4279541033686165,
           5.368298143150623,
           5.3086421829326405,
           5.248986222714647,
           5.1893302624966555,
           5.129674302278673,
           5.07001834206068,
           5.010362381842687,
           4.950706421624694,
           4.891050461406712
          ],
          [
           49.76096189290226,
           49.81214668283699,
           49.86333147277172,
           49.91451626270645,
           49.96570105264118,
           50.01688584257591,
           50.06807063251064,
           50.11925542244537,
           50.1704402123801,
           50.22162500231483,
           50.27280979224956,
           50.32399458218429,
           50.375179372119014,
           50.42636416205375,
           50.477548951988474,
           50.528733741923205,
           50.579918531857935,
           50.631103321792665,
           50.6822881117274,
           50.733472901662125,
           50.784657691596855,
           50.835842481531586,
           50.887027271466316,
           50.938212061401046,
           50.989396851335776,
           51.04058164127051,
           51.09176643120523,
           51.14295122113997,
           51.1941360110747,
           51.24532080100943,
           51.29650559094415,
           51.34769038087889,
           51.39887517081361,
           51.45005996074835,
           51.50124475068307,
           51.55242954061781,
           51.60361433055253,
           51.65479912048726,
           51.70598391042199,
           51.75716870035672,
           51.80835349029145,
           51.85953828022618,
           51.91072307016091,
           51.96190786009564,
           52.01309265003037,
           52.064277439965096,
           52.11546222989983,
           52.166647019834556,
           52.21783180976928,
           52.26901659970402,
           52.32020138963874,
           52.37138617957348,
           52.42257096950821,
           52.47375575944294,
           52.524940549377675,
           52.57612533931239,
           52.62731012924713,
           52.67849491918186,
           52.72967970911658,
           52.78086449905132,
           52.83204928898604,
           52.88323407892078,
           52.9344188688555,
           52.98560365879023,
           53.03678844872496,
           53.08797323865969,
           53.13915802859442,
           53.19034281852916,
           53.24152760846388,
           53.29271239839861,
           53.343897188333344,
           53.39454428603258,
           53.44492253680691,
           53.495300787581236,
           53.545679038355566,
           53.596057289129895,
           53.646435539904225,
           53.696813790678554,
           53.747192041452884,
           53.79757029222722,
           53.84794854300155,
           53.89832679377588,
           53.94870504455021,
           53.99908329532454,
           54.04504091448582,
           54.09011440732449,
           54.13518790016317,
           54.18026139300184,
           54.22533488584051,
           54.270408378679186,
           54.31548187151786,
           54.36055536435654,
           54.40562885719521,
           54.450702350033886,
           54.49577584287257,
           54.540849335711236,
           54.58592282854991,
           54.63099632138858,
           54.67606981422727,
           54.721143307065944,
           54.76621679990461,
           54.81129029274329,
           54.85636378558196,
           54.90143727842064,
           54.94651077125931,
           54.99158426409798,
           55.036657756936656,
           55.08173124977533,
           55.12680474261401,
           55.17187823545268,
           55.216951728291356,
           55.26202522113003,
           55.307098713968706,
           55.35217220680738,
           55.39724569964605,
           55.442319192484725,
           55.4873926853234,
           55.532466178162075,
           55.57753967100075,
           55.62261316383942,
           55.6676866566781,
           55.712760149516775,
           55.75783364235545,
           55.80290713519412,
           55.8479806280328,
           55.89305412087147,
           55.938127613710144,
           55.98320110654882,
           56.028274599387494,
           56.07334809222617,
           56.11842158506484,
           56.16349507790352,
           56.208568570742194,
           56.25364206358087,
           56.29871555641954,
           56.34378904925822,
           56.38886254209689,
           56.43393603493557,
           56.47900952777424,
           56.52408302061291,
           56.56915651345159,
           56.61423000629026,
           56.65930349912894,
           56.704376991967614,
           56.74945048480629,
           56.794523977644964,
           56.83959747048364,
           56.884670963322314,
           56.92974445616099,
           56.974817948999664,
           57.01989144183833,
           57.064964934677015,
           57.11003842751568,
           57.15511192035436,
           57.19999999197161,
           57.24470264187261,
           57.289405291773605,
           57.3341079416746,
           57.3788105915756,
           57.4235132414766,
           57.46821589137761,
           57.51291854127861,
           57.55762119117961,
           57.602323841080604,
           57.6470264909816,
           57.6917291408826,
           57.7364317907836,
           57.781845881659585,
           57.82761569302306,
           57.87338550438655,
           57.91915531575002,
           57.964925127113496,
           58.01069493847697,
           58.05646474984046,
           58.102234561203936,
           58.148004372567414,
           58.193774183930884,
           58.23954399529437,
           58.28531380665785,
           58.331083618021324,
           58.3768534293848,
           58.42262324074828,
           58.46839305211176,
           58.514162863475235,
           58.55993267483872,
           58.60570248620219,
           58.65147229756568,
           58.697242108929146,
           58.74301192029264,
           58.78878173165611,
           58.834551543019586,
           58.880321354383064,
           58.92609116574654,
           58.97186097711002,
           59.0176307884735,
           59.06340059983698,
           59.10917041120045,
           59.15494022256393,
           59.20071003392741,
           59.24647984529089,
           59.292249656654356,
           59.338019468017855,
           59.38378927938131,
           59.4295590907448,
           59.47532890210828,
           59.52109871347176,
           59.566868524835236,
           59.612638336198714,
           59.658408147562184,
           59.70401099543361,
           59.74944688127704,
           59.794882767120455,
           59.84031865296385,
           59.88575453880726,
           59.93119042465069,
           59.97662631049408,
           60.022062196337515,
           60.06749808218091,
           60.11293396802432,
           60.15836985386774,
           60.20380573971114,
           60.24924162555456,
           60.294677511397985,
           60.34011339724138,
           60.385549283084806,
           60.43098516892821,
           60.47642105477163,
           60.521856940615045,
           60.56729282645844,
           60.61272871230186,
           60.65816459814527,
           60.70360048398868,
           60.7490363698321,
           60.794472255675515,
           60.83990814151892,
           60.885344027362336,
           60.93077991320574,
           60.97621579904915,
           61.021651684892575,
           61.06708757073598,
           61.11252345657939,
           61.1579593424228,
           61.20339522826621,
           61.248831114109635,
           61.29426699995304,
           61.33970288579645,
           61.385138771639866,
           61.43057465748327,
           61.47601054332668,
           61.5214464291701,
           61.4324002776925,
           61.20887208889389,
           60.98534390009531,
           60.76181571129673,
           60.53828752249813,
           60.314759333699534,
           60.09123114490095,
           59.86770295610235,
           59.64417476730375,
           59.420646578505185,
           59.19711838970658,
           58.973590200907985,
           58.750062012109396,
           58.526533823310814,
           58.30300563451221,
           58.07947744571362,
           57.855949256915046,
           57.632421068116436,
           57.40889287931786,
           57.19798982561045,
           57.00889391949021,
           56.81979801336997,
           56.630702107249775,
           56.44160620112953,
           56.252510295009294,
           56.06341438888907,
           55.87431848276885,
           55.685222576648606,
           55.49612667052838,
           55.30703076440817,
           55.11793485828793,
           54.928838952167695,
           54.73974304604748,
           54.55064713992724,
           54.361551233807,
           54.17245532768679,
           53.98335942156656,
           53.79426351544632,
           53.6051676093261,
           53.41607170320588,
           53.22697579708564,
           53.03787989096542,
           52.8487839848452,
           52.659688078724955,
           52.47059217260471,
           52.28149626648451,
           52.09240036036428,
           51.90330445424404,
           51.714208548123814,
           51.52511264200359,
           51.33601673588335,
           51.14692082976313,
           50.9578249236429,
           50.76872901752267,
           50.57963311140243,
           50.39053720528222,
           50.20144129916198,
           50.01234539304175,
           49.823249486921526,
           49.6341535808013,
           49.44505767468106,
           49.25596176856084,
           49.066865862440615,
           48.87776995632038,
           48.688674050200156,
           48.49957814407993,
           48.3104822379597,
           48.12138633183945,
           47.93229042571925,
           47.74319451959901,
           47.55409861347877,
           47.36500270735855,
           47.17590680123833,
           46.98681089511808,
           46.79771498899787,
           46.608619082877645,
           46.4195231767574,
           46.230427270637186,
           46.04133136451696,
           45.85223545839672,
           45.663139552276476,
           45.474043646156254,
           45.284947740036046,
           45.02978451921544,
           44.642486668994216,
           44.25518881877298,
           43.86789096855171,
           43.48059311833049,
           43.09329526810926,
           42.70599741788799,
           42.318699567666734,
           41.93140171744554,
           41.54410386722428,
           41.156806017003014,
           40.76950816678178,
           40.38221031656055,
           39.99491246633929,
           39.60761461611806,
           39.22031676589683,
           38.83301891567557,
           38.44572106545434,
           38.05842321523311,
           37.67112536501185,
           37.28382751479059,
           36.89652966456936,
           36.50923181434812,
           36.11539694557586,
           35.7207570477451,
           35.32611714991433,
           34.93147725208353,
           34.53683735425277,
           34.14219745642201,
           33.7475575585912,
           33.352917660760404,
           32.958277762929676,
           32.563637865098876,
           32.168997967268076,
           31.774358069437312,
           31.379718171606545,
           30.985078273775745,
           30.59043837594498,
           30.195798478114213,
           29.801158580283413,
           29.40651868245265,
           29.011878784621885,
           28.617238886791082,
           28.222598988960282,
           27.827959091129514,
           27.433319193298754,
           27.038679295467954,
           26.64403939763719,
           26.249399499806426,
           25.854759601975623,
           25.46011970414486,
           25.06547980631409,
           24.67083990848329,
           24.27620001065249,
           23.881560112821763,
           23.48692021499096,
           23.09228031716016,
           22.697640419329396,
           22.30300052149863,
           21.908360623667832,
           21.513720725837068,
           21.119080828006304,
           20.7244409301755,
           20.329801032344736,
           19.935161134513972,
           19.54052123668317,
           19.14588133885237,
           18.75124144102164,
           18.35660154319084,
           17.96196164536004,
           17.567321747529274,
           17.172681849698513,
           16.77804195186771,
           16.383402054036946,
           15.988762156206182,
           15.59412225837538,
           15.199482360544579,
           14.80484246271385,
           14.410202564883049,
           14.015562667052247,
           13.620922769221485,
           13.226282871390719,
           12.83164297355992,
           12.482090216053884,
           12.357973160171245,
           12.233856104288606,
           12.109739048405967,
           11.985621992523349,
           11.86150493664071,
           11.737387880758071,
           11.613270824875453,
           11.489153768992814,
           11.365036713110173,
           11.240919657227558,
           11.116802601344919,
           10.992685545462278,
           10.868568489579637,
           10.744451433697021,
           10.620334377814382,
           10.496217321931743,
           10.372100266049127,
           10.247983210166488,
           10.123866154283848,
           9.999749098401232,
           9.87563204251859,
           9.751514986635952,
           9.627397930753334,
           9.503280874870695,
           9.379163818988054,
           9.255046763105417,
           9.1309297072228,
           9.00681265134016,
           8.88269559545752,
           8.758578539574902,
           8.634461483692263,
           8.510344427809624,
           8.386227371927008,
           8.26211031604437,
           8.137993260161728,
           8.01387620427909,
           7.889759148396473,
           7.765642092513833,
           7.666183604193549,
           7.576878580847119,
           7.487573557500672,
           7.398268534154226,
           7.308963510807795,
           7.2196584874613485,
           7.143942580135044,
           7.084286619917062,
           7.024630659699069,
           6.9649746994810755,
           6.905318739263083,
           6.845662779045101,
           6.786006818827108,
           6.726350858609115,
           6.666694898391134,
           6.60703893817314,
           6.547382977955147,
           6.487727017737165,
           6.428071057519172,
           6.36841509730118,
           6.308759137083186,
           6.249103176865204,
           6.189447216647211,
           6.129791256429217,
           6.070135296211236,
           6.010479335993242,
           5.950823375775251,
           5.891167415557267,
           5.831511455339275,
           5.771855495121281,
           5.7121995349032995,
           5.652543574685307,
           5.592887614467313,
           5.53323165424932,
           5.4735756940313385,
           5.413919733813346,
           5.354263773595353,
           5.29460781337737,
           5.2349518531593775,
           5.175295892941385,
           5.115639932723402,
           5.05598397250541,
           4.9963280122874165,
           4.936672052069424,
           4.877016091851441
          ],
          [
           50.08407527369974,
           50.135887269261815,
           50.187699264823884,
           50.23951126038597,
           50.29111418792755,
           50.34229897786228,
           50.393483767797,
           50.44466855773174,
           50.49585334766646,
           50.5470381376012,
           50.59822292753592,
           50.64940771747065,
           50.70059250740538,
           50.751777297340105,
           50.80296208727484,
           50.85414687720957,
           50.9053316671443,
           50.956516457079026,
           51.007701247013756,
           51.05888603694849,
           51.11007082688322,
           51.16125561681795,
           51.21244040675268,
           51.26362519668741,
           51.31480998662214,
           51.36599477655687,
           51.41717956649159,
           51.46836435642632,
           51.51954914636106,
           51.57073393629578,
           51.62191872623052,
           51.67310351616524,
           51.72428830609998,
           51.77547309603471,
           51.82665788596944,
           51.87784267590416,
           51.92902746583889,
           51.98021225577362,
           52.03139704570835,
           52.08258183564308,
           52.133766625577806,
           52.18495141551254,
           52.236136205447266,
           52.287320995382004,
           52.33850578531673,
           52.389690575251464,
           52.44087536518619,
           52.492060155120924,
           52.54324494505565,
           52.59442973499037,
           52.64561452492511,
           52.69679931485983,
           52.74798410479457,
           52.7991688947293,
           52.85035368466403,
           52.901538474598766,
           52.95272326453348,
           53.00390805446822,
           53.05509284440295,
           53.10627763433767,
           53.15746242427241,
           53.20864721420713,
           53.25983200414187,
           53.3110167940766,
           53.36220158401133,
           53.413386373946054,
           53.464571163880784,
           53.515755953815514,
           53.566940743750244,
           53.618125533684974,
           53.669310323619705,
           53.720495113554435,
           53.771679903489165,
           53.822864693423895,
           53.87404948335862,
           53.92523427329335,
           53.97641906322808,
           54.027603853162816,
           54.07878864309754,
           54.12997343303227,
           54.18115822296701,
           54.23234301290173,
           54.28352780283646,
           54.33471259277119,
           54.38080463512587,
           54.42587812796455,
           54.47095162080322,
           54.516025113641895,
           54.56109860648057,
           54.60617209931924,
           54.65124559215792,
           54.69631908499659,
           54.74139257783526,
           54.78646607067394,
           54.83153956351262,
           54.87661305635129,
           54.92168654918997,
           54.96676004202864,
           55.01183353486732,
           55.056907027705996,
           55.101980520544664,
           55.14705401338334,
           55.192127506222015,
           55.23720099906069,
           55.28227449189936,
           55.32734798473804,
           55.37242147757671,
           55.41749497041538,
           55.46256846325406,
           55.507641956092726,
           55.55271544893141,
           55.597788941770084,
           55.64286243460876,
           55.68793592744743,
           55.73300942028611,
           55.77808291312478,
           55.82315640596345,
           55.86822989880213,
           55.91330339164081,
           55.95837688447948,
           56.00345037731816,
           56.04852387015683,
           56.093597362995496,
           56.13867085583418,
           56.183744348672846,
           56.22881784151152,
           56.2738913343502,
           56.31896482718887,
           56.364038320027554,
           56.40911181286623,
           56.4541853057049,
           56.49925879854357,
           56.54433229138225,
           56.589405784220915,
           56.6344792770596,
           56.679552769898265,
           56.72462626273694,
           56.769699755575616,
           56.8147732484143,
           56.859846741252966,
           56.90492023409164,
           56.949993726930316,
           56.995067219768984,
           57.04014071260766,
           57.08521420544634,
           57.13028769828502,
           57.175361191123685,
           57.22043468396236,
           57.265508176801035,
           57.31058166963972,
           57.355655162478385,
           57.40072865531706,
           57.445802148155735,
           57.49087564099441,
           57.53594913383308,
           57.58102262667175,
           57.62609611951043,
           57.67116961234911,
           57.71624310518778,
           57.761316598026454,
           57.80639009086513,
           57.851463583703804,
           57.89653707654248,
           57.94168486237605,
           57.98698123364301,
           58.03227760490996,
           58.0775739761769,
           58.1229578760623,
           58.16838554025692,
           58.213813204451526,
           58.259240868646145,
           58.304668532840765,
           58.35009619703538,
           58.39552386123,
           58.44095908933111,
           58.48639497517453,
           58.53183086101794,
           58.57726674686135,
           58.622702632704765,
           58.66813851854817,
           58.71357440439158,
           58.75901029023499,
           58.8044461760784,
           58.84988206192182,
           58.895317947765236,
           58.94075383360864,
           58.98618971945206,
           59.031625605295474,
           59.07706149113888,
           59.12249737698229,
           59.167933262825706,
           59.213369148669116,
           59.25880503451253,
           59.304240920355944,
           59.34967680619935,
           59.395112692042765,
           59.44054857788617,
           59.48598446372959,
           59.531420349573004,
           59.57685623541641,
           59.622292121259825,
           59.667728007103236,
           59.71316389294664,
           59.75859977879006,
           59.804035664633474,
           59.849471550476885,
           59.894907436320295,
           59.9403433221637,
           59.98577920800712,
           60.031215093850534,
           60.07665097969394,
           60.122086865537355,
           60.16752275138076,
           60.212958637224176,
           60.25839452306759,
           60.303830408911,
           60.349266294754415,
           60.39470218059782,
           60.440138066441236,
           60.48557395228465,
           60.53100983812806,
           60.576445723971474,
           60.621881609814885,
           60.66731749565829,
           60.712753381501706,
           60.75818926734511,
           60.80362515318854,
           60.849061039031945,
           60.894496924875355,
           60.93993281071877,
           60.985368696562176,
           61.030804582405594,
           61.076240468249004,
           61.121676354092415,
           61.16711223993583,
           61.212548125779236,
           61.25798401162265,
           61.303419897466064,
           61.348855783309475,
           61.39429166915289,
           61.4397275549963,
           61.485163440839706,
           61.53059932668312,
           61.576035212526534,
           61.62147109836995,
           61.666906984213355,
           61.71234287005677,
           61.757778755900176,
           61.803214641743594,
           61.84865052758701,
           61.7596043761094,
           61.5360761873108,
           61.312547998512215,
           61.08901980971363,
           60.86549162091504,
           60.64196343211645,
           60.418435243317866,
           60.19490705451926,
           59.97137886572065,
           59.74785067692209,
           59.52432248812349,
           59.30079429932489,
           59.077266110526296,
           58.85373792172772,
           58.63020973292912,
           58.406681544130535,
           58.18315335533195,
           57.95962516653335,
           57.736096977734775,
           57.51256878893618,
           57.289040600137575,
           57.06551241133897,
           56.841984222540404,
           56.61845603374181,
           56.3949278449432,
           56.17139965614462,
           55.94787146734604,
           55.72434327854743,
           55.500815089748855,
           55.277286900950266,
           55.05375871215166,
           54.83023052335306,
           54.6067023345545,
           54.38317414575589,
           54.159645956957284,
           53.93611776815871,
           53.71258957936013,
           53.48906139056152,
           53.265533201762935,
           53.04200501296435,
           52.81847682416575,
           52.59494863536716,
           52.37142044656858,
           52.14789225776998,
           51.926659510547694,
           51.73756360442749,
           51.54846769830725,
           51.35937179218701,
           51.17027588606679,
           50.98117997994656,
           50.792084073826324,
           50.60298816770611,
           50.413892261585886,
           50.22479635546564,
           50.035700449345406,
           49.8466045432252,
           49.657508637104954,
           49.468412730984724,
           49.2793168248645,
           49.09022091874428,
           48.901125012624036,
           48.71202910650381,
           48.52293320038359,
           48.33383729426336,
           48.14474138814313,
           47.95564548202291,
           47.76654957590267,
           47.57745366978243,
           47.38835776366223,
           47.199261857541984,
           47.01016595142175,
           46.821070045301525,
           46.6319741391813,
           46.442878233061066,
           46.25378232694084,
           46.06468642082062,
           45.875590514700384,
           45.68649460858016,
           45.49739870245994,
           45.3083027963397,
           45.11920689021946,
           44.93011098409924,
           44.741015077979014,
           44.485851857158416,
           44.098554006937185,
           43.71125615671596,
           43.323958306494696,
           42.936660456273465,
           42.54936260605224,
           42.162064755830976,
           41.77476690560971,
           41.38746905538852,
           41.00017120516725,
           40.61287335494599,
           40.22557550472476,
           39.83827765450353,
           39.45097980428227,
           39.06368195406104,
           38.67638410383981,
           38.28908625361855,
           37.90178840339732,
           37.51449055317609,
           37.12719270295483,
           36.739894852733556,
           36.35259700251233,
           35.9652991522911,
           35.578001302069836,
           35.190703451848606,
           34.80340560162738,
           34.416107751406116,
           34.028809901184886,
           33.64151205096366,
           33.254214200742396,
           32.86691635052113,
           32.47961850029994,
           32.092320650078676,
           31.70502279985741,
           31.31772494963618,
           30.930427099414956,
           30.54312924919369,
           30.15583139897246,
           29.76853354875123,
           29.381235698529963,
           28.99393784830874,
           28.60663999808751,
           28.219342147866247,
           27.832044297644984,
           27.444746447423753,
           27.057448597202526,
           26.670150746981264,
           26.282852896760033,
           25.895555046538803,
           25.50825719631754,
           25.120959346096306,
           24.733661495875083,
           24.346363645653817,
           23.95906579543255,
           23.571767945211366,
           23.1844700949901,
           22.79717224476883,
           22.409874394547607,
           22.022576544326377,
           21.635278694105114,
           21.247980843883887,
           20.86068299366265,
           20.47338514344139,
           20.08608729322016,
           19.698789442998933,
           19.31149159277767,
           18.924193742556405,
           18.536895892335217,
           18.14959804211395,
           17.762300191892685,
           17.375002341671458,
           16.987704491450227,
           16.600406641228965,
           16.206088775329132,
           15.811448877498366,
           15.416808979667566,
           15.022169081836765,
           14.627529184006036,
           14.232889286175235,
           13.838249388344435,
           13.443609490513671,
           13.048969592682905,
           12.654329694852105,
           12.30477693734607,
           12.18065988146343,
           12.05654282558079,
           11.932425769698153,
           11.808308713815537,
           11.684191657932894,
           11.560074602050255,
           11.447561612538204,
           11.358256589191758,
           11.26895156584531,
           11.17964654249888,
           11.090341519152433,
           11.00103649580599,
           10.91173147245954,
           10.822426449113111,
           10.733121425766665,
           10.643816402420219,
           10.554511379073787,
           10.465206355727341,
           10.375901332380895,
           10.286596309034465,
           10.197291285688017,
           10.107986262341571,
           10.018681238995141,
           9.929376215648695,
           9.840071192302249,
           9.750766168955803,
           9.661461145609373,
           9.572156122262927,
           9.48285109891648,
           9.39354607557005,
           9.304241052223603,
           9.214936028877158,
           9.125631005530728,
           9.03632598218428,
           8.947020958837834,
           8.857715935491388,
           8.768410912144958,
           8.67910588879851,
           8.589800865452066,
           8.500495842105634,
           8.411190818759188,
           8.32188579541274,
           8.232580772066312,
           8.143275748719866,
           8.053970725373418,
           7.964665702026988,
           7.875360678680543,
           7.7860556553340965,
           7.6967506319876495,
           7.607445608641219,
           7.5181405852947725,
           7.4288355619483255,
           7.339530538601896,
           7.250225515255449,
           7.160920491909003,
           7.071615468562572,
           6.982310445216126,
           6.893005421869681,
           6.803700398523233,
           6.714395375176804,
           6.625090351830357,
           6.535785328483911,
           6.446480305137481,
           6.357175281791034,
           6.267870258444587,
           6.178565235098158,
           6.089260211751711,
           5.999955188405265,
           5.9106501650588354,
           5.8213451417123885,
           5.732040118365942,
           5.642735095019496,
           5.553430071673065,
           5.464125048326619,
           5.374820024980172,
           5.285515001633742,
           5.220917483604107,
           5.161261523386114,
           5.101605563168131,
           5.0419496029501385,
           4.982293642732145,
           4.922637682514154,
           4.862981722296171
          ],
          [
           50.39750259430863,
           50.4493145898707,
           50.50112658543277,
           50.552938580994855,
           50.60475057655694,
           50.656562572119014,
           50.70837456768109,
           50.76018656324317,
           50.81199855880525,
           50.86381055436733,
           50.91562254992941,
           50.967434545491486,
           51.01924654105356,
           51.07105853661564,
           51.12287053217772,
           51.1746825277398,
           51.22649452330188,
           51.27830651886396,
           51.33011851442603,
           51.38193050998811,
           51.43374250555019,
           51.48503183038158,
           51.53621662031631,
           51.58740141025103,
           51.63858620018577,
           51.68977099012049,
           51.740955780055224,
           51.792140569989954,
           51.84332535992469,
           51.894510149859414,
           51.945694939794144,
           51.996879729728875,
           52.04806451966361,
           52.099249309598335,
           52.15043409953306,
           52.201618889467795,
           52.25280367940252,
           52.303988469337256,
           52.355173259271986,
           52.406358049206716,
           52.45754283914144,
           52.508727629076176,
           52.5599124190109,
           52.61109720894564,
           52.66228199888036,
           52.71346678881509,
           52.76465157874982,
           52.81583636868456,
           52.86702115861928,
           52.918205948554004,
           52.96939073848874,
           53.020575528423464,
           53.0717603183582,
           53.122945108292924,
           53.17412989822766,
           53.225314688162385,
           53.27649947809712,
           53.327684268031845,
           53.378869057966575,
           53.430053847901306,
           53.48123863783604,
           53.532423427770766,
           53.583608217705496,
           53.634793007640226,
           53.68597779757496,
           53.73716258750969,
           53.78834737744442,
           53.83953216737915,
           53.89071695731387,
           53.94190174724861,
           53.99308653718334,
           54.04427132711807,
           54.09545611705279,
           54.14664090698753,
           54.19782569692225,
           54.24901048685698,
           54.30019527679171,
           54.351380066726435,
           54.40256485666117,
           54.4537496465959,
           54.50493443653063,
           54.556119226465356,
           54.60730401640009,
           54.65848880633482,
           54.7045808486895,
           54.74965434152818,
           54.794727834366846,
           54.83980132720552,
           54.8848748200442,
           54.92994831288287,
           54.975021805721546,
           55.02009529856022,
           55.0651687913989,
           55.11024228423757,
           55.15531577707625,
           55.200389269914915,
           55.245462762753604,
           55.29053625559227,
           55.335609748430954,
           55.38068324126962,
           55.4257567341083,
           55.47083022694697,
           55.51590371978564,
           55.56097721262432,
           55.60605070546299,
           55.651124198301666,
           55.69619769114034,
           55.74127118397901,
           55.78634467681769,
           55.83141816965636,
           55.87649166249504,
           55.92156515533371,
           55.96663864817239,
           56.01171214101107,
           56.056785633849735,
           56.10185912668841,
           56.14693261952708,
           56.19200611236575,
           56.237079605204435,
           56.28215309804311,
           56.327226590881786,
           56.372300083720454,
           56.41737357655913,
           56.46244706939781,
           56.50752056223648,
           56.552594055075154,
           56.59766754791384,
           56.642741040752504,
           56.68781453359118,
           56.73288802642985,
           56.77796151926852,
           56.823035012107205,
           56.86810850494588,
           56.91318199778455,
           56.95825549062322,
           57.0033289834619,
           57.04840247630057,
           57.09347596913925,
           57.138549461977924,
           57.1836229548166,
           57.228696447655274,
           57.27376994049395,
           57.31884343333262,
           57.36391692617129,
           57.408990419009974,
           57.45406391184865,
           57.49913740468732,
           57.54439662977181,
           57.58969300103876,
           57.63498937230572,
           57.68028574357266,
           57.72558211483961,
           57.770878486106554,
           57.816174857373504,
           57.86147122864046,
           57.90676759990741,
           57.95206397117436,
           57.99736034244131,
           58.042656713708254,
           58.08795308497521,
           58.13324945624216,
           58.17854582750911,
           58.22384219877606,
           58.26913857004301,
           58.31443494130996,
           58.35973131257691,
           58.405027683843855,
           58.450411583729256,
           58.49583924792387,
           58.54126691211848,
           58.58669457631311,
           58.63212224050772,
           58.67754990470233,
           58.72297756889695,
           58.76840523309157,
           58.81383289728618,
           58.8592605614808,
           58.90468822567542,
           58.95011588987004,
           58.99554355406465,
           59.04097121825926,
           59.08639888245389,
           59.1318265466485,
           59.17725421084312,
           59.222681875037736,
           59.26810953923235,
           59.31353720342696,
           59.35896486762159,
           59.4043925318162,
           59.44982019601082,
           59.49524786020544,
           59.540675524400044,
           59.58610318859466,
           59.63153085278929,
           59.676958516983895,
           59.72238618117852,
           59.767813845373134,
           59.813241509567746,
           59.85866917376238,
           59.904096837956985,
           59.949524502151604,
           59.994952166346216,
           60.040379830540836,
           60.08580749473545,
           60.13123976305039,
           60.1766756488938,
           60.22211153473721,
           60.26754742058063,
           60.31298330642404,
           60.35841919226745,
           60.403855078110865,
           60.44929096395427,
           60.49472684979768,
           60.54016273564109,
           60.58559862148451,
           60.63103450732792,
           60.67647039317133,
           60.721906279014746,
           60.76734216485815,
           60.81277805070157,
           60.85821393654498,
           60.903649822388395,
           60.949085708231806,
           60.99452159407521,
           61.03995747991863,
           61.08539336576204,
           61.130829251605455,
           61.176265137448866,
           61.22170102329227,
           61.26713690913569,
           61.31257279497909,
           61.358008680822515,
           61.403444566665925,
           61.44888045250933,
           61.494316338352746,
           61.53975222419616,
           61.58518811003957,
           61.63062399588298,
           61.676059881726395,
           61.721495767569806,
           61.766931653413224,
           61.81236753925663,
           61.857803425100045,
           61.903239310943455,
           61.948675196786866,
           61.994111082630276,
           62.03954696847368,
           62.08498285431709,
           62.130418740160515,
           62.175854626003925,
           62.08680847452632,
           61.863280285727726,
           61.639752096929136,
           61.416223908130554,
           61.19269571933196,
           60.969167530533376,
           60.74563934173479,
           60.522111152936176,
           60.29858296413758,
           60.07505477533901,
           59.85152658654041,
           59.627998397741806,
           59.40447020894322,
           59.18094202014464,
           58.95741383134604,
           58.733885642547456,
           58.51035745374887,
           58.28682926495026,
           58.06330107615169,
           57.8397728873531,
           57.61624469855449,
           57.392716509755886,
           57.16918832095733,
           56.94566013215873,
           56.72213194336012,
           56.49860375456154,
           56.275075565762954,
           56.05154737696435,
           55.82801918816577,
           55.60449099936719,
           55.38096281056859,
           55.15743462176998,
           54.93390643297141,
           54.71037824417281,
           54.486850055374205,
           54.26332186657562,
           54.03979367777704,
           53.816265488978445,
           53.59273730017985,
           53.36920911138127,
           53.14568092258267,
           52.92215273378408,
           52.6986245449855,
           52.475096356186896,
           52.25156816738829,
           52.02803997858973,
           51.80451178979112,
           51.580983600992525,
           51.35745541219394,
           51.13392722339536,
           50.91039903459675,
           50.68687084579817,
           50.463342656999586,
           50.23981446820098,
           50.01628627940238,
           49.79275809060381,
           49.56922990180521,
           49.345701713006605,
           49.12217352420802,
           48.89864533540945,
           48.675117146610845,
           48.45158895781226,
           48.22806076901367,
           48.00453258021507,
           47.78100439141649,
           47.5574762026179,
           47.3339480138193,
           47.1104198250207,
           46.88689163622213,
           46.66336344742353,
           46.4662332893647,
           46.27713738324448,
           46.088041477124264,
           45.89894557100402,
           45.709849664883805,
           45.520753758763576,
           45.331657852643346,
           45.14256194652312,
           44.953466040402894,
           44.76437013428265,
           44.575274228162414,
           44.38617832204219,
           44.19708241592197,
           43.94191919510136,
           43.55462134488015,
           43.167323494658916,
           42.78002564443766,
           42.39272779421642,
           42.005429943995196,
           41.61813209377393,
           41.230834243552664,
           40.843536393331476,
           40.45623854311021,
           40.068940692888944,
           39.68164284266771,
           39.29434499244648,
           38.90704714222522,
           38.51974929200399,
           38.13245144178276,
           37.745153591561504,
           37.35785574134027,
           36.97055789111904,
           36.583260040897784,
           36.19596219067652,
           35.808664340455294,
           35.421366490234064,
           35.0340686400128,
           34.64677078979156,
           34.25947293957034,
           33.87217508934907,
           33.48487723912784,
           33.09757938890662,
           32.71028153868535,
           32.322983688464085,
           31.9356858382429,
           31.54838798802163,
           31.161090137800368,
           30.778236342840728,
           30.396863869435276,
           30.015491396029788,
           29.634118922624346,
           29.252746449218893,
           28.871373975813405,
           28.490001502407956,
           28.108629029002504,
           27.727256555597016,
           27.34588408219153,
           26.964511608786083,
           26.583139135380634,
           26.201766661975146,
           25.820394188569693,
           25.439021715164245,
           25.05764924175876,
           24.67627676835331,
           24.29490429494786,
           23.91353182154237,
           23.532159348136886,
           23.150786874731473,
           22.76941440132599,
           22.3880419279205,
           22.006669454515052,
           21.6252969811096,
           21.243924507704115,
           20.862552034298666,
           20.48117956089321,
           20.09980708748773,
           19.71843461408228,
           19.337062140676828,
           18.955689667271344,
           18.574317193865856,
           18.192944720460442,
           17.811572247054958,
           17.43019977364947,
           17.04882730024402,
           16.667454826838565,
           16.28608235343308,
           15.904709880027632,
           15.523337406622181,
           15.141964933216697,
           14.76059245981121,
           14.379219986405793,
           13.997847513000309,
           13.616475039594825,
           13.235102566189372,
           12.853730092783927,
           12.472357619378437,
           12.135130410762445,
           12.018629526093497,
           11.902128641424547,
           11.785627756755598,
           11.669126872086672,
           11.552625987417722,
           11.436125102748774,
           11.319624218079847,
           11.203123333410897,
           11.086622448741949,
           10.97012156407302,
           10.853620679404072,
           10.737119794735124,
           10.620618910066174,
           10.504118025397247,
           10.387617140728297,
           10.271116256059349,
           10.154615371390422,
           10.038114486721472,
           9.921613602052524,
           9.805112717383597,
           9.688611832714647,
           9.5721109480457,
           9.472710480852967,
           9.383405457506521,
           9.294100434160075,
           9.204795410813627,
           9.115490387467197,
           9.026185364120751,
           8.936880340774305,
           8.847575317427875,
           8.758270294081427,
           8.668965270734983,
           8.579660247388553,
           8.490355224042105,
           8.40105020069566,
           8.311745177349213,
           8.222440154002783,
           8.133135130656337,
           8.04383010730989,
           7.9545250839634605,
           7.865220060617014,
           7.775915037270568,
           7.686610013924137,
           7.59730499057769,
           7.507999967231244,
           7.418694943884814,
           7.329389920538368,
           7.240084897191921,
           7.150779873845475,
           7.061474850499044,
           6.972169827152599,
           6.882864803806152,
           6.793559780459722,
           6.704254757113276,
           6.614949733766829,
           6.5256447104204,
           6.436339687073953,
           6.347034663727506,
           6.25772964038106,
           6.1684246170346295,
           6.096663892258757,
           6.039976414725173,
           5.983288937191599,
           5.9266014596580145,
           5.86991398212443,
           5.813226504590856,
           5.756539027057272,
           5.699851549523687,
           5.643164071990114,
           5.5864765944565296,
           5.529789116922945,
           5.47310163938936,
           5.416414161855786,
           5.359726684322202,
           5.303039206788617,
           5.246351729255044,
           5.189664251721459,
           5.132976774187874,
           5.076289296654301,
           5.019601819120717,
           4.962914341587132,
           4.906226864053548,
           4.849539386519974
          ],
          [
           50.7109299149175,
           50.76274191047958,
           50.81455390604166,
           50.86636590160374,
           50.91817789716582,
           50.969989892727895,
           51.02180188828997,
           51.07361388385205,
           51.12542587941413,
           51.17723787497621,
           51.22904987053829,
           51.280861866100366,
           51.33267386166244,
           51.384485857224526,
           51.4362978527866,
           51.488109848348685,
           51.53992184391076,
           51.59173383947284,
           51.643545835034914,
           51.695357830597,
           51.747169826159066,
           51.79898182172115,
           51.85079381728323,
           51.90260581284531,
           51.954417808407385,
           52.00622980396946,
           52.058041799531544,
           52.10985379509361,
           52.1616657906557,
           52.21347778621777,
           52.265289781779856,
           52.31710177734193,
           52.36891377290401,
           52.42072576846609,
           52.47253776402816,
           52.524349759590244,
           52.57616175515233,
           52.62776468290087,
           52.678949472835605,
           52.730134262770335,
           52.78131905270505,
           52.832503842639795,
           52.88368863257452,
           52.93487342250925,
           52.98605821244398,
           53.03724300237871,
           53.08842779231343,
           53.139612582248176,
           53.1907973721829,
           53.24198216211762,
           53.29316695205236,
           53.34435174198708,
           53.39553653192182,
           53.44672132185655,
           53.49790611179127,
           53.549090901726004,
           53.60027569166074,
           53.651460481595464,
           53.702645271530194,
           53.753830061464924,
           53.80501485139965,
           53.856199641334385,
           53.907384431269115,
           53.95856922120384,
           54.009754011138575,
           54.060938801073306,
           54.11212359100803,
           54.163308380942766,
           54.21449317087749,
           54.26567796081222,
           54.31686275074695,
           54.36804754068168,
           54.41923233061641,
           54.47041712055114,
           54.52160191048587,
           54.5727867004206,
           54.62397149035533,
           54.675156280290054,
           54.72634107022479,
           54.777525860159514,
           54.82871065009425,
           54.879895440028974,
           54.93108022996371,
           54.982265019898435,
           55.02835706225312,
           55.073430555091804,
           55.11850404793047,
           55.16357754076914,
           55.20865103360782,
           55.25372452644649,
           55.298798019285165,
           55.34387151212384,
           55.388945004962515,
           55.43401849780119,
           55.47909199063987,
           55.52416548347854,
           55.56923897631722,
           55.61431246915589,
           55.659385961994566,
           55.70445945483324,
           55.74953294767191,
           55.79460644051059,
           55.83967993334927,
           55.88475342618794,
           55.92982691902661,
           55.97490041186529,
           56.01997390470396,
           56.065047397542635,
           56.11012089038132,
           56.15519438321998,
           56.20026787605866,
           56.24534136889733,
           56.29041486173601,
           56.33548835457468,
           56.38056184741336,
           56.42563534025203,
           56.470708833090704,
           56.51578232592937,
           56.560855818768054,
           56.60592931160672,
           56.651002804445405,
           56.69607629728408,
           56.74114979012275,
           56.78622328296143,
           56.8312967758001,
           56.87637026863877,
           56.92144376147745,
           56.96651725431612,
           57.0115907471548,
           57.056664239993474,
           57.1018120259006,
           57.14710839716756,
           57.1924047684345,
           57.23770113970144,
           57.2829975109684,
           57.32829388223535,
           57.37359025350229,
           57.41888662476925,
           57.4641829960362,
           57.50947936730315,
           57.5547757385701,
           57.60007210983705,
           57.645368481104,
           57.69066485237094,
           57.7359612236379,
           57.78125759490485,
           57.8265539661718,
           57.87185033743875,
           57.9171467087057,
           57.96244307997266,
           58.0077394512396,
           58.05303582250655,
           58.0983321937735,
           58.143628565040444,
           58.1889249363074,
           58.234221307574344,
           58.2795176788413,
           58.32481405010825,
           58.3701104213752,
           58.415406792642145,
           58.4607031639091,
           58.50599953517605,
           58.551295906443,
           58.596592277709945,
           58.6418886489769,
           58.68718502024385,
           58.7324813915108,
           58.777865291396196,
           58.82329295559081,
           58.86872061978543,
           58.91414828398004,
           58.95957594817466,
           59.00500361236927,
           59.05043127656389,
           59.0958589407585,
           59.14128660495313,
           59.18671426914774,
           59.23214193334236,
           59.277569597536974,
           59.32299726173159,
           59.36842492592621,
           59.413852590120825,
           59.459280254315445,
           59.50470791851006,
           59.55013558270468,
           59.595563246899296,
           59.64099091109391,
           59.68641857528853,
           59.73184623948314,
           59.77727390367775,
           59.82270156787237,
           59.86812923206699,
           59.91355689626161,
           59.95898456045622,
           60.004412224650835,
           60.049839888845455,
           60.095267553040074,
           60.14069521723469,
           60.1861228814293,
           60.231550545623925,
           60.276978209818544,
           60.32240587401316,
           60.367833538207776,
           60.413261202402396,
           60.458688866597,
           60.50411653079162,
           60.54954419498624,
           60.59497185918085,
           60.64039952337548,
           60.685827187570084,
           60.7312548517647,
           60.77668251595932,
           60.82211018015394,
           60.86753784434856,
           60.91296550854317,
           60.95839317273779,
           61.00382083693241,
           61.049248501127025,
           61.09467616532164,
           61.14010382951625,
           61.18553149371087,
           61.23095915790549,
           61.276386822100115,
           61.32181448629472,
           61.36724215048934,
           61.41266981468396,
           61.45809747887858,
           61.50352514307319,
           61.5489528072678,
           61.59438047146242,
           61.639808135657034,
           61.685235799851654,
           61.73066346404627,
           61.77609112824089,
           61.82152043676965,
           61.86695632261306,
           61.912392208456474,
           61.95782809429989,
           62.0032639801433,
           62.04869986598671,
           62.09413575183012,
           62.139571637673534,
           62.185007523516944,
           62.23044340936036,
           62.27587929520377,
           62.32131518104718,
           62.36675106689059,
           62.412186952734004,
           62.45762283857742,
           62.50305872442083,
           62.41401257294323,
           62.19048438414463,
           61.96695619534604,
           61.74342800654746,
           61.51989981774886,
           61.296371628950276,
           61.07284344015169,
           60.84931525135309,
           60.62578706255449,
           60.402258873755926,
           60.178730684957316,
           59.95520249615871,
           59.73167430736012,
           59.50814611856155,
           59.28461792976294,
           59.061089740964356,
           58.83756155216577,
           58.61403336336717,
           58.39050517456859,
           58.166976985770006,
           57.943448796971396,
           57.7199206081728,
           57.49639241937424,
           57.27286423057563,
           57.04933604177703,
           56.82580785297845,
           56.60227966417986,
           56.378751475381264,
           56.155223286582675,
           55.93169509778409,
           55.70816690898549,
           55.48463872018689,
           55.261110531388326,
           55.037582342589715,
           54.81405415379112,
           54.59052596499252,
           54.36699777619394,
           54.143469587395344,
           53.919941398596755,
           53.69641320979817,
           53.47288502099957,
           53.249356832200995,
           53.025828643402406,
           52.80230045460381,
           52.569528054848085,
           52.33560014731228,
           52.10167223977641,
           51.86774433224055,
           51.633816424704705,
           51.399888517168876,
           51.16596060963301,
           50.93203270209716,
           50.69810479456133,
           50.464176887025474,
           50.2302489794896,
           49.99632107195379,
           49.76239316441793,
           49.52846525688207,
           49.29453734934623,
           49.060609441810385,
           48.82668153427453,
           48.592753626738684,
           48.35882571920284,
           48.12489781166698,
           47.89096990413114,
           47.6570419965953,
           47.42311408905944,
           47.18918618152358,
           46.95525827398776,
           46.7213303664519,
           46.487402458916044,
           46.2534745513802,
           46.019546643844365,
           45.78561873630849,
           45.55169082877266,
           45.31776292123682,
           45.08383501370096,
           44.84990710616512,
           44.615979198629276,
           44.38205129109341,
           44.148123383557554,
           43.91419547602171,
           43.680267568485874,
           43.39953209883133,
           43.025181504939496,
           42.65083091104767,
           42.27648031715581,
           41.902129723263975,
           41.52777912937215,
           41.15342853548027,
           40.77907794158842,
           40.404727347696614,
           40.03037675380475,
           39.65602615991289,
           39.28167556602106,
           38.90732497212923,
           38.53297437823736,
           38.15862378434553,
           37.7842731904537,
           37.409922596561834,
           37.03557200267001,
           36.661221408778175,
           36.28687081488631,
           35.912520220994445,
           35.53816962710261,
           35.163819033210785,
           34.789468439318924,
           34.41511784542709,
           34.04076725153526,
           33.660063555373185,
           33.278691081967736,
           32.897318608562294,
           32.5159461351568,
           32.13457366175132,
           31.753201188345905,
           31.37182871494042,
           30.990456241534933,
           30.609083768129484,
           30.22771129472403,
           29.846338821318543,
           29.46496634791309,
           29.08359387450765,
           28.702221401102157,
           28.32084892769671,
           27.93947645429125,
           27.558103980885775,
           27.176731507480284,
           26.795359034074835,
           26.413986560669386,
           26.0326140872639,
           25.65124161385845,
           25.269869140452997,
           24.888496667047512,
           24.507124193642063,
           24.125751720236615,
           23.744379246831123,
           23.36300677342564,
           22.981634300020225,
           22.600261826614744,
           22.218889353209253,
           21.8375168798038,
           21.45614440639835,
           21.074771932992867,
           20.693399459587418,
           20.312026986181962,
           19.93065451277648,
           19.549282039371036,
           19.167909565965587,
           18.786537092560092,
           18.40516461915461,
           18.023792145749194,
           17.64241967234371,
           17.261047198938222,
           16.87967472553277,
           16.498302252127324,
           16.11692977872184,
           15.735557305316384,
           15.354184831910935,
           14.972812358505452,
           14.591439885099964,
           14.21006741169455,
           13.828694938289061,
           13.44732246488358,
           13.065949991478126,
           12.684577518072679,
           12.30320504466719,
           11.965977836051197,
           11.849476951382249,
           11.732976066713299,
           11.616475182044352,
           11.499974297375424,
           11.383473412706476,
           11.266972528037526,
           11.150471643368599,
           11.03397075869965,
           10.9174698740307,
           10.800968989361774,
           10.684468104692826,
           10.567967220023876,
           10.451466335354926,
           10.334965450686,
           10.218464566017051,
           10.101963681348103,
           9.985462796679176,
           9.868961912010226,
           9.752461027341276,
           9.63596014267235,
           9.519459258003401,
           9.402958373334453,
           9.286457488665524,
           9.169956603996575,
           9.053455719327626,
           8.936954834658678,
           8.820453949989751,
           8.703953065320801,
           8.587452180651852,
           8.470951295982925,
           8.354450411313977,
           8.257182696434032,
           8.173217210522887,
           8.089251724611724,
           8.005286238700563,
           7.921320752789402,
           7.837355266878257,
           7.753389780967096,
           7.669424295055934,
           7.585458809144788,
           7.5014933232336265,
           7.4175278373224645,
           7.333562351411318,
           7.249596865500157,
           7.165631379588996,
           7.08166589367785,
           6.997700407766688,
           6.913734921855527,
           6.829769435944366,
           6.74580395003322,
           6.6618384641220585,
           6.593572036653898,
           6.536884559120324,
           6.48019708158674,
           6.423509604053155,
           6.3668221265195815,
           6.310134648985997,
           6.253447171452413,
           6.196759693918828,
           6.140072216385255,
           6.08338473885167,
           6.026697261318086,
           5.970009783784512,
           5.913322306250928,
           5.856634828717343,
           5.79994735118377,
           5.743259873650185,
           5.6865723961166,
           5.629884918583026,
           5.573197441049443,
           5.516509963515858,
           5.459822485982273,
           5.403135008448699,
           5.346447530915114,
           5.28976005338153,
           5.233072575847957,
           5.176385098314372,
           5.119697620780788,
           5.063010143247213,
           5.00632266571363,
           4.949635188180045,
           4.89294771064646,
           4.8362602331128866
          ],
          [
           51.02435723552638,
           51.07616923108846,
           51.12798122665055,
           51.17979322221262,
           51.2316052177747,
           51.283417213336776,
           51.33522920889885,
           51.38704120446093,
           51.43885320002302,
           51.490665195585095,
           51.54247719114717,
           51.59428918670925,
           51.64610118227132,
           51.697913177833414,
           51.74972517339549,
           51.801537168957566,
           51.85334916451964,
           51.90516116008172,
           51.956973155643794,
           52.00878515120587,
           52.06059714676795,
           52.11240914233004,
           52.164221137892106,
           52.21603313345419,
           52.26784512901626,
           52.31965712457834,
           52.371469120140425,
           52.423281115702494,
           52.475093111264584,
           52.52690510682666,
           52.57871710238874,
           52.63052909795082,
           52.68234109351289,
           52.73415308907497,
           52.78596508463704,
           52.83777708019913,
           52.88958907576121,
           52.94140107132328,
           52.99321306688537,
           53.045025062447436,
           53.09683705800953,
           53.1486490535716,
           53.20046104913368,
           53.252273044695755,
           53.30408504025783,
           53.35589703581991,
           53.407709031381984,
           53.459521026944074,
           53.51133302250615,
           53.56314501806823,
           53.6149570136303,
           53.66676900919238,
           53.718581004754455,
           53.77039300031653,
           53.82168232535489,
           53.87286711528964,
           53.92405190522436,
           53.97523669515909,
           54.02642148509382,
           54.07760627502854,
           54.12879106496328,
           54.17997585489801,
           54.231160644832734,
           54.282345434767464,
           54.3335302247022,
           54.384715014636924,
           54.435899804571655,
           54.487084594506385,
           54.538269384441115,
           54.589454174375845,
           54.640638964310575,
           54.6918237542453,
           54.74300854418003,
           54.794193334114766,
           54.84537812404949,
           54.896562913984226,
           54.94774770391895,
           54.99893249385368,
           55.05011728378841,
           55.10130207372315,
           55.15248686365787,
           55.2036716535926,
           55.25485644352733,
           55.30604123346207,
           55.35213327581674,
           55.39720676865542,
           55.44228026149409,
           55.48735375433277,
           55.53242724717144,
           55.57750074001011,
           55.62257423284879,
           55.66764772568746,
           55.712721218526134,
           55.75779471136481,
           55.80286820420349,
           55.84794169704216,
           55.893015189880835,
           55.93808868271951,
           55.98316217555819,
           56.02823566839687,
           56.07330916123554,
           56.11838265407421,
           56.163456146912885,
           56.20852963975156,
           56.25360313259023,
           56.298676625428904,
           56.343750118267586,
           56.388823611106254,
           56.43389710394493,
           56.4789705967836,
           56.52404408962228,
           56.569117582460954,
           56.61419107529963,
           56.659264568138305,
           56.70452379329634,
           56.74982016456329,
           56.79511653583024,
           56.84041290709719,
           56.88570927836414,
           56.93100564963108,
           56.97630202089803,
           57.02159839216499,
           57.06689476343193,
           57.11219113469888,
           57.15748750596583,
           57.20278387723279,
           57.24808024849974,
           57.29337661976669,
           57.33867299103363,
           57.38396936230059,
           57.42926573356753,
           57.47456210483449,
           57.51985847610144,
           57.56515484736838,
           57.61045121863533,
           57.65574758990229,
           57.70104396116923,
           57.74634033243618,
           57.79163670370313,
           57.83693307497009,
           57.882229446237034,
           57.92752581750399,
           57.972822188770934,
           58.018118560037884,
           58.06341493130484,
           58.10871130257179,
           58.154007673838734,
           58.19930404510569,
           58.244600416372634,
           58.28989678763959,
           58.335193158906534,
           58.38048953017349,
           58.425785901440435,
           58.47108227270738,
           58.516378643974335,
           58.56167501524128,
           58.606971386508235,
           58.652267757775185,
           58.697564129042135,
           58.74286050030909,
           58.788156871576035,
           58.83345324284299,
           58.878749614109935,
           58.924045985376885,
           58.969342356643836,
           59.01463872791078,
           59.059935099177736,
           59.10531899906314,
           59.15074666325775,
           59.19617432745236,
           59.24160199164698,
           59.2870296558416,
           59.33245732003621,
           59.37788498423084,
           59.42331264842545,
           59.46874031262007,
           59.51416797681468,
           59.5595956410093,
           59.605023305203915,
           59.65045096939853,
           59.69587863359315,
           59.741306297787766,
           59.78673396198238,
           59.832161626177,
           59.87758929037162,
           59.923016954566236,
           59.968444618760856,
           60.01387228295546,
           60.05929994715008,
           60.10472761134469,
           60.15015527553931,
           60.19558293973394,
           60.241010603928544,
           60.28643826812316,
           60.331865932317776,
           60.377293596512395,
           60.42272126070702,
           60.46814892490163,
           60.513576589096246,
           60.559004253290865,
           60.604431917485485,
           60.649859581680104,
           60.69528724587471,
           60.740714910069336,
           60.78614257426395,
           60.83157023845857,
           60.87699790265318,
           60.9224255668478,
           60.96785323104241,
           61.01328089523703,
           61.05870855943165,
           61.104136223626256,
           61.14956388782088,
           61.194991552015495,
           61.240419216210114,
           61.28584688040473,
           61.33127454459935,
           61.37670220879396,
           61.42212987298858,
           61.4675575371832,
           61.512985201377816,
           61.558412865572436,
           61.60384052976704,
           61.64926819396167,
           61.694695858156294,
           61.7401235223509,
           61.78555118654551,
           61.83097885074013,
           61.87640651493474,
           61.92183417912937,
           61.96726184332398,
           62.012689507518594,
           62.058117171713214,
           62.10305533992913,
           62.147969033243115,
           62.19288272655711,
           62.2377964198711,
           62.2827101131851,
           62.32762380649909,
           62.372537499813085,
           62.41745119312708,
           62.46236488644108,
           62.50727857975507,
           62.55219227306905,
           62.597105966383054,
           62.64201965969704,
           62.686933353011035,
           62.73184704632503,
           62.77676073963903,
           62.821674432953024,
           62.71687178398849,
           62.46235279274545,
           62.207833801502424,
           61.95331481025941,
           61.698795819016354,
           61.444276827773336,
           61.18975783653032,
           60.935238845287266,
           60.68071985404422,
           60.426200862801224,
           60.17168187155818,
           59.91716288031513,
           59.662643889072115,
           59.4081248978291,
           59.153605906586044,
           58.89908691534303,
           58.6445679241,
           58.390048932856956,
           58.13552994161394,
           57.881010950370914,
           57.63395907498766,
           57.4000311674518,
           57.16610325991598,
           56.93217535238013,
           56.69824744484427,
           56.46431953730842,
           56.230391629772576,
           55.99646372223672,
           55.76253581470088,
           55.52860790716504,
           55.294679999629174,
           55.06075209209332,
           54.826824184557495,
           54.59289627702164,
           54.35896836948578,
           54.125040461949936,
           53.8911125544141,
           53.657184646878235,
           53.42325673934239,
           53.18932883180655,
           52.9554009242707,
           52.721473016734855,
           52.48754510919901,
           52.253617201663154,
           52.019689294127296,
           51.785761386591474,
           51.5518334790556,
           51.317905571519745,
           51.08397766398391,
           50.85004975644807,
           50.61612184891221,
           50.38219394137637,
           50.14826603384053,
           49.91433812630467,
           49.680410218768806,
           49.446482311232984,
           49.21255440369712,
           48.97862649616127,
           48.744698588625425,
           48.51077068108958,
           48.276842773553724,
           48.04291486601789,
           47.808986958482045,
           47.57505905094618,
           47.34113114341035,
           47.10720323587451,
           46.873275328338636,
           46.63934742080278,
           46.40541951326696,
           46.171491605731106,
           45.93756369819524,
           45.703635790659405,
           45.46970788312356,
           45.2357799755877,
           45.00185206805186,
           44.76792416051602,
           44.53399625298016,
           44.300068345444316,
           44.06614043790847,
           43.832212530372615,
           43.59828462283676,
           43.364356715300914,
           43.13042880776507,
           42.84969333811054,
           42.47534274421871,
           42.100992150326874,
           41.72664155643501,
           41.35229096254318,
           40.977940368651346,
           40.603589774759484,
           40.22923918086762,
           39.85488858697582,
           39.480537993083956,
           39.106187399192095,
           38.73183680530026,
           38.35748621140843,
           37.98313561751657,
           37.60878502362473,
           37.23443442973291,
           36.86008383584104,
           36.485733241949205,
           36.11138264805738,
           35.73703205416551,
           35.36268146027365,
           34.988330866381816,
           34.61398027248999,
           34.23962967859812,
           33.86527908470629,
           33.49092849081446,
           33.1165778969226,
           32.742227303030774,
           32.36787670913894,
           31.99352611524707,
           31.61917552135521,
           31.244824927463412,
           30.870474333571543,
           30.496123739679682,
           30.121773145787852,
           29.74742255189602,
           29.373071958004154,
           28.99872136411232,
           28.624370770220494,
           28.250020176328626,
           27.875669582436796,
           27.501318988544966,
           27.126968394653098,
           26.752617800761236,
           26.378267206869403,
           26.003916612977573,
           25.629566019085708,
           25.255215425193878,
           24.88086483130205,
           24.506514237410183,
           24.132163643518354,
           23.75781304962652,
           23.38346245573466,
           23.00911186184279,
           22.634761267950996,
           22.26041067405913,
           21.886060080167265,
           21.511709486275436,
           21.137358892383606,
           20.76300829849174,
           20.388657704599908,
           20.014307110708078,
           19.639956516816213,
           19.265605922924383,
           18.891255329032553,
           18.516904735140688,
           18.142554141248823,
           17.76820354735703,
           17.393852953465164,
           17.0195023595733,
           16.64515176568147,
           16.270801171789635,
           15.89645057789777,
           15.52209998400594,
           15.14774939011411,
           14.773398796222246,
           14.39904820233038,
           14.024697608438586,
           13.650347014546718,
           13.275996420654852,
           12.896797416766878,
           12.515424943361433,
           12.134052469955943,
           11.79682526133995,
           11.680324376671003,
           11.571618504997605,
           11.487653019086444,
           11.4036875331753,
           11.319722047264136,
           11.235756561352975,
           11.151791075441828,
           11.067825589530669,
           10.983860103619508,
           10.89989461770836,
           10.8159291317972,
           10.731963645886037,
           10.647998159974875,
           10.564032674063728,
           10.480067188152567,
           10.396101702241406,
           10.312136216330261,
           10.228170730419098,
           10.144205244507939,
           10.060239758596792,
           9.97627427268563,
           9.892308786774468,
           9.808343300863324,
           9.724377814952161,
           9.640412329041002,
           9.55644684312984,
           9.472481357218694,
           9.388515871307533,
           9.30455038539637,
           9.220584899485225,
           9.136619413574063,
           9.0526539276629,
           8.968688441751755,
           8.884722955840594,
           8.800757469929431,
           8.71679198401827,
           8.632826498107123,
           8.548861012195962,
           8.464895526284803,
           8.380930040373656,
           8.296964554462495,
           8.212999068551333,
           8.129033582640186,
           8.045068096729025,
           7.961102610817864,
           7.877137124906718,
           7.793171638995557,
           7.709206153084395,
           7.625240667173233,
           7.541275181262088,
           7.457309695350927,
           7.373344209439764,
           7.2893787235286185,
           7.205413237617457,
           7.121447751706294,
           7.037482265795149,
           6.953516779883988,
           6.869551293972827,
           6.785585808061666,
           6.701620322150519,
           6.617654836239358,
           6.5336893503281965,
           6.44972386441705,
           6.365758378505888,
           6.281792892594728,
           6.197827406683582,
           6.11386192077242,
           6.029896434861259,
           5.945930948950113,
           5.861965463038951,
           5.777999977127789,
           5.6940344912166285,
           5.6100690053054825,
           5.52610351939432,
           5.442138033483159,
           5.358172547572013,
           5.274207061660852,
           5.190241575749691,
           5.106276089838545,
           5.022310603927383,
           4.938345118016222,
           4.8796685572393725,
           4.822981079705801
          ],
          [
           51.33778455613526,
           51.38959655169734,
           51.441408547259414,
           51.4932205428215,
           51.54503253838357,
           51.59684453394565,
           51.648656529507726,
           51.7004685250698,
           51.75228052063189,
           51.80409251619397,
           51.85590451175605,
           51.90771650731812,
           51.959528502880204,
           52.01134049844228,
           52.06315249400436,
           52.11496448956644,
           52.166776485128516,
           52.21858848069059,
           52.27040047625267,
           52.32221247181475,
           52.37402446737683,
           52.42583646293891,
           52.47764845850098,
           52.52946045406307,
           52.581272449625146,
           52.633084445187215,
           52.6848964407493,
           52.736708436311375,
           52.78852043187346,
           52.840332427435534,
           52.89214442299761,
           52.943956418559694,
           52.99576841412177,
           53.04758040968385,
           53.09939240524593,
           53.151204400808005,
           53.20301639637009,
           53.25482839193216,
           53.30664038749425,
           53.35845238305632,
           53.4102643786184,
           53.46207637418048,
           53.51388836974255,
           53.56570036530463,
           53.617512360866705,
           53.66932435642878,
           53.721136351990864,
           53.77294834755295,
           53.824760343115024,
           53.8765723386771,
           53.928384334239176,
           53.98019632980125,
           54.032008325363336,
           54.08382032092541,
           54.13563231648749,
           54.187444312049564,
           54.23925630761165,
           54.29106830317373,
           54.3428802987358,
           54.394692294297876,
           54.446504289859966,
           54.49831628542204,
           54.55012828098412,
           54.601940276546195,
           54.65375227210827,
           54.705564267670354,
           54.75737626323243,
           54.80918825879451,
           54.86100025435658,
           54.912812249918666,
           54.964415177874194,
           55.01559996780892,
           55.066784757743655,
           55.117969547678385,
           55.16915433761311,
           55.220339127547845,
           55.27152391748257,
           55.322708707417306,
           55.37389349735203,
           55.425078287286766,
           55.476263077221496,
           55.52744786715622,
           55.57863265709095,
           55.62981744702568,
           55.67590948938036,
           55.72098298221904,
           55.76605647505771,
           55.81112996789639,
           55.85620346073506,
           55.901276953573735,
           55.94635044641241,
           55.991423939251085,
           56.03649743208975,
           56.08157092492843,
           56.12664441776711,
           56.17171791060578,
           56.21679140344446,
           56.26193918942513,
           56.30723556069208,
           56.35253193195903,
           56.39782830322598,
           56.44312467449293,
           56.488421045759885,
           56.533717417026836,
           56.57901378829378,
           56.624310159560736,
           56.66960653082768,
           56.71490290209463,
           56.76019927336158,
           56.80549564462853,
           56.85079201589548,
           56.89608838716243,
           56.94138475842938,
           56.986681129696336,
           57.03197750096328,
           57.07727387223023,
           57.12257024349718,
           57.16786661476413,
           57.21316298603108,
           57.25845935729804,
           57.30375572856498,
           57.34905209983194,
           57.39434847109888,
           57.43964484236584,
           57.48494121363278,
           57.53023758489973,
           57.57553395616669,
           57.62083032743364,
           57.66612669870058,
           57.71142306996754,
           57.75671944123448,
           57.80201581250144,
           57.84731218376839,
           57.89260855503533,
           57.93790492630228,
           57.98320129756923,
           58.02849766883618,
           58.07379404010313,
           58.11909041137008,
           58.164386782637024,
           58.20968315390398,
           58.25497952517094,
           58.300275896437874,
           58.34557226770483,
           58.390868638971774,
           58.436165010238724,
           58.48146138150568,
           58.526757752772625,
           58.57205412403958,
           58.61735049530653,
           58.662646866573475,
           58.70794323784043,
           58.75323960910738,
           58.798535980374325,
           58.84383235164128,
           58.88912872290823,
           58.934425094175175,
           58.97972146544213,
           59.025017836709075,
           59.070314207976026,
           59.11561057924298,
           59.160906950509926,
           59.20620332177688,
           59.25149969304383,
           59.296796064310776,
           59.34209243557773,
           59.38738880684468,
           59.43277270673008,
           59.47820037092469,
           59.5236280351193,
           59.56905569931393,
           59.61448336350854,
           59.65991102770316,
           59.70533869189778,
           59.750766356092385,
           59.796194020287004,
           59.84162168448162,
           59.88704934867625,
           59.932477012870855,
           59.977904677065474,
           60.02333234126009,
           60.068760005454706,
           60.11418766964932,
           60.159615333843945,
           60.20504299803855,
           60.25047066223317,
           60.29589832642779,
           60.3413259906224,
           60.386753654817014,
           60.43218131901164,
           60.47760898320626,
           60.52303664740087,
           60.56846431159549,
           60.61389197579011,
           60.65931963998472,
           60.70474730417934,
           60.75012601780284,
           60.79503971111684,
           60.83995340443084,
           60.88486709774483,
           60.92978079105881,
           60.974694484372804,
           61.019608177686806,
           61.06452187100081,
           61.10943556431479,
           61.15434925762879,
           61.19926295094278,
           61.24417664425678,
           61.28909033757076,
           61.334004030884756,
           61.37891772419875,
           61.42383141751276,
           61.46874511082674,
           61.51365880414073,
           61.558572497454726,
           61.60348619076872,
           61.64839988408272,
           61.69331357739671,
           61.7382272707107,
           61.7831409640247,
           61.82805465733868,
           61.872968350652684,
           61.91788204396668,
           61.96279573728067,
           62.00770943059467,
           62.05262312390865,
           62.09753681722266,
           62.14245051053664,
           62.18736420385063,
           62.232277897164636,
           62.27719159047862,
           62.32210528379262,
           62.36701897710661,
           62.41193267042061,
           62.456846363734606,
           62.5017600570486,
           62.54667375036259,
           62.59158744367658,
           62.636501136990574,
           62.681414830304576,
           62.72632852361856,
           62.77124221693256,
           62.81615591024655,
           62.861069603560544,
           62.90598329687454,
           62.950896990188525,
           62.99581068350252,
           63.04072437681651,
           63.085638070130514,
           63.13055176344451,
           63.02574911447997,
           62.77123012323693,
           62.51671113199391,
           62.262192140750884,
           62.00767314950784,
           61.75315415826482,
           61.4986351670218,
           61.24411617577876,
           60.98959718453571,
           60.73507819329271,
           60.48055920204966,
           60.226040210806616,
           59.9715212195636,
           59.71700222832058,
           59.462483237077535,
           59.20796424583451,
           58.953445254591486,
           58.69892626334845,
           58.44440727210542,
           58.1898882808624,
           57.93536928961935,
           57.680850298376306,
           57.42633130713331,
           57.171812315890264,
           56.917293324647225,
           56.6627743334042,
           56.408255342161176,
           56.15373635091814,
           55.89921735967512,
           55.64469836843209,
           55.39017937718904,
           55.135660385946,
           54.88114139470301,
           54.62662240345996,
           54.37210341221691,
           54.11758442097389,
           53.86306542973087,
           53.60854643848783,
           53.3540274472448,
           53.09950845600178,
           52.84498946475873,
           52.590470473515715,
           52.33595148227269,
           52.081432491029645,
           51.8269134997866,
           51.57239450854361,
           51.317875517300564,
           51.063356526057525,
           50.80883753481448,
           50.55431854357147,
           50.29979955232842,
           50.045280561085406,
           49.790761569842374,
           49.53624257859933,
           49.28172358735629,
           49.02720459611329,
           48.77268560487025,
           48.5181666136272,
           48.26364762238418,
           48.00912863114116,
           47.75460963989812,
           47.50009064865509,
           47.25914819776125,
           47.02522029022538,
           46.79129238268955,
           46.557364475153705,
           46.32343656761785,
           46.08950866008198,
           45.85558075254617,
           45.6216528450103,
           45.387724937474445,
           45.1537970299386,
           44.91986912240276,
           44.6859412148669,
           44.45201330733106,
           44.21808539979522,
           43.984157492259364,
           43.75022958472353,
           43.516301677187684,
           43.28237376965182,
           43.048445862115955,
           42.81451795458012,
           42.580590047044275,
           42.29985457738974,
           41.925503983497904,
           41.55115338960607,
           41.17680279571421,
           40.802452201822376,
           40.42810160793054,
           40.05375101403868,
           39.67940042014682,
           39.30504982625502,
           38.93069923236315,
           38.55634863847129,
           38.18199804457946,
           37.80764745068763,
           37.433296856795764,
           37.05894626290394,
           36.684595669012104,
           36.31024507512025,
           35.93589448122841,
           35.56154388733658,
           35.187193293444714,
           34.812842699552846,
           34.43849210566102,
           34.064141511769186,
           33.689790917877325,
           33.3154403239855,
           32.941089730093665,
           32.5667391362018,
           32.19238854230997,
           31.818037948418137,
           31.443687354526276,
           31.075627192083108,
           30.708045635043646,
           30.34046407800411,
           29.972882520964575,
           29.605300963925078,
           29.237719406885578,
           28.870137849846042,
           28.50255629280654,
           28.134974735767045,
           27.767393178727506,
           27.39981162168801,
           27.032230064648516,
           26.664648507608977,
           26.29706695056944,
           25.929485393529944,
           25.561903836490444,
           25.194322279450912,
           24.826740722411408,
           24.459159165371904,
           24.091577608332376,
           23.723996051292872,
           23.356414494253375,
           22.98883293721384,
           22.621251380174307,
           22.253669823134842,
           21.886088266095307,
           21.518506709055774,
           21.150925152016274,
           20.783343594976778,
           20.41576203793724,
           20.04818048089774,
           19.68059892385824,
           19.313017366818706,
           18.945435809779205,
           18.577854252739705,
           18.210272695700173,
           17.84269113866064,
           17.475109581621176,
           17.10752802458164,
           16.739946467542104,
           16.372364910502604,
           16.004783353463107,
           15.637201796423573,
           15.269620239384071,
           14.902038682344568,
           14.534457125305039,
           14.166875568265505,
           13.799294011226042,
           13.431712454186503,
           13.06413089714697,
           12.69654934010747,
           12.328967783067972,
           11.961386226028434,
           11.636866853784282,
           11.527658405516593,
           11.418449957248903,
           11.309241508981216,
           11.200033060713547,
           11.090824612445859,
           10.98161616417817,
           10.872407715910501,
           10.763199267642813,
           10.653990819375124,
           10.544782371107457,
           10.435573922839769,
           10.32636547457208,
           10.21715702630439,
           10.107948578036723,
           9.998740129769034,
           9.889531681501346,
           9.780323233233677,
           9.67111478496599,
           9.561906336698302,
           9.452697888430631,
           9.343489440162942,
           9.234280991895256,
           9.125072543627587,
           9.015864095359898,
           8.906655647092208,
           8.797447198824521,
           8.688238750556852,
           8.579030302289162,
           8.483732648695256,
           8.399767162784112,
           8.31580167687295,
           8.231836190961788,
           8.147870705050643,
           8.06390521913948,
           7.97993973322832,
           7.895974247317158,
           7.8120087614060125,
           7.7280432754948505,
           7.644077789583689,
           7.560112303672543,
           7.476146817761382,
           7.39218133185022,
           7.308215845939075,
           7.224250360027913,
           7.140284874116752,
           7.056319388205606,
           6.972353902294444,
           6.8883884163832825,
           6.80442293047212,
           6.720457444560975,
           6.636491958649813,
           6.552526472738652,
           6.468560986827506,
           6.384595500916344,
           6.319152299929067,
           6.265275459988876,
           6.2113986200486755,
           6.157521780108475,
           6.103644940168274,
           6.049768100228083,
           5.995891260287881,
           5.942014420347681,
           5.88813758040749,
           5.834260740467289,
           5.780383900527088,
           5.726507060586897,
           5.672630220646695,
           5.618753380706494,
           5.564876540766304,
           5.510999700826103,
           5.457122860885902,
           5.403246020945701,
           5.34936918100551,
           5.295492341065309,
           5.241615501125109,
           5.187738661184918,
           5.133861821244716,
           5.0799849813045155,
           5.0261081413643245,
           4.972231301424124,
           4.918354461483922,
           4.864477621543721,
           4.81060078160353
          ],
          [
           51.648617303101766,
           51.70042929866385,
           51.752241294225925,
           51.804053289788,
           51.85586528535008,
           51.907677280912154,
           51.95948927647423,
           52.01130127203631,
           52.06311326759838,
           52.11492526316047,
           52.16673725872255,
           52.21854925428463,
           52.27036124984671,
           52.322173245408784,
           52.37398524097086,
           52.42579723653294,
           52.47760923209502,
           52.52942122765709,
           52.58123322321917,
           52.63304521878125,
           52.68485721434334,
           52.736669209905415,
           52.78848120546749,
           52.84029320102957,
           52.89210519659164,
           52.94391719215373,
           52.9957291877158,
           53.04754118327788,
           53.099353178839955,
           53.15116517440204,
           53.20297716996412,
           53.2547891655262,
           53.30660116108827,
           53.35841315665035,
           53.410225152212426,
           53.46203714777451,
           53.51384914333658,
           53.56566113889866,
           53.617473134460745,
           53.669285130022814,
           53.7210971255849,
           53.77290912114698,
           53.82472111670906,
           53.87653311227114,
           53.928345107833216,
           53.98015710339529,
           54.03196909895737,
           54.083781094519445,
           54.13559309008153,
           54.187405085643604,
           54.23921708120569,
           54.291029076767764,
           54.34284107232984,
           54.394653067891916,
           54.44646506345399,
           54.49827705901607,
           54.55008905457815,
           54.601901050140235,
           54.653713045702304,
           54.70552504126439,
           54.75733703682647,
           54.80914903238855,
           54.86096102795062,
           54.912773023512706,
           54.96458501907478,
           55.01639701463686,
           55.068209010198935,
           55.12002100576101,
           55.171833001323094,
           55.22364499688517,
           55.275456992447246,
           55.32726898800932,
           55.379080983571406,
           55.43089297913348,
           55.482704974695565,
           55.53451697025764,
           55.58632896581972,
           55.6381409613818,
           55.68995295694388,
           55.74176495250595,
           55.793576948068036,
           55.84584217230289,
           55.89819804127502,
           55.950553910247166,
           55.997100980671675,
           56.04248629138668,
           56.08787160210168,
           56.13318279674587,
           56.17847916801282,
           56.223775539279764,
           56.26907191054672,
           56.31436828181367,
           56.35966465308062,
           56.404961024347564,
           56.45025739561452,
           56.495553766881464,
           56.540850138148414,
           56.586146509415364,
           56.631442880682314,
           56.676739251949265,
           56.722035623216215,
           56.76733199448317,
           56.81262836575012,
           56.85792473701707,
           56.903221108284015,
           56.94851747955097,
           56.993813850817915,
           57.039110222084865,
           57.084406593351815,
           57.12970296461876,
           57.174999335885715,
           57.220295707152665,
           57.265592078419616,
           57.31088844968657,
           57.356184820953516,
           57.401481192220466,
           57.446777563487416,
           57.492073934754366,
           57.537370306021316,
           57.582666677288266,
           57.627963048555216,
           57.673259419822166,
           57.718555791089116,
           57.763852162356066,
           57.809148533623016,
           57.85444490488997,
           57.899741276156924,
           57.945037647423874,
           57.99033401869081,
           58.03563038995777,
           58.08092676122472,
           58.12622313249167,
           58.171519503758624,
           58.21681587502557,
           58.26211224629252,
           58.30740861755947,
           58.35270498882642,
           58.39800136009336,
           58.44329773136032,
           58.48859410262727,
           58.53389047389422,
           58.57918684516116,
           58.62448321642812,
           58.66977958769506,
           58.71507595896202,
           58.76037233022896,
           58.80566870149592,
           58.85096507276287,
           58.89626144402981,
           58.94155781529677,
           58.98685418656372,
           59.03215055783067,
           59.07744692909761,
           59.12274330036456,
           59.16803967163152,
           59.21333604289846,
           59.25863241416541,
           59.30392878543236,
           59.34922515669931,
           59.39452152796626,
           59.43981789923321,
           59.48511427050017,
           59.53041064176712,
           59.57570701303406,
           59.62100338430102,
           59.66629975556797,
           59.71159612683491,
           59.75662597623004,
           59.80152256468924,
           59.84641915314845,
           59.89131574160767,
           59.93621233006687,
           59.98110891852608,
           60.02600550698529,
           60.0709020954445,
           60.11581578870048,
           60.160729482014474,
           60.20564317532847,
           60.250556868642455,
           60.29547056195645,
           60.34038425527045,
           60.38529794858444,
           60.43021164189843,
           60.475125335212425,
           60.520039028526426,
           60.56495272184042,
           60.60986641515441,
           60.6547801084684,
           60.699693801782395,
           60.74460749509639,
           60.78952118841038,
           60.83443488172437,
           60.87934857503837,
           60.92426226835236,
           60.96917596166636,
           61.014089654980346,
           61.05900334829434,
           61.10391704160833,
           61.14883073492233,
           61.19374442823632,
           61.238658121550316,
           61.2835718148643,
           61.328485508178304,
           61.37339920149229,
           61.418312894806284,
           61.46322658812028,
           61.50814028143428,
           61.553053974748266,
           61.59796766806227,
           61.64288136137626,
           61.687795054690255,
           61.73270874800424,
           61.777622441318236,
           61.82253613463223,
           61.867449827946224,
           61.91236352126022,
           61.95727721457422,
           62.002190907888206,
           62.04710460120219,
           62.092018294516194,
           62.13693198783018,
           62.18184568114419,
           62.22675937445818,
           62.27167306777217,
           62.31658676108616,
           62.361500454400144,
           62.40641414771416,
           62.451327841028146,
           62.49624153434213,
           62.541155227656134,
           62.58606892097012,
           62.63098261428412,
           62.675896307598116,
           62.7208100009121,
           62.7657236942261,
           62.8106373875401,
           62.855551080854084,
           62.90046477416808,
           62.94537846748207,
           62.99029216079607,
           63.03520585411006,
           63.08011954742405,
           63.12503324073805,
           63.16994693405204,
           63.214860627366036,
           63.25977432068002,
           63.30468801399402,
           63.34960170730801,
           63.394515400622005,
           63.439429093936,
           63.33462644497148,
           63.080107453728424,
           62.8255884624854,
           62.571069471242396,
           62.31655047999934,
           62.06203148875632,
           61.807512497513294,
           61.552993506270255,
           61.29847451502721,
           61.043955523784206,
           60.78943653254116,
           60.534917541298114,
           60.2803985500551,
           60.02587955881208,
           59.77136056756903,
           59.516841576326,
           59.262322585082984,
           59.00780359383994,
           58.75328460259692,
           58.49876561135389,
           58.24424662011084,
           57.9897276288678,
           57.73520863762481,
           57.48068964638176,
           57.226170655138716,
           56.97165166389569,
           56.717132672652674,
           56.46261368140963,
           56.208094690166604,
           55.953575698923586,
           55.69905670768054,
           55.444537716437495,
           55.1900187251945,
           54.93549973395146,
           54.68098074270841,
           54.42646175146538,
           54.171942760222365,
           53.917423768979326,
           53.6629047777363,
           53.40838578649327,
           53.15386679525024,
           52.89934780400721,
           52.64482881276419,
           52.39030982152114,
           52.1357908302781,
           51.88127183903511,
           51.626752847792055,
           51.372233856549016,
           51.117714865305985,
           50.86319587406297,
           50.60867688281992,
           50.354157891576904,
           50.09963890033387,
           49.845119909090826,
           49.59060091784779,
           49.33608192660479,
           49.081562935361745,
           48.8270439441187,
           48.57252495287567,
           48.31800596163266,
           48.06348697038962,
           47.80896797914659,
           47.55444898790356,
           47.299929996660524,
           47.045411005417506,
           46.78705259782858,
           46.50904533772019,
           46.23103807761181,
           45.95303081750346,
           45.67502355739508,
           45.397016297286676,
           45.119009037178316,
           44.84100177706995,
           44.56299451696157,
           44.284987256853206,
           44.00697999674484,
           43.72897273663644,
           43.45096547652808,
           43.172958216419715,
           42.894950956311334,
           42.616943696202945,
           42.33893643609458,
           42.06092917598622,
           41.75524268082289,
           41.39419771554979,
           41.03315275027666,
           40.67210778500352,
           40.3110628197304,
           39.950017854457286,
           39.58897288918414,
           39.22792792391099,
           38.866882958637916,
           38.50583799336476,
           38.14479302809161,
           37.7837480628185,
           37.42270309754539,
           37.061658132272235,
           36.70061316699912,
           36.339568201726,
           35.97852323645286,
           35.61747827117975,
           35.25643330590663,
           34.89538834063348,
           34.534343375360336,
           34.17329841008722,
           33.812253444814104,
           33.45120847954096,
           33.09016351426784,
           32.72911854899473,
           32.368073583721575,
           32.00702861844846,
           31.64598365317535,
           31.282589587949886,
           30.915008030910347,
           30.547426473870882,
           30.17984491683135,
           29.812263359791814,
           29.444681802752317,
           29.077100245712817,
           28.709518688673278,
           28.341937131633784,
           27.974355574594284,
           27.60677401755475,
           27.23919246051525,
           26.871610903475748,
           26.504029346436216,
           26.13644778939668,
           25.768866232357183,
           25.401284675317683,
           25.033703118278147,
           24.666121561238644,
           24.298540004199147,
           23.93095844715961,
           23.56337689012011,
           23.195795333080618,
           22.82821377604108,
           22.460632219001546,
           22.09305066196208,
           21.725469104922546,
           21.35788754788301,
           20.990305990843517,
           20.622724433804017,
           20.25514287676448,
           19.887561319724977,
           19.51997976268548,
           19.152398205645945,
           18.784816648606444,
           18.417235091566944,
           18.04965353452741,
           17.68207197748788,
           17.31449042044841,
           16.94690886340888,
           16.579327306369343,
           16.211745749329843,
           15.844164192290345,
           15.476582635250812,
           15.109001078211307,
           14.74141952117181,
           14.373837964132274,
           14.00625640709274,
           13.638674850053278,
           13.271093293013744,
           12.903511735974206,
           12.535930178934711,
           12.16834862189521,
           11.800767064855677,
           11.47624769261152,
           11.367039244343829,
           11.257830796076142,
           11.148622347808454,
           11.039413899540785,
           10.930205451273098,
           10.820997003005408,
           10.71178855473774,
           10.602580106470052,
           10.493371658202364,
           10.384163209934695,
           10.274954761667004,
           10.165746313399318,
           10.056537865131629,
           9.947329416863962,
           9.838120968596272,
           9.728912520328583,
           9.619704072060916,
           9.510495623793226,
           9.401287175525539,
           9.29207872725787,
           9.182870278990181,
           9.073661830722493,
           8.964453382454824,
           8.855244934187137,
           8.746036485919447,
           8.656969049729534,
           8.578083715732737,
           8.499198381735923,
           8.420313047739107,
           8.341427713742307,
           8.262542379745492,
           8.183657045748678,
           8.104771711751876,
           8.025886377755063,
           7.947001043758247,
           7.868115709761433,
           7.7892303757646335,
           7.710345041767818,
           7.631459707771004,
           7.5525743737742035,
           7.47368903977739,
           7.394803705780574,
           7.315918371783774,
           7.23703303778696,
           7.158147703790146,
           7.079262369793345,
           7.000377035796531,
           6.921491701799716,
           6.842606367802902,
           6.763721033806102,
           6.6848356998092875,
           6.605950365812473,
           6.527065031815672,
           6.448179697818858,
           6.369294363822044,
           6.290409029825244,
           6.211523695828429,
           6.145203966932283,
           6.091327126992083,
           6.037450287051891,
           5.983573447111691,
           5.92969660717149,
           5.875819767231299,
           5.821942927291097,
           5.768066087350897,
           5.714189247410706,
           5.660312407470505,
           5.606435567530303,
           5.552558727590112,
           5.498681887649912,
           5.444805047709711,
           5.390928207769511,
           5.337051367829319,
           5.283174527889118,
           5.229297687948917,
           5.175420848008726,
           5.1215440080685255,
           5.067667168128324,
           5.013790328188133,
           4.959913488247932,
           4.906036648307731,
           4.85215980836753,
           4.79828296842734
          ],
          [
           51.9477744764175,
           51.999586471979576,
           52.05139846754166,
           52.103210463103736,
           52.15502245866581,
           52.20683445422789,
           52.258646449789964,
           52.310458445352054,
           52.36227044091412,
           52.41408243647621,
           52.46589443203828,
           52.51770642760036,
           52.569518423162435,
           52.62133041872452,
           52.673142414286595,
           52.72495440984868,
           52.776766405410754,
           52.82857840097283,
           52.88039039653491,
           52.93220239209699,
           52.984014387659066,
           53.03582638322114,
           53.087638378783225,
           53.1394503743453,
           53.19126236990738,
           53.24307436546946,
           53.29488636103154,
           53.34669835659362,
           53.39851035215569,
           53.450322347717766,
           53.50213434327985,
           53.55394633884193,
           53.605758334404015,
           53.657570329966084,
           53.70938232552816,
           53.76119432109024,
           53.81300631665231,
           53.864818312214396,
           53.91663030777648,
           53.96844230333856,
           54.02025429890063,
           54.07206629446271,
           54.123878290024784,
           54.17569028558687,
           54.22750228114894,
           54.27931427671102,
           54.3311262722731,
           54.38293826783518,
           54.434750263397255,
           54.48656225895934,
           54.538374254521415,
           54.59018625008349,
           54.64199824564557,
           54.69381024120765,
           54.74562223676973,
           54.7974342323318,
           54.84924622789388,
           54.90105822345597,
           54.95287021901804,
           55.004682214580114,
           55.0564942101422,
           55.108306205704274,
           55.16011820126636,
           55.21193019682843,
           55.263923484061735,
           55.31627935303386,
           55.368635222006006,
           55.42099109097814,
           55.47334695995028,
           55.52570282892242,
           55.578058697894555,
           55.63041456686669,
           55.682770435838826,
           55.73512630481097,
           55.787482173783104,
           55.83983804275524,
           55.892193911727375,
           55.94454978069951,
           55.99690564967165,
           56.04926151864378,
           56.101617387615924,
           56.15397325658807,
           56.206329125560195,
           56.25868499453234,
           56.305232064956854,
           56.35061737567185,
           56.39600268638685,
           56.44138799710185,
           56.48677330781685,
           56.532158618531845,
           56.57754392924684,
           56.622929239961834,
           56.66831455067684,
           56.71369986139183,
           56.75908517210683,
           56.80447048282183,
           56.849855793536825,
           56.895241104251824,
           56.94062641496682,
           56.98601172568182,
           57.03139703639681,
           57.07678234711181,
           57.122167657826814,
           57.167523322146536,
           57.212819693413486,
           57.258116064680436,
           57.30341243594738,
           57.34870880721434,
           57.39400517848129,
           57.43930154974823,
           57.48459792101518,
           57.52989429228214,
           57.57519066354908,
           57.62048703481604,
           57.66578340608298,
           57.71107977734994,
           57.75637614861689,
           57.80167251988383,
           57.84696889115078,
           57.89226526241773,
           57.93756163368468,
           57.98285800495164,
           58.02815437621858,
           58.07345074748553,
           58.11874711875248,
           58.16404349001944,
           58.20933986128639,
           58.254636232553345,
           58.29993260382028,
           58.345228975087245,
           58.39052534635419,
           58.435821717621145,
           58.48111808888809,
           58.52641446015504,
           58.57171083142198,
           58.61700720268894,
           58.66230357395588,
           58.70759994522283,
           58.75289631648978,
           58.79819268775673,
           58.84348905902368,
           58.88878543029064,
           58.93408180155758,
           58.97937817282453,
           59.02467454409148,
           59.06997091535843,
           59.11526728662538,
           59.16056365789234,
           59.20586002915928,
           59.25115640042624,
           59.29645277169318,
           59.34174914296013,
           59.38704551422708,
           59.432341885494026,
           59.47763825676098,
           59.52293462802793,
           59.56823099929488,
           59.61352737056183,
           59.658823741828776,
           59.70412011309573,
           59.74941648436268,
           59.79471285562963,
           59.84000922689658,
           59.885305598163534,
           59.930601969430484,
           59.975898340697434,
           60.021194711964384,
           60.066224561359505,
           60.11112114981871,
           60.15601773827792,
           60.200914326737134,
           60.24581091519634,
           60.29070750365555,
           60.33560409211476,
           60.38050068057397,
           60.42539726903317,
           60.47029385749238,
           60.51519044595159,
           60.5600870344108,
           60.60498362287,
           60.64988021132922,
           60.69477679978842,
           60.739673388247624,
           60.78456997670684,
           60.82946656516605,
           60.874363153625254,
           60.91925974208446,
           60.96415633054368,
           61.00905291900288,
           61.05394950746209,
           61.0988460959213,
           61.14374268438051,
           61.18863927283971,
           61.233535861298925,
           61.278432449758135,
           61.32332903821734,
           61.36822562667655,
           61.41312221513575,
           61.45801880359497,
           61.50291539205418,
           61.54781198051339,
           61.5927085689726,
           61.63760515743181,
           61.68250174589102,
           61.72739833435021,
           61.77229492280942,
           61.81719151126863,
           61.86208809972784,
           61.906984688187045,
           61.95188127664626,
           61.99677786510547,
           62.041674453564674,
           62.086571042023884,
           62.13146763048309,
           62.1763642189423,
           62.22126080740151,
           62.266157395860716,
           62.311068238379676,
           62.355981931693684,
           62.40089562500768,
           62.445809318321665,
           62.490723011635666,
           62.53563670494966,
           62.58055039826365,
           62.62546409157765,
           62.670377784891635,
           62.71529147820563,
           62.76020517151963,
           62.80511886483362,
           62.85003255814762,
           62.894946251461604,
           62.9398599447756,
           62.98477363808959,
           63.02968733140359,
           63.07460102471758,
           63.119514718031574,
           63.16442841134557,
           63.20934210465957,
           63.254255797973556,
           63.29916949128755,
           63.344083184601544,
           63.38899687791553,
           63.433910571229525,
           63.478824264543526,
           63.52373795785751,
           63.56865165117151,
           63.61356534448551,
           63.658479037799495,
           63.70339273111349,
           63.74830642442749,
           63.64350377546296,
           63.388984784219915,
           63.1344657929769,
           62.879946801733865,
           62.62542781049082,
           62.3709088192478,
           62.116389828004785,
           61.86187083676174,
           61.60735184551869,
           61.35283285427569,
           61.09831386303265,
           60.8437948717896,
           60.58927588054658,
           60.33475688930356,
           60.08023789806051,
           59.82571890681749,
           59.57119991557447,
           59.31668092433143,
           59.062161933088404,
           58.80764294184537,
           58.55312395060233,
           58.29860495935928,
           58.04408596811629,
           57.789566976873246,
           57.5350479856302,
           57.280528994387176,
           57.026010003144165,
           56.77149101190112,
           56.516972020658095,
           56.24709536775801,
           55.96908810764962,
           55.69108084754122,
           55.41307358743289,
           55.135066327324495,
           54.85705906721611,
           54.579051807107746,
           54.30104454699938,
           54.023037286891,
           53.74503002678263,
           53.46702276667427,
           53.18901550656587,
           52.911008246457506,
           52.633000986349145,
           52.35499372624075,
           52.076986466132354,
           51.79897920602403,
           51.52097194591563,
           51.242964685807245,
           50.964957425698884,
           50.68695016559052,
           50.40894290548213,
           50.13093564537377,
           49.8529283852654,
           49.57492112515701,
           49.29691386504862,
           49.018906604940284,
           48.74089934483189,
           48.4628920847235,
           48.18488482461514,
           47.90687756450677,
           47.628870304398376,
           47.35086304429002,
           47.072855784181655,
           46.79484852407327,
           46.516841263964906,
           46.23883400385654,
           45.96082674374815,
           45.68281948363976,
           45.404812223531415,
           45.12680496342302,
           44.84879770331463,
           44.57079044320627,
           44.29278318309791,
           44.014775922989514,
           43.73676866288116,
           43.4587614027728,
           43.180754142664405,
           42.90274688255604,
           42.62473962244767,
           42.34673236233929,
           42.06872510223089,
           41.79071784212253,
           41.51271058201416,
           41.20702408685085,
           40.845979121577734,
           40.48493415630462,
           40.123889191031466,
           39.76284422575836,
           39.40179926048524,
           39.040754295212096,
           38.679709329938945,
           38.318664364665864,
           37.95761939939271,
           37.59657443411956,
           37.23552946884645,
           36.87448450357334,
           36.51343953830019,
           36.15239457302708,
           35.79134960775396,
           35.43030464248081,
           35.0692596772077,
           34.70821471193458,
           34.347169746661436,
           33.986124781388284,
           33.625079816115175,
           33.26403485084206,
           32.902989885568914,
           32.5419449202958,
           32.18089995502268,
           31.819854989749533,
           31.45881002447642,
           31.097765059203304,
           30.736720093930153,
           30.375675128657008,
           30.014630163383924,
           29.65358519811078,
           29.29254023283763,
           28.931495267564515,
           28.5704503022914,
           28.20940533701825,
           27.848360371745137,
           27.48731540647202,
           27.12627044119887,
           26.765225475925753,
           26.404180510652644,
           26.043135545379492,
           25.682090580106344,
           25.321045614833228,
           24.960000649560115,
           24.598955684286967,
           24.237910719013854,
           23.876865753740738,
           23.515820788467586,
           23.154775823194473,
           22.79373085792136,
           22.432685892648212,
           22.071640927375064,
           21.71059596210198,
           21.34955099682883,
           20.988506031555687,
           20.62746106628257,
           20.266416101009455,
           19.90537113573631,
           19.544326170463194,
           19.183281205190077,
           18.822236239916933,
           18.461191274643816,
           18.1001463093707,
           17.739101344097556,
           17.378056378824404,
           17.017011413551323,
           16.655966448278175,
           16.294921483005027,
           15.933876517731914,
           15.572831552458798,
           15.21178658718565,
           14.850741621912535,
           14.48969665663942,
           14.128651691366272,
           13.767606726093124,
           13.406561760820043,
           13.045516795546892,
           12.689764757285943,
           12.336241378550552,
           11.982717999815158,
           11.629194621079737,
           11.317545686377525,
           11.215268971840985,
           11.112992257304445,
           11.018916041800956,
           10.940030707804157,
           10.861145373807343,
           10.782260039810527,
           10.703374705813728,
           10.624489371816912,
           10.545604037820098,
           10.466718703823298,
           10.387833369826483,
           10.308948035829669,
           10.230062701832853,
           10.151177367836056,
           10.07229203383924,
           9.993406699842426,
           9.914521365845626,
           9.83563603184881,
           9.756750697851997,
           9.677865363855195,
           9.598980029858382,
           9.520094695861568,
           9.441209361864768,
           9.362324027867952,
           9.283438693871137,
           9.204553359874325,
           9.125668025877523,
           9.04678269188071,
           8.967897357883894,
           8.889012023887094,
           8.81012668989028,
           8.731241355893465,
           8.652356021896665,
           8.573470687899851,
           8.494585353903037,
           8.415700019906222,
           8.336814685909422,
           8.257929351912608,
           8.179044017915793,
           8.100158683918993,
           8.021273349922179,
           7.9423880159253635,
           7.863502681928564,
           7.78461734793175,
           7.705732013934934,
           7.626846679938135,
           7.547961345941321,
           7.469076011944505,
           7.390190677947691,
           7.311305343950892,
           7.232420009954076,
           7.153534675957262,
           7.074649341960463,
           6.995764007963648,
           6.916878673966833,
           6.8379933399700334,
           6.759108005973218,
           6.680222671976404,
           6.601337337979588,
           6.522452003982789,
           6.443566669985975,
           6.36468133598916,
           6.28579600199236,
           6.206910667995546,
           6.12802533399873,
           6.04914000000193,
           5.970254666005117,
           5.891369332008301,
           5.812483998011501,
           5.733598664014687,
           5.654713330017873,
           5.575827996021058,
           5.496942662024258,
           5.418057328027444,
           5.339171994030629,
           5.260286660033828,
           5.1814013260370135,
           5.1025159920402,
           5.0236306580434,
           4.944745324046585,
           4.8884541445519165,
           4.837254710688502,
           4.786055276825098
          ],
          [
           52.246931649733234,
           52.29874364529532,
           52.350555640857394,
           52.40236763641947,
           52.454179631981546,
           52.50599162754362,
           52.5578036231057,
           52.60961561866779,
           52.661427614229865,
           52.71323960979194,
           52.76505160535402,
           52.81686360091609,
           52.86867559647817,
           52.92048759204025,
           52.972299587602336,
           53.02411158316441,
           53.07592357872649,
           53.127735574288565,
           53.17954756985064,
           53.231359565412724,
           53.28317156097481,
           53.33498355653688,
           53.38679555209896,
           53.43860754766103,
           53.49041954322312,
           53.54223153878519,
           53.594043534347264,
           53.645855529909355,
           53.697667525471424,
           53.74947952103351,
           53.80129151659558,
           53.85310351215766,
           53.90491550771974,
           53.95672750328181,
           54.0085394988439,
           54.06035149440598,
           54.11216348996805,
           54.16397548553014,
           54.21578748109221,
           54.2675994766543,
           54.319411472216366,
           54.37122346777845,
           54.423035463340526,
           54.4748474589026,
           54.52665945446468,
           54.578471450026754,
           54.63028344558883,
           54.68209544115092,
           54.73436066479271,
           54.786716533764846,
           54.83907240273698,
           54.891428271709124,
           54.94378414068126,
           54.996140009653395,
           55.04849587862553,
           55.10085174759767,
           55.15320761656981,
           55.205563485541944,
           55.25791935451408,
           55.31027522348622,
           55.36263109245835,
           55.41498696143049,
           55.46734283040263,
           55.51969869937477,
           55.57205456834691,
           55.62441043731904,
           55.67676630629117,
           55.72912217526331,
           55.781478044235456,
           55.833833913207584,
           55.88618978217973,
           55.93854565115186,
           55.990901520124,
           56.04325738909614,
           56.095613258068276,
           56.14796912704041,
           56.20032499601254,
           56.25268086498468,
           56.30503673395682,
           56.35739260292896,
           56.409748471901096,
           56.46210434087323,
           56.51446020984537,
           56.56681607881751,
           56.61336314924202,
           56.65874845995703,
           56.70413377067202,
           56.749519081387014,
           56.79490439210202,
           56.84028970281702,
           56.88567501353201,
           56.93106032424701,
           56.97644563496201,
           57.021830945676996,
           57.067216256391994,
           57.112601567107,
           57.157986877822,
           57.20337218853699,
           57.248757499251994,
           57.29414280996699,
           57.33952812068199,
           57.38491343139698,
           57.43029874211198,
           57.475684052826985,
           57.52106936354198,
           57.566454674256974,
           57.61183998497197,
           57.65722529568697,
           57.70261060640197,
           57.74799591711696,
           57.793381227831965,
           57.83876653854696,
           57.884151849261954,
           57.92953715997696,
           57.97492247069195,
           58.020307781406956,
           58.06569309212195,
           58.111078402836945,
           58.15646371355194,
           58.20184902426694,
           58.24716021881415,
           58.2924565900811,
           58.337752961348045,
           58.383049332615,
           58.42834570388195,
           58.4736420751489,
           58.51893844641586,
           58.5642348176828,
           58.609531188949745,
           58.6548275602167,
           58.70012393148366,
           58.7454203027506,
           58.79071667401756,
           58.8360130452845,
           58.88130941655145,
           58.9266057878184,
           58.97190215908535,
           59.0171985303523,
           59.06249490161925,
           59.107791272886196,
           59.15308764415315,
           59.1983840154201,
           59.24368038668705,
           59.288976757953996,
           59.33427312922095,
           59.3795695004879,
           59.424865871754854,
           59.470162243021804,
           59.515458614288754,
           59.560754985555704,
           59.606051356822654,
           59.651347728089604,
           59.69664409935655,
           59.74194047062349,
           59.78723684189045,
           59.83253321315739,
           59.87782958442435,
           59.923125955691305,
           59.96842232695825,
           60.0137186982252,
           60.05901506949215,
           60.1043114407591,
           60.149607812026055,
           60.194904183293,
           60.24020055455995,
           60.285496925826905,
           60.33079329709385,
           60.375823146488976,
           60.42071973494818,
           60.46561632340739,
           60.5105129118666,
           60.55540950032581,
           60.60030608878502,
           60.64520267724423,
           60.69009926570343,
           60.73499585416264,
           60.77989244262184,
           60.82478903108105,
           60.86968561954026,
           60.914582207999466,
           60.95947879645868,
           61.00437538491789,
           61.0492719733771,
           61.094168561836305,
           61.139065150295515,
           61.18396173875473,
           61.228858327213935,
           61.273754915673145,
           61.31865150413235,
           61.36354809259156,
           61.40844468105077,
           61.45334126950998,
           61.49823785796918,
           61.54313444642839,
           61.58803103488759,
           61.63292762334681,
           61.67782421180601,
           61.72272080026523,
           61.76761738872443,
           61.81251397718364,
           61.85741056564285,
           61.90230715410206,
           61.94720374256127,
           61.99210033102048,
           62.036996919479684,
           62.08189350793889,
           62.126790096398096,
           62.171686684857306,
           62.216583273316516,
           62.261479861775726,
           62.306376450234936,
           62.351273038694146,
           62.396169627153355,
           62.44106621561255,
           62.48596280407176,
           62.53085939253097,
           62.57575598099018,
           62.62065256944939,
           62.66554915790859,
           62.71044574636781,
           62.75534233482702,
           62.80023892328623,
           62.84513551174543,
           62.89003210020464,
           62.93492868866385,
           62.97982527712306,
           63.02472186558227,
           63.069618454041475,
           63.11451504250068,
           63.159411630959895,
           63.2043082194191,
           63.24920480787831,
           63.294101396337524,
           63.33899798479672,
           63.383894573255944,
           63.42879116171514,
           63.473687750174356,
           63.518584338633566,
           63.563480927092755,
           63.60837751555198,
           63.65327410401119,
           63.698170692470384,
           63.7430672809296,
           63.78796386938881,
           63.832735818567244,
           63.87693441682714,
           63.921133015087044,
           63.96533161334695,
           64.00953021160684,
           64.05372880986675,
           63.933287628988055,
           63.64820666897076,
           63.3631257089535,
           63.07804474893623,
           62.79296378891894,
           62.50788282890168,
           62.22280186888442,
           61.93772090886712,
           61.65263994884983,
           61.36755898883259,
           61.08247802881531,
           60.79739706879802,
           60.512316108780745,
           60.22723514876349,
           59.942154188746194,
           59.65707322872893,
           59.37199226871168,
           59.08691130869438,
           58.801830348677115,
           58.516749388659846,
           58.231668428642564,
           57.94658746862527,
           57.66150650860803,
           57.376425548590746,
           57.091344588573456,
           56.810905814219446,
           56.532898554111085,
           56.25489129400269,
           55.97688403389432,
           55.698876773785955,
           55.42086951367757,
           55.142862253569184,
           54.864854993460845,
           54.58684773335246,
           54.30884047324406,
           54.03083321313569,
           53.75282595302733,
           53.47481869291895,
           53.19681143281059,
           52.918804172702224,
           52.64079691259383,
           52.36278965248546,
           52.08478239237709,
           51.80677513226871,
           51.52876787216032,
           51.25076061205198,
           50.97275335194359,
           50.6947460918352,
           50.41673883172683,
           50.138731571618464,
           49.86072431151008,
           49.582717051401715,
           49.304709791293355,
           49.02670253118497,
           48.74869527107657,
           48.47068801096823,
           48.19268075085984,
           47.914673490751454,
           47.63666623064309,
           47.35865897053473,
           47.08065171042634,
           46.80264445031797,
           46.52463719020961,
           46.24662993010122,
           45.96862266999286,
           45.690615409884494,
           45.4126081497761,
           45.13460088966771,
           44.85659362955937,
           44.57858636945098,
           44.30057910934259,
           44.02257184923423,
           43.74456458912587,
           43.466557329017476,
           43.18855006890911,
           42.91054280880075,
           42.63253554869235,
           42.35452828858399,
           42.07652102847563,
           41.798513768367236,
           41.520506508258855,
           41.24249924815049,
           40.96449198804213,
           40.6588054928788,
           40.29776052760568,
           39.93671556233258,
           39.57567059705942,
           39.214625631786305,
           38.8535806665132,
           38.492535701240044,
           38.131490735966906,
           37.77044577069382,
           37.409400805420674,
           37.04835584014752,
           36.68731087487441,
           36.3262659096013,
           35.965220944328145,
           35.60417597905503,
           35.24313101378191,
           34.88208604850877,
           34.52104108323565,
           34.159996117962535,
           33.79895115268939,
           33.43790618741624,
           33.07686122214312,
           32.71581625687001,
           32.35477129159686,
           31.99372632632375,
           31.632681361050636,
           31.274735541583063,
           30.921212162847674,
           30.567688784112278,
           30.214165405376857,
           29.860642026641433,
           29.507118647906076,
           29.153595269170648,
           28.800071890435227,
           28.446548511699834,
           28.093025132964442,
           27.739501754229018,
           27.38597837549363,
           27.032454996758233,
           26.678931618022812,
           26.32540823928742,
           25.97188486055203,
           25.61836148181661,
           25.264838103081182,
           24.91131472434579,
           24.5577913456104,
           24.204267966874973,
           23.850744588139584,
           23.49722120940419,
           23.143697830668767,
           22.790174451933378,
           22.436651073197986,
           22.08312769446256,
           21.729604315727137,
           21.37608093699178,
           21.022557558256356,
           20.66903417952093,
           20.31551080078554,
           19.96198742205015,
           19.608464043314726,
           19.254940664579333,
           18.90141728584394,
           18.547893907108516,
           18.194370528373128,
           17.840847149637735,
           17.48732377090231,
           17.133800392166886,
           16.78027701343153,
           16.4267536346961,
           16.07323025596068,
           15.719706877225288,
           15.366183498489896,
           15.012660119754473,
           14.659136741019083,
           14.30561336228369,
           13.952089983548266,
           13.598566604812842,
           13.245043226077483,
           12.89151984734206,
           12.537996468606636,
           12.184473089871243,
           11.830949711135853,
           11.47742633240043,
           11.165777397698218,
           11.063500683161678,
           10.961223968625138,
           10.858947254088598,
           10.756670539552076,
           10.654393825015536,
           10.552117110478996,
           10.449840395942475,
           10.347563681405934,
           10.245286966869395,
           10.143010252332875,
           10.040733537796335,
           9.938456823259795,
           9.836180108723255,
           9.733903394186733,
           9.631626679650193,
           9.529349965113653,
           9.427073250577132,
           9.32479653604059,
           9.22251982150405,
           9.12024310696753,
           9.01796639243099,
           8.91568967789445,
           8.81341296335793,
           8.71113624882139,
           8.608859534284848,
           8.50658281974831,
           8.404306105211788,
           8.302029390675246,
           8.19975267613871,
           8.097475961602186,
           7.995199247065646,
           7.892922532529107,
           7.790645817992585,
           7.688369103456044,
           7.586092388919505,
           7.498670505729562,
           7.419785171732761,
           7.340899837735947,
           7.262014503739132,
           7.183129169742333,
           7.104243835745518,
           7.025358501748704,
           6.946473167751903,
           6.867587833755088,
           6.7887024997582746,
           6.709817165761475,
           6.63093183176466,
           6.56676462376563,
           6.515565189902216,
           6.464365756038811,
           6.413166322175397,
           6.361966888311983,
           6.310767454448579,
           6.259568020585165,
           6.208368586721751,
           6.157169152858346,
           6.105969718994933,
           6.054770285131518,
           6.003570851268104,
           5.9523714174046995,
           5.9011719835412855,
           5.849972549677871,
           5.798773115814466,
           5.747573681951053,
           5.696374248087639,
           5.645174814224234,
           5.5939753803608205,
           5.5427759464974065,
           5.491576512634001,
           5.440377078770588,
           5.389177644907173,
           5.33797821104376,
           5.286778777180356,
           5.235579343316941,
           5.1843799094535274,
           5.133180475590123,
           5.081981041726708,
           5.030781607863295,
           4.979582173999891,
           4.928382740136476,
           4.8771833062730625,
           4.8259838724096475,
           4.774784438546243
          ],
          [
           52.546088823048976,
           52.59790081861106,
           52.64971281417313,
           52.70152480973521,
           52.753336805297295,
           52.80514880085937,
           52.85696079642145,
           52.90877279198352,
           52.9605847875456,
           53.01239678310769,
           53.064208778669766,
           53.116020774231835,
           53.16783276979392,
           53.219644765356,
           53.27145676091808,
           53.32326875648016,
           53.37508075204223,
           53.42689274760431,
           53.47870474316639,
           53.53051673872847,
           53.58232873429054,
           53.634140729852625,
           53.685952725414694,
           53.73776472097678,
           53.78957671653885,
           53.84138871210094,
           53.89320070766301,
           53.94501270322509,
           53.996824698787165,
           54.048636694349256,
           54.100448689911325,
           54.152441976551565,
           54.20479784552371,
           54.25715371449584,
           54.30950958346798,
           54.36186545244012,
           54.414221321412256,
           54.46657719038439,
           54.51893305935653,
           54.57128892832867,
           54.623644797300805,
           54.67600066627294,
           54.72835653524508,
           54.78071240421721,
           54.83306827318935,
           54.88542414216148,
           54.937780011133626,
           54.99013588010576,
           55.0424917490779,
           55.09484761805003,
           55.147203487022175,
           55.19955935599431,
           55.251915224966446,
           55.30427109393858,
           55.356626962910724,
           55.40898283188286,
           55.461338700854995,
           55.51369456982713,
           55.566050438799266,
           55.6184063077714,
           55.670762176743544,
           55.72311804571568,
           55.77547391468782,
           55.82782978365996,
           55.88018565263209,
           55.93254152160423,
           55.984897390576364,
           56.0372532595485,
           56.089609128520635,
           56.14196499749278,
           56.19432086646491,
           56.24667673543705,
           56.299032604409184,
           56.35138847338132,
           56.403744342353455,
           56.4561002113256,
           56.50845608029773,
           56.56081194926987,
           56.61316781824201,
           56.66552368721415,
           56.71787955618629,
           56.770235425158425,
           56.82259129413056,
           56.87494716310269,
           56.92149423352721,
           56.96687954424221,
           57.01226485495721,
           57.05765016567221,
           57.1030354763872,
           57.1484207871022,
           57.1938060978172,
           57.2391914085322,
           57.28457671924719,
           57.32996202996219,
           57.37534734067719,
           57.420732651392186,
           57.46611796210718,
           57.51150327282219,
           57.55688858353717,
           57.60227389425218,
           57.64765920496718,
           57.693044515682175,
           57.738429826397166,
           57.78381513711217,
           57.82920044782716,
           57.87458575854216,
           57.91997106925717,
           57.965356379972164,
           58.010741690687155,
           58.05612700140216,
           58.10151231211715,
           58.14689762283215,
           58.19228293354715,
           58.23766824426215,
           58.283053554977144,
           58.328438865692135,
           58.37382417640714,
           58.41920948712213,
           58.46459479783712,
           58.50998010855213,
           58.55536541926712,
           58.600750729982124,
           58.64613604069712,
           58.69152135141211,
           58.736906662127126,
           58.78229197284212,
           58.827677283557115,
           58.87306259427211,
           58.918447904987104,
           58.9638332157021,
           59.0092185264171,
           59.054603837132106,
           59.0999891478471,
           59.14537445856209,
           59.19075976927708,
           59.236145079992085,
           59.281500744214824,
           59.32679711548178,
           59.372093486748724,
           59.417389858015675,
           59.462686229282625,
           59.50798260054958,
           59.553278971816525,
           59.598575343083475,
           59.643871714350425,
           59.689168085617375,
           59.73446445688433,
           59.77976082815128,
           59.82505719941823,
           59.87035357068518,
           59.91564994195213,
           59.96094631321908,
           60.006242684486025,
           60.051539055752976,
           60.096835427019926,
           60.142131798286876,
           60.187428169553826,
           60.232724540820776,
           60.278020912087726,
           60.32331728335468,
           60.368613654621626,
           60.413910025888576,
           60.459206397155526,
           60.504502768422476,
           60.549799139689426,
           60.59509551095638,
           60.64039188222333,
           60.68542173161845,
           60.73031832007766,
           60.775214908536874,
           60.82011149699608,
           60.86500808545529,
           60.90990467391449,
           60.95480126237371,
           60.999697850832916,
           61.04459443929212,
           61.08949102775132,
           61.13438761621053,
           61.17928420466974,
           61.22418079312895,
           61.26907738158816,
           61.31397397004737,
           61.358870558506574,
           61.403767146965784,
           61.448663735425,
           61.493560323884196,
           61.53845691234341,
           61.583353500802616,
           61.628250089261826,
           61.673146677721036,
           61.718043266180246,
           61.762939854639455,
           61.80783644309866,
           61.85273303155787,
           61.89762962001707,
           61.94252620847629,
           61.9874227969355,
           62.0323193853947,
           62.07721597385391,
           62.12211256231312,
           62.16700915077233,
           62.21190573923154,
           62.25680232769075,
           62.30169891614996,
           62.34659550460916,
           62.391492093068365,
           62.43638868152758,
           62.481285269986785,
           62.526181858445995,
           62.571078446905204,
           62.615975035364414,
           62.660871623823624,
           62.705768212282834,
           62.75066480074203,
           62.79556138920124,
           62.84045797766045,
           62.88535456611966,
           62.930051730444674,
           62.97425032870458,
           63.01844892696449,
           63.06264752522438,
           63.10684612348428,
           63.151044721744185,
           63.19524332000408,
           63.239441918263985,
           63.28364051652388,
           63.327839114783785,
           63.37203771304368,
           63.41623631130359,
           63.46043490956349,
           63.50463350782339,
           63.548832106083296,
           63.59303070434319,
           63.6372293026031,
           63.681427900863,
           63.725626499122896,
           63.7698250973828,
           63.8140236956427,
           63.8582222939026,
           63.9024208921625,
           63.94661949042241,
           63.9908180886823,
           64.03501668694221,
           64.07921528520211,
           64.123413883462,
           64.1676124817219,
           64.21181107998181,
           64.25600967824172,
           64.3002082765016,
           64.34440687476152,
           64.22396569388282,
           63.938884733865535,
           63.65380377384827,
           63.368722813831,
           63.08364185381372,
           62.79856089379645,
           62.51347993377919,
           62.228398973761884,
           61.9433180137446,
           61.65823705372736,
           61.37315609371008,
           61.08807513369278,
           60.802994173675515,
           60.51791321365825,
           60.23283225364097,
           59.94775129362371,
           59.662670333606435,
           59.377589373589146,
           59.092508413571885,
           58.807427453554624,
           58.52234649353733,
           58.23726553352004,
           57.952184573502805,
           57.667103613485516,
           57.382022653468226,
           57.09694169345096,
           56.81186073343369,
           56.52677977341641,
           56.24169881339914,
           55.95661785338187,
           55.67153689336459,
           55.38645593334729,
           55.10137497333006,
           54.81629401331277,
           54.531213053295474,
           54.24613209327822,
           53.96105113326095,
           53.67597017324366,
           53.39088921322639,
           53.105808253209126,
           52.82072729319184,
           52.53564633317457,
           52.250565373157315,
           51.96548441314002,
           51.680403453122736,
           51.395322493105496,
           51.1102415330882,
           50.82516057307092,
           50.54007961305364,
           50.25499865303638,
           49.96991769301909,
           49.68483673300183,
           49.39975577298457,
           49.11467481296728,
           48.829593852949984,
           48.544512892932744,
           48.259431932915454,
           47.974350972898165,
           47.689270012880904,
           47.40418905286364,
           47.119108092846346,
           46.834027132829085,
           46.54894617281182,
           46.26386521279453,
           45.97878425277727,
           45.69370329276,
           45.408622332742716,
           45.12354137272542,
           44.83846041270818,
           44.55337945269089,
           44.26829849267361,
           43.97730065412289,
           43.65649910920172,
           43.33569756428052,
           43.014896019359355,
           42.6940944744382,
           42.373292929517,
           42.05249138459583,
           41.73168983967467,
           41.41088829475348,
           41.09008674983228,
           40.769285204911114,
           40.448483659989954,
           40.11875762603719,
           39.77118261402135,
           39.423607602005504,
           39.07603258998962,
           38.728457577973785,
           38.38088256595793,
           38.03330755394206,
           37.685732541926185,
           37.338157529910376,
           36.990582517894495,
           36.64300750587862,
           36.295432493862776,
           35.94785748184693,
           35.60028246983106,
           35.25270745781521,
           34.905132445799374,
           34.557557433783494,
           34.20998242176765,
           33.86240740975181,
           33.51483239773593,
           33.16725738572005,
           32.819682373704204,
           32.472107361688366,
           32.124532349672485,
           31.776957337656647,
           31.429382325640802,
           31.081807313624928,
           30.73423230160908,
           30.386657289593238,
           30.03908227757736,
           29.691507265561484,
           29.34393225354567,
           28.996357241529793,
           28.648303601755913,
           28.294780223020524,
           27.94125684428513,
           27.587733465549707,
           27.234210086814315,
           26.880686708078922,
           26.527163329343498,
           26.17363995060811,
           25.820116571872717,
           25.466593193137292,
           25.113069814401868,
           24.759546435666476,
           24.406023056931087,
           24.05249967819566,
           23.698976299460274,
           23.345452920724878,
           22.991929541989457,
           22.63840616325406,
           22.284882784518672,
           21.93135940578325,
           21.577836027047823,
           21.224312648312466,
           20.870789269577045,
           20.517265890841617,
           20.163742512106225,
           19.810219133370836,
           19.456695754635412,
           19.10317237590002,
           18.749648997164627,
           18.396125618429203,
           18.042602239693814,
           17.68907886095842,
           17.335555482222997,
           16.982032103487576,
           16.628508724752216,
           16.27498534601679,
           15.921461967281367,
           15.567938588545976,
           15.214415209810586,
           14.86089183107516,
           14.507368452339769,
           14.153845073604376,
           13.800321694868952,
           13.446798316133528,
           13.09327493739817,
           12.739751558662746,
           12.386228179927322,
           12.03270480119193,
           11.67918142245654,
           11.325658043721116,
           11.014009109018904,
           10.911732394482364,
           10.809455679945824,
           10.707178965409284,
           10.604902250872764,
           10.502625536336225,
           10.400348821799682,
           10.298072107263163,
           10.195795392726623,
           10.093518678190083,
           9.991241963653561,
           9.888965249117021,
           9.786688534580481,
           9.684411820043941,
           9.582135105507419,
           9.479858390970879,
           9.377581676434339,
           9.27530496189782,
           9.173028247361279,
           9.070751532824739,
           8.970237579154148,
           8.8961650694971,
           8.822092559840051,
           8.748020050183017,
           8.673947540525969,
           8.599875030868922,
           8.525802521211872,
           8.451730011554838,
           8.37765750189779,
           8.303584992240742,
           8.229512482583708,
           8.155439972926658,
           8.081367463269611,
           8.007294953612575,
           7.933222443955529,
           7.859149934298481,
           7.7850774246414325,
           7.7110049149843976,
           7.636932405327348,
           7.562859895670301,
           7.488787386013266,
           7.414714876356218,
           7.34064236669917,
           7.2665698570421355,
           7.192497347385086,
           7.118424837728039,
           7.044352328071003,
           6.970279818413957,
           6.8962073087569085,
           6.822134799099859,
           6.748062289442825,
           6.673989779785778,
           6.599917270128729,
           6.525844760471694,
           6.451772250814646,
           6.377699741157598,
           6.303627231500563,
           6.229554721843514,
           6.155482212186468,
           6.0814097025294185,
           6.0073371928723835,
           5.933264683215336,
           5.859192173558288,
           5.787502277535612,
           5.736302843672198,
           5.685103409808783,
           5.63390397594538,
           5.582704542081966,
           5.531505108218552,
           5.480305674355147,
           5.429106240491733,
           5.377906806628318,
           5.326707372764905,
           5.2755079389015,
           5.224308505038087,
           5.173109071174673,
           5.121909637311267,
           5.070710203447854,
           5.019510769584439,
           4.968311335721035,
           4.917111901857622,
           4.865912467994208,
           4.8147130341307935,
           4.763513600267389
          ],
          [
           52.84524599636471,
           52.89705799192679,
           52.94886998748886,
           53.000681983050946,
           53.05249397861303,
           53.104305974175105,
           53.15611796973718,
           53.20792996529926,
           53.25974196086134,
           53.31155395642342,
           53.3633659519855,
           53.41517794754757,
           53.466989943109645,
           53.51880193867173,
           53.57061393423381,
           53.62287915728254,
           53.67523502625469,
           53.727590895226825,
           53.779946764198954,
           53.832302633171096,
           53.88465850214324,
           53.93701437111537,
           53.98937024008751,
           54.04172610905964,
           54.09408197803178,
           54.146437847003924,
           54.19879371597605,
           54.251149584948195,
           54.30350545392033,
           54.355861322892466,
           54.40821719186461,
           54.46057306083674,
           54.51292892980888,
           54.565284798781015,
           54.61764066775315,
           54.66999653672529,
           54.72235240569742,
           54.774708274669564,
           54.8270641436417,
           54.879420012613835,
           54.93177588158598,
           54.984131750558106,
           55.03648761953025,
           55.08884348850239,
           55.14119935747452,
           55.193555226446655,
           55.245911095418805,
           55.29826696439093,
           55.350622833363076,
           55.402978702335204,
           55.45533457130735,
           55.50769044027949,
           55.56004630925162,
           55.61240217822376,
           55.66475804719589,
           55.71711391616803,
           55.76946978514017,
           55.8218256541123,
           55.87418152308444,
           55.92653739205658,
           55.97889326102871,
           56.03124913000085,
           56.08360499897299,
           56.13596086794512,
           56.18831673691726,
           56.2406726058894,
           56.29302847486153,
           56.34538434383367,
           56.39774021280581,
           56.45009608177794,
           56.502451950750086,
           56.554807819722214,
           56.60716368869436,
           56.65951955766649,
           56.71187542663863,
           56.76423129561077,
           56.8165871645829,
           56.86894303355505,
           56.92129890252719,
           56.97365477149931,
           57.026010640471455,
           57.07836650944359,
           57.130722378415726,
           57.18307824738787,
           57.22962531781239,
           57.27501062852738,
           57.32039593924238,
           57.36578124995739,
           57.41116656067238,
           57.456551871387376,
           57.501937182102374,
           57.54732249281737,
           57.59270780353237,
           57.63809311424737,
           57.68347842496237,
           57.728863735677365,
           57.774249046392356,
           57.81963435710736,
           57.86501966782235,
           57.91040497853736,
           57.95579028925235,
           58.00117559996735,
           58.046560910682345,
           58.09194622139734,
           58.13733153211234,
           58.18271684282734,
           58.22810215354234,
           58.27348746425733,
           58.31887277497232,
           58.364258085687325,
           58.409643396402316,
           58.45502870711732,
           58.50041401783232,
           58.54579932854732,
           58.591184639262316,
           58.63656994997731,
           58.681955260692305,
           58.72734057140731,
           58.772725882122295,
           58.81811119283731,
           58.8634965035523,
           58.908881814267296,
           58.954267124982294,
           58.999652435697286,
           59.04503774641229,
           59.09042305712728,
           59.13580836784229,
           59.181193678557285,
           59.22657898927228,
           59.271964299987275,
           59.31734961070227,
           59.36273492141728,
           59.408120232132276,
           59.45350554284726,
           59.49889085356226,
           59.54427616427725,
           59.58966147499226,
           59.635046785707246,
           59.68043209642225,
           59.72581740713724,
           59.77120271785223,
           59.816588028567246,
           59.86197333928224,
           59.907358649997235,
           59.952743960712226,
           59.99812927142723,
           60.04351458214224,
           60.08889989285722,
           60.13428520357222,
           60.179670514287224,
           60.225055825002215,
           60.27044113571722,
           60.31582644643221,
           60.36113764088245,
           60.4064340121494,
           60.45173038341635,
           60.4970267546833,
           60.54232312595025,
           60.58761949721719,
           60.63291586848415,
           60.67821223975109,
           60.72350861101805,
           60.76880498228499,
           60.81410135355194,
           60.85939772481889,
           60.90469409608584,
           60.94999046735279,
           60.99502031674792,
           61.03991690520713,
           61.08481349366633,
           61.12971008212554,
           61.17460667058475,
           61.21950325904396,
           61.26439984750317,
           61.30929643596238,
           61.35419302442159,
           61.3990896128808,
           61.443986201339996,
           61.488882789799206,
           61.533779378258416,
           61.578675966717626,
           61.623572555176835,
           61.668469143636045,
           61.713365732095255,
           61.758262320554465,
           61.80315890901367,
           61.848055497472885,
           61.89295208593208,
           61.93784867439129,
           61.9827452628505,
           62.027367642322105,
           62.071566240582,
           62.1157648388419,
           62.15996343710181,
           62.20416203536171,
           62.2483606336216,
           62.29255923188151,
           62.33675783014141,
           62.38095642840131,
           62.42515502666121,
           62.46935362492111,
           62.51355222318101,
           62.557750821440905,
           62.601949419700816,
           62.646148017960726,
           62.690346616220616,
           62.73454521448052,
           62.77874381274042,
           62.82294241100033,
           62.86714100926022,
           62.911339607520134,
           62.95553820578003,
           62.99973680403993,
           63.04393540229982,
           63.088134000559734,
           63.13233259881963,
           63.17653119707953,
           63.22072979533943,
           63.264928393599334,
           63.30912699185923,
           63.35332559011914,
           63.39752418837904,
           63.44172278663894,
           63.48592138489884,
           63.53011998315874,
           63.574318581418645,
           63.61851717967855,
           63.662715777938445,
           63.70691437619834,
           63.751112974458245,
           63.79531157271815,
           63.839510170978045,
           63.883708769237955,
           63.92790736749785,
           63.972105965757756,
           64.01630456401766,
           64.06050316227756,
           64.10470176053747,
           64.14890035879736,
           64.19309895705726,
           64.23729755531716,
           64.28149615357705,
           64.32569475183696,
           64.36989335009686,
           64.41409194835677,
           64.45829054661667,
           64.50248914487656,
           64.54668774313646,
           64.59088634139637,
           64.63508493965628,
           64.51464375877757,
           64.22956279876028,
           63.944481838743016,
           63.65940087872576,
           63.374319918708466,
           63.08923895869121,
           62.80415799867394,
           62.519077038656654,
           62.23399607863936,
           61.948915118622125,
           61.663834158604836,
           61.37875319858753,
           61.09367223857028,
           60.80859127855301,
           60.52351031853572,
           60.23842935851846,
           59.95334839850119,
           59.66826743848391,
           59.38318647846664,
           59.09810551844938,
           58.81302455843209,
           58.5279435984148,
           58.24286263839757,
           57.95778167838027,
           57.672700718362975,
           57.387619758345714,
           57.10253879832846,
           56.81745783831116,
           56.532376878293896,
           56.247295918276635,
           55.962214958259345,
           55.677133998242056,
           55.392053038224816,
           55.10697207820753,
           54.82189111819023,
           54.53681015817297,
           54.25172919815571,
           53.96664823813842,
           53.68156727812116,
           53.39648631810388,
           53.11140535808659,
           52.82632439806933,
           52.541243438052064,
           52.256162478034774,
           51.97108151801749,
           51.68600055800025,
           51.400919597982956,
           51.115838637965666,
           50.81476012008252,
           50.49395857516135,
           50.173157030240155,
           49.852355485318995,
           49.53155394039783,
           49.21075239547663,
           48.88995085055544,
           48.5691493056343,
           48.2483477607131,
           47.927546215791914,
           47.60674467087074,
           47.28594312594958,
           46.965141581028384,
           46.644340036107224,
           46.323538491186056,
           46.002736946264854,
           45.681935401343694,
           45.361133856422526,
           45.04033231150133,
           44.719530766580135,
           44.398729221658996,
           44.0779276767378,
           43.757126131816605,
           43.436324586895445,
           43.11552304197427,
           42.794721497053075,
           42.473919952131915,
           42.15311840721075,
           41.83231686228956,
           41.51151531736839,
           41.190713772447225,
           40.86991222752603,
           40.549110682604834,
           40.22830913768367,
           39.9075075927625,
           39.57778155880975,
           39.2302065467939,
           38.88263153477806,
           38.535056522762176,
           38.18748151074634,
           37.83990649873049,
           37.49233148671462,
           37.144756474698745,
           36.79718146268293,
           36.449606450667055,
           36.102031438651174,
           35.75445642663533,
           35.406881414619484,
           35.05930640260361,
           34.711731390587765,
           34.36415637857192,
           34.016581366556046,
           33.66900635454021,
           33.32143134252436,
           32.97385633050848,
           32.6262813184926,
           32.278706306476764,
           31.93113129446092,
           31.58355628244504,
           31.235981270429196,
           30.888406258413355,
           30.540831246397477,
           30.193256234381636,
           29.84568122236579,
           29.498106210349917,
           29.150531198334036,
           28.802956186318227,
           28.45538117430235,
           28.107806162286476,
           27.760231150270627,
           27.41265613825479,
           27.065081126238912,
           26.717506114223067,
           26.369931102207225,
           26.022356090191348,
           25.674781078175503,
           25.327206066159658,
           24.979631054143784,
           24.632056042127907,
           24.28448103011206,
           23.93690601809622,
           23.58933100608034,
           23.241755994064498,
           22.894180982048653,
           22.54660597003278,
           22.199030958016934,
           21.851455946001092,
           21.503880933985215,
           21.156305921969338,
           20.80873090995353,
           20.461155897937648,
           20.113580885921774,
           19.76600587390593,
           19.418430861890087,
           19.070855849874206,
           18.723280837858365,
           18.375705825842523,
           18.028130813826643,
           17.6805558018108,
           17.33298078979496,
           16.985405777779082,
           16.637830765763205,
           16.290255753747395,
           15.942680741731515,
           15.595105729715641,
           15.247530717699796,
           14.899955705683954,
           14.55815354950303,
           14.21876554329945,
           13.879377537095866,
           13.539989530892253,
           13.20060152468864,
           12.861213518485089,
           12.521825512281476,
           12.182437506077864,
           11.843049499874283,
           11.5036614936707,
           11.164273487467087,
           10.86549386258337,
           10.769756144298757,
           10.674018426014143,
           10.57828070772953,
           10.482542989444934,
           10.38680527116032,
           10.291067552875706,
           10.195329834591112,
           10.099592116306498,
           10.021908783560354,
           9.94783627390332,
           9.873763764246274,
           9.799691254589224,
           9.725618744932175,
           9.651546235275141,
           9.577473725618091,
           9.503401215961045,
           9.429328706304009,
           9.35525619664696,
           9.281183686989912,
           9.207111177332878,
           9.13303866767583,
           9.058966158018782,
           8.984893648361748,
           8.910821138704701,
           8.836748629047653,
           8.762676119390605,
           8.688603609733569,
           8.614531100076523,
           8.540458590419473,
           8.466386080762438,
           8.39231357110539,
           8.318241061448342,
           8.244168551791308,
           8.17009604213426,
           8.096023532477211,
           8.021951022820163,
           7.947878513163128,
           7.87380600350608,
           7.799733493849032,
           7.725660984191997,
           7.6515884745349485,
           7.5775159648779,
           7.503443455220866,
           7.429370945563818,
           7.355298435906769,
           7.281225926249735,
           7.207153416592687,
           7.133080906935638,
           7.059008397278591,
           6.984935887621557,
           6.910863377964508,
           6.8367908683074585,
           6.7627183586504245,
           6.688645848993376,
           6.614573339336328,
           6.540500829679294,
           6.466428320022246,
           6.392355810365197,
           6.31828330070815,
           6.244210791051115,
           6.170138281394067,
           6.096065771737019,
           6.021993262079984,
           5.947920752422935,
           5.873848242765887,
           5.799775733108852,
           5.725703223451804,
           5.651630713794757,
           5.577558204137722,
           5.503485694480674,
           5.429413184823625,
           5.355340675166578,
           5.281268165509542,
           5.2071956558524946,
           5.141598188718759,
           5.09295096511596,
           5.0443037415131515,
           4.995656517910344,
           4.947009294307546,
           4.898362070704738,
           4.84971484710193,
           4.801067623499122,
           4.752420399896323
          ],
          [
           53.14213077651395,
           53.19448664548609,
           53.24684251445822,
           53.29919838343036,
           53.351554252402494,
           53.403910121374636,
           53.45626599034677,
           53.50862185931891,
           53.56097772829105,
           53.61333359726318,
           53.665689466235314,
           53.71804533520746,
           53.7704012041796,
           53.82275707315173,
           53.87511294212386,
           53.927468811096,
           53.97982468006814,
           54.03218054904027,
           54.08453641801241,
           54.13689228698455,
           54.18924815595669,
           54.241604024928826,
           54.29395989390096,
           54.3463157628731,
           54.39867163184524,
           54.451027500817375,
           54.5033833697895,
           54.55573923876165,
           54.60809510773378,
           54.660450976705924,
           54.71280684567806,
           54.76516271465019,
           54.81751858362233,
           54.869874452594466,
           54.92223032156661,
           54.974586190538744,
           55.02694205951087,
           55.07929792848302,
           55.13165379745515,
           55.18400966642729,
           55.23636553539943,
           55.288721404371564,
           55.34107727334371,
           55.39343314231584,
           55.44578901128798,
           55.49814488026012,
           55.55050074923225,
           55.60285661820439,
           55.65521248717652,
           55.70756835614866,
           55.7599242251208,
           55.812280094092934,
           55.864635963065076,
           55.91699183203721,
           55.96934770100935,
           56.02170356998148,
           56.07405943895362,
           56.12641530792576,
           56.1787711768979,
           56.23112704587003,
           56.28348291484217,
           56.33583878381431,
           56.388194652786446,
           56.44055052175858,
           56.49290639073072,
           56.54526225970285,
           56.597618128674995,
           56.64997399764713,
           56.702329866619266,
           56.75468573559141,
           56.80704160456354,
           56.85939747353568,
           56.911753342507815,
           56.96410921147995,
           57.01646508045209,
           57.06882094942422,
           57.121176818396364,
           57.1735326873685,
           57.225888556340635,
           57.27824442531278,
           57.33060029428491,
           57.38305000291506,
           57.43596891354329,
           57.48888782417152,
           57.53549966951357,
           57.5808501017984,
           57.62621797333658,
           57.67160328405158,
           57.716988594766576,
           57.762373905481574,
           57.807759216196565,
           57.853144526911564,
           57.89852983762657,
           57.94391514834156,
           57.98930045905656,
           58.034685769771556,
           58.080071080486555,
           58.12545639120155,
           58.17084170191655,
           58.21622701263155,
           58.26161232334654,
           58.30699763406154,
           58.352382944776544,
           58.39776825549154,
           58.44315356620653,
           58.48853887692153,
           58.53392418763653,
           58.57930949835153,
           58.624694809066526,
           58.670080119781524,
           58.71546543049652,
           58.76085074121151,
           58.80623605192652,
           58.85162136264151,
           58.897006673356515,
           58.942391984071506,
           58.987777294786504,
           59.0331626055015,
           59.07854791621649,
           59.1239332269315,
           59.1693185376465,
           59.214703848361495,
           59.260089159076486,
           59.30547446979149,
           59.35085978050648,
           59.39624509122149,
           59.441630401936486,
           59.487015712651484,
           59.532401023366475,
           59.57778633408148,
           59.62317164479647,
           59.66855695551148,
           59.713942266226475,
           59.75932757694146,
           59.804712887656464,
           59.85009819837146,
           59.89548350908645,
           59.94086881980145,
           59.98625413051646,
           60.03163944123145,
           60.077024751946446,
           60.122410062661444,
           60.16779537337645,
           60.21318068409144,
           60.25856599480644,
           60.30395130552144,
           60.34933661623644,
           60.39472192695143,
           60.440107237666425,
           60.48549254838143,
           60.53087785909642,
           60.576263169811426,
           60.62164848052642,
           60.66703379124141,
           60.712419101956414,
           60.757804412671405,
           60.80318972338641,
           60.8485750341014,
           60.8939603448164,
           60.9393456555314,
           60.984730966246396,
           61.030116276961394,
           61.07550158767639,
           61.12088689839139,
           61.16627220910639,
           61.21165751982139,
           61.25704283053638,
           61.30162613267803,
           61.34580843053299,
           61.389990728387964,
           61.43417302624293,
           61.4783553240979,
           61.522537621952864,
           61.56671991980783,
           61.6109022176628,
           61.65508451551777,
           61.69926681337273,
           61.74346392983814,
           61.78766252809804,
           61.83186112635794,
           61.876059724617846,
           61.92025832287774,
           61.964456921137646,
           62.00865551939755,
           62.05285411765745,
           62.09705271591735,
           62.141251314177254,
           62.18544991243715,
           62.229648510697054,
           62.27384710895695,
           62.31804570721686,
           62.362244305476764,
           62.40644290373666,
           62.45064150199656,
           62.49484010025646,
           62.539038698516364,
           62.583237296776254,
           62.627435895036164,
           62.67163449329607,
           62.715833091555965,
           62.76003168981587,
           62.80423028807577,
           62.848428886335675,
           62.89262748459558,
           62.936826082855475,
           62.98102468111538,
           63.02522327937528,
           63.06942187763517,
           63.113620475895075,
           63.15781907415498,
           63.20201767241488,
           63.24621627067478,
           63.29041486893468,
           63.334613467194586,
           63.37881206545449,
           63.42301066371439,
           63.46720926197429,
           63.511407860234186,
           63.55560645849409,
           63.59980505675399,
           63.6440036550139,
           63.68820225327379,
           63.7324008515337,
           63.77659944979359,
           63.820798048053504,
           63.864996646313394,
           63.9091952445733,
           63.953393842833194,
           63.997592441093104,
           64.041791039353,
           64.08598963761291,
           64.13018823587281,
           64.1743868341327,
           64.21858543239262,
           64.26278403065251,
           64.30698262891241,
           64.3511812271723,
           64.39537982543222,
           64.43957842369211,
           64.48377702195202,
           64.52797562021192,
           64.57217421847182,
           64.61637281673173,
           64.66057141499162,
           64.70477001325152,
           64.74896861151143,
           64.79316720977133,
           64.83736580803122,
           64.88156440629113,
           64.92576300455103,
           64.80532182367233,
           64.52024086365505,
           64.23515990363778,
           63.95007894362052,
           63.66499798360323,
           63.37991702358597,
           63.0948360635687,
           62.80975510355141,
           62.524674143534114,
           62.239593183516874,
           61.954512223499584,
           61.6694312634823,
           61.384350303465034,
           61.099269343447766,
           60.81418838343048,
           60.529107423413215,
           60.24402646339595,
           59.95894550337866,
           59.6738645433614,
           59.388783583344136,
           59.10370262332684,
           58.81862166330956,
           58.53354070329232,
           58.24845974327503,
           57.96337878325774,
           57.65221958604215,
           57.33141804112098,
           57.01061649619979,
           56.68981495127862,
           56.36901340635745,
           56.04821186143626,
           55.72741031651507,
           55.40660877159393,
           55.085807226672735,
           54.76500568175154,
           54.44420413683037,
           54.1234025919092,
           53.80260104698801,
           53.48179950206684,
           53.16099795714568,
           52.840196412224486,
           52.519394867303326,
           52.19859332238215,
           51.87779177746096,
           51.55699023253976,
           51.23618868761863,
           50.91538714269744,
           50.59458559777624,
           50.27378405285508,
           49.9529825079339,
           49.63218096301271,
           49.31137941809155,
           48.99057787317038,
           48.669776328249185,
           48.34897478332799,
           48.02817323840685,
           47.70737169348566,
           47.386570148564466,
           47.065768603643306,
           46.74496705872214,
           46.42416551380094,
           46.10336396887977,
           45.78256242395861,
           45.46176087903741,
           45.140959334116246,
           44.82015778919508,
           44.49935624427388,
           44.17855469935269,
           43.85775315443155,
           43.53695160951035,
           43.216150064589165,
           42.895348519668,
           42.57454697474682,
           42.253745429825635,
           41.93294388490447,
           41.6121423399833,
           41.29134079506211,
           40.970539250140945,
           40.64973770521978,
           40.32893616029858,
           40.00813461537739,
           39.68733307045622,
           39.36653152553505,
           39.0368054915823,
           38.68923047956646,
           38.34165546755061,
           37.99408045553473,
           37.64650544351889,
           37.298930431503045,
           36.95135541948717,
           36.60378040747129,
           36.25620539545548,
           35.9086303834396,
           35.56105537142373,
           35.21348035940788,
           34.86590534739204,
           34.51833033537616,
           34.17075532336032,
           33.82318031134447,
           33.475605299328606,
           33.128030287312754,
           32.780455275296916,
           32.43288026328104,
           32.085305251265154,
           31.737730239249316,
           31.390155227233475,
           31.045519101374,
           30.70613109517042,
           30.366743088966835,
           30.027355082763222,
           29.68796707655964,
           29.34857907035606,
           29.00919106415245,
           28.669803057948833,
           28.330415051745284,
           27.991027045541674,
           27.651639039338058,
           27.312251033134473,
           26.972863026930895,
           26.633475020727282,
           26.2940870145237,
           25.954699008320123,
           25.615311002116503,
           25.27592299591292,
           24.93653498970934,
           24.59714698350573,
           24.257758977302117,
           23.918370971098536,
           23.57898296489495,
           23.239594958691338,
           22.90020695248776,
           22.560818946284172,
           22.221430940080563,
           21.88204293387698,
           21.5426549276734,
           21.20326692146979,
           20.86387891526617,
           20.52449090906262,
           20.18510290285901,
           19.845714896655398,
           19.506326890451817,
           19.166938884248232,
           18.827550878044622,
           18.488162871841038,
           18.14877486563746,
           17.809386859433843,
           17.469998853230262,
           17.13061084702668,
           16.791222840823067,
           16.451834834619454,
           16.112446828415905,
           15.773058822212292,
           15.433670816008679,
           15.094282809805096,
           14.754894803601513,
           14.415506797397903,
           14.07611879119432,
           13.73673078499074,
           13.397342778787126,
           13.057954772583512,
           12.718566766379961,
           12.379178760176348,
           12.039790753972735,
           11.700402747769154,
           11.361014741565572,
           11.02162673536196,
           10.722847110478241,
           10.627109392193628,
           10.531371673909016,
           10.4356339556244,
           10.339896237339806,
           10.244158519055194,
           10.148420800770579,
           10.052683082485984,
           9.95694536420137,
           9.861207645916759,
           9.76546992763216,
           9.669732209347547,
           9.573994491062935,
           9.478256772778321,
           9.382519054493725,
           9.286781336209112,
           9.191043617924498,
           9.095305899639904,
           8.99956818135529,
           8.903830463070676,
           8.80809274478608,
           8.712355026501466,
           8.616617308216853,
           8.520879589932257,
           8.425141871647645,
           8.329404153363031,
           8.233666435078419,
           8.137928716793823,
           8.04219099850921,
           7.9464532802245955,
           7.8507155619399995,
           7.754977843655386,
           7.659240125370772,
           7.563502407086177,
           7.467764688801563,
           7.37202697051695,
           7.276289252232337,
           7.180551533947741,
           7.084813815663128,
           6.989076097378514,
           6.893338379093919,
           6.821839045585293,
           6.752292555384854,
           6.6877875458233635,
           6.639140322220555,
           6.590493098617748,
           6.541845875014949,
           6.4931986514121425,
           6.444551427809334,
           6.395904204206526,
           6.347256980603729,
           6.29860975700092,
           6.249962533398112,
           6.201315309795314,
           6.152668086192506,
           6.104020862589699,
           6.055373638986899,
           6.006726415384091,
           5.958079191781285,
           5.909431968178476,
           5.860784744575678,
           5.81213752097287,
           5.763490297370062,
           5.7148430737672635,
           5.666195850164456,
           5.617548626561648,
           5.56890140295885,
           5.520254179356042,
           5.471606955753234,
           5.422959732150436,
           5.374312508547627,
           5.32566528494482,
           5.277018061342012,
           5.228370837739213,
           5.179723614136407,
           5.1310763905335985,
           5.082429166930799,
           5.033781943327991,
           4.985134719725184,
           4.9364874961223855,
           4.887840272519577,
           4.839193048916769,
           4.790545825313962,
           4.7418986017111635
          ],
          [
           53.42521887614693,
           53.477574745119064,
           53.5299306140912,
           53.58228648306334,
           53.63464235203547,
           53.68699822100761,
           53.739354089979756,
           53.791709958951884,
           53.84406582792403,
           53.896421696896155,
           53.9487775658683,
           54.00113343484044,
           54.05348930381258,
           54.10584517278471,
           54.15820104175685,
           54.21055691072898,
           54.262912779701125,
           54.31526864867325,
           54.36762451764539,
           54.41998038661753,
           54.47233625558967,
           54.5246921245618,
           54.57704799353394,
           54.62940386250608,
           54.681759731478216,
           54.734115600450345,
           54.786471469422494,
           54.83882733839463,
           54.891183207366765,
           54.9435390763389,
           54.99589494531103,
           55.04825081428318,
           55.100606683255315,
           55.15296255222745,
           55.205318421199586,
           55.25767429017172,
           55.310030159143864,
           55.362386028116,
           55.414741897088135,
           55.46709776606027,
           55.519453635032406,
           55.57180950400454,
           55.624165372976684,
           55.67652124194882,
           55.728877110920955,
           55.78123297989309,
           55.833588848865226,
           55.88594471783737,
           55.9383005868095,
           55.99065645578164,
           56.043012324753775,
           56.09536819372591,
           56.14772406269805,
           56.20007993167019,
           56.252435800642324,
           56.30479166961446,
           56.357147538586595,
           56.40950340755874,
           56.46185927653087,
           56.51421514550301,
           56.566571014475144,
           56.61892688344728,
           56.67128275241942,
           56.72363862139156,
           56.77599449036369,
           56.8287257199148,
           56.88164463054302,
           56.93456354117126,
           56.98748245179948,
           57.04040136242771,
           57.09332027305593,
           57.14623918368416,
           57.19915809431239,
           57.25207700494061,
           57.30499591556884,
           57.35791482619707,
           57.410833736825296,
           57.46375264745352,
           57.51667155808175,
           57.569590468709976,
           57.622509379338204,
           57.675428289966426,
           57.72834720059466,
           57.781266111222884,
           57.82787795656493,
           57.87322838884976,
           57.91857882113458,
           57.9639292534194,
           58.00927968570423,
           58.05463011798904,
           58.09998055027386,
           58.14533098255869,
           58.19068141484351,
           58.23603184712833,
           58.28138227941315,
           58.32673271169797,
           58.37208314398279,
           58.41743357626761,
           58.46278400855243,
           58.50813444083725,
           58.55348487312208,
           58.598835305406894,
           58.64418573772426,
           58.68957104843925,
           58.734956359154246,
           58.780341669869244,
           58.82572698058424,
           58.87111229129924,
           58.91649760201424,
           58.96188291272924,
           59.00726822344423,
           59.05265353415923,
           59.098038844874225,
           59.14342415558923,
           59.18880946630422,
           59.23419477701922,
           59.27958008773422,
           59.32496539844921,
           59.37035070916421,
           59.41573601987921,
           59.46112133059421,
           59.5065066413092,
           59.5518919520242,
           59.597277262739205,
           59.64266257345419,
           59.688047884169194,
           59.7334331948842,
           59.77881850559919,
           59.82420381631419,
           59.86958912702919,
           59.91497443774418,
           59.96035974845918,
           60.005745059174174,
           60.05113036988918,
           60.09651568060417,
           60.141900991319176,
           60.18728630203416,
           60.232671612749165,
           60.27805692346416,
           60.323442234179154,
           60.36882754489415,
           60.41421285560915,
           60.459598166324156,
           60.50498347703915,
           60.55036878775415,
           60.59575409846914,
           60.64113940918414,
           60.68652471989914,
           60.73191003061414,
           60.777295341329136,
           60.82268065204413,
           60.86806596275913,
           60.913451273474124,
           60.95883658418912,
           61.00422189490412,
           61.04960720561912,
           61.094992516334116,
           61.14037782704911,
           61.18576313776411,
           61.23114844847911,
           61.2765337591941,
           61.3219190699091,
           61.367304380624105,
           61.4126896913391,
           61.458075002054095,
           61.50346031276909,
           61.54884562348409,
           61.59342892562573,
           61.6376112234807,
           61.68179352133567,
           61.72597581919064,
           61.7701581170456,
           61.81434041490057,
           61.85852271275553,
           61.902705010610504,
           61.94688730846546,
           61.99106960632044,
           62.035251904175404,
           62.07943420203037,
           62.12361649988533,
           62.167798797740296,
           62.21198109559526,
           62.25616339345024,
           62.300345691305196,
           62.34452798916017,
           62.388710287015144,
           62.43289258487011,
           62.47707488272506,
           62.52125718058004,
           62.565439478435,
           62.60962177628997,
           62.65380407414493,
           62.6979863719999,
           62.74216866985488,
           62.786350967709836,
           62.83053326556481,
           62.87471556341977,
           62.91889786127473,
           62.96308015912972,
           63.00726245698468,
           63.05144475483963,
           63.09562705269461,
           63.13980935054957,
           63.18399164840454,
           63.2281739462595,
           63.27235624411447,
           63.316538541969436,
           63.360720839824396,
           63.40490313767937,
           63.44908543553433,
           63.49326773338931,
           63.537450031244276,
           63.581632329099236,
           63.6258146269542,
           63.66999692480917,
           63.71417922266414,
           63.7583615205191,
           63.802543818374076,
           63.84672611622904,
           63.89090841408401,
           63.935090711938976,
           63.97927300979394,
           64.0234553076489,
           64.06763760550388,
           64.11181990335884,
           64.15600220121381,
           64.20018449906877,
           64.24436679692374,
           64.28854909477872,
           64.33273139263368,
           64.37691369048865,
           64.42109598834361,
           64.46527828619857,
           64.50946058405354,
           64.5536428819085,
           64.59782517976348,
           64.64200747761845,
           64.68618977547341,
           64.73037207332838,
           64.77455437118334,
           64.81873666903832,
           64.86291896689328,
           64.90710126474823,
           64.95128356260322,
           64.99546586045818,
           65.03964815831314,
           65.08384527466609,
           65.12804387292599,
           65.17224247118588,
           65.21644106944579,
           65.09599988856708,
           64.81048059692296,
           64.48967905200178,
           64.16887750708061,
           63.84807596215941,
           63.52727441723825,
           63.206472872317086,
           62.88567132739589,
           62.564869782474695,
           62.244109696790915,
           61.92338810819972,
           61.60266651960851,
           61.281944931017335,
           60.96122334242617,
           60.64050175383497,
           60.3197801652438,
           59.999058576652615,
           59.67833698806142,
           59.35761539947025,
           59.03689381087908,
           58.71617222228787,
           58.39545063369667,
           58.07472904510553,
           57.75400745651432,
           57.43328586792312,
           57.11256427933195,
           56.79184269074078,
           56.47112110214957,
           56.1503995135584,
           55.82967792496723,
           55.50895633637602,
           55.18823474778482,
           54.86751315919368,
           54.54679157060248,
           54.22606998201127,
           53.9053483934201,
           53.58462680482893,
           53.26390521623773,
           52.943183627646555,
           52.622462039055385,
           52.30174045046418,
           51.98101886187301,
           51.660297273281834,
           51.33957568469063,
           51.01885409609943,
           50.69813250750829,
           50.37741091891708,
           50.05668933032588,
           49.73596774173471,
           49.415246153143535,
           49.09452456455233,
           48.77380297596116,
           48.45308138736999,
           48.13235979877878,
           47.81163821018758,
           47.49091662159644,
           47.17019503300523,
           46.84947344441404,
           46.52875185582287,
           46.20803026723169,
           45.887308678640494,
           45.56658709004932,
           45.24586550145814,
           44.925143912866936,
           44.60442232427577,
           44.2837007356846,
           43.96297914709339,
           43.642257558502195,
           43.32153596991105,
           43.00081438131984,
           42.680092792728644,
           42.359371204137474,
           42.038649615546305,
           41.71792802695509,
           41.397206438363924,
           41.076484849772754,
           40.75576326118154,
           40.43504167259037,
           40.1143200839992,
           39.79359849540799,
           39.4728769068168,
           39.152155318225624,
           38.831433729634455,
           38.50625800634775,
           38.17217401367011,
           37.83809002099246,
           37.50400602831478,
           37.16992203563713,
           36.83583804295948,
           36.5017540502818,
           36.16767005760411,
           35.8335860649265,
           35.499502072248816,
           35.16541807957113,
           34.831334086893484,
           34.497250094215836,
           34.16316610153816,
           33.82908210886051,
           33.494998116182856,
           33.16091412350517,
           32.82683013082753,
           32.492746138149876,
           32.1586621454722,
           31.82457815279452,
           31.490494160116867,
           31.156410167439216,
           30.822326174761535,
           30.488242182083887,
           30.15415818940624,
           29.82007419672856,
           29.48599020405091,
           29.151906211373262,
           28.817822218695575,
           28.4837382260179,
           28.149654233340282,
           27.815570240662602,
           27.481486247984925,
           27.147402255307274,
           26.813318262629622,
           26.479234269951945,
           26.14515027727429,
           25.81106628459664,
           25.472664250011377,
           25.133276243807792,
           24.793888237604214,
           24.4545002314006,
           24.11511222519699,
           23.775724218993407,
           23.436336212789826,
           23.096948206586212,
           22.75756020038263,
           22.418172194179046,
           22.078784187975437,
           21.739396181771852,
           21.40000817556827,
           21.06062016936466,
           20.721232163161048,
           20.381844156957495,
           20.042456150753882,
           19.70306814455027,
           19.363680138346687,
           19.024292132143106,
           18.684904125939493,
           18.345516119735912,
           18.00612811353233,
           17.666740107328714,
           17.327352101125136,
           16.98796409492155,
           16.648576088717938,
           16.30918808251433,
           15.969800076310776,
           15.630412070107162,
           15.291024063903551,
           14.951636057699968,
           14.612248051496387,
           14.272860045292774,
           13.933472039089192,
           13.594084032885611,
           13.254696026681998,
           12.915308020478385,
           12.575920014274836,
           12.236532008071219,
           11.897144001867607,
           11.557755995664026,
           11.218367989460443,
           10.878979983256832,
           10.580200358373114,
           10.4844626400885,
           10.388724921803888,
           10.292987203519274,
           10.197249485234678,
           10.101511766950065,
           10.005774048665451,
           9.910036330380855,
           9.814298612096241,
           9.71856089381163,
           9.622823175527033,
           9.527085457242421,
           9.431347738957806,
           9.335610020673194,
           9.239872302388596,
           9.144134584103984,
           9.07177366950652,
           9.002227179306095,
           8.932680689105656,
           8.863134198905218,
           8.793587708704791,
           8.724041218504354,
           8.654494728303915,
           8.58494823810349,
           8.51540174790305,
           8.445855257702613,
           8.376308767502174,
           8.30676227730175,
           8.237215787101311,
           8.167669296900872,
           8.098122806700447,
           8.028576316500008,
           7.95902982629957,
           7.889483336099145,
           7.819936845898707,
           7.750390355698268,
           7.680843865497829,
           7.611297375297404,
           7.541750885096967,
           7.4722043948965275,
           7.4026579046961025,
           7.333111414495664,
           7.263564924295226,
           7.1940184340948,
           7.124471943894362,
           7.054925453693922,
           6.985378963493497,
           6.91583247329306,
           6.846285983092621,
           6.776739492892183,
           6.707193002691758,
           6.637646512491319,
           6.568100022290881,
           6.498553532090455,
           6.429007041890017,
           6.359460551689578,
           6.289914061489152,
           6.220367571288714,
           6.150821081088276,
           6.081274590887838,
           6.011728100687412,
           5.942181610486974,
           5.872635120286535,
           5.803088630086109,
           5.733542139885671,
           5.663995649685233,
           5.594449159484808,
           5.524902669284369,
           5.461085157568074,
           5.412437933965275,
           5.363790710362467,
           5.315143486759659,
           5.266496263156851,
           5.217849039554053,
           5.169201815951245,
           5.120554592348437,
           5.071907368745639,
           5.023260145142832,
           4.974612921540023,
           4.925965697937224,
           4.877318474334417,
           4.828671250731609,
           4.7800240271288015,
           4.731376803526002
          ],
          [
           53.70830697577992,
           53.76066284475205,
           53.81301871372419,
           53.86537458269633,
           53.91773045166846,
           53.970086320640604,
           54.02244218961273,
           54.074798058584875,
           54.12715392755702,
           54.179509796529146,
           54.23186566550129,
           54.28422153447342,
           54.33657740344556,
           54.3889332724177,
           54.44128914138983,
           54.49364501036197,
           54.5460008793341,
           54.598356748306244,
           54.65071261727839,
           54.703068486250515,
           54.75542435522266,
           54.807780224194794,
           54.86013609316693,
           54.912491962139065,
           54.96484783111121,
           55.01720370008334,
           55.06955956905547,
           55.12191543802762,
           55.17427130699975,
           55.226627175971885,
           55.27898304494403,
           55.331338913916156,
           55.383694782888305,
           55.436050651860434,
           55.48840652083257,
           55.54076238980471,
           55.59311825877684,
           55.64547412774899,
           55.69782999672112,
           55.75018586569326,
           55.8025417346654,
           55.85489760363754,
           55.90725347260967,
           55.95960934158181,
           56.01196521055394,
           56.06432107952608,
           56.116676948498224,
           56.16903281747035,
           56.22148252628632,
           56.274401436914545,
           56.327320347542766,
           56.380239258170995,
           56.433158168799224,
           56.486077079427446,
           56.53899599005568,
           56.5919149006839,
           56.64483381131214,
           56.69775272194036,
           56.75067163256858,
           56.80359054319681,
           56.85650945382503,
           56.90942836445326,
           56.9623472750815,
           57.01526618570972,
           57.06818509633794,
           57.12110400696618,
           57.1740229175944,
           57.226941828222635,
           57.27986073885086,
           57.33277964947908,
           57.38569856010731,
           57.43861747073554,
           57.491536381363765,
           57.54445529199199,
           57.597374202620216,
           57.650293113248445,
           57.703212023876674,
           57.756130934504895,
           57.809049845133124,
           57.86196875576135,
           57.91488766638958,
           57.967806577017804,
           58.02072548764604,
           58.07364439827426,
           58.12025624361631,
           58.16560667590113,
           58.21095710818595,
           58.25630754047078,
           58.301657972755606,
           58.34700840504041,
           58.39235883732524,
           58.43770926961007,
           58.48305970189489,
           58.52841013417971,
           58.57376056646453,
           58.61911099874935,
           58.66446143103417,
           58.70981186331899,
           58.75516229560381,
           58.80051272788863,
           58.84586316017346,
           58.89121359245827,
           58.9365640247431,
           58.98191445702792,
           59.02726488931275,
           59.07261532159756,
           59.11796575388239,
           59.16331618616721,
           59.20866661845203,
           59.25401705073685,
           59.29936748302167,
           59.34471791530649,
           59.39006834759131,
           59.43541877987614,
           59.48076921216096,
           59.52611964444577,
           59.5714700767306,
           59.61682050901542,
           59.66217094130024,
           59.707538812826925,
           59.75292412354191,
           59.798309434256915,
           59.84369474497191,
           59.88908005568691,
           59.9344653664019,
           59.9798506771169,
           60.025235987831906,
           60.0706212985469,
           60.116006609261895,
           60.16139191997689,
           60.20677723069189,
           60.25216254140689,
           60.29754785212189,
           60.342933162836886,
           60.38831847355188,
           60.43370378426688,
           60.47908909498187,
           60.52447440569688,
           60.56985971641187,
           60.61524502712687,
           60.660630337841866,
           60.70601564855686,
           60.75140095927186,
           60.79678626998685,
           60.84217158070186,
           60.88755689141685,
           60.93294220213185,
           60.97832751284685,
           61.02371282356185,
           61.06909813427684,
           61.11448344499184,
           61.15986875570684,
           61.20525406642184,
           61.250639377136835,
           61.29602468785184,
           61.341409998566824,
           61.38679530928183,
           61.43218061999683,
           61.47756593071182,
           61.52295124142681,
           61.568336552141815,
           61.61372186285681,
           61.65910717357181,
           61.7044924842868,
           61.74987779500181,
           61.7952631057168,
           61.840648416431804,
           61.88523171857345,
           61.92941401642841,
           61.973596314283384,
           62.01777861213834,
           62.06196090999332,
           62.10614320784828,
           62.15032550570325,
           62.19450780355821,
           62.238690101413184,
           62.28287239926814,
           62.32705469712312,
           62.371236994978084,
           62.41541929283305,
           62.45960159068802,
           62.50378388854298,
           62.54796618639795,
           62.59214848425292,
           62.63633078210788,
           62.68051307996285,
           62.724695377817824,
           62.768877675672776,
           62.81305997352776,
           62.85724227138272,
           62.90142456923769,
           62.94560686709265,
           62.98978916494761,
           63.03397146280258,
           63.07815376065755,
           63.122336058512516,
           63.16651835636748,
           63.21070065422245,
           63.25488295207742,
           63.29906524993239,
           63.34324754778734,
           63.38742984564232,
           63.431612143497276,
           63.475794441352264,
           63.51997673920722,
           63.56415903706218,
           63.60834133491715,
           63.652523632772116,
           63.69670593062708,
           63.74088822848205,
           63.78507052633702,
           63.82925282419198,
           63.873435122046956,
           63.91761741990191,
           63.96179971775689,
           64.00598201561186,
           64.05016431346682,
           64.0943466113218,
           64.13852890917676,
           64.18271120703173,
           64.22689350488669,
           64.27107580274165,
           64.31525810059662,
           64.35944039845158,
           64.40362269630656,
           64.44780499416152,
           64.49198729201649,
           64.53616958987145,
           64.58035188772642,
           64.62453418558138,
           64.6680106045762,
           64.71131055470455,
           64.75461050483288,
           64.79791045496123,
           64.84121040508957,
           64.88451035521791,
           64.92781030534626,
           64.9711102554746,
           65.01441020560294,
           65.05771015573127,
           65.10101010585961,
           65.14431005598796,
           65.1876100061163,
           65.23090995624464,
           65.27420990637299,
           65.31750985650132,
           65.36080980662966,
           65.404109756758,
           65.44740970688635,
           65.49070965701469,
           65.34047548114843,
           64.99670717928758,
           64.65293887742675,
           64.30917057556593,
           63.96540227370507,
           63.62163397184425,
           63.27786566998343,
           62.93409736812257,
           62.59032906626172,
           62.24656076440093,
           61.90279246254007,
           61.559024160679215,
           61.215255858818395,
           60.871487556957575,
           60.52771925509672,
           60.18395095323589,
           59.840182651375066,
           59.49641434951421,
           59.15264604765339,
           58.808877745792564,
           58.46510944393171,
           58.121341142070854,
           57.77757284021006,
           57.433804538349214,
           57.09003623648836,
           56.74626793462754,
           56.402499632766705,
           56.05873133090586,
           55.71496302904503,
           55.37119472718421,
           55.027426425323355,
           54.68365812346249,
           54.3398898216017,
           54.017053812754234,
           53.69633222416303,
           53.37561063557186,
           53.05488904698068,
           52.734167458389486,
           52.41344586979831,
           52.09272428120714,
           51.772002692615935,
           51.451281104024766,
           51.130559515433596,
           50.809837926842384,
           50.48911633825119,
           50.16839474966004,
           49.84767316106884,
           49.52695157247764,
           49.20622998388646,
           48.88550839529529,
           48.564786806704085,
           48.24406521811291,
           47.92334362952174,
           47.60262204093054,
           47.28190045233934,
           46.961178863748195,
           46.64045727515699,
           46.31973568656579,
           45.99901409797462,
           45.67829250938345,
           45.35757092079224,
           45.03684933220107,
           44.7161277436099,
           44.39540615501869,
           44.07468456642753,
           43.75396297783635,
           43.433241389245154,
           43.11251980065394,
           42.7917982120628,
           42.4710766234716,
           42.1503550348804,
           41.82963344628923,
           41.50891185769805,
           41.18819026910685,
           40.86746868051568,
           40.54674709192451,
           40.226025503333304,
           39.905303914742134,
           39.58458232615096,
           39.26386073755975,
           38.943139148968555,
           38.62241756037738,
           38.3016959717862,
           37.97652024849951,
           37.642436255821856,
           37.308352263144215,
           36.97426827046654,
           36.640184277788876,
           36.306100285111235,
           35.972016292433544,
           35.63793229975587,
           35.303848307078255,
           34.96976431440057,
           34.63568032172289,
           34.301596329045246,
           33.96751233636759,
           33.63342834368991,
           33.299344351012266,
           32.96526035833461,
           32.63117636565693,
           32.297092372979286,
           31.963008380301634,
           31.628924387623957,
           31.294840394946274,
           30.960756402268622,
           30.62667240959097,
           30.292588416913297,
           29.958504424235645,
           29.624420431557997,
           29.290336438880317,
           28.956252446202672,
           28.622168453525013,
           28.288084460847333,
           27.954000468169653,
           27.619916475492037,
           27.285832482814357,
           26.951748490136676,
           26.617664497459028,
           26.283580504781376,
           25.949496512103696,
           25.615412519426044,
           25.2813285267484,
           24.94724453407072,
           24.613160541393064,
           24.279076548715416,
           23.94499255603774,
           23.61090856336006,
           23.276824570682404,
           22.94274057800476,
           22.608656585327076,
           22.274572592649427,
           21.94048859997178,
           21.6064046072941,
           21.272320614616447,
           20.9382366219388,
           20.60415262926112,
           20.27006863658344,
           19.935984643905822,
           19.60190065122814,
           19.267816658550462,
           18.933732665872814,
           18.59964867319516,
           18.26556468051748,
           17.93148068783983,
           17.597396695162182,
           17.2633127024845,
           16.92922870980685,
           16.5951447171292,
           16.26106072445152,
           15.933174943581538,
           15.607865963234044,
           15.282556982886492,
           14.957248002538938,
           14.631939022191414,
           14.306630041843889,
           13.981321061496335,
           13.656012081148813,
           13.330703100801287,
           13.005394120453733,
           12.68008514010618,
           12.354776159758686,
           12.02946717941113,
           11.704158199063578,
           11.378849218716054,
           11.05354023836853,
           10.728231258020974,
           10.442203877554798,
           10.352584496495142,
           10.262965115435485,
           10.173345734375829,
           10.08372635331619,
           9.994106972256533,
           9.904487591196876,
           9.814868210137238,
           9.725248829077582,
           9.635629448017927,
           9.546010066958285,
           9.45639068589863,
           9.366771304838974,
           9.277151923779316,
           9.187532542719678,
           9.106611449804374,
           9.037064959603935,
           8.96751846940351,
           8.89797197920307,
           8.828425489002633,
           8.758878998802206,
           8.689332508601769,
           8.61978601840133,
           8.550239528200905,
           8.480693038000465,
           8.411146547800026,
           8.341600057599589,
           8.272053567399164,
           8.202507077198726,
           8.132960586998287,
           8.063414096797862,
           7.993867606597423,
           7.9243211163969836,
           7.8547746261965585,
           7.785228135996122,
           7.715681645795684,
           7.646135155595244,
           7.576588665394819,
           7.50704217519438,
           7.437495684993942,
           7.367949194793516,
           7.2984027045930775,
           7.228856214392639,
           7.159309724192214,
           7.089763233991776,
           7.020216743791337,
           6.9506702535909115,
           6.881123763390473,
           6.811577273190036,
           6.742030782989597,
           6.672484292789171,
           6.602937802588733,
           6.533391312388295,
           6.46384482218787,
           6.394298331987431,
           6.324751841786993,
           6.255205351586567,
           6.185658861386129,
           6.116112371185691,
           6.046565880985253,
           5.977019390784827,
           5.907472900584389,
           5.83792641038395,
           5.768379920183524,
           5.698833429983086,
           5.629286939782647,
           5.559740449582222,
           5.490193959381783,
           5.420647469181346,
           5.368200988159265,
           5.321972748431627,
           5.275744508703985,
           5.2295162689763455,
           5.183288029248713,
           5.137059789521073,
           5.090831549793433,
           5.044603310065801,
           4.998375070338161,
           4.952146830610521,
           4.905918590882889,
           4.859690351155249,
           4.813462111427609,
           4.767233871699968,
           4.7210056319723375
          ],
          [
           53.991395075412896,
           54.04375094438503,
           54.09610681335716,
           54.14846268232931,
           54.20081855130144,
           54.25317442027358,
           54.305530289245716,
           54.357886158217845,
           54.410242027189994,
           54.46259789616212,
           54.514953765134265,
           54.5673096341064,
           54.61966550307854,
           54.67202137205067,
           54.724377241022815,
           54.77673310999495,
           54.829088978967086,
           54.88144484793922,
           54.933800716911364,
           54.9861565858835,
           55.038512454855635,
           55.09086832382778,
           55.1432241927999,
           55.19558006177205,
           55.24793593074418,
           55.30029179971632,
           55.35264766868846,
           55.40500353766059,
           55.45735940663273,
           55.50971527560487,
           55.562071144577004,
           55.61442701354915,
           55.667158243286046,
           55.720077153914275,
           55.772996064542504,
           55.82591497517073,
           55.878833885798954,
           55.931752796427176,
           55.98467170705541,
           56.037590617683634,
           56.09050952831186,
           56.14342843894009,
           56.19634734956831,
           56.24926626019655,
           56.30218517082477,
           56.35510408145299,
           56.40802299208123,
           56.46094190270945,
           56.51386081333767,
           56.56677972396591,
           56.61969863459413,
           56.67261754522236,
           56.72553645585059,
           56.77845536647881,
           56.831374277107045,
           56.88429318773527,
           56.93721209836349,
           56.990131008991725,
           57.043049919619946,
           57.095968830248175,
           57.1488877408764,
           57.201806651504626,
           57.25472556213286,
           57.30764447276108,
           57.360563383389305,
           57.413482294017534,
           57.466401204645756,
           57.519320115273985,
           57.57223902590222,
           57.62515793653044,
           57.67807684715867,
           57.7309957577869,
           57.78391466841513,
           57.83683357904335,
           57.88975248967158,
           57.94267140029981,
           57.99559031092804,
           58.04850922155626,
           58.10142813218449,
           58.15434704281272,
           58.20726595344094,
           58.26018486406916,
           58.3131037746974,
           58.366022685325625,
           58.412634530667674,
           58.457984962952494,
           58.503335395237315,
           58.548685827522135,
           58.59403625980696,
           58.63938669209178,
           58.684737124376596,
           58.730087556661424,
           58.775437988946244,
           58.82078842123107,
           58.86613885351589,
           58.91148928580071,
           58.95683971808553,
           59.00219015037035,
           59.047540582655174,
           59.092891014939994,
           59.138241447224814,
           59.18359187950964,
           59.22894231179446,
           59.27429274407929,
           59.319643176364096,
           59.36499360864892,
           59.41034404093375,
           59.45569447321857,
           59.50104490550339,
           59.54639533778821,
           59.59174577007303,
           59.63709620235785,
           59.68244663464267,
           59.727797066927494,
           59.773147499212314,
           59.818497931497134,
           59.86384836378196,
           59.90919879606678,
           59.9545492283516,
           59.99989966063642,
           60.04525009292125,
           60.090600525206064,
           60.135950957490884,
           60.18130138977571,
           60.22665182206053,
           60.27200225434535,
           60.31735268663018,
           60.362703118915,
           60.408053551199814,
           60.453403983484634,
           60.498754415769454,
           60.54410484805428,
           60.5894552803391,
           60.634805712623915,
           60.68015614490874,
           60.72550657721458,
           60.77089188792957,
           60.81627719864458,
           60.861662509359576,
           60.90704782007457,
           60.952433130789565,
           60.99781844150456,
           61.04320375221956,
           61.08858906293456,
           61.133974373649565,
           61.179359684364556,
           61.224744995079554,
           61.27013030579455,
           61.31551561650954,
           61.36090092722455,
           61.40628623793954,
           61.45167154865454,
           61.49705685936954,
           61.542442170084534,
           61.58782748079953,
           61.63321279151453,
           61.67859810222953,
           61.72398341294452,
           61.76936872365952,
           61.814754034374516,
           61.860139345089515,
           61.90552465580451,
           61.95090996651952,
           61.99629527723451,
           62.04168058794951,
           62.087065898664505,
           62.1324512093795,
           62.17703451152115,
           62.221216809376116,
           62.26539910723109,
           62.30958140508604,
           62.353763702941016,
           62.39794600079599,
           62.44212829865096,
           62.486310596505916,
           62.53049289436088,
           62.57467519221585,
           62.61885749007082,
           62.66303978792578,
           62.70722208578076,
           62.75140438363572,
           62.79558668149069,
           62.83976897934565,
           62.88395127720062,
           62.92813357505559,
           62.972315872910556,
           63.016498170765516,
           63.06068046862048,
           63.10486276647546,
           63.14904506433042,
           63.19322736218538,
           63.237409660040356,
           63.28159195789531,
           63.32577425575029,
           63.369956553605256,
           63.41413885146023,
           63.45832114931519,
           63.502503447170156,
           63.54668574502512,
           63.59086804288009,
           63.63505034073505,
           63.67923263859003,
           63.72341493644498,
           63.767597234299956,
           63.81177953215492,
           63.85596183000988,
           63.90014412786485,
           63.94432642571982,
           63.98808015435003,
           64.03138010447836,
           64.07468005460672,
           64.11798000473506,
           64.16127995486339,
           64.20457990499173,
           64.24787985512008,
           64.29117980524842,
           64.33447975537676,
           64.3777797055051,
           64.42107965563345,
           64.46437960576179,
           64.50767955589012,
           64.55097950601848,
           64.59427945614682,
           64.63757940627514,
           64.68087935640351,
           64.72417930653184,
           64.76747925666018,
           64.81077920678852,
           64.85407915691685,
           64.89737910704521,
           64.94067905717354,
           64.98397900730188,
           65.02727895743023,
           65.07057890755857,
           65.11387885768691,
           65.15717880781526,
           65.2004787579436,
           65.24377870807194,
           65.28707865820027,
           65.33037860832862,
           65.37367855845696,
           65.4169785085853,
           65.46027845871365,
           65.50357840884197,
           65.54687835897033,
           65.59017830909866,
           65.63347825922702,
           65.67677820935535,
           65.72007815948369,
           65.76337810961203,
           65.61314393374577,
           65.26937563188491,
           64.92560733002409,
           64.58183902816327,
           64.23807072630241,
           63.89430242444159,
           63.55053412258077,
           63.206765820719916,
           62.86299751885906,
           62.51922921699827,
           62.17546091513742,
           61.831692613276566,
           61.48792431141574,
           61.14415600955491,
           60.80038770769406,
           60.45661940583324,
           60.11285110397241,
           59.769082802111555,
           59.425314500250735,
           59.08154619838991,
           58.73777789652905,
           58.394009594668205,
           58.050241292807414,
           57.70647299094655,
           57.362704689085696,
           57.018936387224876,
           56.67516808536405,
           56.3313997835032,
           55.98763148164237,
           55.64386317978155,
           55.30009487792069,
           54.95632657605984,
           54.612558274199046,
           54.2687899723382,
           53.925021670477335,
           53.581253368616515,
           53.23748506675569,
           52.89371676489483,
           52.54994846303402,
           52.20618016117319,
           51.86241185931233,
           51.51864355745152,
           51.174875255590685,
           50.83110695372983,
           50.48733865186898,
           50.14357035000819,
           49.799802048147335,
           49.456033746286465,
           49.112265444425645,
           48.76849714256482,
           48.42472884070398,
           48.08096053884315,
           47.73719223698233,
           47.393423935121476,
           47.04965563326061,
           46.70588733139982,
           46.362119029538974,
           46.01835072767811,
           45.674582425817285,
           45.330814123956465,
           44.98704582209561,
           44.64327752023479,
           44.29950921837396,
           43.95574091651312,
           43.611972614652295,
           43.26820431279147,
           42.924436010930606,
           42.582782042805725,
           42.26206045421458,
           41.94133886562338,
           41.62061727703218,
           41.299895688441,
           40.97917409984983,
           40.65845251125862,
           40.33773092266746,
           40.01700933407628,
           39.69628774548508,
           39.3755661568939,
           39.054844568302734,
           38.734122979711536,
           38.41340139112033,
           38.092679802529155,
           37.771958213937985,
           37.44678249065129,
           37.11269849797363,
           36.77861450529599,
           36.444530512618314,
           36.11044651994065,
           35.776362527263004,
           35.44227853458533,
           35.10819454190764,
           34.77411054923003,
           34.44002655655235,
           34.10594256387466,
           33.77185857119702,
           33.43777457851937,
           33.10369058584169,
           32.76960659316404,
           32.43552260048639,
           32.10143860780871,
           31.76735461513106,
           31.43327062245341,
           31.09918662977573,
           30.765102637098046,
           30.43878384536947,
           30.113474865021946,
           29.78816588467439,
           29.46285690432687,
           29.137547923979344,
           28.81223894363179,
           28.48692996328427,
           28.161620982936746,
           27.836312002589192,
           27.51100302224164,
           27.185694041894145,
           26.860385061546587,
           26.535076081199033,
           26.209767100851508,
           25.884458120503986,
           25.559149140156432,
           25.23384015980891,
           24.908531179461388,
           24.583222199113834,
           24.25791321876631,
           23.932604238418786,
           23.60729525807123,
           23.281986277723675,
           22.956677297376153,
           22.631368317028624,
           22.30605933668107,
           21.980750356333548,
           21.655441375986026,
           21.330132395638472,
           21.00482341529095,
           20.679514434943425,
           20.35420545459587,
           20.028896474248313,
           19.703587493900823,
           19.37827851355327,
           19.05296953320572,
           18.72766055285819,
           18.402351572510668,
           18.077042592163114,
           17.751733611815588,
           17.426424631468066,
           17.101115651120512,
           16.77580667077299,
           16.450497690425465,
           16.12518871007791,
           15.799879729730357,
           15.474570749382863,
           15.14926176903531,
           14.823952788687755,
           14.498643808340232,
           14.173334827992706,
           13.848025847645154,
           13.522716867297632,
           13.197407886950106,
           12.872098906602552,
           12.546789926254998,
           12.221480945907501,
           11.89617196555995,
           11.570862985212397,
           11.245554004864871,
           10.92024502451735,
           10.594936044169792,
           10.308908663703615,
           10.21928928264396,
           10.129669901584304,
           10.040050520524648,
           9.950431139465007,
           9.860811758405351,
           9.771192377345695,
           9.681572996286057,
           9.5919536152264,
           9.502334234166744,
           9.412714853107104,
           9.323095472047449,
           9.233476090987791,
           9.143856709928134,
           9.054237328868496,
           8.96461794780884,
           8.874998566749184,
           8.785379185689544,
           8.695759804629887,
           8.606140423570231,
           8.516521042510591,
           8.426901661450936,
           8.337282280391278,
           8.247662899331639,
           8.158043518271983,
           8.068424137212327,
           7.978804756152671,
           7.889185375093031,
           7.799565994033374,
           7.709946612973719,
           7.620327231914079,
           7.530707850854423,
           7.441088469794767,
           7.351469088735127,
           7.26184970767547,
           7.184882315133852,
           7.119554792431067,
           7.054227269728296,
           6.988899747025512,
           6.923572224322728,
           6.858244701619956,
           6.792917178917172,
           6.727589656214389,
           6.662262133511616,
           6.596934610808832,
           6.531607088106048,
           6.466279565403275,
           6.400952042700492,
           6.335624519997707,
           6.282631967427803,
           6.236403727700171,
           6.190175487972532,
           6.14394724824489,
           6.0977190085172595,
           6.051490768789619,
           6.005262529061978,
           5.959034289334347,
           5.912806049606707,
           5.866577809879067,
           5.820349570151427,
           5.774121330423795,
           5.7278930906961545,
           5.681664850968514,
           5.635436611240882,
           5.589208371513243,
           5.542980131785603,
           5.49675189205797,
           5.45052365233033,
           5.40429541260269,
           5.358067172875058,
           5.311838933147419,
           5.265610693419778,
           5.219382453692138,
           5.173154213964506,
           5.126925974236865,
           5.080697734509226,
           5.034469494781593,
           4.988241255053953,
           4.942013015326314,
           4.895784775598681,
           4.8495565358710415,
           4.803328296143402,
           4.75710005641576,
           4.71087181668813
          ],
          [
           54.27448317504588,
           54.326839044018016,
           54.379194912990144,
           54.43155078196229,
           54.48390665093443,
           54.536262519906565,
           54.58861838887869,
           54.64097425785083,
           54.69333012682297,
           54.745685995795114,
           54.79804186476725,
           54.85039773373938,
           54.90275360271153,
           54.955109471683656,
           55.0074653406558,
           55.059915049657555,
           55.11283396028578,
           55.16575287091401,
           55.218671781542234,
           55.27159069217046,
           55.324509602798685,
           55.37742851342691,
           55.43034742405514,
           55.48326633468337,
           55.5361852453116,
           55.58910415593982,
           55.64202306656805,
           55.69494197719628,
           55.74786088782451,
           55.80077979845272,
           55.85369870908096,
           55.90661761970918,
           55.95953653033742,
           56.01245544096564,
           56.06537435159387,
           56.118293262222096,
           56.17121217285032,
           56.22413108347855,
           56.277049994106775,
           56.329968904735,
           56.382887815363226,
           56.435806725991455,
           56.488725636619684,
           56.54164454724791,
           56.594563457876134,
           56.64748236850436,
           56.70040127913259,
           56.753320189760814,
           56.806239100389035,
           56.85915801101727,
           56.91207692164549,
           56.96499583227372,
           57.01791474290195,
           57.07083365353017,
           57.12375256415841,
           57.17667147478663,
           57.229590385414866,
           57.28250929604309,
           57.33542820667132,
           57.38834711729954,
           57.44126602792776,
           57.494184938556,
           57.547103849184225,
           57.60002275981245,
           57.65294167044067,
           57.7058605810689,
           57.75877949169712,
           57.81169840232536,
           57.864617312953584,
           57.917536223581806,
           57.97045513421004,
           58.02337404483826,
           58.07629295546649,
           58.129211866094714,
           58.18213077672295,
           58.23504968735117,
           58.2879685979794,
           58.34088750860762,
           58.39380641923585,
           58.44672532986408,
           58.4996442404923,
           58.55256315112052,
           58.605482061748766,
           58.65840097237699,
           58.70501281771904,
           58.750363250003865,
           58.79571368228868,
           58.841064114573506,
           58.886414546858326,
           58.931764979143146,
           58.977115411427974,
           59.022465843712794,
           59.06781627599761,
           59.113166708282435,
           59.15851714056726,
           59.203867572852076,
           59.249218005136896,
           59.29456843742172,
           59.339918869706544,
           59.385269301991364,
           59.430619734276185,
           59.475970166561005,
           59.52132059884583,
           59.56667103113065,
           59.612021463415466,
           59.65737189570029,
           59.702722327985114,
           59.748072760269935,
           59.793423192554755,
           59.838773624839575,
           59.884124057124396,
           59.929474489409216,
           59.97482492169404,
           60.020175353978864,
           60.065525786263684,
           60.1108762185485,
           60.15622665083332,
           60.20157708311814,
           60.246927515402966,
           60.29227794768779,
           60.337628379972614,
           60.382978812257434,
           60.428329244542255,
           60.473679676827075,
           60.519030109111895,
           60.564380541396716,
           60.609730973681536,
           60.65508140596636,
           60.70043183825118,
           60.745782270536004,
           60.791132702820825,
           60.83648313510565,
           60.88183356739047,
           60.927183999675286,
           60.972534431960106,
           61.01788486424493,
           61.063235296529754,
           61.108585728814575,
           61.15393616109939,
           61.199286593384215,
           61.244637025669036,
           61.289987457953856,
           61.335337890238684,
           61.380688322523504,
           61.42603875480832,
           61.47138918709314,
           61.516739619377965,
           61.562090051662786,
           61.607440483947606,
           61.652790916232426,
           61.69814134851725,
           61.743491780802074,
           61.78885965231724,
           61.83424496303224,
           61.87963027374724,
           61.92501558446224,
           61.97040089517723,
           62.01578620589223,
           62.061171516607224,
           62.10655682732222,
           62.15194213803722,
           62.19732744875222,
           62.242712759467224,
           62.288098070182215,
           62.33348338089721,
           62.37886869161221,
           62.4242540023272,
           62.468837304468856,
           62.51301960232382,
           62.55720190017878,
           62.60138419803375,
           62.64556649588872,
           62.689748793743696,
           62.73393109159865,
           62.77811338945362,
           62.82229568730859,
           62.866477985163556,
           62.91066028301852,
           62.95484258087349,
           62.999024878728456,
           63.04320717658342,
           63.08738947443838,
           63.131571772293356,
           63.17575407014832,
           63.21993636800329,
           63.264118665858255,
           63.308149704123856,
           63.35144965425221,
           63.39474960438054,
           63.438049554508886,
           63.48134950463722,
           63.524649454765566,
           63.56794940489391,
           63.61124935502226,
           63.654549305150596,
           63.69784925527894,
           63.741149205407275,
           63.78444915553561,
           63.827749105663955,
           63.8710490557923,
           63.91434900592064,
           63.95764895604898,
           64.00094890617731,
           64.04424885630567,
           64.08754880643401,
           64.13084875656234,
           64.17414870669069,
           64.21744865681903,
           64.26074860694737,
           64.30404855707572,
           64.34734850720406,
           64.3906484573324,
           64.43394840746075,
           64.47724835758908,
           64.52054830771742,
           64.56384825784576,
           64.60714820797412,
           64.65044815810244,
           64.69374810823078,
           64.73704805835914,
           64.78034800848746,
           64.82364795861582,
           64.86694790874415,
           64.9102478588725,
           64.95354780900084,
           64.99684775912918,
           65.04014770925752,
           65.08344765938587,
           65.1267476095142,
           65.17004755964255,
           65.21334750977088,
           65.25664745989923,
           65.29994741002757,
           65.34324736015591,
           65.38654731028426,
           65.4298472604126,
           65.47314721054093,
           65.51644716066927,
           65.55974711079762,
           65.60304706092596,
           65.6463470110543,
           65.68964696118265,
           65.73294691131099,
           65.77624686143932,
           65.81954681156768,
           65.862846761696,
           65.90614671182435,
           65.94944666195268,
           65.99274661208104,
           66.03604656220938,
           65.88581238634312,
           65.54204408448226,
           65.19827578262144,
           64.85450748076062,
           64.51073917889977,
           64.16697087703893,
           63.823202575178115,
           63.47943427331727,
           63.135665971456405,
           62.79189766959561,
           62.44812936773475,
           62.1043610658739,
           61.760592764013076,
           61.41682446215226,
           61.0730561602914,
           60.72928785843058,
           60.38551955656975,
           60.041751254708906,
           59.69798295284808,
           59.35421465098726,
           59.0104463491264,
           58.666678047265535,
           58.32290974540475,
           57.97914144354389,
           57.63537314168303,
           57.291604839822206,
           56.947836537961386,
           56.604068236100545,
           56.26029993423971,
           55.91653163237889,
           55.57276333051803,
           55.22899502865718,
           54.88522672679639,
           54.54145842493554,
           54.19769012307468,
           53.85392182121386,
           53.510153519353025,
           53.16638521749218,
           52.82261691563136,
           52.47884861377053,
           52.135080311909675,
           51.791312010048856,
           51.44754370818802,
           51.10377540632717,
           50.76000710446632,
           50.41623880260553,
           50.07247050074467,
           49.72870219888382,
           49.384933897023,
           49.04116559516217,
           48.69739729330131,
           48.353628991440495,
           48.00986068957967,
           47.666092387718805,
           47.32232408585796,
           46.978555783997166,
           46.63478748213631,
           46.29101918027546,
           45.947250878414636,
           45.59475645117533,
           45.23312042537398,
           44.87148439957268,
           44.509848373771376,
           44.14821234797004,
           43.78657632216873,
           43.424940296367424,
           43.06330427056608,
           42.70166824476475,
           42.34003221896347,
           41.978396193162126,
           41.61676016736079,
           41.255124141559484,
           40.89348811575818,
           40.531852089956836,
           40.17021606415553,
           39.80858003835422,
           39.446944012552876,
           39.08530798675157,
           38.72367196095027,
           38.36203593514893,
           38.00039990934759,
           37.63876388354629,
           37.27712785774498,
           36.929146308081435,
           36.60847371069349,
           36.28780111330554,
           35.967128515917565,
           35.64645591852962,
           35.32578332114168,
           35.0051107237537,
           34.68443812636573,
           34.36376552897781,
           34.04309293158983,
           33.72242033420186,
           33.40174773681392,
           33.08107513942597,
           32.760402542037994,
           32.43972994465005,
           32.1190573472621,
           31.798384749874128,
           31.477712152486184,
           31.157039555098237,
           30.83636695771026,
           30.515694360322286,
           30.195021762934342,
           29.874349165546395,
           29.553676568158423,
           29.233003970770476,
           28.91233137338253,
           28.591658775994556,
           28.27098617860661,
           27.950313581218666,
           27.62964098383069,
           27.308968386442714,
           26.988295789054796,
           26.667623191666824,
           26.346950594278848,
           26.026277996890904,
           25.705605399502957,
           25.384932802114985,
           25.064260204727038,
           24.74358760733909,
           24.422915009951115,
           24.102242412563175,
           23.781569815175224,
           23.46089721778725,
           23.140224620399277,
           22.81955202301133,
           22.498073103177443,
           22.17276412282989,
           21.847455142482367,
           21.522146162134845,
           21.196837181787288,
           20.871528201439766,
           20.54621922109224,
           20.220910240744686,
           19.895601260397132,
           19.57029228004964,
           19.244983299702085,
           18.919674319354534,
           18.59436533900701,
           18.269056358659483,
           17.943747378311933,
           17.618438397964407,
           17.293129417616885,
           16.96782043726933,
           16.642511456921806,
           16.317202476574284,
           15.991893496226728,
           15.666584515879174,
           15.34127553553168,
           15.015966555184127,
           14.690657574836573,
           14.365348594489049,
           14.040039614141525,
           13.71473063379397,
           13.389421653446448,
           13.064112673098922,
           12.73880369275137,
           12.413494712403816,
           12.088185732056322,
           11.762876751708768,
           11.437567771361214,
           11.11225879101369,
           10.786949810666165,
           10.461640830318611,
           10.175613449852435,
           10.085994068792779,
           9.996374687733123,
           9.906755306673466,
           9.817135925613828,
           9.727516544554168,
           9.637897163494515,
           9.548277782434875,
           9.458658401375219,
           9.369039020315562,
           9.279419639255924,
           9.195620167313153,
           9.13029264461037,
           9.064965121907585,
           8.999637599204814,
           8.93431007650203,
           8.868982553799245,
           8.803655031096474,
           8.73832750839369,
           8.672999985690906,
           8.607672462988134,
           8.54234494028535,
           8.477017417582566,
           8.411689894879794,
           8.346362372177008,
           8.281034849474224,
           8.21570732677144,
           8.150379804068669,
           8.085052281365886,
           8.0197247586631,
           7.954397235960329,
           7.889069713257546,
           7.823742190554761,
           7.758414667851988,
           7.693087145149205,
           7.627759622446421,
           7.562432099743637,
           7.497104577040865,
           7.431777054338081,
           7.366449531635297,
           7.301122008932525,
           7.23579448622974,
           7.170466963526956,
           7.105139440824184,
           7.0398119181214005,
           6.9744843954186155,
           6.909156872715844,
           6.84382935001306,
           6.778501827310276,
           6.7131743046074925,
           6.64784678190472,
           6.582519259201936,
           6.517191736499152,
           6.45186421379638,
           6.386536691093596,
           6.321209168390812,
           6.25588164568804,
           6.190554122985255,
           6.125226600282471,
           6.059899077579687,
           5.994571554876916,
           5.929244032174131,
           5.863916509471347,
           5.798588986768575,
           5.733261464065791,
           5.667933941363007,
           5.602606418660234,
           5.537278895957451,
           5.471951373254667,
           5.406623850551895,
           5.341296327849111,
           5.275968805146327,
           5.210641282443543,
           5.163020398680298,
           5.116792158952658,
           5.070563919225018,
           5.024335679497386,
           4.9781074397697465,
           4.931879200042106,
           4.885650960314474,
           4.839422720586834,
           4.793194480859193,
           4.746966241131553,
           4.700738001403922
          ],
          [
           54.55579416076376,
           54.60938262325181,
           54.662747901604064,
           54.71566681223229,
           54.768585722860514,
           54.82150463348874,
           54.87442354411697,
           54.92734245474519,
           54.98026136537342,
           55.033180276001644,
           55.08609918662988,
           55.1390180972581,
           55.19193700788633,
           55.24485591851456,
           55.29777482914279,
           55.35069373977102,
           55.40361265039924,
           55.45653156102747,
           55.5094504716557,
           55.56236938228392,
           55.61528829291214,
           55.66820720354037,
           55.7211261141686,
           55.774045024796834,
           55.826963935425056,
           55.87988284605328,
           55.93280175668151,
           55.98572066730973,
           56.03863957793797,
           56.091558488566186,
           56.144477399194415,
           56.197396309822636,
           56.25031522045087,
           56.3032341310791,
           56.35615304170732,
           56.40907195233555,
           56.46199086296378,
           56.514909773591995,
           56.56782868422023,
           56.62074759484845,
           56.67366650547669,
           56.72658541610491,
           56.77950432673314,
           56.83242323736137,
           56.88534214798959,
           56.93826105861782,
           56.99117996924605,
           57.04409887987428,
           57.097017790502505,
           57.14993670113073,
           57.20285561175896,
           57.255774522387185,
           57.308693433015414,
           57.36161234364364,
           57.414531254271864,
           57.46745016490009,
           57.52036907552832,
           57.573287986156544,
           57.62620689678477,
           57.679125807413,
           57.73204471804122,
           57.78496362866946,
           57.83788253929768,
           57.8908014499259,
           57.94372036055413,
           57.99663927118236,
           58.04955818181059,
           58.10247709243881,
           58.15539600306704,
           58.20831491369526,
           58.2612338243235,
           58.31415273495172,
           58.367071645579955,
           58.41999055620818,
           58.472909466836406,
           58.52582837746463,
           58.578747288092856,
           58.631666198721085,
           58.68458510934931,
           58.737504019977536,
           58.79042293060577,
           58.84334184123399,
           58.896260751862215,
           58.94917966249045,
           58.99566729146928,
           59.04089350743153,
           59.08624393971634,
           59.13159437200116,
           59.17694480428599,
           59.22229523657081,
           59.26764566885563,
           59.31299610114045,
           59.35834653342527,
           59.4036969657101,
           59.44904739799492,
           59.49439783027974,
           59.53974826256456,
           59.58509869484938,
           59.630449127134206,
           59.675799559419026,
           59.72114999170384,
           59.76650042398867,
           59.81185085627349,
           59.8572012885583,
           59.90255172084312,
           59.94790215312795,
           59.99325258541277,
           60.03860301769759,
           60.08395344998242,
           60.12930388226724,
           60.17465431455206,
           60.22000474683688,
           60.2653551791217,
           60.31070561140652,
           60.35605604369134,
           60.40140647597616,
           60.44675690826098,
           60.4921073405458,
           60.537457772830635,
           60.58280820511544,
           60.628158637400276,
           60.67350906968509,
           60.7188595019699,
           60.76420993425474,
           60.80956036653956,
           60.85491079882438,
           60.900261231109205,
           60.945611663394025,
           60.99096209567884,
           61.03631252796366,
           61.08166296024848,
           61.1270133925333,
           61.17236382481812,
           61.21771425710295,
           61.26306468938777,
           61.308415121672596,
           61.353765553957416,
           61.39911598624223,
           61.44446641852706,
           61.48981685081188,
           61.5351672830967,
           61.58051771538152,
           61.62586814766634,
           61.67121857995116,
           61.71656901223598,
           61.7619194445208,
           61.80726987680563,
           61.85262030909045,
           61.89797074137526,
           61.94332117366009,
           61.98867160594491,
           62.03402203822973,
           62.079372470514556,
           62.12472290279938,
           62.1700733350842,
           62.21542376736902,
           62.26077419965384,
           62.30612463193866,
           62.35147506422348,
           62.3968254965083,
           62.44217592879312,
           62.48752636107795,
           62.53287679336277,
           62.57822722564759,
           62.6235776579324,
           62.66892809021723,
           62.71427852250205,
           62.75825699755479,
           62.80154949399148,
           62.84484199042818,
           62.88813448686488,
           62.93142698330157,
           62.974719479738276,
           63.01801197617497,
           63.06130447261166,
           63.10459696904836,
           63.14788946548506,
           63.19118196192176,
           63.23447445835845,
           63.27776695479515,
           63.32105945123184,
           63.36435194766854,
           63.40764444410523,
           63.450936940541936,
           63.494229436978635,
           63.537521933415334,
           63.580818156721215,
           63.624118106849565,
           63.667418056977894,
           63.71071800710624,
           63.75401795723458,
           63.797317907362924,
           63.84061785749125,
           63.88391780761961,
           63.927217757747954,
           63.97051770787628,
           64.01381765800463,
           64.05711760813297,
           64.10041755826131,
           64.14371750838966,
           64.187017458518,
           64.23031740864633,
           64.27361735877467,
           64.31691730890302,
           64.36021725903136,
           64.4035172091597,
           64.44681715928805,
           64.49011710941639,
           64.53341705954472,
           64.57671700967306,
           64.6200169598014,
           64.66331690992976,
           64.70661686005809,
           64.74991681018643,
           64.79321676031478,
           64.8365167104431,
           64.87981666057146,
           64.9231166106998,
           64.96641656082814,
           65.00971651095648,
           65.05301646108482,
           65.09631641121317,
           65.13961636134151,
           65.18291631146985,
           65.2262162615982,
           65.26951621172653,
           65.31281616185487,
           65.35611611198323,
           65.39941606211156,
           65.4427160122399,
           65.48601596236824,
           65.52931591249657,
           65.57261586262491,
           65.61591581275326,
           65.65921576288162,
           65.70251571300994,
           65.74581566313829,
           65.78911561326663,
           65.83241556339496,
           65.87571551352332,
           65.91901546365166,
           65.96231541378,
           66.00561536390833,
           66.04891531403668,
           66.09221526416502,
           66.13551521429335,
           66.1788151644217,
           66.22211511455004,
           66.2654150646784,
           66.30871501480674,
           66.15848083894048,
           65.81471253707961,
           65.4709442352188,
           65.12717593335796,
           64.78340763149711,
           64.4396393296363,
           64.09587102777547,
           63.75210272591461,
           63.40833442405375,
           63.06456612219296,
           62.72079782033211,
           62.377029518471254,
           62.03326121661043,
           61.68949291474961,
           61.34572461288875,
           60.99094480752032,
           60.629308781719004,
           60.267672755917665,
           59.90603673011637,
           59.54440070431505,
           59.18276467851371,
           58.821128652712375,
           58.45949262691111,
           58.09785660110977,
           57.73622057530843,
           57.37458454950712,
           57.012948523705816,
           56.65131249790447,
           56.28967647210317,
           55.92804044630186,
           55.56640442050052,
           55.20476839469918,
           54.84313236889791,
           54.48149634309658,
           54.119860317295235,
           53.75822429149393,
           53.396588265692614,
           53.03495223989128,
           52.67331621408996,
           52.311680188288655,
           51.950044162487316,
           51.58840813668602,
           51.22677211088472,
           50.86513608508338,
           50.50350005928204,
           50.14186403348076,
           49.78022800767942,
           49.41859198187808,
           49.05695595607676,
           48.69531993027547,
           48.33368390447413,
           47.972047878672825,
           47.61041185287152,
           47.248775827070176,
           46.88713980126884,
           46.52550377546756,
           46.163867749666224,
           45.802231723864885,
           45.440595698063575,
           45.07895967226227,
           44.717323646460926,
           44.35568762065962,
           43.99405159485832,
           43.63241556905698,
           43.27077954325567,
           42.90914351745436,
           42.54750749165302,
           42.18587146585168,
           41.824235440050415,
           41.46259941424907,
           41.10096338844773,
           40.739327362646435,
           40.377691336845125,
           40.016055311043786,
           39.65441928524247,
           39.292783259441165,
           38.931147233639834,
           38.56951120783852,
           38.20787518203721,
           37.84623915623588,
           37.484603130434536,
           37.12296710463323,
           36.76133107883192,
           36.41334952916837,
           36.09267693178043,
           35.772004334392484,
           35.45133173700451,
           35.13065913961656,
           34.80998654222862,
           34.489313944840646,
           34.16864134745267,
           33.84796875006475,
           33.52729615267678,
           33.20662355528881,
           32.88595095790086,
           32.56527836051291,
           32.24460576312494,
           31.923933165736994,
           31.603260568349043,
           31.282587970961075,
           30.961915373573127,
           30.641242776185184,
           30.320570178797205,
           29.99989758140923,
           29.679224984021282,
           29.35855238663334,
           29.037879789245366,
           28.71720719185742,
           28.396534594469472,
           28.075861997081496,
           27.755189399693553,
           27.43451680230561,
           27.113844204917633,
           26.793171607529658,
           26.472499010141743,
           26.151826412753763,
           25.831153815365795,
           25.510481217977848,
           25.189808620589904,
           24.86913602320193,
           24.548463425813978,
           24.227790828426034,
           23.90711823103806,
           23.586445633650115,
           23.26577303626217,
           22.945100438874196,
           22.624427841486217,
           22.303755244098273,
           21.98308264671033,
           21.662410049322354,
           21.34173745193441,
           21.021064854546466,
           20.700392257158484,
           20.37971965977054,
           20.059047062382596,
           19.738374464994624,
           19.417701867606645,
           19.097029270218734,
           18.776356672830758,
           18.455684075442782,
           18.135011478054835,
           17.81433888066689,
           17.493666283278916,
           17.172993685890972,
           16.860757683446195,
           16.549382565174596,
           16.238007446903026,
           15.926632328631456,
           15.615257210359855,
           15.303882092088259,
           14.992506973816718,
           14.681131855545118,
           14.369756737273516,
           14.058381619001949,
           13.747006500730377,
           13.435631382458777,
           13.124256264187206,
           12.812881145915638,
           12.501506027644039,
           12.19013090937244,
           11.878755791100897,
           11.567380672829298,
           11.2560055545577,
           10.944630436286129,
           10.63325531801456,
           10.321880199742962,
           10.048409893894359,
           9.964463650160408,
           9.880517406426454,
           9.796571162692503,
           9.712624918958564,
           9.628678675224611,
           9.544732431490658,
           9.460786187756721,
           9.37683994402277,
           9.292893700288817,
           9.20894745655488,
           9.125001212820926,
           9.041054969086973,
           8.95710872535302,
           8.873162481619083,
           8.789216237885132,
           8.705269994151179,
           8.621323750417242,
           8.537377506683288,
           8.453431262949335,
           8.369485019215398,
           8.285538775481445,
           8.201592531747492,
           8.134780956439158,
           8.069453433736374,
           8.00412591103359,
           7.938798388330806,
           7.873470865628034,
           7.80814334292525,
           7.742815820222467,
           7.6774882975196945,
           7.6121607748169104,
           7.546833252114126,
           7.481505729411355,
           7.416178206708571,
           7.3508506840057874,
           7.2855231613030025,
           7.220195638600231,
           7.154868115897447,
           7.089540593194663,
           7.02421307049189,
           6.958885547789107,
           6.893558025086321,
           6.8282305023835494,
           6.762902979680765,
           6.697575456977982,
           6.63224793427521,
           6.5669204115724265,
           6.5015928888696415,
           6.436265366166857,
           6.370937843464086,
           6.305610320761302,
           6.240282798058518,
           6.174955275355745,
           6.109627752652962,
           6.044300229950177,
           5.978972707247404,
           5.913645184544621,
           5.848317661841837,
           5.782990139139054,
           5.717662616436281,
           5.65760119156402,
           5.613648055915471,
           5.5696949202669295,
           5.52574178461838,
           5.481788648969831,
           5.43783551332129,
           5.393882377672742,
           5.349929242024192,
           5.30597610637565,
           5.2620229707271005,
           5.218069835078552,
           5.1741166994300025,
           5.130163563781461,
           5.086210428132912,
           5.042257292484363,
           4.998304156835821,
           4.954351021187272,
           4.910397885538723,
           4.866444749890181,
           4.822491614241633,
           4.778538478593083,
           4.734585342944533,
           4.690632207295992
          ],
          [
           54.821288829583615,
           54.87487729207166,
           54.92846575455971,
           54.98205421704776,
           55.03564267953581,
           55.08923114202386,
           55.142819604511914,
           55.196408066999965,
           55.249996529488016,
           55.30358499197607,
           55.35717345446412,
           55.41076191695216,
           55.46435037944021,
           55.51793884192826,
           55.57152730441631,
           55.625115766904365,
           55.67870422939241,
           55.73229269188046,
           55.78588115436851,
           55.838911656901324,
           55.89183056752955,
           55.944749478157775,
           55.997668388785996,
           56.05058729941423,
           56.103506210042454,
           56.15642512067068,
           56.20934403129891,
           56.26226294192713,
           56.31518185255537,
           56.36810076318359,
           56.42101967381182,
           56.47393858444005,
           56.52685749506827,
           56.57977640569651,
           56.63269531632473,
           56.68561422695295,
           56.738533137581186,
           56.79145204820941,
           56.84437095883764,
           56.897289869465865,
           56.95020878009409,
           57.003127690722316,
           57.056046601350545,
           57.10896551197877,
           57.161884422606995,
           57.214803333235224,
           57.267722243863446,
           57.32064115449168,
           57.373560065119904,
           57.426478975748125,
           57.47939788637636,
           57.53231679700459,
           57.58523570763281,
           57.63815461826104,
           57.69107352888926,
           57.74399243951749,
           57.79691135014572,
           57.84983026077394,
           57.90274917140217,
           57.9556680820304,
           58.00858699265863,
           58.06150590328686,
           58.11442481391508,
           58.1673437245433,
           58.22026263517154,
           58.273181545799766,
           58.32610045642799,
           58.379019367056216,
           58.43193827768444,
           58.484857188312674,
           58.537776098940896,
           58.59069500956912,
           58.64361392019735,
           58.696532830825575,
           58.749451741453804,
           58.80237065208203,
           58.85528956271026,
           58.90820847333848,
           58.96112738396671,
           59.01404629459494,
           59.06696520522317,
           59.11988411585139,
           59.17280302647962,
           59.22572193710785,
           59.27220956608669,
           59.31741093873565,
           59.36261231138461,
           59.40781368403357,
           59.45301505668253,
           59.49821642933149,
           59.54341780198045,
           59.588619174629414,
           59.633820547278376,
           59.67902191992734,
           59.7242232925763,
           59.76942466522526,
           59.81462603787422,
           59.85982741052318,
           59.90502878317215,
           59.95023015582111,
           59.995431528470064,
           60.04063290111903,
           60.08593364687461,
           60.13128407915943,
           60.17663451144425,
           60.22198494372907,
           60.26733537601389,
           60.31268580829871,
           60.35803624058353,
           60.40338667286835,
           60.448737105153185,
           60.494087537438,
           60.53943796972282,
           60.584788402007646,
           60.63013883429247,
           60.67548926657729,
           60.72083969886211,
           60.76619013114693,
           60.81154056343175,
           60.85689099571656,
           60.902241428001396,
           60.94759186028621,
           60.99294229257103,
           61.03829272485586,
           61.08364315714067,
           61.12899358942549,
           61.174344021710326,
           61.21969445399514,
           61.26504488627996,
           61.31039531856479,
           61.35574575084959,
           61.40109618313443,
           61.44644661541925,
           61.49179704770407,
           61.53714747998889,
           61.58249791227371,
           61.62784834455853,
           61.67319877684336,
           61.71854920912817,
           61.763899641413,
           61.80925007369782,
           61.854600505982646,
           61.89995093826745,
           61.94530137055227,
           61.99065180283711,
           62.03600223512193,
           62.08135266740674,
           62.12670309969157,
           62.17205353197639,
           62.21740396426121,
           62.26275439654603,
           62.30810482883085,
           62.35345526111568,
           62.3988056934005,
           62.444156125685325,
           62.489506557970145,
           62.53485699025496,
           62.58020742253978,
           62.6255578548246,
           62.67090828710943,
           62.71625871939424,
           62.76160915167906,
           62.80695958396389,
           62.85231001624871,
           62.89766044853353,
           62.943010880818356,
           62.98836131310318,
           63.03233978815591,
           63.075632284592594,
           63.11892478102931,
           63.162217277466,
           63.2055097739027,
           63.24880227033939,
           63.292094766776096,
           63.33538726321279,
           63.378679759649486,
           63.421972256086185,
           63.46526475252287,
           63.508557248959576,
           63.55184974539626,
           63.59514224183296,
           63.63843473826966,
           63.68172723470636,
           63.72501973114305,
           63.76831222757975,
           63.81160472401645,
           63.85489722045314,
           63.898189716889846,
           63.94148221332653,
           63.98477470976323,
           64.02806720619992,
           64.07135970263663,
           64.11465219907332,
           64.15794469551001,
           64.20123719194672,
           64.24452968838341,
           64.2878221848201,
           64.3311146812568,
           64.37440717769351,
           64.41769967413019,
           64.4609921705669,
           64.50428466700359,
           64.54757716344028,
           64.59086965987699,
           64.63416215631368,
           64.67745465275038,
           64.72074714918708,
           64.76403964562377,
           64.80733214206046,
           64.85062463849717,
           64.89391713493384,
           64.93720963137055,
           64.98050212780726,
           65.02379462424395,
           65.06708712068065,
           65.11037961711733,
           65.15367211355405,
           65.19696460999074,
           65.24025710642744,
           65.28354960286413,
           65.32684209930082,
           65.37013459573753,
           65.41342709217422,
           65.45671958861091,
           65.50001208504762,
           65.5433045814843,
           65.586597077921,
           65.62988957435769,
           65.6731820707944,
           65.71647456723109,
           65.75976706366778,
           65.80305956010449,
           65.84635205654118,
           65.88964455297787,
           65.93293704941456,
           65.97622954585127,
           66.01952204228797,
           66.06281453872467,
           66.10559905255741,
           66.14782478526179,
           66.19005051796617,
           66.23227625067054,
           66.27450198337492,
           66.3167277160793,
           66.35895344878367,
           66.40117918148805,
           66.44340491419243,
           66.48563064689681,
           66.52785637960116,
           66.57008211230556,
           66.40530053876745,
           66.03351165898687,
           65.66172277920633,
           65.28993389942578,
           64.91814501964521,
           64.54635613986466,
           64.17456726008412,
           63.802778380303536,
           63.430989500522955,
           63.05920062074245,
           62.68741174096187,
           62.315622861181296,
           61.94383398140074,
           61.572045101620205,
           61.20025622183962,
           60.828467342059085,
           60.456678462278546,
           60.084889582497965,
           59.71310070271742,
           59.34131182293687,
           58.969522943156306,
           58.597734063375725,
           58.22594518359521,
           57.854156303814634,
           57.48236742403405,
           57.110578544253514,
           56.73878966447296,
           56.367000784692394,
           55.99521190491184,
           55.623423025131295,
           55.25163414535072,
           54.87984526557014,
           54.50805638578963,
           54.13626750600906,
           53.764478626228474,
           53.392689746447935,
           53.02090086666739,
           52.64911198688682,
           52.27732310710627,
           51.905534227325724,
           51.53374534754515,
           51.1619564677646,
           50.79016758798406,
           50.41837870820348,
           50.046589828422896,
           49.67480094864239,
           49.30301206886181,
           48.93122318908124,
           48.55943430930069,
           48.187645429520146,
           47.81788712556109,
           47.45625109975978,
           47.09461507395847,
           46.732979048157134,
           46.371343022355795,
           46.00970699655453,
           45.648070970753196,
           45.28643494495185,
           44.92479891915055,
           44.56316289334924,
           44.2015268675479,
           43.839890841746595,
           43.47825481594528,
           43.11661879014394,
           42.75498276434263,
           42.39334673854133,
           42.031710712739994,
           41.670074686938655,
           41.30843866113737,
           40.946802635336034,
           40.585166609534696,
           40.22353058373339,
           39.86189455793208,
           39.500258532130744,
           39.13862250632943,
           38.77698648052814,
           38.4153504547268,
           38.05371442892548,
           37.69207840312418,
           37.33044237732284,
           36.9688063515215,
           36.60717032572019,
           36.24553429991889,
           35.897552750255336,
           35.576880152867396,
           35.25620755547945,
           34.93553495809147,
           34.614862360703526,
           34.294189763315586,
           33.97351716592761,
           33.652844568539635,
           33.332171971151716,
           33.01149937376375,
           32.690826776375765,
           32.37015417898782,
           32.04948158159988,
           31.7288089842119,
           31.40813638682396,
           31.08746378943601,
           30.766791192048036,
           30.44611859466009,
           30.1261346968721,
           29.814759578600498,
           29.503384460328903,
           29.19200934205733,
           28.880634223785762,
           28.569259105514163,
           28.25788398724259,
           27.946508868971023,
           27.635133750699428,
           27.323758632427854,
           27.012383514156287,
           26.701008395884678,
           26.38963327761309,
           26.07825815934154,
           25.766883041069942,
           25.455507922798343,
           25.144132804526773,
           24.832757686255206,
           24.521382567983604,
           24.210007449712037,
           23.898632331440467,
           23.587257213168865,
           23.275882094897298,
           22.964506976625724,
           22.65313185835413,
           22.341756740082527,
           22.030381621810957,
           21.71900650353939,
           21.407631385267784,
           21.096256266996214,
           20.784881148724644,
           20.473506030453052,
           20.16213091218148,
           19.850755793909908,
           19.53938067563831,
           19.22800555736671,
           18.91663043909517,
           18.60525532082357,
           18.29388020255197,
           17.9825050842804,
           17.67112996600883,
           17.359754847737232,
           17.04837972946566,
           16.737004611194088,
           16.42562949292249,
           16.11425437465092,
           15.802879256379349,
           15.49150413810775,
           15.180129019836151,
           14.86875390156461,
           14.55737878329301,
           14.246003665021412,
           13.934628546749844,
           13.62325342847827,
           13.311878310206673,
           13.000503191935103,
           12.68912807366353,
           12.377752955391934,
           12.066377837120335,
           11.755002718848791,
           11.443627600577193,
           11.132252482305594,
           10.820877364034025,
           10.509502245762453,
           10.198127127490856,
           9.924656821642255,
           9.840710577908302,
           9.756764334174349,
           9.672818090440398,
           9.58887184670646,
           9.504925602972508,
           9.420979359238553,
           9.337033115504617,
           9.253086871770664,
           9.169140628036711,
           9.085194384302774,
           9.001248140568821,
           8.917301896834868,
           8.833355653100915,
           8.749409409366978,
           8.665463165633026,
           8.581516921899073,
           8.497570678165136,
           8.413624434431183,
           8.32967819069723,
           8.245731946963293,
           8.16178570322934,
           8.077839459495387,
           7.993893215761449,
           7.909946972027497,
           7.826000728293544,
           7.742054484559591,
           7.658108240825654,
           7.574161997091701,
           7.490215753357749,
           7.419401822925754,
           7.357968175789916,
           7.296534528654077,
           7.235100881518252,
           7.173667234382414,
           7.112233587246577,
           7.05079994011074,
           6.989366292974913,
           6.927932645839077,
           6.866498998703238,
           6.805065351567413,
           6.743631704431575,
           6.682198057295738,
           6.620764410159912,
           6.559330763024074,
           6.497897115888238,
           6.436463468752411,
           6.3750298216165735,
           6.313596174480737,
           6.252162527344899,
           6.190728880209074,
           6.129295233073236,
           6.067861585937398,
           6.006427938801572,
           5.955191283654315,
           5.911238148005767,
           5.867285012357225,
           5.823331876708675,
           5.779378741060126,
           5.735425605411577,
           5.691472469763036,
           5.647519334114486,
           5.603566198465937,
           5.559613062817395,
           5.515659927168847,
           5.4717067915202975,
           5.427753655871756,
           5.383800520223207,
           5.339847384574657,
           5.295894248926116,
           5.251941113277567,
           5.207987977629017,
           5.1640348419804685,
           5.120081706331927,
           5.0761285706833785,
           5.032175435034828,
           4.988222299386287,
           4.944269163737738,
           4.900316028089189,
           4.8563628924406474,
           4.812409756792098,
           4.768456621143548,
           4.724503485494999,
           4.680550349846458
          ],
          [
           55.086783498403456,
           55.14037196089151,
           55.19396042337956,
           55.24754888586761,
           55.30113734835565,
           55.35472581084371,
           55.408314273331754,
           55.461902735819805,
           55.515491198307856,
           55.56907966079591,
           55.62266812328396,
           55.67625658577201,
           55.72984504826005,
           55.78343351074811,
           55.837021973236155,
           55.890610435724206,
           55.94419889821226,
           55.99778736070031,
           56.05137582318835,
           56.10496428567641,
           56.15855274816445,
           56.212141210652504,
           56.265729673140555,
           56.319318135628606,
           56.37290659811666,
           56.42649506060471,
           56.48008352309276,
           56.53367198558081,
           56.587260448068854,
           56.640848910556905,
           56.694437373044956,
           56.748025835533,
           56.80161429802105,
           56.8552027605091,
           56.90879122299715,
           56.96215650157036,
           57.015075412198584,
           57.067994322826806,
           57.12091323345504,
           57.17383214408326,
           57.22675105471149,
           57.27966996533972,
           57.33258887596794,
           57.38550778659617,
           57.4384266972244,
           57.49134560785262,
           57.54426451848086,
           57.59718342910908,
           57.6501023397373,
           57.70302125036554,
           57.75594016099376,
           57.80885907162199,
           57.86177798225022,
           57.91469689287844,
           57.96761580350667,
           58.0205347141349,
           58.07345362476312,
           58.126372535391354,
           58.179291446019576,
           58.232210356647805,
           58.28512926727603,
           58.338048177904255,
           58.39096708853249,
           58.44388599916071,
           58.496804909788935,
           58.549723820417164,
           58.602642731045385,
           58.655561641673614,
           58.70848055230185,
           58.76139946293007,
           58.8143183735583,
           58.86723728418653,
           58.92015619481476,
           58.97307510544298,
           59.0259940160712,
           59.07891292669944,
           59.13183183732767,
           59.18475074795589,
           59.23766965858412,
           59.290588569212346,
           59.34350747984057,
           59.39642639046879,
           59.44934530109703,
           59.502264211725254,
           59.548751840704085,
           59.593953213353046,
           59.63915458600201,
           59.68435595865097,
           59.72955733129993,
           59.77475870394889,
           59.81996007659785,
           59.86516144924681,
           59.91036282189578,
           59.95556419454474,
           60.0007655671937,
           60.045966939842664,
           60.091168312491625,
           60.136369685140586,
           60.18157105778955,
           60.22677243043851,
           60.27197380308747,
           60.31717517573643,
           60.3623765483854,
           60.40757792103436,
           60.452779293683314,
           60.49798066633228,
           60.54318203898124,
           60.5883834116302,
           60.633584784279165,
           60.678786156928126,
           60.72398752957709,
           60.76918890222605,
           60.81439027487501,
           60.85959164752397,
           60.90479302017293,
           60.94999439282189,
           60.995195765470854,
           61.040397138119815,
           61.085623354032876,
           61.13097378631768,
           61.17632421860252,
           61.22167465088732,
           61.26702508317214,
           61.31237551545698,
           61.35772594774179,
           61.40307638002662,
           61.44842681231144,
           61.49377724459626,
           61.53912767688108,
           61.5844781091659,
           61.62982854145072,
           61.67517897373554,
           61.72052940602036,
           61.76587983830519,
           61.81123027059001,
           61.85658070287484,
           61.90193113515966,
           61.94728156744447,
           61.9926319997293,
           62.03798243201412,
           62.08333286429894,
           62.12868329658376,
           62.17403372886858,
           62.2193841611534,
           62.26473459343822,
           62.31008502572304,
           62.35543545800787,
           62.40078589029268,
           62.4461363225775,
           62.49148675486233,
           62.53683718714715,
           62.58218761943198,
           62.62753805171679,
           62.67288848400161,
           62.71823891628644,
           62.76358934857126,
           62.80893978085608,
           62.85429021314091,
           62.89964064542573,
           62.94499107771054,
           62.99034150999536,
           63.03569194228019,
           63.08104237456501,
           63.12639280684983,
           63.17174323913465,
           63.21709367141947,
           63.26244410370429,
           63.30642257875704,
           63.34971507519373,
           63.39300757163042,
           63.43630006806712,
           63.47959256450381,
           63.52288506094052,
           63.56617755737721,
           63.60947005381391,
           63.65276255025061,
           63.6960550466873,
           63.739347543124,
           63.7826400395607,
           63.82593253599739,
           63.86922503243409,
           63.91251752887078,
           63.95581002530748,
           63.99910252174417,
           64.04239501818087,
           64.08568751461758,
           64.12898001105427,
           64.17227250749096,
           64.21556500392765,
           64.25885750036434,
           64.30214999680105,
           64.34544249323774,
           64.38873498967445,
           64.43202748611114,
           64.47531998254783,
           64.51861247898452,
           64.56190497542123,
           64.60519747185792,
           64.64848996829463,
           64.69178246473132,
           64.73507496116801,
           64.77836745760472,
           64.82165995404141,
           64.86495245047811,
           64.9082449469148,
           64.9515374433515,
           64.99482993978819,
           65.03812243622488,
           65.08141493266159,
           65.1247074290983,
           65.16799992553497,
           65.21129242197168,
           65.25458491840837,
           65.29787741484506,
           65.34116991128177,
           65.38446240771846,
           65.42775490415517,
           65.47104740059186,
           65.51433989702855,
           65.55763239346525,
           65.60034070969577,
           65.64256644240014,
           65.68479217510452,
           65.72701790780889,
           65.76924364051328,
           65.81146937321765,
           65.85369510592203,
           65.8959208386264,
           65.93814657133078,
           65.98037230403514,
           66.02259803673952,
           66.0648237694439,
           66.10704950214827,
           66.14927523485265,
           66.19150096755703,
           66.2337267002614,
           66.27595243296578,
           66.31817816567016,
           66.36040389837454,
           66.40262963107891,
           66.44485536378329,
           66.48708109648767,
           66.52930682919204,
           66.57153256189642,
           66.6137582946008,
           66.65598402730518,
           66.69820976000955,
           66.74043549271391,
           66.78266122541831,
           66.82488695812268,
           66.66010538458457,
           66.28831650480399,
           65.91652762502345,
           65.54473874524291,
           65.17294986546233,
           64.80116098568179,
           64.42937210590124,
           64.05758322612067,
           63.68579434634009,
           63.31400546655958,
           62.942216586779,
           62.57042770699842,
           62.19863882721788,
           61.82684994743733,
           61.45506106765676,
           61.083272187876204,
           60.711483308095666,
           60.339694428315084,
           59.967905548534546,
           59.596116668754,
           59.224327788973426,
           58.852538909192845,
           58.480750029412334,
           58.10896114963175,
           57.73717226985118,
           57.36538339007063,
           56.993594510290094,
           56.62180563050951,
           56.250016750728975,
           55.87822787094842,
           55.50643899116785,
           55.13465011138727,
           54.76286123160676,
           54.39107235182618,
           54.0192834720456,
           53.64749459226506,
           53.275705712484516,
           52.90391683270394,
           52.53212795292339,
           52.160339073142836,
           51.78855019336227,
           51.41676131358172,
           51.04497243380118,
           50.6731835540206,
           50.30139467424002,
           49.92960579445952,
           49.55781691467894,
           49.18602803489836,
           48.81423915511781,
           48.442450275337265,
           48.0706613955567,
           47.698872515776145,
           47.327083635995606,
           46.955294756215025,
           46.583505876434444,
           46.21171699665394,
           45.83992811687337,
           45.468139237092785,
           45.09635035731224,
           44.724561477531694,
           44.35277259775111,
           43.980983717970574,
           43.609194838190035,
           43.237405958409454,
           42.865617078628915,
           42.49382819884836,
           42.12203931906779,
           41.750250439287214,
           41.3734873600416,
           40.972848053829836,
           40.57220874761808,
           40.171569441406355,
           39.77093013519463,
           39.370290828982874,
           38.96965152277115,
           38.56901221655943,
           38.168372910347664,
           37.76773360413594,
           37.36709429792422,
           36.96645499171246,
           36.5658156855007,
           36.16517637928897,
           35.76453707307725,
           35.39497538544934,
           35.08756893498914,
           34.780162484528944,
           34.47275603406871,
           34.16534958360851,
           33.85794313314831,
           33.550536682688076,
           33.24313023222785,
           32.93572378176767,
           32.62831733130745,
           32.320910880847215,
           32.013504430387016,
           31.706097979926813,
           31.398691529466586,
           31.091285079006383,
           30.783878628546184,
           30.476472178085952,
           30.16906572762575,
           29.86165927716555,
           29.554252826705316,
           29.246846376245088,
           28.939439925784885,
           28.63203347532469,
           28.32462702486446,
           28.017220574404256,
           27.70981412394405,
           27.402407673483825,
           27.095001223023626,
           26.787594772563423,
           26.480188322103192,
           26.172781871642968,
           25.86537542118279,
           25.55796897072256,
           25.250562520262328,
           24.94315606980213,
           24.63574961934193,
           24.328343168881702,
           24.020936718421495,
           23.713530267961296,
           23.40612381750106,
           23.098717367040862,
           22.79131091658066,
           22.48390446612043,
           22.1764980156602,
           21.8690915652,
           21.5616851147398,
           21.254278664279568,
           20.94687221381937,
           20.63946576335917,
           20.332059312898938,
           20.024652862438735,
           19.717246411978532,
           19.409839961518305,
           19.102433511058074,
           18.79287736684306,
           18.481502248571466,
           18.17012713029986,
           17.858752012028297,
           17.547376893756724,
           17.236001775485125,
           16.92462665721355,
           16.613251538941984,
           16.30187642067039,
           15.990501302398815,
           15.679126184127245,
           15.367751065855643,
           15.056375947584048,
           14.745000829312504,
           14.433625711040909,
           14.122250592769305,
           13.810875474497735,
           13.499500356226164,
           13.188125237954567,
           12.876750119682995,
           12.565375001411427,
           12.253999883139828,
           11.94262476486823,
           11.631249646596686,
           11.319874528325087,
           11.008499410053489,
           10.69712429178192,
           10.385749173510352,
           10.07437405523875,
           9.80090374939015,
           9.716957505656195,
           9.633011261922244,
           9.54906501818829,
           9.465118774454353,
           9.381172530720402,
           9.297226286986447,
           9.217166140582709,
           9.155732493446871,
           9.094298846311034,
           9.032865199175209,
           8.971431552039371,
           8.909997904903532,
           8.848564257767697,
           8.787130610631868,
           8.725696963496034,
           8.664263316360195,
           8.60282966922437,
           8.541396022088533,
           8.479962374952695,
           8.418528727816868,
           8.357095080681031,
           8.295661433545193,
           8.234227786409368,
           8.172794139273531,
           8.111360492137692,
           8.049926845001856,
           7.988493197866029,
           7.927059550730192,
           7.865625903594355,
           7.804192256458529,
           7.742758609322691,
           7.681324962186854,
           7.619891315051028,
           7.5584576679151905,
           7.497024020779353,
           7.435590373643516,
           7.374156726507691,
           7.312723079371852,
           7.251289432236015,
           7.189855785100189,
           7.1284221379643515,
           7.066988490828514,
           7.005554843692688,
           6.94412119655685,
           6.882687549421013,
           6.8212539022851875,
           6.759820255149348,
           6.698386608013512,
           6.636952960877675,
           6.575519313741849,
           6.514085666606011,
           6.4526520194701735,
           6.391218372334348,
           6.32978472519851,
           6.268351078062673,
           6.206917430926847,
           6.1454837837910095,
           6.084050136655172,
           6.022616489519335,
           5.961182842383509,
           5.899749195247672,
           5.838315548111835,
           5.776881900976008,
           5.7154482538401705,
           5.654014606704333,
           5.592580959568507,
           5.531147312432671,
           5.469713665296833,
           5.4082800181610065,
           5.34684637102517,
           5.285412723889332,
           5.223979076753494,
           5.162545429617667,
           5.10111178248183,
           5.039678135345993,
           4.9782444882101675,
           4.934187306288203,
           4.890234170639655,
           4.846281034991113,
           4.802327899342564,
           4.758374763694015,
           4.714421628045465,
           4.670468492396924
          ],
          [
           55.352278167223304,
           55.405866629711355,
           55.459455092199406,
           55.51304355468746,
           55.56663201717551,
           55.62022047966356,
           55.673808942151595,
           55.727397404639646,
           55.78098586712771,
           55.83457432961576,
           55.8881627921038,
           55.94175125459185,
           55.9953397170799,
           56.04892817956795,
           56.102516642056,
           56.156105104544054,
           56.209693567032105,
           56.263282029520155,
           56.316870492008206,
           56.37045895449626,
           56.42404741698431,
           56.47763587947236,
           56.531224341960396,
           56.584812804448454,
           56.6384012669365,
           56.69198972942455,
           56.74557819191261,
           56.79916665440065,
           56.85275511688871,
           56.90634357937675,
           56.9599320418648,
           57.013520504352854,
           57.0671089668409,
           57.120697429328956,
           57.17428589181701,
           57.22787435430506,
           57.2814628167931,
           57.33505127928115,
           57.388639741769204,
           57.44222820425725,
           57.4958166667453,
           57.54940512923335,
           57.6029935917214,
           57.65658205420945,
           57.7101705166975,
           57.76375897918555,
           57.817347441673604,
           57.870935904161655,
           57.92452436664969,
           57.97811282913774,
           58.03170129162581,
           58.08528975411386,
           58.13832025686762,
           58.19123916749585,
           58.24415807812407,
           58.2970769887523,
           58.34999589938053,
           58.40291481000875,
           58.45583372063698,
           58.5087526312652,
           58.56167154189343,
           58.61459045252167,
           58.66750936314989,
           58.72042827377811,
           58.77334718440635,
           58.826266095034576,
           58.87918500566279,
           58.93210391629103,
           58.98502282691925,
           59.03794173754748,
           59.090860648175706,
           59.14377955880393,
           59.19669846943216,
           59.249617380060386,
           59.302536290688614,
           59.355455201316836,
           59.408374111945065,
           59.46129302257329,
           59.514211933201516,
           59.56713084382975,
           59.62004975445798,
           59.6729686650862,
           59.72588757571443,
           59.77880648634265,
           59.8252941153215,
           59.87049548797046,
           59.91569686061942,
           59.96089823326838,
           60.00609960591734,
           60.0513009785663,
           60.096502351215264,
           60.141703723864225,
           60.186905096513186,
           60.23210646916215,
           60.27730784181111,
           60.32250921446006,
           60.36771058710903,
           60.41291195975799,
           60.45811333240696,
           60.50331470505592,
           60.548516077704875,
           60.593717450353836,
           60.6389188230028,
           60.68412019565176,
           60.72932156830072,
           60.77452294094968,
           60.81972431359864,
           60.8649256862476,
           60.91012705889658,
           60.955328431545524,
           61.000529804194485,
           61.04573117684346,
           61.09093254949241,
           61.13613392214138,
           61.181335294790344,
           61.226536667439305,
           61.27173804008826,
           61.31693941273722,
           61.36214078538619,
           61.40734215803514,
           61.45254353068411,
           61.497744903333064,
           61.542946275982025,
           61.588147648630994,
           61.63334902127995,
           61.678550393928916,
           61.72375176657788,
           61.76895313922684,
           61.8141545118758,
           61.85935588452476,
           61.90455725717372,
           61.94975862982268,
           61.99496000247164,
           62.040161375120604,
           62.085362747769565,
           62.13066349347595,
           62.17601392576077,
           62.2213643580456,
           62.266714790330425,
           62.31206522261524,
           62.35741565490006,
           62.40276608718489,
           62.44811651946971,
           62.49346695175453,
           62.53881738403935,
           62.58416781632417,
           62.62951824860899,
           62.67486868089381,
           62.72021911317863,
           62.76556954546345,
           62.81091997774827,
           62.85627041003309,
           62.90162084231792,
           62.94697127460274,
           62.992321706887566,
           63.037672139172386,
           63.0830225714572,
           63.12837300374203,
           63.17372343602685,
           63.21907386831167,
           63.26442430059648,
           63.309774732881316,
           63.35512516516613,
           63.40047559745095,
           63.44582602973578,
           63.4911764620206,
           63.53652689430542,
           63.58050536935815,
           63.62379786579484,
           63.66709036223155,
           63.71038285866824,
           63.75367535510493,
           63.79696785154163,
           63.84026034797833,
           63.88355284441503,
           63.92684534085173,
           63.970137837288426,
           64.01343033372513,
           64.05672283016182,
           64.10001532659851,
           64.1433078230352,
           64.1866003194719,
           64.2298928159086,
           64.27318531234529,
           64.316477808782,
           64.35977030521869,
           64.40306280165538,
           64.44635529809209,
           64.48964779452876,
           64.53294029096547,
           64.57623278740218,
           64.61952528383887,
           64.66281778027556,
           64.70611027671225,
           64.74940277314896,
           64.79269526958565,
           64.83598776602236,
           64.87928026245905,
           64.92257275889574,
           64.96586525533243,
           65.00915775176914,
           65.05245024820583,
           65.0950823668341,
           65.1373080995385,
           65.17953383224287,
           65.22175956494723,
           65.26398529765162,
           65.306211030356,
           65.34843676306036,
           65.39066249576476,
           65.43288822846912,
           65.47511396117349,
           65.51733969387789,
           65.55956542658225,
           65.60179115928663,
           65.644016891991,
           65.68624262469538,
           65.72846835739976,
           65.77069409010414,
           65.81291982280851,
           65.85514555551289,
           65.89737128821727,
           65.93959702092164,
           65.98182275362602,
           66.0240484863304,
           66.06627421903477,
           66.10849995173915,
           66.15072568444351,
           66.1929514171479,
           66.23517714985228,
           66.27740288255666,
           66.31962861526102,
           66.3618543479654,
           66.40408008066979,
           66.44630581337415,
           66.48853154607853,
           66.5307572787829,
           66.57298301148728,
           66.61520874419166,
           66.65743447689604,
           66.69966020960041,
           66.74188594230479,
           66.78411167500917,
           66.82633740771354,
           66.86856314041792,
           66.9107888731223,
           66.95301460582667,
           66.99524033853106,
           67.03746607123541,
           67.0796918039398,
           66.9149102304017,
           66.54312135062112,
           66.17133247084058,
           65.79954359106003,
           65.42775471127945,
           65.05596583149891,
           64.68417695171837,
           64.31238807193779,
           63.940599192157215,
           63.5688103123767,
           63.19702143259612,
           62.82523255281555,
           62.453443673035,
           62.08165479325446,
           61.70986591347388,
           61.33807703369334,
           60.96628815391279,
           60.59449927413221,
           60.222710394351665,
           59.85092151457112,
           59.479132634790545,
           59.10734375500997,
           58.73555487522947,
           58.36376599544889,
           57.991977115668305,
           57.62018823588777,
           57.248399356107214,
           56.87661047632663,
           56.504821596546094,
           56.133032716765555,
           55.76124383698498,
           55.3894549572044,
           55.01766607742389,
           54.645877197643316,
           54.27408831786273,
           53.90229943808218,
           53.53051055830164,
           53.15872167852107,
           52.786932798740516,
           52.41514391895997,
           52.043355039179396,
           51.67156615939885,
           51.28982888692576,
           50.889189580714,
           50.488550274502245,
           50.08791096829056,
           49.68727166207879,
           49.28663235586703,
           48.885993049655305,
           48.48535374344358,
           48.084714437231824,
           47.684075131020094,
           47.28343582480838,
           46.88279651859662,
           46.482157212384855,
           46.08151790617317,
           45.68087859996141,
           45.28023929374965,
           44.87959998753793,
           44.4789606813262,
           44.07832137511444,
           43.67768206890271,
           43.277042762690996,
           42.87640345647923,
           42.47576415026751,
           42.07512484405579,
           41.67448553784403,
           41.27384623163226,
           40.87320692542058,
           40.472567619208824,
           40.07192831299706,
           39.67128900678534,
           39.270649700573614,
           38.870010394361856,
           38.46937108815013,
           38.06873178193841,
           37.668092475726645,
           37.26745316951492,
           36.8668138633032,
           36.466174557091435,
           36.06553525087968,
           35.66489594466796,
           35.26425663845623,
           34.894694950828324,
           34.58728850036812,
           34.27988204990792,
           33.97247559944769,
           33.66506914898749,
           33.35766269852729,
           33.05025624806706,
           32.74284979760683,
           32.43544334714665,
           32.128036896686424,
           31.820630446226197,
           31.513223995765998,
           31.205817545305795,
           30.898411094845564,
           30.591004644385364,
           30.283598193925158,
           29.976191743464934,
           29.66878529300473,
           29.361378842544532,
           29.0539723920843,
           28.74656594162407,
           28.43915949116387,
           28.131753040703668,
           27.824346590243437,
           27.516940139783237,
           27.209533689323035,
           26.902127238862803,
           26.594720788402604,
           26.287314337942405,
           25.97990788748217,
           25.672501437021946,
           25.365094986561772,
           25.05768853610154,
           24.750282085641313,
           24.44287563518111,
           24.135469184720908,
           23.82806273426068,
           23.520656283800477,
           23.213249833340274,
           22.905843382880043,
           22.598436932419844,
           22.29103048195964,
           21.98362403149941,
           21.676217581039182,
           21.36881113057898,
           21.061404680118777,
           20.753998229658553,
           20.446591779198346,
           20.139185328738144,
           19.83177887827792,
           19.524372427817717,
           19.21696597735751,
           18.909559526897286,
           18.602153076437055,
           18.29474662597688,
           17.987340175516653,
           17.684407924471877,
           17.386763376274875,
           17.089118828077872,
           16.791474279880838,
           16.493829731683835,
           16.196185183486833,
           15.898540635289802,
           15.600896087092798,
           15.303251538895795,
           15.005606990698762,
           14.707962442501733,
           14.410317894304757,
           14.112673346107727,
           13.815028797910696,
           13.51738424971369,
           13.219739701516687,
           12.922095153319658,
           12.624450605122654,
           12.326806056925651,
           12.02916150872862,
           11.731516960531588,
           11.433872412334612,
           11.136227864137581,
           10.83858331594055,
           10.540938767743548,
           10.243294219546542,
           9.945649671349512,
           9.684490420808945,
           9.605757658550376,
           9.527024896291804,
           9.448292134033235,
           9.369559371774677,
           9.290826609516108,
           9.212093847257536,
           9.133361084998981,
           9.05462832274041,
           8.97589556048184,
           8.897162798223285,
           8.818430035964713,
           8.739697273706142,
           8.660964511447572,
           8.582231749189017,
           8.503498986930445,
           8.424766224671874,
           8.346033462413319,
           8.267300700154749,
           8.188567937896178,
           8.10983517563762,
           8.03110241337905,
           7.95236965112048,
           7.873636888861924,
           7.7949041266033525,
           7.716171364344783,
           7.637438602086213,
           7.558705839827656,
           7.4799730775690865,
           7.401240315310515,
           7.32250755305196,
           7.243774790793388,
           7.181929223993484,
           7.1204955768576585,
           7.059061929721821,
           6.997628282585983,
           6.936194635450146,
           6.87476098831432,
           6.813327341178483,
           6.7518936940426455,
           6.69046004690682,
           6.629026399770982,
           6.567592752635145,
           6.506159105499318,
           6.4447254583634805,
           6.383291811227643,
           6.321858164091817,
           6.26042451695598,
           6.198990869820143,
           6.137557222684305,
           6.076123575548479,
           6.0146899284126425,
           5.956990680107154,
           5.915162412808262,
           5.873334145509363,
           5.831505878210465,
           5.789677610911573,
           5.747849343612673,
           5.706021076313775,
           5.664192809014875,
           5.622364541715984,
           5.580536274417085,
           5.538708007118186,
           5.4968797398192955,
           5.455051472520395,
           5.413223205221497,
           5.371394937922606,
           5.329566670623706,
           5.287738403324807,
           5.245910136025914,
           5.204081868727016,
           5.162253601428118,
           5.120425334129218,
           5.078597066830326,
           5.036768799531428,
           4.994940532232528,
           4.953112264933637,
           4.911283997634738,
           4.869455730335839,
           4.827627463036948,
           4.785799195738049,
           4.743970928439149,
           4.70214266114025,
           4.660314393841358
          ],
          [
           55.617772836043166,
           55.67136129853122,
           55.72494976101926,
           55.77853822350731,
           55.83212668599537,
           55.88571514848341,
           55.939303610971464,
           55.992892073459515,
           56.04648053594756,
           56.10006899843561,
           56.15365746092367,
           56.20724592341171,
           56.26083438589976,
           56.314422848387814,
           56.368011310875865,
           56.421599773363916,
           56.47518823585196,
           56.52877669834001,
           56.58236516082806,
           56.63595362331612,
           56.68954208580416,
           56.743130548292214,
           56.79671901078026,
           56.850307473268316,
           56.90389593575636,
           56.95748439824442,
           57.01107286073247,
           57.06466132322051,
           57.11824978570856,
           57.17183824819661,
           57.22542671068466,
           57.27901517317271,
           57.33260363566076,
           57.38619209814881,
           57.43978056063686,
           57.49336902312491,
           57.546957485612964,
           57.600545948101015,
           57.654134410589066,
           57.70772287307711,
           57.76131133556516,
           57.81489979805321,
           57.86848826054126,
           57.92207672302931,
           57.97566518551736,
           58.02925364800541,
           58.08284211049346,
           58.13643057298151,
           58.190019035469554,
           58.243607497957605,
           58.29719596044566,
           58.350784422933714,
           58.404372885421765,
           58.45796134790981,
           58.51154981039786,
           58.56513827288591,
           58.61872673537396,
           58.672315197862005,
           58.72590366035006,
           58.779492122838114,
           58.83308058532616,
           58.88666904781421,
           58.94025751030226,
           58.993845972790304,
           59.047434435278355,
           59.101022897766406,
           59.15461136025446,
           59.20819982274251,
           59.26156510153666,
           59.3144840121649,
           59.36740292279312,
           59.42032183342134,
           59.473240744049576,
           59.526159654677805,
           59.57907856530603,
           59.631997475934256,
           59.684916386562485,
           59.737835297190706,
           59.790754207818935,
           59.84367311844717,
           59.89659202907539,
           59.949510939703615,
           60.00242985033184,
           60.05534876096007,
           60.1018363899389,
           60.14703776258787,
           60.192239135236825,
           60.237440507885786,
           60.28264188053475,
           60.32784325318371,
           60.37304462583268,
           60.41824599848164,
           60.4634473711306,
           60.50864874377956,
           60.55385011642852,
           60.599051489077475,
           60.64425286172645,
           60.689454234375404,
           60.73465560702437,
           60.77985697967333,
           60.82505835232229,
           60.87025972497125,
           60.915461097620216,
           60.96066247026918,
           61.00586384291814,
           61.0510652155671,
           61.09626658821606,
           61.14146796086502,
           61.18666933351398,
           61.231870706162944,
           61.277072078811905,
           61.322273451460866,
           61.36747482410983,
           61.41267619675879,
           61.45787756940775,
           61.50307894205671,
           61.54828031470567,
           61.59348168735463,
           61.6386830600036,
           61.683884432652555,
           61.72908580530152,
           61.774287177950484,
           61.81948855059944,
           61.864689923248406,
           61.90989129589737,
           61.95509266854633,
           62.00029404119529,
           62.04549541384425,
           62.09069678649321,
           62.13589815914217,
           62.181099531791126,
           62.2263009044401,
           62.271502277089056,
           62.31670364973802,
           62.36190502238698,
           62.40710639503594,
           62.45230776768491,
           62.49750914033387,
           62.54271051298283,
           62.58791188563179,
           62.633113258280744,
           62.67831463092971,
           62.72351600357867,
           62.768717376227634,
           62.813918748876596,
           62.85912012152556,
           62.90432149417452,
           62.94952286682348,
           62.99472423947244,
           63.0399256121214,
           63.08512698477036,
           63.13035320063422,
           63.175703632919046,
           63.221054065203866,
           63.266404497488686,
           63.31175492977351,
           63.35710536205833,
           63.402455794343155,
           63.447806226627975,
           63.493156658912795,
           63.53850709119761,
           63.583857523482436,
           63.62920795576726,
           63.67455838805208,
           63.719908820336904,
           63.765259252621725,
           63.81060968490654,
           63.85458815995928,
           63.89788065639598,
           63.941173152832675,
           63.984465649269374,
           64.02775814570606,
           64.07105064214277,
           64.11434313857947,
           64.15763563501616,
           64.20092813145286,
           64.24422062788955,
           64.28751312432625,
           64.33080562076294,
           64.37409811719964,
           64.41739061363634,
           64.46068311007303,
           64.50397560650973,
           64.54726810294642,
           64.58982402397248,
           64.63204975667685,
           64.67427548938123,
           64.71650122208561,
           64.75872695478998,
           64.80095268749436,
           64.84317842019874,
           64.8854041529031,
           64.92762988560749,
           64.96985561831187,
           65.01208135101623,
           65.05430708372062,
           65.096532816425,
           65.13875854912938,
           65.18098428183374,
           65.22321001453813,
           65.26543574724249,
           65.30766147994687,
           65.34988721265125,
           65.39211294535563,
           65.43433867806,
           65.47656441076438,
           65.51879014346875,
           65.56101587617313,
           65.60324160887751,
           65.64546734158188,
           65.68769307428626,
           65.72991880699064,
           65.772144539695,
           65.81437027239939,
           65.85659600510377,
           65.89882173780813,
           65.94104747051253,
           65.9832732032169,
           66.02549893592128,
           66.06772466862564,
           66.10995040133002,
           66.1521761340344,
           66.19440186673879,
           66.23662759944315,
           66.27885333214753,
           66.3210790648519,
           66.36330479755628,
           66.40553053026066,
           66.44775626296504,
           66.48998199566941,
           66.53220772837379,
           66.57443346107816,
           66.61665919378254,
           66.65888492648692,
           66.70111065919129,
           66.74333639189567,
           66.78556212460005,
           66.82778785730441,
           66.8700135900088,
           66.91223932271318,
           66.95446505541756,
           66.99669078812192,
           67.0389165208263,
           67.08114225353069,
           67.12336798623505,
           67.16559371893943,
           67.20781945164381,
           67.25004518434818,
           67.29227091705256,
           67.33449664975694,
           67.16971507621884,
           66.79792619643825,
           66.42613731665772,
           66.05434843687716,
           65.6825595570966,
           65.31077067731604,
           64.9389817975355,
           64.56719291775492,
           64.19540403797434,
           63.82361515819383,
           63.45182627841326,
           63.08003739863268,
           62.70824851885214,
           62.33645963907159,
           61.96467075929101,
           61.592881879510465,
           61.20617041380989,
           60.80553110759814,
           60.40489180138641,
           60.00425249517469,
           59.60361318896293,
           59.20297388275117,
           58.80233457653949,
           58.40169527032772,
           58.00105596411596,
           57.60041665790424,
           57.19977735169252,
           56.79913804548075,
           56.39849873926903,
           55.99785943305731,
           55.59722012684555,
           55.196580820633784,
           54.795941514422104,
           54.39530220821034,
           53.99466290199858,
           53.59402359578686,
           53.193384289575135,
           52.79274498336338,
           52.39210567715165,
           51.991466370939925,
           51.59082706472817,
           51.190187758516444,
           50.78954845230472,
           50.38890914609296,
           49.9882698398812,
           49.58763053366951,
           49.18699122745775,
           48.78635192124599,
           48.38571261503427,
           47.98507330882254,
           47.58443400261078,
           47.18379469639906,
           46.78315539018734,
           46.38251608397558,
           45.98187677776382,
           45.581237471552136,
           45.18059816534037,
           44.77995885912861,
           44.37931955291689,
           43.97868024670517,
           43.5780409404934,
           43.17740163428168,
           42.77676232806996,
           42.37612302185819,
           41.975483715646476,
           41.574844409434746,
           41.17420510322299,
           40.77356579701123,
           40.37292649079955,
           39.972287184587785,
           39.57164787837602,
           39.1710085721643,
           38.770369265952574,
           38.369729959740816,
           37.96909065352909,
           37.568451347317364,
           37.167812041105606,
           36.76717273489388,
           36.36653342868216,
           35.9658941224704,
           35.56525481625864,
           35.164615510046914,
           34.76397620383519,
           34.394414516207284,
           34.08700806574708,
           33.77960161528688,
           33.47219516482665,
           33.16478871436645,
           32.85738226390625,
           32.54997581344602,
           32.24256936298579,
           31.935162912525616,
           31.62775646206539,
           31.320350011605157,
           31.012943561144958,
           30.70553711068475,
           30.398130660224524,
           30.090724209764325,
           29.783317759304122,
           29.475911308843894,
           29.1781650563171,
           28.880520508120096,
           28.582875959923065,
           28.28523141172603,
           27.987586863529028,
           27.689942315332026,
           27.392297767135,
           27.09465321893799,
           26.79700867074099,
           26.499364122543955,
           26.201719574346953,
           25.90407502614995,
           25.60643047795292,
           25.308785929755892,
           25.011141381558915,
           24.713496833361884,
           24.415852285164853,
           24.118207736967847,
           23.820563188770844,
           23.522918640573817,
           23.225274092376807,
           22.92762954417981,
           22.629984995982777,
           22.33234044778577,
           22.03469589958877,
           21.737051351391738,
           21.439406803194707,
           21.1417622549977,
           20.844117706800695,
           20.546473158603668,
           20.248828610406665,
           19.951184062209663,
           19.653539514012632,
           19.35589496581563,
           19.058250417618623,
           18.760605869421592,
           18.46296132122456,
           18.165316773027584,
           17.867672224830557,
           17.570027676633522,
           17.27238312843652,
           16.974738580239517,
           16.677094032042486,
           16.37944948384548,
           16.08180493564848,
           15.784160387451447,
           15.486515839254444,
           15.188871291057442,
           14.89122674286041,
           14.59358219466338,
           14.295937646466404,
           13.998293098269372,
           13.700648550072344,
           13.403004001875338,
           13.105359453678336,
           12.807714905481305,
           12.510070357284299,
           12.212425809087296,
           11.914781260890265,
           11.617136712693236,
           11.319492164496259,
           11.021847616299228,
           10.724203068102197,
           10.426558519905193,
           10.12891397170819,
           9.83126942351116,
           9.570110172970594,
           9.491377410712023,
           9.412644648453453,
           9.333911886194882,
           9.255179123936326,
           9.176446361677755,
           9.097713599419185,
           9.018980837160628,
           8.940248074902058,
           8.861515312643489,
           8.782782550384931,
           8.70404978812636,
           8.625317025867789,
           8.546584263609219,
           8.467851501350664,
           8.389118739092092,
           8.310385976833523,
           8.231653214574967,
           8.152920452316396,
           8.074187690057824,
           7.995454927799269,
           7.9167221655406985,
           7.837989403282128,
           7.759256641023572,
           7.680523878765,
           7.605664428156958,
           7.54780000038994,
           7.48993557262293,
           7.432071144855912,
           7.374206717088894,
           7.316342289321886,
           7.258477861554867,
           7.200613433787847,
           7.14274900602084,
           7.0848845782538215,
           7.027020150486803,
           6.969155722719784,
           6.911291294952777,
           6.853426867185758,
           6.79556243941874,
           6.737698011651731,
           6.6798335838847125,
           6.621969156117694,
           6.564104728350686,
           6.506240300583666,
           6.448375872816649,
           6.39051144504964,
           6.332647017282621,
           6.2747825895156035,
           6.216918161748584,
           6.159053733981576,
           6.1011893062145575,
           6.043324878447538,
           5.985460450680531,
           5.927596022913512,
           5.869731595146494,
           5.811867167379486,
           5.754002739612467,
           5.6961383118454485,
           5.6540063122543565,
           5.612178044955466,
           5.570349777656567,
           5.528521510357668,
           5.486693243058776,
           5.444864975759876,
           5.403036708460978,
           5.361208441162087,
           5.319380173863188,
           5.277551906564288,
           5.235723639265397,
           5.193895371966498,
           5.152067104667599,
           5.1102388373686995,
           5.068410570069808,
           5.026582302770909,
           4.98475403547201,
           4.942925768173119,
           4.9010975008742195,
           4.85926923357532,
           4.817440966276429,
           4.77561269897753,
           4.733784431678631,
           4.691956164379731,
           4.650127897080841
          ],
          [
           55.88229784405495,
           55.936549327679444,
           55.99013779053373,
           56.04372625302179,
           56.09731471550984,
           56.15090317799789,
           56.204491640485934,
           56.258080102973985,
           56.31166856546204,
           56.36525702795009,
           56.41884549043814,
           56.47243395292619,
           56.52602241541424,
           56.57961087790228,
           56.63319934039034,
           56.68678780287839,
           56.740376265366436,
           56.79396472785449,
           56.84755319034254,
           56.90114165283059,
           56.95473011531863,
           57.00831857780668,
           57.06190704029474,
           57.115495502782785,
           57.16908396527084,
           57.22267242775888,
           57.27626089024693,
           57.329849352734996,
           57.38343781522303,
           57.437026277711084,
           57.490614740199135,
           57.54420320268718,
           57.59779166517524,
           57.65138012766328,
           57.70496859015134,
           57.75855705263939,
           57.812145515127426,
           57.86573397761549,
           57.91932244010353,
           57.97291090259159,
           58.02649936507963,
           58.08008782756768,
           58.13367629005573,
           58.18726475254378,
           58.240853215031834,
           58.294441677519885,
           58.348030140007936,
           58.40161860249599,
           58.45520706498404,
           58.50879552747209,
           58.56238398996014,
           58.61597245244818,
           58.669560914936234,
           58.72314937742429,
           58.776737839912336,
           58.83032630240039,
           58.88391476488844,
           58.93750322737649,
           58.99109168986453,
           59.04468015235259,
           59.09826861484064,
           59.151857077328685,
           59.205445539816736,
           59.25903400230479,
           59.31262246479284,
           59.36621092728089,
           59.41979938976894,
           59.47338785225699,
           59.526976314745035,
           59.580564777233086,
           59.63415323972114,
           59.68774170220918,
           59.74133016469723,
           59.79491862718528,
           59.84850708967333,
           59.90209555216139,
           59.955684014649435,
           60.009272477137486,
           60.06286093962554,
           60.11644940211359,
           60.17003786460164,
           60.22362632708968,
           60.27721478957774,
           60.33080325206579,
           60.377402473021256,
           60.422603845670224,
           60.467805218319185,
           60.513006590968146,
           60.5582079636171,
           60.60340933626606,
           60.64861070891502,
           60.69381208156399,
           60.73901345421295,
           60.78421482686191,
           60.829416199510874,
           60.87461757215983,
           60.919818944808796,
           60.96502031745776,
           61.010221690106725,
           61.055423062755686,
           61.10062443540465,
           61.14582580805361,
           61.19102718070257,
           61.23622855335154,
           61.281429926000484,
           61.326631298649446,
           61.37183267129841,
           61.41703404394737,
           61.462235416596336,
           61.5074367892453,
           61.55263816189425,
           61.59783953454321,
           61.64304090719217,
           61.68824227984114,
           61.7334436524901,
           61.77864502513906,
           61.823846397788024,
           61.86904777043698,
           61.91424914308595,
           61.9594505157349,
           62.004651888383876,
           62.04985326103283,
           62.09505463368179,
           62.14025600633076,
           62.18545737897972,
           62.23065875162868,
           62.27586012427764,
           62.3210614969266,
           62.366262869575564,
           62.411464242224525,
           62.45666561487349,
           62.501866987522455,
           62.54706836017141,
           62.59226973282037,
           62.63747110546933,
           62.68267247811829,
           62.72787385076726,
           62.77307522341622,
           62.818276596065175,
           62.863477968714136,
           62.9086793413631,
           62.95388071401207,
           62.999082086661026,
           63.04428345930999,
           63.08948483195895,
           63.13468620460791,
           63.17988757725688,
           63.22508894990584,
           63.27029032255479,
           63.315491695203754,
           63.360693067852715,
           63.405894440501676,
           63.451095813150644,
           63.496297185799605,
           63.541498558448566,
           63.58669993109753,
           63.63190130374648,
           63.67710267639545,
           63.72230404904441,
           63.76750542169337,
           63.81270679434233,
           63.857908166991294,
           63.90310953964026,
           63.948310912289216,
           63.99351228493818,
           64.03871365758714,
           64.0837298288325,
           64.12618703242957,
           64.16777212587846,
           64.20992462213282,
           64.25207711838718,
           64.29422961464154,
           64.33638211089591,
           64.37853460715027,
           64.42068710340463,
           64.46283959965899,
           64.50499209591335,
           64.54714459216771,
           64.58929708842207,
           64.63144958467645,
           64.67360208093079,
           64.71575457718517,
           64.75790707343953,
           64.80005956969389,
           64.84221206594825,
           64.88436456220262,
           64.92651705845697,
           64.96866955471134,
           65.0108220509657,
           65.05297454722006,
           65.09512704347442,
           65.1372795397288,
           65.17943203598314,
           65.22158453223751,
           65.26373702849186,
           65.30588952474623,
           65.3480420210006,
           65.39019451725495,
           65.43234701350931,
           65.47449950976369,
           65.51665200601803,
           65.55880450227241,
           65.60095699852677,
           65.64310949478113,
           65.68526199103549,
           65.72741448728985,
           65.76956698354421,
           65.81171947979857,
           65.85387197605293,
           65.89602447230729,
           65.93817696856166,
           65.98032946481602,
           66.02248196107038,
           66.06463445732474,
           66.10678695357912,
           66.14893944983346,
           66.19109194608784,
           66.2332444423422,
           66.27539693859656,
           66.31754943485093,
           66.35970193110528,
           66.40185442735965,
           66.44400692361401,
           66.48615941986837,
           66.52831191612275,
           66.57046441237709,
           66.61261690863145,
           66.65476940488583,
           66.69692190114017,
           66.73907439739455,
           66.78122689364889,
           66.82337938990327,
           66.86553188615763,
           66.90768438241199,
           66.94983687866636,
           66.99198937492072,
           67.03414187117508,
           67.07629436742944,
           67.1184468636838,
           67.16059935993816,
           67.20275185619253,
           67.2449043524469,
           67.28705684870125,
           67.32920934495561,
           67.37136184120997,
           67.41351433746433,
           67.4556668337187,
           67.49781932997307,
           67.53997182622743,
           67.58212432248179,
           67.3908407542415,
           66.96612112150656,
           66.54140148877167,
           66.11668185603676,
           65.69196222330184,
           65.26724259056694,
           64.84252295783205,
           64.41780332509711,
           63.99308369236217,
           63.568364059627314,
           63.14364442689238,
           62.718924794157445,
           62.3150947668349,
           61.914493088347726,
           61.5138914098605,
           61.113289731373314,
           60.71268805288613,
           60.312086374398916,
           59.911484695911724,
           59.51088301742454,
           59.11028133893732,
           58.70967966045009,
           58.30907798196295,
           57.90847630347573,
           57.50787462498851,
           57.107272946501325,
           56.706671268014134,
           56.30606958952691,
           55.905467911039736,
           55.50486623255255,
           55.104264554065324,
           54.703662875578104,
           54.303061197090955,
           53.90245951860374,
           53.501857840116514,
           53.10125616162934,
           52.70065448314215,
           52.300052804654925,
           51.89945112616773,
           51.498849447680556,
           51.098247769193335,
           50.69764609070616,
           50.297044412218966,
           49.896442733731746,
           49.495841055244526,
           49.09523937675738,
           48.69463769827016,
           48.294036019782936,
           47.89343434129575,
           47.49283266280857,
           47.09223098432135,
           46.691629305834155,
           46.29102762734698,
           45.89042594885976,
           45.48982427037254,
           45.08922259188539,
           44.68862091339817,
           44.28801923491094,
           43.887417556423756,
           43.48681587793658,
           43.08621419944936,
           42.68561252096217,
           42.28501084247499,
           41.88440916398777,
           41.48380748550058,
           41.0832058070134,
           40.68260412852617,
           40.28200245003895,
           39.88140077155181,
           39.48079909306458,
           39.08019741457737,
           38.67959573609018,
           38.278994057603,
           37.87839237911577,
           37.47779070062859,
           37.077189022141404,
           36.676587343654184,
           36.275985665167,
           35.875383986679815,
           35.47478230819259,
           35.074180629705374,
           34.67357895121819,
           34.27297727273101,
           33.907799701237245,
           33.613470343730434,
           33.31914098622362,
           33.024811628716776,
           32.730482271209965,
           32.436152913703154,
           32.14182355619631,
           31.847494198689468,
           31.55316484118268,
           31.258835483675846,
           30.964506126169,
           30.670176768662184,
           30.375847411155373,
           30.081518053648534,
           29.78718869614172,
           29.492859338634904,
           29.198529981128065,
           28.90420062362125,
           28.609871266114435,
           28.315541908607596,
           28.021212551100753,
           27.72688319359394,
           27.432553836087123,
           27.138224478580288,
           26.843895121073473,
           26.549565763566658,
           26.255236406059815,
           25.960907048553004,
           25.66657769104619,
           25.37224833353935,
           25.077918976032507,
           24.78358961852572,
           24.489260261018877,
           24.194930903512038,
           23.900601546005227,
           23.606272188498416,
           23.31194283099157,
           23.017613473484758,
           22.723284115977943,
           22.4289547584711,
           22.134625400964286,
           21.84029604345747,
           21.54596668595063,
           21.251637328443792,
           20.957307970936977,
           20.662978613430163,
           20.368649255923323,
           20.074319898416505,
           19.779990540909694,
           19.485661183402854,
           19.19133182589604,
           18.897002468389225,
           18.602673110882385,
           18.308343753375546,
           18.014014395868756,
           17.719685038361916,
           17.425355680855073,
           17.131026323348262,
           16.836696965841448,
           16.542367608334608,
           16.24803825082779,
           15.953708893320979,
           15.65937953581414,
           15.365050178307323,
           15.07072082080051,
           14.776391463293669,
           14.479201946825032,
           14.181557398628055,
           13.883912850431024,
           13.586268302233993,
           13.28862375403699,
           12.990979205839986,
           12.693334657642957,
           12.395690109445953,
           12.098045561248949,
           11.800401013051918,
           11.502756464854889,
           11.205111916657911,
           10.907467368460882,
           10.60982282026385,
           10.312178272066847,
           10.014533723869842,
           9.716889175672812,
           9.455729925132246,
           9.376997162873675,
           9.298264400615103,
           9.219531638356536,
           9.156410620275324,
           9.098546192508305,
           9.040681764741288,
           8.982817336974279,
           8.92495290920726,
           8.867088481440241,
           8.809224053673235,
           8.751359625906215,
           8.693495198139196,
           8.635630770372178,
           8.57776634260517,
           8.519901914838151,
           8.462037487071132,
           8.404173059304124,
           8.346308631537106,
           8.288444203770087,
           8.23057977600308,
           8.17271534823606,
           8.114850920469042,
           8.056986492702034,
           7.999122064935015,
           7.941257637167997,
           7.883393209400977,
           7.82552878163397,
           7.767664353866951,
           7.709799926099932,
           7.651935498332924,
           7.594071070565906,
           7.536206642798887,
           7.478342215031879,
           7.42047778726486,
           7.362613359497841,
           7.304748931730822,
           7.246884503963815,
           7.189020076196796,
           7.131155648429777,
           7.073291220662769,
           7.0154267928957506,
           6.957562365128732,
           6.899697937361724,
           6.841833509594705,
           6.783969081827687,
           6.726104654060678,
           6.66824022629366,
           6.61037579852664,
           6.552511370759621,
           6.494646942992614,
           6.436782515225596,
           6.378918087458577,
           6.321053659691569,
           6.26318923192455,
           6.205324804157533,
           6.147460376390524,
           6.089595948623505,
           6.031731520856487,
           5.973867093089467,
           5.91600266532246,
           5.8581382375554405,
           5.800273809788422,
           5.742409382021414,
           5.684544954254395,
           5.626680526487377,
           5.568816098720369,
           5.51095167095335,
           5.4530872431863315,
           5.395222815419324,
           5.337358387652305,
           5.279493959885286,
           5.221629532118268,
           5.16376510435126,
           5.105900676584241,
           5.048036248817223,
           4.990171821050214,
           4.932307393283195,
           4.874442965516176,
           4.8165785377491686,
           4.765426202217012,
           4.7235979349181125,
           4.681769667619214,
           4.639941400320322
          ],
          [
           56.13179311821963,
           56.18604460184413,
           56.24029608546862,
           56.29454756909312,
           56.34879905271762,
           56.40305053634211,
           56.457302019966605,
           56.5115535035911,
           56.56580498721559,
           56.62005647084009,
           56.67430795446458,
           56.72855943808908,
           56.78281092171357,
           56.83706240533806,
           56.89131388896256,
           56.945565372587055,
           56.99981685621155,
           57.05406833983604,
           57.10798831336797,
           57.161576775856005,
           57.215165238344056,
           57.26875370083211,
           57.32234216332016,
           57.37593062580821,
           57.42951908829626,
           57.48310755078431,
           57.53669601327236,
           57.59028447576041,
           57.643872938248464,
           57.697461400736515,
           57.751049863224566,
           57.8046383257126,
           57.85822678820065,
           57.91181525068871,
           57.96540371317676,
           58.01899217566482,
           58.07258063815286,
           58.12616910064091,
           58.17975756312896,
           58.23334602561701,
           58.28693448810506,
           58.34052295059311,
           58.39411141308116,
           58.447699875569214,
           58.50128833805726,
           58.554876800545316,
           58.60846526303337,
           58.66205372552142,
           58.715642188009454,
           58.769230650497505,
           58.822819112985556,
           58.87640757547361,
           58.92999603796166,
           58.98358450044971,
           59.03717296293776,
           59.09076142542581,
           59.14434988791386,
           59.19793835040191,
           59.251526812889956,
           59.30511527537801,
           59.35870373786606,
           59.412292200354116,
           59.46588066284217,
           59.51946912533021,
           59.57305758781826,
           59.62664605030631,
           59.680234512794364,
           59.733822975282415,
           59.78741143777046,
           59.84099990025851,
           59.89458836274656,
           59.94817682523461,
           60.001765287722655,
           60.055353750210706,
           60.108942212698764,
           60.162530675186815,
           60.21611913767486,
           60.26970760016291,
           60.32329606265096,
           60.37688452513901,
           60.43047298762706,
           60.484061450115114,
           60.537649912603165,
           60.591238375091216,
           60.63783759604668,
           60.68303896869565,
           60.72824034134461,
           60.77344171399357,
           60.81864308664253,
           60.863844459291485,
           60.909045831940446,
           60.95424720458941,
           60.999448577238375,
           61.04464994988734,
           61.0898513225363,
           61.13505269518525,
           61.18025406783422,
           61.225455440483174,
           61.27065681313215,
           61.31585818578111,
           61.36105955843007,
           61.40626093107903,
           61.45146230372799,
           61.496663676376954,
           61.54186504902591,
           61.587066421674876,
           61.63226779432384,
           61.6774691669728,
           61.72267053962176,
           61.76787191227072,
           61.81307328491968,
           61.85827465756864,
           61.903476030217604,
           61.948677402866565,
           61.993878775515526,
           62.03908014816449,
           62.08428152081345,
           62.12948289346241,
           62.17468426611137,
           62.21988563876033,
           62.2650870114093,
           62.31028838405825,
           62.355489756707215,
           62.400691129356176,
           62.44589250200514,
           62.49109387465411,
           62.53629524730307,
           62.58149661995203,
           62.62669799260099,
           62.67189936524995,
           62.71710073789891,
           62.76230211054788,
           62.80750348319684,
           62.8527048558458,
           62.89790622849476,
           62.943107601143716,
           62.988308973792684,
           63.033510346441645,
           63.078711719090606,
           63.12391309173957,
           63.16911446438853,
           63.214315837037496,
           63.25951720968645,
           63.30471858233541,
           63.34991995498437,
           63.39512132763333,
           63.4403227002823,
           63.48552407293126,
           63.530725445580224,
           63.57588051771736,
           63.62080408849112,
           63.665727659264874,
           63.71065123003863,
           63.75557480081239,
           63.800498371586144,
           63.845421942359906,
           63.89034551313366,
           63.935269083907414,
           63.98019265468118,
           64.02511622545494,
           64.0700397962287,
           64.11496336700245,
           64.1598869377762,
           64.20481050854997,
           64.24973407932373,
           64.29465765009749,
           64.33958122087125,
           64.3820384244683,
           64.423262444477,
           64.4644864644857,
           64.50571048449441,
           64.54693450450313,
           64.58815852451184,
           64.62938254452054,
           64.67060656452925,
           64.71183058453795,
           64.75305460454666,
           64.79427862455537,
           64.83550264456407,
           64.87672666457279,
           64.91795068458148,
           64.9591747045902,
           65.0003987245989,
           65.04162274460761,
           65.0828467646163,
           65.12407078462502,
           65.16529480463372,
           65.20651882464243,
           65.24774284465113,
           65.28925056488379,
           65.33140306113816,
           65.37355555739252,
           65.4157080536469,
           65.45786054990126,
           65.5000130461556,
           65.54216554240998,
           65.58431803866434,
           65.6264705349187,
           65.66862303117307,
           65.71077552742743,
           65.75292802368179,
           65.79508051993615,
           65.83723301619051,
           65.87938551244487,
           65.92153800869923,
           65.96369050495359,
           66.00584300120795,
           66.04799549746232,
           66.09014799371668,
           66.13230048997104,
           66.1744529862254,
           66.21660548247976,
           66.25875797873412,
           66.30091047498848,
           66.34306297124286,
           66.3852154674972,
           66.42736796375158,
           66.46952046000592,
           66.5116729562603,
           66.55382545251467,
           66.59597794876902,
           66.63813044502339,
           66.68028294127775,
           66.72243543753211,
           66.76458793378649,
           66.80674043004083,
           66.8488929262952,
           66.89104542254957,
           66.93319791880391,
           66.97535041505829,
           67.01750291131265,
           67.059655407567,
           67.10180790382137,
           67.14396040007573,
           67.18611289633009,
           67.22826539258446,
           67.27041788883882,
           67.31257038509318,
           67.35472288134756,
           67.3968753776019,
           67.43902787385628,
           67.48118037011064,
           67.523332866365,
           67.56548536261936,
           67.60763785887372,
           67.64979035512808,
           67.69194285138244,
           67.73409534763681,
           67.77624784389116,
           67.81840034014553,
           67.62711677190524,
           67.2023971391703,
           66.77767750643541,
           66.35295787370052,
           65.92823824096558,
           65.50351860823068,
           65.07879897549579,
           64.65407934276085,
           64.22935971002592,
           63.804640077291054,
           63.37992044455612,
           62.955200811821186,
           62.53048117908628,
           62.105761546351395,
           61.681041913616454,
           61.25632228088156,
           60.831602648146664,
           60.406883015411736,
           59.98216338267684,
           59.55744374994194,
           59.132724117207,
           58.70800448447206,
           58.28328485173721,
           57.85856521900227,
           57.43384558626734,
           57.00912595353244,
           56.584406320797555,
           56.15968668806261,
           55.734967055327715,
           55.31024742259282,
           54.88552778985788,
           54.460808157122955,
           54.03608852438809,
           53.61136889165316,
           53.18664925891822,
           52.761929626183324,
           52.337209993448425,
           51.9124903607135,
           51.4877707279786,
           51.0630510952437,
           50.63833146250876,
           50.21361182977387,
           49.81263033319195,
           49.41202865470472,
           49.01142697621749,
           48.61082529773036,
           48.21022361924314,
           47.80962194075591,
           47.409020262268726,
           47.00841858378155,
           46.60781690529432,
           46.207215226807136,
           45.80661354831995,
           45.40601186983273,
           45.00541019134552,
           44.604808512858355,
           44.204206834371135,
           43.803605155883915,
           43.40300347739674,
           43.002401798909546,
           42.601800120422325,
           42.20119844193514,
           41.800596763447956,
           41.399995084960736,
           40.99939340647356,
           40.59879172798637,
           40.19819004949915,
           39.797588371011926,
           39.396986692524784,
           38.99638501403756,
           38.59578333555034,
           38.19518165706315,
           37.79457997857597,
           37.39397830008875,
           36.99337662160156,
           36.592774943114385,
           36.19217326462716,
           35.79157158613997,
           35.39096990765279,
           34.99036822916556,
           34.58976655067835,
           34.18916487219116,
           33.78856319370398,
           33.42338562221022,
           33.12905626470341,
           32.8347269071966,
           32.54039754968975,
           32.24606819218294,
           31.951738834676128,
           31.65740947716929,
           31.36308011966245,
           31.06875076215566,
           30.77442140464882,
           30.480092047141977,
           30.185762689635162,
           29.89143333212835,
           29.597103974621508,
           29.302774617114697,
           29.008445259607882,
           28.71411590210104,
           28.419786544594224,
           28.125457187087413,
           27.83112782958057,
           27.53679847207373,
           27.242469114566916,
           26.948139757060105,
           26.653810399553265,
           26.359481042046447,
           26.065151684539632,
           25.770822327032793,
           25.47649296952598,
           25.182163612019163,
           24.887834254512327,
           24.593504897005484,
           24.299175539498695,
           24.004846181991855,
           23.710516824485016,
           23.4161874669782,
           23.12185810947139,
           22.82752875196455,
           22.533199394457732,
           22.238870036950917,
           21.944540679444074,
           21.65021132193726,
           21.35588196443045,
           21.061552606923605,
           20.767223249416766,
           20.472893891909955,
           20.178564534403137,
           19.884235176896297,
           19.589905819389482,
           19.295576461882668,
           19.001247104375828,
           18.706917746869017,
           18.412588389362202,
           18.12308081743746,
           17.83892704240588,
           17.554773267374358,
           17.27061949234278,
           16.9864657173112,
           16.70231194227965,
           16.418158167248098,
           16.13400439221652,
           15.849850617184972,
           15.565696842153418,
           15.281543067121843,
           14.99738929209029,
           14.713235517058738,
           14.429081742027162,
           14.144927966995585,
           13.86077419196406,
           13.57662041693248,
           13.292466641900905,
           13.008312866869353,
           12.724159091837802,
           12.440005316806225,
           12.155851541774673,
           11.871697766743122,
           11.587543991711545,
           11.303390216679967,
           11.019236441648442,
           10.735082666616865,
           10.450928891585287,
           10.166775116553735,
           9.882621341522183,
           9.598467566490607,
           9.349345098267417,
           9.275379164085859,
           9.201413229904297,
           9.127447295722735,
           9.05348136154119,
           8.97951542735963,
           8.905549493178068,
           8.831583558996522,
           8.757617624814962,
           8.6836516906334,
           8.609685756451855,
           8.535719822270295,
           8.461753888088733,
           8.387787953907173,
           8.313822019725626,
           8.239856085544066,
           8.165890151362504,
           8.091924217180958,
           8.017958282999398,
           7.943992348817837,
           7.870026414636291,
           7.796060480454729,
           7.722094546273169,
           7.648128612091623,
           7.574162677910063,
           7.500196743728502,
           7.426230809546942,
           7.352264875365394,
           7.2782989411838335,
           7.2043330070022735,
           7.130367072820727,
           7.056401138639167,
           6.982435204457607,
           6.9084692702760595,
           6.834503336094499,
           6.760537401912938,
           6.686571467731378,
           6.61260553354983,
           6.53863959936827,
           6.4646736651867105,
           6.390707731005164,
           6.316741796823603,
           6.263511128690184,
           6.223664758892442,
           6.183818389094694,
           6.143972019296946,
           6.1041256494992036,
           6.064279279701456,
           6.024432909903707,
           5.984586540105958,
           5.944740170308218,
           5.904893800510468,
           5.865047430712719,
           5.825201060914979,
           5.785354691117229,
           5.74550832131948,
           5.705661951521741,
           5.665815581723992,
           5.625969211926242,
           5.5861228421284945,
           5.546276472330753,
           5.506430102533004,
           5.4665837327352556,
           5.426737362937514,
           5.386890993139765,
           5.347044623342017,
           5.307198253544275,
           5.267351883746528,
           5.227505513948778,
           5.187659144151037,
           5.147812774353289,
           5.1079664045555395,
           5.068120034757792,
           5.02827366496005,
           4.988427295162301,
           4.948580925364553,
           4.908734555566812,
           4.8688881857690625,
           4.829041815971315,
           4.789195446173572,
           4.749349076375824,
           4.709502706578076,
           4.669656336780327,
           4.629809966982585
          ],
          [
           56.381288392384334,
           56.43553987600883,
           56.489791359633315,
           56.54404284325781,
           56.59829432688231,
           56.6525458105068,
           56.706797294131306,
           56.761048777755796,
           56.81530026138029,
           56.869551745004784,
           56.92380322862928,
           56.978054712253766,
           57.03230619587826,
           57.08655767950277,
           57.14080916312726,
           57.195060646751756,
           57.24931213037624,
           57.303563614000744,
           57.357815097625235,
           57.41206658124973,
           57.46631806487422,
           57.52056954849872,
           57.57482103212321,
           57.62907251574771,
           57.683323999372206,
           57.737575482996704,
           57.791826966621194,
           57.84607845024569,
           57.90032993387018,
           57.95458141749468,
           58.00883290111918,
           58.06308438474367,
           58.117335868368166,
           58.17158735199266,
           58.225838835617154,
           58.27942729869025,
           58.3330157611783,
           58.386604223666346,
           58.440192686154404,
           58.49378114864245,
           58.5473696111305,
           58.60095807361854,
           58.65454653610661,
           58.708134998594645,
           58.761723461082696,
           58.81531192357075,
           58.8689003860588,
           58.922488848546855,
           58.9760773110349,
           59.02966577352294,
           59.08325423601101,
           59.136842698499045,
           59.1904311609871,
           59.244019623475154,
           59.29760808596319,
           59.351196548451256,
           59.40478501093929,
           59.45837347342735,
           59.511961935915394,
           59.565550398403445,
           59.619138860891496,
           59.67272732337955,
           59.726315785867605,
           59.77990424835565,
           59.83349271084369,
           59.88708117333176,
           59.9406696358198,
           59.994258098307846,
           60.047846560795904,
           60.10143502328395,
           60.155023485772006,
           60.20861194826005,
           60.2622004107481,
           60.315788873236144,
           60.369377335724195,
           60.422965798212246,
           60.4765542607003,
           60.53014272318835,
           60.58373118567639,
           60.63731964816444,
           60.690908110652494,
           60.74449657314055,
           60.7980850356286,
           60.851673498116654,
           60.898272719072125,
           60.943474091721086,
           60.98867546437005,
           61.03387683701901,
           61.079078209667976,
           61.12427958231693,
           61.169480954965884,
           61.21468232761485,
           61.25988370026381,
           61.305085072912775,
           61.35028644556174,
           61.3954878182107,
           61.440689190859665,
           61.48589056350862,
           61.531091936157594,
           61.576293308806555,
           61.6214946814555,
           61.66669605410447,
           61.71189742675343,
           61.75709879940239,
           61.80230017205135,
           61.84750154470032,
           61.89270291734927,
           61.93790428999823,
           61.983105662647205,
           62.02830703529616,
           62.07350840794512,
           62.11870978059409,
           62.16391115324305,
           62.20911252589201,
           62.25431389854097,
           62.29951527118993,
           62.344716643838886,
           62.38991801648785,
           62.435119389136815,
           62.48032076178577,
           62.525522134434745,
           62.5707235070837,
           62.61592487973265,
           62.66112625238162,
           62.70632762503058,
           62.75152899767955,
           62.79673037032851,
           62.84193174297747,
           62.887133115626426,
           62.932334488275394,
           62.97753586092435,
           63.02273723357331,
           63.06793860622227,
           63.11295477737597,
           63.15787834814973,
           63.20280191892348,
           63.247725489697245,
           63.292649060471,
           63.33757263124476,
           63.38249620201852,
           63.42741977279228,
           63.47234334356603,
           63.517266914339785,
           63.562190485113554,
           63.60711405588731,
           63.65203762666107,
           63.696961197434824,
           63.74188476820859,
           63.78680833898235,
           63.8317319097561,
           63.87665548052986,
           63.92157905130362,
           63.96650262207737,
           64.01142619285113,
           64.0563497636249,
           64.10127333439864,
           64.1461969051724,
           64.19112047594616,
           64.23604404671993,
           64.28096761749369,
           64.32589118826743,
           64.3708147590412,
           64.41573832981496,
           64.46066190058872,
           64.50558547136248,
           64.55050904213624,
           64.59543261290999,
           64.63788981650706,
           64.67911383651575,
           64.72033785652447,
           64.76156187653316,
           64.80278589654186,
           64.84400991655058,
           64.88523393655929,
           64.926457956568,
           64.9676819765767,
           65.0089059965854,
           65.05013001659411,
           65.09135403660281,
           65.13257805661152,
           65.17380207662023,
           65.21502609662895,
           65.25625011663764,
           65.29747413664634,
           65.33869815665506,
           65.37992217666377,
           65.42114619667247,
           65.46237021668117,
           65.50359423668989,
           65.54481825669858,
           65.58604227670729,
           65.627266296716,
           65.66849031672471,
           65.70971433673341,
           65.75093835674213,
           65.79216237675084,
           65.83338639675954,
           65.87461041676823,
           65.91583443677695,
           65.95705845678565,
           65.99828247679436,
           66.03950649680306,
           66.08073051681177,
           66.12195453682048,
           66.16317855682918,
           66.20440257683788,
           66.2456265968466,
           66.2868506168553,
           66.328074636864,
           66.36929865687272,
           66.41072900388916,
           66.45288150014352,
           66.49503399639788,
           66.53718649265224,
           66.57933898890661,
           66.62149148516096,
           66.66364398141533,
           66.70579647766968,
           66.74794897392404,
           66.79010147017841,
           66.83225396643277,
           66.87440646268715,
           66.91655895894151,
           66.95871145519585,
           67.00086395145023,
           67.04301644770459,
           67.08516894395896,
           67.12732144021331,
           67.16947393646768,
           67.21162643272203,
           67.25377892897639,
           67.29593142523076,
           67.33808392148512,
           67.3802364177395,
           67.42238891399386,
           67.46454141024822,
           67.50669390650256,
           67.54884640275694,
           67.59099889901131,
           67.63315139526566,
           67.67530389152003,
           67.71745638777438,
           67.75960888402875,
           67.80176138028311,
           67.84391387653747,
           67.88606637279183,
           67.92821886904619,
           67.97037136530055,
           68.01252386155491,
           68.05467635780929,
           67.86339278956899,
           67.43867315683406,
           67.01395352409915,
           66.58923389136426,
           66.16451425862932,
           65.73979462589443,
           65.31507499315954,
           64.89035536042459,
           64.46563572768966,
           64.04091609495481,
           63.61619646221987,
           63.19147682948494,
           62.76675719675005,
           62.34203756401515,
           61.91731793128021,
           61.49259829854532,
           61.06787866581042,
           60.643159033075484,
           60.218439400340586,
           59.79371976760568,
           59.36900013487076,
           58.94428050213581,
           58.519560869400955,
           58.09484123666603,
           57.67012160393109,
           57.24540197119619,
           56.820682338461296,
           56.39596270572636,
           55.97124307299147,
           55.54652344025657,
           55.12180380752163,
           54.697084174786696,
           54.27236454205185,
           53.8476449093169,
           53.42292527658198,
           52.99820564384707,
           52.57348601111218,
           52.148766378377246,
           51.724046745642354,
           51.29932711290746,
           50.874607480172514,
           50.449887847437616,
           50.025168214702724,
           49.60044858196779,
           49.175728949232855,
           48.75100931649799,
           48.326289683763065,
           47.90157005102812,
           47.47685041829323,
           47.05213078555833,
           46.6274111528234,
           46.2026915200885,
           45.77797188735361,
           45.353252254618674,
           44.92853262188373,
           44.50381298914888,
           44.07909335641394,
           43.65437372367901,
           43.229654090944116,
           42.80493445820921,
           42.38021482547428,
           41.955495192739384,
           41.530775560004486,
           41.10605592726955,
           40.68133629453465,
           40.25661666179976,
           39.83189702906482,
           39.4071773963299,
           38.982457763595036,
           38.5577381308601,
           38.13301849812517,
           37.71076757803611,
           37.31016589954892,
           36.90956422106171,
           36.508962542574515,
           36.10836086408734,
           35.70775918560012,
           35.30715750711293,
           34.90655582862575,
           34.50595415013852,
           34.10535247165131,
           33.704750793164116,
           33.30414911467694,
           32.93897154318318,
           32.64464218567637,
           32.35031282816955,
           32.05598347066271,
           31.761654113155895,
           31.467324755649084,
           31.172995398142245,
           30.8786660406354,
           30.584336683128615,
           30.290007325621772,
           29.995677968114933,
           29.70134861060812,
           29.407019253101307,
           29.112689895594464,
           28.818360538087653,
           28.53094795016055,
           28.24679417512897,
           27.962640400097417,
           27.678486625065865,
           27.394332850034292,
           27.110179075002712,
           26.826025299971164,
           26.54187152493961,
           26.25771774990803,
           25.97356397487648,
           25.68941019984493,
           25.405256424813352,
           25.121102649781804,
           24.83694887475025,
           24.552795099718676,
           24.268641324687096,
           23.984487549655572,
           23.700333774623992,
           23.416179999592412,
           23.13202622456086,
           22.847872449529312,
           22.563718674497736,
           22.279564899466184,
           21.995411124434636,
           21.711257349403056,
           21.427103574371504,
           21.142949799339952,
           20.858796024308372,
           20.5746422492768,
           20.290488474245247,
           20.006334699213696,
           19.722180924182116,
           19.438027149150564,
           19.153873374119016,
           18.869719599087436,
           18.585565824055884,
           18.301412049024332,
           18.01725827399276,
           17.73310449896118,
           17.448950723929656,
           17.16479694889808,
           16.8806431738665,
           16.596489398834947,
           16.312335623803396,
           16.02818184877182,
           15.74402807374027,
           15.459874298708717,
           15.175720523677143,
           14.891566748645587,
           14.607412973614036,
           14.323259198582459,
           14.039105423550883,
           13.754951648519356,
           13.47079787348778,
           13.186644098456203,
           12.90249032342465,
           12.618336548393101,
           12.334182773361523,
           12.05002899832997,
           11.76587522329842,
           11.481721448266843,
           11.197567673235264,
           10.91341389820374,
           10.629260123172163,
           10.345106348140584,
           10.060952573109034,
           9.776798798077483,
           9.492645023045904,
           9.243522554822716,
           9.169556620641156,
           9.095590686459595,
           9.021624752278033,
           8.947658818096487,
           8.873692883914927,
           8.799726949733367,
           8.72576101555182,
           8.65179508137026,
           8.577829147188698,
           8.503863213007152,
           8.429897278825592,
           8.35593134464403,
           8.28196541046247,
           8.207999476280923,
           8.134033542099363,
           8.060067607917803,
           7.986101673736256,
           7.912135739554696,
           7.838169805373135,
           7.764203871191588,
           7.697751140074761,
           7.643165024006855,
           7.58857890793896,
           7.533992791871054,
           7.479406675803148,
           7.424820559735242,
           7.370234443667346,
           7.31564832759944,
           7.261062211531533,
           7.206476095463637,
           7.151889979395731,
           7.097303863327826,
           7.04271774725993,
           6.988131631192024,
           6.933545515124118,
           6.878959399056212,
           6.824373282988316,
           6.769787166920409,
           6.715201050852503,
           6.660614934784608,
           6.606028818716702,
           6.551442702648796,
           6.4968565865809,
           6.4422704705129945,
           6.3876843544450885,
           6.333098238377192,
           6.278512122309286,
           6.223926006241381,
           6.169339890173474,
           6.114753774105579,
           6.060167658037673,
           6.005581541969766,
           5.950995425901871,
           5.896409309833965,
           5.841823193766059,
           5.787237077698164,
           5.732650961630258,
           5.678064845562351,
           5.623478729494445,
           5.568892613426549,
           5.514306497358643,
           5.459720381290737,
           5.4166163042816144,
           5.376769934483866,
           5.336923564686117,
           5.2970771948883755,
           5.257230825090628,
           5.217384455292878,
           5.177538085495137,
           5.137691715697389,
           5.09784534589964,
           5.057998976101892,
           5.018152606304151,
           4.978306236506402,
           4.938459866708653,
           4.898613496910912,
           4.858767127113163,
           4.818920757315414,
           4.7790743875176736,
           4.739228017719925,
           4.699381647922176,
           4.659535278124427,
           4.619688908326686
          ],
          [
           56.63078366654902,
           56.68503515017352,
           56.739286633798,
           56.7935381174225,
           56.847789601047,
           56.902041084671495,
           56.95629256829599,
           57.01054405192048,
           57.06479553554498,
           57.11904701916947,
           57.17329850279397,
           57.22754998641846,
           57.28180147004296,
           57.336052953667455,
           57.390304437291945,
           57.44455592091644,
           57.49880740454094,
           57.55305888816544,
           57.607310371789936,
           57.66156185541442,
           57.71581333903892,
           57.770064822663414,
           57.82431630628791,
           57.87856778991241,
           57.93281927353689,
           57.98707075716139,
           58.04132224078589,
           58.095573724410386,
           58.14982520803488,
           58.20407669165937,
           58.258328175283864,
           58.31257965890836,
           58.36683114253285,
           58.42108262615735,
           58.47533410978185,
           58.52958559340634,
           58.58383707703083,
           58.638088560655326,
           58.692340044279824,
           58.74659152790432,
           58.80084301152882,
           58.85509449515331,
           58.9093459787778,
           58.9635974624023,
           59.017848946026795,
           59.072100429651286,
           59.12635191327578,
           59.180603396900274,
           59.234854880524765,
           59.28910636414926,
           59.34335784777376,
           59.397277821524476,
           59.45086628401253,
           59.50445474650057,
           59.55804320898862,
           59.61163167147667,
           59.66522013396472,
           59.718808596452774,
           59.772397058940825,
           59.825985521428876,
           59.87957398391693,
           59.93316244640498,
           59.98675090889303,
           60.04033937138107,
           60.09392783386912,
           60.14751629635717,
           60.201104758845226,
           60.25469322133327,
           60.30828168382132,
           60.36187014630937,
           60.41545860879742,
           60.46904707128547,
           60.52263553377352,
           60.576223996261575,
           60.62981245874962,
           60.68340092123768,
           60.73698938372572,
           60.79057784621377,
           60.84416630870182,
           60.897754771189874,
           60.951343233677925,
           61.004931696165976,
           61.05852015865402,
           61.11210862114208,
           61.15870784209755,
           61.20390921474651,
           61.249110587395464,
           61.294311960044425,
           61.339513332693386,
           61.38471470534235,
           61.429916077991315,
           61.475117450640276,
           61.52031882328924,
           61.5655201959382,
           61.61072156858717,
           61.65592294123611,
           61.70112431388509,
           61.74632568653405,
           61.79152705918301,
           61.83672843183197,
           61.88192980448093,
           61.927131177129894,
           61.97233254977886,
           62.01753392242782,
           62.06273529507677,
           62.10793666772574,
           62.1531380403747,
           62.19833941302366,
           62.24354078567263,
           62.28874215832159,
           62.333943530970544,
           62.37914490361951,
           62.424346276268466,
           62.46954764891743,
           62.51474902156639,
           62.559950394215356,
           62.60510546626081,
           62.65002903703458,
           62.69495260780833,
           62.739876178582094,
           62.78479974935585,
           62.8297233201296,
           62.87464689090337,
           62.919570461677125,
           62.96449403245089,
           63.00941760322464,
           63.054341173998395,
           63.099264744772164,
           63.14418831554591,
           63.18911188631968,
           63.234035457093434,
           63.27895902786719,
           63.32388259864096,
           63.368806169414704,
           63.413729740188465,
           63.45865331096222,
           63.50357688173598,
           63.54850045250974,
           63.593424023283504,
           63.63834759405726,
           63.68327116483101,
           63.728194735604774,
           63.77311830637853,
           63.81804187715228,
           63.86296544792605,
           63.9078890186998,
           63.95281258947357,
           63.99773616024732,
           64.04265973102108,
           64.08758330179484,
           64.1325068725686,
           64.17743044334236,
           64.2223540141161,
           64.26727758488987,
           64.31220115566363,
           64.35712472643738,
           64.40204829721114,
           64.4469718679849,
           64.49189543875866,
           64.53681900953242,
           64.58174258030617,
           64.62666615107993,
           64.67158972185369,
           64.71651329262745,
           64.7614368634012,
           64.80636043417496,
           64.85128400494872,
           64.89374120854579,
           64.93496522855449,
           64.97618924856319,
           65.0174132685719,
           65.05863728858061,
           65.09986130858931,
           65.14108532859802,
           65.18230934860674,
           65.22353336861543,
           65.26475738862413,
           65.30598140863285,
           65.34720542864156,
           65.38842944865027,
           65.42965346865896,
           65.47087748866767,
           65.51210150867638,
           65.5533255286851,
           65.59454954869379,
           65.63577356870249,
           65.6769975887112,
           65.71822160871992,
           65.75944562872861,
           65.80066964873733,
           65.84189366874602,
           65.88311768875474,
           65.92434170876345,
           65.96556572877215,
           66.00678974878086,
           66.04801376878956,
           66.08923778879827,
           66.13046180880698,
           66.17168582881568,
           66.21290984882438,
           66.2541338688331,
           66.2953578888418,
           66.3365819088505,
           66.37780592885922,
           66.41902994886792,
           66.46025396887663,
           66.50147798888534,
           66.54270200889404,
           66.58392602890274,
           66.62515004891145,
           66.66637406892015,
           66.70759808892886,
           66.74882210893757,
           66.79004612894627,
           66.83127014895499,
           66.8724941689637,
           66.9137181889724,
           66.95494220898111,
           66.99616622898981,
           67.03739024899852,
           67.07861426900723,
           67.11983828901592,
           67.16106230902464,
           67.20228632903334,
           67.24351034904205,
           67.28473436905075,
           67.32595838905947,
           67.36718240906816,
           67.40840642907688,
           67.44963044908557,
           67.49085446909429,
           67.5322074428945,
           67.57435993914886,
           67.61651243540322,
           67.6586649316576,
           67.70081742791196,
           67.74296992416632,
           67.78512242042068,
           67.82727491667504,
           67.8694274129294,
           67.91157990918376,
           67.95373240543813,
           67.99588490169249,
           68.03803739794685,
           68.0801898942012,
           68.12234239045557,
           68.16449488670993,
           68.20664738296429,
           68.24879987921867,
           68.29095237547303,
           68.09966880723273,
           67.6749491744978,
           67.2502295417629,
           66.825509909028,
           66.40079027629307,
           65.97607064355817,
           65.55135101082328,
           65.12663137808835,
           64.70191174535341,
           64.27719211261855,
           63.85247247988361,
           63.42775284714868,
           63.003033214413776,
           62.578313581678884,
           62.15359394894395,
           61.72887431620906,
           61.30415468347417,
           60.87943505073922,
           60.45471541800433,
           60.02999578526942,
           59.6052761525345,
           59.18055651979956,
           58.7558368870647,
           58.33111725432977,
           57.906397621594834,
           57.48167798885994,
           57.05695835612504,
           56.63223872339011,
           56.207519090655204,
           55.78279945792031,
           55.358079825185385,
           54.93336019245045,
           54.50864055971559,
           54.083920926980646,
           53.65920129424572,
           53.23448166151081,
           52.80976202877592,
           52.38504239604099,
           51.960322763306095,
           51.53560313057119,
           51.110883497836255,
           50.68616386510136,
           50.261444232366465,
           49.83672459963152,
           49.41200496689659,
           48.98728533416174,
           48.562565701426806,
           48.13784606869187,
           47.713126435956966,
           47.28636337103998,
           46.84901200090443,
           46.41166063076893,
           45.97430926063342,
           45.536957890497874,
           45.09960652036233,
           44.662255150226855,
           44.22490378009131,
           43.78755240995577,
           43.35020103982026,
           42.91284966968476,
           42.47549829954921,
           42.038146929413706,
           41.6007955592782,
           41.16344418914265,
           40.72609281900715,
           40.28874144887163,
           39.85139007873609,
           39.41403870860055,
           38.976687338465084,
           38.53933596832953,
           38.10198459819399,
           37.664633228058484,
           37.227281857922975,
           36.78993048778743,
           36.35257911765193,
           35.91522774751642,
           35.477876377380866,
           35.04052500724537,
           34.60317363710986,
           34.16582226697432,
           33.72847089683877,
           33.29111952670326,
           32.85376815656775,
           32.4683750702482,
           32.186898551560624,
           31.905422032873044,
           31.623945514185433,
           31.34246899549785,
           31.060992476810267,
           30.77951595812266,
           30.498039439435054,
           30.216562920747496,
           29.93508640205989,
           29.653609883372283,
           29.3721333646847,
           29.09065684599712,
           28.809180327309512,
           28.52770380862193,
           28.246227289934346,
           27.96475077124674,
           27.68327425255916,
           27.401797733871575,
           27.12032121518397,
           26.838844696496363,
           26.55736817780878,
           26.2758916591212,
           25.99441514043359,
           25.712938621746012,
           25.43146210305843,
           25.149985584370818,
           24.868509065683238,
           24.587032546995655,
           24.305556028308047,
           24.02407950962044,
           23.742602990932888,
           23.461126472245276,
           23.179649953557664,
           22.898173434870085,
           22.6166969161825,
           22.3352203974949,
           22.053743878807314,
           21.77226736011973,
           21.490790841432123,
           21.209314322744543,
           20.92783780405696,
           20.646361285369355,
           20.364884766681747,
           20.083408247994164,
           19.80193172930658,
           19.520455210618973,
           19.238978691931393,
           18.95750217324381,
           18.6760256545562,
           18.394549135868623,
           18.11307261718104,
           17.831596098493435,
           17.550119579805823,
           17.26864306111827,
           16.98716654243066,
           16.705690023743053,
           16.424213505055473,
           16.14273698636789,
           15.861260467680282,
           15.579783948992699,
           15.298307430305117,
           15.016830911617511,
           14.73535439292993,
           14.453877874242348,
           14.17240135555474,
           13.89092483686713,
           13.609448318179576,
           13.327971799491968,
           13.046495280804361,
           12.76501876211678,
           12.483542243429195,
           12.202065724741589,
           11.920589206054006,
           11.639112687366426,
           11.357636168678818,
           11.07615964999121,
           10.794683131303653,
           10.513206612616044,
           10.231730093928435,
           9.950253575240854,
           9.668777056553273,
           9.386822479601207,
           9.13794579524964,
           9.083359679181733,
           9.028773563113829,
           8.974187447045924,
           8.919601330978027,
           8.865015214910121,
           8.810429098842215,
           8.755842982774318,
           8.701256866706414,
           8.646670750638506,
           8.592084634570611,
           8.537498518502705,
           8.482912402434799,
           8.428326286366893,
           8.373740170298998,
           8.319154054231092,
           8.264567938163186,
           8.20998182209529,
           8.155395706027383,
           8.100809589959477,
           8.046223473891581,
           7.991637357823676,
           7.9370512417557695,
           7.882465125687874,
           7.827879009619968,
           7.773292893552062,
           7.718706777484155,
           7.66412066141626,
           7.609534545348355,
           7.554948429280449,
           7.500362313212553,
           7.445776197144647,
           7.391190081076741,
           7.336603965008845,
           7.282017848940939,
           7.227431732873033,
           7.172845616805127,
           7.11825950073723,
           7.0636733846693245,
           7.009087268601419,
           6.954501152533524,
           6.899915036465616,
           6.84532892039771,
           6.790742804329815,
           6.736156688261908,
           6.681570572194002,
           6.626984456126107,
           6.572398340058201,
           6.517812223990296,
           6.46322610792239,
           6.408639991854494,
           6.354053875786587,
           6.299467759718682,
           6.2448816436507855,
           6.190295527582879,
           6.135709411514973,
           6.081123295447077,
           6.026537179379171,
           5.971951063311265,
           5.91736494724336,
           5.862778831175464,
           5.808192715107558,
           5.753606599039652,
           5.699020482971755,
           5.644434366903849,
           5.589848250835944,
           5.535262134768049,
           5.480676018700143,
           5.426089902632237,
           5.3715037865643405,
           5.3169176704964345,
           5.2623315544285285,
           5.207745438360622,
           5.153159322292725,
           5.09857320622482,
           5.043987090156914,
           4.989400974089018,
           4.934814858021112,
           4.880228741953207,
           4.82564262588531,
           4.771056509817404,
           4.716470393749498,
           4.661884277681592,
           4.609567849670787
          ],
          [
           56.88027894071371,
           56.9345304243382,
           56.9887819079627,
           57.04303339158719,
           57.097284875211685,
           57.15153635883618,
           57.20578784246068,
           57.26003932608517,
           57.31429080970966,
           57.36854229333416,
           57.422793776958656,
           57.477045260583154,
           57.53129674420765,
           57.58554822783214,
           57.63979971145664,
           57.69405119508113,
           57.74830267870563,
           57.802554162330125,
           57.856805645954616,
           57.91105712957911,
           57.965308613203604,
           58.0195600968281,
           58.0738115804526,
           58.12806306407709,
           58.18231454770159,
           58.23656603132608,
           58.290817514950575,
           58.34506899857507,
           58.39932048219956,
           58.45357196582406,
           58.50782344944856,
           58.56207493307304,
           58.61632641669754,
           58.67057790032204,
           58.724829383946535,
           58.779080867571025,
           58.83333235119552,
           58.88758383482002,
           58.941835318444504,
           58.996086802069,
           59.0503382856935,
           59.104589769318,
           59.158841252942494,
           59.21309273656699,
           59.267344220191475,
           59.32159570381597,
           59.37584718744047,
           59.43009867106497,
           59.48435015468945,
           59.53860163831395,
           59.59285312193845,
           59.647104605562944,
           59.70135608918744,
           59.75560757281194,
           59.80985905643644,
           59.86411054006092,
           59.91836202368541,
           59.97261350730991,
           60.02686499093441,
           60.08111647455891,
           60.1353679581834,
           60.189619441807885,
           60.24387092543238,
           60.29812240905688,
           60.35237389268138,
           60.406625376305875,
           60.46087685993036,
           60.515128343554856,
           60.56871680684675,
           60.6223052693348,
           60.67589373182285,
           60.729482194310904,
           60.783070656798955,
           60.836659119287006,
           60.89024758177506,
           60.94383604426311,
           60.99742450675115,
           61.0510129692392,
           61.104601431727254,
           61.158189894215305,
           61.211778356703356,
           61.26536681919141,
           61.31895528167946,
           61.37254374416751,
           61.41914296512298,
           61.46434433777194,
           61.5095457104209,
           61.55474708306986,
           61.599948455718824,
           61.64514982836778,
           61.690351201016746,
           61.73555257366571,
           61.78075394631467,
           61.82595531896363,
           61.8711566916126,
           61.91635806426155,
           61.96155943691052,
           62.00676080955948,
           62.05196218220844,
           62.0971635548574,
           62.14217972591942,
           62.18710329669318,
           62.232026867466935,
           62.276950438240696,
           62.32187400901445,
           62.36679757978821,
           62.411721150561974,
           62.45664472133573,
           62.50156829210949,
           62.546491862883244,
           62.591415433657005,
           62.63633900443076,
           62.681262575204514,
           62.72618614597828,
           62.771109716752036,
           62.8160332875258,
           62.86095685829955,
           62.90588042907331,
           62.95080399984707,
           62.99572757062083,
           63.04065114139459,
           63.085574712168345,
           63.1304982829421,
           63.17542185371586,
           63.220345424489615,
           63.26526899526337,
           63.31019256603714,
           63.35511613681089,
           63.40003970758465,
           63.444963278358415,
           63.48988684913216,
           63.53481041990593,
           63.579733990679685,
           63.62465756145344,
           63.669581132227194,
           63.714504703000955,
           63.759428273774716,
           63.80435184454848,
           63.84927541532223,
           63.89419898609599,
           63.93912255686975,
           63.9840461276435,
           64.02896969841726,
           64.07389326919102,
           64.11881683996478,
           64.16374041073854,
           64.2086639815123,
           64.25358755228606,
           64.29851112305981,
           64.34343469383359,
           64.38835826460733,
           64.43328183538108,
           64.47820540615484,
           64.5231289769286,
           64.56805254770237,
           64.61297611847613,
           64.65789968924987,
           64.70282326002364,
           64.74774683079738,
           64.79267040157116,
           64.8375939723449,
           64.88251754311867,
           64.92744111389243,
           64.97236468466619,
           65.01728825543995,
           65.0622118262137,
           65.10713539698746,
           65.14959260058451,
           65.19081662059322,
           65.23204064060194,
           65.27326466061064,
           65.31448868061933,
           65.35571270062806,
           65.39693672063676,
           65.43816074064546,
           65.47938476065417,
           65.52060878066287,
           65.56183280067158,
           65.60305682068028,
           65.64428084068899,
           65.6855048606977,
           65.72672888070642,
           65.76795290071512,
           65.80917692072383,
           65.85040094073253,
           65.89162496074124,
           65.93284898074994,
           65.97407300075864,
           66.01529702076735,
           66.05652104077606,
           66.09774506078477,
           66.13896908079347,
           66.18019310080217,
           66.22141712081088,
           66.2626411408196,
           66.30386516082831,
           66.34508918083701,
           66.3863132008457,
           66.42753722085442,
           66.46876124086313,
           66.50998526087183,
           66.55120928088053,
           66.59243330088924,
           66.63365732089795,
           66.67488134090665,
           66.71610536091536,
           66.75732938092408,
           66.79855340093278,
           66.83977742094147,
           66.8810014409502,
           66.9222254609589,
           66.9634494809676,
           67.0046735009763,
           67.04589752098502,
           67.08712154099372,
           67.12834556100242,
           67.16956958101113,
           67.21079360101984,
           67.25201762102854,
           67.29324164103724,
           67.33446566104595,
           67.37568968105467,
           67.41691370106338,
           67.45813772107208,
           67.49936174108079,
           67.54058576108949,
           67.5818097810982,
           67.6230338011069,
           67.66425782111563,
           67.70548184112431,
           67.74670586113302,
           67.78792988114174,
           67.82915390115043,
           67.87037792115913,
           67.91160194116785,
           67.95282596117656,
           67.99404998118526,
           68.03527400119397,
           68.07649802120267,
           68.11772204121138,
           68.15894606122008,
           68.2000151546617,
           68.24072276238016,
           68.28143037009862,
           68.32213797781709,
           68.36284558553554,
           68.40355319325401,
           68.44426080097247,
           68.48496840869093,
           68.5256760164094,
           68.32121404801663,
           67.87158250351264,
           67.42195095900868,
           66.97231941450472,
           66.52268787000075,
           66.07305632549678,
           65.62378591454787,
           65.18643454441232,
           64.74908317427678,
           64.31173180414132,
           63.87438043400577,
           63.43702906387021,
           62.99967769373472,
           62.562326323599216,
           62.124974953463656,
           61.68762358332816,
           61.25027221319266,
           60.8129208430571,
           60.3755694729216,
           59.938218102786095,
           59.500866732650536,
           59.063515362515005,
           58.62616399237953,
           58.18881262224399,
           57.75146125210844,
           57.31410988197293,
           56.87675851183742,
           56.43940714170189,
           56.002055771566376,
           55.56470440143088,
           55.12735303129533,
           54.690001661159776,
           54.2526502910243,
           53.815298920888765,
           53.37794755075322,
           52.9405961806177,
           52.5032448104822,
           52.065893440346656,
           51.62854207021116,
           51.19119070007565,
           50.7538393299401,
           50.31648795980459,
           49.87913658966909,
           49.44178521953354,
           49.00443384939799,
           48.56708247926253,
           48.12973110912698,
           47.69237973899144,
           47.25502836885593,
           46.81767699872043,
           46.38032562858488,
           45.942974258449375,
           45.50562288831387,
           45.06827151817832,
           44.630920148042776,
           44.19356877790731,
           43.75621740777176,
           43.31886603763622,
           42.88151466750071,
           42.44416329736521,
           42.00681192722966,
           41.56946055709415,
           41.132109186958644,
           40.6947578168231,
           40.2574064466876,
           39.820055076552094,
           39.38270370641654,
           38.945352336281,
           38.50800096614553,
           38.070649596009986,
           37.63329822587444,
           37.19594685573893,
           36.75859548560342,
           36.32124411546788,
           35.88389274533238,
           35.446541375196865,
           35.00919000506133,
           34.57183863492581,
           34.13448726479031,
           33.697135894654764,
           33.25978452451921,
           32.82243315438371,
           32.385081784248214,
           31.999688697928654,
           31.71821217924107,
           31.43673566055349,
           31.155259141865884,
           30.8737826231783,
           30.592306104490717,
           30.310829585803113,
           30.029353067115505,
           29.74787654842795,
           29.466400029740342,
           29.184923511052734,
           28.903446992365147,
           28.62197047367757,
           28.340493954989963,
           28.05901743630238,
           27.7775409176148,
           27.49606439892719,
           27.21458788023961,
           26.93311136155203,
           26.651634842864418,
           26.37015832417681,
           26.088681805489227,
           25.807205286801647,
           25.52572876811404,
           25.24425224942646,
           24.962775730738876,
           24.681299212051265,
           24.39982269336369,
           24.118346174676105,
           23.8368696559885,
           23.55539313730089,
           23.273916618613335,
           22.992440099925723,
           22.71096358123812,
           22.429487062550535,
           22.148010543862952,
           21.866534025175348,
           21.585057506487765,
           21.30358098780018,
           21.022104469112577,
           20.740627950424994,
           20.45915143173741,
           20.177674913049803,
           19.896198394362195,
           19.614721875674615,
           19.33324535698703,
           19.051768838299424,
           18.77029231961184,
           18.48927156525735,
           18.21834226126134,
           17.947412957265353,
           17.676483653269372,
           17.40555434927336,
           17.13462504527735,
           16.863695741281386,
           16.592766437285377,
           16.321837133289367,
           16.050907829293383,
           15.779978525297395,
           15.509049221301385,
           15.2381199173054,
           14.967190613309416,
           14.696261309313403,
           14.425332005317417,
           14.154402701321434,
           13.883473397325423,
           13.612544093329412,
           13.341614789333452,
           13.070685485337442,
           12.79975618134143,
           12.528826877345445,
           12.25789757334946,
           11.986968269353449,
           11.71603896535746,
           11.44510966136148,
           11.174180357365465,
           10.903251053369457,
           10.632321749373496,
           10.361392445377486,
           10.090463141381473,
           9.81953383738549,
           9.5486045333895,
           9.277675229393493,
           9.040299879183683,
           8.970694297904586,
           8.901088716625491,
           8.831483135346394,
           8.761877554067311,
           8.692271972788216,
           8.622666391509119,
           8.553060810230036,
           8.483455228950941,
           8.413849647671844,
           8.344244066392761,
           8.274638485113666,
           8.205032903834569,
           8.135427322555472,
           8.065821741276391,
           7.996216159997294,
           7.926610578718197,
           7.857004997439113,
           7.787399416160017,
           7.717793834880921,
           7.648188253601838,
           7.578582672322742,
           7.508977091043646,
           7.4393715097645625,
           7.369765928485467,
           7.300160347206372,
           7.230554765927275,
           7.1609491846481905,
           7.091343603369095,
           7.021738022089998,
           6.952132440810916,
           6.882526859531819,
           6.812921278252724,
           6.7433156969736405,
           6.673710115694544,
           6.604104534415449,
           6.534498953136353,
           6.473443965078263,
           6.421879227007028,
           6.3703144889357946,
           6.318749750864569,
           6.267185012793335,
           6.2156202747221005,
           6.164055536650876,
           6.112490798579641,
           6.060926060508407,
           6.009361322437182,
           5.9672025359908245,
           5.929216298516167,
           5.891230061041511,
           5.853243823566861,
           5.815257586092204,
           5.777271348617547,
           5.739285111142896,
           5.7012988736682395,
           5.663312636193583,
           5.625326398718933,
           5.587340161244275,
           5.549353923769618,
           5.511367686294961,
           5.473381448820311,
           5.4353952113456545,
           5.397408973870998,
           5.359422736396347,
           5.32143649892169,
           5.283450261447033,
           5.245464023972383,
           5.2074777864977255,
           5.169491549023068,
           5.131505311548418,
           5.093519074073761,
           5.055532836599104,
           5.017546599124447,
           4.979560361649797,
           4.9415741241751405,
           4.903587886700484,
           4.865601649225833,
           4.827615411751176,
           4.789629174276519,
           4.751642936801869,
           4.713656699327212,
           4.675670461852555,
           4.637684224377898,
           4.599697986903248
          ],
          [
           57.12952550410629,
           57.18377698773078,
           57.23802847135528,
           57.292279954979776,
           57.34653143860426,
           57.40078292222876,
           57.455034405853254,
           57.50928588947775,
           57.56353737310224,
           57.61778885672674,
           57.67204034035124,
           57.72629182397573,
           57.780543307600226,
           57.834794791224724,
           57.889046274849214,
           57.94329775847371,
           57.9975492420982,
           58.0518007257227,
           58.1060522093472,
           58.160303692971695,
           58.21455517659618,
           58.268806660220676,
           58.32305814384518,
           58.37730962746967,
           58.43156111109417,
           58.48581259471865,
           58.54006407834316,
           58.594315561967655,
           58.648567045592145,
           58.702818529216636,
           58.75707001284113,
           58.81132149646563,
           58.86557298009012,
           58.91982446371462,
           58.97407594733912,
           59.02832743096361,
           59.0825789145881,
           59.1368303982126,
           59.19108188183709,
           59.24533336546158,
           59.29958484908608,
           59.35383633271057,
           59.40808781633507,
           59.46233929995957,
           59.51659078358406,
           59.570842267208555,
           59.62509375083305,
           59.67934523445754,
           59.73359671808203,
           59.78784820170653,
           59.84209968533103,
           59.89635116895552,
           59.95060265258002,
           60.004854136204514,
           60.05910561982901,
           60.113357103453495,
           60.16760858707799,
           60.22186007070249,
           60.27611155432699,
           60.330363037951486,
           60.384614521575976,
           60.43886600520047,
           60.493117488824964,
           60.54736897244946,
           60.60162045607395,
           60.65587193969845,
           60.71012342332294,
           60.76437490694744,
           60.818626390571936,
           60.872877874196426,
           60.927129357820924,
           60.981380841445414,
           61.03563232506991,
           61.08988380869441,
           61.14413529231891,
           61.1983867759434,
           61.25263825956789,
           61.306889743192386,
           61.36114122681688,
           61.41539271044138,
           61.46964419406588,
           61.52389567769037,
           61.57814716131487,
           61.63246679851004,
           61.67886759363147,
           61.723791164405235,
           61.76871473517899,
           61.81363830595275,
           61.858561876726505,
           61.903485447500266,
           61.94840901827403,
           61.99333258904778,
           62.03825615982154,
           62.0831797305953,
           62.12810330136906,
           62.17302687214281,
           62.21795044291657,
           62.262874013690336,
           62.30779758446409,
           62.35272115523785,
           62.397644726011606,
           62.44256829678536,
           62.48749186755912,
           62.53241543833288,
           62.57733900910663,
           62.6222625798804,
           62.66718615065415,
           62.712109721427915,
           62.757033292201676,
           62.80195686297543,
           62.846880433749185,
           62.891804004522946,
           62.9367275752967,
           62.98165114607047,
           63.02657471684422,
           63.07149828761798,
           63.11642185839174,
           63.16134542916549,
           63.20626899993925,
           63.251192570713016,
           63.29611614148677,
           63.34103971226053,
           63.385963283034286,
           63.43088685380804,
           63.4758104245818,
           63.52073399535556,
           63.565657566129325,
           63.61058113690308,
           63.65550470767683,
           63.700428278450595,
           63.745351849224356,
           63.79027541999812,
           63.83519899077187,
           63.880122561545626,
           63.92504613231939,
           63.969969703093135,
           64.0148932738669,
           64.05981684464065,
           64.10474041541441,
           64.14966398618817,
           64.19458755696193,
           64.23951112773568,
           64.28443469850944,
           64.3293582692832,
           64.37428184005697,
           64.41920541083073,
           64.46412898160447,
           64.50905255237824,
           64.553976123152,
           64.59889969392574,
           64.6438232646995,
           64.68874683547327,
           64.73367040624703,
           64.77859397702078,
           64.82351754779454,
           64.8684411185683,
           64.91336468934206,
           64.95828826011582,
           65.00321183088957,
           65.04813540166333,
           65.09305897243709,
           65.13798254321085,
           65.18290611398461,
           65.22782968475836,
           65.27275325553212,
           65.31767682630588,
           65.36260039707963,
           65.40430788231272,
           65.4450154900312,
           65.48572309774966,
           65.52643070546813,
           65.56713831318658,
           65.60784592090505,
           65.64855352862351,
           65.68926113634197,
           65.72996874406044,
           65.7706763517789,
           65.81138395949736,
           65.85209156721582,
           65.8927991749343,
           65.93350678265276,
           65.97421439037122,
           66.01492199808969,
           66.05562960580814,
           66.09633721352661,
           66.13704482124507,
           66.17775242896353,
           66.218460036682,
           66.25916764440045,
           66.29987525211892,
           66.34058285983738,
           66.38129046755584,
           66.42199807527432,
           66.46270568299278,
           66.50341329071124,
           66.5441208984297,
           66.58482850614817,
           66.62553611386663,
           66.66624372158509,
           66.70695132930356,
           66.74765893702201,
           66.78836654474048,
           66.82907415245894,
           66.8697817601774,
           66.91048936789588,
           66.95119697561434,
           66.9919045833328,
           67.03261219105126,
           67.07331979876972,
           67.11402740648819,
           67.15473501420665,
           67.19544262192512,
           67.23615022964357,
           67.27685783736203,
           67.3175654450805,
           67.35827305279896,
           67.39898066051742,
           67.4396882682359,
           67.48039587595434,
           67.52110348367282,
           67.56181109139128,
           67.60251869910975,
           67.64322630682821,
           67.68393391454667,
           67.72464152226513,
           67.76534912998359,
           67.80605673770206,
           67.84676434542052,
           67.88747195313898,
           67.92817956085746,
           67.9688871685759,
           68.00959477629438,
           68.05030238401284,
           68.09100999173131,
           68.13171759944976,
           68.17242520716823,
           68.2131328148867,
           68.25384042260515,
           68.29454803032363,
           68.33525563804209,
           68.37596324576054,
           68.41667085347902,
           68.45737846119746,
           68.49808606891594,
           68.5387936766344,
           68.57950128435286,
           68.62020889207133,
           68.66091649978979,
           68.70162410750825,
           68.74233171522671,
           68.53786974683396,
           68.08823820232996,
           67.638606657826,
           67.18897511332206,
           66.73934356881806,
           66.28971202431411,
           65.84008047981015,
           65.39044893530617,
           64.94081739080217,
           64.49118584629827,
           64.04155430179426,
           63.59192275729028,
           63.14229121278632,
           62.692659668282374,
           62.24302812377837,
           61.79339657927443,
           61.34376503477048,
           60.89413349026648,
           60.44450194576253,
           59.99487040125858,
           59.54523885675459,
           59.09560731225059,
           58.64597576774669,
           58.19634422324269,
           57.7467126787387,
           57.29708113423475,
           56.84744958973079,
           56.397818045226806,
           55.94818650072285,
           55.4985549562189,
           55.04892341171491,
           54.59929186721091,
           54.149660322707,
           53.70002877820302,
           53.25039723369901,
           52.80076568919507,
           52.351134144691116,
           51.90150260018712,
           51.45187105568318,
           51.00223951117922,
           50.55260796667523,
           50.10297642217127,
           49.65334487766733,
           49.203713333163336,
           48.75408178865935,
           48.30445024415543,
           47.85481869965144,
           47.405187155147445,
           46.955555610643486,
           46.50592406613955,
           46.05629252163555,
           45.606660977131604,
           45.157029432627645,
           44.70739788812365,
           44.25776634361966,
           43.80813479911575,
           43.35850325461176,
           42.90887171010777,
           42.459240165603816,
           42.00960862109986,
           41.55997707659588,
           41.11034553209191,
           40.66342281463909,
           40.226071444503546,
           39.788720074368044,
           39.35136870423254,
           38.914017334097,
           38.47666596396145,
           38.039314593825985,
           37.60196322369043,
           37.16461185355489,
           36.727260483419386,
           36.289909113283876,
           35.852557743148324,
           35.41520637301282,
           34.97785500287732,
           34.540503632741775,
           34.103152262606265,
           33.66580089247076,
           33.22844952233522,
           32.791098152199666,
           32.35374678206416,
           31.916395411928654,
           31.531002325609105,
           31.249525806921525,
           30.96804928823394,
           30.68657276954633,
           30.40509625085875,
           30.12361973217117,
           29.842143213483563,
           29.560666694795955,
           29.2791901761084,
           28.99771365742079,
           28.716237138733185,
           28.4347606200456,
           28.15328410135802,
           27.873728234844407,
           27.602798930848422,
           27.331869626852438,
           27.060940322856425,
           26.790011018860444,
           26.519081714864456,
           26.24815241086845,
           25.977223106872437,
           25.70629380287645,
           25.435364498880464,
           25.164435194884454,
           24.893505890888466,
           24.622576586892485,
           24.351647282896472,
           24.080717978900488,
           23.8097886749045,
           23.538859370908494,
           23.267930066912484,
           22.997000762916517,
           22.726071458920508,
           22.4551421549245,
           22.18421285092851,
           21.913283546932526,
           21.642354242936516,
           21.371424938940535,
           21.100495634944544,
           20.829566330948534,
           20.558637026952546,
           20.287707722956565,
           20.016778418960552,
           19.745849114964543,
           19.474919810968558,
           19.203990506972573,
           18.93306120297656,
           18.662131898980576,
           18.39120259498459,
           18.12027329098858,
           17.849343986992594,
           17.57841468299661,
           17.307485379000596,
           17.036556075004587,
           16.765626771008627,
           16.494697467012614,
           16.223768163016604,
           15.95283885902062,
           15.681909555024633,
           15.41098025102862,
           15.140050947032638,
           14.869121643036653,
           14.598192339040642,
           14.327263035044654,
           14.056333731048671,
           13.785404427052658,
           13.51447512305665,
           13.243545819060689,
           12.97261651506468,
           12.701687211068666,
           12.430757907072683,
           12.159828603076697,
           11.888899299080688,
           11.6179699950847,
           11.347040691088713,
           11.076111387092704,
           10.805182083096696,
           10.534252779100735,
           10.263323475104722,
           9.99239417110871,
           9.72146486711273,
           9.45053556311674,
           9.179606259120728,
           8.94223090891092,
           8.872625327631825,
           8.803019746352728,
           8.733414165073633,
           8.663808583794548,
           8.594203002515455,
           8.524597421236358,
           8.454991839957275,
           8.385386258678178,
           8.315780677399083,
           8.246175096119998,
           8.176569514840903,
           8.106963933561808,
           8.03735835228271,
           7.967752771003628,
           7.898147189724531,
           7.828541608445435,
           7.763258323390302,
           7.711693585319068,
           7.660128847247834,
           7.60856410917661,
           7.556999371105375,
           7.50543463303414,
           7.453869894962916,
           7.402305156891681,
           7.350740418820447,
           7.2991756807492125,
           7.247610942677987,
           7.196046204606754,
           7.144481466535519,
           7.092916728464294,
           7.041351990393061,
           6.989787252321825,
           6.938222514250601,
           6.886657776179367,
           6.835093038108132,
           6.783528300036898,
           6.7319635619656735,
           6.680398823894439,
           6.628834085823204,
           6.5772693477519795,
           6.525704609680746,
           6.474139871609511,
           6.422575133538286,
           6.371010395467052,
           6.319445657395817,
           6.267880919324592,
           6.216316181253358,
           6.164751443182124,
           6.1131867051108895,
           6.061621967039664,
           6.01005722896843,
           5.958492490897196,
           5.906927752825971,
           5.855363014754737,
           5.803798276683503,
           5.752233538612278,
           5.7006688005410435,
           5.649104062469809,
           5.597539324398575,
           5.54597458632735,
           5.494409848256116,
           5.442845110184882,
           5.391280372113657,
           5.339715634042423,
           5.288150895971189,
           5.236586157899963,
           5.197609813240575,
           5.1596235757659175,
           5.121637338291268,
           5.08365110081661,
           5.045664863341953,
           5.007678625867297,
           4.969692388392646,
           4.931706150917989,
           4.8937199134433325,
           4.855733675968683,
           4.817747438494025,
           4.779761201019368,
           4.741774963544718,
           4.703788726070062,
           4.6658024885954035,
           4.627816251120747,
           4.589830013646097
          ],
          [
           57.36670964580023,
           57.420961129424725,
           57.47521261304922,
           57.52946409667372,
           57.583715580298204,
           57.6379670639227,
           57.6922185475472,
           57.7464700311717,
           57.80072151479619,
           57.854972998420685,
           57.90922448204518,
           57.96347596566967,
           58.01772744929417,
           58.07197893291867,
           58.12623041654316,
           58.180481900167656,
           58.23473338379215,
           58.288984867416644,
           58.34323635104114,
           58.39748783466564,
           58.45173931829013,
           58.50599080191462,
           58.56024228553912,
           58.614493769163616,
           58.6687452527881,
           58.7229967364126,
           58.777248220037094,
           58.83149970366159,
           58.88575118728609,
           58.94000267091058,
           58.99425415453508,
           59.04850563815957,
           59.102757121784066,
           59.15700860540856,
           59.21126008903306,
           59.265511572657545,
           59.31976305628204,
           59.37401453990654,
           59.42826602353104,
           59.482517507155535,
           59.53676899078002,
           59.591020474404516,
           59.645271958029014,
           59.69952344165351,
           59.753774925278,
           59.8080264089025,
           59.862277892527,
           59.91652937615149,
           59.97078085977598,
           60.025032343400476,
           60.07928382702497,
           60.133535310649464,
           60.18778679427396,
           60.24203827789846,
           60.29628976152296,
           60.35054124514744,
           60.40479272877194,
           60.459044212396435,
           60.51329569602093,
           60.56754717964542,
           60.62179866326992,
           60.67605014689441,
           60.73030163051891,
           60.7845531141434,
           60.8388045977679,
           60.893056081392395,
           60.947307565016885,
           61.00183166102902,
           61.056492062733355,
           61.11115246443767,
           61.165812866142005,
           61.22047326784633,
           61.27513366955065,
           61.32979407125498,
           61.3844544729593,
           61.43911487466363,
           61.493775276367955,
           61.54843567807227,
           61.603096079776606,
           61.657756481480924,
           61.712416883185256,
           61.767077284889574,
           61.8217376865939,
           61.87639808829823,
           61.922580513696786,
           61.96706734383419,
           62.01155417397159,
           62.056041004109,
           62.10052783424641,
           62.14501466438381,
           62.18950149452121,
           62.23398832465862,
           62.27847515479603,
           62.32296198493343,
           62.36744881507082,
           62.41193564520823,
           62.45642247534563,
           62.50090930548304,
           62.54539613562044,
           62.589882965757845,
           62.63436979589525,
           62.67929336631183,
           62.724216937085586,
           62.76914050785935,
           62.8140640786331,
           62.85898764940687,
           62.903911220180625,
           62.94883479095438,
           62.99375836172814,
           63.038681932501895,
           63.08360550327565,
           63.12852907404941,
           63.173452644823165,
           63.21837621559693,
           63.26329978637069,
           63.30822335714445,
           63.3531469279182,
           63.398070498691965,
           63.44299406946572,
           63.48791764023948,
           63.53284121101324,
           63.577764781786996,
           63.62268835256076,
           63.66761192333451,
           63.71253549410827,
           63.757459064882035,
           63.802382635655796,
           63.84730620642955,
           63.892229777203305,
           63.937153347977066,
           63.98207691875083,
           64.0270004895246,
           64.07192406029834,
           64.11684763107209,
           64.16177120184585,
           64.20669477261961,
           64.25161834339337,
           64.29654191416712,
           64.34146548494088,
           64.38638905571464,
           64.4313126264884,
           64.47623619726215,
           64.52115976803591,
           64.56608333880968,
           64.61100690958344,
           64.6559304803572,
           64.70085405113095,
           64.74577762190472,
           64.79070119267847,
           64.83562476345223,
           64.88054833422599,
           64.92547190499974,
           64.9703954757735,
           65.01531904654725,
           65.06024261732102,
           65.10516618809477,
           65.15008975886853,
           65.1950133296423,
           65.23993690041604,
           65.28486047118982,
           65.32978404196356,
           65.37470761273732,
           65.41963118351109,
           65.46455475428483,
           65.50947832505861,
           65.55440189583236,
           65.59932546660612,
           65.6409271860636,
           65.68086797986294,
           65.72080877366228,
           65.76074956746162,
           65.80069036126096,
           65.84063115506031,
           65.88057194885965,
           65.92051274265899,
           65.96045353645833,
           66.00039433025766,
           66.04033512405701,
           66.08027591785635,
           66.12021671165569,
           66.16015750545503,
           66.20009829925436,
           66.24003909305371,
           66.27997988685306,
           66.3199206806524,
           66.35986147445175,
           66.39980226825108,
           66.43974306205041,
           66.47968385584977,
           66.5196246496491,
           66.55956544344843,
           66.59950623724778,
           66.63944703104713,
           66.67938782484646,
           66.72006898952856,
           66.76077659724703,
           66.80148420496549,
           66.84219181268396,
           66.88289942040242,
           66.92360702812088,
           66.96431463583934,
           67.0050222435578,
           67.04572985127628,
           67.08643745899474,
           67.1271450667132,
           67.16785267443166,
           67.20856028215013,
           67.24926788986859,
           67.28997549758705,
           67.33068310530551,
           67.37139071302397,
           67.41209832074244,
           67.4528059284609,
           67.49351353617936,
           67.53422114389784,
           67.57492875161628,
           67.61563635933476,
           67.65634396705322,
           67.69705157477168,
           67.73775918249015,
           67.7784667902086,
           67.81917439792707,
           67.85988200564555,
           67.90058961336399,
           67.94129722108246,
           67.98200482880092,
           68.0227124365194,
           68.06342004423784,
           68.1041276519563,
           68.14483525967478,
           68.18554286739324,
           68.2262504751117,
           68.26695808283017,
           68.30766569054863,
           68.34837329826709,
           68.38908090598557,
           68.42978851370401,
           68.47049612142249,
           68.51120372914095,
           68.5519113368594,
           68.59261894457788,
           68.63332655229632,
           68.6740341600148,
           68.71474176773326,
           68.75544937545172,
           68.79615698317019,
           68.83686459088865,
           68.87757219860711,
           68.91827980632559,
           68.95898741404403,
           68.75452544565127,
           68.30489390114728,
           67.85526235664332,
           67.40563081213938,
           66.95599926763538,
           66.50636772313143,
           66.05673617862749,
           65.60710463412349,
           65.15747308961949,
           64.70784154511558,
           64.2582100006116,
           63.8085784561076,
           63.35894691160365,
           62.9093153670997,
           62.45968382259571,
           62.010052278091756,
           61.560420733587804,
           61.11078918908382,
           60.66115764457986,
           60.211526100075915,
           59.761894555571914,
           59.31226301106793,
           58.86263146656401,
           58.412999922060024,
           57.96336837755602,
           57.51373683305208,
           57.06410528854812,
           56.614473744044126,
           56.164842199540175,
           55.71521065503622,
           55.26557911053224,
           54.81594756602824,
           54.36631602152433,
           53.91668447702034,
           53.46705293251635,
           53.017421388012394,
           52.56778984350844,
           52.11815829900445,
           51.6685267545005,
           51.218895209996546,
           50.769263665492545,
           50.31963212098861,
           49.87000057648466,
           49.42036903198066,
           48.97073748747666,
           48.52110594297275,
           48.071474398468766,
           47.62184285396477,
           47.17221130946082,
           46.72257976495686,
           46.27294822045288,
           45.82331667594892,
           45.37368513144497,
           44.924053586940985,
           44.474422042437,
           44.02479049793308,
           43.57515895342908,
           43.125527408925095,
           42.675895864421136,
           42.22626431991719,
           41.77663277541319,
           41.32700123090925,
           40.877369686405295,
           40.4277381419013,
           39.97740044223291,
           39.50534922537997,
           39.03329800852699,
           38.561246791674,
           38.089195574821105,
           37.617144357968115,
           37.14509314111514,
           36.67304192426219,
           36.200990707409254,
           35.728939490556265,
           35.256888273703325,
           34.784837056850385,
           34.3127858399974,
           33.840734623144456,
           33.36868340629152,
           32.896632189438535,
           32.424580972585545,
           31.952529755732606,
           31.480478538879666,
           31.07615437020432,
           30.807284297884237,
           30.538414225564154,
           30.269544153244045,
           30.00067408092396,
           29.731804008603874,
           29.46293393628377,
           29.19406386396366,
           28.9251937916436,
           28.65632371932349,
           28.387453647003383,
           28.1185835746833,
           27.849713502363212,
           27.580843430043103,
           27.31197335772302,
           27.043103285402935,
           26.774233213082827,
           26.505363140762743,
           26.236493068442662,
           25.96762299612255,
           25.698752923802445,
           25.42988285148236,
           25.161012779162277,
           24.892142706842165,
           24.62327263452208,
           24.354402562201997,
           24.085532489881892,
           23.81666241756181,
           23.547792345241724,
           23.278922272921616,
           23.010052200601503,
           22.741182128281444,
           22.47231205596134,
           22.203441983641227,
           21.934571911321143,
           21.66570183900106,
           21.396831766680954,
           21.12796169436087,
           20.859091622040786,
           20.590221549720674,
           20.321351477400587,
           20.052481405080506,
           19.783611332760394,
           19.51474126044029,
           19.245871188120205,
           18.97700111580012,
           18.70813104348001,
           18.439260971159925,
           18.17039089883984,
           17.901520826519736,
           17.63265075419965,
           17.363780681879565,
           17.094910609559456,
           16.826040537239347,
           16.557170464919288,
           16.288300392599183,
           16.01943032027907,
           15.750560247958987,
           15.481690175638903,
           15.212820103318796,
           14.943950030998714,
           14.675079958678626,
           14.406209886358518,
           14.137339814038434,
           13.86846974171835,
           13.599599669398241,
           13.330729597078133,
           13.061859524758075,
           12.792989452437967,
           12.524119380117856,
           12.255249307797772,
           11.986379235477688,
           11.71750916315758,
           11.448639090837496,
           11.179769018517412,
           10.910898946197305,
           10.642028873877196,
           10.373158801557135,
           10.104288729237023,
           9.845727802951235,
           9.58773957411813,
           9.329751345285027,
           9.0717631164519,
           8.84583752407119,
           8.78022511395228,
           8.71461270383337,
           8.64900029371446,
           8.583387883595561,
           8.517775473476652,
           8.452163063357743,
           8.386550653238846,
           8.320938243119937,
           8.256496389281471,
           8.204931651210245,
           8.15336691313901,
           8.101802175067778,
           8.050237436996543,
           7.998672698925318,
           7.947107960854083,
           7.89554322278285,
           7.843978484711625,
           7.79241374664039,
           7.740849008569157,
           7.689284270497932,
           7.637719532426697,
           7.586154794355463,
           7.534590056284238,
           7.483025318213003,
           7.431460580141769,
           7.379895842070535,
           7.32833110399931,
           7.276766365928076,
           7.225201627856842,
           7.173636889785618,
           7.122072151714383,
           7.070507413643148,
           7.018942675571923,
           6.9673779375006895,
           6.915813199429454,
           6.86424846135822,
           6.812683723286996,
           6.761118985215761,
           6.709554247144527,
           6.657989509073302,
           6.606424771002067,
           6.554860032930833,
           6.503295294859608,
           6.451730556788374,
           6.400165818717141,
           6.348601080645915,
           6.297036342574681,
           6.245471604503447,
           6.1939068664322114,
           6.142342128360988,
           6.090777390289753,
           6.039212652218518,
           5.987647914147294,
           5.936083176076059,
           5.884518438004825,
           5.832953699933601,
           5.781388961862366,
           5.729824223791132,
           5.678259485719897,
           5.626694747648672,
           5.575130009577439,
           5.523565271506205,
           5.472000533434979,
           5.420435795363744,
           5.368871057292511,
           5.317306319221286,
           5.265741581150051,
           5.214176843078817,
           5.162612105007593,
           5.111047366936358,
           5.059482628865124,
           5.007917890793889,
           4.956353152722665,
           4.906066597188865,
           4.869838961399414,
           4.8336113256099695,
           4.797383689820518,
           4.7611560540310665,
           4.724928418241622,
           4.688700782452171,
           4.652473146662719,
           4.616245510873268,
           4.580017875083824
          ],
          [
           57.603893787494165,
           57.65814527111866,
           57.71239675474315,
           57.76664823836765,
           57.82089972199215,
           57.87515120561664,
           57.92940268924113,
           57.98365417286563,
           58.037905656490125,
           58.092157140114615,
           58.14640862373911,
           58.2006601073636,
           58.2549115909881,
           58.3091630746126,
           58.363414558237096,
           58.417666041861594,
           58.47191752548608,
           58.526169009110575,
           58.58042049273507,
           58.63467197635957,
           58.68892345998406,
           58.74317494360856,
           58.79742642723305,
           58.851677910857546,
           58.905929394482044,
           58.960180878106534,
           59.014432361731025,
           59.06868384535552,
           59.12293532898002,
           59.17718681260452,
           59.231438296229015,
           59.2856897798535,
           59.339941263477996,
           59.394192747102494,
           59.44844423072699,
           59.50269571435148,
           59.55694719797597,
           59.611198681600484,
           59.66545016522497,
           59.719701648849465,
           59.773953132473956,
           59.82820461609845,
           59.882456099722944,
           59.93670758334744,
           59.99095906697194,
           60.04521055059644,
           60.09946203422093,
           60.15371351784542,
           60.207965001469915,
           60.262216485094406,
           60.31653612184368,
           60.371196523548015,
           60.42585692525233,
           60.48051732695666,
           60.53517772866099,
           60.58983813036531,
           60.64449853206964,
           60.69915893377396,
           60.75381933547828,
           60.808479737182616,
           60.86314013888693,
           60.91780054059126,
           60.972460942295584,
           61.02712134399991,
           61.08178174570423,
           61.13644214740856,
           61.191102549112884,
           61.2457629508172,
           61.300423352521534,
           61.35508375422586,
           61.409744155930184,
           61.46440455763451,
           61.519064959338834,
           61.57372536104316,
           61.62838576274748,
           61.68304616445181,
           61.73770656615613,
           61.79236696786045,
           61.847027369564785,
           61.9016877712691,
           61.956348172973435,
           62.01100857467775,
           62.06566897638208,
           62.12032937808641,
           62.16651180348497,
           62.21099863362238,
           62.25548546375978,
           62.299972293897184,
           62.344459124034586,
           62.38894595417199,
           62.43343278430939,
           62.477919614446805,
           62.522406444584206,
           62.56689327472161,
           62.61138010485901,
           62.65586693499642,
           62.70035376513382,
           62.74484059527123,
           62.78932742540863,
           62.83381425554603,
           62.87830108568344,
           62.92278791582085,
           62.96727474595825,
           63.01176157609565,
           63.05624840623305,
           63.100735236370454,
           63.14522206650786,
           63.18970889664527,
           63.23419572678267,
           63.27868255692008,
           63.32316938705748,
           63.36765621719489,
           63.412143047332286,
           63.4566298774697,
           63.501116707607096,
           63.5456035377445,
           63.590090367881906,
           63.63479556821842,
           63.67971913899218,
           63.724642709765945,
           63.7695662805397,
           63.81448985131346,
           63.859413422087215,
           63.904336992860976,
           63.94926056363474,
           63.994184134408485,
           64.03910770518226,
           64.08403127595601,
           64.12895484672977,
           64.17387841750353,
           64.21880198827729,
           64.26372555905105,
           64.3086491298248,
           64.35357270059855,
           64.39849627137232,
           64.44341984214607,
           64.48834341291983,
           64.53326698369358,
           64.57819055446734,
           64.6231141252411,
           64.66803769601486,
           64.71296126678862,
           64.75788483756239,
           64.80280840833615,
           64.84773197910991,
           64.89265554988364,
           64.9375791206574,
           64.98250269143116,
           65.02742626220493,
           65.07234983297869,
           65.11727340375245,
           65.16219697452621,
           65.20712054529996,
           65.25204411607372,
           65.29696768684748,
           65.34189125762123,
           65.38681482839499,
           65.43173839916875,
           65.47666196994251,
           65.52158554071627,
           65.56650911149003,
           65.61143268226378,
           65.65635625303754,
           65.70127982381129,
           65.74620339458507,
           65.79112696535881,
           65.83605053613257,
           65.87765225559006,
           65.9175930493894,
           65.95753384318874,
           65.99747463698807,
           66.03741543078742,
           66.07735622458677,
           66.11729701838611,
           66.15723781218546,
           66.19717860598479,
           66.23711939978412,
           66.27706019358347,
           66.31700098738281,
           66.35694178118214,
           66.39688257498149,
           66.43682336878084,
           66.47676416258017,
           66.51670495637951,
           66.55664575017886,
           66.5965865439782,
           66.63652733777755,
           66.67646813157688,
           66.71640892537621,
           66.75634971917556,
           66.7962905129749,
           66.83623130677424,
           66.87617210057358,
           66.91611289437293,
           66.95605368817226,
           66.99599448197161,
           67.03593527577095,
           67.07587606957028,
           67.11581686336963,
           67.15575765716898,
           67.19569845096831,
           67.23563924476765,
           67.27558003856699,
           67.31552083236633,
           67.35546162616568,
           67.39540241996502,
           67.43534321376436,
           67.47528400756369,
           67.51522480136305,
           67.55516559516238,
           67.59510638896172,
           67.63504718276107,
           67.6749879765604,
           67.71492877035973,
           67.75486956415908,
           67.79481035795843,
           67.83475115175776,
           67.8746919455571,
           67.91463273935645,
           67.9545735331558,
           67.99512248902592,
           68.03583009674439,
           68.07653770446285,
           68.11724531218131,
           68.15795291989978,
           68.19866052761823,
           68.23936813533672,
           68.28007574305516,
           68.32078335077364,
           68.3614909584921,
           68.40219856621056,
           68.44290617392903,
           68.48361378164748,
           68.52432138936595,
           68.56502899708441,
           68.60573660480287,
           68.64644421252135,
           68.6871518202398,
           68.72785942795826,
           68.76856703567674,
           68.80927464339518,
           68.84998225111366,
           68.89068985883212,
           68.93139746655058,
           68.97210507426904,
           69.0128126819875,
           69.05352028970597,
           69.09422789742442,
           69.13493550514289,
           69.17564311286135,
           68.9711811444686,
           68.5215495999646,
           68.07191805546066,
           67.62228651095668,
           67.17265496645271,
           66.72302342194875,
           66.27339187744481,
           65.82376033294081,
           65.3741287884368,
           64.9244972439329,
           64.4748656994289,
           64.02523415492493,
           63.575602610420965,
           63.125971065917014,
           62.67633952141302,
           62.226707976909076,
           61.777076432405124,
           61.32744488790113,
           60.87781334339718,
           60.42818179889322,
           59.97855025438923,
           59.52891870988523,
           59.07928716538133,
           58.629655620877344,
           58.18002407637335,
           57.7303925318694,
           57.28076098736544,
           56.83112944286145,
           56.381497898357495,
           55.93186635385356,
           55.482234809349556,
           55.03260326484557,
           54.582971720341654,
           54.13334017583765,
           53.683708631333666,
           53.21359926108115,
           52.741548044228196,
           52.26949682737522,
           51.79744561052228,
           51.32539439366934,
           50.85334317681635,
           50.38129195996342,
           49.90924074311047,
           49.437189526257484,
           48.965138309404495,
           48.493087092551605,
           48.021035875698615,
           47.548984658845626,
           47.07693344199269,
           46.60488222513975,
           46.13283100828677,
           45.660779791433825,
           45.18872857458088,
           44.71667735772789,
           44.244626140874914,
           43.77257492402201,
           43.300523707169035,
           42.828472490316045,
           42.35642127346311,
           41.884370056610166,
           41.41231883975718,
           40.94026762290423,
           40.46821640605129,
           39.99616518919831,
           39.52411397234537,
           39.05206275549243,
           38.58001153863944,
           38.10796032178645,
           37.63590910493355,
           37.16385788808057,
           36.691806671227596,
           36.21975545437465,
           35.74770423752171,
           35.27565302066871,
           34.80360180381578,
           34.33155058696284,
           33.85949937010986,
           33.38744815325691,
           32.915396936403965,
           32.44334571955098,
           31.971294502697994,
           31.499243285845054,
           31.02719206899212,
           30.622867900316773,
           30.353997827996686,
           30.085127755676606,
           29.816257683356497,
           29.547387611036413,
           29.27851753871633,
           29.009647466396217,
           28.74077739407611,
           28.471907321756053,
           28.203037249435944,
           27.93416717711583,
           27.665297104795748,
           27.396427032475664,
           27.12755696015556,
           26.858686887835475,
           26.58981681551539,
           26.320946743195286,
           26.052076670875195,
           25.78320659855511,
           25.514336526235006,
           25.245466453914897,
           24.976596381594813,
           24.70772630927473,
           24.43885623695462,
           24.169986164634537,
           23.901116092314453,
           23.632246019994344,
           23.36337594767426,
           23.094505875354177,
           22.825635803034068,
           22.55676573071396,
           22.2878956583939,
           22.01902558607379,
           21.75015551375368,
           21.4812854414336,
           21.212415369113515,
           20.943545296793403,
           20.67467522447332,
           20.405805152153235,
           20.136935079833126,
           19.868065007513042,
           19.599194935192955,
           19.330324862872846,
           19.061454790552737,
           18.792584718232654,
           18.526291940532413,
           18.26830371169929,
           18.010315482866186,
           17.75232725403308,
           17.494339025199952,
           17.236350796366846,
           16.978362567533747,
           16.72037433870062,
           16.462386109867488,
           16.20439788103441,
           15.946409652201284,
           15.688421423368155,
           15.430433194535052,
           15.17244496570195,
           14.914456736868821,
           14.656468508035715,
           14.398480279202612,
           14.140492050369485,
           13.88250382153638,
           13.624515592703279,
           13.366527363870148,
           13.108539135037024,
           12.850550906203942,
           12.592562677370815,
           12.334574448537687,
           12.076586219704584,
           11.818597990871481,
           11.560609762038352,
           11.302621533205249,
           11.044633304372145,
           10.786645075539017,
           10.52865684670589,
           10.270668617872808,
           10.012680389039682,
           9.754692160206554,
           9.49670393137345,
           9.238715702540347,
           8.98072747370722,
           8.75480188132651,
           8.689189471207598,
           8.623577061088689,
           8.55796465096978,
           8.492352240850881,
           8.426739830731972,
           8.361127420613062,
           8.295515010494164,
           8.229902600375254,
           8.164290190256345,
           8.098677780137447,
           8.033065370018537,
           7.967452959899626,
           7.901840549780717,
           7.836228139661819,
           7.770615729542909,
           7.705003319424,
           7.639390909305103,
           7.573778499186194,
           7.5081660890672826,
           7.442553678948385,
           7.3769412688294755,
           7.311328858710565,
           7.2457164485916685,
           7.1801040384727575,
           7.114491628353848,
           7.048879218234939,
           6.983266808116041,
           6.917654397997131,
           6.852041987878222,
           6.786429577759323,
           6.720817167640414,
           6.655204757521504,
           6.6032058606187585,
           6.554434888267513,
           6.5056639159162675,
           6.456892943565022,
           6.408121971213785,
           6.35935099886254,
           6.310580026511295,
           6.261809054160059,
           6.213038081808812,
           6.164267109457567,
           6.115496137106331,
           6.066725164755086,
           6.017954192403841,
           5.969183220052604,
           5.920412247701359,
           5.871641275350113,
           5.822870302998868,
           5.7740993306476325,
           5.729823040724377,
           5.693595404934926,
           5.65736776914548,
           5.621140133356029,
           5.584912497566578,
           5.548684861777134,
           5.512457225987682,
           5.476229590198232,
           5.44000195440878,
           5.403774318619335,
           5.367546682829883,
           5.331319047040433,
           5.295091411250988,
           5.258863775461537,
           5.222636139672085,
           5.186408503882641,
           5.150180868093189,
           5.1139532323037376,
           5.077725596514293,
           5.041497960724842,
           5.005270324935391,
           4.969042689145939,
           4.932815053356495,
           4.896587417567043,
           4.860359781777592,
           4.824132145988147,
           4.787904510198696,
           4.751676874409245,
           4.7154492386198,
           4.679221602830349,
           4.642993967040898,
           4.606766331251446,
           4.570538695462002
          ],
          [
           57.8410779291881,
           57.8953294128126,
           57.94958089643709,
           58.00383238006158,
           58.05808386368608,
           58.11233534731058,
           58.16658683093506,
           58.220838314559565,
           58.275089798184055,
           58.32934128180855,
           58.38359276543305,
           58.43784424905754,
           58.49209573268204,
           58.54634721630653,
           58.60059869993103,
           58.654850183555524,
           58.709101667180015,
           58.76335315080451,
           58.817604634429,
           58.8718561180535,
           58.926107601678,
           58.98035908530249,
           59.034610568926986,
           59.088862052551484,
           59.143113536175974,
           59.19736501980047,
           59.25161650342497,
           59.30586798704946,
           59.36011947067395,
           59.41437095429845,
           59.468622437922946,
           59.522873921547436,
           59.577125405171934,
           59.63137688879643,
           59.685900984362675,
           59.740561386067,
           59.795221787771325,
           59.84988218947565,
           59.904542591179975,
           59.9592029928843,
           60.013863394588626,
           60.06852379629295,
           60.123184197997276,
           60.177844599701594,
           60.23250500140592,
           60.28716540311025,
           60.34182580481457,
           60.3964862065189,
           60.45114660822321,
           60.505807009927544,
           60.560467411631876,
           60.615127813336194,
           60.669788215040526,
           60.72444861674485,
           60.77910901844917,
           60.83376942015349,
           60.88842982185782,
           60.94309022356215,
           60.99775062526646,
           61.052411026970795,
           61.10707142867513,
           61.161731830379445,
           61.21639223208378,
           61.2710526337881,
           61.32571303549242,
           61.380373437196745,
           61.43503383890108,
           61.489694240605395,
           61.54435464230972,
           61.599015044014045,
           61.65367544571838,
           61.708335847422696,
           61.76299624912702,
           61.81765665083135,
           61.87231705253567,
           61.926977454239996,
           61.98163785594433,
           62.03629825764864,
           62.09095865935298,
           62.14561906105729,
           62.20027946276162,
           62.25493986446595,
           62.309600266170264,
           62.364260667874596,
           62.41044309327315,
           62.45492992341055,
           62.49941675354796,
           62.54390358368536,
           62.588390413822765,
           62.632877243960166,
           62.67736407409757,
           62.72185090423498,
           62.766337734372385,
           62.81082456450979,
           62.85531139464719,
           62.8997982247846,
           62.944285054922,
           62.98877188505941,
           63.03325871519681,
           63.07774554533421,
           63.122232375471626,
           63.16671920560903,
           63.21120603574643,
           63.25569286588383,
           63.30017969602123,
           63.34466652615863,
           63.38915335629604,
           63.43364018643345,
           63.47812701657085,
           63.52261384670826,
           63.56710067684567,
           63.61158750698307,
           63.656074337120465,
           63.70056116725788,
           63.745047997395275,
           63.78953482753268,
           63.834021657670085,
           63.878508487807494,
           63.922995317944896,
           63.9674821480823,
           64.0119689782197,
           64.05645580835711,
           64.10094263849452,
           64.14542946863192,
           64.18991629876932,
           64.23440312890672,
           64.27888995904414,
           64.32337678918154,
           64.36786361931894,
           64.41235044945634,
           64.45683727959374,
           64.50132410973114,
           64.54581093986856,
           64.59029777012502,
           64.63522134089878,
           64.68014491167253,
           64.72506848244629,
           64.76999205322005,
           64.81491562399381,
           64.85983919476757,
           64.90476276554134,
           64.94968633631508,
           64.99460990708884,
           65.03953347786259,
           65.08445704863635,
           65.12938061941011,
           65.17430419018388,
           65.21922776095764,
           65.2641513317314,
           65.30907490250516,
           65.3539984732789,
           65.39892204405267,
           65.44384561482643,
           65.48876918560018,
           65.53369275637394,
           65.5786163271477,
           65.62353989792146,
           65.66846346869522,
           65.71338703946898,
           65.75831061024273,
           65.80323418101649,
           65.84815775179024,
           65.893081322564,
           65.93800489333776,
           65.98292846411152,
           66.02785203488529,
           66.07277560565905,
           66.11437732511652,
           66.15431811891585,
           66.1942589127152,
           66.23419970651454,
           66.27414050031388,
           66.31408129411322,
           66.35402208791257,
           66.39396288171191,
           66.43390367551125,
           66.47384446931059,
           66.51378526310994,
           66.55372605690927,
           66.59366685070862,
           66.63360764450795,
           66.6735484383073,
           66.71348923210664,
           66.75343002590598,
           66.7933708197053,
           66.83331161350466,
           66.873252407304,
           66.91319320110335,
           66.95313399490269,
           66.99307478870203,
           67.03301558250136,
           67.0729563763007,
           67.11289717010004,
           67.15283796389939,
           67.19277875769873,
           67.23271955149806,
           67.27266034529741,
           67.31260113909674,
           67.35254193289609,
           67.39248272669543,
           67.43242352049478,
           67.47236431429411,
           67.51230510809346,
           67.5522459018928,
           67.59218669569213,
           67.63212748949148,
           67.67206828329081,
           67.71200907709016,
           67.75194987088949,
           67.79189066468885,
           67.83183145848818,
           67.87177225228753,
           67.91171304608687,
           67.9516538398862,
           67.99159463368554,
           68.03153542748488,
           68.07147622128423,
           68.11141701508356,
           68.1513578088829,
           68.19129860268225,
           68.2312393964816,
           68.27118019028094,
           68.31112098408028,
           68.35106177787961,
           68.39100257167897,
           68.4309433654783,
           68.47088415927765,
           68.51082495307698,
           68.55076574687632,
           68.59070654067567,
           68.630647334475,
           68.67058812827435,
           68.71052892207368,
           68.75046971587302,
           68.79041050967237,
           68.8303513034717,
           68.87029209727105,
           68.9102328910704,
           68.95017368486972,
           68.99011447866907,
           69.03005527246842,
           69.06999606626775,
           69.1099368600671,
           69.14987765386644,
           69.18981844766577,
           69.22975924146512,
           69.27017598852328,
           69.31088359624174,
           69.35159120396021,
           69.39229881167867,
           69.18783684328591,
           68.73820529878192,
           68.28857375427796,
           67.83894220977402,
           67.38931066527002,
           66.92184929678236,
           66.44979807992942,
           65.97774686307643,
           65.50569564622346,
           65.03364442937055,
           64.56159321251758,
           64.08954199566459,
           63.61749077881164,
           63.145439561958696,
           62.67338834510572,
           62.20133712825278,
           61.729285911399835,
           61.25723469454685,
           60.78518347769391,
           60.313132260840966,
           59.841081043987984,
           59.369029827134995,
           58.8969786102821,
           58.424927393429115,
           57.952876176576126,
           57.48082495972319,
           57.00877374287024,
           56.536722526017265,
           56.064671309164325,
           55.59262009231138,
           55.120568875458396,
           54.648517658605414,
           54.17646644175252,
           53.70441522489953,
           53.232364008046545,
           52.7603127911936,
           52.28826157434066,
           51.81621035748767,
           51.34415914063473,
           50.87210792378179,
           50.4000567069288,
           49.928005490075876,
           49.45595427322292,
           48.98390305636994,
           48.51185183951695,
           48.03980062266406,
           47.56774940581107,
           47.09569818895808,
           46.62364697210515,
           46.151595755252195,
           45.67954453839921,
           45.20749332154628,
           44.735442104693334,
           44.263390887840345,
           43.79133967098736,
           43.319288454134465,
           42.84723723728149,
           42.3751860204285,
           41.90313480357555,
           41.431083586722615,
           40.95903236986962,
           40.486981153016686,
           40.01492993616375,
           39.542878719310764,
           39.070827502457824,
           38.59877628560487,
           38.12672506875189,
           37.654673851898906,
           37.18262263504601,
           36.71057141819303,
           36.238520201340044,
           35.7664689844871,
           35.294417767634165,
           34.822366550781176,
           34.35031533392823,
           33.87826411707529,
           33.4062129002223,
           32.93416168336936,
           32.46211046651642,
           31.990059249663435,
           31.518008032810453,
           31.045956815957517,
           30.57390559910457,
           30.169581430429226,
           29.900711358109138,
           29.631841285789058,
           29.362971213468946,
           29.094101141148865,
           28.825231068828785,
           28.556360996508673,
           28.287490924188564,
           28.018620851868505,
           27.749750779548393,
           27.480880707228287,
           27.212010634908204,
           26.948867849280468,
           26.690879620447344,
           26.432891391614238,
           26.17490316278113,
           25.916914933948007,
           25.658926705114904,
           25.400938476281798,
           25.14295024744867,
           24.884962018615546,
           24.626973789782436,
           24.368985560949334,
           24.11099733211621,
           23.853009103283103,
           23.59502087445,
           23.337032645616873,
           23.07904441678377,
           22.821056187950663,
           22.563067959117536,
           22.305079730284408,
           22.047091501451327,
           21.789103272618206,
           21.531115043785075,
           21.273126814951972,
           21.01513858611887,
           20.757150357285738,
           20.49916212845264,
           20.241173899619533,
           19.983185670786405,
           19.725197441953302,
           19.4672092131202,
           19.20922098428707,
           18.95123275545394,
           18.693244526620838,
           18.43525629778773,
           18.177268068954607,
           17.919279840121504,
           17.661291611288398,
           17.40330338245527,
           17.145315153622168,
           16.887326924789065,
           16.629338695955937,
           16.37135046712281,
           16.113362238289728,
           15.855374009456602,
           15.597385780623473,
           15.33939755179037,
           15.081409322957267,
           14.82342109412414,
           14.565432865291035,
           14.30744463645793,
           14.049456407624804,
           13.7914681787917,
           13.533479949958597,
           13.27549172112547,
           13.017503492292342,
           12.75951526345926,
           12.501527034626134,
           12.243538805793007,
           11.985550576959902,
           11.727562348126797,
           11.469574119293672,
           11.211585890460567,
           10.953597661627462,
           10.695609432794337,
           10.437621203961207,
           10.17963297512813,
           9.921644746295001,
           9.663656517461872,
           9.40566828862877,
           9.147680059795665,
           8.889691830962537,
           8.663766238581827,
           8.598153828462918,
           8.532541418344007,
           8.466929008225097,
           8.4013165981062,
           8.335704187987291,
           8.27009177786838,
           8.204479367749483,
           8.138866957630574,
           8.073254547511663,
           8.007642137392766,
           7.942029727273855,
           7.876417317154945,
           7.810804907036036,
           7.7583849457477,
           7.709613973396455,
           7.66084300104521,
           7.612072028693974,
           7.563301056342727,
           7.514530083991482,
           7.465759111640247,
           7.416988139289002,
           7.368217166937755,
           7.319446194586519,
           7.2706752222352735,
           7.2219042498840285,
           7.1731332775327825,
           7.124362305181547,
           7.0755913328303,
           7.026820360479055,
           6.97804938812782,
           6.929278415776574,
           6.880507443425328,
           6.831736471074092,
           6.782965498722847,
           6.734194526371602,
           6.685423554020356,
           6.63665258166912,
           6.587881609317875,
           6.539110636966628,
           6.490339664615393,
           6.441568692264147,
           6.392797719912902,
           6.344026747561665,
           6.2952557752104195,
           6.246484802859175,
           6.197713830507938,
           6.148942858156692,
           6.100171885805447,
           6.051400913454202,
           6.002629941102965,
           5.95385896875172,
           5.905087996400475,
           5.856317024049238,
           5.807546051697993,
           5.758775079346748,
           5.710004106995511,
           5.661233134644265,
           5.61246216229302,
           5.563691189941775,
           5.5149202175905385,
           5.4661492452392935,
           5.4173782728880475,
           5.368607300536811,
           5.319836328185566,
           5.27106535583432,
           5.222294383483084,
           5.173523411131839,
           5.124752438780593,
           5.075981466429357,
           5.0320187811030195,
           4.995791145313569,
           4.959563509524117,
           4.923335873734673,
           4.887108237945221,
           4.85088060215577,
           4.8146529663663244,
           4.778425330576874,
           4.742197694787423,
           4.705970058997978,
           4.669742423208526,
           4.633514787419076,
           4.597287151629624,
           4.56105951584018
          ],
          [
           58.07826207088204,
           58.13251355450654,
           58.18676503813103,
           58.241016521755526,
           58.295268005380024,
           58.349519489004514,
           58.40377097262901,
           58.4580224562535,
           58.512273939878,
           58.5665254235025,
           58.620776907126995,
           58.675028390751486,
           58.729279874375976,
           58.783531358000474,
           58.83778284162498,
           58.89203432524947,
           58.94628580887396,
           59.000605445177335,
           59.05526584688167,
           59.109926248585985,
           59.16458665029032,
           59.219247051994635,
           59.27390745369896,
           59.328567855403286,
           59.38322825710762,
           59.43788865881194,
           59.492549060516254,
           59.547209462220586,
           59.60186986392491,
           59.656530265629236,
           59.71119066733357,
           59.76585106903788,
           59.82051147074221,
           59.875171872446536,
           59.92983227415086,
           59.98449267585519,
           60.039153077559504,
           60.09381347926384,
           60.14847388096816,
           60.20313428267249,
           60.257794684376805,
           60.31245508608113,
           60.36711548778546,
           60.42177588948979,
           60.476436291194105,
           60.53109669289843,
           60.58575709460276,
           60.640417496307094,
           60.695077898011405,
           60.74973829971574,
           60.804398701420055,
           60.85905910312439,
           60.913719504828705,
           60.96837990653303,
           61.02304030823736,
           61.07770070994168,
           61.13236111164601,
           61.18702151335033,
           61.241681915054656,
           61.29634231675899,
           61.351002718463306,
           61.40566312016764,
           61.46032352187196,
           61.51498392357629,
           61.569644325280606,
           61.62430472698494,
           61.67896512868926,
           61.73362553039358,
           61.788285932097914,
           61.84294633380223,
           61.897606735506564,
           61.95226713721089,
           62.00692753891521,
           62.06158794061954,
           62.11624834232386,
           62.17090874402819,
           62.225569145732514,
           62.28022954743683,
           62.33488994914117,
           62.38955035084548,
           62.444210752549814,
           62.49887115425413,
           62.55353155595846,
           62.60819195766279,
           62.65437438306134,
           62.69886121319875,
           62.74334804333614,
           62.78783487347356,
           62.83232170361096,
           62.87680853374836,
           62.92129536388576,
           62.96578219402316,
           63.01026902416057,
           63.05475585429797,
           63.09924268443539,
           63.14372951457278,
           63.1882163447102,
           63.23270317484759,
           63.277190004985,
           63.32167683512241,
           63.36616366525981,
           63.41065049539722,
           63.45513732553462,
           63.499624155672024,
           63.544110985809425,
           63.58859781594683,
           63.633084646084235,
           63.67757147622164,
           63.722058306359045,
           63.76654513649645,
           63.81103196663385,
           63.85551879677125,
           63.90000562690866,
           63.94449245704607,
           63.98897928718347,
           64.03346611732087,
           64.07795294745827,
           64.12243977759569,
           64.16692660773309,
           64.21141343787049,
           64.2559002680079,
           64.30038709814531,
           64.34487392828271,
           64.38936075842011,
           64.43384758855751,
           64.47833441869491,
           64.52282124883232,
           64.56730807896972,
           64.61179490910713,
           64.65628173924453,
           64.70076856938194,
           64.74525539951934,
           64.78974222965675,
           64.83422905979415,
           64.87871588993156,
           64.92320272006896,
           64.96768955020636,
           65.01217638034377,
           65.05666321048118,
           65.10115004061858,
           65.14563687075598,
           65.19012370089338,
           65.2346105310308,
           65.2790973611682,
           65.3235841913056,
           65.368071021443,
           65.4125578515804,
           65.45704468171782,
           65.50153151185522,
           65.54601834199262,
           65.59072354280538,
           65.63564711357915,
           65.6805706843529,
           65.72549425512665,
           65.77041782590041,
           65.81534139667417,
           65.86026496744793,
           65.9051885382217,
           65.95011210899544,
           65.9950356797692,
           66.03995925054296,
           66.08488282131673,
           66.12980639209047,
           66.17472996286423,
           66.219653533638,
           66.26457710441176,
           66.30950067518552,
           66.351102394643,
           66.39104318844232,
           66.43098398224168,
           66.47092477604102,
           66.51086556984035,
           66.5508063636397,
           66.59074715743904,
           66.63068795123837,
           66.67062874503772,
           66.71056953883706,
           66.75051033263641,
           66.79045112643574,
           66.83039192023509,
           66.87033271403442,
           66.91027350783376,
           66.95021430163311,
           66.99015509543246,
           67.03009588923179,
           67.07003668303113,
           67.10997747683047,
           67.14991827062981,
           67.18985906442916,
           67.22979985822849,
           67.26974065202783,
           67.30968144582718,
           67.34962223962651,
           67.38956303342586,
           67.4295038272252,
           67.46944462102454,
           67.50938541482388,
           67.54932620862323,
           67.58926700242256,
           67.6292077962219,
           67.66914859002125,
           67.70908938382058,
           67.74903017761993,
           67.78897097141927,
           67.8289117652186,
           67.86885255901794,
           67.9087933528173,
           67.94873414661663,
           67.98867494041598,
           68.02861573421532,
           68.06855652801465,
           68.108497321814,
           68.14833084479002,
           68.18735982480311,
           68.22638880481621,
           68.26541778482928,
           68.30444676484238,
           68.34347574485548,
           68.38250472486857,
           68.42153370488165,
           68.46056268489474,
           68.49959166490783,
           68.53862064492091,
           68.577649624934,
           68.61667860494708,
           68.65570758496018,
           68.69473656497327,
           68.73376554498634,
           68.77279452499944,
           68.81182350501254,
           68.85085248502563,
           68.88988146503871,
           68.9289104450518,
           68.9679394250649,
           69.00696840507798,
           69.04599738509107,
           69.08502636510416,
           69.12405534511726,
           69.16308432513034,
           69.20211330514343,
           69.24114228515651,
           69.2801712651696,
           69.31920024518269,
           69.35822922519577,
           69.39725820520886,
           69.43628718522196,
           69.47531616523504,
           69.51434514524813,
           69.55337412526121,
           69.59240310527431,
           69.36375531135845,
           68.86743074351361,
           68.37110617566884,
           67.87478160782408,
           67.37845703997925,
           66.88213247213447,
           66.3858079042897,
           65.88948333644488,
           65.39315876860006,
           64.89683420075534,
           64.40050963291051,
           63.90418506506569,
           63.407860497220916,
           62.911535929376136,
           62.41521136153133,
           61.918886793686546,
           61.42256222584177,
           60.92623765799695,
           60.429913090152176,
           59.9335885223074,
           59.43726395446258,
           58.94093938661777,
           58.455480105597275,
           57.98339346580697,
           57.51130682601667,
           57.039220186226416,
           56.56713354643614,
           56.09504690664585,
           55.62296026685557,
           55.15087362706532,
           54.678786987275025,
           54.20670034748471,
           53.73461370769451,
           53.2625270679042,
           52.79044042811391,
           52.318353788323634,
           51.84626714853337,
           51.37418050874308,
           50.902093868952804,
           50.430007229162555,
           49.95792058937225,
           49.48583394958199,
           49.01374730979174,
           48.54166067000143,
           48.06957403021113,
           47.59748739042091,
           47.125400750630604,
           46.653314110840306,
           46.18122747105005,
           45.70914083125979,
           45.23705419146948,
           44.76496755167922,
           44.292880911888965,
           43.82079427209867,
           43.348707632308354,
           42.87662099251814,
           42.404534352727836,
           41.93244771293754,
           41.46036107314728,
           40.98827443335702,
           40.516187793566715,
           40.04410115377645,
           39.5720145139862,
           39.0999278741959,
           38.627841234405636,
           38.155754594615374,
           37.68366795482507,
           37.21158131503477,
           36.73949467524455,
           36.26740803545425,
           35.79532139566395,
           35.32323475587369,
           34.85114811608343,
           34.379061476293124,
           33.90697483650287,
           33.434888196712606,
           32.9628015569223,
           32.49071491713205,
           32.01862827734178,
           31.54654163755148,
           31.07445499776118,
           30.602368357970917,
           30.130281718180655,
           29.73004931619539,
           29.473525389820132,
           29.21700146344488,
           28.9604775370696,
           28.70395361069435,
           28.44742968431909,
           28.190905757943817,
           27.934381831568537,
           27.677857905193306,
           27.42133397881803,
           27.164810052442753,
           26.9082861260675,
           26.651762199692243,
           26.39523827331697,
           26.138714346941715,
           25.882190420566456,
           25.62566649419118,
           25.369142567815928,
           25.11261864144067,
           24.856094715065396,
           24.59957078869012,
           24.343046862314864,
           24.08652293593961,
           23.829999009564332,
           23.573475083189077,
           23.316951156813822,
           23.060427230438545,
           22.80390330406329,
           22.54737937768804,
           22.290855451312762,
           22.034331524937482,
           21.777807598562255,
           21.521283672186975,
           21.264759745811695,
           21.008235819436443,
           20.751711893061188,
           20.49518796668591,
           20.23866404031066,
           19.9821401139354,
           19.72561618756012,
           19.46909226118487,
           19.212568334809614,
           18.956044408434337,
           18.69952048205906,
           18.442996555683806,
           18.186472629308554,
           17.929948702933274,
           17.673424776558022,
           17.416900850182763,
           17.160376923807487,
           16.90385299743223,
           16.64732907105698,
           16.390805144681703,
           16.134281218306427,
           15.877757291931193,
           15.621233365555916,
           15.364709439180638,
           15.108185512805385,
           14.851661586430131,
           14.595137660054853,
           14.338613733679598,
           14.082089807304344,
           13.825565880929066,
           13.569041954553812,
           13.312518028178559,
           13.05599410180328,
           12.799470175428002,
           12.542946249052772,
           12.286422322677495,
           12.029898396302217,
           11.773374469926965,
           11.516850543551708,
           11.260326617176432,
           11.003802690801178,
           10.75271553208038,
           10.507375881467791,
           10.2620362308552,
           10.016696580242654,
           9.771356929630064,
           9.526017279017474,
           9.280677628404906,
           9.03533797779234,
           8.789998327179749,
           8.575223448366412,
           8.513272428549062,
           8.451321408731713,
           8.389370388914365,
           8.327419369097028,
           8.26546834927968,
           8.20351732946233,
           8.141566309644993,
           8.079615289827643,
           8.017664270010295,
           7.95571325019296,
           7.893762230375612,
           7.8318112105582625,
           7.769860190740912,
           7.7079091709235765,
           7.645958151106228,
           7.584007131288879,
           7.522056111471541,
           7.460105091654193,
           7.398154071836844,
           7.336203052019506,
           7.274252032202158,
           7.221003248368918,
           7.172232276017681,
           7.123461303666437,
           7.074690331315191,
           7.025919358963945,
           6.977148386612709,
           6.928377414261463,
           6.879606441910218,
           6.8308354695589815,
           6.782064497207736,
           6.73329352485649,
           6.684522552505254,
           6.635751580154009,
           6.586980607802763,
           6.538209635451517,
           6.489438663100282,
           6.440667690749036,
           6.39189671839779,
           6.343125746046555,
           6.294354773695309,
           6.245583801344065,
           6.196812828992827,
           6.148041856641582,
           6.099270884290337,
           6.0504999119391005,
           6.001728939587855,
           5.9529579672366095,
           5.904186994885364,
           5.8554160225341265,
           5.8066450501828815,
           5.757874077831636,
           5.7091031054804,
           5.660332133129155,
           5.61156116077791,
           5.562790188426673,
           5.514019216075428,
           5.465248243724183,
           5.416477271372937,
           5.3677062990217,
           5.318935326670454,
           5.277363946536697,
           5.242809944048693,
           5.208255941560681,
           5.17370193907267,
           5.139147936584664,
           5.104593934096653,
           5.07003993160864,
           5.035485929120636,
           5.000931926632625,
           4.966377924144613,
           4.931823921656601,
           4.897269919168597,
           4.862715916680585,
           4.828161914192574,
           4.793607911704569,
           4.759053909216558,
           4.724499906728545,
           4.68994590424054,
           4.655391901752529,
           4.620837899264518,
           4.586283896776506,
           4.551729894288501
          ],
          [
           58.31544621257598,
           58.36997030769632,
           58.424630709400645,
           58.47929111110496,
           58.533951512809296,
           58.58861191451362,
           58.64327231621794,
           58.69793271792227,
           58.752593119626596,
           58.80725352133092,
           58.861913923035246,
           58.916574324739564,
           58.971234726443896,
           59.02589512814822,
           59.080555529852546,
           59.13521593155687,
           59.18987633326119,
           59.24453673496552,
           59.29919713666985,
           59.35385753837417,
           59.4085179400785,
           59.46317834178282,
           59.51783874348715,
           59.57249914519147,
           59.6271595468958,
           59.68181994860012,
           59.73648035030445,
           59.79114075200877,
           59.8458011537131,
           59.900461555417415,
           59.95512195712175,
           60.00978235882607,
           60.0644427605304,
           60.11910316223472,
           60.17376356393904,
           60.22842396564337,
           60.2830843673477,
           60.33774476905202,
           60.39240517075635,
           60.447065572460666,
           60.50172597416499,
           60.556386375869316,
           60.61104677757365,
           60.66570717927797,
           60.7203675809823,
           60.77502798268662,
           60.82968838439095,
           60.88434878609527,
           60.9390091877996,
           60.993669589503924,
           61.04832999120825,
           61.102990392912574,
           61.1576507946169,
           61.212311196321224,
           61.26697159802554,
           61.321631999729874,
           61.3762924014342,
           61.430952803138524,
           61.48561320484285,
           61.54027360654717,
           61.5949340082515,
           61.649594409955824,
           61.70425481166015,
           61.758915213364475,
           61.81357561506879,
           61.868236016773125,
           61.92289641847745,
           61.97755682018177,
           62.0322172218861,
           62.08687762359042,
           62.14153802529474,
           62.19619842699907,
           62.250858828703386,
           62.30551923040772,
           62.360179632112036,
           62.41484003381637,
           62.46950043552069,
           62.52416083722501,
           62.57882123892934,
           62.63348164063366,
           62.688142042337994,
           62.74280244404231,
           62.79746284574664,
           62.85212324745097,
           62.898305672849524,
           62.942792502986926,
           62.98727933312433,
           63.031766163261736,
           63.07625299339914,
           63.120739823536546,
           63.16522665367395,
           63.209713483811356,
           63.25420031394876,
           63.29868714408616,
           63.343173974223575,
           63.38766080436097,
           63.432147634498385,
           63.47663446463578,
           63.52112129477319,
           63.5656081249106,
           63.610094955048,
           63.6545817851854,
           63.6990686153228,
           63.7435554454602,
           63.78804227559761,
           63.83252910573501,
           63.87701593587242,
           63.92150276600982,
           63.965989596147224,
           64.01047642628464,
           64.05496325642204,
           64.09945008655944,
           64.14393691669684,
           64.18842374683425,
           64.23291057697165,
           64.27739740710905,
           64.32188423724646,
           64.36637106738387,
           64.41085789752127,
           64.45534472765867,
           64.49983155779609,
           64.54431838793349,
           64.58880521807089,
           64.63329204820829,
           64.67777887834569,
           64.72226570848309,
           64.7667525386205,
           64.8112393687579,
           64.85572619889531,
           64.90021302903271,
           64.94469985917011,
           64.98918668930753,
           65.03367351944493,
           65.07816034958233,
           65.12264717971973,
           65.16713400985714,
           65.21162083999454,
           65.25610767013194,
           65.30059450026936,
           65.34508133040676,
           65.38956816054416,
           65.43405499068157,
           65.47854182081898,
           65.52302865095638,
           65.56751548109378,
           65.61200231123118,
           65.65648914136858,
           65.700975971506,
           65.7454628016434,
           65.7899496317808,
           65.8344364619182,
           65.87892329205562,
           65.92341012219302,
           65.96789695233042,
           66.01238378246782,
           66.05687061260522,
           66.10135744274262,
           66.14584427288004,
           66.19033110301744,
           66.23481793315484,
           66.27930476329225,
           66.32379159342966,
           66.36827842356706,
           66.41276525370446,
           66.45725208384187,
           66.50173891397927,
           66.54622574471196,
           66.58782746416945,
           66.62707099195333,
           66.66609997196642,
           66.7051289519795,
           66.74415793199259,
           66.78318691200569,
           66.82221589201876,
           66.86124487203185,
           66.90027385204493,
           66.93930283205803,
           66.97833181207112,
           67.01736079208422,
           67.0563897720973,
           67.09541875211039,
           67.13444773212348,
           67.17347671213656,
           67.21250569214965,
           67.25153467216273,
           67.29056365217582,
           67.32959263218892,
           67.36862161220202,
           67.4076505922151,
           67.44667957222819,
           67.48570855224128,
           67.52473753225436,
           67.56376651226745,
           67.60279549228053,
           67.64182447229364,
           67.6808534523067,
           67.7198824323198,
           67.7589114123329,
           67.79794039234599,
           67.83696937235908,
           67.87599835237216,
           67.91502733238525,
           67.95405631239834,
           67.99308529241144,
           68.03211427242452,
           68.07114325243761,
           68.11017223245071,
           68.14920121246378,
           68.18823019247688,
           68.22725917248997,
           68.26628815250305,
           68.30531713251614,
           68.34434611252922,
           68.38337509254231,
           68.4224040725554,
           68.4614330525685,
           68.50046203258158,
           68.53949101259467,
           68.57851999260775,
           68.61754897262084,
           68.65657795263392,
           68.69560693264702,
           68.73463591266011,
           68.7736648926732,
           68.81269387268628,
           68.85172285269937,
           68.89075183271247,
           68.92978081272554,
           68.96880979273864,
           69.00783877275173,
           69.04686775276483,
           69.08589673277791,
           69.124925712791,
           69.1639546928041,
           69.20298367281717,
           69.24201265283027,
           69.28104163284335,
           69.32007061285644,
           69.35909959286954,
           69.39812857288263,
           69.43715755289571,
           69.4761865329088,
           69.51521551292188,
           69.55424449293497,
           69.59327347294806,
           69.63230245296114,
           69.67133143297423,
           69.71036041298733,
           69.74938939300041,
           69.7884183730135,
           69.55977057909763,
           69.06344601125282,
           68.56712144340804,
           68.07079687556327,
           67.57447230771845,
           67.07814773987367,
           66.58182317202889,
           66.08549860418407,
           65.58917403633924,
           65.09284946849452,
           64.59652490064971,
           64.10020033280489,
           63.60387576496011,
           63.10755119711534,
           62.61122662927052,
           62.114902061425745,
           61.618577493580965,
           61.12225292573614,
           60.625928357891375,
           60.12960379004659,
           59.63327922220178,
           59.136954654356956,
           58.64063008651223,
           58.14430551866741,
           57.647980950822586,
           57.15165638297781,
           56.65533181513304,
           56.159007247288216,
           55.66268267944345,
           55.16635811159867,
           54.670033543753846,
           54.17370897590902,
           53.6773844080643,
           53.18105984021948,
           52.68473527237467,
           52.188410704529886,
           51.692086136685106,
           51.1957615688403,
           50.699437000995516,
           50.203112433150736,
           49.70678786530591,
           49.21046329746114,
           48.714138729616366,
           48.21781416177154,
           47.72148959392672,
           47.225165026081996,
           46.72884045823717,
           46.23251589039236,
           45.74287767157124,
           45.27079103178099,
           44.79870439199068,
           44.32661775220042,
           43.854531112410164,
           43.38244447261986,
           42.910357832829554,
           42.43827119303934,
           41.966184553249036,
           41.49409791345873,
           41.02201127366848,
           40.54992463387821,
           40.077837994087915,
           39.60575135429765,
           39.1336647145074,
           38.6615780747171,
           38.18949143492683,
           37.717404795136574,
           37.24531815534627,
           36.77323151555596,
           36.30114487576575,
           35.829058235975445,
           35.35697159618515,
           34.884884956394885,
           34.41279831660462,
           33.940711676814324,
           33.46862503702406,
           32.996538397233806,
           32.5244517574435,
           32.052365117653245,
           31.580278477862983,
           31.10819183807268,
           30.63610519828238,
           30.16401855849212,
           29.691931918701854,
           29.291699516716584,
           29.035175590341332,
           28.778651663966073,
           28.5221277375908,
           28.26560381121554,
           28.00907988484029,
           27.75255595846501,
           27.496032032089737,
           27.239508105714506,
           26.982984179339226,
           26.72646025296395,
           26.469936326588694,
           26.213412400213443,
           25.956888473838166,
           25.70036454746291,
           25.44384062108766,
           25.18731669471238,
           24.930792768337128,
           24.67426884196187,
           24.417744915586596,
           24.161220989211316,
           23.90469706283606,
           23.64817313646081,
           23.39164921008553,
           23.135125283710277,
           22.87860135733502,
           22.622077430959745,
           22.36555350458449,
           22.10902957820923,
           21.852505651833958,
           21.59598172545868,
           21.339457799083448,
           21.08293387270817,
           20.82640994633289,
           20.56988601995764,
           20.313362093582388,
           20.056838167207108,
           19.800314240831852,
           19.5437903144566,
           19.28726638808132,
           19.030742461706065,
           18.77421853533081,
           18.518937276736008,
           18.27359762612342,
           18.02825797551085,
           17.78291832489828,
           17.53757867428569,
           17.292239023673122,
           17.046899373060555,
           16.801559722447966,
           16.556220071835398,
           16.31088042122283,
           16.06554077061024,
           15.82020111999765,
           15.574861469385109,
           15.329521818772518,
           15.084182168159925,
           14.83884251754736,
           14.593502866934791,
           14.3481632163222,
           14.102823565709633,
           13.857483915097067,
           13.612144264484476,
           13.366804613871908,
           13.12146496325934,
           12.876125312646751,
           12.63078566203416,
           12.385446011421616,
           12.140106360809025,
           11.894766710196436,
           11.649427059583868,
           11.4040874089713,
           11.15874775835871,
           10.913408107746141,
           10.668068457133575,
           10.422728806520984,
           10.177389155908394,
           9.932049505295849,
           9.686709854683258,
           9.441370204070669,
           9.196030553458101,
           8.950690902845533,
           8.705351252232944,
           8.490576373419605,
           8.428625353602257,
           8.366674333784907,
           8.30472331396756,
           8.242772294150223,
           8.180821274332873,
           8.118870254515526,
           8.056919234698189,
           7.994968214880839,
           7.933017195063491,
           7.871066175246154,
           7.809115155428805,
           7.747164135611456,
           7.685213115794108,
           7.623262095976771,
           7.561311076159423,
           7.499360056342074,
           7.437409036524738,
           7.3754580167073875,
           7.313506996890039,
           7.2515559770727025,
           7.189604957255353,
           7.127653937438005,
           7.065702917620667,
           7.003751897803319,
           6.94180087798597,
           6.879849858168622,
           6.817898838351284,
           6.7559478185339366,
           6.6962896542724,
           6.6371717863285475,
           6.5780539183846845,
           6.518936050440821,
           6.45981818249697,
           6.400700314553106,
           6.341582446609243,
           6.28246457866538,
           6.223346710721527,
           6.164228842777664,
           6.105110974833801,
           6.045993106889949,
           5.9868752389460855,
           5.942853106876193,
           5.9096136432877096,
           5.876374179699221,
           5.843134716110731,
           5.809895252522248,
           5.776655788933758,
           5.743416325345269,
           5.7101768617567785,
           5.676937398168296,
           5.643697934579807,
           5.6104584709913174,
           5.577219007402834,
           5.543979543814345,
           5.510270301226842,
           5.475716298738837,
           5.441162296250825,
           5.406608293762815,
           5.372054291274803,
           5.3375002887867975,
           5.302946286298786,
           5.268392283810775,
           5.23383828132277,
           5.199284278834758,
           5.164730276346747,
           5.130176273858742,
           5.095622271370731,
           5.061068268882719,
           5.026514266394714,
           4.9919602639067024,
           4.957406261418691,
           4.922852258930679,
           4.888298256442674,
           4.8537442539546625,
           4.819190251466651,
           4.7846362489786465,
           4.750082246490635,
           4.715528244002623,
           4.680974241514618,
           4.646420239026607,
           4.611866236538596,
           4.577312234050583,
           4.542758231562579
          ],
          [
           58.54422225365427,
           58.598785560051844,
           58.65334886644941,
           58.70791217284698,
           58.76247547924455,
           58.81703878564212,
           58.87160209203969,
           58.92616539843726,
           58.98072870483483,
           59.0352920112324,
           59.08985531762997,
           59.14441862402754,
           59.198981930425106,
           59.253545236822674,
           59.30810854322024,
           59.36267184961781,
           59.41723515601538,
           59.471879375286306,
           59.52653977699063,
           59.58120017869496,
           59.635860580399275,
           59.6905209821036,
           59.745181383807925,
           59.79984178551226,
           59.854502187216575,
           59.9091625889209,
           59.96382299062523,
           60.01848339232955,
           60.07314379403388,
           60.1278041957382,
           60.182464597442525,
           60.23712499914685,
           60.291785400851175,
           60.34644580255551,
           60.401106204259825,
           60.45576660596415,
           60.510427007668476,
           60.5650874093728,
           60.619747811077126,
           60.674408212781444,
           60.72906861448577,
           60.7837290161901,
           60.83838941789442,
           60.89304981959875,
           60.947710221303076,
           61.002370623007394,
           61.057031024711726,
           61.111691426416044,
           61.16635182812037,
           61.2210122298247,
           61.27567263152902,
           61.33033303323335,
           61.38499343493767,
           61.439653836641995,
           61.49431423834632,
           61.548974640050645,
           61.60363504175498,
           61.658295443459295,
           61.71295584516362,
           61.76761624686795,
           61.82227664857227,
           61.8769370502766,
           61.93159745198093,
           61.98625785368525,
           62.04091825538958,
           62.0955786570939,
           62.15023905879823,
           62.204899460502546,
           62.25955986220688,
           62.3142202639112,
           62.36888066561553,
           62.42354106731985,
           62.47820146902417,
           62.5328618707285,
           62.58752227243283,
           62.64218267413715,
           62.69684307584148,
           62.751503477545796,
           62.80616387925013,
           62.86082428095445,
           62.91548468265878,
           62.970145084363104,
           63.02480548606742,
           63.079465887771754,
           63.1256483131703,
           63.17013514330771,
           63.21462197344512,
           63.25910880358252,
           63.30359563371992,
           63.348082463857324,
           63.392569293994725,
           63.43705612413214,
           63.481542954269536,
           63.526029784406944,
           63.57051661454435,
           63.61500344468175,
           63.65949027481916,
           63.70397710495656,
           63.74846393509397,
           63.792950765231375,
           63.837437595368776,
           63.881924425506185,
           63.926411255643586,
           63.970898085780995,
           64.01538491591839,
           64.05987174605579,
           64.10435857619319,
           64.1488454063306,
           64.19333223646801,
           64.23781906660541,
           64.28230589674281,
           64.32679272688023,
           64.37127955701763,
           64.41576638715503,
           64.46025321729243,
           64.50474004742983,
           64.54922687756724,
           64.59371370770465,
           64.63820053784205,
           64.68268736797945,
           64.72717419811687,
           64.77166102825427,
           64.81614785839167,
           64.86063468852907,
           64.90512151866648,
           64.94960834880388,
           64.99409517894128,
           65.0385820090787,
           65.0830688392161,
           65.1275556693535,
           65.1720424994909,
           65.21652932962832,
           65.26101615976572,
           65.30550298990312,
           65.34998982004052,
           65.39447665017792,
           65.43896348031532,
           65.48345031045274,
           65.52793714059014,
           65.57242397072754,
           65.61691080086494,
           65.66139763100236,
           65.70588446113976,
           65.75037129127716,
           65.79485812141456,
           65.83934495155196,
           65.88383178168938,
           65.92831861182678,
           65.97280544196418,
           66.01729227210159,
           66.06177910223899,
           66.10574958245758,
           66.14961679179092,
           66.19348400112428,
           66.23735121045762,
           66.28121841979097,
           66.32508562912433,
           66.36895283845767,
           66.41282004779103,
           66.45668725712439,
           66.50055446645773,
           66.54442167579109,
           66.58828888512444,
           66.63215609445778,
           66.67602330379114,
           66.71989051312448,
           66.76375772245784,
           66.80399825536404,
           66.84242545005665,
           66.88085264474927,
           66.91927983944188,
           66.95770703413451,
           66.99613422882713,
           67.03456142351975,
           67.07298861821236,
           67.11141581290498,
           67.1498430075976,
           67.18827020229021,
           67.22669739698284,
           67.26512459167546,
           67.30355178636808,
           67.34197898106069,
           67.38040617575331,
           67.41883337044592,
           67.45726056513854,
           67.49568775983117,
           67.53411495452379,
           67.5725421492164,
           67.61096934390902,
           67.64939653860164,
           67.68782373329425,
           67.72625092798688,
           67.7646781226795,
           67.80310531737211,
           67.84153251206473,
           67.87995970675735,
           67.91838690144998,
           67.95681409614258,
           67.99524129083521,
           68.03366848552783,
           68.07209568022044,
           68.11104260012445,
           68.15007158013753,
           68.18910056015062,
           68.2281295401637,
           68.26715852017679,
           68.30618750018989,
           68.34521648020298,
           68.38424546021608,
           68.42327444022915,
           68.46230342024225,
           68.50133240025534,
           68.54036138026842,
           68.57939036028151,
           68.6184193402946,
           68.6574483203077,
           68.69647730032077,
           68.73550628033387,
           68.77453526034695,
           68.81356424036004,
           68.85259322037314,
           68.89162220038622,
           68.93065118039931,
           68.9696801604124,
           69.00870914042548,
           69.04773812043857,
           69.08676710045167,
           69.12579608046474,
           69.16482506047784,
           69.20385404049094,
           69.24288302050401,
           69.28191200051711,
           69.3209409805302,
           69.35996996054328,
           69.39899894055637,
           69.43802792056945,
           69.47705690058254,
           69.51608588059564,
           69.55511486060873,
           69.59414384062181,
           69.6331728206349,
           69.67220180064798,
           69.71123078066107,
           69.75025976067417,
           69.78928874068725,
           69.82831772070034,
           69.86734670071343,
           69.90637568072651,
           69.9454046607396,
           69.9844336407527,
           69.75578584683683,
           69.259461278992,
           68.76313671114724,
           68.26681214330246,
           67.77048757545764,
           67.27416300761287,
           66.77783843976809,
           66.28151387192327,
           65.78518930407844,
           65.28886473623372,
           64.79254016838891,
           64.29621560054407,
           63.79989103269931,
           63.30356646485454,
           62.8072418970097,
           62.31091732916493,
           61.81459276132017,
           61.31826819347534,
           60.82194362563057,
           60.3256190577858,
           59.82929448994097,
           59.332969922096154,
           58.836645354251424,
           58.34032078640661,
           57.843996218561784,
           57.34767165071702,
           56.85134708287224,
           56.355022515027414,
           55.858697947182634,
           55.36237337933786,
           54.866048811493044,
           54.36972424364822,
           53.8733996758035,
           53.377075107958674,
           52.88075054011385,
           52.384425972269085,
           51.888101404424305,
           51.39177683657948,
           50.895452268734715,
           50.399127700889935,
           49.90280313304511,
           49.40647856520034,
           48.910153997355565,
           48.41382942951074,
           47.91750486166592,
           47.42118029382119,
           46.92485572597637,
           46.42853115813155,
           45.93220659028678,
           45.435882022442,
           44.939557454597185,
           44.44323288675241,
           43.94690831890763,
           43.45058375106281,
           42.954259183217985,
           42.45793461537326,
           41.96161004752844,
           41.46528547968362,
           40.96896091183885,
           40.472636343994076,
           39.97631177614925,
           39.47998720830448,
           38.983662640459706,
           38.48733807261488,
           37.99101350477011,
           37.494688936925336,
           36.99836436908051,
           36.50203980123569,
           36.00571523339096,
           35.50939066554615,
           35.013066097701326,
           34.516741529856546,
           34.02041696201177,
           33.524092394166956,
           33.03027523754526,
           32.558188597755006,
           32.0861019579647,
           31.61401531817444,
           31.141928678384183,
           30.669842038593877,
           30.197755398803576,
           29.725668759013317,
           29.25358211922305,
           28.853349717237784,
           28.596825790862525,
           28.34030186448727,
           28.083777938111997,
           27.82725401173674,
           27.570730085361486,
           27.31420615898621,
           27.057682232610933,
           26.8011583062357,
           26.544634379860426,
           26.288110453485146,
           26.039819370779067,
           25.794479720166496,
           25.549140069553907,
           25.303800418941343,
           25.058460768328775,
           24.813121117716182,
           24.567781467103618,
           24.32244181649105,
           24.077102165878458,
           23.831762515265865,
           23.5864228646533,
           23.341083214040736,
           23.09574356342814,
           22.850403912815576,
           22.60506426220301,
           22.359724611590416,
           22.11438496097785,
           21.869045310365284,
           21.623705659752694,
           21.3783660091401,
           21.13302635852756,
           20.88768670791497,
           20.642347057302377,
           20.39700740668981,
           20.15166775607724,
           19.906328105464652,
           19.660988454852085,
           19.415648804239517,
           19.170309153626928,
           18.92496950301436,
           18.679629852401792,
           18.434290201789203,
           18.188950551176614,
           17.943610900564043,
           17.69827124995148,
           17.452931599338886,
           17.207591948726318,
           16.962252298113754,
           16.71691264750116,
           16.471572996888593,
           16.226233346276025,
           15.980893695663436,
           15.735554045050847,
           15.4902143944383,
           15.244874743825712,
           14.999535093213119,
           14.754195442600553,
           14.508855791987987,
           14.263516141375398,
           14.018176490762828,
           13.772836840150259,
           13.52749718953767,
           13.282157538925103,
           13.036817888312534,
           12.791478237699945,
           12.546138587087356,
           12.30079893647481,
           12.05545928586222,
           11.810119635249631,
           11.564779984637061,
           11.319440334024495,
           11.074100683411906,
           10.828761032799337,
           10.583421382186769,
           10.33808173157418,
           10.092742080961589,
           9.847402430349044,
           9.602062779736455,
           9.356723129123864,
           9.111383478511296,
           8.866043827898729,
           8.62070417728614,
           8.4059292984728,
           8.343978278655452,
           8.282027258838102,
           8.220076239020754,
           8.158125219203418,
           8.09617419938607,
           8.034223179568722,
           7.972272159751383,
           7.910321139934035,
           7.848370120116686,
           7.786573468592118,
           7.727455600648254,
           7.668337732704391,
           7.609219864760528,
           7.550101996816675,
           7.490984128872813,
           7.431866260928949,
           7.3727483929850965,
           7.313630525041234,
           7.254512657097371,
           7.195394789153518,
           7.136276921209655,
           7.0771590532657935,
           7.01804118532194,
           6.958923317378077,
           6.899805449434215,
           6.840687581490351,
           6.781569713546499,
           6.722451845602635,
           6.6633339776587714,
           6.60421610971492,
           6.545098241771057,
           6.485980373827194,
           6.426862505883342,
           6.367744637939479,
           6.308626769995616,
           6.249508902051752,
           6.1903910341079005,
           6.1312731661640365,
           6.072155298220174,
           6.013037430276322,
           5.953919562332459,
           5.909897430262566,
           5.876657966674083,
           5.8434185030855925,
           5.810179039497104,
           5.776939575908621,
           5.743700112320131,
           5.710460648731642,
           5.677221185143153,
           5.643981721554669,
           5.61074225796618,
           5.57750279437769,
           5.544263330789207,
           5.511023867200717,
           5.477784403612227,
           5.444544940023745,
           5.411305476435255,
           5.378066012846766,
           5.3448265492582765,
           5.311587085669793,
           5.278347622081304,
           5.2451081584928145,
           5.2118686949043305,
           5.178629231315842,
           5.145389767727352,
           5.1121503041388685,
           5.078910840550379,
           5.04567137696189,
           5.0124319133734065,
           4.979192449784917,
           4.945952986196428,
           4.912713522607938,
           4.879326593716751,
           4.8447725912287405,
           4.810218588740729,
           4.775664586252724,
           4.741110583764712,
           4.7065565812767005,
           4.672002578788695,
           4.6374485763006845,
           4.602894573812673,
           4.568340571324661,
           4.533786568836656
          ],
          [
           58.77282493110391,
           58.82738823750148,
           58.88195154389905,
           58.93651485029662,
           58.991078156694186,
           59.04564146309176,
           59.100204769489324,
           59.15476807588689,
           59.20933138228447,
           59.263894688682036,
           59.31845799507961,
           59.37302130147717,
           59.42758460787475,
           59.48214791427232,
           59.536711220669886,
           59.591274527067455,
           59.64583783346502,
           59.70040113986259,
           59.75496444626016,
           59.80952775265773,
           59.8640910590553,
           59.918654365452866,
           59.973217671850435,
           60.02778097824802,
           60.08234428464557,
           60.13690759104315,
           60.19147089744072,
           60.24603420383828,
           60.30059751023586,
           60.35516081663343,
           60.409724123031,
           60.46428742942857,
           60.51885073582613,
           60.573446407427646,
           60.62810680913197,
           60.6827672108363,
           60.73742761254062,
           60.79208801424495,
           60.84674841594927,
           60.9014088176536,
           60.95606921935793,
           61.01072962106225,
           61.06539002276658,
           61.1200504244709,
           61.17471082617522,
           61.229371227879554,
           61.28403162958387,
           61.338692031288204,
           61.393352432992515,
           61.44801283469685,
           61.50267323640118,
           61.5573336381055,
           61.61199403980983,
           61.666654441514154,
           61.72131484321847,
           61.77597524492279,
           61.83063564662712,
           61.885296048331455,
           61.939956450035766,
           61.9946168517401,
           62.04927725344443,
           62.10393765514875,
           62.15859805685307,
           62.213258458557405,
           62.26791886026172,
           62.32257926196605,
           62.37723966367037,
           62.43190006537469,
           62.48656046707902,
           62.54122086878335,
           62.59588127048768,
           62.650541672192,
           62.705202073896324,
           62.75986247560065,
           62.814522877304974,
           62.8691832790093,
           62.92384368071363,
           62.97850408241794,
           63.03316448412228,
           63.08782488582659,
           63.142485287530924,
           63.19714568923524,
           63.25180609093957,
           63.3064664926439,
           63.35264891804246,
           63.39713574817986,
           63.441622578317265,
           63.486109408454666,
           63.53059623859207,
           63.57508306872948,
           63.61956989886688,
           63.66405672900429,
           63.70854355914169,
           63.75303038927909,
           63.797517219416505,
           63.8420040495539,
           63.88649087969131,
           63.93097770982871,
           63.975464539966126,
           64.01995137010353,
           64.06443820024093,
           64.10892503037833,
           64.15341186051575,
           64.19789869065315,
           64.24238552079055,
           64.28687235092795,
           64.33135918106535,
           64.37584601120275,
           64.42033284134016,
           64.46481967147756,
           64.50930650161497,
           64.55379333175237,
           64.59828016188978,
           64.64276699202718,
           64.68725382216459,
           64.731740652302,
           64.7762274824394,
           64.8207143125768,
           64.8652011427142,
           64.9096879728516,
           64.95417480298902,
           64.9986616331264,
           65.04314846326382,
           65.08763529340123,
           65.13212212353864,
           65.17660895367604,
           65.22109578381342,
           65.26558261395084,
           65.31006944408824,
           65.35455627422564,
           65.39904310436305,
           65.44352993450046,
           65.48801676463786,
           65.53250359477526,
           65.57678388529364,
           65.620651094627,
           65.66451830396034,
           65.70838551329369,
           65.75225272262703,
           65.79611993196039,
           65.83998714129375,
           65.88385435062709,
           65.92772155996045,
           65.9715887692938,
           66.01545597862714,
           66.0593231879605,
           66.10319039729384,
           66.1470576066272,
           66.19092481596056,
           66.2347920252939,
           66.27865923462726,
           66.32252644396061,
           66.36639365329395,
           66.4102608626273,
           66.45412807196065,
           66.49799528129401,
           66.54186249062735,
           66.58572969996071,
           66.62959690929407,
           66.67346411862741,
           66.71733132796076,
           66.76119853729412,
           66.80506574662746,
           66.84893295596082,
           66.89280016529418,
           66.93666737462752,
           66.98053458396087,
           67.02077511686707,
           67.05920231155969,
           67.0976295062523,
           67.13605670094493,
           67.17448389563754,
           67.21291109033015,
           67.25133828502278,
           67.2897654797154,
           67.32819267440803,
           67.36661986910063,
           67.40504706379326,
           67.44347425848588,
           67.4819014531785,
           67.52032864787111,
           67.55875584256373,
           67.59718303725634,
           67.63561023194896,
           67.67403742664158,
           67.7124646213342,
           67.75089181602682,
           67.78931901071942,
           67.82774620541207,
           67.86617340010467,
           67.90460059479729,
           67.94302778948992,
           67.98145498418253,
           68.01988217887515,
           68.05830937356777,
           68.09673656826038,
           68.135163762953,
           68.17359095764563,
           68.21201815233823,
           68.25044534703086,
           68.28887254172346,
           68.3272997364161,
           68.36572693110871,
           68.40415412580133,
           68.44258132049396,
           68.48100851518657,
           68.51943570987919,
           68.5578629045718,
           68.59629009926442,
           68.63471729395704,
           68.67314448864965,
           68.71157168334229,
           68.7499988780349,
           68.78842607272752,
           68.82685326742012,
           68.86528046211275,
           68.90370765680537,
           68.942134851498,
           68.98056204619061,
           69.01898924088322,
           69.05741643557585,
           69.09584363026846,
           69.13427082496108,
           69.17269801965371,
           69.21112521434631,
           69.24955240903893,
           69.28797960373156,
           69.32640679842417,
           69.36483399311679,
           69.4032611878094,
           69.44168838250204,
           69.48011557719464,
           69.51854277188727,
           69.55696996657987,
           69.5953971612725,
           69.63404318830865,
           69.67307216832175,
           69.71210114833482,
           69.75113012834792,
           69.79015910836101,
           69.8291880883741,
           69.86821706838718,
           69.90724604840028,
           69.94627502841337,
           69.98530400842645,
           70.02433298843954,
           70.06336196845263,
           70.10239094846573,
           70.1414199284788,
           70.1804489084919,
           69.95180111457603,
           69.4554765467312,
           68.95915197888642,
           68.46282741104166,
           67.96650284319684,
           67.47017827535207,
           66.97385370750729,
           66.47752913966247,
           65.98120457181766,
           65.48488000397292,
           64.9885554361281,
           64.49223086828327,
           63.995906300438506,
           63.49958173259373,
           63.0032571647489,
           62.506932596904136,
           62.01060802905936,
           61.51428346121453,
           61.01795889336976,
           60.52163432552499,
           60.02530975768017,
           59.52898518983535,
           59.03266062199063,
           58.5363360541458,
           58.040011486300976,
           57.54368691845621,
           57.04736235061143,
           56.55103778276661,
           56.05471321492183,
           55.55838864707706,
           55.06206407923224,
           54.56573951138742,
           54.06941494354269,
           53.56655556481144,
           53.06206243416338,
           52.557569303515365,
           52.05307617286736,
           51.5485830422193,
           51.04408991157129,
           50.53959678092328,
           50.03510365027523,
           49.53061051962722,
           49.0261173889792,
           48.521624258331144,
           48.017131127683086,
           47.51263799703512,
           47.00814486638707,
           46.50365173573901,
           45.999158605091,
           45.49466547444299,
           44.99017234379493,
           44.485679213146916,
           43.98118608249891,
           43.47669295185085,
           42.97219982120279,
           42.467706690554834,
           41.96321355990678,
           41.45872042925872,
           40.95422729861071,
           40.4497341679627,
           39.945241037314645,
           39.44074790666663,
           38.93625477601863,
           38.43176164537057,
           37.927268514722556,
           37.42277538407455,
           36.91828225342648,
           36.41378912277843,
           35.90929599213047,
           35.40480286148241,
           34.90030973083436,
           34.39581660018635,
           33.891323469538335,
           33.38683033889028,
           32.88233720824227,
           32.37784407759426,
           31.8733509469462,
           31.36885781629819,
           30.864364685650177,
           30.359871555002123,
           29.85537842435407,
           29.350885293706057,
           28.846392163058045,
           28.4285815772061,
           28.184136080946327,
           27.939690584686556,
           27.69524508842676,
           27.45079959216699,
           27.206354095907223,
           26.961908599647423,
           26.717463103387633,
           26.473017607127886,
           26.228572110868086,
           25.984126614608297,
           25.739681118348525,
           25.495235622088753,
           25.25079012582896,
           25.006344629569185,
           24.76189913330942,
           24.51745363704962,
           24.273008140789855,
           24.028562644530084,
           23.784117148270287,
           23.539671652010494,
           23.295226155750722,
           23.050780659490954,
           22.806335163231157,
           22.56188966697139,
           22.317444170711617,
           22.07299867445182,
           21.828553178192053,
           21.58410768193228,
           21.339662185672488,
           21.09521668941269,
           20.85077119315294,
           20.606325696893155,
           20.361880200633355,
           20.117434704373586,
           19.87298920811381,
           19.62854371185402,
           19.38409821559425,
           19.139652719334478,
           18.895207223074685,
           18.65076172681491,
           18.406316230555138,
           18.161870734295345,
           17.917425238035552,
           17.672979741775784,
           17.428534245516012,
           17.18408874925622,
           16.939643252996447,
           16.695197756736675,
           16.450752260476882,
           16.20630676421711,
           15.961861267957339,
           15.717415771697546,
           15.472970275437753,
           15.228524779178002,
           14.98407928291821,
           14.739633786658416,
           14.495188290398644,
           14.250742794138873,
           14.00629729787908,
           13.761851801619308,
           13.517406305359536,
           13.272960809099743,
           13.028515312839971,
           12.7840698165802,
           12.539624320320407,
           12.295178824060613,
           12.050733327800865,
           11.80628783154107,
           11.561842335281277,
           11.324187449425366,
           11.091201132954003,
           10.858214816482619,
           10.625228500011255,
           10.392242183539892,
           10.159255867068506,
           9.926269550597121,
           9.69328323412578,
           9.460296917654395,
           9.227310601183008,
           8.994324284711645,
           8.761337968240282,
           8.528351651768897,
           8.324432073574036,
           8.265846186761532,
           8.20726029994903,
           8.148674413136527,
           8.090088526324035,
           8.031502639511533,
           7.97291675269903,
           7.914330865886538,
           7.855744979074036,
           7.797159092261532,
           7.738573205449041,
           7.679987318636537,
           7.621401431824035,
           7.562815545011531,
           7.50422965819904,
           7.445643771386537,
           7.387057884574034,
           7.328471997761542,
           7.26988611094904,
           7.2113002241365365,
           7.152714337324044,
           7.094128450511542,
           7.035542563699039,
           6.976956676886546,
           6.918370790074045,
           6.8597849032615414,
           6.801199016449038,
           6.7426131296365455,
           6.684027242824043,
           6.625441356011541,
           6.566855469199048,
           6.508269582386546,
           6.449683695574043,
           6.39109780876155,
           6.332511921949049,
           6.273926035136546,
           6.215340148324042,
           6.156754261511551,
           6.098168374699048,
           6.0391996216065476,
           5.980081753662695,
           5.920963885718832,
           5.876941753648939,
           5.843702290060455,
           5.810462826471966,
           5.777350567968172,
           5.74439570008932,
           5.711440832210459,
           5.6784859643316,
           5.645531096452741,
           5.612576228573887,
           5.579621360695027,
           5.5466664928161675,
           5.513711624937314,
           5.480756757058454,
           5.447801889179595,
           5.414847021300742,
           5.381892153421882,
           5.348937285543022,
           5.315982417664163,
           5.283027549785309,
           5.250072681906449,
           5.21711781402759,
           5.184162946148737,
           5.151208078269877,
           5.118253210391018,
           5.085298342512164,
           5.052343474633305,
           5.019388606754445,
           4.986433738875592,
           4.953478870996731,
           4.920524003117872,
           4.887569135239012,
           4.854614267360159,
           4.8216593994813,
           4.78870453160244,
           4.755749663723586,
           4.7227947958447265,
           4.689839927965867,
           4.6568850600870135,
           4.623930192208154,
           4.590975324329294,
           4.558020456450435,
           4.525065588571581
          ],
          [
           59.001427608553556,
           59.055990914951124,
           59.11055422134869,
           59.16511752774626,
           59.21968083414383,
           59.2742441405414,
           59.32880744693897,
           59.383370753336536,
           59.43793405973412,
           59.49249736613169,
           59.547060672529255,
           59.601623978926824,
           59.65618728532439,
           59.71075059172196,
           59.76531389811953,
           59.8198772045171,
           59.87444051091467,
           59.929003817312235,
           59.983567123709804,
           60.03813043010739,
           60.09269373650494,
           60.14725704290251,
           60.201820349300085,
           60.25638365569766,
           60.31094696209522,
           60.3655102684928,
           60.42007357489037,
           60.47463688128793,
           60.529200187685504,
           60.58376349408307,
           60.63832680048064,
           60.69289010687821,
           60.74745341327578,
           60.802016719673354,
           60.856580026070915,
           60.911143332468484,
           60.96570663886606,
           61.02026994526362,
           61.074833251661204,
           61.129396558058765,
           61.18395986445634,
           61.23852317085391,
           61.29308647725148,
           61.34764978364905,
           61.402213090046615,
           61.456776396444184,
           61.51133970284175,
           61.56590300923932,
           61.62046631563689,
           61.67502962203446,
           61.729673841273325,
           61.78433424297766,
           61.838994644681975,
           61.8936550463863,
           61.948315448090625,
           62.00297584979495,
           62.05763625149928,
           62.1122966532036,
           62.166957054907925,
           62.22161745661225,
           62.276277858316575,
           62.3309382600209,
           62.38559866172523,
           62.44025906342956,
           62.494919465133876,
           62.54957986683821,
           62.604240268542526,
           62.65890067024685,
           62.71356107195118,
           62.7682214736555,
           62.82288187535983,
           62.87754227706416,
           62.932202678768476,
           62.9868630804728,
           63.041523482177126,
           63.09618388388146,
           63.15084428558578,
           63.2055046872901,
           63.26016508899443,
           63.31482549069875,
           63.369485892403084,
           63.4241462941074,
           63.47880669581173,
           63.53346709751606,
           63.57964952291461,
           63.624136353052016,
           63.668623183189425,
           63.713110013326826,
           63.75759684346423,
           63.80208367360163,
           63.84657050373904,
           63.89105733387645,
           63.93554416401385,
           63.98003099415125,
           64.02451782428865,
           64.06900465442605,
           64.11349148456347,
           64.15797831470087,
           64.20246514483827,
           64.24695197497567,
           64.29143880511309,
           64.33592563525049,
           64.38041246538789,
           64.4248992955253,
           64.4693861256627,
           64.51387295580011,
           64.55835978593751,
           64.60284661607491,
           64.64733344621231,
           64.69182027634972,
           64.73630710648712,
           64.78079393662452,
           64.82528076676194,
           64.86976759689934,
           64.91425442703674,
           64.95874125717415,
           65.00322808731154,
           65.04771491744896,
           65.09168539746307,
           65.13555260679642,
           65.17941981612977,
           65.22328702546312,
           65.26715423479646,
           65.3110214441298,
           65.35488865346318,
           65.39875586279652,
           65.44262307212988,
           65.48649028146322,
           65.53035749079658,
           65.57422470012993,
           65.61809190946329,
           65.66195911879663,
           65.70582632812999,
           65.74969353746333,
           65.79356074679669,
           65.83742795613003,
           65.88129516546338,
           65.92516237479674,
           65.96902958413008,
           66.01289679346344,
           66.0567640027968,
           66.10063121213014,
           66.1444984214635,
           66.18836563079684,
           66.2322328401302,
           66.27610004946354,
           66.31996725879691,
           66.36383446813025,
           66.40770167746359,
           66.45156888679695,
           66.4954360961303,
           66.53930330546365,
           66.58317051479699,
           66.62703772413036,
           66.6709049334637,
           66.71477214279706,
           66.75863935213042,
           66.80250656146376,
           66.8463737707971,
           66.89024098013047,
           66.93410818946381,
           66.97797539879716,
           67.02184260813051,
           67.06570981746385,
           67.10957702679723,
           67.15344423613057,
           67.19731144546392,
           67.23755197837012,
           67.27597917306274,
           67.31440636775535,
           67.35283356244798,
           67.3912607571406,
           67.42968795183322,
           67.46811514652583,
           67.50654234121843,
           67.54496953591106,
           67.58339673060368,
           67.6218239252963,
           67.66025111998891,
           67.69867831468154,
           67.73710550937416,
           67.77553270406678,
           67.81395989875938,
           67.85238709345201,
           67.89081428814464,
           67.92924148283726,
           67.96766867752987,
           68.00609587222249,
           68.0445230669151,
           68.08295026160772,
           68.12137745630034,
           68.15980465099295,
           68.19823184568557,
           68.2366590403782,
           68.2750862350708,
           68.31351342976342,
           68.35194062445605,
           68.39036781914866,
           68.42879501384128,
           68.46722220853391,
           68.50564940322651,
           68.54407659791913,
           68.58250379261176,
           68.62093098730438,
           68.65935818199699,
           68.69778537668961,
           68.73621257138223,
           68.77463976607484,
           68.81306696076747,
           68.85149415546007,
           68.8899213501527,
           68.92834854484533,
           68.96677573953795,
           69.00520293423057,
           69.04363012892317,
           69.0820573236158,
           69.12048451830842,
           69.15891171300103,
           69.19733890769365,
           69.23576610238626,
           69.27419329707888,
           69.31262049177151,
           69.35104768646411,
           69.38947488115674,
           69.42790207584935,
           69.46632927054198,
           69.5047564652346,
           69.54318365992722,
           69.58161085461984,
           69.62003804931246,
           69.65846524400506,
           69.69689243869769,
           69.73465033548445,
           69.77173892983753,
           69.80882752419062,
           69.8459161185437,
           69.88300471289678,
           69.92009330724986,
           69.95718190160294,
           69.99427049595603,
           70.03135909030911,
           70.0684476846622,
           70.10553627901527,
           70.14262487336836,
           70.17971346772144,
           70.21680206207452,
           70.25389065642761,
           70.2909792507807,
           70.32806784513377,
           70.36515643948685,
           70.12467362956603,
           69.60661941537131,
           69.08856520117664,
           68.57051098698196,
           68.05245677278724,
           67.53440255859256,
           67.01634834439788,
           66.49829413020316,
           65.98023991600843,
           65.46218570181381,
           64.94413148761909,
           64.42607727342437,
           63.908023059229684,
           63.38996884503501,
           62.871914630840294,
           62.35386041664562,
           61.83580620245094,
           61.31775198825622,
           60.79969777406154,
           60.281643559866865,
           59.763589345672145,
           59.24553513147741,
           58.72748091728279,
           58.209426703088056,
           57.69137248889334,
           57.17852195476931,
           56.674028824121294,
           56.169535693473236,
           55.66504256282523,
           55.16054943217722,
           54.65605630152916,
           54.15156317088109,
           53.64707004023314,
           53.142576909585074,
           52.63808377893702,
           52.13359064828901,
           51.629097517641,
           51.124604386992935,
           50.62011125634493,
           50.11561812569691,
           49.611124995048854,
           49.10663186440085,
           48.60213873375284,
           48.09764560310479,
           47.59315247245674,
           47.088659341808764,
           46.58416621116071,
           46.079673080512656,
           45.57517994986465,
           45.07068681921663,
           44.566193688568575,
           44.06170055792057,
           43.55720742727256,
           43.0527142966245,
           42.548221165976436,
           42.043728035328485,
           41.53923490468041,
           41.034741774032355,
           40.530248643384354,
           40.02575551273634,
           39.52126238208829,
           39.01676925144028,
           38.512276120792265,
           38.007782990144214,
           37.5032898594962,
           36.99879672884819,
           36.494303598200126,
           35.989810467552076,
           35.48531733690411,
           34.98082420625605,
           34.476331075608,
           33.97183794495999,
           33.46734481431198,
           32.96285168366392,
           32.45835855301591,
           31.9538654223679,
           31.449372291719843,
           30.94487916107183,
           30.440386030423824,
           29.935892899775766,
           29.431399769127708,
           28.9269066384797,
           28.42241350783169,
           28.00460292197974,
           27.76015742571997,
           27.5157119294602,
           27.271266433200402,
           27.026820936940634,
           26.782375440680863,
           26.537929944421066,
           26.293484448161273,
           26.049038951901526,
           25.80459345564173,
           25.560147959381936,
           25.315702463122168,
           25.071256966862396,
           24.826811470602603,
           24.58236597434283,
           24.337920478083063,
           24.093474981823267,
           23.84902948556349,
           23.604583989303723,
           23.36013849304393,
           23.115692996784137,
           22.871247500524365,
           22.626802004264594,
           22.3823565080048,
           22.137911011745032,
           21.893465515485257,
           21.649020019225464,
           21.404574522965696,
           21.160129026705924,
           20.91568353044613,
           20.671238034186334,
           20.426792537926584,
           20.182347041666794,
           19.937901545406998,
           19.69345604914723,
           19.449010552887454,
           19.20456505662766,
           18.960119560367893,
           18.71567406410812,
           18.47122856784833,
           18.234937889784735,
           18.00195157331337,
           17.768965256841987,
           17.5359789403706,
           17.302992623899236,
           17.070006307427875,
           16.837019990956488,
           16.604033674485127,
           16.37104735801376,
           16.13806104154238,
           15.905074725071014,
           15.67208840859965,
           15.439102092128266,
           15.20611577565688,
           14.97312945918554,
           14.740143142714155,
           14.50715682624277,
           14.274170509771409,
           14.041184193300044,
           13.808197876828658,
           13.575211560357294,
           13.342225243885931,
           13.109238927414548,
           12.876252610943183,
           12.643266294471818,
           12.410279978000434,
           12.177293661529049,
           11.944307345057709,
           11.711321028586323,
           11.478334712114938,
           11.245348395643575,
           11.01236207917221,
           10.779375762700827,
           10.546389446229462,
           10.313403129758099,
           10.080416813286714,
           9.84743049681533,
           9.614444180343988,
           9.381457863872601,
           9.148471547401217,
           8.915485230929853,
           8.68249891445849,
           8.449512597987106,
           8.245593019792244,
           8.18700713297974,
           8.128421246167237,
           8.069835359354736,
           8.011249472542243,
           7.952663585729741,
           7.894077698917237,
           7.835491812104746,
           7.776905925292244,
           7.718320038479741,
           7.659734151667249,
           7.6011482648547455,
           7.542562378042243,
           7.483976491229739,
           7.425390604417248,
           7.3668047176047455,
           7.308218830792242,
           7.249632943979751,
           7.191047057167248,
           7.132461170354745,
           7.073875283542252,
           7.0152893967297505,
           6.956703509917246,
           6.8981176231047545,
           6.839531736292252,
           6.78233492345018,
           6.726452102063923,
           6.670569280677677,
           6.61468645929142,
           6.558803637905163,
           6.502920816518917,
           6.447037995132661,
           6.391155173746404,
           6.335272352360159,
           6.279389530973901,
           6.223506709587644,
           6.167623888201388,
           6.111741066815141,
           6.055858245428885,
           5.999975424042629,
           5.944092602656382,
           5.888209781270126,
           5.846463190653429,
           5.814813907729279,
           5.7831646248051225,
           5.751515341880967,
           5.719866058956816,
           5.688216776032659,
           5.656567493108504,
           5.624918210184347,
           5.593268927260198,
           5.561619644336041,
           5.529970361411884,
           5.498321078487733,
           5.4666717955635775,
           5.435022512639421,
           5.40337322971527,
           5.371723946791114,
           5.340074663866958,
           5.307573123460746,
           5.274618255581893,
           5.241663387703033,
           5.2087085198241745,
           5.17575365194532,
           5.142798784066461,
           5.109843916187602,
           5.076889048308748,
           5.043934180429888,
           5.0109793125510285,
           4.978024444672174,
           4.9450695767933155,
           4.912114708914455,
           4.879159841035596,
           4.846204973156743,
           4.813250105277883,
           4.780295237399024,
           4.74734036952017,
           4.71438550164131,
           4.681430633762451,
           4.648475765883598,
           4.615520898004737,
           4.582566030125879,
           4.549611162247018,
           4.516656294368165
          ],
          [
           59.23003028600319,
           59.28459359240076,
           59.33915689879833,
           59.3937202051959,
           59.44828351159347,
           59.50284681799104,
           59.5574101243886,
           59.61197343078618,
           59.666536737183755,
           59.72110004358132,
           59.77566334997889,
           59.83022665637645,
           59.88478996277403,
           59.9393532691716,
           59.993916575569166,
           60.048479881966735,
           60.1030431883643,
           60.15760649476187,
           60.21216980115945,
           60.266733107557016,
           60.321296413954585,
           60.37585972035215,
           60.43042302674972,
           60.48498633314729,
           60.53954963954486,
           60.594112945942435,
           60.648676252339996,
           60.703239558737565,
           60.75780286513514,
           60.81236617153271,
           60.86692947793028,
           60.921492784327846,
           60.97605609072541,
           61.03061939712298,
           61.08518270352055,
           61.13974600991812,
           61.19430931631569,
           61.24887262271326,
           61.30343592911083,
           61.357999235508395,
           61.41256254190598,
           61.46712584830354,
           61.521689154701114,
           61.57625246109868,
           61.63081576749625,
           61.68537907389382,
           61.73994238029139,
           61.79450568668896,
           61.849068993086526,
           61.903632299484094,
           61.95819560588167,
           62.01275891227924,
           62.0673222186768,
           62.12188552507437,
           62.17644883147194,
           62.23101213786951,
           62.28557544426708,
           62.34013875066465,
           62.39470205706222,
           62.449265363459794,
           62.50382866985736,
           62.55839197625493,
           62.6129552826525,
           62.66751858905007,
           62.722081895447644,
           62.77664520184521,
           62.83124087341468,
           62.885901275119004,
           62.94056167682333,
           62.995222078527654,
           63.049882480231986,
           63.104542881936304,
           63.15920328364063,
           63.21386368534496,
           63.26852408704928,
           63.32318448875361,
           63.37784489045793,
           63.432505292162254,
           63.48716569386659,
           63.541826095570904,
           63.59648649727523,
           63.651146898979555,
           63.70580730068388,
           63.760467702388205,
           63.80665012778676,
           63.85113695792417,
           63.89562378806157,
           63.94011061819898,
           63.98459744833638,
           64.02908427847379,
           64.07357110861119,
           64.11805793874859,
           64.162544768886,
           64.20703159902341,
           64.25151842916081,
           64.2960052592982,
           64.34049208943561,
           64.38497891957302,
           64.42946574971043,
           64.47395257984783,
           64.51843940998523,
           64.56271970029913,
           64.60658690963248,
           64.65045411896584,
           64.69432132829918,
           64.73818853763254,
           64.78205574696588,
           64.82592295629924,
           64.8697901656326,
           64.91365737496594,
           64.95752458429929,
           65.00139179363265,
           65.04525900296599,
           65.08912621229935,
           65.1329934216327,
           65.17686063096605,
           65.2207278402994,
           65.26459504963275,
           65.3084622589661,
           65.35232946829944,
           65.3961966776328,
           65.44006388696616,
           65.4839310962995,
           65.52779830563286,
           65.57166551496621,
           65.61553272429956,
           65.65939993363291,
           65.70326714296627,
           65.74713435229961,
           65.79100156163297,
           65.83486877096632,
           65.87873598029967,
           65.92260318963301,
           65.96647039896636,
           66.01033760829972,
           66.05420481763306,
           66.09807202696642,
           66.14193923629978,
           66.18580644563312,
           66.22967365496648,
           66.27354086429983,
           66.31740807363317,
           66.36127528296653,
           66.40514249229987,
           66.44900970163323,
           66.49287691096657,
           66.53674412029994,
           66.58061132963329,
           66.62447853896663,
           66.66834574829998,
           66.71221295763334,
           66.7560801669667,
           66.79994737630004,
           66.8438145856334,
           66.88768179496674,
           66.9315490043001,
           66.97541621363344,
           67.0192834229668,
           67.06315063230015,
           67.10701784163349,
           67.15088505096685,
           67.19475226030019,
           67.23861946963356,
           67.2824866789669,
           67.32635388830025,
           67.3702210976336,
           67.41408830696696,
           67.45432883987314,
           67.49275603456577,
           67.53118322925839,
           67.569610423951,
           67.60803761864362,
           67.64646481333624,
           67.68489200802887,
           67.72331920272148,
           67.7617463974141,
           67.80017359210672,
           67.83860078679933,
           67.87702798149195,
           67.91545517618457,
           67.95388237087718,
           67.99230956556981,
           68.03073676026243,
           68.06916395495504,
           68.10759114964766,
           68.14601834434029,
           68.18444553903291,
           68.22287273372552,
           68.26129992841814,
           68.29972712311076,
           68.33815431780337,
           68.37658151249599,
           68.41500870718862,
           68.45343590188124,
           68.49186309657385,
           68.53029029126647,
           68.5687174859591,
           68.60714468065171,
           68.64557187534433,
           68.68399907003695,
           68.72225894152768,
           68.75934753588078,
           68.79643613023386,
           68.83352472458694,
           68.87061331894002,
           68.9077019132931,
           68.94479050764619,
           68.98187910199927,
           69.01896769635235,
           69.05605629070544,
           69.09314488505852,
           69.1302334794116,
           69.16732207376468,
           69.20441066811777,
           69.24149926247085,
           69.27858785682393,
           69.31567645117701,
           69.3527650455301,
           69.38985363988319,
           69.42694223423626,
           69.46403082858936,
           69.50111942294242,
           69.53820801729552,
           69.57529661164861,
           69.61238520600168,
           69.64947380035477,
           69.68656239470785,
           69.72365098906093,
           69.76073958341401,
           69.7978281777671,
           69.83491677212018,
           69.87200536647326,
           69.90909396082634,
           69.94618255517942,
           69.98327114953251,
           70.02035974388559,
           70.05744833823867,
           70.09453693259175,
           70.13162552694484,
           70.16871412129792,
           70.20580271565102,
           70.2428913100041,
           70.27997990435716,
           70.31706849871024,
           70.35415709306335,
           70.39124568741643,
           70.42833428176951,
           70.46542287612259,
           70.50251147047567,
           70.53960006482875,
           70.29911725490794,
           69.7810630407132,
           69.26300882651853,
           68.74495461232385,
           68.22690039812913,
           67.70884618393447,
           67.19079196973979,
           66.67273775554506,
           66.15468354135034,
           65.6366293271557,
           65.11857511296098,
           64.60052089876626,
           64.08246668457159,
           63.56441247037691,
           63.04635825618219,
           62.52830404198751,
           62.01024982779283,
           61.49219561359811,
           60.974141399403436,
           60.456087185208766,
           59.93803297101403,
           59.41997875681931,
           58.90192454262469,
           58.383870328429964,
           57.86581611423523,
           57.34776190004056,
           56.82970768584588,
           56.31165347165117,
           55.79359925745649,
           55.275545043261815,
           54.757490829067095,
           54.23943661487236,
           53.72138240067774,
           53.20332818648301,
           52.685273972288286,
           52.16721975809361,
           51.64916554389893,
           51.13111132970421,
           50.613057115509534,
           50.09500290131486,
           49.57694868712014,
           49.05889447292546,
           48.54084025873078,
           48.02278604453606,
           47.504731830341335,
           46.98667761614671,
           46.46862340195199,
           45.95056918775727,
           45.43251497356258,
           44.91446075936791,
           44.396406545173186,
           43.878352330978515,
           43.36029811678384,
           42.84224390258911,
           42.324189688394384,
           41.806135474199756,
           41.288081260005036,
           40.77002704581031,
           40.25197283161563,
           39.733918617420954,
           39.215864403226234,
           38.69781018903156,
           38.17975597483689,
           37.66170176064216,
           37.14364754644748,
           36.625593332252805,
           36.107539118058085,
           35.589484903863365,
           35.07143068966873,
           34.55684555102972,
           34.05235242038166,
           33.54785928973365,
           33.04336615908564,
           32.538873028437585,
           32.03437989778958,
           31.529886767141566,
           31.025393636493504,
           30.52090050584549,
           30.01640737519748,
           29.511914244549423,
           29.00742111390137,
           28.50292798325336,
           27.998434852605346,
           27.5806242667534,
           27.33617877049363,
           27.091733274233857,
           26.84728777797406,
           26.60284228171429,
           26.358396785454524,
           26.113951289194727,
           25.86950579293493,
           25.625060296675187,
           25.38061480041539,
           25.145688330144083,
           24.91270201367272,
           24.67971569720136,
           24.446729380729973,
           24.213743064258612,
           23.980756747787247,
           23.74777043131586,
           23.5147841148445,
           23.281797798373137,
           23.04881148190175,
           22.81582516543036,
           22.582838848959003,
           22.34985253248764,
           22.116866216016252,
           21.88387989954489,
           21.65089358307353,
           21.417907266602143,
           21.18492095013078,
           20.951934633659416,
           20.71894831718803,
           20.485962000716643,
           20.252975684245307,
           20.019989367773917,
           19.78700305130253,
           19.554016734831173,
           19.321030418359808,
           19.08804410188842,
           18.85505778541706,
           18.622071468945695,
           18.38908515247431,
           18.15609883600295,
           17.923112519531582,
           17.6901262030602,
           17.457139886588813,
           17.224153570117448,
           16.991167253646086,
           16.7581809371747,
           16.52519462070334,
           16.292208304231973,
           16.059221987760587,
           15.826235671289226,
           15.59324935481786,
           15.360263038346478,
           15.127276721875091,
           14.894290405403751,
           14.661304088932367,
           14.42831777246098,
           14.195331455989617,
           13.962345139518254,
           13.72935882304687,
           13.496372506575504,
           13.263386190104143,
           13.030399873632758,
           12.797413557161395,
           12.56442724069003,
           12.331440924218645,
           12.09845460774726,
           11.865468291275917,
           11.632481974804534,
           11.399495658333148,
           11.166509341861783,
           10.933523025390421,
           10.700536708919037,
           10.467550392447674,
           10.23456407597631,
           10.001577759504926,
           9.768591443033541,
           9.535605126562197,
           9.302618810090815,
           9.069632493619428,
           8.836646177148065,
           8.603659860676702,
           8.370673544205317,
           8.166753966010456,
           8.108168079197952,
           8.049582192385449,
           7.990996305572947,
           7.932410418760455,
           7.873824531947951,
           7.815238645135448,
           7.756878012061325,
           7.700995190675068,
           7.645112369288811,
           7.5892295479025655,
           7.533346726516308,
           7.477463905130053,
           7.421581083743796,
           7.365698262357549,
           7.309815440971293,
           7.253932619585036,
           7.198049798198789,
           7.142166976812533,
           7.086284155426276,
           7.030401334040031,
           6.974518512653773,
           6.918635691267517,
           6.8627528698812705,
           6.806870048495014,
           6.750987227108757,
           6.6951044057225015,
           6.639221584336255,
           6.583338762949998,
           6.5274559415637405,
           6.471573120177495,
           6.4156902987912385,
           6.359807477404981,
           6.303924656018736,
           6.248041834632479,
           6.192159013246222,
           6.136276191859966,
           6.080393370473719,
           6.024510549087463,
           5.968627727701206,
           5.912744906314959,
           5.856862084928703,
           5.815115494312007,
           5.783466211387856,
           5.7518169284636995,
           5.720167645539544,
           5.688518362615393,
           5.656869079691237,
           5.62521979676708,
           5.593570513842925,
           5.561921230918774,
           5.530271947994618,
           5.498622665070461,
           5.4669733821463105,
           5.435324099222154,
           5.403674816297999,
           5.372025533373847,
           5.340376250449692,
           5.308726967525535,
           5.2770776846013785,
           5.245428401677228,
           5.213779118753072,
           5.182129835828916,
           5.1504805529047655,
           5.118831269980609,
           5.087181987056454,
           5.055532704132302,
           5.023883421208146,
           4.99223413828399,
           4.960584855359839,
           4.928935572435683,
           4.897286289511527,
           4.86563700658737,
           4.83398772366322,
           4.802338440739065,
           4.770689157814908,
           4.738931075316754,
           4.705976207437894,
           4.6730213395590345,
           4.640066471680181,
           4.607111603801322,
           4.574156735922462,
           4.541201868043602,
           4.508247000164749
          ],
          [
           59.45863296345283,
           59.5131962698504,
           59.56775957624796,
           59.62232288264553,
           59.6768861890431,
           59.73144949544068,
           59.78601280183824,
           59.84057610823581,
           59.895139414633384,
           59.94970272103095,
           60.00426602742853,
           60.05882933382609,
           60.11339264022366,
           60.16795594662123,
           60.222519253018795,
           60.27708255941637,
           60.33164586581394,
           60.38620917221151,
           60.44077247860908,
           60.495335785006645,
           60.549899091404214,
           60.60446239780179,
           60.65902570419935,
           60.71358901059693,
           60.76815231699449,
           60.822715623392064,
           60.87727892978963,
           60.9318422361872,
           60.98640554258477,
           61.04096884898234,
           61.09553215537991,
           61.15009546177749,
           61.204658768175044,
           61.25922207457263,
           61.31378538097018,
           61.36834868736775,
           61.42291199376533,
           61.477475300162894,
           61.53203860656047,
           61.58660191295804,
           61.64116521935561,
           61.695728525753175,
           61.750291832150744,
           61.80485513854831,
           61.85941844494588,
           61.91398175134345,
           61.96854505774102,
           62.023108364138594,
           62.07767167053616,
           62.13223497693373,
           62.186798283331306,
           62.241361589728875,
           62.29592489612644,
           62.350488202524005,
           62.405051508921574,
           62.45961481531915,
           62.51417812171672,
           62.568741428114286,
           62.623304734511855,
           62.67786804090942,
           62.73243134730699,
           62.78699465370456,
           62.841557960102136,
           62.896121266499705,
           62.95068457289727,
           63.00524787929484,
           63.05981118569241,
           63.11437449208997,
           63.16893779848755,
           63.223501104885116,
           63.278064411282685,
           63.33262771768025,
           63.38719102407783,
           63.4417543304754,
           63.496317636872966,
           63.550880943270535,
           63.6054442496681,
           63.66000755606567,
           63.71457086246325,
           63.769134168860816,
           63.823697475258385,
           63.878260781655946,
           63.93282408805352,
           63.98746830726036,
           64.03365073265891,
           64.07762121246856,
           64.1214884218019,
           64.16535563113526,
           64.20922284046861,
           64.25309004980195,
           64.29695725913531,
           64.34082446846865,
           64.38469167780201,
           64.42855888713535,
           64.47242609646871,
           64.51629330580207,
           64.56016051513542,
           64.60402772446876,
           64.64789493380212,
           64.69176214313546,
           64.73562935246882,
           64.77949656180218,
           64.82336377113552,
           64.86723098046888,
           64.91109818980222,
           64.95496539913557,
           64.99883260846892,
           65.04269981780227,
           65.08656702713563,
           65.13043423646897,
           65.17430144580233,
           65.21816865513568,
           65.26203586446903,
           65.30590307380238,
           65.34977028313574,
           65.39363749246908,
           65.43750470180244,
           65.48137191113578,
           65.52523912046914,
           65.56910632980248,
           65.61297353913584,
           65.6568407484692,
           65.70070795780254,
           65.74457516713589,
           65.78844237646925,
           65.83230958580259,
           65.87617679513595,
           65.92004400446929,
           65.96391121380265,
           66.007778423136,
           66.05164563246936,
           66.0955128418027,
           66.13938005113604,
           66.1832472604694,
           66.22711446980276,
           66.2709816791361,
           66.31484888846946,
           66.35871609780281,
           66.40258330713615,
           66.44645051646951,
           66.49031772580287,
           66.53418493513621,
           66.57805214446955,
           66.62191935380291,
           66.66578656313627,
           66.70965377246962,
           66.75352098180298,
           66.79738819113632,
           66.84125540046966,
           66.88512260980302,
           66.92898981913638,
           66.97285702846973,
           67.01672423780307,
           67.06059144713642,
           67.10445865646977,
           67.14832586580312,
           67.19219307513647,
           67.23606028446983,
           67.27992749380317,
           67.32379470313653,
           67.36766191246988,
           67.41152912180323,
           67.45539633113658,
           67.49926354046994,
           67.54313074980328,
           67.58699795913664,
           67.63086516847,
           67.67110570137618,
           67.70953289606881,
           67.74695614192402,
           67.7840447362771,
           67.82113333063018,
           67.85822192498327,
           67.89531051933635,
           67.93239911368944,
           67.96948770804251,
           68.0065763023956,
           68.04366489674868,
           68.08075349110176,
           68.11784208545484,
           68.15493067980793,
           68.192019274161,
           68.22910786851409,
           68.26619646286719,
           68.30328505722026,
           68.34037365157336,
           68.37746224592642,
           68.4145508402795,
           68.4516394346326,
           68.48872802898566,
           68.52581662333876,
           68.56290521769185,
           68.59999381204491,
           68.63708240639801,
           68.6741710007511,
           68.71125959510417,
           68.74834818945726,
           68.78543678381033,
           68.82252537816342,
           68.85961397251651,
           68.89670256686958,
           68.93379116122267,
           68.97087975557577,
           69.00796834992883,
           69.04505694428192,
           69.082145538635,
           69.11923413298808,
           69.15632272734118,
           69.19341132169426,
           69.23049991604734,
           69.26758851040043,
           69.3046771047535,
           69.34176569910659,
           69.37885429345967,
           69.41594288781275,
           69.45303148216584,
           69.49012007651892,
           69.527208670872,
           69.56429726522508,
           69.60138585957817,
           69.63847445393125,
           69.67556304828433,
           69.71265164263741,
           69.7497402369905,
           69.78682883134357,
           69.82391742569666,
           69.86100602004974,
           69.89809461440284,
           69.93518320875592,
           69.972271803109,
           70.00936039746207,
           70.04644899181517,
           70.08353758616823,
           70.12062618052133,
           70.1577147748744,
           70.1948033692275,
           70.23189196358058,
           70.26898055793366,
           70.30606915228674,
           70.34315774663983,
           70.3802463409929,
           70.41733493534599,
           70.45442352969907,
           70.49151212405215,
           70.52860071840526,
           70.56568931275832,
           70.6027779071114,
           70.6398665014645,
           70.67695509581758,
           70.71404369017066,
           70.47356088024983,
           69.9555066660551,
           69.43745245186044,
           68.91939823766575,
           68.40134402347103,
           67.88328980927636,
           67.36523559508169,
           66.84718138088695,
           66.32912716669223,
           65.81107295249761,
           65.29301873830289,
           64.77496452410816,
           64.25691030991348,
           63.73885609571881,
           63.220801881524096,
           62.702747667329405,
           62.18469345313474,
           61.66663923894001,
           61.14858502474533,
           60.63053081055067,
           60.11247659635595,
           59.594422382161206,
           59.07636816796659,
           58.55831395377186,
           58.04025973957714,
           57.52220552538246,
           57.00415131118779,
           56.48609709699306,
           55.968042882798386,
           55.44998866860371,
           54.93193445440899,
           54.41388024021426,
           53.895826026019634,
           53.37777181182491,
           52.85971759763019,
           52.34166338343551,
           51.82360916924084,
           51.30555495504612,
           50.787500740851435,
           50.26944652665675,
           49.75139231246203,
           49.23333809826735,
           48.715283884072676,
           48.197229669877956,
           47.679175455683236,
           47.1611212414886,
           46.64306702729388,
           46.12501281309916,
           45.606958598904484,
           45.08890438470981,
           44.57085017051509,
           44.05279595632041,
           43.53474174212573,
           43.01668752793101,
           42.49863331373629,
           41.98057909954166,
           41.46252488534693,
           40.94447067115221,
           40.42641645695753,
           39.90558903148358,
           39.37074180266197,
           38.83589457384042,
           38.30104734501886,
           37.766200116197254,
           37.2313528873757,
           36.696505658554145,
           36.16165842973254,
           35.62681120091093,
           35.091963972089424,
           34.55711674326781,
           34.022269514446215,
           33.48742228562466,
           32.9525750568031,
           32.417727827981494,
           31.88288059915994,
           31.348033370338385,
           30.813186141516784,
           30.278338912695226,
           29.74349168387367,
           29.208644455052067,
           28.673797226230462,
           28.138949997408904,
           27.604102768587346,
           27.169992274988378,
           26.93735525183461,
           26.704718228680843,
           26.472081205527054,
           26.239444182373283,
           26.006807159219516,
           25.774170136065727,
           25.54153311291194,
           25.308896089758193,
           25.0762590666044,
           24.843622043450612,
           24.610985020296845,
           24.378347997143077,
           24.145710973989285,
           23.913073950835518,
           23.68043692768175,
           23.44779990452796,
           23.21516288137419,
           22.982525858220427,
           22.749888835066635,
           22.517251811912846,
           22.28461478875908,
           22.05197776560531,
           21.81934074245152,
           21.586703719297752,
           21.354066696143985,
           21.121429672990196,
           20.888792649836425,
           20.65615562668266,
           20.42351860352887,
           20.190881580375077,
           19.958244557221335,
           19.725607534067542,
           19.492970510913754,
           19.260333487759986,
           19.027696464606215,
           18.79505944145243,
           18.56242241829866,
           18.329785395144892,
           18.097148371991096,
           17.864511348837333,
           17.631874325683565,
           17.399237302529777,
           17.166600279375984,
           16.933963256222217,
           16.70132623306845,
           16.468689209914658,
           16.23605218676089,
           16.003415163607123,
           15.770778140453334,
           15.538141117299565,
           15.305504094145798,
           15.072867070992007,
           14.840230047838219,
           14.607593024684471,
           14.374956001530682,
           14.142318978376892,
           13.909681955223125,
           13.677044932069355,
           13.444407908915567,
           13.2117708857618,
           12.97913386260803,
           12.746496839454242,
           12.513859816300473,
           12.281222793146704,
           12.048585769992915,
           11.819763509741096,
           11.59883694688997,
           11.377910384038799,
           11.156983821187628,
           10.93605725833648,
           10.715130695485332,
           10.494204132634161,
           10.273277569783012,
           10.052351006931863,
           9.831424444080694,
           9.610497881229524,
           9.389571318378396,
           9.168644755527225,
           8.947718192676057,
           8.726791629824907,
           8.505865066973758,
           8.28493850412259,
           8.091585962212545,
           8.036103525007883,
           7.9806210878032235,
           7.925138650598562,
           7.869656213393912,
           7.814173776189252,
           7.758691338984591,
           7.7032089017799406,
           7.64772646457528,
           7.5922440273706195,
           7.536761590165969,
           7.481279152961308,
           7.425796715756649,
           7.370314278551986,
           7.314831841347337,
           7.259349404142676,
           7.2038669669380155,
           7.148384529733366,
           7.092902092528704,
           7.037419655324044,
           6.981937218119393,
           6.926454780914733,
           6.870972343710072,
           6.815489906505423,
           6.760007469300762,
           6.704525032096102,
           6.649042594891441,
           6.59356015768679,
           6.5380777204821285,
           6.482595283277469,
           6.427112846072818,
           6.371630408868158,
           6.316147971663497,
           6.260665534458847,
           6.205183097254187,
           6.149700660049526,
           6.094218222844865,
           6.038735785640215,
           5.983284123202774,
           5.930387036105836,
           5.8774899490089085,
           5.824592861911971,
           5.784964377622728,
           5.754813466767554,
           5.724662555912375,
           5.6943138763403836,
           5.662885085567929,
           5.631456294795468,
           5.600027504023007,
           5.568598713250546,
           5.537169922478091,
           5.50574113170563,
           5.474312340933169,
           5.442883550160714,
           5.411454759388253,
           5.380025968615792,
           5.348597177843336,
           5.3171683870708755,
           5.285739596298414,
           5.254310805525953,
           5.222882014753498,
           5.191453223981036,
           5.160024433208576,
           5.128595642436121,
           5.097166851663659,
           5.0657380608911975,
           5.034309270118742,
           5.002880479346281,
           4.97145168857382,
           4.940022897801366,
           4.908594107028904,
           4.877165316256443,
           4.845736525483982,
           4.814307734711527,
           4.782878943939066,
           4.751450153166605,
           4.720021362394149,
           4.6885925716216885,
           4.657163780849228,
           4.625734990076772,
           4.594306199304311,
           4.56287740853185,
           4.531448617759389,
           4.500019826986934
          ],
          [
           59.68247069133622,
           59.73619596363026,
           59.7899212359243,
           59.84364650821834,
           59.89737178051239,
           59.95109705280643,
           60.00482232510047,
           60.05854759739451,
           60.11227286968856,
           60.165998141982605,
           60.21972341427664,
           60.27344868657068,
           60.327173958864726,
           60.38089923115878,
           60.43462450345282,
           60.48834977574686,
           60.542494065417316,
           60.59705737181488,
           60.65162067821245,
           60.70618398461002,
           60.76074729100759,
           60.815310597405166,
           60.86987390380273,
           60.924437210200296,
           60.979000516597864,
           61.03356382299544,
           61.08812712939301,
           61.14269043579057,
           61.197253742188146,
           61.25181704858573,
           61.30638035498329,
           61.36094366138086,
           61.41550696777842,
           61.470070274175995,
           61.52463358057357,
           61.57919688697113,
           61.63376019336871,
           61.68832349976627,
           61.742886806163845,
           61.79745011256141,
           61.852013418958975,
           61.90657672535656,
           61.96114003175412,
           62.015703338151695,
           62.070266644549264,
           62.12482995094683,
           62.1793932573444,
           62.23395656374196,
           62.288519870139524,
           62.34308317653711,
           62.397646482934675,
           62.452209789332244,
           62.50677309572981,
           62.56133640212738,
           62.61589970852496,
           62.67046301492252,
           62.7250263213201,
           62.77958962771766,
           62.834152934115224,
           62.8887162405128,
           62.943279546910375,
           62.997842853307944,
           63.05240615970551,
           63.10696946610308,
           63.16153277250065,
           63.21609607889821,
           63.27065938529578,
           63.32522269169335,
           63.379785998090924,
           63.43434930448849,
           63.48891261088606,
           63.54347591728363,
           63.5980392236812,
           63.652602530078774,
           63.70716583647634,
           63.76172914287391,
           63.81629244927148,
           63.87085575566905,
           63.925419062066624,
           63.97998236846419,
           64.03454567486176,
           64.08910898125933,
           64.1436722876569,
           64.19823559405447,
           64.24388548623185,
           64.2877526955652,
           64.33161990489856,
           64.3754871142319,
           64.41935432356526,
           64.4632215328986,
           64.50708874223196,
           64.55095595156531,
           64.59482316089866,
           64.63869037023201,
           64.68255757956535,
           64.72642478889871,
           64.77029199823207,
           64.81415920756541,
           64.85802641689878,
           64.90189362623212,
           64.94576083556548,
           64.98962804489884,
           65.03349525423218,
           65.07736246356554,
           65.12122967289888,
           65.16509688223223,
           65.20896409156558,
           65.25283130089893,
           65.29669851023229,
           65.34056571956563,
           65.38443292889899,
           65.42830013823234,
           65.47216734756569,
           65.51603455689904,
           65.55990176623239,
           65.60376897556574,
           65.64763618489908,
           65.69150339423244,
           65.7353706035658,
           65.77923781289914,
           65.8231050222325,
           65.86697223156585,
           65.9108394408992,
           65.95470665023255,
           65.99857385956591,
           66.04244106889925,
           66.0863082782326,
           66.13017548756595,
           66.1740426968993,
           66.21790990623266,
           66.261777115566,
           66.30564432489936,
           66.3495115342327,
           66.39337874356606,
           66.43724595289942,
           66.48111316223277,
           66.52498037156612,
           66.56884758089947,
           66.61271479023281,
           66.65658199956619,
           66.70044920889953,
           66.74431641823287,
           66.78818362756623,
           66.83205083689958,
           66.87591804623293,
           66.91978525556627,
           66.96365246489962,
           67.00751967423298,
           67.05138688356632,
           67.09525409289968,
           67.13912130223302,
           67.18285111243928,
           67.22589392509384,
           67.2689367377484,
           67.31197955040297,
           67.35502236305753,
           67.39806517571209,
           67.44110798836664,
           67.4841508010212,
           67.52719361367576,
           67.57023642633033,
           67.61327923898489,
           67.65632205163945,
           67.69936486429403,
           67.74240767694857,
           67.78545048960315,
           67.8284933022577,
           67.8672813056568,
           67.90394190442818,
           67.94060250319956,
           67.97726310197092,
           68.0139237007423,
           68.05058429951367,
           68.08724489828505,
           68.12390549705643,
           68.16056609582779,
           68.19722669459915,
           68.23388729337054,
           68.2705478921419,
           68.30720849091328,
           68.34386908968466,
           68.38052968845602,
           68.4171902872274,
           68.45385088599878,
           68.49051148477015,
           68.52717208354153,
           68.56383268231289,
           68.60049328108427,
           68.63715387985565,
           68.67381447862702,
           68.71047507739839,
           68.74713567616976,
           68.78379627494112,
           68.82045687371252,
           68.85711747248388,
           68.89377807125526,
           68.93043867002663,
           68.967099268798,
           69.00375986756937,
           69.04042046634075,
           69.07708106511211,
           69.1137416638835,
           69.15040226265486,
           69.18706286142624,
           69.22372346019762,
           69.26038405896898,
           69.29704465774036,
           69.33370525651173,
           69.3703658552831,
           69.40702645405447,
           69.44368705282585,
           69.48034765159723,
           69.5170082503686,
           69.55366884913997,
           69.59038651315466,
           69.62747510750773,
           69.66456370186083,
           69.70165229621391,
           69.73874089056699,
           69.77582948492007,
           69.81291807927316,
           69.85000667362624,
           69.88709526797932,
           69.9241838623324,
           69.96127245668548,
           69.99836105103857,
           70.03544964539167,
           70.07253823974473,
           70.10962683409781,
           70.1467154284509,
           70.18380402280398,
           70.22089261715706,
           70.25798121151016,
           70.29506980586324,
           70.33215840021631,
           70.3692469945694,
           70.40633558892247,
           70.44342418327557,
           70.48051277762865,
           70.51760137198173,
           70.5546899663348,
           70.59177856068789,
           70.62886715504098,
           70.66595574939407,
           70.70304434374715,
           70.74013293810023,
           70.77722153245331,
           70.8143101268064,
           70.85139872115947,
           70.88848731551256,
           70.64800450559173,
           70.12995029139701,
           69.61189607720235,
           69.09384186300767,
           68.57578764881293,
           68.05773343461827,
           67.5396792204236,
           67.02162500622886,
           66.50357079203414,
           65.98551657783952,
           65.46746236364478,
           64.94940814945006,
           64.43135393525539,
           63.91329972106072,
           63.39524550686598,
           62.87719129267131,
           62.35913707847664,
           61.841082864281915,
           61.32302865008724,
           60.80497443589257,
           60.28692022169785,
           59.768866007503114,
           59.25081179330849,
           58.73275757911377,
           58.21470336491904,
           57.680164211369274,
           57.145316982547726,
           56.61046975372612,
           56.07562252490457,
           55.540775296083005,
           55.00592806726141,
           54.4710808384398,
           53.9362336096183,
           53.401386380796694,
           52.86653915197509,
           52.331691923153535,
           51.79684469433198,
           51.261997465510376,
           50.727150236688814,
           50.19230300786726,
           49.657455779045655,
           49.1226085502241,
           48.58776132140254,
           48.052914092580934,
           47.51806686375933,
           46.983219634937825,
           46.44837240611622,
           45.91352517729461,
           45.378677948473054,
           44.8438307196515,
           44.3089834908299,
           43.77413626200834,
           43.23928903318678,
           42.70444180436518,
           42.16959457554357,
           41.634747346722065,
           41.09990011790046,
           40.565052889078856,
           40.030205660257295,
           39.49535843143575,
           38.960511202614136,
           38.42566397379258,
           37.890816744971026,
           37.35596951614942,
           36.82112228732787,
           36.286275058506305,
           35.75142782968471,
           35.2165806008631,
           34.681733372041585,
           34.14688614321999,
           33.61203891439838,
           33.07719168557682,
           32.542344456755266,
           32.00749722793366,
           31.472649999112107,
           30.93780277029055,
           30.402955541468945,
           29.868108312647387,
           29.333261083825832,
           28.798413855004227,
           28.263566626182627,
           27.72871939736107,
           27.193872168539507,
           26.759761674940542,
           26.527124651786778,
           26.294487628633007,
           26.06185060547922,
           25.82921358232545,
           25.59657655917168,
           25.363939536017895,
           25.131302512864103,
           24.898665489710357,
           24.66602846655657,
           24.433391443402776,
           24.20075442024901,
           23.96811739709524,
           23.73548037394145,
           23.502843350787685,
           23.270206327633915,
           23.037569304480126,
           22.80493228132636,
           22.572295258172588,
           22.339658235018803,
           22.10702121186501,
           21.874384188711243,
           21.641747165557476,
           21.409110142403684,
           21.176473119249916,
           20.943836096096152,
           20.711199072942357,
           20.478562049788593,
           20.245925026634826,
           20.013288003481037,
           19.780650980327245,
           19.5480139571735,
           19.31537693401971,
           19.08273991086592,
           18.85010288771215,
           18.617465864558383,
           18.384828841404595,
           18.153078974494047,
           17.932152411642896,
           17.711225848791724,
           17.490299285940576,
           17.269372723089425,
           17.048446160238257,
           16.82751959738709,
           16.60659303453594,
           16.38566647168479,
           16.16473990883362,
           15.943813345982472,
           15.722886783131322,
           15.501960220280152,
           15.281033657429006,
           15.060107094577855,
           14.839180531726686,
           14.618253968875516,
           14.397327406024386,
           14.17640084317322,
           13.955474280322049,
           13.7345477174709,
           13.51362115461975,
           13.29269459176858,
           13.071768028917433,
           12.850841466066283,
           12.629914903215113,
           12.408988340363964,
           12.188061777512814,
           11.967135214661646,
           11.746208651810475,
           11.525282088959347,
           11.304355526108179,
           11.083428963257008,
           10.862502400405859,
           10.64157583755471,
           10.42064927470354,
           10.199722711852392,
           9.978796149001242,
           9.757869586150072,
           9.536943023298903,
           9.316016460447774,
           9.095089897596605,
           8.874163334745436,
           8.653236771894287,
           8.432310209043138,
           8.211383646191967,
           8.018031104281924,
           7.962548667077263,
           7.907066229872602,
           7.851583792667941,
           7.796101355463291,
           7.740618918258631,
           7.685136481053971,
           7.62965404384932,
           7.57417160664466,
           7.518689169439999,
           7.4632067322353475,
           7.407724295030687,
           7.3522418578260265,
           7.296759420621367,
           7.241276983416717,
           7.1857945462120565,
           7.130312109007395,
           7.074829671802744,
           7.019347234598084,
           6.9638647973934225,
           6.9083823601887735,
           6.852899922984113,
           6.799883569226562,
           6.746986482129634,
           6.694089395032697,
           6.64119230793576,
           6.5882952208388215,
           6.535398133741895,
           6.482501046644957,
           6.42960395954802,
           6.376706872451093,
           6.323809785354156,
           6.270912698257218,
           6.2180156111602916,
           6.165118524063354,
           6.112221436966417,
           6.059324349869479,
           6.006427262772553,
           5.953530175675615,
           5.900633088578677,
           5.84773600148175,
           5.794838914384814,
           5.75521043009557,
           5.7250595192403955,
           5.694908608385217,
           5.664757697530038,
           5.634606786674864,
           5.604455875819685,
           5.5743049649645044,
           5.544154054109327,
           5.514003143254152,
           5.483852232398974,
           5.453701321543794,
           5.42355041068862,
           5.39339949983344,
           5.36324858897826,
           5.333097678123088,
           5.302946767267908,
           5.2727958564127295,
           5.242644945557551,
           5.2124940347023765,
           5.182343123847197,
           5.151920282200672,
           5.120491491428217,
           5.089062700655755,
           5.057633909883294,
           5.026205119110838,
           4.994776328338379,
           4.963347537565918,
           4.931918746793461,
           4.900489956021,
           4.869061165248539,
           4.837632374476079,
           4.806203583703623,
           4.774774792931162,
           4.743346002158701,
           4.711917211386245,
           4.680488420613784,
           4.649059629841323,
           4.617630839068869,
           4.586202048296408,
           4.554773257523945,
           4.523344466751484,
           4.491915675979029
          ],
          [
           59.90600100294105,
           59.9597262752351,
           60.01345154752913,
           60.067176819823175,
           60.12090209211722,
           60.174627364411265,
           60.2283526367053,
           60.28207790899934,
           60.33580318129339,
           60.38952845358744,
           60.443253725881476,
           60.49697899817552,
           60.55070427046956,
           60.60442954276361,
           60.65815481505766,
           60.711880087351695,
           60.76560535964573,
           60.81933063193978,
           60.87305590423382,
           60.92678117652787,
           60.98050644882191,
           61.03423172111595,
           61.08795699340999,
           61.14168226570404,
           61.19540753799808,
           61.249132810292124,
           61.30285808258617,
           61.3565833548802,
           61.41030862717425,
           61.4640338994683,
           61.517759171762336,
           61.57148444405638,
           61.62520971653679,
           61.67977302293437,
           61.73433632933194,
           61.78889963572951,
           61.843462942127076,
           61.89802624852464,
           61.95258955492221,
           62.00715286131978,
           62.06171616771735,
           62.116279474114926,
           62.17084278051249,
           62.22540608691006,
           62.27996939330763,
           62.33453269970519,
           62.389096006102776,
           62.44365931250034,
           62.4982226188979,
           62.55278592529548,
           62.607349231693036,
           62.66191253809062,
           62.71647584448818,
           62.77103915088574,
           62.82560245728333,
           62.88016576368089,
           62.93472907007846,
           62.98929237647603,
           63.0438556828736,
           63.098418989271174,
           63.152982295668735,
           63.20754560206632,
           63.26210890846388,
           63.31667221486145,
           63.37123552125902,
           63.425798827656585,
           63.480362134054154,
           63.53492544045172,
           63.5894887468493,
           63.64405205324687,
           63.69861535964443,
           63.753178666042,
           63.80774197243957,
           63.86230527883714,
           63.91686858523472,
           63.971431891632285,
           64.02599519802986,
           64.08055850442743,
           64.135121810825,
           64.18968511722257,
           64.24424842362014,
           64.29881173001769,
           64.35337503641526,
           64.40793834281283,
           64.45358823499022,
           64.49745544432358,
           64.54132265365693,
           64.58518986299028,
           64.62905707232363,
           64.67292428165698,
           64.71679149099033,
           64.76065870032369,
           64.80452590965703,
           64.84839311899039,
           64.89226032832374,
           64.93612753765709,
           64.97999474699044,
           65.02386195632378,
           65.06772916565714,
           65.1115963749905,
           65.15546358432384,
           65.1993307936572,
           65.24319800299055,
           65.2870652123239,
           65.33093242165724,
           65.3747996309906,
           65.41866684032394,
           65.46253404965731,
           65.50640125899065,
           65.550268468324,
           65.59413567765736,
           65.6380028869907,
           65.68187009632405,
           65.7257373056574,
           65.76960451499076,
           65.8134717243241,
           65.85733893365747,
           65.90120614299082,
           65.94507335232416,
           65.98894056165751,
           66.03280777099087,
           66.07667498032421,
           66.12054218965757,
           66.16440939899093,
           66.20827660832427,
           66.25214381765761,
           66.29601102699097,
           66.33987823632432,
           66.38374544565767,
           66.42761265499104,
           66.47147986432438,
           66.51534707365772,
           66.55921428299108,
           66.60308149232443,
           66.64694870165779,
           66.6902663133886,
           66.73330912604318,
           66.77635193869773,
           66.8193947513523,
           66.86243756400685,
           66.90548037666142,
           66.94852318931598,
           66.99156600197054,
           67.0346088146251,
           67.07765162727966,
           67.12069443993423,
           67.16373725258879,
           67.20678006524335,
           67.24982287789791,
           67.29286569055247,
           67.33590850320704,
           67.3789513158616,
           67.42199412851616,
           67.46503694117072,
           67.50807975382529,
           67.55112256647985,
           67.59416537913441,
           67.63720819178897,
           67.68025100444353,
           67.72329381709808,
           67.76633662975266,
           67.8093794424072,
           67.85242225506178,
           67.89546506771633,
           67.93850788037089,
           67.98155069302545,
           68.02459350568002,
           68.06338150907911,
           68.1000421078505,
           68.13670270662186,
           68.17336330539324,
           68.21002390416461,
           68.24668450293598,
           68.28334510170737,
           68.32000570047873,
           68.35666629925011,
           68.39332689802148,
           68.42998749679286,
           68.46664809556421,
           68.5033086943356,
           68.53996929310696,
           68.57662989187835,
           68.61329049064972,
           68.6499510894211,
           68.68661168819247,
           68.72327228696383,
           68.75993288573521,
           68.79659348450659,
           68.83325408327796,
           68.86991468204934,
           68.9065752808207,
           68.94323587959208,
           68.97989647836344,
           69.01655707713483,
           69.0532176759062,
           69.08987827467757,
           69.12653887344895,
           69.16319947222031,
           69.19986007099169,
           69.23652066976307,
           69.27318126853443,
           69.3098418673058,
           69.34650246607717,
           69.38316306484856,
           69.41982366361992,
           69.4564842623913,
           69.49314486116268,
           69.52980545993405,
           69.56646605870542,
           69.60312665747679,
           69.63978725624816,
           69.67644785501955,
           69.71310845379091,
           69.74976905256229,
           69.78642965133366,
           69.82309025010504,
           69.85975084887642,
           69.89641144764778,
           69.93307204641916,
           69.96973264519052,
           70.0063932439619,
           70.04305384273327,
           70.07971444150465,
           70.11637504027601,
           70.1530356390474,
           70.18969623781877,
           70.22635683659014,
           70.2630174353615,
           70.29967803413288,
           70.33633863290426,
           70.37299923167562,
           70.409659830447,
           70.44632042921837,
           70.48298102798974,
           70.51964162676113,
           70.55630222553249,
           70.59296282430387,
           70.62962342307524,
           70.66628402184661,
           70.70294462061798,
           70.73960521938936,
           70.77626581816072,
           70.81292641693211,
           70.84825263265742,
           70.88311472022698,
           70.91797680779658,
           70.95283889536617,
           70.98770098293575,
           71.02256307050534,
           71.05742515807492,
           70.79558970586152,
           70.23705671386516,
           69.67852372186881,
           69.1199907298725,
           68.56145773787611,
           68.00292474587978,
           67.44439175388347,
           66.90033315490977,
           66.36539349734068,
           65.83045383977169,
           65.2955141822026,
           64.7605745246335,
           64.22563486706446,
           63.690695209495416,
           63.155755551926326,
           62.620815894357285,
           62.08587623678824,
           61.55093657921914,
           61.0159969216501,
           60.48105726408106,
           59.94611760651197,
           59.41117794894287,
           58.87623829137387,
           58.34129863380478,
           57.80635897623569,
           57.271419318666645,
           56.736479661097604,
           56.20154000352851,
           55.666600345959466,
           55.131660688390426,
           54.59672103082133,
           54.06178137325224,
           53.52684171568325,
           52.991902058114164,
           52.45696240054506,
           51.92202274297602,
           51.38708308540698,
           50.85214342783789,
           50.31720377026883,
           49.782264112699785,
           49.247324455130695,
           48.712384797561654,
           48.17753072135473,
           47.642683492533116,
           47.10783626371152,
           46.57298903489001,
           46.0381418060684,
           45.5032945772468,
           44.96844734842524,
           44.43360011960368,
           43.89875289078208,
           43.36390566196052,
           42.82905843313897,
           42.294211204317364,
           41.75936397549575,
           41.22451674667425,
           40.68966951785264,
           40.15482228903104,
           39.619975060209484,
           39.08512783138792,
           38.55028060256632,
           38.01543337374477,
           37.48058614492321,
           36.945738916101604,
           36.41089168728004,
           35.876044458458495,
           35.34119722963688,
           34.806350000815286,
           34.27150277199378,
           33.736655543172176,
           33.201808314350565,
           32.66696108552901,
           32.132113856707456,
           31.59726662788585,
           31.062419399064293,
           30.527572170242742,
           29.992724941421134,
           29.457877712599576,
           28.92303048377802,
           28.388183254956417,
           27.853336026134812,
           27.318488797313254,
           26.783641568491696,
           26.349531074892724,
           26.11689405173896,
           25.88425702858519,
           25.6516200054314,
           25.418982982277633,
           25.186345959123862,
           24.953708935970077,
           24.721071912816285,
           24.488434889662543,
           24.265467876395828,
           24.04454131354466,
           23.82361475069351,
           23.602688187842357,
           23.38176162499119,
           23.16083506214004,
           22.93990849928889,
           22.718981936437718,
           22.498055373586574,
           22.277128810735423,
           22.05620224788425,
           21.835275685033082,
           21.614349122181935,
           21.393422559330784,
           21.172495996479615,
           20.951569433628467,
           20.73064287077732,
           20.509716307926148,
           20.288789745075,
           20.067863182223853,
           19.84693661937268,
           19.626010056521512,
           19.405083493670382,
           19.184156930819213,
           18.963230367968045,
           18.742303805116894,
           18.521377242265746,
           18.300450679414578,
           18.079524116563427,
           17.85859755371228,
           17.63767099086111,
           17.41674442800996,
           17.19581786515881,
           16.97489130230764,
           16.75396473945647,
           16.533038176605324,
           16.312111613754173,
           16.091185050903004,
           15.870258488051853,
           15.649331925200704,
           15.428405362349533,
           15.207478799498386,
           14.986552236647238,
           14.765625673796068,
           14.544699110944897,
           14.32377254809377,
           14.1028459852426,
           13.88191942239143,
           13.660992859540283,
           13.440066296689132,
           13.219139733837963,
           12.998213170986814,
           12.777286608135665,
           12.556360045284496,
           12.335433482433347,
           12.114506919582197,
           11.893580356731029,
           11.672653793879856,
           11.45172723102873,
           11.23080066817756,
           11.00987410532639,
           10.788947542475242,
           10.568020979624091,
           10.347094416772922,
           10.126167853921775,
           9.905241291070624,
           9.684314728219455,
           9.463388165368285,
           9.242461602517157,
           9.021535039665988,
           8.800608476814817,
           8.579681913963668,
           8.358755351112519,
           8.13782878826135,
           7.9444762463513054,
           7.888993809146645,
           7.833511371941984,
           7.778028934737324,
           7.722546497532674,
           7.669380102347289,
           7.616483015250351,
           7.563585928153423,
           7.510688841056487,
           7.457791753959549,
           7.404894666862622,
           7.351997579765685,
           7.299100492668748,
           7.24620340557181,
           7.193306318474883,
           7.140409231377946,
           7.087512144281009,
           7.034615057184081,
           6.981717970087143,
           6.928820882990206,
           6.8759237958932795,
           6.823026708796341,
           6.770129621699405,
           6.717232534602477,
           6.664335447505539,
           6.611438360408603,
           6.558541273311665,
           6.505644186214738,
           6.4527470991178015,
           6.399850012020863,
           6.3469529249239365,
           6.294055837826999,
           6.241158750730062,
           6.188261663633134,
           6.135364576536197,
           6.082467489439259,
           6.029570402342322,
           5.976673315245394,
           5.923776228148458,
           5.87087914105152,
           5.817982053954593,
           5.765084966857656,
           5.725456482568413,
           5.695305571713239,
           5.665154660858059,
           5.6350037500028805,
           5.604852839147707,
           5.574701928292527,
           5.544551017437348,
           5.514400106582169,
           5.484249195726996,
           5.454098284871816,
           5.423947374016636,
           5.393796463161462,
           5.363645552306283,
           5.333494641451104,
           5.30334373059593,
           5.273192819740752,
           5.243041908885573,
           5.212890998030394,
           5.182740087175219,
           5.15258917632004,
           5.122438265464861,
           5.092287354609686,
           5.0621364437545076,
           5.031985532899328,
           5.001834622044155,
           4.971683711188976,
           4.941532800333795,
           4.911381889478622,
           4.881230978623443,
           4.8510800677682635,
           4.820929156913085,
           4.790778246057911,
           4.760627335202732,
           4.730476424347552,
           4.700325513492379,
           4.670174602637199,
           4.64002369178202,
           4.609526688060964,
           4.578097897288504,
           4.546669106516043,
           4.515240315743582,
           4.4838115249711255
          ],
          [
           60.12953131454588,
           60.183256586839924,
           60.23698185913396,
           60.29070713142801,
           60.34443240372205,
           60.3981576760161,
           60.451882948310136,
           60.505608220604174,
           60.559333492898226,
           60.61305876519227,
           60.666784037486316,
           60.720509309780354,
           60.77423458207439,
           60.827959854368444,
           60.88168512666248,
           60.93541039895653,
           60.989135671250565,
           61.04286094354461,
           61.096586215838656,
           61.1503114881327,
           61.20403676042674,
           61.257762032720784,
           61.31148730501482,
           61.36521257730888,
           61.41893784960291,
           61.47266312189696,
           61.526388394191,
           61.58011366648503,
           61.63383893877909,
           61.68756421107313,
           61.74128948336717,
           61.795014755661214,
           61.848740027955245,
           61.902465300249304,
           61.95619057254334,
           62.00991584483739,
           62.06364111713144,
           62.11736638942547,
           62.171091661719515,
           62.224816934013546,
           62.2785422063076,
           62.33226747860164,
           62.38599275089568,
           62.43971802318973,
           62.49344329548377,
           62.54716856777782,
           62.60089384007186,
           62.6546191123659,
           62.708344384659945,
           62.762488674053856,
           62.817051980451424,
           62.87161528684899,
           62.92617859324656,
           62.98074189964412,
           63.0353052060417,
           63.08986851243927,
           63.144431818836836,
           63.198995125234404,
           63.25355843163197,
           63.30812173802954,
           63.36268504442711,
           63.417248350824686,
           63.471811657222254,
           63.52637496361982,
           63.5809382700174,
           63.63550157641497,
           63.690064882812536,
           63.7446281892101,
           63.79919149560767,
           63.85375480200524,
           63.90831810840282,
           63.962881414800385,
           64.01744472119795,
           64.07200802759552,
           64.12657133399308,
           64.18113464039065,
           64.23569794678822,
           64.29026125318579,
           64.34482455958337,
           64.39938786598094,
           64.45395117237851,
           64.50851447877608,
           64.56307778517363,
           64.61764109157122,
           64.6632909837486,
           64.70715819308195,
           64.75102540241531,
           64.79489261174865,
           64.83875982108201,
           64.88262703041535,
           64.9264942397487,
           64.97036144908206,
           65.01422865841542,
           65.05809586774876,
           65.1019630770821,
           65.14583028641546,
           65.18969749574882,
           65.23356470508217,
           65.27743191441552,
           65.32129912374887,
           65.36516633308221,
           65.40903354241557,
           65.45290075174893,
           65.49676796108227,
           65.54063517041563,
           65.58450237974897,
           65.62836958908233,
           65.67223679841567,
           65.71610400774902,
           65.75997121708238,
           65.80383842641574,
           65.84770563574908,
           65.89157284508244,
           65.93544005441578,
           65.97930726374913,
           66.02317447308249,
           66.06704168241583,
           66.11090889174919,
           66.15463870168338,
           66.19768151433794,
           66.2407243269925,
           66.28376713964707,
           66.32680995230163,
           66.36985276495619,
           66.41289557761075,
           66.45593839026532,
           66.49898120291988,
           66.54202401557444,
           66.585066828229,
           66.62810964088357,
           66.67115245353811,
           66.71419526619269,
           66.75723807884724,
           66.80028089150181,
           66.84332370415638,
           66.88636651681094,
           66.92940932946549,
           66.97245214212006,
           67.01549495477461,
           67.05853776742917,
           67.10158058008373,
           67.1446233927383,
           67.18766620539286,
           67.23070901804742,
           67.27375183070198,
           67.31679464335654,
           67.3598374560111,
           67.40288026866567,
           67.44592308132023,
           67.4889658939748,
           67.53200870662936,
           67.57505151928392,
           67.61809433193848,
           67.66113714459304,
           67.7041799572476,
           67.74722276990217,
           67.79026558255671,
           67.83330839521128,
           67.87635120786585,
           67.9193940205204,
           67.96243683317496,
           68.00547964582952,
           68.04852245848409,
           68.09156527113865,
           68.13460808379321,
           68.17765089644777,
           68.22069370910233,
           68.25948171250144,
           68.2961423112728,
           68.33280291004418,
           68.36946350881556,
           68.40612410758692,
           68.44278470635831,
           68.47944530512967,
           68.51610590390105,
           68.55276650267243,
           68.58942710144379,
           68.62608770021518,
           68.66274829898654,
           68.6994088977579,
           68.73606949652928,
           68.77273009530066,
           68.80939069407204,
           68.84605129284341,
           68.88271189161478,
           68.91937249038615,
           68.95603308915753,
           68.99269368792889,
           69.02935428670027,
           69.06601488547165,
           69.10267548424302,
           69.1393360830144,
           69.17599668178576,
           69.21265728055714,
           69.24931787932852,
           69.28597847809989,
           69.32263907687125,
           69.35929967564263,
           69.39596027441401,
           69.43262087318539,
           69.46928147195675,
           69.50594207072812,
           69.5426026694995,
           69.57926326827088,
           69.61592386704224,
           69.6525844658136,
           69.68924506458498,
           69.72590566335637,
           69.76256626212773,
           69.79922686089911,
           69.83588745967049,
           69.87254805844185,
           69.90920865721323,
           69.94586925598459,
           69.98252985475598,
           70.01919045352736,
           70.05585105229872,
           70.0925116510701,
           70.12876613160738,
           70.16362821917699,
           70.19849030674656,
           70.23335239431616,
           70.26821448188574,
           70.30307656945531,
           70.3379386570249,
           70.3728007445945,
           70.40766283216408,
           70.44252491973369,
           70.47738700730326,
           70.51224909487284,
           70.54711118244242,
           70.58197327001201,
           70.6168353575816,
           70.6516974451512,
           70.68655953272078,
           70.72142162029036,
           70.75628370785995,
           70.79114579542953,
           70.82600788299912,
           70.86086997056871,
           70.8957320581383,
           70.93059414570787,
           70.96545623327745,
           71.00031832084706,
           71.03518040841664,
           71.07004249598621,
           71.10490458355581,
           71.13976667112539,
           71.17462875869498,
           71.20949084626457,
           70.94765539405117,
           70.3891224020548,
           69.83058941005847,
           69.27205641806214,
           68.71352342606576,
           68.15499043406945,
           67.5964574420731,
           67.03792445007673,
           66.47939145808036,
           65.92085846608408,
           65.3623254740877,
           64.80379248209132,
           64.245259490095,
           63.68672649809867,
           63.12819350610229,
           62.56966051410596,
           62.01112752210964,
           61.45259453011326,
           60.894061538116944,
           60.33552854612061,
           59.77699555412423,
           59.218462562127854,
           58.65992957013158,
           58.1013965781352,
           57.54286358613883,
           56.9843305941425,
           56.42579760214617,
           55.86726461014979,
           55.30873161815347,
           54.75019862615714,
           54.199481803426764,
           53.66454214585767,
           53.12960248828868,
           52.5946628307196,
           52.0597231731505,
           51.52478351558146,
           50.98984385801241,
           50.45490420044331,
           49.919964542874276,
           49.385024885305235,
           48.850085227736145,
           48.315145570167104,
           47.780205912598056,
           47.245266255028966,
           46.71032659745987,
           46.17538693989088,
           45.64044728232179,
           45.10550762475269,
           44.57056796718365,
           44.0356283096146,
           43.50068865204551,
           42.96574899447647,
           42.43080933690743,
           41.89586967933833,
           41.360930021769235,
           40.825990364200244,
           40.291050706631154,
           39.756111049062056,
           39.221171391493016,
           38.686231733923975,
           38.15129207635488,
           37.61635241878584,
           37.0814127612168,
           36.5464731036477,
           36.01153344607866,
           35.47659378850961,
           34.94165413094052,
           34.40671447337142,
           33.87177481580244,
           33.33683515823334,
           32.801895500664244,
           32.266955843095204,
           31.732016185526156,
           31.197076527957066,
           30.662136870388025,
           30.12719721281898,
           29.592257555249894,
           29.057317897680853,
           28.52237824011181,
           27.987438582542715,
           27.452498924973618,
           26.917559267404577,
           26.382619609835533,
           25.95604502296165,
           25.746200577478106,
           25.536356131994562,
           25.326511686511,
           25.116667241027457,
           24.90682279554391,
           24.696978350060352,
           24.487133904576787,
           24.277289459093264,
           24.067445013609703,
           23.85760056812614,
           23.647756122642594,
           23.437911677159047,
           23.228067231675492,
           23.018222786191945,
           22.808378340708405,
           22.59853389522484,
           22.3886894497413,
           22.178845004257752,
           21.96900055877419,
           21.75915611329063,
           21.544233534890886,
           21.323309505880918,
           21.10238547687093,
           20.88146144786096,
           20.660537418850993,
           20.439613389841007,
           20.21868936083104,
           19.99776533182107,
           19.77684130281108,
           19.555917273801093,
           19.334993244791143,
           19.114069215781157,
           18.893145186771168,
           18.6722211577612,
           18.451297128751232,
           18.230373099741243,
           18.009449070731275,
           17.788525041721307,
           17.567601012711318,
           17.34667698370135,
           17.125752954691382,
           16.904828925681393,
           16.683904896671407,
           16.462980867661436,
           16.242056838651468,
           16.02113280964148,
           15.800208780631511,
           15.579284751621543,
           15.358360722611556,
           15.137436693601586,
           14.91651266459162,
           14.69558863558163,
           14.474664606571642,
           14.253740577561693,
           14.032816548551706,
           13.811892519541717,
           13.59096849053175,
           13.370044461521783,
           13.149120432511793,
           12.928196403501824,
           12.707272374491858,
           12.486348345481868,
           12.2654243164719,
           12.044500287461931,
           11.823576258451943,
           11.602652229441953,
           11.381728200432008,
           11.160804171422017,
           10.93988014241203,
           10.71895611340206,
           10.498032084392094,
           10.277108055382104,
           10.056184026372136,
           9.835259997362167,
           9.61433596835218,
           9.393411939342192,
           9.172487910332244,
           8.951563881322254,
           8.730639852312267,
           8.5097158233023,
           8.28879179429233,
           8.067867765282342,
           7.874996175737261,
           7.822386783516473,
           7.769777391295685,
           7.717167999074897,
           7.6645586068541185,
           7.611949214633331,
           7.559339822412543,
           7.506730430191764,
           7.454121037970976,
           7.401511645750189,
           7.348902253529411,
           7.296292861308623,
           7.243683469087834,
           7.191074076867047,
           7.1384646846462685,
           7.08585529242548,
           7.033245900204692,
           6.980636507983916,
           6.928027115763127,
           6.875417723542338,
           6.822808331321561,
           6.770198939100774,
           6.717589546879985,
           6.664980154659206,
           6.6123707624384185,
           6.559761370217631,
           6.507151977996843,
           6.454542585776064,
           6.401933193555276,
           6.349323801334489,
           6.296714409113711,
           6.244105016892923,
           6.191495624672134,
           6.138886232451357,
           6.086276840230569,
           6.0356484922463896,
           5.98551896488509,
           5.935389437523802,
           5.885259910162503,
           5.8351303828012036,
           5.785000855439915,
           5.734871328078616,
           5.697204364224758,
           5.668439231447644,
           5.639674098670525,
           5.610908965893408,
           5.5821438331162945,
           5.5533787003391755,
           5.524613567562057,
           5.495397423538828,
           5.4654061002147705,
           5.435414776890708,
           5.405423453566645,
           5.375432130242588,
           5.345440806918526,
           5.315449483594462,
           5.285458160270405,
           5.255466836946343,
           5.22547551362228,
           5.1954841902982185,
           5.165492866974161,
           5.135501543650098,
           5.105510220326035,
           5.075518897001978,
           5.045527573677916,
           5.015536250353853,
           4.985544927029796,
           4.9555536037057335,
           4.92556228038167,
           4.895570957057613,
           4.865579633733551,
           4.835588310409488,
           4.805596987085425,
           4.775605663761368,
           4.745614340437306,
           4.715623017113244,
           4.685631693789186,
           4.6556403704651235,
           4.625649047141061,
           4.595657723817004,
           4.565666400492941,
           4.535675077168879,
           4.505683753844816,
           4.475692430520759
          ],
          [
           60.35306162615071,
           60.40678689844476,
           60.460512170738795,
           60.51423744303284,
           60.567962715326885,
           60.62168798762093,
           60.67541325991497,
           60.729138532209014,
           60.78286380450306,
           60.836589076797104,
           60.89031434909115,
           60.94403962138519,
           60.99776489367923,
           61.05149016597327,
           61.105215438267315,
           61.15894071056136,
           61.2126659828554,
           61.26639125514944,
           61.32011652744349,
           61.373841799737534,
           61.42756707203158,
           61.48129234432562,
           61.535017616619655,
           61.58874288891371,
           61.642468161207745,
           61.69619343350179,
           61.74991870579584,
           61.80364397808988,
           61.857369250383925,
           61.911094522677956,
           61.964819794972,
           62.018545067266054,
           62.07227033956009,
           62.125995611854144,
           62.179720884148175,
           62.23344615644222,
           62.287171428736265,
           62.3408967010303,
           62.394621973324355,
           62.44834724561839,
           62.50207251791244,
           62.55579779020648,
           62.609523062500514,
           62.66324833479456,
           62.716973607088605,
           62.77069887938265,
           62.824424151676695,
           62.87814942397073,
           62.93187469626478,
           62.98559996855882,
           63.03932524085287,
           63.093050513146906,
           63.14677578544095,
           63.20050105773499,
           63.254226330029034,
           63.30795160232307,
           63.36167687461712,
           63.41540214691116,
           63.46912741920521,
           63.52285269149925,
           63.57657796379329,
           63.630303236087336,
           63.68402850838138,
           63.737753780675426,
           63.791479052969464,
           63.84520432526351,
           63.8997676315709,
           63.95433093796847,
           64.00889424436605,
           64.06345755076362,
           64.11802085716117,
           64.17258416355874,
           64.22714746995631,
           64.28171077635389,
           64.33627408275146,
           64.39083738914903,
           64.4454006955466,
           64.49996400194416,
           64.55452730834173,
           64.6090906147393,
           64.66365392113687,
           64.71821722753444,
           64.772780533932,
           64.82734384032958,
           64.87299373250697,
           64.91686094184033,
           64.96072815117367,
           65.00459536050703,
           65.04846256984037,
           65.09232977917372,
           65.13619698850707,
           65.18006419784044,
           65.22393140717378,
           65.26779861650714,
           65.31166582584048,
           65.35553303517383,
           65.39940024450718,
           65.44326745384053,
           65.48713466317389,
           65.53100187250723,
           65.57486908184059,
           65.61873629117395,
           65.6620539026327,
           65.70509671528727,
           65.74813952794185,
           65.7911823405964,
           65.83422515325096,
           65.87726796590552,
           65.9203107785601,
           65.96335359121464,
           66.0063964038692,
           66.04943921652377,
           66.09248202917833,
           66.13552484183289,
           66.17856765448745,
           66.22161046714201,
           66.26465327979658,
           66.30769609245114,
           66.3507389051057,
           66.39378171776026,
           66.43682453041482,
           66.47986734306939,
           66.52291015572395,
           66.56595296837851,
           66.60899578103306,
           66.65203859368762,
           66.69508140634218,
           66.73812421899675,
           66.78116703165132,
           66.82420984430587,
           66.86725265696043,
           66.910295469615,
           66.95333828226956,
           66.99638109492412,
           67.03942390757868,
           67.08246672023324,
           67.1255095328878,
           67.16855234554237,
           67.21159515819693,
           67.25463797085149,
           67.29768078350605,
           67.34072359616061,
           67.38376640881518,
           67.42680922146974,
           67.4698520341243,
           67.51289484677885,
           67.55593765943343,
           67.59898047208799,
           67.64202328474254,
           67.6850660973971,
           67.72810891005167,
           67.77115172270622,
           67.81419453536078,
           67.85723734801535,
           67.90028016066991,
           67.94332297332447,
           67.98636578597903,
           68.0294085986336,
           68.07245141128816,
           68.11549422394272,
           68.15853703659727,
           68.20157984925184,
           68.2446226619064,
           68.28766547456095,
           68.33070828721551,
           68.37375109987009,
           68.41679391252464,
           68.45558191592374,
           68.49224251469512,
           68.5289031134665,
           68.56556371223787,
           68.60222431100924,
           68.63888490978063,
           68.67554550855199,
           68.71220610732335,
           68.74886670609473,
           68.78552730486611,
           68.82218790363748,
           68.85884850240885,
           68.89550910118024,
           68.9321696999516,
           68.96883029872298,
           69.00549089749435,
           69.04215149626572,
           69.0788120950371,
           69.11547269380847,
           69.15213329257985,
           69.18879389135121,
           69.22545449012259,
           69.26211508889396,
           69.29877568766533,
           69.3354362864367,
           69.37209688520808,
           69.40875748397947,
           69.44414171812697,
           69.47900380569656,
           69.51386589326614,
           69.54872798083572,
           69.58359006840531,
           69.61845215597491,
           69.65331424354449,
           69.68817633111406,
           69.72303841868366,
           69.75790050625325,
           69.79276259382283,
           69.82762468139241,
           69.862486768962,
           69.89734885653158,
           69.93221094410117,
           69.96707303167076,
           70.00193511924034,
           70.03679720680994,
           70.07165929437951,
           70.10652138194911,
           70.1413834695187,
           70.17624555708828,
           70.21110764465787,
           70.24596973222745,
           70.28083181979703,
           70.31569390736664,
           70.3505559949362,
           70.3854180825058,
           70.42028017007539,
           70.45514225764497,
           70.49000434521456,
           70.52486643278414,
           70.55972852035373,
           70.59459060792332,
           70.6294526954929,
           70.6643147830625,
           70.69917687063207,
           70.73403895820167,
           70.76890104577124,
           70.80376313334082,
           70.83862522091042,
           70.87348730848001,
           70.90834939604959,
           70.94321148361917,
           70.97807357118876,
           71.01293565875835,
           71.04779774632794,
           71.08265983389751,
           71.1175219214671,
           71.1523840090367,
           71.18724609660627,
           71.22210818417585,
           71.25697027174544,
           71.29183235931504,
           71.32669444688463,
           71.3615565344542,
           71.09972108224082,
           70.54118809024443,
           69.9826550982481,
           69.42412210625179,
           68.8655891142554,
           68.30705612225907,
           67.74852313026275,
           67.18999013826638,
           66.63145714627001,
           66.07292415427372,
           65.51439116227735,
           64.95585817028096,
           64.39732517828463,
           63.838792186288316,
           63.28025919429193,
           62.72172620229561,
           62.16319321029929,
           61.60466021830291,
           61.04612722630658,
           60.48759423431025,
           59.929061242313864,
           59.37052825031749,
           58.81199525832122,
           58.25346226632484,
           57.69492927432847,
           57.13639628233214,
           56.57786329033581,
           56.01933029833944,
           55.4607973063431,
           54.90226431434678,
           54.3437313223504,
           53.78519833035402,
           53.22666533835776,
           52.668132346361375,
           52.109599354365,
           51.55106636236868,
           50.99253337037235,
           50.43400037837596,
           49.87546738637964,
           49.31693439438332,
           48.75840140238694,
           48.199868410390614,
           47.641335418394284,
           47.082802426397905,
           46.524269434401525,
           45.96573644240525,
           45.40720345040887,
           44.8486704584125,
           44.29013746641617,
           43.731604474419846,
           43.173071482423474,
           42.61453849042714,
           42.056005498430814,
           41.498630451943775,
           40.963690794374685,
           40.42875113680569,
           39.89381147923659,
           39.3588718216675,
           38.82393216409845,
           38.28899250652941,
           37.75405284896032,
           37.21911319139128,
           36.68417353382223,
           36.14923387625314,
           35.614294218684094,
           35.07935456111505,
           34.54441490354596,
           34.00947524597687,
           33.474535588407875,
           32.939595930838784,
           32.40465627326969,
           31.869716615700643,
           31.3347769581316,
           30.79983730056251,
           30.264897642993468,
           29.72995798542442,
           29.19501832785534,
           28.660078670286296,
           28.12513901271725,
           27.59019935514815,
           27.055259697579064,
           26.52032004001002,
           25.985380382440972,
           25.558805795567093,
           25.348961350083545,
           25.1391169046,
           24.92927245911644,
           24.7194280136329,
           24.509583568149353,
           24.299739122665795,
           24.089894677182226,
           23.880050231698704,
           23.670205786215142,
           23.460361340731584,
           23.250516895248037,
           23.04067244976449,
           22.83082800428093,
           22.620983558797388,
           22.411139113313844,
           22.201294667830282,
           21.99145022234674,
           21.781605776863195,
           21.571761331379633,
           21.36191688589607,
           21.152072440412528,
           20.942227994928984,
           20.732383549445423,
           20.52253910396188,
           20.312694658478335,
           20.102850212994774,
           19.89300576751123,
           19.683161322027683,
           19.473316876544125,
           19.263472431060563,
           19.053627985577037,
           18.843783540093476,
           18.63393909460991,
           18.424094649126367,
           18.214250203642827,
           18.004405758159262,
           17.79456131267572,
           17.584716867192178,
           17.374872421708613,
           17.165027976225073,
           16.95518353074153,
           16.745339085257967,
           16.535494639774402,
           16.32565019429086,
           16.115805748807315,
           15.905961303323755,
           15.69611685784021,
           15.486272412356666,
           15.276427966873106,
           15.066583521389562,
           14.847765775109867,
           14.626841746099878,
           14.405917717089888,
           14.18499368807994,
           13.964069659069953,
           13.743145630059963,
           13.522221601049996,
           13.301297572040028,
           13.080373543030039,
           12.85944951402007,
           12.638525485010103,
           12.417601456000114,
           12.196677426990146,
           11.975753397980178,
           11.754829368970189,
           11.5339053399602,
           11.312981310950253,
           11.092057281940264,
           10.871133252930276,
           10.650209223920308,
           10.429285194910339,
           10.208361165900351,
           9.987437136890382,
           9.766513107880414,
           9.545589078870426,
           9.324665049860437,
           9.103741020850489,
           8.8828169918405,
           8.661892962830514,
           8.440968933820544,
           8.220044904810576,
           7.999120875800588,
           7.8062492862555075,
           7.75363989403472,
           7.701030501813931,
           7.648421109593143,
           7.5958117173723645,
           7.543202325151576,
           7.490592932930788,
           7.437983540710011,
           7.385374148489223,
           7.3327647562684355,
           7.280155364047657,
           7.227545971826869,
           7.174936579606081,
           7.122327187385293,
           7.0697177951645145,
           7.017108402943727,
           6.964499010722939,
           6.91188961850216,
           6.859668597710963,
           6.809539070349665,
           6.759409542988376,
           6.709280015627077,
           6.659150488265778,
           6.609020960904488,
           6.55889143354319,
           6.508761906181891,
           6.458632378820592,
           6.408502851459303,
           6.358373324098005,
           6.308243796736705,
           6.258114269375415,
           6.207984742014117,
           6.15785521465282,
           6.10772568729153,
           6.057596159930232,
           6.007466632568933,
           5.957337105207634,
           5.907207577846345,
           5.857078050485047,
           5.806948523123748,
           5.756818995762458,
           5.7066894684011595,
           5.669022504547302,
           5.640257371770188,
           5.611492238993069,
           5.582727106215951,
           5.553961973438838,
           5.52519684066172,
           5.4964317078846,
           5.467666575107482,
           5.43890144233037,
           5.410136309553251,
           5.381371176776133,
           5.352606043999019,
           5.3238409112219,
           5.295075778444782,
           5.266310645667669,
           5.23754551289055,
           5.208780380113433,
           5.180015247336313,
           5.1512501145592005,
           5.122484981782082,
           5.093719849004964,
           5.0649547162278505,
           5.0361895834507315,
           5.007412119182128,
           4.977420795858071,
           4.947429472534008,
           4.917438149209945,
           4.887446825885888,
           4.857455502561825,
           4.8274641792377615,
           4.7974728559137,
           4.767481532589644,
           4.73749020926558,
           4.707498885941518,
           4.6775075626174605,
           4.647516239293398,
           4.6175249159693355,
           4.587533592645279,
           4.557542269321216,
           4.527550945997153,
           4.49755962267309,
           4.467568299349033
          ],
          [
           60.57659193775556,
           60.630317210049604,
           60.68404248234364,
           60.73776775463769,
           60.79149302693173,
           60.84521829922577,
           60.89894357151981,
           60.95266884381385,
           61.0063941161079,
           61.060119388401944,
           61.11384466069599,
           61.16756993299003,
           61.22129520528407,
           61.27502047757812,
           61.32874574987216,
           61.38247102216621,
           61.436196294460245,
           61.48992156675428,
           61.54364683904833,
           61.597372111342374,
           61.65109738363642,
           61.70482265593046,
           61.7585479282245,
           61.81227320051855,
           61.865998472812585,
           61.91972374510663,
           61.97344901740068,
           62.02717428969471,
           62.080899561988765,
           62.13462483428281,
           62.18835010657685,
           62.242075378870894,
           62.295800651164924,
           62.34952592345898,
           62.403251195753015,
           62.45697646804706,
           62.510701740341105,
           62.56442701263514,
           62.618152284929195,
           62.671877557223226,
           62.72560282951728,
           62.77932810181132,
           62.83305337410536,
           62.88677864639941,
           62.940503918693445,
           62.99422919098749,
           63.047954463281535,
           63.10167973557558,
           63.15540500786962,
           63.20913028016366,
           63.26285555245771,
           63.316580824751746,
           63.37030609704579,
           63.424031369339836,
           63.47775664163388,
           63.53148191392792,
           63.58520718622196,
           63.638932458516,
           63.69265773081005,
           63.74638300310409,
           63.80010827539814,
           63.85383354769218,
           63.90755881998622,
           63.961284092280266,
           64.01500936457431,
           64.06873463686836,
           64.1224599091624,
           64.17618518145645,
           64.22991045375048,
           64.28363572604452,
           64.33736099833857,
           64.39108627063261,
           64.44481154292666,
           64.49853681522069,
           64.55226208751473,
           64.60598735980878,
           64.65971263210282,
           64.71343790439687,
           64.76716317669091,
           64.82088844898496,
           64.874613721279,
           64.92833899357305,
           64.98248328269038,
           65.03704658908795,
           65.08269648126534,
           65.1264262909275,
           65.16946910358206,
           65.21251191623662,
           65.25555472889117,
           65.29859754154573,
           65.34164035420031,
           65.38468316685486,
           65.42772597950942,
           65.47076879216398,
           65.51381160481854,
           65.5568544174731,
           65.59989723012767,
           65.64294004278223,
           65.68598285543679,
           65.72902566809135,
           65.77206848074592,
           65.81511129340048,
           65.85815410605503,
           65.90119691870959,
           65.94423973136415,
           65.98728254401871,
           66.03032535667327,
           66.07336816932784,
           66.1164109819824,
           66.15945379463696,
           66.20249660729152,
           66.24553941994608,
           66.28858223260065,
           66.33162504525521,
           66.37466785790977,
           66.41771067056433,
           66.4607534832189,
           66.50379629587346,
           66.54683910852802,
           66.58988192118258,
           66.63292473383714,
           66.6759675464917,
           66.71901035914627,
           66.76205317180083,
           66.80509598445539,
           66.84813879710997,
           66.89118160976453,
           66.93422442241908,
           66.97726723507363,
           67.0203100477282,
           67.06335286038275,
           67.10639567303733,
           67.14943848569189,
           67.19248129834645,
           67.235524111001,
           67.27856692365556,
           67.32160973631012,
           67.36465254896468,
           67.40769536161925,
           67.45073817427381,
           67.49378098692836,
           67.53682379958292,
           67.5798666122375,
           67.62290942489204,
           67.6659522375466,
           67.70899505020117,
           67.75203786285573,
           67.79508067551029,
           67.83812348816485,
           67.88116630081943,
           67.92420911347398,
           67.96725192612855,
           68.01029473878312,
           68.05333755143766,
           68.09638036409223,
           68.13942317674679,
           68.18246598940136,
           68.22550880205593,
           68.26855161471047,
           68.31159442736505,
           68.35463724001961,
           68.39768005267418,
           68.44072286532872,
           68.48376567798329,
           68.52680849063783,
           68.56985130329241,
           68.61289411594696,
           68.65168211934608,
           68.68834271811745,
           68.72465521707697,
           68.75951730464655,
           68.79437939221614,
           68.82924147978572,
           68.8641035673553,
           68.8989656549249,
           68.93382774249449,
           68.96868983006406,
           69.00355191763366,
           69.03841400520324,
           69.07327609277283,
           69.10813818034241,
           69.143000267912,
           69.17786235548158,
           69.21272444305117,
           69.24758653062075,
           69.28244861819034,
           69.31731070575992,
           69.35217279332952,
           69.3870348808991,
           69.42189696846867,
           69.45675905603827,
           69.49162114360786,
           69.52648323117745,
           69.56134531874703,
           69.59620740631661,
           69.6310694938862,
           69.6659315814558,
           69.70079366902537,
           69.73565575659497,
           69.77051784416454,
           69.80537993173414,
           69.84024201930372,
           69.87510410687331,
           69.9099661944429,
           69.94482828201248,
           69.97969036958206,
           70.01455245715165,
           70.04941454472123,
           70.08427663229082,
           70.11913871986042,
           70.15400080743,
           70.18886289499959,
           70.22372498256917,
           70.25858707013874,
           70.29344915770835,
           70.32831124527792,
           70.36317333284752,
           70.3980354204171,
           70.43289750798668,
           70.46775959555627,
           70.50262168312585,
           70.53748377069545,
           70.57234585826502,
           70.6072079458346,
           70.64207003340421,
           70.67693212097379,
           70.71179420854338,
           70.74665629611296,
           70.78151838368254,
           70.81638047125213,
           70.85124255882171,
           70.88610464639129,
           70.9209667339609,
           70.95582882153047,
           70.99069090910007,
           71.02555299666966,
           71.06041508423922,
           71.09527717180882,
           71.13013925937841,
           71.165001346948,
           71.19986343451758,
           71.23472552208716,
           71.26958760965675,
           71.30444969722635,
           71.33931178479592,
           71.3741738723655,
           71.4090359599351,
           71.44389804750469,
           71.47876013507427,
           71.51362222264386,
           71.25178677043047,
           70.69325377843408,
           70.13472078643775,
           69.57618779444142,
           69.01765480244504,
           68.45912181044872,
           67.9005888184524,
           67.34205582645602,
           66.78352283445965,
           66.22498984246337,
           65.66645685046699,
           65.10792385847061,
           64.54939086647428,
           63.99085787447796,
           63.43232488248159,
           62.873791890485265,
           62.315258898488935,
           61.756725906492555,
           61.19819291449623,
           60.6396599224999,
           60.081126930503515,
           59.52259393850714,
           58.96406094651087,
           58.40552795451449,
           57.84699496251811,
           57.288461970521794,
           56.729928978525464,
           56.171395986529085,
           55.612862994532755,
           55.05433000253643,
           54.49579701054005,
           53.93726401854367,
           53.378731026547406,
           52.82019803455103,
           52.261665042554654,
           51.703132050558324,
           51.144599058561994,
           50.586066066565614,
           50.02753307456929,
           49.46900008257296,
           48.91046709057659,
           48.35193409858026,
           47.79340110658393,
           47.234868114587556,
           46.67633512259118,
           46.117802130594896,
           45.55926913859852,
           45.00073614660215,
           44.44220315460582,
           43.8836701626095,
           43.32513717061312,
           42.76660417861679,
           42.20807118662046,
           41.649538194624085,
           41.0910052026277,
           40.53247221063143,
           39.97393921863506,
           39.41540622663868,
           38.85687323464236,
           38.29834024264603,
           37.73980725064965,
           37.18127425865332,
           36.622741266657,
           36.06420827466062,
           35.50567528266429,
           34.94714229066797,
           34.38860929867159,
           33.83007630667522,
           33.27154331467894,
           32.71301032268256,
           32.154477330686184,
           31.59594433868986,
           31.03741134669353,
           30.47887835469715,
           29.920345362700832,
           29.361812370704502,
           28.803279378708122,
           28.262839442891718,
           27.727899785322673,
           27.19296012775358,
           26.658020470184486,
           26.123080812615445,
           25.5881411550464,
           25.161566568172518,
           24.951722122688974,
           24.74187767720543,
           24.53203323172187,
           24.322188786238325,
           24.11234434075478,
           23.90249989527122,
           23.692655449787654,
           23.48281100430413,
           23.27296655882057,
           23.063122113337005,
           22.853277667853465,
           22.64343322236992,
           22.43358877688636,
           22.223744331402816,
           22.01389988591927,
           21.804055440435707,
           21.594210994952167,
           21.384366549468623,
           21.174522103985062,
           20.9646776585015,
           20.754833213017953,
           20.54498876753441,
           20.33514432205085,
           20.125299876567308,
           19.915455431083764,
           19.705610985600202,
           19.49576654011666,
           19.28592209463311,
           19.076077649149553,
           18.86623320366599,
           18.656388758182466,
           18.4465443126989,
           18.23669986721534,
           18.026855421731796,
           17.817010976248252,
           17.60716653076469,
           17.397322085281147,
           17.187477639797603,
           16.97763319431404,
           16.767788748830498,
           16.557944303346954,
           16.34809985786339,
           16.138255412379827,
           15.928410966896283,
           15.718566521412743,
           15.508722075929182,
           15.298877630445636,
           15.089033184962092,
           14.87918873947853,
           14.669344293994985,
           14.459499848511443,
           14.24965540302788,
           14.039810957544319,
           13.829966512060796,
           13.620122066577233,
           13.41027762109367,
           13.200433175610126,
           12.990588730126582,
           12.78074428464302,
           12.570899839159477,
           12.361055393675933,
           12.151210948192372,
           11.941366502708828,
           11.731522057225286,
           11.521677611741723,
           11.311833166258161,
           11.101988720774635,
           10.892144275291074,
           10.68229982980751,
           10.472455384323968,
           10.262610938840425,
           10.052766493356863,
           9.84292204787332,
           9.633077602389776,
           9.423233156906214,
           9.21338871142265,
           9.003544265939126,
           8.793699820455563,
           8.583855374972002,
           8.372222044338788,
           8.15129801532882,
           7.930373986318831,
           7.737502396773751,
           7.684893004552962,
           7.633559175814237,
           7.583429648452938,
           7.533300121091649,
           7.483170593730351,
           7.433041066369053,
           7.382911539007764,
           7.332782011646464,
           7.282652484285165,
           7.2325229569238765,
           7.182393429562579,
           7.13226390220128,
           7.08213437483998,
           7.032004847478691,
           6.981875320117393,
           6.931745792756095,
           6.881616265394804,
           6.831486738033506,
           6.781357210672207,
           6.731227683310918,
           6.68109815594962,
           6.63096862858832,
           6.580839101227031,
           6.530709573865732,
           6.480580046504434,
           6.430450519143136,
           6.380320991781846,
           6.3301914644205475,
           6.280061937059249,
           6.229932409697959,
           6.17980288233666,
           6.129673354975362,
           6.0795438276140725,
           6.029414300252774,
           5.979284772891475,
           5.929155245530177,
           5.879025718168888,
           5.828896190807589,
           5.77876666344629,
           5.728637136085002,
           5.678507608723703,
           5.640840644869844,
           5.612075512092731,
           5.583310379315613,
           5.554545246538494,
           5.525780113761381,
           5.497014980984263,
           5.468249848207144,
           5.439484715430025,
           5.410719582652913,
           5.381954449875793,
           5.353189317098676,
           5.324424184321562,
           5.295659051544444,
           5.266893918767325,
           5.238128785990212,
           5.209363653213094,
           5.180598520435975,
           5.151833387658856,
           5.123068254881743,
           5.094303122104625,
           5.065537989327506,
           5.036772856550393,
           5.008007723773274,
           4.979242590996156,
           4.950477458219043,
           4.921712325441924,
           4.892947192664806,
           4.8641820598876935,
           4.835416927110574,
           4.8066517943334555,
           4.777886661556337,
           4.7491215287792246,
           4.720356396002106,
           4.691591263224987,
           4.662826130447874,
           4.634060997670756,
           4.6052958648936375,
           4.576530732116525,
           4.547765599339406,
           4.519000466562287,
           4.489435491501364,
           4.459444168177307
          ],
          [
           60.78918297964897,
           60.84184679158359,
           60.894510603518206,
           60.94717441545282,
           60.99983822738744,
           61.05250203932206,
           61.10516585125668,
           61.1578296631913,
           61.210493475125915,
           61.26315728706054,
           61.31582109899516,
           61.36848491092977,
           61.42114872286439,
           61.47381253479901,
           61.52647634673363,
           61.57931706826365,
           61.633042340557694,
           61.68676761285174,
           61.740492885145784,
           61.79421815743982,
           61.84794342973386,
           61.901668702027905,
           61.95539397432195,
           62.009119246615995,
           62.06284451891004,
           62.11656979120408,
           62.17029506349812,
           62.22402033579217,
           62.27774560808621,
           62.33147088038025,
           62.3851961526743,
           62.43892142496834,
           62.49264669726239,
           62.54637196955643,
           62.60009724185046,
           62.65382251414451,
           62.707547786438546,
           62.76127305873259,
           62.814998331026636,
           62.86872360332068,
           62.92244887561473,
           62.976174147908765,
           63.02989942020281,
           63.083624692496855,
           63.1373499647909,
           63.19107523708493,
           63.244800509378976,
           63.29852578167302,
           63.352251053967066,
           63.40597632626111,
           63.45970159855516,
           63.5134268708492,
           63.56715214314324,
           63.620877415437285,
           63.67460268773132,
           63.72832796002537,
           63.78205323231941,
           63.83577850461345,
           63.88950377690749,
           63.943229049201534,
           63.99695432149558,
           64.05067959378962,
           64.10440486608367,
           64.15813013837771,
           64.21185541067175,
           64.2655806829658,
           64.31930595525984,
           64.37303122755388,
           64.42675649984793,
           64.48048177214197,
           64.534207044436,
           64.58793231673005,
           64.64165758902409,
           64.69538286131814,
           64.74910813361218,
           64.80283340590623,
           64.85655867820026,
           64.91028395049432,
           64.96400922278835,
           65.0177344950824,
           65.07145976737644,
           65.12518503967048,
           65.17891031196453,
           65.23263558425857,
           65.27745880685305,
           65.32050161950761,
           65.36354443216217,
           65.40658724481673,
           65.44963005747128,
           65.49267287012586,
           65.5357156827804,
           65.57875849543497,
           65.62180130808953,
           65.6648441207441,
           65.70788693339865,
           65.75092974605322,
           65.79397255870778,
           65.83701537136234,
           65.8800581840169,
           65.92310099667147,
           65.96614380932603,
           66.00918662198059,
           66.05222943463515,
           66.09527224728971,
           66.13831505994428,
           66.18135787259882,
           66.2244006852534,
           66.26744349790795,
           66.31048631056252,
           66.35352912321707,
           66.39657193587163,
           66.43961474852621,
           66.48265756118076,
           66.52570037383532,
           66.56874318648988,
           66.61178599914444,
           66.654828811799,
           66.69787162445357,
           66.74091443710813,
           66.7839572497627,
           66.82700006241726,
           66.87004287507182,
           66.91308568772638,
           66.95612850038094,
           66.9991713130355,
           67.04221412569007,
           67.08525693834463,
           67.12829975099919,
           67.17134256365375,
           67.21438537630831,
           67.25742818896288,
           67.30047100161744,
           67.343513814272,
           67.38655662692656,
           67.42959943958112,
           67.47264225223567,
           67.51568506489023,
           67.55872787754481,
           67.60177069019936,
           67.64481350285392,
           67.68785631550848,
           67.73089912816305,
           67.77394194081761,
           67.81698475347216,
           67.86002756612673,
           67.9030703787813,
           67.94611319143586,
           67.98915600409042,
           68.03219881674498,
           68.07524162939954,
           68.11828444205409,
           68.16132725470867,
           68.20386785333469,
           68.2459062388113,
           68.28794462428792,
           68.32998300976452,
           68.37202139524112,
           68.41405978071774,
           68.45609816619434,
           68.49813655167095,
           68.54017493714755,
           68.58221332262416,
           68.62425170810077,
           68.66629009357737,
           68.70832847905399,
           68.75036686453059,
           68.7924052500072,
           68.82948229799426,
           68.86407867723653,
           68.89867505647882,
           68.93327143572111,
           68.96786781496337,
           69.00246419420566,
           69.03706057344795,
           69.07165695269023,
           69.1062533319325,
           69.14084971117478,
           69.17544609041707,
           69.21004246965934,
           69.24463884890163,
           69.2792352281439,
           69.31383160738619,
           69.34842798662847,
           69.38302436587075,
           69.41762074511303,
           69.45221712435531,
           69.48681350359759,
           69.52140988283986,
           69.55600626208215,
           69.59060264132442,
           69.62519902056671,
           69.659795399809,
           69.69439177905127,
           69.72898815829356,
           69.76358453753583,
           69.79818091677811,
           69.83277729602038,
           69.86737367526268,
           69.90197005450497,
           69.93656643374725,
           69.97116281298952,
           70.00575919223179,
           70.04035557147408,
           70.07495195071635,
           70.10954832995864,
           70.14414470920092,
           70.17874108844319,
           70.21333746768548,
           70.24793384692776,
           70.28253022617004,
           70.31712660541231,
           70.3517229846546,
           70.38631936389687,
           70.42091574313916,
           70.45551212238144,
           70.49010850162372,
           70.52470488086601,
           70.55930126010828,
           70.59389763935056,
           70.62849401859285,
           70.66309039783512,
           70.69768677707741,
           70.7322831563197,
           70.76687953556197,
           70.80147591480426,
           70.83607229404652,
           70.87066867328882,
           70.90526505253109,
           70.93986143177337,
           70.97445781101565,
           71.00905419025793,
           71.0436505695002,
           71.0782469487425,
           71.11284332798476,
           71.14743970722705,
           71.18203608646932,
           71.21663246571163,
           71.2512288449539,
           71.28582522419617,
           71.32042160343845,
           71.35501798268075,
           71.38961436192301,
           71.42421074116531,
           71.45880712040757,
           71.49340349964986,
           71.52799987889215,
           71.56259625813442,
           71.59719263737671,
           71.63178901661898,
           71.66638539586127,
           71.39400703375732,
           70.82646122087631,
           70.263390910208,
           69.70032059953971,
           69.13725028887134,
           68.57417997820303,
           68.01110966753474,
           67.44803935686639,
           66.88496904619804,
           66.32189873552979,
           65.75882842486143,
           65.19575811419307,
           64.63268780352476,
           64.06961749285647,
           63.506547182188115,
           62.94347687151981,
           62.38040656085151,
           61.81733625018315,
           61.25426593951485,
           60.69119562884655,
           60.12812531817819,
           59.56505500750984,
           59.00198469684159,
           58.43891438617323,
           57.87584407550487,
           57.31277376483657,
           56.74970345416827,
           56.18663314349991,
           55.62356283283161,
           55.06049252216331,
           54.49742221149496,
           53.9343519008266,
           53.371281590158354,
           52.808211279489996,
           52.245140968821644,
           51.68207065815334,
           51.11900034748504,
           50.555930036816676,
           49.992859726148374,
           49.42978941548007,
           48.86671910481172,
           48.30364879414341,
           47.74057848347511,
           47.17750817280675,
           46.6144378621384,
           46.05136755147015,
           45.4882972408018,
           44.92522693013344,
           44.36215661946514,
           43.79908630879684,
           43.23601599812848,
           42.67294568746018,
           42.10987537679188,
           41.546805066123525,
           40.98373475545516,
           40.42066444478691,
           39.85759413411856,
           39.294523823450206,
           38.7314535127819,
           38.168383202113596,
           37.60531289144524,
           37.04224258077694,
           36.479172270108634,
           35.91610195944028,
           35.35303164877198,
           34.78996133810368,
           34.22689102743532,
           33.66382071676696,
           33.10075040609871,
           32.53768009543036,
           31.97460978476201,
           31.411539474093704,
           30.848469163425403,
           30.285398852757048,
           29.722328542088743,
           29.159258231420438,
           28.596187920752083,
           28.033117610083778,
           27.470047299415477,
           26.906976988747125,
           26.343906678078774,
           25.78083636741047,
           25.217766056742164,
           24.77611820511709,
           24.57731527157848,
           24.378512338039876,
           24.179709404501253,
           23.980906470962644,
           23.782103537424035,
           23.583300603885412,
           23.384497670346786,
           23.1856947368082,
           22.98689180326957,
           22.788088869730945,
           22.589285936192343,
           22.390483002653735,
           22.191680069115108,
           21.9928771355765,
           21.794074202037894,
           21.595271268499268,
           21.396468334960662,
           21.197665401422057,
           20.99886246788343,
           20.800059534344804,
           20.6012566008062,
           20.40245366726759,
           20.19514718379446,
           19.9860043875557,
           19.77686159131694,
           19.56771879507816,
           19.358575998839402,
           19.14943320260064,
           18.94029040636186,
           18.73114761012308,
           18.52200481388434,
           18.312862017645557,
           18.10371922140678,
           17.89457642516802,
           17.68543362892926,
           17.47629083269048,
           17.26714803645172,
           17.05800524021296,
           16.84886244397418,
           16.63971964773542,
           16.43057685149666,
           16.22143405525788,
           16.0122912590191,
           15.803148462780339,
           15.59400566654158,
           15.3848628703028,
           15.175720074064039,
           14.96657727782528,
           14.757434481586497,
           14.548291685347738,
           14.339148889108976,
           14.130006092870197,
           13.92086329663142,
           13.711720500392676,
           13.502577704153898,
           13.293434907915117,
           13.084292111676358,
           12.875149315437596,
           12.666006519198817,
           12.456863722960058,
           12.247720926721298,
           12.038578130482517,
           11.829435334243758,
           11.620292538004996,
           11.411149741766218,
           11.202006945527437,
           10.992864149288696,
           10.783721353049916,
           10.574578556811137,
           10.365435760572376,
           10.156292964333616,
           9.947150168094836,
           9.738007371856076,
           9.528864575617316,
           9.319721779378536,
           9.110578983139757,
           8.901436186901016,
           8.692293390662236,
           8.483150594423456,
           8.274007798184696,
           8.064865001945936,
           7.855722205707156,
           7.673113428225915,
           7.623174744532134,
           7.573236060838354,
           7.523297377144576,
           7.473358693450806,
           7.423420009757026,
           7.373481326063246,
           7.3235426423694765,
           7.273603958675698,
           7.223665274981919,
           7.173726591288148,
           7.123787907594368,
           7.073849223900588,
           7.023910540206808,
           6.973971856513037,
           6.924033172819259,
           6.874094489125479,
           6.82415580543171,
           6.77421712173793,
           6.72427843804415,
           6.674339754350379,
           6.6244010706566,
           6.5744623869628205,
           6.52452370326905,
           6.474585019575271,
           6.424646335881491,
           6.374707652187711,
           6.324768968493942,
           6.274830284800162,
           6.224891601106383,
           6.174952917412613,
           6.125808812383399,
           6.078253861684287,
           6.030698910985183,
           5.983143960286071,
           5.935589009586958,
           5.888034058887845,
           5.840479108188742,
           5.7929241574896295,
           5.745369206790517,
           5.697814256091414,
           5.650259305392301,
           5.614412222243372,
           5.58692790163029,
           5.559443581017201,
           5.531959260404114,
           5.504474939791032,
           5.476990619177943,
           5.449506298564856,
           5.422021977951768,
           5.3945376573386845,
           5.367053336725598,
           5.339569016112509,
           5.311105456441977,
           5.282446048368586,
           5.253786640295196,
           5.225127232221811,
           5.196467824148421,
           5.167808416075031,
           5.139149008001641,
           5.110489599928256,
           5.081830191854866,
           5.053170783781476,
           5.024511375708091,
           4.995851967634701,
           4.967192559561311,
           4.938533151487927,
           4.909873743414536,
           4.881214335341146,
           4.852554927267761,
           4.82389551919437,
           4.795236111120981,
           4.766576703047591,
           4.737917294974206,
           4.709257886900817,
           4.6805984788274255,
           4.6519390707540405,
           4.62327966268065,
           4.5946202546072605,
           4.5659608465338755,
           4.537301438460486,
           4.5086420303870955,
           4.479982622313706,
           4.451323214240321
          ],
          [
           61.00054489035143,
           61.05320870228605,
           61.105872514220664,
           61.158536326155286,
           61.21120013808991,
           61.263863950024515,
           61.31652776195914,
           61.36919157389376,
           61.42185538582838,
           61.474519197763,
           61.52718300969762,
           61.57984682163223,
           61.63251063356685,
           61.685174445501474,
           61.73783825743609,
           61.79050206937071,
           61.843165881305325,
           61.895829693239946,
           61.94849350517457,
           62.00115731710918,
           62.053821129043804,
           62.106484940978426,
           62.15914875291304,
           62.211812564847655,
           62.26447637678228,
           62.3171401887169,
           62.36980400065151,
           62.422467812586135,
           62.47513162452075,
           62.527795436455364,
           62.580459248389985,
           62.63312306032461,
           62.686494511859195,
           62.74021978415325,
           62.793945056447285,
           62.84767032874132,
           62.901395601035375,
           62.955120873329406,
           63.00884614562346,
           63.062571417917496,
           63.11629669021154,
           63.17002196250559,
           63.22374723479963,
           63.27747250709367,
           63.33119777938771,
           63.38492305168175,
           63.4386483239758,
           63.49237359626984,
           63.54609886856389,
           63.59982414085793,
           63.65354941315198,
           63.70727468544601,
           63.76099995774006,
           63.8147252300341,
           63.868450502328145,
           63.92217577462218,
           63.975901046916235,
           64.02962631921028,
           64.08335159150431,
           64.13707686379836,
           64.1908021360924,
           64.24452740838645,
           64.29825268068049,
           64.35197795297454,
           64.40570322526858,
           64.45942849756261,
           64.51315376985666,
           64.5668790421507,
           64.62060431444475,
           64.67432958673879,
           64.72805485903282,
           64.78178013132687,
           64.83550540362091,
           64.88923067591496,
           64.942955948209,
           64.99668122050305,
           65.0504064927971,
           65.10413176509114,
           65.15785703738517,
           65.21158230967922,
           65.26530758197326,
           65.3190328542673,
           65.37275812656134,
           65.4264833988554,
           65.47130662144987,
           65.51434943410442,
           65.557392246759,
           65.60043505941354,
           65.6434778720681,
           65.68652068472268,
           65.72956349737723,
           65.77260631003179,
           65.81564912268635,
           65.85869193534091,
           65.90173474799548,
           65.94477756065004,
           65.9878203733046,
           66.03086318595916,
           66.07390599861372,
           66.11694881126829,
           66.15999162392285,
           66.20303443657741,
           66.24607724923197,
           66.28912006188654,
           66.3321628745411,
           66.37520568719566,
           66.41824849985022,
           66.46129131250478,
           66.50433412515935,
           66.5473769378139,
           66.59041975046847,
           66.63346256312302,
           66.67650537577758,
           66.71954818843216,
           66.7625910010867,
           66.80563381374127,
           66.84867662639583,
           66.89171943905039,
           66.93476225170495,
           66.97780506435952,
           67.02084787701408,
           67.06389068966864,
           67.10693350232319,
           67.14997631497775,
           67.19301912763233,
           67.23606194028687,
           67.27910475294145,
           67.32214756559601,
           67.36519037825056,
           67.40823319090512,
           67.4512760035597,
           67.49431881621426,
           67.53736162886881,
           67.58040444152337,
           67.62344725417793,
           67.66649006622721,
           67.70852845170383,
           67.75056683718043,
           67.79260522265704,
           67.83464360813366,
           67.87668199361026,
           67.91872037908686,
           67.96075876456347,
           68.00279715004008,
           68.0448355355167,
           68.0868739209933,
           68.12891230646991,
           68.17095069194652,
           68.21298907742312,
           68.25502746289973,
           68.29706584837633,
           68.33910423385295,
           68.38114261932955,
           68.42318100480615,
           68.46521939028277,
           68.50725777575937,
           68.54929616123599,
           68.59133454671259,
           68.63337293218919,
           68.6754113176658,
           68.7174497031424,
           68.75948808861901,
           68.80152647409562,
           68.84356485957223,
           68.88560324504884,
           68.92764163052544,
           68.96968001600206,
           69.00675706398913,
           69.04135344323139,
           69.07594982247367,
           69.11054620171595,
           69.14514258095824,
           69.17973896020051,
           69.2143353394428,
           69.24893171868509,
           69.28352809792736,
           69.31812447716963,
           69.35272085641192,
           69.3873172356542,
           69.42191361489648,
           69.45650999413876,
           69.49110637338104,
           69.52570275262332,
           69.5602991318656,
           69.5948955111079,
           69.62949189035017,
           69.66408826959244,
           69.69868464883473,
           69.733281028077,
           69.76787740731929,
           69.80247378656156,
           69.83707016580385,
           69.87166654504612,
           69.90626292428841,
           69.94085930353069,
           69.97545568277297,
           70.01005206201526,
           70.04464844125754,
           70.07924482049981,
           70.1138411997421,
           70.14843757898437,
           70.18303395822666,
           70.21763033746893,
           70.25222671671122,
           70.2868230959535,
           70.32141947519577,
           70.35601585443806,
           70.39061223368033,
           70.4252086129226,
           70.45980499216489,
           70.49440137140718,
           70.52899775064947,
           70.56359412989173,
           70.59819050913401,
           70.6327868883763,
           70.66738326761858,
           70.70197964686086,
           70.73657602610314,
           70.77117240534542,
           70.80576878458771,
           70.84036516382997,
           70.87496154307226,
           70.90955792231455,
           70.94415430155681,
           70.97875068079911,
           71.01334706004138,
           71.04794343928367,
           71.08253981852594,
           71.11713619776822,
           71.1517325770105,
           71.18408667112568,
           71.21624857130095,
           71.2484104714762,
           71.28057237165144,
           71.3127342718267,
           71.34489617200197,
           71.3770580721772,
           71.40921997235246,
           71.44138187252773,
           71.47354377270297,
           71.50570567287822,
           71.53786757305348,
           71.57002947322873,
           71.60219137340398,
           71.63435327357924,
           71.66651517375449,
           71.69867707392974,
           71.73083897410498,
           71.76300087428024,
           71.79516277445549,
           71.52265628316398,
           70.9454814004057,
           70.36830651764747,
           69.79113163488924,
           69.21395675213095,
           68.63678186937273,
           68.05960698661448,
           67.4824321038562,
           66.90525722109791,
           66.32808233833974,
           65.75090745558145,
           65.17373257282317,
           64.59655769006494,
           64.01938280730671,
           63.44220792454843,
           62.8650330417902,
           62.28785815903196,
           61.71068327627368,
           61.13350839351544,
           60.55633351075722,
           59.97915862799893,
           59.40198374524064,
           58.82480886248247,
           58.247633979724185,
           57.6704590969659,
           57.09328421420767,
           56.516109331449435,
           55.93893444869116,
           55.36175956593292,
           54.78458468317469,
           54.20740980041641,
           53.63023491765813,
           53.05306003489994,
           52.475885152141664,
           51.89871026938337,
           51.32153538662514,
           50.744360503866915,
           50.169898050075815,
           49.606827739407514,
           49.04375742873921,
           48.48068711807086,
           47.91761680740255,
           47.35454649673425,
           46.79147618606589,
           46.22840587539754,
           45.66533556472929,
           45.10226525406093,
           44.53919494339258,
           43.97612463272428,
           43.41305432205598,
           42.84998401138761,
           42.28691370071931,
           41.723843390051,
           41.16077307938266,
           40.597702768714306,
           40.03463245804605,
           39.47156214737771,
           38.908491836709345,
           38.345421526041044,
           37.78235121537274,
           37.21928090470439,
           36.65621059403608,
           36.093140283367774,
           35.53006997269942,
           34.966999662031114,
           34.40392935136281,
           33.840859040694454,
           33.2777887300261,
           32.71471841935785,
           32.1516481086895,
           31.588577798021152,
           31.025507487352847,
           30.462437176684546,
           29.89936686601619,
           29.336296555347882,
           28.77322624467958,
           28.210155934011226,
           27.64708562334292,
           27.08401531267462,
           26.52094500200626,
           25.95787469133791,
           25.394804380669605,
           24.831734070001303,
           24.390086218376226,
           24.19128328483762,
           23.992480351299015,
           23.793677417760385,
           23.59487448422178,
           23.396071550683175,
           23.19726861714455,
           22.99846568360592,
           22.799662750067334,
           22.60085981652871,
           22.402056882990085,
           22.20325394945148,
           22.00445101591287,
           21.805648082374248,
           21.60684514883564,
           21.408042215297034,
           21.209239281758407,
           21.010436348219798,
           20.81163341468119,
           20.61283048114257,
           20.414027547603943,
           20.215224614065335,
           20.016421680526726,
           19.817618746988103,
           19.618815813449494,
           19.42001287991089,
           19.221209946372262,
           19.02240701283366,
           18.823604079295052,
           18.62480114575642,
           18.4259982122178,
           18.227195278679208,
           18.028392345140585,
           17.82958941160196,
           17.630786478063353,
           17.431983544524748,
           17.23318061098612,
           17.034377677447512,
           16.835574743908907,
           16.63677181037028,
           16.437968876831675,
           16.23916594329307,
           16.040363009754444,
           15.84156007621582,
           15.642757142677212,
           15.443954209138603,
           15.24515127559998,
           15.046348342061373,
           14.847545408522766,
           14.64874247498414,
           14.449939541445534,
           14.251136607906927,
           14.052333674368302,
           13.853530740829674,
           13.647326054441349,
           13.43818325820257,
           13.229040461963791,
           13.019897665725031,
           12.81075486948627,
           12.60161207324749,
           12.39246927700873,
           12.18332648076997,
           11.97418368453119,
           11.76504088829243,
           11.55589809205367,
           11.346755295814889,
           11.13761249957611,
           10.928469703337369,
           10.719326907098589,
           10.51018411085981,
           10.301041314621049,
           10.091898518382289,
           9.882755722143509,
           9.673612925904749,
           9.46447012966599,
           9.255327333427209,
           9.046184537188429,
           8.837041740949688,
           8.627898944710909,
           8.418756148472129,
           8.209613352233369,
           8.000470555994607,
           7.791327759755829,
           7.608718982274587,
           7.558780298580809,
           7.508841614887029,
           7.45890293119325,
           7.408964247499479,
           7.359025563805698,
           7.30908688011192,
           7.25914819641815,
           7.209209512724371,
           7.15927082903059,
           7.10933214533682,
           7.05939346164304,
           7.00945477794926,
           6.9595160942554815,
           6.9095774105617105,
           6.859986355972926,
           6.812431405273813,
           6.7648764545747095,
           6.717321503875597,
           6.669766553176485,
           6.62221160247738,
           6.574656651778268,
           6.527101701079157,
           6.479546750380053,
           6.43199179968094,
           6.384436848981828,
           6.336881898282716,
           6.289326947583612,
           6.2417719968845,
           6.194217046185388,
           6.146662095486284,
           6.099107144787172,
           6.051552194088059,
           6.003997243388956,
           5.956442292689843,
           5.90888734199073,
           5.861332391291619,
           5.8137774405925144,
           5.766222489893402,
           5.71866753919429,
           5.671112588495186,
           5.623557637796074,
           5.5877105546471455,
           5.560226234034062,
           5.532741913420973,
           5.505257592807887,
           5.477773272194804,
           5.450288951581715,
           5.422804630968628,
           5.39532031035554,
           5.367835989742457,
           5.340351669129369,
           5.312867348516281,
           5.285383027903199,
           5.257898707290112,
           5.2304143866770225,
           5.20293006606394,
           5.175445745450853,
           5.1479614248377645,
           5.120477104224677,
           5.092992783611594,
           5.0655084629985065,
           5.038024142385418,
           5.010539821772336,
           4.983055501159248,
           4.95557118054616,
           4.928086859933076,
           4.90060253931999,
           4.873093738396758,
           4.844434330323372,
           4.815774922249982,
           4.787115514176593,
           4.7584561061032025,
           4.729796698029817,
           4.701137289956428,
           4.6724778818830375,
           4.643818473809652,
           4.615159065736262,
           4.5864996576628725,
           4.557840249589487,
           4.529180841516098,
           4.500521433442707,
           4.471862025369317,
           4.443202617295933
          ],
          [
           61.2119068010539,
           61.26457061298852,
           61.31723442492313,
           61.36989823685775,
           61.42256204879237,
           61.475225860726994,
           61.52788967266161,
           61.58055348459623,
           61.63321729653085,
           61.685881108465466,
           61.73854492040009,
           61.7912087323347,
           61.843872544269324,
           61.896536356203946,
           61.94920016813857,
           62.00186398007318,
           62.054527792007804,
           62.107191603942425,
           62.15985541587703,
           62.212519227811654,
           62.265183039746276,
           62.3178468516809,
           62.37051066361551,
           62.42317447555013,
           62.475838287484756,
           62.52850209941937,
           62.58116591135399,
           62.633829723288606,
           62.68649353522323,
           62.73915734715784,
           62.791821159092464,
           62.844484971027086,
           62.89714878296169,
           62.949812594896315,
           63.00247640683094,
           63.05514021876556,
           63.10780403070017,
           63.16046784263479,
           63.21313165456941,
           63.26579546650403,
           63.31845927843865,
           63.37112309037326,
           63.423786902307896,
           63.4764507142425,
           63.529114526177125,
           63.58177833811174,
           63.634442150046354,
           63.68710596198098,
           63.73994668316071,
           63.793671955454755,
           63.8473972277488,
           63.901122500042845,
           63.95484777233688,
           64.00857304463094,
           64.06229831692497,
           64.11602358921901,
           64.16974886151306,
           64.2234741338071,
           64.27719940610113,
           64.33092467839518,
           64.38464995068922,
           64.43837522298327,
           64.49210049527731,
           64.54582576757136,
           64.5995510398654,
           64.65327631215945,
           64.70700158445348,
           64.76072685674754,
           64.81445212904157,
           64.86817740133561,
           64.92190267362966,
           64.9756279459237,
           65.02935321821774,
           65.08307849051178,
           65.13680376280583,
           65.19052903509987,
           65.24425430739392,
           65.29797957968796,
           65.351704851982,
           65.40543012427605,
           65.45915539657008,
           65.51288066886413,
           65.56660594115816,
           65.62033121345222,
           65.66515443604669,
           65.70819724870125,
           65.75124006135582,
           65.79428287401038,
           65.83732568666494,
           65.8803684993195,
           65.92341131197405,
           65.96645412462863,
           66.00949693728317,
           66.05253974993775,
           66.0955825625923,
           66.13862537524687,
           66.18166818790142,
           66.22471100055598,
           66.26775381321055,
           66.31079662586512,
           66.35383943851967,
           66.39688225117423,
           66.4399250638288,
           66.48296787648336,
           66.52601068913792,
           66.56905350179248,
           66.61209631444704,
           66.65513912710159,
           66.69818193975617,
           66.74122475241073,
           66.78426756506529,
           66.82731037771985,
           66.8703531903744,
           66.91339600302898,
           66.95643881568353,
           66.99948162833809,
           67.04252444099265,
           67.08556725364721,
           67.12861006630177,
           67.17115066459635,
           67.21318905007296,
           67.25522743554957,
           67.29726582102617,
           67.33930420650279,
           67.38134259197939,
           67.423380977456,
           67.46541936293261,
           67.50745774840922,
           67.54949613388582,
           67.59153451936244,
           67.63357290483904,
           67.67561129031566,
           67.71764967579226,
           67.75968806126886,
           67.80172644674548,
           67.84376483222208,
           67.8858032176987,
           67.9278416031753,
           67.96987998865191,
           68.01191837412851,
           68.05395675960511,
           68.09599514508173,
           68.13803353055833,
           68.18007191603493,
           68.22211030151155,
           68.26414868698816,
           68.30618707246477,
           68.34822545794137,
           68.39026384341798,
           68.4323022288946,
           68.4743406143712,
           68.5163789998478,
           68.5584173853244,
           68.600455770801,
           68.64249415627762,
           68.68453254175424,
           68.72657092723084,
           68.76860931270744,
           68.81064769818406,
           68.85268608366067,
           68.89472446913727,
           68.93676285461387,
           68.97880124009049,
           69.02083962556709,
           69.0628780110437,
           69.10491639652031,
           69.14695478199691,
           69.18403182998398,
           69.21862820922625,
           69.25322458846854,
           69.28782096771081,
           69.3224173469531,
           69.35701372619538,
           69.39161010543765,
           69.42620648467994,
           69.46080286392223,
           69.4953992431645,
           69.52999562240677,
           69.56459200164906,
           69.59918838089135,
           69.63378476013362,
           69.6683811393759,
           69.70297751861818,
           69.73757389786046,
           69.77217027710275,
           69.80676665634502,
           69.8413630355873,
           69.8759594148296,
           69.91055579407187,
           69.94515217331414,
           69.97974855255643,
           70.01434493179872,
           70.04894131104099,
           70.08353769028326,
           70.11813406952555,
           70.15273044876784,
           70.18732682801011,
           70.2219232072524,
           70.25651958649468,
           70.29111596573695,
           70.32571234497924,
           70.36030872422151,
           70.3949051034638,
           70.42950148270607,
           70.46409786194835,
           70.49869424119063,
           70.53329062043292,
           70.5678869996752,
           70.60248337891747,
           70.63707975815976,
           70.66949791702729,
           70.70165981720254,
           70.7338217173778,
           70.76598361755305,
           70.7981455177283,
           70.83030741790355,
           70.86246931807881,
           70.89463121825406,
           70.92679311842932,
           70.95895501860457,
           70.99111691877982,
           71.02327881895508,
           71.05544071913033,
           71.08760261930558,
           71.11976451948084,
           71.15192641965609,
           71.18408831983133,
           71.2162502200066,
           71.24841212018184,
           71.2805740203571,
           71.31273592053235,
           71.34489782070762,
           71.37705972088287,
           71.40922162105811,
           71.44138352123336,
           71.47354542140863,
           71.50570732158388,
           71.53786922175912,
           71.57003112193438,
           71.60219302210963,
           71.63435492228488,
           71.66651682246012,
           71.69867872263539,
           71.73084062281063,
           71.7630025229859,
           71.79516442316114,
           71.8273263233364,
           71.85948822351165,
           71.8916501236869,
           71.92381202386215,
           71.65130553257065,
           71.07413064981236,
           70.49695576705412,
           69.9197808842959,
           69.3426060015376,
           68.76543111877939,
           68.18825623602115,
           67.61108135326286,
           67.03390647050458,
           66.45673158774639,
           65.87955670498812,
           65.30238182222983,
           64.7252069394716,
           64.14803205671336,
           63.57085717395509,
           62.99368229119685,
           62.41650740843862,
           61.839332525680334,
           61.262157642922105,
           60.68498276016388,
           60.10780787740559,
           59.530632994647306,
           58.953458111889134,
           58.37628322913085,
           57.79910834637256,
           57.221933463614334,
           56.6447585808561,
           56.06758369809781,
           55.490408815339585,
           54.91323393258135,
           54.336059049823064,
           53.758884167064785,
           53.181709284306606,
           52.60453440154832,
           52.027359518790036,
           51.45018463603181,
           50.87300975327358,
           50.29583487051529,
           49.71865998775706,
           49.14148510499882,
           48.564310222240536,
           47.98713533948231,
           47.40996045672407,
           46.83278557396579,
           46.25561069120751,
           45.67843580844932,
           45.101260925691044,
           44.52408604293276,
           43.94691116017452,
           43.369736277416294,
           42.79256139465801,
           42.21538651189978,
           41.63821162914155,
           41.061036746383266,
           40.48386186362498,
           39.9066869808668,
           39.329512098108516,
           38.75233721535023,
           38.175162332592,
           37.59798744983377,
           37.02081256707549,
           36.44363768431725,
           35.866462801559024,
           35.28928791880074,
           34.71211303604251,
           34.13493815328428,
           33.557763270525996,
           32.98058838776771,
           32.40341350500953,
           31.826238622251246,
           31.24906373949296,
           30.671888856734732,
           30.094713973976503,
           29.517539091218218,
           28.950264568607004,
           28.3871942579387,
           27.824123947270348,
           27.261053636602043,
           26.69798332593374,
           26.134913015265386,
           25.57184270459703,
           25.00877239392873,
           24.445702083260425,
           24.004054231635347,
           23.805251298096742,
           23.606448364558133,
           23.40764543101951,
           23.208842497480905,
           23.0100395639423,
           22.811236630403673,
           22.612433696865047,
           22.413630763326456,
           22.214827829787833,
           22.016024896249206,
           21.8172219627106,
           21.618419029171992,
           21.419616095633366,
           21.22081316209476,
           21.022010228556155,
           20.823207295017532,
           20.624404361478923,
           20.425601427940318,
           20.22679849440169,
           20.027995560863065,
           19.82919262732446,
           19.63038969378585,
           19.431586760247228,
           19.23278382670862,
           19.033980893170014,
           18.835177959631384,
           18.63637502609278,
           18.43757209255417,
           18.238769159015547,
           18.03996622547692,
           17.841163291938336,
           17.642360358399706,
           17.443557424861083,
           17.244754491322478,
           17.045951557783866,
           16.847148624245243,
           16.648345690706638,
           16.449542757168032,
           16.250739823629402,
           16.051936890090797,
           15.853133956552192,
           15.654331023013565,
           15.45552808947494,
           15.256725155936333,
           15.057922222397728,
           14.859119288859103,
           14.660316355320496,
           14.461513421781886,
           14.262710488243261,
           14.063907554704656,
           13.865104621166047,
           13.666301687627422,
           13.467498754088798,
           13.26869582055021,
           13.069892887011584,
           12.87108995347296,
           12.672287019934354,
           12.473484086395747,
           12.274681152857122,
           12.075878219318515,
           11.877075285779906,
           11.67827235224128,
           11.479469418702674,
           11.280666485164067,
           11.081863551625442,
           10.883060618086818,
           10.684257684548228,
           10.485454751009604,
           10.286651817470979,
           10.088735321320666,
           9.891133356319521,
           9.693531391318356,
           9.49592942631721,
           9.298327461316063,
           9.100725496314901,
           8.903123531313735,
           8.705521566312608,
           8.507919601311443,
           8.31031763631028,
           8.112715671309134,
           7.915113706307988,
           7.717511741306821,
           7.544935415563601,
           7.497487286109877,
           7.450039156656152,
           7.402591027202429,
           7.355142897748714,
           7.30769476829499,
           7.2602466388412665,
           7.212798509387553,
           7.165350379933827,
           7.117902250480104,
           7.070454121026389,
           7.023005991572665,
           6.975557862118941,
           6.928109732665218,
           6.880661603211503,
           6.833213473757779,
           6.785729737677585,
           6.7381747869784805,
           6.690619836279368,
           6.643064885580256,
           6.595509934881152,
           6.547954984182039,
           6.5004000334829275,
           6.452845082783824,
           6.405290132084711,
           6.357735181385599,
           6.310180230686488,
           6.262625279987383,
           6.215070329288271,
           6.167515378589159,
           6.119960427890055,
           6.072405477190943,
           6.0248505264918295,
           5.977295575792727,
           5.929740625093614,
           5.882185674394501,
           5.83463072369539,
           5.787075772996285,
           5.739520822297173,
           5.691965871598061,
           5.644410920898958,
           5.596855970199845,
           5.561008887050916,
           5.533524566437833,
           5.506040245824745,
           5.478555925211658,
           5.451071604598575,
           5.423587283985487,
           5.396102963372399,
           5.368618642759311,
           5.341134322146228,
           5.313650001533141,
           5.286165680920052,
           5.258681360306969,
           5.231197039693882,
           5.203712719080794,
           5.176228398467712,
           5.148744077854624,
           5.1212597572415355,
           5.093775436628448,
           5.066291116015365,
           5.0388067954022775,
           5.011322474789189,
           4.983838154176107,
           4.9563538335630195,
           4.928869512949932,
           4.901385192336848,
           4.873900871723761,
           4.846466219006621,
           4.8190414995638164,
           4.791616780121007,
           4.764192060678197,
           4.736767341235388,
           4.709342621792583,
           4.681917902349774,
           4.654493182906963,
           4.627068463464159,
           4.599643744021349,
           4.57221902457854,
           4.544794305135735,
           4.517369585692925,
           4.489944866250116,
           4.4625201468073055,
           4.435095427364502
          ],
          [
           61.423268711756364,
           61.475932523690986,
           61.5285963356256,
           61.58126014756022,
           61.63392395949484,
           61.68658777142946,
           61.739251583364066,
           61.79191539529869,
           61.84457920723331,
           61.89724301916793,
           61.94990683110255,
           62.00257064303717,
           62.05523445497179,
           62.10789826690641,
           62.160562078841025,
           62.21322589077565,
           62.26588970271026,
           62.31855351464488,
           62.371217326579504,
           62.42388113851412,
           62.47654495044874,
           62.52920876238336,
           62.581872574317984,
           62.63453638625259,
           62.68720019818721,
           62.739864010121835,
           62.79252782205645,
           62.84519163399107,
           62.89785544592569,
           62.95051925786031,
           63.00318306979492,
           63.055846881729536,
           63.10851069366416,
           63.16117450559878,
           63.2138383175334,
           63.26650212946802,
           63.319165941402645,
           63.37182975333725,
           63.424493565271874,
           63.477157377206495,
           63.52982118914112,
           63.582485001075725,
           63.635148813010346,
           63.68781262494497,
           63.74047643687958,
           63.793140248814204,
           63.84580406074882,
           63.89846787268344,
           63.951131684618055,
           64.00379549655267,
           64.05645930848729,
           64.10912312042191,
           64.16178693235653,
           64.21445074429116,
           64.26711455622576,
           64.31977836816039,
           64.372442180095,
           64.42510599202963,
           64.47776980396425,
           64.53043361589887,
           64.58309742783348,
           64.6357612397681,
           64.68842505170272,
           64.74108886363734,
           64.79375267557197,
           64.84712412675627,
           64.90084939905032,
           64.95457467134435,
           65.0082999436384,
           65.06202521593244,
           65.11575048822648,
           65.16947576052053,
           65.22320103281457,
           65.27692630510862,
           65.33065157740266,
           65.38437684969671,
           65.43810212199074,
           65.49182739428478,
           65.54555266657883,
           65.59927793887287,
           65.65300321116692,
           65.70672848346096,
           65.760453755755,
           65.81417902804904,
           65.85900225064351,
           65.90204506329809,
           65.94508787595264,
           65.9881306886072,
           66.03117350126176,
           66.07421631391632,
           66.11725912657089,
           66.16030193922545,
           66.20334475188001,
           66.24638756453457,
           66.28943037718913,
           66.3324731898437,
           66.37551600249826,
           66.41855881515282,
           66.46160162780738,
           66.50464444046193,
           66.5476872531165,
           66.59073006577107,
           66.63377287748888,
           66.6758112629655,
           66.7178496484421,
           66.75988803391871,
           66.80192641939531,
           66.84396480487193,
           66.88600319034853,
           66.92804157582513,
           66.97007996130175,
           67.01211834677835,
           67.05415673225497,
           67.09619511773157,
           67.13823350320817,
           67.18027188868479,
           67.22231027416139,
           67.264348659638,
           67.3063870451146,
           67.34842543059122,
           67.39046381606784,
           67.43250220154442,
           67.47454058702102,
           67.51657897249764,
           67.55861735797426,
           67.60065574345086,
           67.64269412892747,
           67.68473251440409,
           67.72677089988068,
           67.76880928535729,
           67.81084767083391,
           67.85288605631051,
           67.89492444178711,
           67.93696282726371,
           67.97900121274033,
           68.02103959821694,
           68.06307798369355,
           68.10511636917016,
           68.14715475464675,
           68.18919314012336,
           68.23123152559998,
           68.27326991107658,
           68.31530829655318,
           68.3573466820298,
           68.39938506750642,
           68.441423452983,
           68.48346183845962,
           68.52550022393623,
           68.56753860941285,
           68.60957699488945,
           68.65161538036605,
           68.69365376584267,
           68.73569215131926,
           68.77773053679587,
           68.81976892227249,
           68.86180730774909,
           68.90384569322569,
           68.9458840787023,
           68.98792246417892,
           69.02996084965551,
           69.07199923513213,
           69.11403762060874,
           69.15607600608534,
           69.19811439156194,
           69.24015277703856,
           69.28219116251516,
           69.32422954799178,
           69.36130659597883,
           69.3959029752211,
           69.4304993544634,
           69.46509573370567,
           69.49969211294795,
           69.53428849219023,
           69.56888487143252,
           69.60348125067479,
           69.63807762991706,
           69.67267400915935,
           69.70727038840162,
           69.74186676764391,
           69.7764631468862,
           69.81105952612847,
           69.84565590537076,
           69.88025228461304,
           69.91484866385532,
           69.9494450430976,
           69.98404142233989,
           70.01863780158216,
           70.05323418082443,
           70.08783056006672,
           70.122426939309,
           70.15490916292889,
           70.18707106310413,
           70.2192329632794,
           70.25139486345465,
           70.2835567636299,
           70.31571866380516,
           70.3478805639804,
           70.38004246415565,
           70.4122043643309,
           70.44436626450616,
           70.47652816468141,
           70.50869006485667,
           70.54085196503192,
           70.57301386520717,
           70.60517576538243,
           70.63733766555768,
           70.66949956573293,
           70.70166146590819,
           70.73382336608344,
           70.7659852662587,
           70.79814716643394,
           70.8303090666092,
           70.86247096678446,
           70.89463286695971,
           70.92679476713496,
           70.95895666731022,
           70.99111856748546,
           71.02328046766073,
           71.05544236783597,
           71.08760426801122,
           71.11976616818647,
           71.15192806836173,
           71.18408996853698,
           71.21625186871223,
           71.24841376888749,
           71.28057566906276,
           71.312737569238,
           71.34489946941325,
           71.3770613695885,
           71.40922326976374,
           71.44138516993901,
           71.47354707011426,
           71.50570897028952,
           71.53787087046476,
           71.57003277064001,
           71.60219467081528,
           71.63435657099053,
           71.66651847116577,
           71.69868037134103,
           71.73084227151628,
           71.76300417169153,
           71.79516607186679,
           71.82732797204204,
           71.8594898722173,
           71.89165177239255,
           71.9238136725678,
           71.95597557274306,
           71.98813747291831,
           72.02029937309356,
           72.05246127326882,
           71.7799547819773,
           71.20277989921901,
           70.62560501646078,
           70.04843013370255,
           69.47125525094427,
           68.89408036818602,
           68.3169054854278,
           67.73973060266951,
           67.16255571991124,
           66.58538083715305,
           66.00820595439477,
           65.43103107163648,
           64.85385618887825,
           64.27668130612003,
           63.69950642336174,
           63.12233154060351,
           62.54515665784528,
           61.967981775087,
           61.39080689232876,
           60.813632009570526,
           60.23645712681224,
           59.65928224405396,
           59.08210736129579,
           58.504932478537505,
           57.92775759577922,
           57.350582713020984,
           56.773407830262755,
           56.19623294750447,
           55.61905806474624,
           55.041883181988005,
           54.46470829922972,
           53.887533416471435,
           53.31035853371326,
           52.73318365095498,
           52.1560087681967,
           51.578833885438456,
           51.001659002680235,
           50.42448411992195,
           49.847309237163714,
           49.27013435440547,
           48.69295947164719,
           48.11578458888896,
           47.53860970613073,
           46.96143482337244,
           46.38425994061416,
           45.80708505785598,
           45.2299101750977,
           44.652735292339415,
           44.07556040958118,
           43.49838552682295,
           42.921210644064665,
           42.34403576130643,
           41.76286636266504,
           41.1735746812296,
           40.58428299979416,
           39.99499131835884,
           39.40569963692341,
           38.816407955487975,
           38.22711627405259,
           37.63782459261721,
           37.04853291118177,
           36.4592412297464,
           35.86994954831101,
           35.28065786687558,
           34.6913661854402,
           34.10207450400482,
           33.512782822569385,
           32.92349114113395,
           32.334199459698624,
           31.744907778263187,
           31.155616096827753,
           30.566324415392376,
           29.977032733956992,
           29.38774105252156,
           28.79844937108618,
           28.209157689650795,
           27.61986600821536,
           27.030574326779984,
           26.441282645344604,
           25.851990963909167,
           25.262699282473733,
           24.67340760103835,
           24.084115919602972,
           23.628608958753677,
           23.440671439076567,
           23.252733919399454,
           23.064796399722326,
           22.876858880045216,
           22.68892136036811,
           22.50098384069098,
           22.313046321013854,
           22.12510880133676,
           21.937171281659637,
           21.749233761982506,
           21.561296242305396,
           21.373358722628286,
           21.185421202951158,
           20.99748368327405,
           20.80954616359694,
           20.621608643919814,
           20.4336711242427,
           20.24573360456559,
           20.057796084888466,
           19.869858565211338,
           19.681921045534228,
           19.493983525857118,
           19.30604600617999,
           19.117941846881774,
           18.92033988188063,
           18.72273791687946,
           18.525135951878312,
           18.327533986877167,
           18.12993202187601,
           17.93233005687484,
           17.734728091873713,
           17.53712612687255,
           17.33952416187139,
           17.14192219687024,
           16.944320231869092,
           16.74671826686793,
           16.549116301866782,
           16.351514336865634,
           16.15391237186447,
           15.956310406863325,
           15.75870844186218,
           15.561106476861013,
           15.363504511859851,
           15.165902546858705,
           14.968300581857555,
           14.770698616856393,
           14.573096651855248,
           14.375494686854102,
           14.177892721852935,
           13.98029075685179,
           13.782688791850646,
           13.585086826849484,
           13.387484861848314,
           13.189882896847191,
           12.992280931846025,
           12.794678966844863,
           12.597077001843717,
           12.39947503684257,
           12.201873071841403,
           12.004271106840257,
           11.806669141839112,
           11.609067176837945,
           11.411465211836799,
           11.213863246835654,
           11.016261281834492,
           10.818659316833324,
           10.6210573518322,
           10.423455386831032,
           10.225853421829871,
           10.028251456828725,
           9.830649491827579,
           9.633047526826413,
           9.435445561825267,
           9.23784359682412,
           9.040241631822957,
           8.842639666821793,
           8.645037701820666,
           8.4474357368195,
           8.249833771818338,
           8.052231806817192,
           7.854629841816045,
           7.657027876814879,
           7.484451551071658,
           7.437003421617934,
           7.389555292164211,
           7.342107162710487,
           7.294659033256772,
           7.247210903803047,
           7.199762774349323,
           7.1523146448956085,
           7.104866515441886,
           7.0574183859881625,
           7.009970256534446,
           6.962522127080723,
           6.915073997626999,
           6.867625868173275,
           6.82017773871956,
           6.772729609265836,
           6.7252814798121126,
           6.677833350358398,
           6.6303852209046745,
           6.58293709145095,
           6.535488961997235,
           6.488040832543511,
           6.440592703089788,
           6.393144573636073,
           6.345696444182349,
           6.298248314728625,
           6.250800185274901,
           6.203352055821186,
           6.15737295717076,
           6.11222095994782,
           6.067068962724887,
           6.021916965501946,
           5.976764968279005,
           5.931612971056073,
           5.886460973833131,
           5.84130897661019,
           5.7961569793872485,
           5.751004982164316,
           5.705852984941375,
           5.6607009877184336,
           5.615548990495501,
           5.57039699327256,
           5.536252810909595,
           5.509971353446614,
           5.483689895983629,
           5.457408438520644,
           5.431126981057663,
           5.404845523594678,
           5.378564066131692,
           5.352282608668707,
           5.326001151205726,
           5.299719693742741,
           5.273438236279755,
           5.247156778816776,
           5.220875321353789,
           5.1945938638908045,
           5.167710042572797,
           5.140285323129988,
           5.112860603687178,
           5.085435884244368,
           5.058011164801564,
           5.030586445358754,
           5.003161725915945,
           4.975737006473139,
           4.94831228703033,
           4.9208875675875206,
           4.893462848144717,
           4.8660381287019066,
           4.838613409259097,
           4.8111886898162926,
           4.783763970373482,
           4.756339250930672,
           4.728914531487863,
           4.701489812045058,
           4.674065092602249,
           4.646640373159439,
           4.619215653716634,
           4.591790934273824,
           4.564366214831015,
           4.536941495388211,
           4.509516775945401,
           4.482092056502591,
           4.454667337059782,
           4.427242617616977
          ],
          [
           61.63463062245882,
           61.68729443439344,
           61.73995824632806,
           61.79262205826268,
           61.8452858701973,
           61.897949682131916,
           61.95061349406653,
           62.003277306001145,
           62.05594111793577,
           62.10860492987039,
           62.161268741805,
           62.213932553739625,
           62.266596365674246,
           62.31926017760887,
           62.37192398954348,
           62.424587801478104,
           62.47725161341272,
           62.52991542534734,
           62.58257923728196,
           62.63524304921658,
           62.68790686115119,
           62.74057067308581,
           62.793234485020434,
           62.84589829695505,
           62.89856210888968,
           62.95122592082429,
           63.0038897327589,
           63.05655354469353,
           63.109217356628136,
           63.16188116856276,
           63.21454498049738,
           63.267208792431994,
           63.31987260436662,
           63.37253641630123,
           63.42520022823585,
           63.47786404017047,
           63.530527852105095,
           63.58319166403972,
           63.635855475974324,
           63.68851928790895,
           63.74118309984357,
           63.79384691177819,
           63.84651072371281,
           63.89917453564742,
           63.95183834758204,
           64.00450215951666,
           64.05716597145128,
           64.1098297833859,
           64.16249359532051,
           64.21515740725513,
           64.26782121918976,
           64.32048503112438,
           64.373148843059,
           64.42581265499362,
           64.47847646692823,
           64.53114027886285,
           64.58380409079747,
           64.63646790273208,
           64.6891317146667,
           64.74179552660132,
           64.79445933853594,
           64.84712315047057,
           64.89978696240519,
           64.9524507743398,
           65.00511458627442,
           65.05777839820904,
           65.11044221014366,
           65.16310602207828,
           65.21576983401289,
           65.26843364594751,
           65.32109745788213,
           65.37376126981675,
           65.42642508175138,
           65.47908889368598,
           65.5317527056206,
           65.58441651755523,
           65.63708032948983,
           65.68974414142446,
           65.74240795335908,
           65.79507176529368,
           65.84773557722832,
           65.90057629805777,
           65.95430157035182,
           66.00802684264586,
           66.05285006524034,
           66.0958928778949,
           66.13843347585801,
           66.18047186133462,
           66.22251024681124,
           66.26454863228784,
           66.30658701776444,
           66.34862540324106,
           66.39066378871766,
           66.43270217419428,
           66.47474055967088,
           66.5167789451475,
           66.5588173306241,
           66.6008557161007,
           66.64289410157731,
           66.68493248705391,
           66.72697087253053,
           66.76900925800713,
           66.81104764348373,
           66.85308602896035,
           66.89512441443695,
           66.93716279991357,
           66.97920118539017,
           67.02123957086678,
           67.06327795634338,
           67.10531634182,
           67.1473547272966,
           67.1893931127732,
           67.23143149824982,
           67.27346988372642,
           67.31550826920304,
           67.35754665467964,
           67.39958504015624,
           67.44162342563286,
           67.48366181110947,
           67.52570019658607,
           67.56773858206267,
           67.60977696753929,
           67.65181535301589,
           67.6938537384925,
           67.73589212396911,
           67.77793050944572,
           67.81996889492233,
           67.86200728039893,
           67.90404566587553,
           67.94608405135214,
           67.98812243682875,
           68.03016082230536,
           68.07219920778196,
           68.11423759325857,
           68.15627597873518,
           68.1983143642118,
           68.24035274968838,
           68.282391135165,
           68.3244295206416,
           68.36646790611822,
           68.40850629159482,
           68.45054467707143,
           68.49258306254804,
           68.53462144802464,
           68.57665983350125,
           68.61869821897787,
           68.66073660445447,
           68.70277498993109,
           68.74481337540769,
           68.7868517608843,
           68.8288901463609,
           68.87092853183752,
           68.91296691731411,
           68.95500530279071,
           68.99704368826733,
           69.03908207374394,
           69.08112045922054,
           69.12315884469716,
           69.16519723017376,
           69.20723561565038,
           69.24927400112698,
           69.2913123866036,
           69.3333507720802,
           69.3753891575568,
           69.41742754303341,
           69.45946592851001,
           69.50150431398663,
           69.53858136197368,
           69.57317774121596,
           69.60777412045825,
           69.64032040883049,
           69.67248230900574,
           69.70464420918098,
           69.73680610935625,
           69.76896800953149,
           69.80112990970675,
           69.833291809882,
           69.86545371005725,
           69.8976156102325,
           69.92977751040776,
           69.96193941058301,
           69.99410131075827,
           70.02626321093351,
           70.05842511110878,
           70.09058701128401,
           70.12274891145928,
           70.15491081163454,
           70.18707271180979,
           70.21923461198504,
           70.25139651216028,
           70.28355841233554,
           70.31572031251079,
           70.34788221268606,
           70.3800441128613,
           70.41220601303655,
           70.4443679132118,
           70.47652981338706,
           70.50869171356231,
           70.54085361373757,
           70.57301551391282,
           70.60517741408806,
           70.63733931426333,
           70.66950121443858,
           70.70166311461384,
           70.73382501478909,
           70.76598691496434,
           70.79814881513958,
           70.83031071531484,
           70.8624726154901,
           70.89463451566535,
           70.9267964158406,
           70.95895831601585,
           70.9911202161911,
           71.02328211636636,
           71.05544401654161,
           71.08760591671688,
           71.11976781689212,
           71.15192971706738,
           71.18409161724263,
           71.21625351741788,
           71.24841541759312,
           71.28057731776838,
           71.31273921794364,
           71.34490111811888,
           71.37706301829415,
           71.40922491846939,
           71.44138681864465,
           71.4735487188199,
           71.50571061899515,
           71.5378725191704,
           71.57003441934566,
           71.60219631952091,
           71.63435821969617,
           71.66652011987144,
           71.69868202004668,
           71.73084392022193,
           71.76300582039718,
           71.79516772057244,
           71.82732962074769,
           71.85949152092293,
           71.8916534210982,
           71.92381532127345,
           71.95597722144869,
           71.98813912162396,
           72.0203010217992,
           72.05246292197445,
           72.08462482214972,
           72.11678672232496,
           72.14894862250021,
           72.18111052267547,
           71.90860403138396,
           71.33142914862569,
           70.75425426586743,
           70.17707938310922,
           69.59990450035093,
           69.02272961759269,
           68.44555473483446,
           67.86837985207617,
           67.29120496931789,
           66.71403008655972,
           66.13645577148083,
           65.54716409004538,
           64.95787240861,
           64.36858072717463,
           63.7792890457392,
           63.189997364303814,
           62.60070568286844,
           62.011414001433,
           61.42212231999762,
           60.832830638562235,
           60.2435389571268,
           59.65424727569137,
           59.06495559425604,
           58.47566391282061,
           57.886372231385174,
           57.2970805499498,
           56.70778886851442,
           56.11849718707898,
           55.529205505643596,
           54.93991382420822,
           54.35062214277278,
           53.76133046133736,
           53.172038779902024,
           52.58274709846659,
           51.99345541703116,
           51.40416373559578,
           50.814872054160396,
           50.22558037272496,
           49.63628869128958,
           49.0469970098542,
           48.45770532841876,
           47.868413646983385,
           47.279121965548,
           46.68983028411257,
           46.10053860267713,
           45.511246921241806,
           44.921955239806366,
           44.33266355837094,
           43.743371876935555,
           43.15408019550017,
           42.564788514064745,
           41.97549683262936,
           41.38620515119398,
           40.79691346975855,
           40.20762178832311,
           39.61833010688778,
           39.029038425452356,
           38.439746744016915,
           37.85045506258153,
           37.261163381146154,
           36.67187169971072,
           36.08258001827534,
           35.49328833683996,
           34.90399665540453,
           34.31470497396914,
           33.72541329253376,
           33.13612161109833,
           32.5468299296629,
           31.957538248227568,
           31.368246566792134,
           30.7789548853567,
           30.18966320392132,
           29.600371522485936,
           29.011079841050503,
           28.421788159615126,
           27.83249647817974,
           27.24320479674431,
           26.653913115308924,
           26.064621433873544,
           25.475329752438114,
           24.886038071002677,
           24.296746389567296,
           23.707454708131912,
           23.251947747282617,
           23.064010227605507,
           22.8760727079284,
           22.688135188251273,
           22.500197668574163,
           22.312260148897053,
           22.124322629219925,
           21.936385109542798,
           21.748447589865705,
           21.560510070188577,
           21.37257255051145,
           21.184635030834343,
           20.99669751115723,
           20.808759991480105,
           20.620822471802995,
           20.43288495212588,
           20.244947432448757,
           20.057009912771644,
           19.869072393094534,
           19.681134873417406,
           19.493197353740285,
           19.305259834063172,
           19.117322314386062,
           18.929384794708934,
           18.741447275031824,
           18.553509755354714,
           18.365572235677583,
           18.177634716000476,
           17.98969719632337,
           17.801759676646242,
           17.61382215696911,
           17.42588463729202,
           17.237947117614894,
           17.050009597937766,
           16.862072078260653,
           16.674134558583546,
           16.48619703890642,
           16.298259519229312,
           16.1103219995522,
           15.922384479875072,
           15.73444696019796,
           15.54650944052085,
           15.358571920843723,
           15.170634401166597,
           14.982696881489485,
           14.794759361812375,
           14.60682184213525,
           14.41888432245814,
           14.230946802781029,
           14.0430092831039,
           13.85507176342679,
           13.66713424374968,
           13.479196724072553,
           13.291259204395427,
           13.103321684718335,
           12.915384165041207,
           12.727446645364079,
           12.536593137351772,
           12.338991172350626,
           12.141389207349462,
           11.943787242348314,
           11.746185277347166,
           11.548583312346004,
           11.350981347344858,
           11.153379382343712,
           10.955777417342546,
           10.758175452341384,
           10.560573487340255,
           10.362971522339091,
           10.165369557337925,
           9.96776759233678,
           9.770165627335633,
           9.572563662334469,
           9.374961697333324,
           9.177359732332178,
           8.979757767331014,
           8.78215580232985,
           8.584553837328723,
           8.386951872327558,
           8.189349907326394,
           7.991747942325248,
           7.794145977324103,
           7.596544012322935,
           7.423967686579715,
           7.376519557125992,
           7.329071427672267,
           7.281623298218544,
           7.234175168764829,
           7.186727039311105,
           7.1392789098573814,
           7.091830780403667,
           7.044382650949943,
           6.996934521496218,
           6.9494863920425045,
           6.90203826258878,
           6.854590133135056,
           6.809305430785949,
           6.764153433563017,
           6.719001436340076,
           6.673849439117134,
           6.628697441894202,
           6.583545444671261,
           6.538393447448319,
           6.493241450225387,
           6.448089453002447,
           6.402937455779505,
           6.357785458556572,
           6.312633461333631,
           6.26748146411069,
           6.222329466887749,
           6.177177469664816,
           6.132025472441875,
           6.086873475218933,
           6.041721477996001,
           5.99656948077306,
           5.951417483550118,
           5.906265486327187,
           5.861113489104246,
           5.815961491881303,
           5.770809494658362,
           5.72565749743543,
           5.680505500212489,
           5.635353502989547,
           5.590201505766615,
           5.545049508543674,
           5.510905326180708,
           5.484623868717728,
           5.458342411254742,
           5.4320609537917575,
           5.405779496328776,
           5.379498038865792,
           5.3532165814028065,
           5.326935123939822,
           5.30065366647684,
           5.2743722090138565,
           5.24809075155087,
           5.2218092940878895,
           5.195527836624905,
           5.169246379161919,
           5.142964921698939,
           5.116683464235953,
           5.090402006772967,
           5.0641205493099815,
           5.037839091847001,
           5.011557634384016,
           4.9852761769210305,
           4.95899471945805,
           4.932713261995065,
           4.9064318045320805,
           4.880150347069099,
           4.8538688896061135,
           4.827587432143129,
           4.801305974680148,
           4.7750245172171635,
           4.7484864411831476,
           4.721061721740338,
           4.693637002297534,
           4.666212282854724,
           4.638787563411914,
           4.6113628439691094,
           4.5839381245263,
           4.556513405083491,
           4.529088685640686,
           4.501663966197876,
           4.474239246755067,
           4.446814527312257,
           4.419389807869452
          ],
          [
           61.822619835424305,
           61.87528364735892,
           61.927947459293534,
           61.980611271228156,
           62.03327508316278,
           62.0859388950974,
           62.138602707032014,
           62.19126651896663,
           62.24393033090125,
           62.29659414283587,
           62.34925795477049,
           62.4019217667051,
           62.45458557863972,
           62.507249390574344,
           62.559913202508966,
           62.61257701444358,
           62.665240826378195,
           62.71790463831282,
           62.77056845024744,
           62.82323226218206,
           62.875896074116675,
           62.928559886051296,
           62.98122369798591,
           63.03388750992053,
           63.086551321855154,
           63.139215133789776,
           63.19187894572439,
           63.244542757659005,
           63.29720656959363,
           63.34987038152825,
           63.402534193462856,
           63.45519800539748,
           63.5078618173321,
           63.56052562926672,
           63.61318944120134,
           63.665853253135964,
           63.71851706507058,
           63.77118087700519,
           63.823844688939815,
           63.87650850087443,
           63.92917231280905,
           63.98183612474367,
           64.03449993667829,
           64.08716374861291,
           64.13982756054752,
           64.19249137248215,
           64.24515518441676,
           64.29781899635138,
           64.350482808286,
           64.40314662022061,
           64.45581043215525,
           64.50847424408985,
           64.56113805602448,
           64.6138018679591,
           64.6664656798937,
           64.71912949182834,
           64.77179330376295,
           64.82445711569757,
           64.87712092763219,
           64.92978473956681,
           64.98244855150143,
           65.03511236343604,
           65.08777617537068,
           65.14043998730529,
           65.1931037992399,
           65.24576761117453,
           65.29843142310914,
           65.35109523504376,
           65.40375904697837,
           65.45642285874415,
           65.50882802246417,
           65.5612331861842,
           65.61363834990422,
           65.66604351362423,
           65.71844867734427,
           65.7708538410643,
           65.82325900478432,
           65.87566416850433,
           65.92806933222435,
           65.98047449594439,
           66.03287965966442,
           66.08528482338443,
           66.13768998710445,
           66.19009515082449,
           66.23295769319509,
           66.27391171129582,
           66.31486572939654,
           66.35581974749728,
           66.396773765598,
           66.43772778369873,
           66.47868180179947,
           66.51963581990019,
           66.56058983800092,
           66.60154385610166,
           66.64249787420238,
           66.68345189230311,
           66.72440591040383,
           66.76535992850455,
           66.80703685748131,
           66.84907524295791,
           66.89111362843451,
           66.93315201391113,
           66.97519039938773,
           67.01722878486434,
           67.05926717034095,
           67.10130555581756,
           67.14334394129418,
           67.18538232677078,
           67.22742071224738,
           67.26945909772398,
           67.3114974832006,
           67.3535358686772,
           67.39557425415381,
           67.43761263963043,
           67.47965102510703,
           67.52168941058363,
           67.56372779606023,
           67.60576618153685,
           67.64780456701345,
           67.68984295249007,
           67.73188133796668,
           67.77391972344327,
           67.81595810891989,
           67.8579964943965,
           67.9000348798731,
           67.9420732653497,
           67.98411165082632,
           68.02615003630294,
           68.06818842177952,
           68.11022680725614,
           68.15226519273274,
           68.19430357820936,
           68.23634196368596,
           68.27838034916257,
           68.32041873463918,
           68.36245712011579,
           68.4044955055924,
           68.44653389106901,
           68.4885722765456,
           68.53061066202221,
           68.57264904749883,
           68.61468743297544,
           68.65672581845203,
           68.69876420392865,
           68.74080258940526,
           68.78284097488186,
           68.82487936035847,
           68.86691774583508,
           68.9089561313117,
           68.9509945167883,
           68.9930329022649,
           69.03507128774152,
           69.07710967321812,
           69.11914805869473,
           69.16118644417134,
           69.20322482964795,
           69.24526321512454,
           69.28730160060115,
           69.32933998607777,
           69.37137837155437,
           69.41341675703097,
           69.45545514250759,
           69.49749352798419,
           69.5395319134608,
           69.58157029893741,
           69.62360868441402,
           69.66564706989062,
           69.69875963831356,
           69.72740929820965,
           69.75605895810574,
           69.78470861800183,
           69.81335827789792,
           69.84200793779402,
           69.87065759769011,
           69.8993072575862,
           69.92795691748229,
           69.95660657737838,
           69.98525623727447,
           70.01390589717056,
           70.04255555706666,
           70.07120521696275,
           70.09985487685884,
           70.12850453675495,
           70.15848816608577,
           70.19069508393167,
           70.22290200177757,
           70.25510891962347,
           70.28731583746935,
           70.31952275531526,
           70.35172967316115,
           70.38393659100704,
           70.41614350885294,
           70.44835042669882,
           70.48055734454474,
           70.51276426239062,
           70.54497118023652,
           70.57717809808241,
           70.60938501592831,
           70.64159193377421,
           70.6737988516201,
           70.706005769466,
           70.7382126873119,
           70.7704196051578,
           70.8026265230037,
           70.8348334408496,
           70.86704035869548,
           70.89924727654137,
           70.93145419438727,
           70.96366111223317,
           70.99586803007907,
           71.02807494792495,
           71.06028186577086,
           71.09248878361674,
           71.12469570146264,
           71.15690261930855,
           71.18910953715444,
           71.22131645500033,
           71.25352337284622,
           71.28573029069213,
           71.31793720853801,
           71.35014412638391,
           71.38235104422982,
           71.4145579620757,
           71.4467648799216,
           71.4789717977675,
           71.5111787156134,
           71.5433856334593,
           71.57559255130519,
           71.60779946915109,
           71.64000638699699,
           71.67221330484287,
           71.70442022268877,
           71.73662714053467,
           71.76883405838056,
           71.80104097622646,
           71.83324789407236,
           71.86545481191824,
           71.89766172976414,
           71.92986864761005,
           71.96207556545593,
           71.99428248330183,
           72.02648940114773,
           72.05869631899363,
           72.09090323683952,
           72.12311015468542,
           72.1553170725313,
           72.18752399037722,
           72.2197309082231,
           72.25193782606898,
           72.2841447439149,
           72.00280902995131,
           71.40793068417821,
           70.8130523384052,
           70.21817399263217,
           69.6232956468591,
           69.02841730108607,
           68.43353895531305,
           67.83866060953999,
           67.2437822637669,
           66.64890391799393,
           66.05402557222085,
           65.45914722644778,
           64.86426888067476,
           64.26939053490173,
           63.67451218912865,
           63.07963384335564,
           62.48475549758261,
           61.88987715180954,
           61.29499880603652,
           60.70012046026349,
           60.105242114490416,
           59.51036376871733,
           58.915485422944364,
           58.32060707717129,
           57.72572873139822,
           57.130850385625195,
           56.53597203985217,
           55.94109369407909,
           55.346215348306075,
           54.75133700253305,
           54.156458656759966,
           53.5615803109869,
           52.96670196521392,
           52.371823619440846,
           51.77694527366777,
           51.18206692789475,
           50.587188582121726,
           49.99231023634865,
           49.397431890575625,
           48.802553544802606,
           48.20767519902953,
           47.6127968532565,
           47.017918507483486,
           46.423040161710404,
           45.82816181593733,
           45.23328347016436,
           44.63840512439129,
           44.04352677861821,
           43.44864843284518,
           42.853770087072164,
           42.25889174129909,
           41.66401339552606,
           41.069135049753044,
           40.47425670397997,
           39.879378358206885,
           39.284500012433924,
           38.68962166666084,
           38.094743320887765,
           37.49986497511474,
           36.90498662934172,
           36.310108283568646,
           35.71522993779562,
           35.1203515920226,
           34.52733544393347,
           33.93804376249809,
           33.348752081062706,
           32.75946039962727,
           32.17016871819184,
           31.58087703675651,
           30.991585355321078,
           30.402293673885644,
           29.81300199245026,
           29.223710311014884,
           28.634418629579447,
           28.045126948144066,
           27.455835266708686,
           26.866543585273252,
           26.277251903837872,
           25.687960222402488,
           25.098668540967058,
           24.50937685953162,
           23.92008517809624,
           23.33079349666086,
           22.875286535811565,
           22.687349016134455,
           22.49941149645734,
           22.311473976780217,
           22.12353645710311,
           21.935598937425993,
           21.747661417748873,
           21.559723898071745,
           21.37178637839465,
           21.18384885871752,
           20.995911339040394,
           20.807973819363287,
           20.620036299686177,
           20.43209878000905,
           20.24416126033194,
           20.05622374065483,
           19.8682862209777,
           19.68034870130059,
           19.49241118162348,
           19.304473661946354,
           19.116536142269226,
           18.928598622592112,
           18.740661102915006,
           18.552723583237878,
           18.364786063560768,
           18.17684854388366,
           17.98891102420653,
           17.800973504529424,
           17.61303598485231,
           17.425098465175186,
           17.237160945498054,
           17.049223425820962,
           16.861285906143838,
           16.67334838646671,
           16.4854108667896,
           16.297473347112486,
           16.109535827435362,
           15.921598307758254,
           15.733660788081142,
           15.545723268404014,
           15.357785748726904,
           15.169848229049794,
           14.981910709372666,
           14.79397318969554,
           14.606035670018429,
           14.41865983185638,
           14.232407283327113,
           14.046154734797867,
           13.859902186268616,
           13.673649637739352,
           13.487397089210102,
           13.301144540680857,
           13.114891992151591,
           12.928639443622323,
           12.742386895093095,
           12.55613434656383,
           12.369881798034564,
           12.183629249505316,
           11.997376700976066,
           11.811124152446801,
           11.624871603917557,
           11.438619055388308,
           11.252366506859042,
           11.066113958329794,
           10.879861409800544,
           10.69360886127128,
           10.507356312742015,
           10.321103764212785,
           10.134851215683518,
           9.948598667154252,
           9.762346118625006,
           9.576093570095757,
           9.389841021566493,
           9.203588473037245,
           9.017335924507996,
           8.83108337597873,
           8.644830827449466,
           8.458578278920236,
           8.27232573039097,
           8.086073181861705,
           7.899820633332457,
           7.713568084803208,
           7.527315536273943,
           7.364585295803543,
           7.319466595627264,
           7.274347895450985,
           7.229229195274706,
           7.184110495098435,
           7.138991794922157,
           7.093873094745877,
           7.048754394569606,
           7.003635694393326,
           6.958516994217047,
           6.9133982940407765,
           6.868279593864497,
           6.823160893688218,
           6.778042193511938,
           6.732923493335667,
           6.687804793159388,
           6.642686092983109,
           6.5975673928068375,
           6.552448692630559,
           6.507329992454279,
           6.462211292278009,
           6.41709259210173,
           6.37197389192545,
           6.326855191749178,
           6.2817364915729,
           6.23661779139662,
           6.191499091220342,
           6.146380391044071,
           6.1012616908677915,
           6.056142990691512,
           6.011024290515241,
           5.965905590338961,
           5.920786890162683,
           5.875668189986412,
           5.8305494898101315,
           5.785430789633853,
           5.740312089457574,
           5.695193389281303,
           5.650074689105024,
           5.604955988928745,
           5.56186425317818,
           5.518959935477135,
           5.486417673063488,
           5.4612768787122725,
           5.435854164289886,
           5.409591538334876,
           5.383328912379873,
           5.357066286424864,
           5.330803660469855,
           5.304541034514847,
           5.278278408559843,
           5.2520157826048335,
           5.225753156649826,
           5.199490530694821,
           5.173227904739813,
           5.146965278784804,
           5.1207026528298005,
           5.094440026874791,
           5.068177400919782,
           5.0419147749647735,
           5.01565214900977,
           4.989389523054761,
           4.963126897099753,
           4.936864271144748,
           4.91060164518974,
           4.884339019234732,
           4.8580763932797275,
           4.831813767324718,
           4.80555114136971,
           4.779288515414706,
           4.753025889459697,
           4.7267632635046875,
           4.70050063754968,
           4.674238011594675,
           4.647975385639667,
           4.621712759684658,
           4.5954501337296545,
           4.569187507774645,
           4.542924881819636,
           4.516662255864633,
           4.490399629909624,
           4.464137003954614,
           4.437874377999606,
           4.411611752044602
          ],
          [
           62.00675942974002,
           62.05942324167465,
           62.11208705360926,
           62.16475086554388,
           62.2174146774785,
           62.27007848941312,
           62.322742301347745,
           62.37540611328235,
           62.428069925216974,
           62.4807337371516,
           62.53339754908622,
           62.58606136102084,
           62.638725172955446,
           62.69138898489007,
           62.74405279682469,
           62.79671660875931,
           62.849380420693926,
           62.90204423262855,
           62.95470804456317,
           63.007371856497784,
           63.060035668432405,
           63.11269948036702,
           63.165363292301635,
           63.218027104236256,
           63.27069091617088,
           63.3233547281055,
           63.37601854004012,
           63.42868235197473,
           63.481346163909365,
           63.53400997584397,
           63.586673787778594,
           63.63933759971321,
           63.69200141164782,
           63.74466522358245,
           63.797329035517066,
           63.84999284745168,
           63.9026566593863,
           63.95532047132092,
           64.00798428325555,
           64.06064809519015,
           64.11331190712477,
           64.16597571905939,
           64.21863953099401,
           64.27130334292863,
           64.32396715486325,
           64.37663096679788,
           64.42929477873248,
           64.4819585906671,
           64.53462240260173,
           64.58728621453635,
           64.63995002647097,
           64.69261383840558,
           64.7452776503402,
           64.79781213813969,
           64.85021730185971,
           64.90262246557974,
           64.95502762929976,
           65.00743279301979,
           65.05983795673981,
           65.11224312045984,
           65.16464828417986,
           65.21705344789989,
           65.26945861161991,
           65.32186377533993,
           65.37426893905996,
           65.42667410277997,
           65.4790792665,
           65.53148443022003,
           65.58388959394006,
           65.63629475766007,
           65.6886999213801,
           65.74110508510013,
           65.79351024882016,
           65.84591541254017,
           65.8983205762602,
           65.95072573998021,
           66.00313090370024,
           66.05553606742026,
           66.10794123114029,
           66.16034639486033,
           66.21275155858034,
           66.26515672230036,
           66.31756188602039,
           66.36996704974042,
           66.41282959211102,
           66.45378361021176,
           66.49473762831248,
           66.53569164641321,
           66.57664566451393,
           66.61759968261467,
           66.65855370071539,
           66.69950771881612,
           66.74046173691684,
           66.78141575501758,
           66.82236977311831,
           66.86332379121903,
           66.90427780931977,
           66.9452318274205,
           66.98618584552122,
           67.02713986362195,
           67.06809388172269,
           67.10904789982341,
           67.15000191792414,
           67.19095593602486,
           67.2319099541256,
           67.27286397222632,
           67.31381799032705,
           67.35477200842779,
           67.39572602652851,
           67.43668004462923,
           67.47763406272998,
           67.5185880808307,
           67.55954209893142,
           67.60049611703215,
           67.64163086291217,
           67.68366924838878,
           67.72570763386538,
           67.76774601934198,
           67.8097844048186,
           67.8518227902952,
           67.89386117577182,
           67.93589956124842,
           67.97793794672502,
           68.01997633220164,
           68.06201471767824,
           68.10405310315485,
           68.14609148863146,
           68.18812987410807,
           68.23016825958467,
           68.27220664506127,
           68.31424503053789,
           68.35628341601449,
           68.39832180149111,
           68.44036018696771,
           68.48239857244432,
           68.52443695792093,
           68.56647534339753,
           68.60851372887414,
           68.65055211435075,
           68.69259049982736,
           68.73462888530396,
           68.77666727078056,
           68.81870565625718,
           68.86074404173378,
           68.9027824272104,
           68.944820812687,
           68.98685919816361,
           69.02889758364023,
           69.07093596911682,
           69.11297435459343,
           69.15501274007005,
           69.19705112554665,
           69.23908951102325,
           69.28112789649987,
           69.32316628197647,
           69.36520466745307,
           69.40724305292969,
           69.4492814384063,
           69.49131982388289,
           69.5333582093595,
           69.57539659483612,
           69.61743498031272,
           69.65947336578932,
           69.70151175126594,
           69.74355013674254,
           69.78558852221916,
           69.82762690769576,
           69.86073947611871,
           69.88938913601478,
           69.91803879591089,
           69.94668845580698,
           69.97533811570305,
           70.00398777559917,
           70.03263743549525,
           70.06128709539134,
           70.08993675528743,
           70.11858641518353,
           70.1472360750796,
           70.17588573497571,
           70.20453539487181,
           70.2331850547679,
           70.26183471466399,
           70.29048437456008,
           70.31913403445617,
           70.34778369435226,
           70.37643335424835,
           70.40508301414445,
           70.43373267404053,
           70.46238233393663,
           70.49103199383272,
           70.51968165372881,
           70.54833131362491,
           70.57698097352099,
           70.60563063341709,
           70.63428029331317,
           70.66292995320927,
           70.69157961310536,
           70.72022927300145,
           70.74887893289755,
           70.77752859279364,
           70.80617825268972,
           70.83482791258582,
           70.86490047603161,
           70.89710739387752,
           70.9293143117234,
           70.96152122956929,
           70.9937281474152,
           71.0259350652611,
           71.05814198310699,
           71.09034890095288,
           71.12255581879877,
           71.15476273664467,
           71.18696965449058,
           71.21917657233647,
           71.25138349018236,
           71.28359040802826,
           71.31579732587414,
           71.34800424372004,
           71.38021116156594,
           71.41241807941182,
           71.44462499725773,
           71.47683191510363,
           71.50903883294953,
           71.54124575079543,
           71.57345266864132,
           71.6056595864872,
           71.6378665043331,
           71.670073422179,
           71.70228034002488,
           71.7344872578708,
           71.7666941757167,
           71.79890109356258,
           71.83110801140847,
           71.86331492925439,
           71.89552184710027,
           71.92772876494617,
           71.95993568279206,
           71.99214260063796,
           72.02434951848386,
           72.05655643632976,
           72.08876335417565,
           72.12097027202154,
           72.15317718986745,
           72.18538410771333,
           72.21759102555924,
           72.24979794340511,
           72.28200486125102,
           72.31421177909691,
           72.34641869694282,
           72.37862561478872,
           72.09728990082512,
           71.50241155505203,
           70.90753320927901,
           70.312654863506,
           69.71777651773291,
           69.1228981719599,
           68.52801982618689,
           67.93314148041378,
           67.33826313464071,
           66.74338478886774,
           66.14850644309467,
           65.55362809732159,
           64.95874975154858,
           64.36387140577555,
           63.76899306000247,
           63.174114714229454,
           62.57923636845643,
           61.984358022683345,
           61.38947967691033,
           60.7946013311373,
           60.19972298536423,
           59.60484463959115,
           59.00996629381818,
           58.41508794804511,
           57.82020960227203,
           57.225331256499004,
           56.63045291072599,
           56.03557456495291,
           55.44069621917989,
           54.84581787340686,
           54.25093952763379,
           53.65606118186071,
           53.06118283608774,
           52.46630449031466,
           51.87142614454159,
           51.27654779876857,
           50.681669452995536,
           50.08679110722247,
           49.49191276144944,
           48.897034415676416,
           48.30215606990334,
           47.707277724130314,
           47.1123993783573,
           46.51752103258423,
           45.922642686811145,
           45.327764341038176,
           44.7328859952651,
           44.138007649492025,
           43.543129303719,
           42.94825095794598,
           42.353372612172905,
           41.75849426639988,
           41.16361592062685,
           40.56873757485378,
           39.9738592290807,
           39.37898088330773,
           38.78410253753466,
           38.18922419176158,
           37.594345845988556,
           36.99946750021554,
           36.40458915444246,
           35.809710808669436,
           35.21483246289641,
           34.61995411712334,
           34.013506105986785,
           33.40035989393253,
           32.78721368187823,
           32.17406746982392,
           31.560921257769728,
           30.94777504571542,
           30.33462883366111,
           29.72148262160686,
           29.10833640955261,
           28.495190197498303,
           27.882043985444053,
           27.268897773389803,
           26.655751561335492,
           26.042605349281246,
           25.429459137226992,
           24.81631292517269,
           24.203166713118378,
           23.590020501064128,
           22.976874289009878,
           22.509028459329514,
           22.331783394396922,
           22.154538329464334,
           21.97729326453173,
           21.800048199599143,
           21.622803134666555,
           21.44555806973395,
           21.268313004801346,
           21.091067939868772,
           20.91382287493617,
           20.736577810003563,
           20.559332745070975,
           20.382087680138387,
           20.204842615205784,
           20.027597550273192,
           19.850352485340604,
           19.673107420408,
           19.49586235547541,
           19.318617290542825,
           19.14137222561022,
           18.964127160677613,
           18.786882095745025,
           18.60963703081244,
           18.432391965879834,
           18.255146900947246,
           18.077901836014657,
           17.900520320945198,
           17.71426777241595,
           17.528015223886705,
           17.341762675357437,
           17.155510126828172,
           16.96925757829894,
           16.783005029769676,
           16.59675248124041,
           16.41049993271116,
           16.224247384181915,
           16.03799483565265,
           15.8517422871234,
           15.665489738594154,
           15.479237190064888,
           15.29298464153564,
           15.106732093006395,
           14.920479544477129,
           14.734226995947862,
           14.547974447418614,
           14.361721898889366,
           14.175469350360103,
           13.989216801830853,
           13.802964253301603,
           13.616711704772339,
           13.43045915624309,
           13.244206607713844,
           13.057954059184578,
           12.871701510655312,
           12.685448962126081,
           12.499196413596817,
           12.312943865067552,
           12.126691316538302,
           11.940438768009054,
           11.75418621947979,
           11.567933670950543,
           11.381681122421295,
           11.19542857389203,
           11.00917602536278,
           10.822923476833532,
           10.636670928304268,
           10.450418379775002,
           10.264165831245773,
           10.077913282716509,
           9.89166073418724,
           9.705408185657994,
           9.519155637128744,
           9.33290308859948,
           9.146650540070231,
           8.960397991540985,
           8.774145443011719,
           8.587892894482453,
           8.401640345953222,
           8.215387797423958,
           8.029135248894692,
           7.842882700365445,
           7.656630151836196,
           7.470377603306931,
           7.307647362836531,
           7.262528662660252,
           7.2174099624839725,
           7.172291262307693,
           7.127172562131422,
           7.082053861955143,
           7.036935161778864,
           6.9918164616025935,
           6.946697761426314,
           6.901579061250035,
           6.856460361073763,
           6.811341660897484,
           6.766222960721205,
           6.721104260544926,
           6.675985560368654,
           6.630866860192375,
           6.585748160016096,
           6.540629459839826,
           6.495510759663546,
           6.4503920594872675,
           6.405273359310996,
           6.360154659134716,
           6.315035958958437,
           6.269917258782167,
           6.224798558605887,
           6.181317578295246,
           6.1384132605941994,
           6.0955089428931615,
           6.0526046251921155,
           6.0097003074910695,
           5.966795989790031,
           5.923891672088985,
           5.880987354387939,
           5.8380830366869,
           5.795178718985854,
           5.752274401284808,
           5.709370083583762,
           5.666465765882723,
           5.623561448181678,
           5.580657130480631,
           5.537752812779592,
           5.494848495078546,
           5.462306232664901,
           5.437165438313685,
           5.412024643962466,
           5.386883849611246,
           5.361743055260031,
           5.336602260908812,
           5.311461466557591,
           5.286320672206371,
           5.261179877855156,
           5.236039083503937,
           5.210898289152716,
           5.185757494801502,
           5.160616700450282,
           5.135475906099062,
           5.110335111747847,
           5.085194317396628,
           5.060053523045408,
           5.034433612856718,
           5.008170986901714,
           4.981908360946705,
           4.9556457349916965,
           4.929383109036692,
           4.9031204830816835,
           4.876857857126675,
           4.850595231171671,
           4.824332605216663,
           4.798069979261653,
           4.771807353306649,
           4.745544727351641,
           4.719282101396631,
           4.6930194754416235,
           4.666756849486619,
           4.640494223531611,
           4.614231597576602,
           4.5879689716215974,
           4.56170634566659,
           4.53544371971158,
           4.509181093756577,
           4.482918467801568,
           4.456655841846558,
           4.43039321589155,
           4.404130589936546
          ],
          [
           62.19089902405574,
           62.24356283599036,
           62.296226647924975,
           62.3488904598596,
           62.40155427179422,
           62.45421808372883,
           62.50688189566345,
           62.55954570759807,
           62.61220951953268,
           62.664873331467305,
           62.71753714340193,
           62.77020095533655,
           62.82286476727117,
           62.87552857920579,
           62.9281923911404,
           62.98085620307502,
           63.03352001500964,
           63.08618382694426,
           63.13884763887888,
           63.19151145081349,
           63.244175262748115,
           63.29683907468274,
           63.34950288661735,
           63.40216669855197,
           63.45483051048659,
           63.50749432242121,
           63.56015813435583,
           63.612821946290445,
           63.66548575822507,
           63.71814957015968,
           63.7708133820943,
           63.823477194028925,
           63.87614100596354,
           63.92880481789816,
           63.98146862983277,
           64.0341324417674,
           64.08679625370202,
           64.13920141753523,
           64.19160658125526,
           64.24401174497527,
           64.2964169086953,
           64.34882207241532,
           64.40122723613536,
           64.45363239985537,
           64.50603756357539,
           64.55844272729541,
           64.61084789101545,
           64.66325305473546,
           64.71565821845549,
           64.76806338217551,
           64.82046854589554,
           64.87287370961556,
           64.92527887333559,
           64.97768403705561,
           65.03008920077563,
           65.08249436449566,
           65.13489952821568,
           65.18730469193571,
           65.23970985565572,
           65.29211501937576,
           65.34452018309578,
           65.3969253468158,
           65.44933051053583,
           65.50173567425585,
           65.55414083797588,
           65.6065460016959,
           65.65895116541591,
           65.71135632913595,
           65.76376149285596,
           65.816166656576,
           65.86857182029603,
           65.92097698401604,
           65.97338214773606,
           66.0257873114561,
           66.07819247517612,
           66.13059763889615,
           66.18300280261616,
           66.2354079663362,
           66.28781313005622,
           66.34021829377625,
           66.39262345749627,
           66.44502862121628,
           66.4974337849363,
           66.54983894865633,
           66.59270149102694,
           66.63365550912768,
           66.6746095272284,
           66.71556354532913,
           66.75651756342987,
           66.79747158153059,
           66.83842559963131,
           66.87937961773204,
           66.92033363583278,
           66.96128765393351,
           67.00224167203423,
           67.04319569013497,
           67.08414970823569,
           67.12510372633642,
           67.16605774443714,
           67.20701176253787,
           67.24796578063861,
           67.28891979873933,
           67.32987381684006,
           67.3708278349408,
           67.41178185304152,
           67.45273587114224,
           67.49368988924297,
           67.5346439073437,
           67.57559792544444,
           67.61655194354515,
           67.65750596164588,
           67.69845997974662,
           67.73941399784734,
           67.78036801594807,
           67.8213220340488,
           67.86227605214953,
           67.90323007025026,
           67.944184088351,
           67.98513810645173,
           68.02609212455245,
           68.06704614265317,
           68.1080001607539,
           68.14895417885464,
           68.18990819695536,
           68.23086221505609,
           68.27181623315681,
           68.31277025125753,
           68.35372426935827,
           68.394678287459,
           68.43563230555972,
           68.47658632366046,
           68.51826325381963,
           68.56030163929624,
           68.60234002477284,
           68.64437841024944,
           68.68641679572606,
           68.72845518120266,
           68.77049356667928,
           68.81253195215588,
           68.8545703376325,
           68.8966087231091,
           68.93864710858571,
           68.98068549406231,
           69.02272387953892,
           69.06476226501553,
           69.10680065049213,
           69.14883903596875,
           69.19087742144535,
           69.23291580692197,
           69.27495419239857,
           69.31699257787517,
           69.35903096335178,
           69.4010693488284,
           69.44310773430499,
           69.4851461197816,
           69.52718450525822,
           69.56922289073482,
           69.61126127621144,
           69.65329966168804,
           69.69533804716464,
           69.73737643264126,
           69.77941481811786,
           69.82145320359447,
           69.86349158907107,
           69.90552997454769,
           69.94756836002429,
           69.98960674550091,
           70.02271931392383,
           70.05136897381992,
           70.08001863371601,
           70.10866829361211,
           70.1373179535082,
           70.16596761340429,
           70.1946172733004,
           70.22326693319648,
           70.25191659309257,
           70.28056625298865,
           70.30921591288475,
           70.33786557278084,
           70.36651523267693,
           70.39516489257302,
           70.42381455246912,
           70.45246421236521,
           70.4811138722613,
           70.5097635321574,
           70.53841319205348,
           70.56706285194957,
           70.59571251184566,
           70.62436217174175,
           70.65301183163785,
           70.68166149153394,
           70.71031115143003,
           70.73896081132612,
           70.76761047122221,
           70.79626013111832,
           70.82490979101442,
           70.8535594509105,
           70.88220911080658,
           70.91085877070269,
           70.93950843059878,
           70.96815809049485,
           70.99680775039096,
           71.02545741028703,
           71.05410707018314,
           71.08275673007923,
           71.11140638997531,
           71.14005604987142,
           71.1687057097675,
           71.1973553696636,
           71.22600502955969,
           71.25465468945578,
           71.28330434935187,
           71.31195400924796,
           71.34060366914406,
           71.36925332904015,
           71.39790298893624,
           71.42655264883233,
           71.45520230872842,
           71.4838519686245,
           71.51250162852061,
           71.5411512884167,
           71.57131278597744,
           71.60351970382334,
           71.63572662166924,
           71.66793353951513,
           71.70014045736103,
           71.73234737520693,
           71.76455429305281,
           71.79676121089871,
           71.8289681287446,
           71.8611750465905,
           71.8933819644364,
           71.9255888822823,
           71.95779580012818,
           71.9900027179741,
           72.02220963581998,
           72.05441655366587,
           72.08662347151177,
           72.11883038935767,
           72.15103730720357,
           72.18324422504946,
           72.21545114289535,
           72.24765806074126,
           72.27986497858714,
           72.31207189643304,
           72.34427881427895,
           72.37648573212485,
           72.40869264997073,
           72.44089956781664,
           72.47310648566253,
           72.19177077169894,
           71.59689242592586,
           71.00201408015283,
           70.4071357343798,
           69.81225738860674,
           69.2173790428337,
           68.62250069706069,
           68.0276223512876,
           67.43274400551454,
           66.83786565974157,
           66.24298731396848,
           65.64810896819542,
           65.05323062242239,
           64.45835227664936,
           63.86347393087628,
           63.26859558510327,
           62.673717239330244,
           62.07883889355716,
           61.48396054778414,
           60.889082202011124,
           60.29420385623804,
           59.69932551046496,
           59.104447164692,
           58.50956881891892,
           57.91469047314584,
           57.31981212737282,
           56.7249337815998,
           56.130055435826726,
           55.53517709005369,
           54.940298744280675,
           54.3454203985076,
           53.75054205273453,
           53.155663706961555,
           52.56078536118848,
           51.965907015415404,
           51.37102866964238,
           50.77615032386935,
           50.18127197809628,
           49.58639363232325,
           48.97446528718425,
           48.36131907512994,
           47.7481728630757,
           47.13502665102144,
           46.521880438967145,
           45.90873422691283,
           45.29558801485864,
           44.68244180280433,
           44.06929559075002,
           43.45614937869577,
           42.84300316664152,
           42.22985695458721,
           41.616710742532966,
           41.00356453047871,
           40.39041831842441,
           39.7772721063701,
           39.1641258943159,
           38.550979682261605,
           37.937833470207295,
           37.32468725815304,
           36.71154104609879,
           36.098394834044484,
           35.48524862199023,
           34.872102409935984,
           34.25895619788167,
           33.64580998582743,
           33.03266377377317,
           32.41951756171886,
           31.80637134966456,
           31.193225137610362,
           30.58007892555606,
           29.966932713501752,
           29.3537865014475,
           28.74064028939325,
           28.127494077338945,
           27.51434786528469,
           26.90120165323044,
           26.288055441176134,
           25.674909229121884,
           25.061763017067634,
           24.448616805013323,
           23.83547059295902,
           23.222324380904766,
           22.609178168850516,
           22.141332339170148,
           21.964087274237563,
           21.786842209304975,
           21.609597144372373,
           21.43235207943978,
           21.255107014507196,
           21.077861949574586,
           20.900616884641984,
           20.723371819709413,
           20.546126754776804,
           20.3688816898442,
           20.191636624911613,
           20.014391559979025,
           19.837146495046422,
           19.659901430113834,
           19.482656365181242,
           19.305411300248643,
           19.12816623531605,
           18.950921170383463,
           18.77367610545086,
           18.59643104051825,
           18.419185975585663,
           18.241940910653078,
           18.06469584572047,
           17.887450780787884,
           17.710205715855295,
           17.53296065092269,
           17.355715585990104,
           17.178470521057516,
           17.00122545612491,
           16.823980391192308,
           16.64673532625973,
           16.46949026132713,
           16.292245196394525,
           16.115000131461937,
           15.937755066529348,
           15.760510001596742,
           15.583264936664154,
           15.406019871731568,
           15.228774806798961,
           15.051529741866371,
           14.874284676933787,
           14.697039612001179,
           14.519794547068576,
           14.342549482135988,
           14.165304417203398,
           13.988059352270795,
           13.810814287338205,
           13.633569222405617,
           13.456324157473013,
           13.279079092540425,
           13.101834027607836,
           12.924588962675232,
           12.747343897742628,
           12.570098832810055,
           12.392853767877453,
           12.215608702944847,
           12.038363638012259,
           11.86111857307967,
           11.683873508147066,
           11.506628443214478,
           11.324743189454285,
           11.138490640925019,
           10.95223809239577,
           10.76598554386652,
           10.579732995337256,
           10.393480446807992,
           10.207227898278763,
           10.020975349749497,
           9.834722801220229,
           9.648470252690984,
           9.462217704161734,
           9.27596515563247,
           9.08971260710322,
           8.903460058573975,
           8.717207510044707,
           8.530954961515443,
           8.344702412986212,
           8.158449864456946,
           7.972197315927681,
           7.785944767398433,
           7.599692218869185,
           7.413439670339921,
           7.250709429869521,
           7.205590729693242,
           7.160472029516963,
           7.1153533293406825,
           7.070234629164412,
           7.025115928988133,
           6.979997228811854,
           6.934878528635583,
           6.889759828459303,
           6.8446411282830235,
           6.800770903412319,
           6.757866585711273,
           6.714962268010228,
           6.672057950309181,
           6.629153632608143,
           6.586249314907096,
           6.543344997206051,
           6.5004406795050125,
           6.457536361803966,
           6.4146320441029205,
           6.371727726401883,
           6.328823408700837,
           6.28591909099979,
           6.243014773298752,
           6.200110455597706,
           6.157206137896659,
           6.114301820195613,
           6.071397502494575,
           6.02849318479353,
           5.985588867092483,
           5.942684549391444,
           5.899780231690398,
           5.856875913989352,
           5.813971596288314,
           5.771067278587267,
           5.728162960886221,
           5.6852586431851755,
           5.642354325484137,
           5.599450007783091,
           5.556545690082045,
           5.513641372381007,
           5.47073705467996,
           5.438194792266314,
           5.413053997915099,
           5.38791320356388,
           5.36277240921266,
           5.337631614861445,
           5.3124908205102255,
           5.287350026159006,
           5.262209231807785,
           5.23706843745657,
           5.2119276431053505,
           5.18678684875413,
           5.161646054402915,
           5.136505260051695,
           5.1113644657004755,
           5.08622367134926,
           5.06108287699804,
           5.03594208264682,
           5.010801288295601,
           4.985660493944385,
           4.960519699593165,
           4.9353789052419454,
           4.910238110890731,
           4.885097316539511,
           4.859956522188291,
           4.834815727837076,
           4.809674933485856,
           4.784534139134637,
           4.759393344783421,
           4.734252550432201,
           4.709111756080982,
           4.683970961729761,
           4.658830167378547,
           4.633013061423554,
           4.6067504354685465,
           4.580487809513542,
           4.5542251835585335,
           4.527962557603525,
           4.5016999316485204,
           4.475437305693513,
           4.449174679738503,
           4.422912053783494,
           4.396649427828491
          ],
          [
           62.375038618371455,
           62.42770243030608,
           62.48036624224069,
           62.53303005417531,
           62.585693866109935,
           62.63835767804455,
           62.691021489979164,
           62.743685301913786,
           62.79634911384841,
           62.84901292578303,
           62.90167673771765,
           62.95434054965226,
           63.00700436158688,
           63.0596681735215,
           63.112331985456116,
           63.16499579739074,
           63.21765960932535,
           63.270323421259974,
           63.322987233194596,
           63.37565104512921,
           63.428185533210744,
           63.480590696930776,
           63.53299586065079,
           63.58540102437081,
           63.637806188090835,
           63.690211351810866,
           63.742616515530884,
           63.79502167925091,
           63.84742684297093,
           63.899832006690964,
           63.95223717041099,
           64.004642334131,
           64.05704749785103,
           64.10945266157105,
           64.1618578252911,
           64.2142629890111,
           64.26666815273113,
           64.31907331645115,
           64.37147848017118,
           64.4238836438912,
           64.47628880761123,
           64.52869397133125,
           64.58109913505128,
           64.6335042987713,
           64.68590946249131,
           64.73831462621135,
           64.79071978993137,
           64.8431249536514,
           64.89553011737142,
           64.94793528109145,
           65.00034044481147,
           65.0527456085315,
           65.1051507722515,
           65.15755593597154,
           65.20996109969157,
           65.26236626341158,
           65.3147714271316,
           65.36717659085164,
           65.41958175457165,
           65.47198691829168,
           65.5243920820117,
           65.57679724573174,
           65.62920240945175,
           65.68160757317177,
           65.7340127368918,
           65.78641790061184,
           65.83882306433185,
           65.89122822805187,
           65.9436333917719,
           65.99603855549192,
           66.04844371921195,
           66.10084888293197,
           66.153254046652,
           66.20565921037202,
           66.25806437409204,
           66.31046953781207,
           66.36287470153209,
           66.4152798652521,
           66.46768502897213,
           66.52009019269215,
           66.57249535641219,
           66.62490052013221,
           66.67730568385223,
           66.72971084757226,
           66.77257338994286,
           66.8135274080436,
           66.85448142614433,
           66.89543544424505,
           66.93638946234577,
           66.9773434804465,
           67.01829749854724,
           67.05925151664796,
           67.1002055347487,
           67.14115955284942,
           67.18211357095015,
           67.22306758905088,
           67.2640216071516,
           67.30497562525234,
           67.34592964335306,
           67.3868836614538,
           67.42783767955453,
           67.46879169765526,
           67.50974571575598,
           67.55069973385672,
           67.59165375195744,
           67.63260777005817,
           67.6735617881589,
           67.71451580625961,
           67.75546982436035,
           67.79642384246108,
           67.83737786056182,
           67.87833187866254,
           67.91928589676326,
           67.96023991486399,
           68.00119393296472,
           68.04214795106544,
           68.08310196916618,
           68.12405598726691,
           68.16501000536763,
           68.20596402346837,
           68.2469180415691,
           68.28787205966984,
           68.32882607777054,
           68.36978009587128,
           68.41073411397201,
           68.45168813207275,
           68.49264215017347,
           68.53359616827419,
           68.57455018637492,
           68.61550420447566,
           68.65645822257638,
           68.69741224067711,
           68.73836625877784,
           68.77932027687856,
           68.82027429497928,
           68.86122831308002,
           68.90218233118075,
           68.94313634928147,
           68.98409036738221,
           69.02504438548294,
           69.06599840358366,
           69.10695242168438,
           69.14790643978513,
           69.18886045788585,
           69.22981447598657,
           69.2707684940873,
           69.31172251218804,
           69.35285725925048,
           69.3948956447271,
           69.4369340302037,
           69.47897241568032,
           69.52101080115692,
           69.56304918663352,
           69.60508757211014,
           69.64712595758675,
           69.68916434306335,
           69.73120272853996,
           69.77324111401657,
           69.81527949949317,
           69.85731788496977,
           69.89935627044639,
           69.94139465592299,
           69.9834330413996,
           70.02547142687621,
           70.06750981235282,
           70.10954819782943,
           70.15158658330603,
           70.18469915172898,
           70.21334881162505,
           70.24199847152116,
           70.27064813141723,
           70.29929779131334,
           70.32794745120943,
           70.35659711110551,
           70.38524677100162,
           70.41389643089771,
           70.4425460907938,
           70.47119575068989,
           70.49984541058598,
           70.52849507048207,
           70.55714473037816,
           70.58579439027424,
           70.61444405017035,
           70.64309371006644,
           70.67174336996253,
           70.70039302985863,
           70.72904268975472,
           70.7576923496508,
           70.7863420095469,
           70.814991669443,
           70.84364132933908,
           70.87229098923517,
           70.90094064913126,
           70.92959030902736,
           70.95823996892345,
           70.98688962881954,
           71.01553928871563,
           71.0441889486117,
           71.07283860850781,
           71.10148826840391,
           71.13013792829999,
           71.15878758819609,
           71.18743724809218,
           71.21608690798828,
           71.24473656788436,
           71.27338622778045,
           71.30203588767654,
           71.33068554757263,
           71.35933520746872,
           71.38798486736482,
           71.41663452726091,
           71.445284187157,
           71.47393384705309,
           71.5025835069492,
           71.53123316684528,
           71.55988282674137,
           71.58853248663748,
           71.61718214653357,
           71.64583180642964,
           71.67448146632574,
           71.70313112622182,
           71.73178078611792,
           71.76043044601401,
           71.7890801059101,
           71.81772976580619,
           71.8463794257023,
           71.87502908559838,
           71.90367874549447,
           71.93232840539056,
           71.96097806528667,
           71.98962772518274,
           72.01827738507883,
           72.04692704497494,
           72.07557670487103,
           72.10422636476711,
           72.1328760246632,
           72.1615256845593,
           72.19017534445538,
           72.21882500435149,
           72.24747466424756,
           72.27772509592327,
           72.30993201376916,
           72.34213893161507,
           72.37434584946097,
           72.40655276730685,
           72.43875968515275,
           72.47096660299866,
           72.50317352084454,
           72.53538043869045,
           72.56758735653634,
           72.28625164257274,
           71.69137329679967,
           71.09649495102664,
           70.50161660525362,
           69.90673825948055,
           69.31185991370752,
           68.7169815679345,
           68.12210322216143,
           67.52722487638835,
           66.93234653061538,
           66.3374681848423,
           65.74258983906921,
           65.1477114932962,
           64.54857068043597,
           63.93542446838166,
           63.32227825632742,
           62.70913204427316,
           62.09598583221886,
           61.482839620164604,
           60.86969340811036,
           60.25654719605605,
           59.643400984001744,
           59.03025477194755,
           58.41710855989324,
           57.80396234783893,
           57.19081613578468,
           56.57766992373044,
           55.96452371167613,
           55.351377499621876,
           54.73823128756762,
           54.12508507551332,
           53.51193886345901,
           52.89879265140482,
           52.28564643935051,
           51.672500227296204,
           51.05935401524195,
           50.4462078031877,
           49.83306159113339,
           49.21991537907915,
           48.60676916702489,
           47.99362295497059,
           47.380476742916336,
           46.76733053086208,
           46.15418431880778,
           45.54103810675347,
           44.92789189469927,
           44.31474568264497,
           43.70159947059066,
           43.08845325853641,
           42.47530704648216,
           41.862160834427854,
           41.24901462237361,
           40.635868410319354,
           40.02272219826505,
           39.40957598621074,
           38.79642977415654,
           38.18328356210223,
           37.57013735004793,
           36.956991137993676,
           36.34384492593943,
           35.73069871388512,
           35.11755250183087,
           34.504406289776625,
           33.891260077722315,
           33.27811386566806,
           32.664967653613814,
           32.051821441559504,
           31.438675229505193,
           30.825529017451004,
           30.212382805396697,
           29.59923659334239,
           28.986090381288136,
           28.37294416923389,
           27.75979795717958,
           27.14665174512533,
           26.53350553307108,
           25.92035932101677,
           25.307213108962518,
           24.694066896908268,
           24.080920684853965,
           23.467774472799654,
           22.854628260745404,
           22.241482048691154,
           21.773636219010786,
           21.5963911540782,
           21.419146089145613,
           21.241901024213007,
           21.06465595928042,
           20.887410894347834,
           20.710165829415228,
           20.532920764482622,
           20.355675699550048,
           20.178430634617445,
           20.00118556968484,
           19.82394050475225,
           19.646695439819663,
           19.46945037488706,
           19.29220530995447,
           19.114960245021884,
           18.937715180089278,
           18.76047011515669,
           18.5832250502241,
           18.4059799852915,
           18.228734920358892,
           18.051489855426304,
           17.874244790493712,
           17.69699972556111,
           17.51975466062852,
           17.34250959569593,
           17.16526453076333,
           16.98801946583074,
           16.81077440089815,
           16.633529335965548,
           16.456284271032942,
           16.279039206100375,
           16.1030354367678,
           15.927941922092494,
           15.7528484074172,
           15.57775489274191,
           15.402661378066604,
           15.22756786339131,
           15.052474348716022,
           14.877380834040714,
           14.702287319365427,
           14.527193804690132,
           14.352100290014825,
           14.177006775339517,
           14.001913260664228,
           13.826819745988935,
           13.651726231313628,
           13.476632716638338,
           13.301539201963047,
           13.12644568728774,
           12.951352172612449,
           12.776258657937158,
           12.60116514326185,
           12.426071628586545,
           12.25097811391127,
           12.075884599235962,
           11.900791084560655,
           11.725697569885364,
           11.550604055210073,
           11.375510540534766,
           11.200417025859476,
           11.025323511184185,
           10.850229996508876,
           10.675136481833587,
           10.500042967158297,
           10.324949452482988,
           10.14985593780768,
           9.974762423132406,
           9.799668908457098,
           9.624575393781793,
           9.4494818791065,
           9.27438836443121,
           9.099294849755903,
           8.924201335080612,
           8.749107820405321,
           8.574014305730014,
           8.398920791054707,
           8.223827276379431,
           8.048733761704124,
           7.873640247028816,
           7.6985467323535275,
           7.523453217678235,
           7.348359703002929,
           7.195631927585547,
           7.1547328484576,
           7.113833769329653,
           7.072934690201706,
           7.032035611073766,
           6.991136531945819,
           6.948680544154625,
           6.905777412966293,
           6.862874281777952,
           6.819971150589612,
           6.77706801940128,
           6.734164888212939,
           6.6912617570245985,
           6.648358625836258,
           6.605455494647927,
           6.562552363459588,
           6.519649232271247,
           6.476746101082914,
           6.433842969894574,
           6.390939838706235,
           6.3480367075179025,
           6.3051335763295615,
           6.2622304451412205,
           6.219327313952889,
           6.176424182764549,
           6.133521051576208,
           6.090617920387869,
           6.047714789199537,
           6.004811658011197,
           5.961908526822857,
           5.9190053956345245,
           5.876102264446184,
           5.833199133257844,
           5.790296002069512,
           5.747392870881171,
           5.704489739692832,
           5.661586608504491,
           5.618683477316159,
           5.575780346127819,
           5.532877214939479,
           5.489974083751147,
           5.4470709525628065,
           5.414528492397044,
           5.389386511533122,
           5.364244530669197,
           5.33910254980527,
           5.313960568941349,
           5.288818588077422,
           5.2636766072134975,
           5.238534626349572,
           5.2133926454856505,
           5.188250664621724,
           5.163108683757798,
           5.137966702893877,
           5.112824722029952,
           5.0876827411660255,
           5.062540760302104,
           5.0373987794381785,
           5.012256798574253,
           4.987114817710327,
           4.961972836846406,
           4.93683085598248,
           4.911688875118554,
           4.886546894254633,
           4.861404913390707,
           4.836262932526782,
           4.81112095166286,
           4.785978970798935,
           4.760836989935009,
           4.735695009071088,
           4.710553028207161,
           4.685411047343236,
           4.66026906647931,
           4.635127085615388,
           4.609985104751463,
           4.584843123887537,
           4.5597011430236165,
           4.534559162159691,
           4.509817911005882,
           4.48570400550408,
           4.461590100002274,
           4.437476194500467,
           4.413362288998661,
           4.3892483834968585
          ],
          [
           62.55917821268718,
           62.6118420246218,
           62.664505836556415,
           62.71716964849103,
           62.76957481260629,
           62.82197997632632,
           62.874385140046336,
           62.92679030376635,
           62.979195467486385,
           63.03160063120641,
           63.08400579492644,
           63.13641095864645,
           63.188816122366475,
           63.241221286086514,
           63.29362644980654,
           63.346031613526556,
           63.39843677724657,
           63.450841940966605,
           63.503247104686636,
           63.55565226840665,
           63.60805743212667,
           63.660462595846695,
           63.71286775956672,
           63.765272923286744,
           63.81767808700677,
           63.87008325072679,
           63.922488414446825,
           63.974893578166835,
           64.02729874188688,
           64.07970390560689,
           64.13210906932692,
           64.18451423304694,
           64.23691939676695,
           64.28932456048699,
           64.34172972420701,
           64.39413488792704,
           64.44654005164706,
           64.49894521536709,
           64.55135037908713,
           64.60375554280714,
           64.65616070652715,
           64.70856587024718,
           64.76097103396721,
           64.81337619768723,
           64.86578136140724,
           64.91818652512728,
           64.9705916888473,
           65.02299685256733,
           65.07540201628734,
           65.12780718000738,
           65.18021234372739,
           65.23261750744743,
           65.28502267116744,
           65.33742783488748,
           65.38983299860749,
           65.44223816232751,
           65.49464332604754,
           65.54704848976758,
           65.59945365348759,
           65.65185881720761,
           65.70426398092764,
           65.75666914464766,
           65.80907430836768,
           65.86147947208771,
           65.91388463580773,
           65.96628979952774,
           66.01869496324777,
           66.0711001269678,
           66.12350529068783,
           66.17591045440784,
           66.22831561812787,
           66.28072078184789,
           66.33312594556793,
           66.38553110928794,
           66.43793627300796,
           66.49034143672799,
           66.54274660044801,
           66.59515176416804,
           66.64755692788806,
           66.69996209160809,
           66.75236725532811,
           66.80477241904813,
           66.85717758276816,
           66.90958274648818,
           66.9524452888588,
           66.99339930695953,
           67.03435332506025,
           67.07530734316099,
           67.1162613612617,
           67.15721537936244,
           67.19816939746318,
           67.2391234155639,
           67.28007743366462,
           67.32103145176535,
           67.36198546986608,
           67.4029394879668,
           67.44389350606755,
           67.48484752416827,
           67.525801542269,
           67.56675556036973,
           67.60770957847046,
           67.6486635965712,
           67.68961761467192,
           67.73057163277264,
           67.77152565087337,
           67.8124796689741,
           67.85343368707483,
           67.89438770517556,
           67.93534172327628,
           67.97629574137702,
           68.01724975947774,
           68.05820377757847,
           68.09915779567919,
           68.14011181377992,
           68.18106583188066,
           68.22201984998138,
           68.26297386808211,
           68.30392788618283,
           68.34488190428357,
           68.3858359223843,
           68.42678994048504,
           68.46774395858574,
           68.50869797668648,
           68.54965199478721,
           68.59060601288795,
           68.63156003098867,
           68.67251404908939,
           68.71346806719012,
           68.75442208529086,
           68.79537610339158,
           68.83633012149231,
           68.87728413959304,
           68.91823815769376,
           68.9591921757945,
           69.00014619389523,
           69.04110021199595,
           69.08205423009667,
           69.12300824819741,
           69.16396226629814,
           69.20491628439886,
           69.2458703024996,
           69.28682432060033,
           69.32777833870105,
           69.36873235680179,
           69.40968637490252,
           69.45064039300324,
           69.49159441110396,
           69.53254842920471,
           69.57350244730543,
           69.61445646540615,
           69.65541048350688,
           69.6963645016076,
           69.73731851970834,
           69.77827253780907,
           69.8192265559098,
           69.86018057401051,
           69.90113459211126,
           69.94208861021198,
           69.9830426283127,
           70.02399664641345,
           70.06495066451417,
           70.10590468261489,
           70.14685870071564,
           70.18781271881636,
           70.22948965015796,
           70.27152803563457,
           70.31356642111118,
           70.34667898953411,
           70.3753286494302,
           70.40397830932629,
           70.43262796922238,
           70.46127762911847,
           70.48992728901456,
           70.51857694891066,
           70.54722660880674,
           70.57587626870284,
           70.60452592859895,
           70.63317558849502,
           70.66182524839111,
           70.69047490828721,
           70.7191245681833,
           70.7477742280794,
           70.77642388797548,
           70.80507354787157,
           70.83372320776768,
           70.86237286766377,
           70.89102252755985,
           70.91967218745593,
           70.94832184735203,
           70.97697150724812,
           71.0048829384931,
           71.03242523430892,
           71.05996753012474,
           71.08750982594056,
           71.11505212175638,
           71.1425944175722,
           71.17013671338802,
           71.19767900920382,
           71.22522130501964,
           71.25276360083546,
           71.28030589665127,
           71.3078481924671,
           71.33539048828293,
           71.36293278409873,
           71.39047507991457,
           71.41801737573037,
           71.44555967154619,
           71.47310196736201,
           71.50064426317785,
           71.52818655899365,
           71.55572885480947,
           71.5832711506253,
           71.6108134464411,
           71.63835574225692,
           71.66589803807275,
           71.69344033388856,
           71.7209826297044,
           71.7485249255202,
           71.77606722133602,
           71.80360951715184,
           71.83115181296766,
           71.85869410878348,
           71.8862364045993,
           71.91377870041512,
           71.94132099623096,
           71.96886329204676,
           71.99640558786258,
           72.0239478836784,
           72.05149017949421,
           72.07903247531004,
           72.10657477112585,
           72.13411706694167,
           72.16165936275749,
           72.18920165857331,
           72.21674395438913,
           72.24428625020496,
           72.27182854602077,
           72.29937084183659,
           72.32691313765241,
           72.35445543346823,
           72.38199772928405,
           72.40954002509986,
           72.43708232091568,
           72.4646246167315,
           72.49216691254733,
           72.51970920836312,
           72.54725150417896,
           72.57479379999477,
           72.6023360958106,
           72.62987839162642,
           72.33098559051376,
           71.70565769247264,
           71.08032979443159,
           70.45500189639051,
           69.8296739983494,
           69.20434610030834,
           68.57901820226728,
           67.95369030422616,
           67.32836240618504,
           66.70303450814401,
           66.07770661010291,
           65.45237871206179,
           64.82705081402072,
           64.20172291597966,
           63.57639501793854,
           62.95967912232255,
           62.34656820099363,
           61.73345727966468,
           61.120346358335766,
           60.507235437006855,
           59.89412451567789,
           59.28101359434892,
           58.66790267302007,
           58.054791751691106,
           57.441680830362145,
           56.828569909033234,
           56.21545898770433,
           55.60234806637536,
           54.98923714504645,
           54.37612622371754,
           53.763015302388574,
           53.149904381059606,
           52.53679345973076,
           51.923682538401785,
           51.31057161707283,
           50.69746069574392,
           50.08434977441501,
           49.47123885308604,
           48.85812793175714,
           48.24501701042823,
           47.63190608909926,
           47.01879516777036,
           46.40568424644144,
           45.792573325112485,
           45.17946240378351,
           44.56635148245466,
           43.953240561125696,
           43.34012963979673,
           42.72701871846782,
           42.11390779713891,
           41.50079687580995,
           40.88768595448104,
           40.27457503315213,
           39.661464111823165,
           39.0483531904942,
           38.43524226916534,
           37.82213134783638,
           37.209020426507415,
           36.595909505178504,
           35.9827985838496,
           35.36968766252063,
           34.75657674119172,
           34.14346581986281,
           33.530354898533844,
           32.91724397720494,
           32.30413305587603,
           31.691022134547065,
           31.077911213218098,
           30.464800291889247,
           29.85168937056028,
           29.23857844923132,
           28.62546752790241,
           28.012356606573498,
           27.39924568524453,
           26.786134763915623,
           26.173023842586716,
           25.55991292125775,
           24.946801999928844,
           24.333691078599934,
           23.720580157270966,
           23.107469235942006,
           22.494358314613095,
           21.881247393284184,
           21.416923621050557,
           21.250174147007503,
           21.083424672964448,
           20.916675198921375,
           20.74992572487832,
           20.583176250835262,
           20.416426776792193,
           20.24967730274912,
           20.08292782870608,
           19.91617835466301,
           19.749428880619938,
           19.58267940657688,
           19.415929932533828,
           19.249180458490756,
           19.0824309844477,
           18.915681510404646,
           18.74893203636157,
           18.582182562318515,
           18.41543308827546,
           18.24868361423239,
           18.081934140189315,
           17.91518466614626,
           17.748435192103205,
           17.581685718060136,
           17.414936244017078,
           17.248186769974023,
           17.081437295930954,
           16.914687821887895,
           16.74793834784484,
           16.574663401575954,
           16.399569886900647,
           16.224476372225368,
           16.049382857550068,
           15.874289342874757,
           15.69919582819947,
           15.524102313524178,
           15.34900879884887,
           15.173915284173578,
           14.998821769498285,
           14.823728254822978,
           14.648634740147688,
           14.473541225472399,
           14.298447710797092,
           14.123354196121785,
           13.948260681446492,
           13.773167166771202,
           13.598073652095895,
           13.422980137420602,
           13.247886622745312,
           13.072793108070005,
           12.897699593394716,
           12.722606078719425,
           12.547512564044117,
           12.372419049368808,
           12.197325534693533,
           12.022232020018226,
           11.847138505342919,
           11.672044990667631,
           11.49695147599234,
           11.321857961317033,
           11.14676444664174,
           10.97167093196645,
           10.796577417291143,
           10.62148390261585,
           10.446390387940562,
           10.271296873265253,
           10.096203358589948,
           9.921109843914671,
           9.746016329239364,
           9.570922814564057,
           9.395829299888765,
           9.220735785213474,
           9.04564227053817,
           8.870548755862881,
           8.695455241187588,
           8.520361726512279,
           8.345268211836972,
           8.170174697161697,
           7.995081182486389,
           7.819987667811082,
           7.6448941531357955,
           7.4698006384605025,
           7.294707123785194,
           7.141979348367814,
           7.101080269239866,
           7.060181190111918,
           7.019282110983973,
           6.9783830318560325,
           6.937483952728085,
           6.896584873600137,
           6.855685794472198,
           6.814786715344251,
           6.773887636216303,
           6.732988557088364,
           6.692089477960416,
           6.651190398832468,
           6.610291319704521,
           6.569392240576581,
           6.528493161448635,
           6.487594082320688,
           6.4466950031927475,
           6.405795924064801,
           6.364896844936853,
           6.3239977658089135,
           6.282147840986514,
           6.239244709798175,
           6.196341578609842,
           6.153438447421502,
           6.110535316233162,
           6.067632185044822,
           6.02472905385649,
           5.9818259226681505,
           5.9389227914798095,
           5.8960196602914765,
           5.853116529103137,
           5.810213397914797,
           5.767310266726465,
           5.724407135538124,
           5.681504004349785,
           5.638600873161444,
           5.595697741973113,
           5.552794610784771,
           5.509891479596432,
           5.466988348408099,
           5.424085217219759,
           5.391542757053997,
           5.3664007761900745,
           5.341258795326149,
           5.316116814462223,
           5.290974833598302,
           5.265832852734376,
           5.24069087187045,
           5.215548891006525,
           5.190406910142603,
           5.165264929278677,
           5.140122948414752,
           5.11498096755083,
           5.089838986686905,
           5.064697005822978,
           5.039555024959057,
           5.014413044095132,
           4.989271063231206,
           4.96412908236728,
           4.938987101503359,
           4.913845120639433,
           4.888703139775507,
           4.864272797913147,
           4.84015889241134,
           4.816044986909534,
           4.791931081407732,
           4.767817175905925,
           4.743703270404119,
           4.719589364902317,
           4.695475459400511,
           4.671361553898704,
           4.647247648396897,
           4.623133742895095,
           4.599019837393288,
           4.574905931891482,
           4.550792026389679,
           4.526678120887873,
           4.502564215386067,
           4.4784503098842645,
           4.454336404382459,
           4.430222498880651,
           4.406108593378844,
           4.381994687877043
          ],
          [
           62.72808399644214,
           62.78048916016216,
           62.83289432388219,
           62.88529948760222,
           62.937704651322235,
           62.99010981504226,
           63.04251497876229,
           63.094920142482316,
           63.14732530620233,
           63.19973046992236,
           63.25213563364238,
           63.304540797362414,
           63.35694596108244,
           63.409351124802456,
           63.46175628852248,
           63.514161452242504,
           63.566566615962536,
           63.61897177968255,
           63.67137694340258,
           63.7237821071226,
           63.77618727084263,
           63.82859243456265,
           63.88099759828267,
           63.9334027620027,
           63.985807925722725,
           64.03821308944273,
           64.09061825316277,
           64.14302341688278,
           64.19542858060282,
           64.24783374432285,
           64.30023890804286,
           64.35264407176288,
           64.40504923548292,
           64.45745439920293,
           64.50985956292295,
           64.56226472664298,
           64.614669890363,
           64.66707505408303,
           64.71948021780305,
           64.77188538152308,
           64.8242905452431,
           64.87669570896313,
           64.92910087268315,
           64.98150603640318,
           65.0339112001232,
           65.08631636384322,
           65.13872152756325,
           65.19112669128327,
           65.2435318550033,
           65.29593701872332,
           65.34834218244335,
           65.40074734616337,
           65.4531525098834,
           65.50555767360342,
           65.55796283732344,
           65.61036800104347,
           65.6627731647635,
           65.71517832848352,
           65.76758349220354,
           65.81998865592357,
           65.87239381964359,
           65.92479898336362,
           65.97720414708364,
           66.02960931080366,
           66.08201447452369,
           66.1344196382437,
           66.18682480196372,
           66.23922996568376,
           66.29163512940379,
           66.3440402931238,
           66.39635301304585,
           66.44848084413044,
           66.50060867521505,
           66.55273650629965,
           66.60486433738426,
           66.65699216846886,
           66.70911999955345,
           66.76124783063806,
           66.81337566172266,
           66.86550349280726,
           66.91763132389187,
           66.96975915497647,
           67.02188698606106,
           67.07401481714567,
           67.11683113741037,
           67.1577851555111,
           67.19873917361183,
           67.23969319171256,
           67.28064720981328,
           67.32160122791402,
           67.36255524601474,
           67.40350926411547,
           67.4444632822162,
           67.48541730031693,
           67.52637131841766,
           67.56732533651838,
           67.60827935461911,
           67.64923337271985,
           67.69018739082057,
           67.7311414089213,
           67.77209542702202,
           67.81304944512276,
           67.85400346322349,
           67.89495748132421,
           67.93591149942495,
           67.97686551752567,
           68.0178195356264,
           68.05877355372712,
           68.09972757182786,
           68.14068158992858,
           68.18163560802931,
           68.22258962613004,
           68.26354364423077,
           68.3044976623315,
           68.34545168043223,
           68.38640569853295,
           68.42735971663369,
           68.46831373473441,
           68.50926775283514,
           68.55022177093588,
           68.5911757890366,
           68.63212980713733,
           68.67308382523805,
           68.71403784333879,
           68.75499186143952,
           68.79594587954024,
           68.83689989764096,
           68.8778539157417,
           68.91880793384243,
           68.95976195194315,
           69.00071597004388,
           69.0416699881446,
           69.08262400624534,
           69.12357802434607,
           69.16453204244681,
           69.20548606054753,
           69.24644007864825,
           69.28739409674898,
           69.32834811484972,
           69.36930213295045,
           69.41025615105117,
           69.45121016915189,
           69.49216418725263,
           69.53311820535336,
           69.5740722234541,
           69.61502624155482,
           69.65598025965554,
           69.69693427775627,
           69.737888295857,
           69.77884231395772,
           69.81979633205844,
           69.86075035015918,
           69.90170436825991,
           69.94249031954176,
           69.98243592770098,
           70.0223815358602,
           70.06232714401942,
           70.10227275217862,
           70.14221836033785,
           70.18216396849706,
           70.22210957665628,
           70.2620551848155,
           70.30200079297471,
           70.34194640113392,
           70.38189200929314,
           70.42183761745235,
           70.46178322561157,
           70.48991191677672,
           70.51213214944482,
           70.53435238211293,
           70.55657261478103,
           70.57879284744915,
           70.60101308011726,
           70.62323331278536,
           70.64545354545346,
           70.6676737781216,
           70.6898940107897,
           70.71211424345779,
           70.7343344761259,
           70.75655470879401,
           70.77877494146213,
           70.80099517413024,
           70.82321540679834,
           70.84543563946644,
           70.86765587213456,
           70.88987610480267,
           70.91661203547963,
           70.94415433129545,
           70.97169662711127,
           70.99923892292708,
           71.02678121874291,
           71.05432351455873,
           71.08186581037455,
           71.10940810619036,
           71.13695040200619,
           71.164492697822,
           71.19203499363783,
           71.21957728945364,
           71.24711958526947,
           71.27466188108528,
           71.3022041769011,
           71.32974647271692,
           71.35728876853273,
           71.38483106434856,
           71.41237336016437,
           71.43991565598019,
           71.467457951796,
           71.49500024761184,
           71.52254254342765,
           71.55008483924347,
           71.57762713505929,
           71.60516943087512,
           71.63271172669093,
           71.66025402250675,
           71.68779631832257,
           71.71533861413837,
           71.74288090995421,
           71.77042320577002,
           71.79796550158584,
           71.82550779740166,
           71.85305009321748,
           71.8805923890333,
           71.90813468484912,
           71.93567698066494,
           71.96321927648076,
           71.99076157229658,
           72.0183038681124,
           72.04584616392822,
           72.07338845974402,
           72.10093075555986,
           72.12847305137566,
           72.15601534719148,
           72.1835576430073,
           72.21109993882312,
           72.23864223463895,
           72.26618453045477,
           72.29372682627059,
           72.3212691220864,
           72.34881141790221,
           72.37635371371803,
           72.40389600953385,
           72.43143830534967,
           72.45898060116549,
           72.48652289698131,
           72.51406519279713,
           72.54160748861295,
           72.56914978442877,
           72.5966920802446,
           72.6242343760604,
           72.65177667187623,
           72.35288387076358,
           71.72755597272244,
           71.1022280746814,
           70.47690017664033,
           69.85157227859922,
           69.22624438055816,
           68.60091648251708,
           67.97558858447596,
           67.35026068643485,
           66.72493278839384,
           66.09960489035272,
           65.47427699231162,
           64.84894909427054,
           64.22362119622946,
           63.598293298188345,
           62.972965400147295,
           62.34763750210624,
           61.722309604065124,
           61.09698170602405,
           60.47165380798298,
           59.84632590994187,
           59.22099801190075,
           58.59567011385975,
           57.970342215818626,
           57.3450143177775,
           56.71968641973643,
           56.094358521695376,
           55.469030623654255,
           54.8437027256132,
           54.21837482757213,
           53.593046929531006,
           52.967719031489885,
           52.342391133448885,
           51.717063235407764,
           51.09173533736665,
           50.46640743932558,
           49.841079541284515,
           49.2157516432434,
           48.59042374520233,
           47.965095847161265,
           47.33976794912015,
           46.71444005107909,
           46.08911215303802,
           45.46378425499691,
           44.83845635695578,
           44.21312845891478,
           43.595110744336864,
           42.9819998230079,
           42.368888901678986,
           41.75577798035008,
           41.142667059021115,
           40.529556137692204,
           39.9164452163633,
           39.30333429503433,
           38.690223373705365,
           38.07711245237651,
           37.46400153104755,
           36.85089060971858,
           36.23777968838968,
           35.62466876706077,
           35.0115578457318,
           34.39844692440289,
           33.78533600307398,
           33.17222508174502,
           32.55911416041611,
           31.9460032390872,
           31.332892317758233,
           30.71978139642927,
           30.10667047510042,
           29.49355955377145,
           28.880448632442487,
           28.267337711113576,
           27.654226789784666,
           27.041115868455705,
           26.428004947126794,
           25.814894025797884,
           25.201783104468923,
           24.588672183140012,
           23.9755612618111,
           23.362450340482138,
           22.749339419153173,
           22.136228497824263,
           21.523117576495356,
           21.058793804261725,
           20.89204433021867,
           20.725294856175616,
           20.558545382132543,
           20.391795908089488,
           20.225046434046433,
           20.05829696000336,
           19.891547485960288,
           19.72479801191725,
           19.55804853787418,
           19.391299063831106,
           19.22454958978805,
           19.057800115744996,
           18.891050641701923,
           18.72430116765887,
           18.557551693615814,
           18.39080221957274,
           18.224052745529686,
           18.057303271486628,
           17.890553797443555,
           17.723804323400486,
           17.55705484935743,
           17.390305375314377,
           17.223555901271304,
           17.05680642722825,
           16.890056953185194,
           16.72330747914212,
           16.556558005099063,
           16.38980853105601,
           16.22305905701294,
           16.056309582969867,
           15.889560108926826,
           15.722810634883755,
           15.556061160840683,
           15.389311686797628,
           15.222562212754571,
           15.0558127387115,
           14.889063264668446,
           14.722313790625389,
           14.555564316582315,
           14.38881484253926,
           14.222065368496203,
           14.055315894453132,
           13.888566420410061,
           13.721816946367005,
           13.55506747232395,
           13.388317998280877,
           13.22156852423782,
           13.054819050194766,
           12.888069576151695,
           12.721320102108638,
           12.554570628065584,
           12.387821154022511,
           12.22107167997944,
           12.0543222059364,
           11.887572731893329,
           11.720823257850258,
           11.554073783807201,
           11.387324309764146,
           11.220574835721074,
           11.053825361678019,
           10.887075887634962,
           10.720326413591891,
           10.553576939548837,
           10.386827465505778,
           10.217644294047522,
           10.042550779372213,
           9.867457264696938,
           9.692363750021634,
           9.517270235346324,
           9.342176720671034,
           9.167083205995743,
           8.991989691320438,
           8.816896176645145,
           8.641802661969853,
           8.466709147294548,
           8.29161563261924,
           8.116522117943965,
           7.941428603268658,
           7.766335088593351,
           7.5912415739180625,
           7.41614805924277,
           7.241054544567462,
           7.088326769150081,
           7.047427690022133,
           7.006528610894186,
           6.965629531766239,
           6.924730452638299,
           6.883831373510352,
           6.842932294382404,
           6.802033215254465,
           6.761134136126518,
           6.720235056998571,
           6.679335977870631,
           6.638436898742683,
           6.597537819614736,
           6.556638740486789,
           6.5157396613588485,
           6.474840582230902,
           6.433941503102955,
           6.393042423975016,
           6.352143344847069,
           6.311244265719122,
           6.270345186591181,
           6.229446107463234,
           6.188547028335287,
           6.147647949207347,
           6.106748870079399,
           6.065849790951452,
           6.0249507118235055,
           5.984051632695565,
           5.943152553567618,
           5.902253474439671,
           5.86135439531173,
           5.820455316183784,
           5.779556237055837,
           5.738657157927896,
           5.69775807879995,
           5.656858999672002,
           5.615615137818398,
           5.572712006630066,
           5.529808875441725,
           5.486905744253386,
           5.444002613065053,
           5.401099481876713,
           5.36855702171095,
           5.343415040847028,
           5.318273059983103,
           5.293131079119176,
           5.267989098255256,
           5.24284711739133,
           5.218727684820407,
           5.1946137793186,
           5.170499873816799,
           5.146385968314992,
           5.122272062813186,
           5.098158157311383,
           5.074044251809577,
           5.049930346307771,
           5.025816440805969,
           5.001702535304162,
           4.977588629802355,
           4.953474724300549,
           4.929360818798747,
           4.90524691329694,
           4.881133007795134,
           4.857019102293332,
           4.8329051967915255,
           4.808791291289719,
           4.784677385787917,
           4.76056348028611,
           4.736449574784303,
           4.712335669282501,
           4.688221763780694,
           4.6641078582788875,
           4.639993952777082,
           4.6158800472752795,
           4.591766141773473,
           4.567652236271666,
           4.543538330769865,
           4.519424425268058,
           4.495310519766251,
           4.471196614264449,
           4.447082708762642,
           4.4229688032608365,
           4.39885489775903,
           4.374740992257228
          ],
          [
           62.893604486717194,
           62.94600965043722,
           62.99841481415724,
           63.05081997787727,
           63.10322514159729,
           63.15563030531732,
           63.20803546903734,
           63.260440632757366,
           63.31284579647739,
           63.365250960197415,
           63.41765612391744,
           63.47006128763746,
           63.52246645135749,
           63.57487161507751,
           63.62727677879754,
           63.67968194251756,
           63.732087106237586,
           63.78449226995761,
           63.836897433677635,
           63.88930259739766,
           63.941707761117684,
           63.99411292483771,
           64.04651808855772,
           64.09892325227776,
           64.15132841599777,
           64.2037335797178,
           64.25613874343783,
           64.30854390715785,
           64.36094907087788,
           64.4133542345979,
           64.46575939831791,
           64.51816456203795,
           64.57056972575796,
           64.622974889478,
           64.67538005319801,
           64.72778521691804,
           64.78019038063806,
           64.83259554435809,
           64.88500070807811,
           64.93740587179813,
           64.98981103551816,
           65.04221619923818,
           65.09462136295821,
           65.14702652667823,
           65.19943169039826,
           65.25183685411828,
           65.3042420178383,
           65.35664718155833,
           65.40905234527835,
           65.46145750899838,
           65.5138626727184,
           65.56626783643843,
           65.61867300015845,
           65.67107816387848,
           65.72325221743705,
           65.77538004852164,
           65.82750787960626,
           65.87963571069085,
           65.93176354177545,
           65.98389137286006,
           66.03601920394465,
           66.08814703502927,
           66.14027486611386,
           66.19240269719846,
           66.24453052828306,
           66.29665835936765,
           66.34878619045226,
           66.40091402153686,
           66.45304185262147,
           66.50516968370606,
           66.55729751479066,
           66.60942534587527,
           66.66155317695987,
           66.71368100804446,
           66.76580883912906,
           66.81793667021367,
           66.87006450129827,
           66.92219233238288,
           66.97432016346747,
           67.02644799455207,
           67.07857582563669,
           67.13070365672128,
           67.18283148780587,
           67.23495931889049,
           67.27777563915518,
           67.31872965725591,
           67.35968367535665,
           67.40063769345737,
           67.44159171155809,
           67.48254572965882,
           67.52349974775956,
           67.56445376586029,
           67.60540778396101,
           67.64636180206175,
           67.68731582016247,
           67.72826983826319,
           67.76922385636394,
           67.81017787446466,
           67.85113189256539,
           67.89208591066611,
           67.93303992876685,
           67.97399394686758,
           68.0149479649683,
           68.05590198306902,
           68.09685600116975,
           68.13781001927049,
           68.17876403737122,
           68.21971805547194,
           68.26067207357266,
           68.3016260916734,
           68.34258010977413,
           68.38353412787487,
           68.42448814597557,
           68.46544216407631,
           68.50639618217704,
           68.54735020027778,
           68.5883042183785,
           68.62925823647922,
           68.67021225457997,
           68.71116627268069,
           68.75212029078142,
           68.79307430888214,
           68.83402832698286,
           68.8749823450836,
           68.91593636318433,
           68.95689038128506,
           68.99784439938578,
           69.0387984174865,
           69.07975243558724,
           69.12070645368797,
           69.16166047178871,
           69.20261448988943,
           69.24356850799015,
           69.28452252609088,
           69.32547654419162,
           69.36643056229235,
           69.40738458039306,
           69.4476663265378,
           69.487611934697,
           69.52755754285621,
           69.56750315101544,
           69.60744875917464,
           69.64739436733386,
           69.68733997549309,
           69.7272855836523,
           69.7672311918115,
           69.80717679997073,
           69.84712240812995,
           69.88706801628916,
           69.92701362444838,
           69.96695923260759,
           70.00690484076681,
           70.04685044892602,
           70.08679605708522,
           70.12674166524445,
           70.16668727340367,
           70.20663288156288,
           70.2465784897221,
           70.28652409788131,
           70.32646970604053,
           70.36641531419974,
           70.40636092235896,
           70.44630653051817,
           70.48625213867737,
           70.5261977468366,
           70.56614335499582,
           70.60608896315503,
           70.63421765432017,
           70.65643788698829,
           70.67865811965639,
           70.7008783523245,
           70.72309858499261,
           70.74531881766072,
           70.76753905032882,
           70.78975928299693,
           70.81197951566503,
           70.83419974833315,
           70.85641998100127,
           70.87864021366936,
           70.90086044633748,
           70.92308067900558,
           70.94530091167368,
           70.96752114434179,
           70.9897413770099,
           71.01196160967801,
           71.03418184234611,
           71.05640207501423,
           71.07862230768234,
           71.10084254035044,
           71.12306277301855,
           71.14528300568666,
           71.16750323835477,
           71.18972347102287,
           71.21194370369099,
           71.2341639363591,
           71.2563841690272,
           71.27860440169532,
           71.30082463436342,
           71.32304486703151,
           71.34526509969965,
           71.36748533236774,
           71.38970556503585,
           71.41192579770396,
           71.43414603037206,
           71.45636626304018,
           71.47858649570827,
           71.50080672837639,
           71.52302696104451,
           71.54524719371261,
           71.57198311949327,
           71.5995254153091,
           71.62706771112492,
           71.65461000694073,
           71.68215230275655,
           71.70969459857238,
           71.73723689438819,
           71.76477919020402,
           71.79232148601983,
           71.81986378183564,
           71.84740607765147,
           71.87494837346728,
           71.90249066928311,
           71.93003296509893,
           71.95757526091475,
           71.98511755673057,
           72.01265985254639,
           72.0402021483622,
           72.06774444417803,
           72.09528673999384,
           72.12282903580967,
           72.15037133162548,
           72.17791362744131,
           72.20545592325712,
           72.23299821907294,
           72.26054051488876,
           72.28808281070458,
           72.3156251065204,
           72.34316740233622,
           72.37070969815203,
           72.39825199396786,
           72.42579428978368,
           72.45333658559949,
           72.48087888141531,
           72.50842117723113,
           72.53596347304695,
           72.56350576886277,
           72.59104806467857,
           72.61859036049441,
           72.64613265631021,
           72.67367495212604,
           72.37478215101339,
           71.74945425297227,
           71.1241263549312,
           70.49879845689014,
           69.87347055884902,
           69.24814266080797,
           68.6228147627669,
           67.99748686472579,
           67.37215896668467,
           66.74683106864364,
           66.12150317060252,
           65.49617527256142,
           64.87084737452035,
           64.24551947647929,
           63.62019157843817,
           62.9948636803971,
           62.369535782356046,
           61.744207884314925,
           61.11887998627386,
           60.493552088232796,
           59.86822419019168,
           59.242896292150554,
           58.617568394109554,
           57.99224049606843,
           57.36691259802731,
           56.74158469998625,
           56.11625680194518,
           55.49092890390407,
           54.865601005863006,
           54.24027310782194,
           53.61494520978082,
           52.9896173117397,
           52.36428941369869,
           51.73896151565758,
           51.11363361761646,
           50.48830571957539,
           49.86297782153432,
           49.237649923493215,
           48.612322025452144,
           47.98699412741108,
           47.36166622936996,
           46.73633833132891,
           46.11101043328784,
           45.485682535246724,
           44.86035463720559,
           44.235026739164596,
           43.609698841123475,
           42.984370943082354,
           42.35904304504129,
           41.733715147000225,
           41.108387248959104,
           40.48305935091805,
           39.85773145287698,
           39.23240355483586,
           38.60707565679474,
           37.981747758753734,
           37.35641986071261,
           36.73109196267149,
           36.10576406463043,
           35.48043616658937,
           34.85510826854825,
           34.229780370507186,
           33.60445247246612,
           32.979124574425,
           32.35379667638394,
           31.728468778342876,
           31.10314088030176,
           30.477812982260634,
           29.85248508421963,
           29.22715718617851,
           28.601829288137388,
           27.976501390096324,
           27.351173492055263,
           26.725845594014142,
           26.100517695973082,
           25.475189797932014,
           24.849861899890897,
           24.23054236635118,
           23.61743144502227,
           23.00432052369331,
           22.39120960236434,
           21.778098681035434,
           21.164987759706523,
           20.700663987472897,
           20.533914513429842,
           20.367165039386787,
           20.200415565343715,
           20.033666091300656,
           19.866916617257605,
           19.700167143214532,
           19.533417669171463,
           19.366668195128423,
           19.19991872108535,
           19.033169247042277,
           18.86641977299922,
           18.699670298956164,
           18.532920824913095,
           18.366171350870037,
           18.19942187682698,
           18.03267240278391,
           17.865922928740854,
           17.6991734546978,
           17.53242398065473,
           17.365674506611658,
           17.198925032568603,
           17.032175558525545,
           16.865426084482472,
           16.700891605678855,
           16.53673531454187,
           16.372579023404864,
           16.208422732267874,
           16.044266441130887,
           15.880110149993879,
           15.715953858856878,
           15.551797567719904,
           15.387641276582903,
           15.223484985445896,
           15.05932869430891,
           14.895172403171918,
           14.731016112034915,
           14.566859820897927,
           14.402703529760938,
           14.238547238623934,
           14.074390947486945,
           13.910234656349957,
           13.746078365212952,
           13.581922074075948,
           13.417765782938961,
           13.25360949180197,
           13.089453200664966,
           12.92529690952798,
           12.761140618390991,
           12.596984327253987,
           12.432828036116996,
           12.268671744980008,
           12.104515453843003,
           11.940359162706,
           11.776202871569026,
           11.612046580432022,
           11.447890289295021,
           11.28373399815803,
           11.11957770702104,
           10.95542141588404,
           10.79126512474705,
           10.62710883361006,
           10.462952542473056,
           10.298796251336068,
           10.134639960199081,
           9.970483669062075,
           9.806327377925072,
           9.642171086788098,
           9.478014795651093,
           9.31385850451409,
           9.149702213377102,
           8.985545922240114,
           8.821389631103111,
           8.65723333996612,
           8.493077048829132,
           8.328920757692128,
           8.164764466555123,
           8.00060817541815,
           7.836451884281146,
           7.672295593144143,
           7.508139302007153,
           7.343983010870165,
           7.179826719733161,
           7.036214908896398,
           6.995325499560663,
           6.954436090224929,
           6.913546680889193,
           6.872657271553466,
           6.831767862217732,
           6.790878452881997,
           6.74998904354627,
           6.709099634210535,
           6.6682102248748,
           6.627320815539072,
           6.586431406203338,
           6.545541996867604,
           6.504652587531868,
           6.46376317819614,
           6.422873768860406,
           6.381984359524671,
           6.341094950188943,
           6.300205540853209,
           6.259316131517473,
           6.218426722181746,
           6.177537312846011,
           6.136647903510276,
           6.095758494174548,
           6.054869084838814,
           6.013979675503078,
           5.973090266167345,
           5.932200856831617,
           5.891311447495881,
           5.850422038160147,
           5.80953262882442,
           5.768643219488684,
           5.727753810152951,
           5.691238939730315,
           5.660292775873344,
           5.6293466120163735,
           5.598400448159403,
           5.567454284302438,
           5.536508120445467,
           5.505561956588497,
           5.474615792731532,
           5.44366962887456,
           5.4127234650175895,
           5.381777301160625,
           5.350831137303653,
           5.319884973446683,
           5.288938809589718,
           5.257992645732747,
           5.227046481875777,
           5.1961003180188055,
           5.16515415416184,
           5.139172946161682,
           5.115058827895303,
           5.090944709628927,
           5.066830591362548,
           5.042716473096167,
           5.018602354829792,
           4.994488236563412,
           4.970374118297032,
           4.946260000030652,
           4.922145881764276,
           4.8980317634978965,
           4.873917645231517,
           4.849803526965142,
           4.825689408698762,
           4.801575290432382,
           4.7774611721660065,
           4.753347053899627,
           4.729232935633247,
           4.705118817366872,
           4.681004699100491,
           4.656890580834111,
           4.6327764625677315,
           4.608662344301356,
           4.584548226034976,
           4.560434107768597,
           4.536319989502221,
           4.512205871235841,
           4.488091752969462,
           4.4639776347030855,
           4.439863516436706,
           4.415749398170326,
           4.391635279903946,
           4.367521161637571
          ],
          [
           63.05912497699226,
           63.111530140712276,
           63.1639353044323,
           63.216340468152325,
           63.26874563187235,
           63.321150795592374,
           63.3735559593124,
           63.42596112303242,
           63.47836628675245,
           63.53077145047247,
           63.583176614192496,
           63.63558177791251,
           63.687986941632545,
           63.74039210535257,
           63.792797269072594,
           63.84520243279262,
           63.897607596512636,
           63.95001276023267,
           64.00241792395269,
           64.05482308767272,
           64.10722825139274,
           64.15963341511275,
           64.21203857883279,
           64.26444374255281,
           64.31684890627284,
           64.36925406999285,
           64.42165923371289,
           64.4740643974329,
           64.52646956115294,
           64.57887472487295,
           64.63127988859299,
           64.683685052313,
           64.73609021603303,
           64.78849537975306,
           64.84090054347307,
           64.8933057071931,
           64.94571087091313,
           64.99802359074366,
           65.05015142182825,
           65.10227925291285,
           65.15440708399744,
           65.20653491508206,
           65.25866274616665,
           65.31079057725125,
           65.36291840833586,
           65.41504623942046,
           65.46717407050505,
           65.51930190158966,
           65.57142973267426,
           65.62355756375885,
           65.67568539484347,
           65.72781322592806,
           65.77994105701266,
           65.83206888809727,
           65.88419671918186,
           65.93632455026648,
           65.98845238135107,
           66.04058021243567,
           66.09270804352028,
           66.14483587460487,
           66.19696370568947,
           66.24909153677407,
           66.30121936785868,
           66.35334719894328,
           66.40547503002787,
           66.45760286111248,
           66.50973069219708,
           66.56185852328167,
           66.61398635436629,
           66.6661141854509,
           66.71824201653548,
           66.77036984762009,
           66.82249767870469,
           66.8746255097893,
           66.92675334087389,
           66.97888117195849,
           67.0310090030431,
           67.08313683412769,
           67.1352646652123,
           67.1873924962969,
           67.2395203273815,
           67.2916481584661,
           67.34377598955069,
           67.3959038206353,
           67.43872014089999,
           67.47967415900072,
           67.52062817710146,
           67.56158219520219,
           67.60253621330291,
           67.64349023140363,
           67.68444424950437,
           67.7253982676051,
           67.76635228570584,
           67.80730630380656,
           67.8482603219073,
           67.88921434000802,
           67.93016835810874,
           67.97112237620948,
           68.01207639431021,
           68.05303041241093,
           68.09398443051167,
           68.13493844861239,
           68.17589246671312,
           68.21684648481386,
           68.25780050291458,
           68.2987545210153,
           68.33970853911603,
           68.38066255721677,
           68.4216165753175,
           68.46257059341822,
           68.50352461151894,
           68.54447862961968,
           68.58543264772041,
           68.62638666582114,
           68.66734068392186,
           68.70829470202258,
           68.74924872012332,
           68.79020273822405,
           68.83115675632479,
           68.87211077442551,
           68.9128967253746,
           68.95284233353381,
           68.99278794169302,
           69.03273354985224,
           69.07267915801145,
           69.11262476617067,
           69.1525703743299,
           69.1925159824891,
           69.23246159064831,
           69.27240719880753,
           69.31235280696674,
           69.35229841512596,
           69.39224402328517,
           69.43218963144437,
           69.4721352396036,
           69.51208084776282,
           69.55202645592203,
           69.59197206408125,
           69.63191767224046,
           69.67186328039968,
           69.71180888855889,
           69.7517544967181,
           69.79170010487732,
           69.83164571303654,
           69.87159132119575,
           69.91153692935497,
           69.95148253751418,
           69.99142814567341,
           70.03137375383261,
           70.07131936199183,
           70.11126497015104,
           70.15121057831027,
           70.19115618646947,
           70.23110179462869,
           70.2710474027879,
           70.31099301094712,
           70.35093861910633,
           70.39088422726554,
           70.43082983542476,
           70.47077544358397,
           70.51072105174319,
           70.5506666599024,
           70.59061226806162,
           70.63055787622085,
           70.67050348438005,
           70.71044909253928,
           70.75039470069848,
           70.77852339186363,
           70.80074362453173,
           70.82296385719985,
           70.84518408986796,
           70.86740432253606,
           70.88962455520416,
           70.91184478787227,
           70.93406502054037,
           70.95628525320849,
           70.9785054858766,
           71.00072571854471,
           71.02294595121282,
           71.04516618388094,
           71.06738641654904,
           71.08960664921715,
           71.11182688188525,
           71.13404711455335,
           71.15626734722147,
           71.17848757988958,
           71.20070781255768,
           71.22292804522579,
           71.2451482778939,
           71.26736851056201,
           71.28958874323013,
           71.31180897589823,
           71.33402920856634,
           71.35624944123444,
           71.37846967390254,
           71.40068990657066,
           71.42291013923877,
           71.44513037190688,
           71.46735060457499,
           71.4895708372431,
           71.5117910699112,
           71.5340113025793,
           71.5562315352474,
           71.57845176791552,
           71.60067200058363,
           71.62289223325175,
           71.64511246591985,
           71.66733269858796,
           71.68955293125607,
           71.71177316392418,
           71.73399339659228,
           71.75621362926039,
           71.7784338619285,
           71.80065409459661,
           71.82287432726471,
           71.84509455993282,
           71.86731479260092,
           71.88953502526904,
           71.91175525793714,
           71.93397549060526,
           71.95619572327337,
           71.97841595594147,
           72.00063618860958,
           72.02285642127768,
           72.0450766539458,
           72.06729688661392,
           72.08951711928202,
           72.11173735195013,
           72.13395758461823,
           72.15617781728633,
           72.17839804995445,
           72.20061828262256,
           72.22735420350693,
           72.25489649932275,
           72.28243879513857,
           72.3099810909544,
           72.33752338677021,
           72.36506568258602,
           72.39260797840184,
           72.42015027421766,
           72.44769257003348,
           72.4752348658493,
           72.50277716166512,
           72.53031945748094,
           72.55786175329676,
           72.58540404911258,
           72.6129463449284,
           72.64048864074421,
           72.66803093656003,
           72.69557323237585,
           72.3966804312632,
           71.77135253322207,
           71.14602463518102,
           70.52069673713996,
           69.89536883909884,
           69.27004094105779,
           68.64471304301671,
           68.01938514497559,
           67.39405724693448,
           66.76872934889347,
           66.14340145085235,
           65.51807355281122,
           64.89274565477017,
           64.2674177567291,
           63.64208985868798,
           63.016761960646924,
           62.39143406260586,
           61.76610616456474,
           61.14077826652367,
           60.51545036848261,
           59.89012247044149,
           59.26479457240036,
           58.63946667435937,
           58.014138776318255,
           57.38881087827713,
           56.76348298023607,
           56.138155082195006,
           55.51282718415388,
           54.88749928611282,
           54.26217138807175,
           53.636843490030635,
           53.01151559198951,
           52.3861876939485,
           51.76085979590738,
           51.135531897866265,
           50.51020399982521,
           49.884876101784144,
           49.259548203743016,
           48.63422030570196,
           48.008892407660895,
           47.38356450961978,
           46.75804209842239,
           46.12561454543644,
           45.49318699245043,
           44.86075943946442,
           44.22833188647853,
           43.59590433349252,
           42.96347678050651,
           42.33104922752056,
           41.698621674534614,
           41.066194121548605,
           40.43376656856266,
           39.8013390155767,
           39.1689114625907,
           38.53648390960469,
           37.904056356618796,
           37.27162880363279,
           36.63920125064678,
           36.006773697660826,
           35.37434614467488,
           34.74191859168887,
           34.10949103870292,
           33.47706348571697,
           32.84463593273097,
           32.21220837974501,
           31.57978082675906,
           30.947353273773054,
           30.314925720787038,
           29.68249816780115,
           29.05007061481514,
           28.417643061829136,
           27.78521550884318,
           27.152787955857235,
           26.520360402871223,
           25.887932849885274,
           25.255505296899322,
           24.623077743913317,
           23.990650190927365,
           23.358222637941417,
           22.725795084955404,
           22.0933675319694,
           21.460939978983447,
           20.828512425997495,
           20.354728303667212,
           20.198231042648253,
           20.041733781629297,
           19.885236520610324,
           19.728739259591368,
           19.57224199857241,
           19.415744737553435,
           19.259247476534465,
           19.10275021551552,
           18.94625295449655,
           18.789755693477577,
           18.633258432458618,
           18.476761171439662,
           18.32026391042069,
           18.16376664940173,
           18.007269388382774,
           17.850772127363804,
           17.694274866344845,
           17.537777605325886,
           17.381280344306916,
           17.224783083287942,
           17.068285822268987,
           16.911788561250027,
           16.755291300231058,
           16.5987940392121,
           16.44229677819314,
           16.28579951717417,
           16.129302256155214,
           15.972804995136253,
           15.81630773411728,
           15.65981047309831,
           15.501203058301586,
           15.337046767164585,
           15.172890476027579,
           15.00873418489059,
           14.844577893753598,
           14.680421602616596,
           14.516265311479607,
           14.352109020342619,
           14.187952729205616,
           14.023796438068626,
           13.859640146931639,
           13.695483855794633,
           13.53132756465763,
           13.367171273520643,
           13.203014982383653,
           13.038858691246649,
           12.87470240010966,
           12.710546108972672,
           12.546389817835667,
           12.382233526698679,
           12.21807723556169,
           12.053920944424686,
           11.889764653287681,
           11.725608362150709,
           11.561452071013704,
           11.397295779876703,
           11.233139488739713,
           11.068983197602726,
           10.904826906465718,
           10.74067061532873,
           10.576514324191741,
           10.412358033054737,
           10.24820174191775,
           10.084045450780762,
           9.919889159643756,
           9.755732868506751,
           9.591576577369779,
           9.427420286232774,
           9.263263995095773,
           9.099107703958785,
           8.934951412821796,
           8.770795121684792,
           8.606638830547801,
           8.442482539410813,
           8.278326248273807,
           8.114169957136806,
           7.950013665999833,
           7.785857374862828,
           7.6217010837258234,
           7.457544792588833,
           7.293388501451844,
           7.129232210314843,
           6.98562039947808,
           6.944730990142345,
           6.90384158080661,
           6.8629521714708766,
           6.822062762135149,
           6.781173352799414,
           6.7402839434636785,
           6.699394534127952,
           6.658505124792216,
           6.617615715456482,
           6.576726306120754,
           6.535836896785019,
           6.494947487449284,
           6.454058078113549,
           6.413168668777821,
           6.372279259442088,
           6.331389850106352,
           6.290500440770626,
           6.24961103143489,
           6.212620929715848,
           6.181674765858882,
           6.150728602001912,
           6.119782438144941,
           6.088836274287975,
           6.057890110431004,
           6.026943946574033,
           5.995997782717064,
           5.965051618860098,
           5.934105455003127,
           5.9031592911461575,
           5.872213127289191,
           5.841266963432221,
           5.81032079957525,
           5.779374635718284,
           5.748428471861314,
           5.717482308004343,
           5.6865361441473725,
           5.655589980290407,
           5.624643816433435,
           5.5936976525764655,
           5.5627514887195,
           5.531805324862529,
           5.500859161005558,
           5.469912997148594,
           5.438966833291623,
           5.408020669434652,
           5.377074505577688,
           5.346128341720716,
           5.315182177863745,
           5.284236014006774,
           5.25328985014981,
           5.222343686292839,
           5.191397522435868,
           5.160451358578904,
           5.129505194721933,
           5.098559030864961,
           5.0676128670079965,
           5.036666703151026,
           5.005720539294055,
           4.974774375437084,
           4.943828211580119,
           4.912882047723148,
           4.881935883866177,
           4.850989720009212,
           4.820043556152241,
           4.794388881565146,
           4.7702747632987705,
           4.74616064503239,
           4.722046526766011,
           4.697932408499635,
           4.673818290233255,
           4.649704171966874,
           4.6255900537004955,
           4.60147593543412,
           4.57736181716774,
           4.553247698901361,
           4.529133580634985,
           4.505019462368605,
           4.480905344102226,
           4.4567912258358495,
           4.43267710756947,
           4.408562989303089,
           4.38444887103671,
           4.360334752770335
          ],
          [
           63.22464546726731,
           63.27705063098733,
           63.32945579470736,
           63.38186095842738,
           63.434266122147406,
           63.48667128586743,
           63.539076449587455,
           63.59148161330747,
           63.643886777027504,
           63.69629194074753,
           63.74869710446755,
           63.80110226818758,
           63.8535074319076,
           63.905912595627626,
           63.95831775934765,
           64.01072292306768,
           64.0631280867877,
           64.11553325050772,
           64.16793841422775,
           64.22034357794777,
           64.2727487416678,
           64.32492279513484,
           64.37705062621944,
           64.42917845730406,
           64.48130628838865,
           64.53343411947324,
           64.58556195055786,
           64.63768978164245,
           64.68981761272705,
           64.74194544381166,
           64.79407327489625,
           64.84620110598087,
           64.89832893706546,
           64.95045676815006,
           65.00258459923467,
           65.05471243031926,
           65.10684026140387,
           65.15896809248846,
           65.21109592357307,
           65.26322375465766,
           65.31535158574226,
           65.36747941682688,
           65.41960724791147,
           65.47173507899606,
           65.52386291008068,
           65.57599074116527,
           65.62811857224987,
           65.68024640333448,
           65.73237423441907,
           65.78450206550367,
           65.83662989658828,
           65.88875772767288,
           65.94088555875749,
           65.99301338984208,
           66.04514122092668,
           66.09726905201128,
           66.14939688309589,
           66.2015247141805,
           66.2536525452651,
           66.30578037634969,
           66.35790820743429,
           66.41003603851888,
           66.4621638696035,
           66.51429170068809,
           66.5664195317727,
           66.61854736285729,
           66.67067519394189,
           66.7228030250265,
           66.7749308561111,
           66.8270586871957,
           66.8791865182803,
           66.9313143493649,
           66.98344218044952,
           67.0355700115341,
           67.08769784261871,
           67.13982567370331,
           67.19195350478792,
           67.24408133587251,
           67.29620916695711,
           67.34833699804172,
           67.40046482912632,
           67.45259266021093,
           67.50472049129552,
           67.55684832238012,
           67.59966464264483,
           67.64061866074556,
           67.68157267884628,
           67.72252669694701,
           67.76348071504773,
           67.80443473314847,
           67.8453887512492,
           67.88634276934992,
           67.92729678745064,
           67.96825080555138,
           68.00920482365211,
           68.05015884175283,
           68.09111285985358,
           68.13206687795429,
           68.17302089605504,
           68.21397491415576,
           68.25492893225649,
           68.29588295035721,
           68.33683696845794,
           68.37779098655867,
           68.4180727323706,
           68.45801834052983,
           68.49796394868905,
           68.53790955684825,
           68.57785516500746,
           68.61780077316669,
           68.65774638132591,
           68.69769198948511,
           68.73763759764434,
           68.77758320580355,
           68.81752881396275,
           68.85747442212198,
           68.8974200302812,
           68.9373656384404,
           68.97731124659961,
           69.01725685475884,
           69.05720246291806,
           69.09714807107727,
           69.13709367923649,
           69.1770392873957,
           69.21698489555492,
           69.25693050371413,
           69.29687611187336,
           69.33682172003256,
           69.37676732819178,
           69.41671293635099,
           69.4566585445102,
           69.49660415266942,
           69.53654976082863,
           69.57649536898784,
           69.61644097714706,
           69.65638658530628,
           69.6963321934655,
           69.73627780162471,
           69.77622340978391,
           69.81616901794314,
           69.85611462610235,
           69.89606023426157,
           69.93600584242078,
           69.97595145058,
           70.01589705873923,
           70.05584266689843,
           70.09578827505764,
           70.13573388321686,
           70.17567949137607,
           70.21562509953529,
           70.2555707076945,
           70.29551631585372,
           70.33546192401292,
           70.37540753217215,
           70.41535314033135,
           70.45529874849058,
           70.49524435664979,
           70.535189964809,
           70.57513557296822,
           70.61508118112744,
           70.65502678928665,
           70.69497239744587,
           70.73491800560508,
           70.7748636137643,
           70.81480922192351,
           70.85475483008273,
           70.89470043824194,
           70.92282912940709,
           70.9450493620752,
           70.9672695947433,
           70.9894898274114,
           71.01171006007952,
           71.03393029274763,
           71.05615052541573,
           71.07837075808385,
           71.10059099075195,
           71.12281122342006,
           71.14503145608816,
           71.16725168875627,
           71.1894719214244,
           71.2116921540925,
           71.23391238676061,
           71.25613261942871,
           71.27835285209682,
           71.30057308476493,
           71.32279331743304,
           71.34501355010114,
           71.36723378276926,
           71.38945401543737,
           71.41167424810547,
           71.43389448077357,
           71.45611471344168,
           71.47833494610978,
           71.50055517877792,
           71.522775411446,
           71.54499564411411,
           71.56721587678223,
           71.58943610945033,
           71.61165634211844,
           71.63387657478656,
           71.65609680745466,
           71.67831704012276,
           71.70053727279087,
           71.72275750545899,
           71.74497773812709,
           71.7671979707952,
           71.78941820346331,
           71.81163843613142,
           71.83385866879952,
           71.85607890146763,
           71.87829913413574,
           71.90051936680385,
           71.92273959947195,
           71.94495983214006,
           71.96718006480819,
           71.9894002974763,
           72.0116205301444,
           72.0338407628125,
           72.0560609954806,
           72.07828122814871,
           72.10050146081682,
           72.12272169348493,
           72.14494192615305,
           72.16716215882116,
           72.18938239148926,
           72.21160262415738,
           72.23382285682548,
           72.25604308949357,
           72.27826332216169,
           72.3004835548298,
           72.3227037874979,
           72.34492402016602,
           72.36714425283412,
           72.38936448550224,
           72.41158471817035,
           72.43380495083845,
           72.45602518350657,
           72.47824541617466,
           72.49925204820416,
           72.51752810322638,
           72.53580415824861,
           72.55408021327084,
           72.57235626829305,
           72.59063232331528,
           72.6089083783375,
           72.62718443335973,
           72.64546048838196,
           72.66373654340418,
           72.68201259842641,
           72.70028865344861,
           72.39104473312064,
           71.7542808374424,
           71.11751694176421,
           70.48075304608604,
           69.8439891504078,
           69.20722525472964,
           68.57046135905146,
           67.93369746337322,
           67.29693356769499,
           66.66016967201686,
           66.02340577633863,
           65.38664188066039,
           64.75125459497137,
           64.11882704198543,
           63.48639948899941,
           62.85397193601346,
           62.221544383027506,
           61.589116830041505,
           60.95668927705556,
           60.32426172406961,
           59.69183417108359,
           59.05940661809759,
           58.4269790651117,
           57.79455151212568,
           57.16212395913968,
           56.529696406153725,
           55.89726885316778,
           55.264841300181764,
           54.63241374719582,
           53.99998619420987,
           53.36755864122386,
           52.73513108823785,
           52.10270353525196,
           51.47027598226595,
           50.83784842927994,
           50.205420876293985,
           49.57299332330805,
           48.94056577032203,
           48.30813821733609,
           47.67571066435014,
           47.04328311136412,
           46.410855558378174,
           45.77842800539223,
           45.14600045240621,
           44.5135728994202,
           43.881145346434316,
           43.24871779344831,
           42.61629024046229,
           41.983862687476346,
           41.351435134490394,
           40.71900758150439,
           40.08658002851844,
           39.45415247553248,
           38.82172492254648,
           38.189297369560464,
           37.556869816574576,
           36.92444226358857,
           36.292014710602565,
           35.65958715761661,
           35.02715960463066,
           34.39473205164465,
           33.7623044986587,
           33.12987694567275,
           32.49744939268675,
           31.865021839700795,
           31.232594286714843,
           30.600166733728834,
           29.967739180742825,
           29.335311627756933,
           28.70288407477092,
           28.070456521784916,
           27.438028968798967,
           26.80560141581302,
           26.173173862827007,
           25.540746309841055,
           24.908318756855106,
           24.275891203869097,
           23.64346365088315,
           23.011036097897197,
           22.378608544911188,
           21.74618099192518,
           21.11375343893923,
           20.481325885953282,
           20.007541763622996,
           19.851044502604033,
           19.694547241585077,
           19.538049980566107,
           19.381552719547148,
           19.225055458528193,
           19.06855819750922,
           18.912060936490246,
           18.755563675471304,
           18.59906641445233,
           18.44256915343336,
           18.2860718924144,
           18.129574631395442,
           17.973077370376473,
           17.816580109357513,
           17.660082848338558,
           17.503585587319584,
           17.34708832630063,
           17.19059106528167,
           17.034093804262696,
           16.877596543243726,
           16.721099282224767,
           16.56460202120581,
           16.408104760186838,
           16.251607499167882,
           16.095110238148923,
           15.938612977129951,
           15.782115716110994,
           15.625618455092036,
           15.469121194073065,
           15.312623933054091,
           15.15612667203515,
           14.999629411016176,
           14.843132149997205,
           14.686634888978247,
           14.53013762795929,
           14.373640366940318,
           14.217143105921359,
           14.060645844902403,
           13.904148583883428,
           13.74765132286447,
           13.591154061845513,
           13.434656800826541,
           13.278159539807568,
           13.121662278788609,
           12.965165017769653,
           12.808667756750681,
           12.652170495731724,
           12.495673234712765,
           12.339175973693795,
           12.182678712674836,
           12.026181451655878,
           11.869684190636907,
           11.713186929617933,
           11.556689668598992,
           11.40019240758002,
           11.243695146561047,
           11.08719788554209,
           10.930700624523132,
           10.77420336350416,
           10.617706102485203,
           10.461208841466245,
           10.304711580447272,
           10.148214319428314,
           9.991717058409357,
           9.835219797390385,
           9.678722536371414,
           9.522225275352469,
           9.365728014333497,
           9.209230753314525,
           9.048513194540462,
           8.884356903403475,
           8.72020061226647,
           8.556044321129482,
           8.391888029992492,
           8.22773173885549,
           8.063575447718485,
           7.899419156581511,
           7.735262865444506,
           7.571106574307504,
           7.406950283170515,
           7.242793992033526,
           7.078637700896523,
           6.935025890059761,
           6.8941364807240255,
           6.8532470713882905,
           6.812357662052556,
           6.771468252716828,
           6.734002919701388,
           6.703056755844417,
           6.672110591987452,
           6.641164428130482,
           6.61021826427351,
           6.579272100416546,
           6.548325936559575,
           6.517379772702603,
           6.486433608845633,
           6.455487444988668,
           6.424541281131697,
           6.393595117274726,
           6.362648953417762,
           6.33170278956079,
           6.30075662570382,
           6.269810461846855,
           6.238864297989885,
           6.207918134132913,
           6.176971970275948,
           6.146025806418978,
           6.115079642562006,
           6.084133478705036,
           6.053187314848071,
           6.0222411509911,
           5.991294987134129,
           5.960348823277164,
           5.929402659420193,
           5.898456495563222,
           5.867510331706257,
           5.836564167849286,
           5.805618003992316,
           5.774671840135344,
           5.7437256762783795,
           5.71277951242141,
           5.681833348564438,
           5.650887184707472,
           5.6199410208505025,
           5.588994856993532,
           5.558048693136566,
           5.5271025292795954,
           5.496156365422625,
           5.465210201565659,
           5.434264037708688,
           5.403317873851718,
           5.372371709994747,
           5.341425546137781,
           5.310479382280811,
           5.27953321842384,
           5.248587054566875,
           5.217640890709904,
           5.186694726852934,
           5.155748562995969,
           5.124802399138998,
           5.0938562352820265,
           5.062910071425057,
           5.031963907568091,
           5.00101774371112,
           4.9700715798541495,
           4.939125415997185,
           4.908179252140213,
           4.877233088283242,
           4.846286924426278,
           4.815340760569307,
           4.784394596712336,
           4.753448432855371,
           4.722502268998401,
           4.69155610514143,
           4.660609941284459,
           4.629663777427494,
           4.598717613570523,
           4.567771449713552,
           4.536825285856587,
           4.505879121999616,
           4.474932958142645,
           4.4496048169686135,
           4.425490698702234,
           4.401376580435853,
           4.377262462169473,
           4.353148343903098
          ],
          [
           63.390165957542365,
           63.44257112126239,
           63.49497628498241,
           63.54738144870243,
           63.599694168441445,
           63.65182199952604,
           63.70394983061065,
           63.75607766169524,
           63.80820549277985,
           63.86033332386445,
           63.91246115494905,
           63.96458898603365,
           64.01671681711825,
           64.06884464820286,
           64.12097247928746,
           64.17310031037205,
           64.22522814145665,
           64.27735597254126,
           64.32948380362586,
           64.38161163471045,
           64.43373946579506,
           64.48586729687966,
           64.53799512796427,
           64.59012295904887,
           64.64225079013346,
           64.69437862121806,
           64.74650645230267,
           64.79863428338727,
           64.85076211447188,
           64.90288994555647,
           64.95501777664107,
           65.00714560772568,
           65.05927343881027,
           65.11140126989488,
           65.16352910097947,
           65.21565693206408,
           65.26778476314868,
           65.31991259423327,
           65.37204042531789,
           65.42416825640248,
           65.47629608748707,
           65.52842391857169,
           65.58055174965628,
           65.63267958074088,
           65.68480741182549,
           65.73693524291009,
           65.7890630739947,
           65.84119090507929,
           65.89331873616389,
           65.9454465672485,
           65.99757439833309,
           66.0497022294177,
           66.1018300605023,
           66.1539578915869,
           66.2060857226715,
           66.2582135537561,
           66.31034138484071,
           66.3624692159253,
           66.4145970470099,
           66.46672487809451,
           66.5188527091791,
           66.5709805402637,
           66.62310837134831,
           66.67523620243291,
           66.7273640335175,
           66.77949186460211,
           66.83161969568671,
           66.88374752677132,
           66.93587535785592,
           66.98800318894051,
           67.04013102002511,
           67.09225885110972,
           67.14438668219432,
           67.19651451327891,
           67.24864234436352,
           67.30077017544812,
           67.35289800653273,
           67.40502583761733,
           67.45715366870192,
           67.50928149978654,
           67.56140933087114,
           67.61353716195573,
           67.66566499304034,
           67.71779282412494,
           67.76060914438965,
           67.80156316249038,
           67.8425171805911,
           67.88330313120741,
           67.92324873936663,
           67.96319434752584,
           68.00313995568507,
           68.04308556384427,
           68.08303117200349,
           68.1229767801627,
           68.16292238832192,
           68.20286799648113,
           68.24281360464035,
           68.28275921279956,
           68.32270482095878,
           68.36265042911799,
           68.4025960372772,
           68.44254164543642,
           68.48248725359564,
           68.52243286175485,
           68.56237846991407,
           68.60232407807328,
           68.6422696862325,
           68.68221529439171,
           68.72216090255093,
           68.76210651071014,
           68.80205211886937,
           68.84199772702857,
           68.88194333518778,
           68.921888943347,
           68.96183455150621,
           69.00178015966543,
           69.04172576782466,
           69.08167137598386,
           69.12161698414307,
           69.16156259230229,
           69.2015082004615,
           69.24145380862072,
           69.28139941677995,
           69.32134502493915,
           69.36129063309838,
           69.40123624125758,
           69.44118184941681,
           69.48112745757601,
           69.52107306573522,
           69.56101867389444,
           69.60096428205367,
           69.64090989021288,
           69.6808554983721,
           69.7208011065313,
           69.76074671469053,
           69.80069232284973,
           69.84063793100896,
           69.88058353916816,
           69.92052914732739,
           69.96047475548659,
           70.0004203636458,
           70.04036597180502,
           70.08031157996423,
           70.12025718812345,
           70.16020279628268,
           70.20014840444188,
           70.2400940126011,
           70.2800396207603,
           70.31998522891953,
           70.35993083707874,
           70.39987644523796,
           70.43982205339717,
           70.47976766155638,
           70.5197132697156,
           70.55965887787481,
           70.59960448603402,
           70.63955009419324,
           70.67949570235245,
           70.71944131051168,
           70.75938691867088,
           70.79933252683011,
           70.83927813498931,
           70.87922374314854,
           70.91916935130774,
           70.95911495946696,
           70.99906056762619,
           71.03900617578539,
           71.06713486695054,
           71.08935509961864,
           71.11157533228676,
           71.13379556495488,
           71.15601579762298,
           71.17823603029107,
           71.2004562629592,
           71.2226764956273,
           71.2448967282954,
           71.26711696096352,
           71.28933719363162,
           71.31155742629973,
           71.33377765896785,
           71.35326731482893,
           71.37154336985115,
           71.38981942487338,
           71.4080954798956,
           71.42637153491782,
           71.44464758994005,
           71.46292364496227,
           71.4811996999845,
           71.49947575500673,
           71.51775181002894,
           71.53602786505117,
           71.5543039200734,
           71.57257997509564,
           71.59085603011785,
           71.60913208514006,
           71.62740814016229,
           71.64568419518451,
           71.66396025020674,
           71.68223630522898,
           71.7005123602512,
           71.71878841527342,
           71.73706447029564,
           71.75534052531788,
           71.7736165803401,
           71.79189263536233,
           71.81016869038453,
           71.82844474540677,
           71.84672080042898,
           71.86499685545121,
           71.88327291047344,
           71.90154896549566,
           71.91982502051789,
           71.93810107554012,
           71.95637713056234,
           71.97465318558456,
           71.9929292406068,
           72.01120529562903,
           72.02948135065124,
           72.04775740567347,
           72.06603346069569,
           72.0843095157179,
           72.10258557074013,
           72.12086162576236,
           72.13913768078459,
           72.15741373580681,
           72.17568979082904,
           72.19396584585127,
           72.21224190087348,
           72.23051795589572,
           72.24879401091793,
           72.26707006594015,
           72.28534612096237,
           72.3036221759846,
           72.32189823100683,
           72.34017428602907,
           72.35845034105128,
           72.3767263960735,
           72.39500245109573,
           72.41327850611796,
           72.43155456114017,
           72.4498306161624,
           72.46810667118463,
           72.48638272620686,
           72.50465878122908,
           72.5229348362513,
           72.54121089127354,
           72.55948694629575,
           72.57776300131798,
           72.59603905634019,
           72.61431511136243,
           72.30507119103441,
           71.66830729535619,
           71.03154339967801,
           70.39477950399983,
           69.7580156083216,
           69.12125171264341,
           68.48448781696526,
           67.84772392128701,
           67.21096002560878,
           66.57419612993067,
           65.93743223425243,
           65.3006683385742,
           64.66390444289601,
           64.02714054721784,
           63.39037665153961,
           62.75361275586143,
           62.11684886018326,
           61.48008496450501,
           60.843321068826846,
           60.206557173148674,
           59.56979327747044,
           58.9330293817922,
           58.29626548611408,
           57.65950159043586,
           57.022737694757616,
           56.38597379907944,
           55.749209903401265,
           55.11244600772303,
           54.47568211204485,
           53.838918216366686,
           53.20215432068845,
           52.56539042501021,
           51.92862652933209,
           51.291862633653864,
           50.65509873797562,
           50.01833484229745,
           49.38157094661928,
           48.74480705094105,
           48.10804315526286,
           47.47127925958468,
           46.83451536390645,
           46.197751468228276,
           45.560987572550104,
           44.92422367687187,
           44.28745978119363,
           43.65069588551551,
           43.013931989837275,
           42.377168094159046,
           41.740404198480874,
           41.103640302802695,
           40.46687640712446,
           39.83011251144629,
           39.19334861576811,
           38.55658472008987,
           37.919820824411644,
           37.28305692873353,
           36.646293033055294,
           36.00952913737706,
           35.37276524169888,
           34.73600134602071,
           34.09923745034247,
           33.46247355466429,
           32.82570965898612,
           32.188945763307885,
           31.55218186762971,
           30.915417971951534,
           30.278654076273302,
           29.641890180595066,
           29.005126284916948,
           28.368362389238715,
           27.73159849356048,
           27.094834597882304,
           26.45841487576881,
           25.825987322782805,
           25.193559769796853,
           24.561132216810904,
           23.928704663824895,
           23.296277110838943,
           22.663849557852995,
           22.031422004866986,
           21.398994451880977,
           20.76656689889503,
           20.134139345909077,
           19.66035522357879,
           19.503857962559827,
           19.347360701540875,
           19.190863440521902,
           19.034366179502943,
           18.877868918483983,
           18.721371657465014,
           18.564874396446044,
           18.408377135427095,
           18.251879874408125,
           18.095382613389155,
           17.9388853523702,
           17.782388091351237,
           17.62589083033227,
           17.469393569313308,
           17.312896308294356,
           17.156399047275382,
           16.999901786256427,
           16.844956307831968,
           16.69145745531121,
           16.53795860279045,
           16.384459750269706,
           16.23096089774896,
           16.0774620452282,
           15.923963192707454,
           15.77046434018671,
           15.61696548766595,
           15.463466635145206,
           15.309967782624462,
           15.156468930103701,
           15.002970077582942,
           14.849471225062212,
           14.695972372541453,
           14.542473520020692,
           14.388974667499948,
           14.235475814979203,
           14.081976962458445,
           13.928478109937698,
           13.774979257416952,
           13.621480404896195,
           13.467981552375448,
           13.314482699854704,
           13.160983847333943,
           13.007484994813186,
           12.853986142292442,
           12.700487289771694,
           12.546988437250937,
           12.39348958473019,
           12.239990732209446,
           12.086491879688687,
           11.93299302716794,
           11.779494174647196,
           11.625995322126437,
           11.472496469605678,
           11.318997617084948,
           11.16549876456419,
           11.011999912043429,
           10.858501059522682,
           10.70500220700194,
           10.551503354481179,
           10.398004501960434,
           10.24450564943969,
           10.091006796918931,
           9.937507944398186,
           9.78400909187744,
           9.63051023935668,
           9.47701138683592,
           9.32351253431519,
           9.17001368179443,
           9.016514829273671,
           8.863015976752926,
           8.709517124232182,
           8.556018271711421,
           8.402519419190678,
           8.249020566669932,
           8.095521714149173,
           7.942022861628413,
           7.788524009107682,
           7.635025156586924,
           7.481526304066164,
           7.328027451545419,
           7.174528599024674,
           7.021029746503915,
           6.888187380356518,
           6.858627446075767,
           6.829067511795015,
           6.799507577514262,
           6.769947643233516,
           6.740387708952764,
           6.710827774672012,
           6.681267840391266,
           6.651707906110514,
           6.622147971829762,
           6.592588037549015,
           6.563028103268263,
           6.533468168987511,
           6.50390823470676,
           6.474348300426012,
           6.444788366145261,
           6.4152284318645085,
           6.3856684975837625,
           6.35610856330301,
           6.3264597661110304,
           6.295513602254066,
           6.264567438397096,
           6.233621274540123,
           6.202675110683159,
           6.171728946826189,
           6.140782782969216,
           6.109836619112247,
           6.078890455255281,
           6.047944291398311,
           6.01699812754134,
           5.986051963684375,
           5.955105799827404,
           5.924159635970433,
           5.893213472113468,
           5.862267308256497,
           5.831321144399527,
           5.800374980542555,
           5.769428816685591,
           5.738482652828619,
           5.707536488971649,
           5.676590325114684,
           5.645644161257712,
           5.614697997400742,
           5.5837518335437775,
           5.552805669686807,
           5.521859505829836,
           5.49091334197287,
           5.4599671781159,
           5.429021014258929,
           5.398074850401958,
           5.367128686544993,
           5.336182522688023,
           5.305236358831051,
           5.274290194974086,
           5.2433440311171156,
           5.212397867260145,
           5.18145170340318,
           5.1505055395462085,
           5.119559375689239,
           5.088613211832268,
           5.057667047975302,
           5.0267208841183315,
           4.995774720261361,
           4.964828556404395,
           4.933882392547425,
           4.902936228690454,
           4.871990064833489,
           4.841043900976518,
           4.8100977371195475,
           4.779151573262583,
           4.748205409405611,
           4.71725924554864,
           4.68631308169167,
           4.655366917834705,
           4.624420753977734,
           4.593474590120763,
           4.562528426263798,
           4.531582262406827,
           4.500636098549856,
           4.469689934692891,
           4.43874377083592,
           4.40779760697895,
           4.3768514431219785,
           4.345905279265014
          ],
          [
           63.54629949275878,
           63.59842732384338,
           63.65055515492798,
           63.702682986012576,
           63.75481081709718,
           63.806938648181784,
           63.85906647926639,
           63.911194310350986,
           63.96332214143559,
           64.01544997252019,
           64.06757780360479,
           64.1197056346894,
           64.171833465774,
           64.22396129685859,
           64.2760891279432,
           64.3282169590278,
           64.38034479011239,
           64.43247262119701,
           64.4846004522816,
           64.5367282833662,
           64.5888561144508,
           64.64098394553541,
           64.69311177662,
           64.7452396077046,
           64.7973674387892,
           64.84949526987381,
           64.90162310095842,
           64.95375093204301,
           65.00587876312761,
           65.05800659421222,
           65.1101344252968,
           65.16226225638141,
           65.214390087466,
           65.26651791855062,
           65.31864574963522,
           65.37077358071981,
           65.42290141180442,
           65.47502924288902,
           65.52715707397363,
           65.57928490505822,
           65.63141273614282,
           65.68354056722742,
           65.73566839831203,
           65.78779622939663,
           65.83992406048122,
           65.89205189156584,
           65.94417972265043,
           65.99630755373502,
           66.04843538481964,
           66.10056321590423,
           66.15269104698883,
           66.20481887807344,
           66.25694670915804,
           66.30907454024263,
           66.36120237132724,
           66.41333020241184,
           66.46545803349645,
           66.51758586458105,
           66.56971369566564,
           66.62184152675025,
           66.67396935783485,
           66.72609718891945,
           66.77822502000406,
           66.83035285108865,
           66.88248068217325,
           66.93460851325786,
           66.98673634434246,
           67.03886417542707,
           67.09099200651166,
           67.14311983759626,
           67.19524766868086,
           67.24695237691252,
           67.29844552308253,
           67.34993866925257,
           67.40143181542258,
           67.45292496159261,
           67.50441810776263,
           67.55591125393266,
           67.60740440010268,
           67.6588975462727,
           67.71039069244273,
           67.76188383861275,
           67.81337698478278,
           67.8648701309528,
           67.90591786480684,
           67.9448765161977,
           67.98383516758854,
           68.02279381897938,
           68.06175247037024,
           68.10071112176108,
           68.13966977315192,
           68.17862842454278,
           68.21758707593364,
           68.25654572732448,
           68.29550437871532,
           68.33446303010618,
           68.37342168215551,
           68.41336729031471,
           68.45331289847392,
           68.49325850663315,
           68.53320411479235,
           68.57314972295157,
           68.61309533111078,
           68.65304093927,
           68.69298654742921,
           68.73293215558843,
           68.77287776374764,
           68.81282337190686,
           68.85276898006607,
           68.89271458822529,
           68.9326601963845,
           68.97260580454372,
           69.01255141270293,
           69.05249702086215,
           69.09244262902136,
           69.13238823718058,
           69.17233384533981,
           69.21227945349901,
           69.25222506165822,
           69.29217066981744,
           69.33211627797665,
           69.37206188613587,
           69.41200749429508,
           69.4519531024543,
           69.49189871061351,
           69.53184431877273,
           69.57178992693196,
           69.61173553509116,
           69.65168114325037,
           69.69162675140959,
           69.73157235956882,
           69.77151796772802,
           69.81146357588725,
           69.85140918404645,
           69.89135479220568,
           69.93130040036488,
           69.9712460085241,
           70.0111916166833,
           70.05113722484253,
           70.09108283300174,
           70.13102844116096,
           70.17097404932017,
           70.2109196574794,
           70.2508652656386,
           70.29081087379782,
           70.33075648195702,
           70.37070209011625,
           70.41064769827547,
           70.45059330643468,
           70.4905389145939,
           70.53048452275311,
           70.57043013091231,
           70.61037573907154,
           70.65032134723074,
           70.69026695538997,
           70.73021256354917,
           70.7701581717084,
           70.8101037798676,
           70.85004938802682,
           70.88999499618603,
           70.92994060434525,
           70.96988621250446,
           71.00983182066368,
           71.04977742882289,
           71.08972303698212,
           71.12966864514132,
           71.16961425330054,
           71.19025677950016,
           71.20124776471997,
           71.21223874993977,
           71.22322973515958,
           71.2342207203794,
           71.2452117055992,
           71.25620269081901,
           71.26719367603883,
           71.27818466125862,
           71.28917564647844,
           71.30016663169825,
           71.31115761691805,
           71.32214860213787,
           71.33313958735768,
           71.34413057257748,
           71.35512155779729,
           71.36611254301711,
           71.37710352823692,
           71.38809451345672,
           71.39908549867653,
           71.41007648389633,
           71.42106746911615,
           71.43205845433596,
           71.45005432296497,
           71.46833037798719,
           71.48660643300943,
           71.50488248803164,
           71.52315854305385,
           71.5414345980761,
           71.55971065309832,
           71.57798670812053,
           71.59626276314276,
           71.614538818165,
           71.63281487318721,
           71.65109092820944,
           71.66936698323167,
           71.6876430382539,
           71.70591909327611,
           71.72419514829834,
           71.74247120332058,
           71.76074725834279,
           71.779023313365,
           71.79729936838723,
           71.81557542340946,
           71.83385147843168,
           71.85212753345391,
           71.87040358847614,
           71.88867964349836,
           71.90695569852059,
           71.92523175354282,
           71.94350780856503,
           71.96178386358726,
           71.98005991860948,
           71.9983359736317,
           72.01661202865392,
           72.03488808367615,
           72.05316413869838,
           72.0714401937206,
           72.08971624874283,
           72.10799230376506,
           72.12626835878729,
           72.14454441380951,
           72.16282046883173,
           72.18109652385394,
           72.19937257887618,
           72.2176486338984,
           72.23592468892062,
           72.25420074394285,
           72.27247679896507,
           72.2907528539873,
           72.30902890900953,
           72.32730496403175,
           72.34558101905397,
           72.3638570740762,
           72.38213312909842,
           72.40040918412065,
           72.41868523914287,
           72.4369612941651,
           72.45523734918731,
           72.47351340420954,
           72.49178945923177,
           72.510065514254,
           72.52834156927622,
           72.2190976489482,
           71.58233375326998,
           70.9455698575918,
           70.30880596191363,
           69.67204206623539,
           69.0352781705572,
           68.39851427487903,
           67.7617503792008,
           67.12498648352258,
           66.48822258784446,
           65.85145869216623,
           65.21469479648799,
           64.5779309008098,
           63.94116700513164,
           63.3044031094534,
           62.667639213775225,
           62.03087531809705,
           61.39411142241882,
           60.757347526740645,
           60.120583631062466,
           59.48381973538423,
           58.847055839706,
           58.21029194402788,
           57.573528048349644,
           56.936764152671415,
           56.30000025699324,
           55.663236361315064,
           55.02647246563683,
           54.38970856995866,
           53.75294467428048,
           53.11618077860224,
           52.47941688292401,
           51.8426529872459,
           51.20588909156766,
           50.56912519588942,
           49.93236130021125,
           49.29559740453307,
           48.65883350885484,
           48.02206961317666,
           47.38530571749848,
           46.74854182182025,
           46.11177792614207,
           45.475014030463896,
           44.83825013478566,
           44.201486239107425,
           43.56472234342931,
           42.927958447751074,
           42.29119455207284,
           41.654430656394666,
           41.01766676071649,
           40.38090286503826,
           39.74413896936008,
           39.1073750736819,
           38.470611178003665,
           37.833847282325436,
           37.197083386647314,
           36.560319490969086,
           35.92355559529085,
           35.28679169961268,
           34.6500278039345,
           34.00503274177514,
           33.35964570073665,
           32.71425865969816,
           32.06887161865961,
           31.423484577621117,
           30.778097536582628,
           30.13271049554408,
           29.487323454505532,
           28.841936413467103,
           28.19654937242855,
           27.551162331390003,
           26.905775290351514,
           26.260388249313028,
           25.61500120827447,
           24.969614167235985,
           24.324227126197496,
           23.678840085158946,
           23.033453044120456,
           22.388066003081967,
           21.742678962043417,
           21.097291921004867,
           20.451904879966378,
           19.80651783892789,
           19.32740584043053,
           19.180843927015435,
           19.03428201360034,
           18.88772010018523,
           18.741158186770136,
           18.59459627335504,
           18.448034359939932,
           18.30147244652482,
           18.15491053310974,
           18.00834861969463,
           17.86178670627952,
           17.715224792864426,
           17.568662879449327,
           17.42210096603422,
           17.275539052619123,
           17.12897713920403,
           16.98241522578892,
           16.83585331237382,
           16.689291398958726,
           16.542729485543617,
           16.39616757212851,
           16.249605658713413,
           16.10304374529832,
           15.956481831883208,
           15.809919918468111,
           15.663358005053016,
           15.516796091637906,
           15.37023417822281,
           15.223672264807716,
           15.077110351392607,
           14.930548437977496,
           14.783986524562414,
           14.637424611147305,
           14.490862697732197,
           14.341234437234768,
           14.187735584714023,
           14.034236732193264,
           13.88073787967252,
           13.727239027151773,
           13.573740174631014,
           13.420241322110268,
           13.266742469589525,
           13.113243617068765,
           12.959744764548006,
           12.806245912027261,
           12.652747059506515,
           12.499248206985758,
           12.34574935446501,
           12.192250501944265,
           12.038751649423508,
           11.885252796902762,
           11.731753944382017,
           11.578255091861257,
           11.424756239340498,
           11.271257386819768,
           11.117758534299007,
           10.964259681778248,
           10.810760829257504,
           10.65726197673676,
           10.503763124215999,
           10.350264271695256,
           10.19676541917451,
           10.04326656665375,
           9.889767714133004,
           9.73626886161226,
           9.582770009091501,
           9.429271156570742,
           9.27577230405001,
           9.122273451529251,
           8.968774599008492,
           8.815275746487746,
           8.661776893967001,
           8.508278041446243,
           8.354779188925496,
           8.201280336404752,
           8.047781483883993,
           7.894282631363232,
           7.740783778842503,
           7.587284926321744,
           7.433786073800984,
           7.280287221280239,
           7.1267883687594935,
           6.973289516238735,
           6.840447150091338,
           6.810887215810586,
           6.781327281529834,
           6.751767347249082,
           6.722207412968336,
           6.692647478687584,
           6.6630875444068325,
           6.633527610126086,
           6.603967675845334,
           6.574407741564581,
           6.544847807283835,
           6.515287873003083,
           6.485727938722331,
           6.4561680044415795,
           6.426608070160833,
           6.39704813588008,
           6.367488201599329,
           6.337928267318583,
           6.30836833303783,
           6.278808398757079,
           6.249248464476332,
           6.2196885301955795,
           6.190128595914827,
           6.160568661634081,
           6.131008727353329,
           6.101448793072578,
           6.071888858791825,
           6.042328924511079,
           6.012768990230327,
           5.983209055949575,
           5.953649121668829,
           5.924089187388077,
           5.894529253107324,
           5.864969318826578,
           5.835409384545826,
           5.805849450265074,
           5.776289515984322,
           5.746729581703576,
           5.717169647422824,
           5.687609713142071,
           5.658049778861326,
           5.6284898445805736,
           5.598929910299821,
           5.5693699760190745,
           5.539810041738322,
           5.510250107457571,
           5.480690173176824,
           5.451130238896073,
           5.4215703046153205,
           5.390801860862605,
           5.3598556970056395,
           5.328909533148669,
           5.297963369291699,
           5.267017205434732,
           5.236071041577762,
           5.205124877720792,
           5.174178713863826,
           5.1432325500068545,
           5.112286386149885,
           5.081340222292914,
           5.050394058435948,
           5.019447894578978,
           4.988501730722007,
           4.957555566865042,
           4.926609403008071,
           4.895663239151101,
           4.864717075294136,
           4.833770911437164,
           4.8028247475801935,
           4.771878583723229,
           4.740932419866258,
           4.709986256009287,
           4.6790400921523165,
           4.648093928295351,
           4.61714776443838,
           4.5862016005814095,
           4.555255436724444,
           4.524309272867473,
           4.493363109010503,
           4.462416945153538,
           4.431470781296567,
           4.400524617439596,
           4.369578453582625,
           4.338632289725661
          ],
          [
           63.69975104006746,
           63.75187887115206,
           63.804006702236656,
           63.85613453332127,
           63.90826236440587,
           63.96039019549047,
           64.01251802657507,
           64.06464585765966,
           64.11677368874427,
           64.16890151982886,
           64.22102935091348,
           64.27315718199807,
           64.32528501308268,
           64.37741284416728,
           64.42954067525187,
           64.48166850633649,
           64.53379633742108,
           64.58592416850568,
           64.63805199959029,
           64.69017983067488,
           64.74230766175948,
           64.79443549284409,
           64.84656332392868,
           64.8986911550133,
           64.95081898609789,
           65.00294681718249,
           65.0550746482671,
           65.10720247935168,
           65.1593303104363,
           65.2114581415209,
           65.2635859726055,
           65.3157138036901,
           65.36784163477469,
           65.41996946585931,
           65.4720972969439,
           65.5242251280285,
           65.57635295911311,
           65.6284807901977,
           65.68060862128232,
           65.73273645236691,
           65.78486428345151,
           65.8369921145361,
           65.8891199456207,
           65.94124777670531,
           65.99337560778991,
           66.04550343887452,
           66.09763126995911,
           66.14975910104371,
           66.20188693212832,
           66.25401476321292,
           66.30614259429751,
           66.35827042538213,
           66.41039825646673,
           66.46252608755132,
           66.51454813813557,
           66.56604128430557,
           66.61753443047562,
           66.66902757664562,
           66.72052072281564,
           66.77201386898568,
           66.82350701515568,
           66.87500016132572,
           66.92649330749573,
           66.97798645366575,
           67.02947959983578,
           67.08097274600581,
           67.13246589217583,
           67.18395903834585,
           67.23545218451588,
           67.28694533068591,
           67.33843847685593,
           67.38993162302594,
           67.44142476919598,
           67.492917915366,
           67.54441106153602,
           67.59590420770604,
           67.64739735387607,
           67.69889050004609,
           67.75038364621611,
           67.80187679238614,
           67.85336993855616,
           67.90486308472617,
           67.9563562308962,
           68.00784937706622,
           68.04889711092028,
           68.08785576231112,
           68.12681441370196,
           68.16577306509282,
           68.20473171648366,
           68.2436903678745,
           68.28264901926536,
           68.3216076706562,
           68.36056632204705,
           68.3995249734379,
           68.43848362482876,
           68.47744227621959,
           68.51640092761046,
           68.55535957900129,
           68.59431823039216,
           68.633276881783,
           68.67223553317385,
           68.7111941845647,
           68.75015283595555,
           68.78911148734639,
           68.82807013873725,
           68.86702879012809,
           68.90598744151893,
           68.94494609290979,
           68.98390474430065,
           69.02286339569147,
           69.06182204708233,
           69.10078069847319,
           69.13973934986403,
           69.17919148013468,
           69.21913708829389,
           69.25908269645312,
           69.29902830461234,
           69.33897391277154,
           69.37891952093076,
           69.41886512908998,
           69.45881073724918,
           69.4987563454084,
           69.53870195356762,
           69.57864756172683,
           69.61859316988604,
           69.65853877804525,
           69.69848438620448,
           69.73842999436368,
           69.7783756025229,
           69.81832121068211,
           69.85826681884133,
           69.89821242700054,
           69.93815803515977,
           69.97810364331899,
           70.0180492514782,
           70.0579948596374,
           70.09794046779662,
           70.13788607595583,
           70.17783168411506,
           70.21777729227426,
           70.25772290043349,
           70.29766850859271,
           70.33761411675192,
           70.37755972491112,
           70.41750533307035,
           70.45745094122955,
           70.49739654938878,
           70.537342157548,
           70.57728776570721,
           70.61723337386643,
           70.65717898202564,
           70.69712459018484,
           70.73707019834407,
           70.77701580650327,
           70.8169614146625,
           70.85690702282172,
           70.89685263098093,
           70.93679823914013,
           70.97674384729935,
           71.01668945545856,
           71.05663506361778,
           71.09658067177699,
           71.13652627993622,
           71.17647188809542,
           71.21641749625465,
           71.25636310441385,
           71.29630871257308,
           71.31695123877267,
           71.3279422239925,
           71.3389332092123,
           71.3499241944321,
           71.36091517965193,
           71.37190616487173,
           71.38289715009154,
           71.39388813531134,
           71.40487912053116,
           71.41587010575097,
           71.42686109097077,
           71.43785207619058,
           71.4488430614104,
           71.45983404663019,
           71.47082503185001,
           71.48181601706983,
           71.49280700228962,
           71.50379798750944,
           71.51478897272924,
           71.52577995794906,
           71.53677094316886,
           71.54776192838868,
           71.55875291360849,
           71.56974389882829,
           71.5807348840481,
           71.59172586926792,
           71.60271685448772,
           71.61370783970753,
           71.62469882492734,
           71.63568981014714,
           71.64668079536695,
           71.65767178058678,
           71.66866276580657,
           71.6796537510264,
           71.6906447362462,
           71.70163572146599,
           71.71262670668582,
           71.72361769190562,
           71.73460867712542,
           71.74559966234523,
           71.75659064756505,
           71.76758163278485,
           71.77857261800466,
           71.78956360322448,
           71.80055458844429,
           71.81154557366409,
           71.8225365588839,
           71.83352754410372,
           71.84451852932352,
           71.85550951454333,
           71.86650049976313,
           71.87749148498294,
           71.89408637652326,
           71.9123624315455,
           71.93063848656772,
           71.94891454158996,
           71.96719059661216,
           71.9854666516344,
           72.00374270665662,
           72.02201876167884,
           72.04029481670106,
           72.0585708717233,
           72.07684692674552,
           72.09512298176774,
           72.11339903678997,
           72.13167509181218,
           72.14995114683441,
           72.16822720185664,
           72.18650325687886,
           72.20477931190109,
           72.22305536692332,
           72.24133142194555,
           72.25960747696776,
           72.27788353199,
           72.29615958701221,
           72.31443564203444,
           72.33271169705667,
           72.3509877520789,
           72.36926380710109,
           72.38753986212335,
           72.40581591714556,
           72.42409197216779,
           72.44236802719001,
           72.13312410686201,
           71.49636021118377,
           70.8595963155056,
           70.22283241982743,
           69.58606852414918,
           68.94930462847101,
           68.31254073279283,
           67.6757768371146,
           67.03901294143637,
           66.40224904575825,
           65.76548515008001,
           65.12872125440178,
           64.4919573587236,
           63.85519346304543,
           63.21842956736719,
           62.58166567168902,
           61.944901776010845,
           61.30813788033261,
           60.67137398465444,
           60.03461008897626,
           59.39784619329802,
           58.76108229761979,
           58.12431840194167,
           57.487554506263436,
           56.85079061058521,
           56.214026714907035,
           55.57726281922886,
           54.94049892355062,
           54.30373502787244,
           53.66697113219426,
           53.030207236516034,
           52.38736795449885,
           51.741980913460424,
           51.09659387242187,
           50.451206831383324,
           49.805819790344835,
           49.160432749306345,
           48.5150457082678,
           47.8696586672293,
           47.22427162619081,
           46.57888458515227,
           45.93349754411378,
           45.288110503075295,
           44.64272346203675,
           43.99733642099819,
           43.35194937995976,
           42.70656233892121,
           42.06117529788266,
           41.41578825684417,
           40.770401215805684,
           40.12501417476714,
           39.47962713372864,
           38.83424009269015,
           38.188853051651606,
           37.54346601061306,
           36.89807896957463,
           36.25269192853608,
           35.60730488749753,
           34.96191784645904,
           34.316530805420555,
           33.671143764382,
           33.02575672334351,
           32.380369682305016,
           31.734982641266473,
           31.08959560022798,
           30.44420855918949,
           29.79882151815094,
           29.153434477112395,
           28.508047436073966,
           27.862660395035412,
           27.217273353996866,
           26.571886312958377,
           25.926499271919887,
           25.281112230881334,
           24.635725189842848,
           23.99033814880436,
           23.34495110776581,
           22.69956406672732,
           22.05417702568883,
           21.408789984650284,
           20.76340294361173,
           20.11801590257324,
           19.47262886153475,
           18.993516863037392,
           18.846954949622297,
           18.700393036207203,
           18.553831122792094,
           18.407269209377,
           18.2607072959619,
           18.114145382546795,
           17.967583469131686,
           17.821021555716605,
           17.674459642301493,
           17.52789772888638,
           17.38133581547129,
           17.234773902056194,
           17.088211988641085,
           16.941650075225986,
           16.79508816181089,
           16.648526248395783,
           16.501964334980688,
           16.355402421565593,
           16.20884050815048,
           16.062278594735368,
           15.915716681320275,
           15.76915476790518,
           15.62259285449007,
           15.476030941074974,
           15.329469027659878,
           15.182907114244768,
           15.036345200829674,
           14.889783287414577,
           14.743221373999468,
           14.596659460584359,
           14.450097547169277,
           14.30353563375417,
           14.156973720339058,
           14.010411806923962,
           13.863849893508867,
           13.717287980093758,
           13.570726066678663,
           13.424164153263565,
           13.277602239848456,
           13.13104032643336,
           12.984478413018264,
           12.837916499603157,
           12.691354586188044,
           12.54479267277295,
           12.398230759357855,
           12.251668845942746,
           12.10510693252765,
           11.958545019112552,
           11.811983105697445,
           11.665421192282349,
           11.518859278867254,
           11.372297365452143,
           11.225735452037034,
           11.079173538621951,
           10.932611625206844,
           10.786049711791732,
           10.639487798376638,
           10.492925884961542,
           10.346363971546431,
           10.199802058131336,
           10.053240144716241,
           9.90667823130113,
           9.760116317886036,
           9.613554404470941,
           9.46699249105583,
           9.320430577640721,
           9.173868664225639,
           9.027306750810528,
           8.88074483739542,
           8.734182923980324,
           8.587621010565229,
           8.44105909715012,
           8.294497183735025,
           8.147935270319929,
           8.00004125361881,
           7.846542401098052,
           7.693043548577321,
           7.539544696056561,
           7.386045843535803,
           7.232546991015058,
           7.079048138494311,
           6.925549285973553,
           6.7927069198261565,
           6.763146985545405,
           6.733587051264652,
           6.704027116983901,
           6.674467182703154,
           6.6449072484224025,
           6.61534731414165,
           6.585787379860904,
           6.556227445580152,
           6.526667511299401,
           6.497107577018653,
           6.467547642737902,
           6.4379877084571495,
           6.408427774176397,
           6.37886783989565,
           6.3493079056149,
           6.319747971334148,
           6.290188037053401,
           6.260628102772649,
           6.2310681684918965,
           6.20150823421115,
           6.171948299930397,
           6.142388365649646,
           6.1128284313689,
           6.083268497088147,
           6.053708562807396,
           6.0241486285266435,
           5.994588694245897,
           5.965028759965144,
           5.935468825684394,
           5.905908891403646,
           5.876348957122895,
           5.846789022842143,
           5.817229088561396,
           5.787669154280644,
           5.758109219999893,
           5.72854928571914,
           5.698989351438394,
           5.669429417157642,
           5.63986948287689,
           5.610309548596144,
           5.580749614315391,
           5.551189680034639,
           5.521629745753893,
           5.492069811473141,
           5.462509877192389,
           5.432949942911643,
           5.403390008630891,
           5.373830074350138,
           5.344270140069387,
           5.314710205788639,
           5.285150271507888,
           5.255590337227136,
           5.22603040294639,
           5.1964704686656376,
           5.166910534384885,
           5.1373506001041385,
           5.107790665823387,
           5.078230731542636,
           5.048670797261884,
           5.019110862981137,
           4.9895509287003845,
           4.959990994419632,
           4.930431060138886,
           4.900871125858134,
           4.871311191577382,
           4.841751257296636,
           4.812191323015884,
           4.782631388735132,
           4.7530714544543855,
           4.723511520173634,
           4.693951585892881,
           4.66439165161213,
           4.634831717331383,
           4.605271783050632,
           4.5757118487698785,
           4.5461519144891325,
           4.51659198020838,
           4.486090119471149,
           4.455143955614184,
           4.424197791757214,
           4.393251627900242,
           4.3623054640432715,
           4.331359300186307
          ],
          [
           63.85320258737614,
           63.905330418460736,
           63.95745824954534,
           64.00958608062994,
           64.06171391171455,
           64.11384174279914,
           64.16596957388374,
           64.21809740496835,
           64.27022523605295,
           64.32235306713756,
           64.37448089822215,
           64.42660872930675,
           64.47873656039135,
           64.53086439147596,
           64.58299222256056,
           64.63512005364515,
           64.68724788472976,
           64.73937571581436,
           64.79150354689897,
           64.84363137798357,
           64.89575920906816,
           64.94788704015276,
           65.00001487123735,
           65.05214270232196,
           65.10427053340656,
           65.15639836449117,
           65.20852619557577,
           65.26065402666036,
           65.31278185774498,
           65.36490968882957,
           65.41703751991417,
           65.46916535099878,
           65.52129318208337,
           65.57342101316799,
           65.62554884425258,
           65.67767667533718,
           65.72980450642179,
           65.78193233750638,
           65.8336370455286,
           65.88513019169862,
           65.93662333786864,
           65.98811648403867,
           66.03960963020869,
           66.09110277637872,
           66.14259592254874,
           66.19408906871875,
           66.24558221488878,
           66.2970753610588,
           66.34856850722883,
           66.40006165339885,
           66.45155479956888,
           66.5030479457389,
           66.55454109190893,
           66.60603423807895,
           66.65752738424898,
           66.709020530419,
           66.76051367658903,
           66.81200682275905,
           66.86349996892906,
           66.9149931150991,
           66.96648626126911,
           67.01797940743914,
           67.06947255360916,
           67.12096569977918,
           67.17245884594921,
           67.22395199211923,
           67.27544513828926,
           67.32693828445927,
           67.37843143062929,
           67.42992457679932,
           67.48141772296934,
           67.53291086913937,
           67.58440401530939,
           67.63589716147942,
           67.68739030764944,
           67.73888345381945,
           67.79037659998949,
           67.8418697461595,
           67.89336289232952,
           67.94485603849955,
           67.99634918466958,
           68.04784233083959,
           68.09933547700962,
           68.15082862317965,
           68.19187635703369,
           68.23083500842453,
           68.26979365981538,
           68.30875231120623,
           68.34771096259709,
           68.38666961398792,
           68.42562826537878,
           68.46458691676963,
           68.50354556816048,
           68.54250421955132,
           68.58146287094218,
           68.62042152233302,
           68.65938017372387,
           68.69833882511472,
           68.73729747650557,
           68.77625612789642,
           68.81521477928726,
           68.85417343067812,
           68.89313208206896,
           68.93209073345982,
           68.97104938485066,
           69.0100080362415,
           69.04896668763234,
           69.0879253390232,
           69.12688399041406,
           69.1658426418049,
           69.20480129319574,
           69.2437599445866,
           69.28271859597744,
           69.3216772473683,
           69.36063589875914,
           69.39959455015,
           69.43855320154084,
           69.47751185293168,
           69.51647050432254,
           69.55542915571338,
           69.59438780710424,
           69.63334645849507,
           69.67230510988593,
           69.71126376127678,
           69.75022241266763,
           69.78918106405848,
           69.82813971544931,
           69.86709836684017,
           69.90605701823102,
           69.94501566995464,
           69.98496127811386,
           70.02490688627307,
           70.06485249443229,
           70.1047981025915,
           70.14474371075072,
           70.18468931890992,
           70.22463492706915,
           70.26458053522836,
           70.30452614338758,
           70.34447175154679,
           70.384417359706,
           70.42436296786522,
           70.46430857602444,
           70.50425418418365,
           70.54419979234287,
           70.58414540050208,
           70.6240910086613,
           70.66403661682051,
           70.70398222497973,
           70.74392783313894,
           70.78387344129816,
           70.82381904945737,
           70.86376465761658,
           70.9037102657758,
           70.94365587393501,
           70.98360148209423,
           71.02354709025344,
           71.06349269841266,
           71.10343830657187,
           71.14338391473109,
           71.1833295228903,
           71.22327513104952,
           71.26322073920873,
           71.30316634736795,
           71.34311195552716,
           71.38305756368638,
           71.4230031718456,
           71.44364569804522,
           71.45463668326502,
           71.46562766848483,
           71.47661865370463,
           71.48760963892444,
           71.49860062414426,
           71.50959160936407,
           71.52058259458387,
           71.53157357980368,
           71.5425645650235,
           71.5535555502433,
           71.56454653546311,
           71.57553752068291,
           71.58652850590272,
           71.59751949112254,
           71.60851047634235,
           71.61950146156215,
           71.63049244678197,
           71.64148343200178,
           71.65247441722158,
           71.66346540244139,
           71.67445638766121,
           71.68544737288101,
           71.69643835810082,
           71.70742934332063,
           71.71842032854043,
           71.72941131376025,
           71.74040229898006,
           71.75139328419988,
           71.76238426941967,
           71.77337525463949,
           71.7843662398593,
           71.7953572250791,
           71.8063482102989,
           71.81733919551871,
           71.82833018073852,
           71.83932116595834,
           71.85031215117814,
           71.86130313639794,
           71.87229412161777,
           71.88328510683758,
           71.89427609205738,
           71.90526707727719,
           71.916258062497,
           71.9272490477168,
           71.93824003293662,
           71.94923101815642,
           71.96022200337623,
           71.97121298859605,
           71.98220397381586,
           71.99319495903566,
           72.00418594425547,
           72.01517692947529,
           72.0261679146951,
           72.0371588999149,
           72.0481498851347,
           72.05914087035453,
           72.07013185557432,
           72.08112284079414,
           72.09211382601396,
           72.10310481123375,
           72.11409579645357,
           72.12508678167337,
           72.13607776689318,
           72.14706875211299,
           72.1580597373328,
           72.16905072255261,
           72.18004170777242,
           72.19103269299224,
           72.20202367821203,
           72.21301466343184,
           72.22400564865166,
           72.23499663387146,
           72.24598761909127,
           72.25697860431107,
           72.26796958953089,
           72.2789605747507,
           72.28995155997052,
           72.30094254519032,
           72.31193353041012,
           72.32292451562994,
           72.33811843008158,
           72.3563944851038,
           72.04715056477579,
           71.41038666909758,
           70.76970316722263,
           70.12431612618415,
           69.47892908514561,
           68.83354204410712,
           68.18815500306863,
           67.54276796203007,
           66.89738092099152,
           66.2519938799531,
           65.60660683891454,
           64.961219797876,
           64.31583275683751,
           63.67044571579902,
           63.025058674760466,
           62.379671633721976,
           61.73428459268349,
           61.08889755164493,
           60.443510510606444,
           59.798123469567955,
           59.15273642852941,
           58.50734938749086,
           57.86196234645243,
           57.21657530541388,
           56.57118826437534,
           55.92580122333685,
           55.28041418229836,
           54.63502714125981,
           53.989640100221315,
           53.344253059182826,
           52.69886601814428,
           52.053478977105726,
           51.4080919360673,
           50.76270489502875,
           50.1173178539902,
           49.47193081295171,
           48.82654377191322,
           48.181156730874676,
           47.53576968983619,
           46.89038264879769,
           46.244995607759144,
           45.599608566720654,
           44.954221525682165,
           44.30883448464362,
           43.663447443605065,
           43.01806040256664,
           42.372673361528086,
           41.72728632048954,
           41.08189927945105,
           40.43651223841256,
           39.791125197374015,
           39.14573815633552,
           38.500351115297036,
           37.85496407425848,
           37.20957703321994,
           36.564189992181504,
           35.91880295114295,
           35.273415910104404,
           34.628028869065915,
           33.982641828027425,
           33.33725478698888,
           32.69186774595039,
           32.0464807049119,
           31.401093663873347,
           30.755706622834857,
           30.110319581796368,
           29.464932540757818,
           28.81954549971927,
           28.174158458680843,
           27.528771417642293,
           26.88338437660374,
           26.237997335565254,
           25.592610294526764,
           24.94722325348821,
           24.30183621244972,
           23.656449171411236,
           23.011062130372686,
           22.365675089334193,
           21.720288048295707,
           21.074901007257154,
           20.42951396621861,
           19.784126925180114,
           19.13873988414163,
           18.659627885644273,
           18.513065972229175,
           18.36650405881408,
           18.21994214539897,
           18.073380231983876,
           17.92681831856878,
           17.78025640515367,
           17.63369449173856,
           17.48713257832348,
           17.34057066490837,
           17.19400875149326,
           17.047446838078162,
           16.900884924663067,
           16.75432301124796,
           16.609892053210793,
           16.4666787603353,
           16.32346546745979,
           16.1802521745843,
           16.037038881708806,
           15.893825588833298,
           15.750612295957794,
           15.607399003082298,
           15.464185710206806,
           15.3209724173313,
           15.177759124455807,
           15.034545831580314,
           14.891332538704809,
           14.748119245829315,
           14.604905952953821,
           14.461692660078313,
           14.318479367202809,
           14.175266074327329,
           14.032052781451823,
           13.888839488576316,
           13.745626195700824,
           13.602412902825328,
           13.459199609949824,
           13.315986317074332,
           13.172773024198836,
           13.02955973132333,
           12.886346438447838,
           12.743133145572344,
           12.59991985269684,
           12.456706559821331,
           12.31349326694584,
           12.170279974070347,
           12.027066681194839,
           11.883853388319345,
           11.740640095443853,
           11.597426802568345,
           11.454213509692854,
           11.31100021681736,
           11.167786923941854,
           11.024573631066346,
           10.881360338190868,
           10.738147045315362,
           10.594933752439854,
           10.45172045956436,
           10.308507166688868,
           10.165293873813361,
           10.02208058093787,
           9.878867288062375,
           9.735653995186869,
           9.592440702311377,
           9.449227409435883,
           9.306014116560377,
           9.16280082368487,
           9.01958753080939,
           8.876374237933884,
           8.73316094505838,
           8.589947652182886,
           8.44673435930739,
           8.303521066431886,
           8.160307773556392,
           8.0170944806809,
           7.8738811878053925,
           7.730667894929885,
           7.5874546020544065,
           7.444241309178899,
           7.301028016303393,
           7.1578147234279,
           7.014601430552408,
           6.8713881376769015,
           6.7471170712338795,
           6.717557136953127,
           6.687997202672376,
           6.658437268391623,
           6.628877334110877,
           6.599317399830125,
           6.569757465549374,
           6.5401975312686265,
           6.510637596987875,
           6.481077662707123,
           6.451517728426376,
           6.421957794145624,
           6.392397859864872,
           6.36283792558412,
           6.333277991303373,
           6.303718057022622,
           6.27415812274187,
           6.244598188461124,
           6.215038254180371,
           6.1854783198996195,
           6.155918385618873,
           6.12635845133812,
           6.096798517057369,
           6.067238582776622,
           6.03767864849587,
           6.008118714215119,
           5.978558779934366,
           5.94899884565362,
           5.919438911372867,
           5.889878977092116,
           5.860319042811369,
           5.830759108530618,
           5.801199174249866,
           5.771639239969119,
           5.742079305688367,
           5.712519371407616,
           5.682959437126863,
           5.653399502846117,
           5.623839568565365,
           5.594279634284613,
           5.564719700003867,
           5.535159765723114,
           5.505599831442362,
           5.476039897161615,
           5.446479962880864,
           5.416920028600112,
           5.387360094319366,
           5.357800160038613,
           5.328240225757861,
           5.29868029147711,
           5.269120357196362,
           5.239560422915611,
           5.210000488634859,
           5.180440554354112,
           5.150880620073361,
           5.121320685792608,
           5.091760751511862,
           5.06220081723111,
           5.032640882950358,
           5.003080948669607,
           4.97418086047397,
           4.945907627555939,
           4.9176343946379095,
           4.889361161719885,
           4.861087928801855,
           4.832814695883825,
           4.8045414629658,
           4.776268230047769,
           4.74799499712974,
           4.719721764211714,
           4.691448531293684,
           4.663175298375655,
           4.6349020654576245,
           4.6066288325396,
           4.5783555996215695,
           4.550082366703539,
           4.521809133785514,
           4.493535900867485,
           4.465262667949454,
           4.436989435031429,
           4.4087162021134,
           4.38044296919537,
           4.3521697362773395,
           4.323896503359315
          ],
          [
           64.00665413468482,
           64.05878196576941,
           64.11090979685402,
           64.16303762793862,
           64.21516545902321,
           64.26729329010783,
           64.31942112119242,
           64.37154895227702,
           64.42367678336163,
           64.47580461444622,
           64.52793244553084,
           64.58006027661543,
           64.63218810770003,
           64.68431593878464,
           64.73644376986924,
           64.78857160095383,
           64.84069943203843,
           64.89282726312304,
           64.94495509420763,
           64.99708292529225,
           65.04921075637685,
           65.10123280675163,
           65.15272595292166,
           65.20421909909167,
           65.25571224526169,
           65.30720539143172,
           65.35869853760174,
           65.41019168377176,
           65.46168482994179,
           65.5131779761118,
           65.56467112228184,
           65.61616426845185,
           65.66765741462187,
           65.7191505607919,
           65.77064370696193,
           65.82213685313195,
           65.87362999930197,
           65.925123145472,
           65.97661629164202,
           66.02810943781203,
           66.07960258398207,
           66.13109573015208,
           66.18258887632211,
           66.23408202249213,
           66.28557516866215,
           66.33706831483218,
           66.3885614610022,
           66.44005460717224,
           66.49154775334225,
           66.54304089951228,
           66.59453404568231,
           66.64602719185231,
           66.69752033802234,
           66.74901348419237,
           66.80050663036239,
           66.85199977653241,
           66.90349292270244,
           66.95498606887247,
           67.00647921504249,
           67.0579723612125,
           67.10946550738254,
           67.16095865355256,
           67.21245179972257,
           67.2639449458926,
           67.31543809206262,
           67.36693123823265,
           67.41842438440267,
           67.4699175305727,
           67.52141067674272,
           67.57290382291274,
           67.62439696908277,
           67.67589011525278,
           67.72738326142282,
           67.77887640759283,
           67.83036955376286,
           67.88186269993288,
           67.9333558461029,
           67.98484899227293,
           68.03634213844295,
           68.08783528461298,
           68.139328430783,
           68.19082157695301,
           68.24231472312304,
           68.29380786929306,
           68.3348556031471,
           68.37381425453796,
           68.4127729059288,
           68.45173155731966,
           68.4906902087105,
           68.52964886010135,
           68.56860751149219,
           68.60756616288305,
           68.64652481427389,
           68.68548346566475,
           68.72444211705559,
           68.76340076844643,
           68.80235941983729,
           68.84131807122814,
           68.88027672261899,
           68.91923537400984,
           68.95819402540069,
           68.99715267679153,
           69.03611132818239,
           69.07506997957323,
           69.11402863096407,
           69.15298728235493,
           69.19194593374577,
           69.23090458513661,
           69.26986323652747,
           69.30882188791831,
           69.34778053930917,
           69.38673919070001,
           69.42569784209086,
           69.46465649348171,
           69.50361514487255,
           69.54257379626341,
           69.58153244765425,
           69.6204910990451,
           69.65944975043595,
           69.6984084018268,
           69.73736705321767,
           69.7763257046085,
           69.81528435599935,
           69.85424300739021,
           69.89320165878104,
           69.9321603101719,
           69.97111896156274,
           70.0100776129536,
           70.04903626434444,
           70.0879949157353,
           70.12695356712614,
           70.16591221851698,
           70.20487086990782,
           70.24382952129868,
           70.28278817268954,
           70.32174682408038,
           70.36070547547122,
           70.39966412686208,
           70.43862277825292,
           70.47758142964378,
           70.51654008103462,
           70.55549873242548,
           70.59445738381632,
           70.63341603520716,
           70.67237468659802,
           70.71133333798886,
           70.75078546793382,
           70.79073107609304,
           70.83067668425225,
           70.87062229241147,
           70.91056790057068,
           70.95051350872988,
           70.99045911688911,
           71.03040472504833,
           71.07035033320754,
           71.11029594136676,
           71.15024154952597,
           71.19018715768519,
           71.2301327658444,
           71.27007837400362,
           71.31002398216283,
           71.34996959032205,
           71.38991519848126,
           71.42986080664048,
           71.46980641479969,
           71.5097520229589,
           71.54969763111812,
           71.57034015731773,
           71.58133114253754,
           71.59232212775736,
           71.60331311297716,
           71.61430409819697,
           71.62529508341677,
           71.6362860686366,
           71.6472770538564,
           71.6582680390762,
           71.66925902429601,
           71.68025000951583,
           71.69124099473564,
           71.70223197995544,
           71.71322296517525,
           71.72421395039507,
           71.73520493561487,
           71.74619592083468,
           71.7571869060545,
           71.76817789127429,
           71.77916887649411,
           71.7901598617139,
           71.80115084693372,
           71.81214183215354,
           71.82313281737335,
           71.83412380259315,
           71.84511478781295,
           71.85610577303277,
           71.86709675825257,
           71.87808774347239,
           71.8890787286922,
           71.900069713912,
           71.91106069913181,
           71.92205168435162,
           71.93304266957144,
           71.94403365479126,
           71.95502464001105,
           71.96601562523087,
           71.97700661045069,
           71.98799759567046,
           71.9989885808903,
           72.00997956611009,
           72.0209705513299,
           72.0319615365497,
           72.04295252176952,
           72.05394350698933,
           72.06493449220915,
           72.07592547742895,
           72.08691646264876,
           72.09108909527318,
           72.092988938899,
           72.09488878252483,
           72.09678862615067,
           72.09868846977649,
           72.10058831340231,
           72.10248815702815,
           72.10438800065397,
           72.10628784427979,
           72.10818768790563,
           72.11008753153145,
           72.11198737515728,
           72.1138872187831,
           72.11578706240893,
           72.11768690603478,
           72.11958674966058,
           72.12148659328642,
           72.12338643691224,
           72.12528628053806,
           72.1271861241639,
           72.12908596778972,
           72.13098581141554,
           72.13288565504138,
           72.13478549866721,
           72.13668534229303,
           72.13858518591886,
           72.14048502954469,
           72.14238487317051,
           72.14428471679634,
           72.14618456042217,
           72.14808440404799,
           72.14998424767381,
           72.15188409129965,
           72.15378393492547,
           72.15568377855129,
           71.83207913862094,
           71.1829700151344,
           70.53386089164793,
           69.88475176816145,
           69.23564264467491,
           68.58653352118844,
           67.93742439770196,
           67.28831527421544,
           66.6392061507289,
           65.99009702724248,
           65.34098790375594,
           64.6918787802694,
           64.04276965678292,
           63.393660533296455,
           62.74455140980992,
           62.09544228632345,
           61.446333162836964,
           60.79722403935043,
           60.14811491586396,
           59.49900579237748,
           58.84989666889094,
           58.2007875454044,
           57.55167842191799,
           56.90256929843146,
           56.25346017494493,
           55.6055423165601,
           54.9601393479062,
           54.31473637925225,
           53.66933341059837,
           53.02393044194447,
           52.378527473290525,
           51.73312450463657,
           51.087721535982745,
           50.4423185673288,
           49.79691559867486,
           49.15151263002096,
           48.50610966136708,
           47.86070669271313,
           47.21530372405923,
           46.56990075540534,
           45.9244977867514,
           45.279094818097505,
           44.63369184944362,
           43.988288880789675,
           43.34288591213571,
           42.69748294348189,
           42.05207997482794,
           41.40667700617399,
           40.7612740375201,
           40.11587106886621,
           39.470468100212265,
           38.82506513155838,
           38.17966216290449,
           37.53425919425054,
           36.88885622559659,
           36.243453256942765,
           35.59805028828881,
           34.95264731963486,
           34.30724435098097,
           33.66184138232708,
           33.016438413673136,
           32.37103544501925,
           31.725632476365355,
           31.08022950771141,
           30.434826539057518,
           29.78942357040363,
           29.14402060174968,
           28.498617633095733,
           27.853214664441904,
           27.20781169578796,
           26.56240872713401,
           25.91700575848012,
           25.27160278982623,
           24.62619982117228,
           23.98079685251839,
           23.335393883864505,
           22.689990915210554,
           22.044587946556664,
           21.399184977902777,
           20.753782009248823,
           20.108379040594876,
           19.46297607194099,
           18.8175731032871,
           18.341634222512422,
           18.204623517496152,
           18.06761281247989,
           17.93060210746361,
           17.793591402447348,
           17.65658069743108,
           17.5195699924148,
           17.38255928739853,
           17.245548582382273,
           17.108537877365993,
           16.971527172349717,
           16.83451646733345,
           16.697505762317185,
           16.560495057300905,
           16.423484352284643,
           16.28647364726838,
           16.1494629422521,
           16.012452237235834,
           15.875441532219568,
           15.73843082720329,
           15.601420122187013,
           15.46440941717075,
           15.32739871215448,
           15.190388007138203,
           15.05337730212194,
           14.916366597105675,
           14.779355892089395,
           14.642345187073131,
           14.505334482056865,
           14.368323777040587,
           14.231313072024307,
           14.094302367008057,
           13.957291661991778,
           13.8202809569755,
           13.683270251959234,
           13.54625954694297,
           13.409248841926692,
           13.270915890103801,
           13.127702597228309,
           12.9844893043528,
           12.84127601147731,
           12.698062718601813,
           12.55484942572631,
           12.411636132850802,
           12.26842283997531,
           12.125209547099816,
           11.98199625422431,
           11.838782961348816,
           11.695569668473325,
           11.552356375597817,
           11.409143082722327,
           11.26592978984683,
           11.122716496971325,
           10.979503204095819,
           10.836289911220339,
           10.69307661834483,
           10.549863325469326,
           10.406650032593832,
           10.26343673971834,
           10.120223446842832,
           9.977010153967342,
           9.833796861091844,
           9.69058356821634,
           9.547370275340846,
           9.404156982465356,
           9.260943689589848,
           9.11773039671434,
           8.97451710383886,
           8.831303810963357,
           8.688090518087847,
           8.544877225212357,
           8.401663932336861,
           8.258450639461358,
           8.115237346585863,
           7.972024053710371,
           7.828810760834862,
           7.685597467959356,
           7.5423841750838765,
           7.399170882208372,
           7.255957589332865,
           7.112744296457372,
           6.969531003581877,
           6.826317710706375,
           6.702046644263351,
           6.672486709982599,
           6.642926775701847,
           6.6133668414210955,
           6.583806907140348,
           6.5542469728595965,
           6.524687038578845,
           6.495127104298098,
           6.465567170017346,
           6.436007235736595,
           6.406447301455847,
           6.376887367175096,
           6.347327432894343,
           6.317767498613592,
           6.288207564332845,
           6.258647630052094,
           6.229087695771342,
           6.199527761490595,
           6.169967827209843,
           6.14040789292909,
           6.110847958648344,
           6.081288024367591,
           6.05172809008684,
           6.022168155806094,
           5.992608221525342,
           5.96304828724459,
           5.933488352963837,
           5.903928418683091,
           5.874368484402339,
           5.844808550121587,
           5.815248615840841,
           5.786595970590571,
           5.75832273767254,
           5.730049504754515,
           5.7017762718364855,
           5.673503038918456,
           5.645229806000425,
           5.616956573082401,
           5.588683340164371,
           5.56041010724634,
           5.532136874328315,
           5.503863641410286,
           5.475590408492256,
           5.447317175574232,
           5.4190439426562005,
           5.39077070973817,
           5.362497476820145,
           5.334224243902116,
           5.305951010984086,
           5.277677778066055,
           5.249404545148031,
           5.221131312230001,
           5.192858079311971,
           5.164584846393946,
           5.1363116134759155,
           5.108038380557885,
           5.07976514763986,
           5.05149191472183,
           5.023218681803801,
           4.994945448885771,
           4.966672215967746,
           4.938398983049716,
           4.9101257501316855,
           4.881852517213661,
           4.8535792842956305,
           4.8253060513776,
           4.797032818459575,
           4.768759585541545,
           4.740486352623516,
           4.71221311970549,
           4.68393988678746,
           4.65566665386943,
           4.6273934209514005,
           4.599120188033375,
           4.5708469551153454,
           4.542573722197315,
           4.51430048927929,
           4.486027256361261,
           4.45775402344323,
           4.429480790525205,
           4.401207557607176,
           4.372934324689146,
           4.3446610917711155,
           4.316387858853091
          ],
          [
           64.1601056819935,
           64.2122335130781,
           64.2643613441627,
           64.3164891752473,
           64.36861700633192,
           64.42032171414468,
           64.4718148603147,
           64.52330800648471,
           64.57480115265474,
           64.62629429882476,
           64.67778744499479,
           64.72928059116481,
           64.78077373733484,
           64.83226688350486,
           64.88376002967489,
           64.9352531758449,
           64.98674632201492,
           65.03823946818495,
           65.08973261435497,
           65.14122576052499,
           65.19271890669502,
           65.24421205286504,
           65.29570519903507,
           65.34719834520509,
           65.39869149137512,
           65.45018463754514,
           65.50167778371517,
           65.55317092988518,
           65.6046640760552,
           65.65615722222523,
           65.70765036839525,
           65.75914351456527,
           65.8106366607353,
           65.86212980690533,
           65.91362295307535,
           65.96511609924536,
           66.0166092454154,
           66.06810239158541,
           66.11959553775544,
           66.17108868392546,
           66.22258183009548,
           66.27407497626551,
           66.32556812243553,
           66.37706126860556,
           66.42855441477558,
           66.48004756094561,
           66.53154070711562,
           66.58303385328566,
           66.63452699945567,
           66.6860201456257,
           66.73751329179572,
           66.78900643796574,
           66.84049958413577,
           66.89199273030579,
           66.94348587647582,
           66.99497902264584,
           67.04647216881587,
           67.09796531498588,
           67.1494584611559,
           67.20095160732593,
           67.25244475349595,
           67.30393789966598,
           67.355431045836,
           67.40692419200602,
           67.45841733817605,
           67.50991048434607,
           67.5614036305161,
           67.61289677668611,
           67.66438992285615,
           67.71588306902616,
           67.7673762151962,
           67.81886936136621,
           67.87036250753623,
           67.92185565370626,
           67.97334879987628,
           68.0248419460463,
           68.07633509221633,
           68.12782823838634,
           68.17932138455637,
           68.23081453072639,
           68.28230767689642,
           68.33380082306644,
           68.38529396923646,
           68.43678711540649,
           68.47783484926052,
           68.51679350065137,
           68.55575215204222,
           68.59471080343307,
           68.63366945482392,
           68.67262810621477,
           68.71158675760562,
           68.75054540899647,
           68.78950406038732,
           68.82846271177817,
           68.86742136316902,
           68.90638001455986,
           68.94533866595071,
           68.98429731734156,
           69.02325596873241,
           69.06221462012326,
           69.1011732715141,
           69.14013192290496,
           69.17909057429581,
           69.21804922568666,
           69.2570078770775,
           69.29596652846836,
           69.33492517985918,
           69.37388383125004,
           69.4128424826409,
           69.45180113403174,
           69.49075978542258,
           69.52971843681344,
           69.56867708820428,
           69.60763573959514,
           69.64659439098598,
           69.68555304237684,
           69.72451169376767,
           69.76347034515852,
           69.80242899654938,
           69.84138764794022,
           69.88034629933108,
           69.91930495072192,
           69.95826360211278,
           69.99722225350362,
           70.03618090489447,
           70.07513955628532,
           70.11409820767616,
           70.15305685906701,
           70.19201551045786,
           70.2309741618487,
           70.26993281323955,
           70.3088914646304,
           70.34785011602125,
           70.38680876741209,
           70.42576741880295,
           70.4647260701938,
           70.50368472158465,
           70.54264337297549,
           70.58160202436635,
           70.62056067575719,
           70.65951932714805,
           70.69847797853889,
           70.73743662992975,
           70.77639528132059,
           70.81535393271143,
           70.85431258410229,
           70.89327123549313,
           70.93222988688397,
           70.97118853827483,
           71.01014718966567,
           71.04910584105653,
           71.08806449244737,
           71.12702314383823,
           71.16598179522907,
           71.20494044661991,
           71.24389909801077,
           71.28285774940161,
           71.32181640079246,
           71.36077505218331,
           71.39973370357416,
           71.438692354965,
           71.47765100635586,
           71.51660965775379,
           71.55655526591299,
           71.5965008740722,
           71.63644648223143,
           71.67639209039064,
           71.69703461659026,
           71.70802560181006,
           71.71901658702987,
           71.73000757224969,
           71.74099855746948,
           71.75198954268932,
           71.76298052790912,
           71.77397151312893,
           71.78496249834873,
           71.79595348356854,
           71.80058066982257,
           71.8024805134484,
           71.80438035707422,
           71.80628020070006,
           71.80818004432588,
           71.8100798879517,
           71.81197973157752,
           71.81387957520336,
           71.81577941882918,
           71.81767926245502,
           71.81957910608084,
           71.82147894970666,
           71.8233787933325,
           71.82527863695833,
           71.82717848058415,
           71.82907832420997,
           71.83097816783581,
           71.83287801146163,
           71.83477785508745,
           71.83667769871329,
           71.83857754233912,
           71.84047738596495,
           71.84237722959077,
           71.8442770732166,
           71.84617691684242,
           71.84807676046825,
           71.84997660409408,
           71.8518764477199,
           71.85377629134572,
           71.85567613497156,
           71.85757597859738,
           71.85947582222322,
           71.86137566584904,
           71.86327550947486,
           71.8651753531007,
           71.86707519672652,
           71.86897504035234,
           71.87087488397817,
           71.872774727604,
           71.87467457122983,
           71.87657441485564,
           71.87847425848148,
           71.88037410210731,
           71.88227394573313,
           71.88417378935895,
           71.88607363298479,
           71.88797347661061,
           71.88987332023645,
           71.89177316386227,
           71.8936730074881,
           71.89557285111394,
           71.89747269473975,
           71.89937253836558,
           71.9012723819914,
           71.90317222561724,
           71.90507206924306,
           71.9069719128689,
           71.90887175649472,
           71.91077160012054,
           71.91267144374638,
           71.9145712873722,
           71.91647113099803,
           71.91837097462385,
           71.92027081824969,
           71.92217066187551,
           71.92407050550133,
           71.92597034912717,
           71.92787019275299,
           71.92977003637881,
           71.93166988000463,
           71.93356972363047,
           71.93546956725629,
           71.93736941088213,
           71.61376477095176,
           70.96465564746522,
           70.31554652397875,
           69.66643740049228,
           69.01732827700573,
           68.36821915351928,
           67.71911003003278,
           67.07000090654626,
           66.42089178305972,
           65.7717826595733,
           65.12267353608677,
           64.47356441260023,
           63.82445528911376,
           63.175346165627275,
           62.52623704214074,
           61.87712791865427,
           61.22801879516779,
           60.57890967168125,
           59.929800548194784,
           59.2806914247083,
           58.63158230122177,
           57.98247317773523,
           57.33336405424882,
           56.68425493076228,
           56.03514580727574,
           55.38603668378927,
           54.736927560302796,
           54.08781843681625,
           53.43870931332978,
           52.7896001898433,
           52.140491066356766,
           51.49138194287024,
           50.842272819383815,
           50.19316369589728,
           49.544054572410744,
           48.894945448924275,
           48.2458363254378,
           47.59672720195126,
           46.947618078464785,
           46.2985089549783,
           45.64939983149178,
           45.000290708005295,
           44.35118158451882,
           43.70207246103228,
           43.05296333754575,
           42.40385421405933,
           41.7547450905728,
           41.10563596708626,
           40.45652684359978,
           39.80741772011331,
           39.158308596626775,
           38.5091994731403,
           37.860884525733056,
           37.21548155707911,
           36.57007858842516,
           35.92467561977133,
           35.27927265111739,
           34.633869682463434,
           33.988466713809544,
           33.34306374515565,
           32.697660776501706,
           32.05225780784782,
           31.40685483919393,
           30.76145187053998,
           30.11604890188609,
           29.470645933232202,
           28.82524296457825,
           28.1798399959243,
           27.534437027270474,
           26.889034058616524,
           26.243631089962577,
           25.598228121308686,
           24.9528251526548,
           24.307422184000846,
           23.662019215346962,
           23.016616246693072,
           22.37121327803912,
           21.72581030938523,
           21.08040734073134,
           20.435004372077394,
           19.789601403423447,
           19.144198434769557,
           18.498795466115666,
           18.02285658534099,
           17.885845880324723,
           17.748835175308457,
           17.61182447029218,
           17.474813765275915,
           17.33780306025965,
           17.200792355243372,
           17.063781650227092,
           16.92677094521084,
           16.789760240194564,
           16.652749535178287,
           16.51573883016202,
           16.378728125145756,
           16.241717420129476,
           16.104706715113213,
           15.967696010096947,
           15.830685305080667,
           15.693674600064401,
           15.556663895048137,
           15.419653190031859,
           15.282642485015582,
           15.145631779999317,
           15.00862107498305,
           14.871610369966774,
           14.734599664950508,
           14.597588959934244,
           14.460578254917964,
           14.3235675499017,
           14.186556844885434,
           14.049546139869157,
           13.912535434852877,
           13.775524729836626,
           13.63851402482035,
           13.501503319804069,
           13.364492614787803,
           13.227481909771537,
           13.09047120475526,
           12.953460499738995,
           12.816449794722729,
           12.679439089706449,
           12.542428384690185,
           12.405417679673919,
           12.26840697465764,
           12.131396269641364,
           11.994385564625098,
           11.857374859608832,
           11.720364154592556,
           11.58335344957629,
           11.446342744560024,
           11.309332039543746,
           11.172321334527481,
           11.035310629511217,
           10.898299924494939,
           10.761289219478659,
           10.624278514462407,
           10.487267809446129,
           10.35025710442985,
           10.213246399413585,
           10.07623569439732,
           9.939224989381042,
           9.802214284364776,
           9.665203579348512,
           9.528192874332234,
           9.391182169315968,
           9.254171464299704,
           9.117160759283426,
           8.980150054267147,
           8.843139349250894,
           8.706128644234617,
           8.569117939218339,
           8.432107234202073,
           8.295096529185807,
           8.15808582416953,
           8.021075119153265,
           7.884064414136999,
           7.747053709120721,
           7.610043004104443,
           7.4730322990881906,
           7.336021594071911,
           7.199010889055634,
           7.062000184039368,
           6.924460576611349,
           6.781247283735844,
           6.656976217292821,
           6.62741628301207,
           6.599011080707172,
           6.570737847789141,
           6.5424646148711165,
           6.514191381953086,
           6.485918149035056,
           6.457644916117031,
           6.429371683199002,
           6.401098450280971,
           6.372825217362946,
           6.344551984444917,
           6.316278751526887,
           6.288005518608856,
           6.259732285690831,
           6.231459052772801,
           6.203185819854772,
           6.174912586936747,
           6.146639354018716,
           6.118366121100686,
           6.090092888182661,
           6.061819655264632,
           6.0335464223466015,
           6.005273189428577,
           5.9769999565105465,
           5.948726723592516,
           5.920453490674486,
           5.892180257756461,
           5.863907024838431,
           5.835633791920402,
           5.807360559002377,
           5.779087326084346,
           5.750814093166316,
           5.722540860248291,
           5.694267627330262,
           5.665994394412231,
           5.637721161494202,
           5.609447928576177,
           5.581174695658147,
           5.552901462740117,
           5.524628229822092,
           5.496354996904062,
           5.4680817639860315,
           5.439808531068007,
           5.4115352981499765,
           5.383262065231947,
           5.354988832313922,
           5.326715599395892,
           5.298442366477862,
           5.270169133559832,
           5.241895900641807,
           5.213622667723776,
           5.1853494348057465,
           5.157076201887722,
           5.1288029689696915,
           5.100529736051661,
           5.072256503133636,
           5.043983270215606,
           5.015710037297577,
           4.987436804379546,
           4.959163571461522,
           4.930890338543492,
           4.9026171056254615,
           4.874343872707437,
           4.846070639789406,
           4.817797406871376,
           4.789524173953351,
           4.761250941035322,
           4.732977708117292,
           4.704704475199266,
           4.676431242281237,
           4.648158009363206,
           4.6198847764451765,
           4.591611543527152,
           4.563338310609121,
           4.535065077691091,
           4.506791844773066,
           4.478518611855037,
           4.450245378937006,
           4.421972146018981,
           4.393698913100952,
           4.365425680182922,
           4.337152447264891,
           4.308879214346866
          ],
          [
           64.30533895850617,
           64.35609713645842,
           64.40685531441068,
           64.45761349236292,
           64.50837167031517,
           64.55912984826743,
           64.60988802621968,
           64.66064620417194,
           64.71140438212419,
           64.76216256007643,
           64.8129207380287,
           64.86367891598094,
           64.91443709393319,
           64.96580774528427,
           65.01730089145428,
           65.0687940376243,
           65.12028718379433,
           65.17178032996435,
           65.22327347613438,
           65.2747666223044,
           65.32625976847442,
           65.37775291464445,
           65.42924606081448,
           65.4807392069845,
           65.53223235315451,
           65.58372549932454,
           65.63521864549456,
           65.68671179166458,
           65.73820493783461,
           65.78969808400463,
           65.84119123017466,
           65.89268437634468,
           65.94417752251469,
           65.99567066868472,
           66.04716381485476,
           66.09865696102477,
           66.15015010719479,
           66.20164325336482,
           66.25313639953484,
           66.30462954570486,
           66.35612269187489,
           66.4076158380449,
           66.45910898421494,
           66.51060213038495,
           66.56209527655497,
           66.613588422725,
           66.66508156889503,
           66.71657471506505,
           66.76806786123507,
           66.8195610074051,
           66.87105415357512,
           66.92254729974515,
           66.97404044591516,
           67.02553359208518,
           67.07702673825523,
           67.12851988442523,
           67.18001303059526,
           67.23150617676528,
           67.28299932293531,
           67.33449246910533,
           67.38598561527535,
           67.43747876144538,
           67.48897190761541,
           67.54046505378541,
           67.59195819995544,
           67.64345134612547,
           67.69494449229549,
           67.74643763846552,
           67.79793078463554,
           67.84942393080556,
           67.90091707697559,
           67.9524102231456,
           68.00390336931564,
           68.05539651548565,
           68.10688966165569,
           68.1583828078257,
           68.20987595399572,
           68.26136910016575,
           68.31286224633577,
           68.3643553925058,
           68.41584853867582,
           68.46734168484583,
           68.51883483101587,
           68.57032797718588,
           68.61137571103993,
           68.65033436243078,
           68.68929301382163,
           68.72825166521248,
           68.76721031660333,
           68.80616896799417,
           68.84512761938501,
           68.88408627077587,
           68.92304492216672,
           68.96200357355757,
           69.00096222494841,
           69.03992087633927,
           69.07887952773012,
           69.11783817912097,
           69.15679683051181,
           69.19575548190267,
           69.23471413329351,
           69.27367278468435,
           69.31263143607521,
           69.35159008746605,
           69.3905487388569,
           69.42950739024775,
           69.46846604163859,
           69.50742469302944,
           69.54638334442029,
           69.58534199581113,
           69.62430064720199,
           69.66325929859283,
           69.70221794998369,
           69.74117660137453,
           69.78013525276538,
           69.81909390415623,
           69.85805255554708,
           69.89701120693792,
           69.93596985832878,
           69.97492850971963,
           70.01388716111049,
           70.05284581250132,
           70.09180446389217,
           70.13076311528303,
           70.16972176667386,
           70.20868041806472,
           70.24763906945556,
           70.28659772084642,
           70.32555637223726,
           70.36451502362812,
           70.40347367501896,
           70.4424323264098,
           70.48139097780064,
           70.5203496291915,
           70.55930828058236,
           70.5982669319732,
           70.63722558336404,
           70.6761842347549,
           70.71514288614574,
           70.7541015375366,
           70.79306018892744,
           70.8320188403183,
           70.87097749170914,
           70.90993614309998,
           70.94889479449084,
           70.98785344588168,
           71.02681209727253,
           71.06577074866338,
           71.10472940005423,
           71.14368805144508,
           71.18264670283592,
           71.22160535422678,
           71.26056400561762,
           71.29952265700847,
           71.33848130839932,
           71.37642557334904,
           71.41416696124108,
           71.45190834913312,
           71.48964973702516,
           71.5273911249172,
           71.56513251280924,
           71.60287390070128,
           71.64061528859332,
           71.67835667648535,
           71.71609806437739,
           71.75383945226943,
           71.79158084016147,
           71.79994717412298,
           71.7936259811192,
           71.78730478811546,
           71.7809835951117,
           71.77466240210794,
           71.7683412091042,
           71.76202001610044,
           71.75569882309668,
           71.74937763009291,
           71.74305643708915,
           71.7367352440854,
           71.73041405108164,
           71.72409285807788,
           71.71777166507412,
           71.71145047207037,
           71.70512927906661,
           71.69880808606285,
           71.6924868930591,
           71.68616570005534,
           71.67984450705157,
           71.67352331404781,
           71.66720212104406,
           71.6608809280403,
           71.65455973503654,
           71.64823854203279,
           71.64191734902903,
           71.63559615602527,
           71.62927496302152,
           71.62295377001776,
           71.61836333104411,
           71.62026317466993,
           71.62216301829577,
           71.62406286192157,
           71.62596270554741,
           71.62786254917324,
           71.62976239279907,
           71.63166223642489,
           71.63356208005071,
           71.63546192367654,
           71.63736176730237,
           71.6392616109282,
           71.64116145455402,
           71.64306129817984,
           71.64496114180568,
           71.64686098543152,
           71.64876082905732,
           71.65066067268316,
           71.652560516309,
           71.6544603599348,
           71.65636020356064,
           71.65826004718646,
           71.6601598908123,
           71.66205973443812,
           71.66395957806395,
           71.66585942168979,
           71.66775926531561,
           71.66965910894143,
           71.67155895256727,
           71.67345879619309,
           71.67535863981891,
           71.67725848344475,
           71.67915832707055,
           71.6810581706964,
           71.68295801432222,
           71.68485785794806,
           71.68675770157388,
           71.6886575451997,
           71.69055738882554,
           71.69245723245136,
           71.69435707607718,
           71.69625691970302,
           71.69815676332885,
           71.70005660695467,
           71.7019564505805,
           71.70385629420633,
           71.70575613783215,
           71.70765598145798,
           71.70955582508381,
           71.71145566870963,
           71.71335551233545,
           71.71525535596129,
           71.71715519958711,
           71.71905504321293,
           71.39545040328258,
           70.74634127979604,
           70.09723215630956,
           69.44812303282309,
           68.79901390933655,
           68.14990478585008,
           67.5007956623636,
           66.85168653887706,
           66.20257741539054,
           65.55346829190411,
           64.90435916841759,
           64.25525004493105,
           63.60614092144456,
           62.95703179795809,
           62.307922674471556,
           61.65881355098508,
           61.00970442749861,
           60.36059530401207,
           59.7114861805256,
           59.06237705703912,
           58.41326793355258,
           57.76415881006605,
           57.115049686579624,
           56.4659405630931,
           55.81683143960656,
           55.167722316120084,
           54.51861319263361,
           53.86950406914706,
           53.220394945660594,
           52.57128582217412,
           51.922176698687586,
           51.273067575201054,
           50.623958451714635,
           49.974849328228096,
           49.325740204741564,
           48.67663108125509,
           48.027521957768606,
           47.378412834282074,
           46.7293037107956,
           46.08019458730912,
           45.43108546382259,
           44.781976340336115,
           44.13286721684963,
           43.4837580933631,
           42.834648969876554,
           42.18553984639015,
           41.53643072290361,
           40.88732159941707,
           40.238212475930595,
           39.58910335244412,
           38.93999422895759,
           38.290885105471105,
           37.64177598198464,
           36.9926668584981,
           36.343557735011565,
           35.69444861152515,
           35.045339488038614,
           34.39623036455208,
           33.7471212410656,
           33.098012117579124,
           32.44890299409259,
           31.79979387060611,
           31.150684747119634,
           30.5015756236331,
           29.852466500146626,
           29.20335737666015,
           28.554248253173615,
           27.90513912968708,
           27.25603000620066,
           26.606920882714128,
           25.957811759227592,
           25.308702635741113,
           24.659593512254638,
           24.010484388768102,
           23.361375265281627,
           22.71226614179515,
           22.063157018308612,
           21.41404789482214,
           20.76493877133566,
           20.11622673490595,
           19.470823766252003,
           18.825420797598113,
           18.180017828944226,
           17.70407894816955,
           17.56706824315328,
           17.430057538137014,
           17.293046833120737,
           17.15603612810447,
           17.01902542308821,
           16.88201471807193,
           16.74500401305565,
           16.607993308039397,
           16.47098260302312,
           16.33397189800684,
           16.19713125173347,
           16.060342362258755,
           15.923553472784027,
           15.786764583309312,
           15.649975693834595,
           15.513186804359869,
           15.376397914885153,
           15.239609025410438,
           15.102820135935708,
           14.966031246460982,
           14.829242356986265,
           14.692453467511552,
           14.555664578036822,
           14.418875688562109,
           14.282086799087391,
           14.145297909612665,
           14.00850902013795,
           13.871720130663235,
           13.734931241188507,
           13.598142351713777,
           13.461353462239074,
           13.324564572764348,
           13.187775683289619,
           13.050986793814904,
           12.914197904340188,
           12.77740901486546,
           12.640620125390747,
           12.503831235916032,
           12.367042346441302,
           12.230253456966585,
           12.09346456749187,
           11.956675678017142,
           11.819886788542416,
           11.683097899067699,
           11.546309009592983,
           11.409520120118255,
           11.27273123064354,
           11.135942341168825,
           10.999153451694099,
           10.862364562219383,
           10.725575672744666,
           10.588786783269938,
           10.451997893795209,
           10.315209004320508,
           10.17842011484578,
           10.041631225371052,
           9.904842335896337,
           9.768053446421622,
           9.631264556946894,
           9.494475667472178,
           9.357686777997463,
           9.220897888522735,
           9.08410899904802,
           9.021414109225494,
           8.993140876307463,
           8.964867643389434,
           8.93659441047141,
           8.908321177553379,
           8.880047944635347,
           8.85177471171732,
           8.823501478799294,
           8.795228245881264,
           8.766955012963235,
           8.738681780045209,
           8.710408547127178,
           8.68213531420915,
           8.653862081291125,
           8.625588848373093,
           8.597315615455063,
           8.569042382537036,
           8.54076914961901,
           8.512495916700978,
           8.484222683782953,
           8.455949450864924,
           8.427676217946894,
           8.399402985028864,
           8.37112975211084,
           8.342856519192809,
           8.314583286274779,
           8.286310053356754,
           8.258036820438724,
           8.229763587520694,
           8.201490354602669,
           8.173217121684639,
           8.144943888766608,
           8.116670655848578,
           8.088397422930553,
           8.060124190012523,
           8.031850957094493,
           8.003577724176468,
           7.975304491258439,
           7.947031258340408,
           7.918758025422383,
           7.890484792504354,
           7.862211559586323,
           7.8339383266682985,
           7.805665093750267,
           7.777391860832239,
           7.749118627914209,
           7.720845394996184,
           7.692572162078154,
           7.664298929160124,
           7.636025696242099,
           7.6077524633240685,
           7.579479230406038,
           7.5512059974880135,
           7.522932764569983,
           7.494659531651953,
           7.466386298733923,
           7.438113065815898,
           7.409839832897869,
           7.3815665999798385,
           7.353293367061814,
           7.325020134143783,
           7.296746901225754,
           7.2684736683077285,
           7.238464883834917,
           7.1563888177023145,
           7.074312751569728,
           6.992236685437126,
           6.910160619304523,
           6.82808455317192,
           6.746008487039333,
           6.663932420906731,
           6.5818563547741284,
           6.499780288641541,
           6.417704222508938,
           6.335628156376336,
           6.253552090243749,
           6.171476024111147,
           6.089399957978544,
           6.0073238918459415,
           5.925247825713354,
           5.843626637571756,
           5.762382791901043,
           5.681138946230345,
           5.599895100559632,
           5.51865125488892,
           5.437407409218222,
           5.3561635635475096,
           5.275953304844519,
           5.1959232611768735,
           5.115893217509213,
           5.0854693852912085,
           5.228667293146984,
           5.371865201002732,
           5.515063108858508,
           5.658261016714283,
           5.623173871944038,
           5.331376779299816,
           5.046587174071487,
           4.7776064280892685,
           4.540342901582143,
           4.372787553115399,
           null,
           null
          ],
          [
           64.44764517969995,
           64.49840335765221,
           64.54916153560447,
           64.59991971355672,
           64.65067789150896,
           64.70143606946122,
           64.75219424741347,
           64.80295242536572,
           64.85371060331798,
           64.90446878127023,
           64.95522695922247,
           65.00598513717473,
           65.05674331512698,
           65.10750149307923,
           65.15825967103149,
           65.20901784898373,
           65.259776026936,
           65.31053420488824,
           65.3612923828405,
           65.41205056079275,
           65.462808738745,
           65.51356691669724,
           65.5643250946495,
           65.61508327260175,
           65.665841450554,
           65.71659962850626,
           65.76735780645852,
           65.81811598441077,
           65.86887416236301,
           65.91987732948392,
           65.97137047565396,
           66.02286362182397,
           66.07435676799399,
           66.12584991416402,
           66.17734306033405,
           66.22883620650407,
           66.28032935267409,
           66.33182249884412,
           66.38331564501414,
           66.43480879118415,
           66.48630193735418,
           66.5377950835242,
           66.58928822969423,
           66.64078137586425,
           66.69227452203427,
           66.7437676682043,
           66.79526081437433,
           66.84675396054435,
           66.89824710671436,
           66.9497402528844,
           67.00123339905441,
           67.05272654522444,
           67.10421969139446,
           67.15571283756448,
           67.20720598373453,
           67.25869912990453,
           67.31019227607456,
           67.36168542224458,
           67.4131785684146,
           67.46467171458463,
           67.51616486075464,
           67.56765800692469,
           67.61915115309469,
           67.67064429926471,
           67.72213744543474,
           67.77363059160477,
           67.82512373777479,
           67.8766168839448,
           67.92811003011484,
           67.97960317628485,
           68.03109632245489,
           68.0825894686249,
           68.13408261479493,
           68.18557576096495,
           68.23706890713497,
           68.288562053305,
           68.34005519947502,
           68.39154834564505,
           68.44304149181507,
           68.4945346379851,
           68.54602778415511,
           68.59752093032513,
           68.64901407649516,
           68.70050722266518,
           68.74155495651922,
           68.78051360791007,
           68.81947225930092,
           68.85843091069177,
           68.89738956208262,
           68.93634821347347,
           68.97530686486431,
           69.01426551625516,
           69.05322416764602,
           69.09218281903686,
           69.1311414704277,
           69.17010012181856,
           69.2090587732094,
           69.24801742460026,
           69.2869760759911,
           69.32593472738195,
           69.3648933787728,
           69.40385203016365,
           69.4428106815545,
           69.48176933294535,
           69.52072798433619,
           69.55968663572705,
           69.59864528711789,
           69.63760393850873,
           69.67656258989959,
           69.71552124129043,
           69.75447989268129,
           69.79343854407213,
           69.83239719546297,
           69.87135584685383,
           69.91031449824467,
           69.94927314963553,
           69.98823180102639,
           70.02719045241723,
           70.06614910380807,
           70.10510775519893,
           70.14406640658977,
           70.18302505798061,
           70.22198370937147,
           70.26094236076231,
           70.29990101215316,
           70.33885966354401,
           70.37781831493486,
           70.41677696632571,
           70.45573561771656,
           70.49469426910741,
           70.53365292049826,
           70.5726115718891,
           70.61157022327994,
           70.6505288746708,
           70.68948752606165,
           70.7284461774525,
           70.76740482884334,
           70.8063634802342,
           70.84491637673247,
           70.88265776462453,
           70.92039915251655,
           70.95814054040859,
           70.99588192830063,
           71.03362331619266,
           71.0713647040847,
           71.10910609197674,
           71.14684747986878,
           71.18458886776082,
           71.22233025565286,
           71.2600716435449,
           71.29781303143693,
           71.33555441932897,
           71.37329580722101,
           71.41103719511305,
           71.4487785830051,
           71.48651997089712,
           71.52426135878916,
           71.5620027466812,
           71.59974413457324,
           71.63748552246528,
           71.67522691035732,
           71.71296829824936,
           71.7507096861414,
           71.78845107403343,
           71.82619246192547,
           71.86393384981751,
           71.90167523770955,
           71.91004157167106,
           71.9037203786673,
           71.89739918566355,
           71.89107799265977,
           71.88475679965603,
           71.87843560665226,
           71.8721144136485,
           71.86579322064476,
           71.85947202764098,
           71.85315083463723,
           71.84682964163348,
           71.84050844862972,
           71.83418725562596,
           71.8278660626222,
           71.82154486961845,
           71.81522367661468,
           71.80890248361092,
           71.80258129060716,
           71.79626009760341,
           71.78993890459965,
           71.7836177115959,
           71.77729651859215,
           71.77097532558838,
           71.76465413258461,
           71.75833293958087,
           71.75201174657711,
           71.74569055357335,
           71.7393693605696,
           71.73304816756584,
           71.72672697456207,
           71.72040578155833,
           71.71408458855456,
           71.7077633955508,
           71.70144220254704,
           71.69512100954329,
           71.68879981653953,
           71.68247862353577,
           71.67615743053202,
           71.66983623752824,
           71.6635150445245,
           71.65719385152074,
           71.65087265851699,
           71.64455146551323,
           71.63823027250947,
           71.6319090795057,
           71.62558788650196,
           71.61926669349819,
           71.61294550049443,
           71.60662430749068,
           71.60030311448692,
           71.59398192148316,
           71.58766072847939,
           71.58133953547565,
           71.57501834247188,
           71.56869714946814,
           71.56237595646438,
           71.55605476346061,
           71.54973357045687,
           71.5434123774531,
           71.53709118444934,
           71.53076999144558,
           71.52444879844182,
           71.51812760543807,
           71.51180641243431,
           71.50548521943054,
           71.4991640264268,
           71.49284283342304,
           71.48652164041927,
           71.48020044741551,
           71.476042708408,
           71.47794255203384,
           71.47984239565967,
           71.4817422392855,
           71.48364208291132,
           71.48554192653714,
           71.48744177016297,
           71.48934161378881,
           71.49124145741463,
           71.49314130104045,
           71.49504114466627,
           71.4969409882921,
           71.49884083191793,
           71.50074067554377,
           71.1771360356134,
           70.52802691212685,
           69.8789177886404,
           69.22980866515391,
           68.58069954166737,
           67.9315904181809,
           67.28248129469442,
           66.63337217120788,
           65.98426304772136,
           65.33515392423494,
           64.6860448007484,
           64.03693567726187,
           63.38782655377539,
           62.738717430288915,
           62.089608306802376,
           61.4404991833159,
           60.791390059829425,
           60.1422809363429,
           59.49317181285642,
           58.84406268936994,
           58.1949535658834,
           57.54584444239687,
           56.896735318910444,
           56.24762619542392,
           55.59763562775301,
           54.94731451185465,
           54.296993395956285,
           53.64667228005786,
           52.99635116415949,
           52.34603004826113,
           51.69570893236269,
           51.04538781646427,
           50.39506670056596,
           49.74474558466754,
           49.09442446876911,
           48.44410335287075,
           47.793782236972376,
           47.14346112107395,
           46.49314000517558,
           45.84281888927722,
           45.19249777337879,
           44.542176657480425,
           43.89185554158207,
           43.24153442568364,
           42.5912133097852,
           41.940892193886896,
           41.290571077988474,
           40.64024996209004,
           39.98992884619168,
           39.33960773029331,
           38.68928661439489,
           38.03896549849652,
           37.38864438259816,
           36.73832326669972,
           36.0880021508013,
           35.437681034902994,
           34.78735991900457,
           34.137038803106144,
           33.48671768720778,
           32.83639657130941,
           32.186075455410986,
           31.535754339512618,
           30.88543322361425,
           30.235112107715825,
           29.584790991817457,
           28.934469875919092,
           28.284148760020663,
           27.63382764412224,
           26.983506528223934,
           26.333185412325506,
           25.682864296427077,
           25.032543180528712,
           24.382222064630348,
           23.73190094873192,
           23.081579832833555,
           22.431258716935186,
           21.78093760103676,
           21.130616485138397,
           20.480295369240025,
           19.829974253341604,
           19.179653137443175,
           18.529332021544807,
           17.879010905646442,
           17.399867198555963,
           17.263078309081248,
           17.126289419606533,
           16.989500530131803,
           16.85271164065709,
           16.715922751182376,
           16.579133861707646,
           16.44234497223292,
           16.305556082758216,
           16.168767193283486,
           16.03197830380876,
           15.895189414334045,
           15.75840052485933,
           15.621611635384602,
           15.484822745909886,
           15.34803385643517,
           15.211244966960443,
           15.074456077485728,
           14.937667188011012,
           14.800878298536283,
           14.664089409061557,
           14.527300519586841,
           14.390511630112126,
           14.253722740637398,
           14.116933851162681,
           13.980144961687968,
           13.84335607221324,
           13.706567182738523,
           13.56977829326381,
           13.43298940378908,
           13.296200514314354,
           13.159411624839649,
           13.022622735364921,
           12.885833845890193,
           12.749044956415478,
           12.612256066940764,
           12.475467177466035,
           12.338678287991321,
           12.201889398516606,
           12.065100509041876,
           11.92831161956716,
           11.791522730092444,
           11.654733840617716,
           11.527279582368614,
           11.499006349450585,
           11.470733116532557,
           11.442459883614529,
           11.4141866506965,
           11.385913417778474,
           11.357640184860443,
           11.329366951942415,
           11.301093719024388,
           11.272820486106358,
           11.244547253188328,
           11.216274020270303,
           11.188000787352273,
           11.159727554434243,
           11.131454321516216,
           11.103181088598188,
           11.07490785568016,
           11.04663462276213,
           11.018361389844102,
           10.990088156926072,
           10.961814924008046,
           10.933541691090019,
           10.905268458171987,
           10.876995225253957,
           10.848721992335932,
           10.820448759417904,
           10.792175526499872,
           10.763902293581845,
           10.735629060663818,
           10.707355827745788,
           10.67908259482776,
           10.650809361909733,
           10.622536128991703,
           10.594262896073673,
           10.565989663155648,
           10.537716430237618,
           10.509443197319587,
           10.48116996440156,
           10.452896731483534,
           10.424623498565502,
           10.396350265647477,
           10.368077032729447,
           10.339803799811419,
           10.311530566893387,
           10.238132425583888,
           10.156056359451286,
           10.073980293318684,
           9.991904227186097,
           9.909828161053493,
           9.827752094920893,
           9.745676028788306,
           9.663599962655702,
           9.581523896523102,
           9.499447830390498,
           9.417371764257911,
           9.335295698125307,
           9.253219631992707,
           9.171143565860117,
           9.089067499727516,
           9.006991433594914,
           8.924915367462326,
           8.842839301329724,
           8.760763235197121,
           8.678687169064535,
           8.596611102931933,
           8.514535036799328,
           8.432458970666726,
           8.35038290453414,
           8.268306838401537,
           8.186230772268935,
           8.104154706136349,
           8.022078640003745,
           7.940002573871144,
           7.857926507738556,
           7.775850441605954,
           7.693774375473351,
           7.611698309340749,
           7.529720455000595,
           7.448476609329882,
           7.367232763659171,
           7.2859889179884725,
           7.2047450723177615,
           7.123501226647047,
           7.04225738097635,
           6.961013535305638,
           6.879769689634925,
           6.798525843964228,
           6.717281998293514,
           6.636038152622802,
           6.55479430695209,
           6.473550461281392,
           6.39282075904063,
           6.312790715372971,
           6.232760671705326,
           6.152730628037666,
           6.072700584370005,
           5.99267054070236,
           5.912640497034702,
           5.832610453367042,
           5.975808361222795,
           6.119006269078543,
           6.262204176934318,
           6.405402084790094,
           6.548599992645842,
           6.6917979005016175,
           6.834995808357393,
           6.978193716213142,
           7.121391624068917,
           7.1977326195397335,
           6.904132174348784,
           6.611794075972269,
           6.321529832949165,
           6.035527562922169,
           5.754514278381497,
           5.482332040969956,
           5.221338355940828,
           4.976080279365322,
           4.754212948574585,
           4.567548628168086,
           4.429433836907141,
           4.342201081490034,
           null,
           null,
           null
          ],
          [
           64.58995140089374,
           64.64070957884599,
           64.69146775679823,
           64.7422259347505,
           64.79298411270275,
           64.843742290655,
           64.89450046860725,
           64.94525864655951,
           64.99601682451176,
           65.046775002464,
           65.09753318041626,
           65.14829135836851,
           65.19904953632076,
           65.24980771427302,
           65.30056589222526,
           65.35132407017753,
           65.40208224812977,
           65.45284042608202,
           65.50359860403428,
           65.55435678198653,
           65.60511495993879,
           65.65587313789104,
           65.70663131584328,
           65.75738949379554,
           65.80814767174779,
           65.85890584970005,
           65.9096640276523,
           65.96042220560454,
           66.0111803835568,
           66.06193856150905,
           66.1126967394613,
           66.16345491741356,
           66.2142130953658,
           66.26497127331805,
           66.31572945127031,
           66.36648762922256,
           66.41724580717482,
           66.46800398512707,
           66.51876216307932,
           66.56952034103158,
           66.62027851898382,
           66.67103669693608,
           66.72179487488833,
           66.77255305284058,
           66.82331123079283,
           66.8740694087451,
           66.92544005985361,
           66.97693320602363,
           67.02842635219366,
           67.0799194983637,
           67.13141264453371,
           67.18290579070373,
           67.23439893687376,
           67.28589208304378,
           67.33738522921381,
           67.38887837538383,
           67.44037152155386,
           67.49186466772386,
           67.54335781389389,
           67.59485096006392,
           67.64634410623394,
           67.69783725240397,
           67.74933039857399,
           67.800823544744,
           67.85231669091404,
           67.90380983708405,
           67.95530298325409,
           68.0067961294241,
           68.05828927559412,
           68.10978242176415,
           68.16127556793418,
           68.2127687141042,
           68.26426186027422,
           68.31575500644425,
           68.36724815261427,
           68.41874129878428,
           68.47023444495431,
           68.52172759112433,
           68.57322073729435,
           68.62471388346438,
           68.67620702963441,
           68.72770017580443,
           68.77919332197445,
           68.83068646814448,
           68.87173420199852,
           68.91069285338938,
           68.94965150478022,
           68.98861015617106,
           69.02756880756192,
           69.06652745895276,
           69.1054861103436,
           69.14444476173446,
           69.1834034131253,
           69.22236206451615,
           69.261320715907,
           69.30027936729785,
           69.33923801868869,
           69.37819667007955,
           69.4171553214704,
           69.45611397286125,
           69.49507262425209,
           69.53403127564295,
           69.5729899270338,
           69.61194857842465,
           69.65090722981549,
           69.68986588120634,
           69.72882453259717,
           69.76778318398803,
           69.80674183537889,
           69.84570048676972,
           69.88465913816059,
           69.92361778955143,
           69.96257644094227,
           70.00153509233311,
           70.04049374372397,
           70.07945239511483,
           70.11841104650567,
           70.15736969789651,
           70.19632834928737,
           70.23528700067821,
           70.27424565206906,
           70.31320430345991,
           70.35114856800793,
           70.38888995589997,
           70.42663134379201,
           70.46437273168405,
           70.50211411957608,
           70.53985550746812,
           70.57759689536016,
           70.6153382832522,
           70.65307967114424,
           70.69082105903628,
           70.72856244692832,
           70.76630383482035,
           70.80404522271239,
           70.84178661060443,
           70.87952799849647,
           70.91726938638851,
           70.95501077428055,
           70.9927521621726,
           71.03049355006462,
           71.06823493795666,
           71.1059763258487,
           71.14371771374074,
           71.18145910163278,
           71.21920048952481,
           71.25694187741686,
           71.29468326530889,
           71.33242465320093,
           71.37016604109297,
           71.40790742898501,
           71.44564881687705,
           71.4833902047691,
           71.52113159266112,
           71.55887298055316,
           71.5966143684452,
           71.63435575633724,
           71.67209714422928,
           71.70983853212132,
           71.74757992001335,
           71.78532130790539,
           71.82306269579743,
           71.86080408368947,
           71.8985454715815,
           71.93628685947355,
           71.97402824736558,
           72.01176963525764,
           72.02013596921913,
           72.01381477621537,
           72.00749358321161,
           72.00117239020786,
           71.9948511972041,
           71.98853000420036,
           71.98220881119659,
           71.97588761819283,
           71.96956642518907,
           71.96324523218532,
           71.95692403918156,
           71.9506028461778,
           71.94428165317404,
           71.93796046017029,
           71.93163926716653,
           71.92531807416276,
           71.91899688115902,
           71.91267568815525,
           71.90635449515149,
           71.90003330214773,
           71.89371210914399,
           71.88739091614022,
           71.88106972313646,
           71.8747485301327,
           71.86842733712895,
           71.86210614412519,
           71.85578495112144,
           71.84946375811768,
           71.84314256511391,
           71.83682137211017,
           71.8305001791064,
           71.82417898610264,
           71.8178577930989,
           71.81153660009514,
           71.80521540709137,
           71.79889421408761,
           71.79257302108385,
           71.7862518280801,
           71.77993063507634,
           71.77360944207257,
           71.76728824906883,
           71.76096705606506,
           71.75464586306128,
           71.74832467005754,
           71.74200347705379,
           71.73568228405003,
           71.72936109104627,
           71.72303989804252,
           71.71671870503876,
           71.710397512035,
           71.70407631903124,
           71.69775512602749,
           71.69143393302372,
           71.68511274001996,
           71.6787915470162,
           71.67247035401246,
           71.66614916100869,
           71.65982796800495,
           71.65350677500118,
           71.64718558199743,
           71.64086438899366,
           71.6345431959899,
           71.62822200298615,
           71.62190080998239,
           71.61557961697864,
           71.5938175179612,
           71.57082011867787,
           71.54782271939453,
           71.52482532011122,
           71.50182792082789,
           71.47883052154455,
           71.45583312226124,
           71.4328357229779,
           71.40983832369456,
           71.38684092441125,
           71.36384352512792,
           71.34084612584459,
           71.31784872656127,
           71.29485132727793,
           71.2718539279946,
           71.24885652871127,
           71.22585912942793,
           71.2028617301446,
           70.86680811001588,
           70.21769826904175,
           69.56858842806768,
           68.91947858709361,
           68.27036874611947,
           67.62125890514541,
           66.97214906417133,
           66.32303922319721,
           65.67392938222306,
           65.02481954124906,
           64.37570970027492,
           63.72659985930079,
           63.07749001832672,
           62.42838017735264,
           61.77927033637852,
           61.13016049540444,
           60.48105065443037,
           59.83194081345624,
           59.182830972482165,
           58.53372113150809,
           57.884611290533954,
           57.235501449559834,
           56.58639160858582,
           55.93728176761169,
           55.288171926637546,
           54.639062085663475,
           53.989952244689405,
           53.34084240371527,
           52.6917325627412,
           52.042622721767124,
           51.393512880793004,
           50.743445979064845,
           50.09312486316654,
           49.44280374726811,
           48.79248263136969,
           48.142161515471315,
           47.49184039957295,
           46.84151928367453,
           46.19119816777616,
           45.54087705187779,
           44.890555935979364,
           44.240234820081,
           43.589913704182635,
           42.93959258828421,
           42.289271472385785,
           41.63895035648748,
           40.98862924058905,
           40.33830812469062,
           39.687987008792255,
           39.03766589289389,
           38.38734477699546,
           37.7370236610971,
           37.086702545198726,
           36.4363814293003,
           35.786060313401876,
           35.13573919750357,
           34.48541808160515,
           33.83509696570672,
           33.18477584980835,
           32.53445473390998,
           31.884133618011557,
           31.233812502113192,
           30.583491386214824,
           29.9331702703164,
           29.28284915441803,
           28.632528038519663,
           27.982206922621238,
           27.331885806722813,
           26.68156469082451,
           26.03124357492608,
           25.38092245902765,
           24.73060134312929,
           24.080280227230922,
           23.429959111332494,
           22.77963799543413,
           22.12931687953576,
           21.478995763637336,
           20.82867464773897,
           20.178353531840603,
           19.528032415942178,
           18.87771130004375,
           18.22739018414538,
           17.577069068247013,
           17.097925361156538,
           16.961136471681822,
           16.824347582207107,
           16.687558692732377,
           16.550769803257666,
           16.41398091378295,
           16.27719202430822,
           16.14040313483349,
           16.00361424535879,
           15.86682535588406,
           15.730036466409334,
           15.593247576934619,
           15.456458687459902,
           15.319669797985174,
           15.18288090851046,
           15.046092019035745,
           14.909303129561017,
           14.772514240086302,
           14.635725350611585,
           14.498936461136859,
           14.36214757166213,
           14.225358682187416,
           14.0885697927127,
           14.004871822593708,
           13.976598589675682,
           13.948325356757653,
           13.920052123839623,
           13.891778890921595,
           13.863505658003568,
           13.835232425085538,
           13.806959192167508,
           13.778685959249483,
           13.750412726331454,
           13.722139493413422,
           13.693866260495396,
           13.665593027577367,
           13.637319794659339,
           13.60904656174131,
           13.580773328823282,
           13.552500095905252,
           13.524226862987225,
           13.495953630069199,
           13.467680397151168,
           13.439407164233138,
           13.41113393131511,
           13.382860698397083,
           13.319876033465446,
           13.237799967332853,
           13.155723901200258,
           13.073647835067655,
           12.99157176893506,
           12.909495702802467,
           12.827419636669866,
           12.745343570537262,
           12.663267504404676,
           12.581191438272072,
           12.499115372139471,
           12.417039306006874,
           12.33496323987428,
           12.252887173741676,
           12.170811107609083,
           12.08873504147649,
           12.006658975343885,
           11.92458290921129,
           11.842506843078699,
           11.760430776946095,
           11.678354710813492,
           11.596278644680904,
           11.514202578548304,
           11.432126512415701,
           11.350050446283106,
           11.267974380150513,
           11.185898314017908,
           11.103822247885313,
           11.021746181752716,
           10.939670115620114,
           10.85759404948751,
           10.775517983354927,
           10.693441917222325,
           10.61136585108972,
           10.529289784957125,
           10.447213718824532,
           10.365137652691928,
           10.28306158655934,
           10.200985520426737,
           10.118909454294137,
           10.036833388161533,
           9.954757322028946,
           9.872681255896344,
           9.790605189763742,
           9.708529123631155,
           9.626453057498551,
           9.544376991365949,
           9.462300925233363,
           9.38022485910076,
           9.298148792968158,
           9.216072726835556,
           9.134570426758723,
           9.053326581088012,
           8.972082735417297,
           8.8908388897466,
           8.809595044075888,
           8.728351198405177,
           8.647107352734478,
           8.565863507063765,
           8.484619661393053,
           8.403375815722354,
           8.322131970051645,
           8.24088812438093,
           8.159644278710218,
           8.07840043303952,
           7.997156587368808,
           7.9159127416980954,
           7.834668896027397,
           7.753425050356686,
           7.672181204685973,
           7.590937359015275,
           7.509693513344562,
           7.429658169569082,
           7.349628125901422,
           7.269598082233779,
           7.189568038566119,
           7.109537994898458,
           7.029507951230814,
           6.949477907563153,
           6.869447863895495,
           6.789417820227849,
           6.709387776560189,
           6.62935773289253,
           6.722949429298578,
           6.866147337154354,
           7.009345245010129,
           7.1525431528659045,
           7.295741060721653,
           7.438938968577428,
           7.5821368764332036,
           7.725334784288952,
           7.868532692144727,
           8.011730600000503,
           8.154928507856251,
           8.298126415712026,
           8.441324323567802,
           8.584522231423577,
           8.727720139279326,
           8.478690921944477,
           8.185090476753476,
           7.892211372644722,
           7.6019471296216174,
           7.31210556155874,
           7.026208960318353,
           6.7425204673621835,
           6.462441382691454,
           6.189866991615673,
           5.923585831095461,
           5.665070283792437,
           5.4175269260825925,
           5.184598340745408,
           4.968082995567027,
           4.774966059686992,
           4.61447658329897,
           4.486506866326096,
           4.3959246131532845,
           null,
           null,
           null,
           null,
           null
          ],
          [
           64.73225762208753,
           64.78301580003978,
           64.83377397799202,
           64.88453215594427,
           64.93529033389653,
           64.98604851184878,
           65.03680668980104,
           65.08756486775329,
           65.13832304570555,
           65.1890812236578,
           65.23983940161006,
           65.2905975795623,
           65.34135575751455,
           65.3921139354668,
           65.44287211341906,
           65.4936302913713,
           65.54438846932356,
           65.59514664727581,
           65.64590482522806,
           65.69666300318032,
           65.74742118113258,
           65.79817935908483,
           65.84893753703707,
           65.89969571498933,
           65.95045389294158,
           66.00121207089383,
           66.05197024884608,
           66.10272842679834,
           66.15348660475058,
           66.20424478270283,
           66.25500296065509,
           66.30576113860735,
           66.3565193165596,
           66.40727749451185,
           66.4580356724641,
           66.50879385041635,
           66.55955202836861,
           66.61031020632086,
           66.66106838427311,
           66.71182656222537,
           66.76258474017762,
           66.81334291812986,
           66.86410109608212,
           66.91485927403437,
           66.96561745198662,
           67.01637562993888,
           67.06713380789112,
           67.11789198584339,
           67.16865016379563,
           67.21940834174788,
           67.27016651970014,
           67.32092469765239,
           67.37168287560465,
           67.4224410535569,
           67.47319923150914,
           67.52395740946139,
           67.57471558741365,
           67.62547376536591,
           67.67623194331817,
           67.7269901212704,
           67.77774829922267,
           67.82850647717491,
           67.87950964405329,
           67.9310027902233,
           67.98249593639333,
           68.03398908256335,
           68.08548222873338,
           68.1369753749034,
           68.18846852107343,
           68.23996166724345,
           68.29145481341348,
           68.3429479595835,
           68.39444110575351,
           68.44593425192355,
           68.49742739809356,
           68.54892054426358,
           68.60041369043361,
           68.65190683660363,
           68.70339998277366,
           68.75489312894368,
           68.80638627511371,
           68.85787942128373,
           68.90937256745374,
           68.96086571362378,
           69.00191344747782,
           69.04087209886868,
           69.07983075025952,
           69.11878940165036,
           69.15774805304122,
           69.19670670443205,
           69.2356653558229,
           69.27462400721376,
           69.3135826586046,
           69.35254130999544,
           69.3914999613863,
           69.43045861277714,
           69.46941726416799,
           69.50837591555884,
           69.5473345669497,
           69.58629321834054,
           69.6252518697314,
           69.66421052112224,
           69.7031691725131,
           69.74212782390394,
           69.78108647529479,
           69.81963937139136,
           69.8573807592834,
           69.89512214717544,
           69.93286353506748,
           69.97060492295952,
           70.00834631085155,
           70.0460876987436,
           70.08382908663563,
           70.12157047452769,
           70.15931186241971,
           70.19705325031175,
           70.2347946382038,
           70.27253602609582,
           70.31027741398788,
           70.3480188018799,
           70.38576018977194,
           70.42350157766398,
           70.46124296555601,
           70.49898435344807,
           70.53672574134009,
           70.57446712923213,
           70.61220851712417,
           70.6499499050162,
           70.68769129290826,
           70.72543268080028,
           70.76317406869232,
           70.80091545658436,
           70.8386568444764,
           70.87639823236844,
           70.91413962026049,
           70.95188100815253,
           70.98962239604455,
           71.0273637839366,
           71.06510517182863,
           71.10284655972067,
           71.14058794761272,
           71.17832933550476,
           71.2160707233968,
           71.25381211128882,
           71.29155349918088,
           71.3292948870729,
           71.36703627496495,
           71.40477766285699,
           71.44251905074901,
           71.48026043864107,
           71.5180018265331,
           71.55574321442514,
           71.59348460231718,
           71.63122599020922,
           71.66896737810124,
           71.70670876599328,
           71.74445015388532,
           71.78219154177737,
           71.8199329296694,
           71.85767431756145,
           71.89541570545349,
           71.93315709334553,
           71.97089848123755,
           72.0086398691296,
           72.04638125702164,
           72.08412264491368,
           72.12186403280572,
           72.13023036676722,
           72.12390917376347,
           72.11758798075971,
           72.11126678775595,
           72.1049455947522,
           72.09862440174844,
           72.09230320874468,
           72.08598201574091,
           72.07966082273717,
           72.0733396297334,
           72.06701843672965,
           72.06069724372588,
           72.05437605072213,
           72.04805485771837,
           72.04173366471461,
           72.03541247171086,
           72.02909127870709,
           72.02277008570333,
           72.01644889269957,
           72.01012769969581,
           72.00380650669207,
           71.9974853136883,
           71.99116412068454,
           71.98484292768079,
           71.97852173467703,
           71.97220054167327,
           71.96587934866952,
           71.95955815566576,
           71.953236962662,
           71.94691576965825,
           71.94059457665449,
           71.93427338365072,
           71.92795219064698,
           71.9216309976432,
           71.91530980463945,
           71.90898861163569,
           71.90204978521226,
           71.87905238592893,
           71.8560549866456,
           71.83305758736228,
           71.81006018807895,
           71.78706278879562,
           71.76406538951228,
           71.74106799022896,
           71.71807059094564,
           71.6950731916623,
           71.67207579237898,
           71.64907839309565,
           71.62608099381232,
           71.60308359452901,
           71.58008619524566,
           71.55708879596233,
           71.53409139667902,
           71.51109399739568,
           71.48809659811235,
           71.46509919882902,
           71.4421017995457,
           71.41910440026237,
           71.39610700097904,
           71.37310960169572,
           71.35011220241239,
           71.32711480312906,
           71.30411740384574,
           71.2811200045624,
           71.25812260527908,
           71.23512520599574,
           71.21212780671242,
           71.18913040742909,
           71.16613300814575,
           71.14313560886244,
           71.1201382095791,
           71.09714081029577,
           71.07414341101246,
           71.05114601172912,
           71.02814861244579,
           71.00515121316246,
           70.98215381387914,
           70.95915641459581,
           70.93615901531248,
           70.91316161602914,
           70.89016421674582,
           70.86716681746249,
           70.84416941817916,
           70.50811579805044,
           69.8590059570763,
           69.20989611610223,
           68.56078627512815,
           67.91167643415403,
           67.26256659317995,
           66.61345675220588,
           65.96434691123176,
           65.31523707025762,
           64.6661272292836,
           64.01701738830948,
           63.367907547335335,
           62.71879770636127,
           62.069687865387195,
           61.42057802441307,
           60.77146818343899,
           60.12235834246492,
           59.473248501490794,
           58.824138660516724,
           58.175028819542646,
           57.525918978568505,
           56.87680913759438,
           56.22769929662036,
           55.578589455646224,
           54.929479614672104,
           54.28036977369803,
           53.631259932723964,
           52.98215009174982,
           52.33304025077575,
           51.683930409801675,
           51.03482056882755,
           50.38571072785341,
           49.7366008868794,
           49.08749104590527,
           48.43838120493114,
           47.78927136395706,
           47.14016152298299,
           46.491051682008866,
           45.84194184103479,
           45.19283200006071,
           44.543722159086585,
           43.89461231811251,
           43.24550247713843,
           42.5963926361643,
           41.94728279519017,
           41.29817295421616,
           40.64906311324202,
           39.9999532722679,
           39.350843431293825,
           38.70173359031975,
           38.05262374934562,
           37.40351390837155,
           36.75440406739747,
           36.10529422642334,
           35.456184385449205,
           34.8070745444752,
           34.157964703501065,
           33.50885486252694,
           32.85974502155286,
           32.210635180578784,
           31.56152533960466,
           30.912415498630583,
           30.263305657656506,
           29.614195816682383,
           28.965085975708313,
           28.315976134734235,
           27.6668662937601,
           27.017756452785974,
           26.36864661181196,
           25.719536770837824,
           25.0704269298637,
           24.421317088889623,
           23.77220724791555,
           23.12309740694142,
           22.47398756596735,
           21.824877724993275,
           21.17576788401914,
           20.526658043045067,
           19.876411694441167,
           19.22609057854274,
           18.575769462644313,
           17.92544834674595,
           17.27512723084758,
           16.7959835237571,
           16.659194634282386,
           16.52240574480767,
           16.482464062818877,
           16.45419082990085,
           16.401619641347015,
           16.31954357521441,
           16.23746750908181,
           16.155391442949217,
           16.07331537681662,
           15.991239310684014,
           15.909163244551422,
           15.827087178418823,
           15.745011112286225,
           15.662935046153628,
           15.580858980021038,
           15.498782913888428,
           15.416706847755838,
           15.334630781623241,
           15.252554715490637,
           15.170478649358039,
           15.088402583225438,
           15.006326517092848,
           14.924250450960242,
           14.842174384827649,
           14.760098318695054,
           14.678022252562453,
           14.595946186429856,
           14.513870120297264,
           14.43179405416466,
           14.349717988032058,
           14.267641921899473,
           14.18556585576687,
           14.103489789634265,
           14.021413723501674,
           13.939337657369078,
           13.857261591236474,
           13.775185525103879,
           13.693109458971282,
           13.61103339283868,
           13.528957326706086,
           13.44688126057349,
           13.364805194440887,
           13.282729128308285,
           13.200653062175691,
           13.118576996043098,
           13.036500929910494,
           12.9544248637779,
           12.872348797645305,
           12.790272731512703,
           12.708196665380108,
           12.626120599247514,
           12.544044533114914,
           12.46196846698231,
           12.379892400849721,
           12.297816334717119,
           12.215740268584518,
           12.133664202451921,
           12.051588136319328,
           11.969512070186724,
           11.88743600405413,
           11.805359937921535,
           11.723283871788933,
           11.641207805656338,
           11.559131739523744,
           11.477055673391142,
           11.39497960725854,
           11.312903541125952,
           11.230827474993351,
           11.148751408860747,
           11.066675342728153,
           10.984599276595558,
           10.902523210462956,
           10.820664244187546,
           10.73942039851684,
           10.65817655284613,
           10.576932707175416,
           10.495688861504718,
           10.414445015834005,
           10.333201170163296,
           10.251957324492588,
           10.170713478821883,
           10.089469633151172,
           10.008225787480471,
           9.92698194180976,
           9.84573809613905,
           9.764494250468335,
           9.683250404797636,
           9.602006559126927,
           9.520762713456214,
           9.439518867785514,
           9.358275022114803,
           9.27703117644409,
           9.195787330773394,
           9.11454348510268,
           9.03329963943197,
           8.952055793761254,
           8.870811948090559,
           8.789568102419846,
           8.708324256749131,
           8.627080411078435,
           8.546525623765186,
           8.466495580097526,
           8.386465536429881,
           8.306435492762219,
           8.226405449094562,
           8.146375405426916,
           8.066345361759254,
           7.986315318091597,
           7.9062852744239365,
           7.826255230756292,
           7.7462251870886325,
           7.666195143420973,
           7.5861650997533285,
           7.506135056085668,
           7.426105012418009,
           7.470090497374489,
           7.613288405230266,
           7.7564863130860395,
           7.899684220941816,
           8.042882128797563,
           8.18608003665334,
           8.329277944509116,
           8.472475852364864,
           8.61567376022064,
           8.758871668076416,
           8.902069575932163,
           9.045267483787939,
           9.188465391643714,
           9.331663299499462,
           9.474861207355238,
           9.618059115211013,
           9.761257023066788,
           9.904454930922538,
           10.047652838778314,
           10.190850746634087,
           10.0532496695402,
           9.759649224349197,
           9.46604877915819,
           9.172628669317142,
           8.882364426294043,
           8.592100183270933,
           8.30278695895484,
           8.016890357714454,
           7.730993756474013,
           7.450447571672111,
           7.170524834969546,
           6.898263139313984,
           6.629302699042775,
           6.365335248605577,
           6.108802211644024,
           5.860311947411379,
           5.621501680044753,
           5.39564180620948,
           5.181953042559453,
           4.986452605144508,
           4.814477764360257,
           4.666418695044309,
           4.543579895745043,
           4.449070444840334,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           64.87456384328131,
           64.92532202123357,
           64.97608019918582,
           65.02683837713806,
           65.07759655509032,
           65.12835473304258,
           65.17911291099482,
           65.22987108894708,
           65.28062926689933,
           65.33138744485159,
           65.38214562280383,
           65.4329038007561,
           65.48366197870834,
           65.53442015666059,
           65.58517833461285,
           65.6359365125651,
           65.68669469051734,
           65.7374528684696,
           65.78821104642185,
           65.8389692243741,
           65.88972740232636,
           65.94048558027862,
           65.99124375823087,
           66.04200193618311,
           66.09276011413537,
           66.14351829208762,
           66.19427647003987,
           66.24503464799213,
           66.29579282594437,
           66.34655100389662,
           66.39730918184888,
           66.44806735980113,
           66.49882553775339,
           66.54958371570564,
           66.60034189365788,
           66.65110007161014,
           66.70185824956239,
           66.75261642751465,
           66.8033746054669,
           66.85413278341916,
           66.9048909613714,
           66.95564913932365,
           67.0064073172759,
           67.05716549522816,
           67.10792367318041,
           67.15868185113266,
           67.20944002908492,
           67.26019820703716,
           67.31095638498942,
           67.36171456294167,
           67.41247274089393,
           67.46323091884618,
           67.51398909679844,
           67.56474727475069,
           67.61550545270293,
           67.66626363065518,
           67.71702180860746,
           67.7677799865597,
           67.81853816451195,
           67.8692963424642,
           67.92005452041644,
           67.9708126983687,
           68.02157087632095,
           68.07232905427321,
           68.12308723222546,
           68.1738454101777,
           68.22460358812995,
           68.27536176608221,
           68.32611994403446,
           68.37687812198672,
           68.42763629993898,
           68.47839447789123,
           68.52915265584348,
           68.57991083379572,
           68.63066901174798,
           68.68142718970023,
           68.73218536765249,
           68.78294354560474,
           68.833701723557,
           68.88507237442298,
           68.93656552059299,
           68.98805866676301,
           69.03955181293304,
           69.09104495910306,
           69.1320926929571,
           69.17105134434796,
           69.2100099957388,
           69.24896864712966,
           69.2879272985205,
           69.32587156266683,
           69.36361295055887,
           69.40135433845091,
           69.43909572634294,
           69.47683711423498,
           69.51457850212702,
           69.55231989001906,
           69.5900612779111,
           69.62780266580315,
           69.66554405369519,
           69.70328544158723,
           69.74102682947925,
           69.77876821737131,
           69.81650960526333,
           69.85425099315538,
           69.89199238104742,
           69.92973376893946,
           69.96747515683148,
           70.00521654472354,
           70.04295793261556,
           70.0806993205076,
           70.11844070839965,
           70.15618209629169,
           70.19392348418371,
           70.23166487207575,
           70.2694062599678,
           70.30714764785984,
           70.34488903575188,
           70.38263042364392,
           70.42037181153596,
           70.45811319942798,
           70.49585458732003,
           70.53359597521205,
           70.5713373631041,
           70.60907875099613,
           70.64682013888817,
           70.68456152678021,
           70.72230291467227,
           70.7600443025643,
           70.79778569045634,
           70.83552707834838,
           70.8732684662404,
           70.91100985413246,
           70.94875124202449,
           70.98649262991653,
           71.02423401780857,
           71.06197540570061,
           71.09971679359265,
           71.13745818148467,
           71.17519956937673,
           71.21294095726876,
           71.2506823451608,
           71.28842373305284,
           71.32616512094488,
           71.36390650883692,
           71.40164789672896,
           71.43938928462099,
           71.47713067251303,
           71.51487206040507,
           71.55261344829711,
           71.59035483618914,
           71.62809622408118,
           71.66583761197322,
           71.70357899986526,
           71.7413203877573,
           71.77906177564934,
           71.81680316354137,
           71.8545445514334,
           71.89228593932545,
           71.93002732721749,
           71.96776871510953,
           72.00551010300157,
           72.04325149089361,
           72.08099287878565,
           72.11873426667768,
           72.15647565456972,
           72.19421704246176,
           72.2319584303538,
           72.2403247643153,
           72.23400357131155,
           72.22768237830779,
           72.22136118530403,
           72.21503999230028,
           72.2087187992965,
           72.20239760629275,
           72.19607641328899,
           72.18728465318,
           72.16428725389669,
           72.14128985461336,
           72.11829245533004,
           72.0952950560467,
           72.07229765676338,
           72.04930025748004,
           72.02630285819671,
           72.00330545891339,
           71.98030805963006,
           71.95731066034674,
           71.93431326106341,
           71.91131586178008,
           71.88831846249674,
           71.86532106321343,
           71.84232366393009,
           71.81932626464676,
           71.79632886536344,
           71.77333146608011,
           71.75033406679678,
           71.72733666751346,
           71.70433926823013,
           71.68134186894679,
           71.65834446966346,
           71.63534707038013,
           71.61234967109681,
           71.58935227181348,
           71.56635487253016,
           71.54335747324683,
           71.5203600739635,
           71.49736267468016,
           71.47436527539683,
           71.45136787611352,
           71.42837047683018,
           71.40537307754686,
           71.38237567826353,
           71.3593782789802,
           71.33638087969686,
           71.31338348041353,
           71.29038608113022,
           71.26738868184688,
           71.24439128256357,
           71.22139388328023,
           71.1983964839969,
           71.17539908471358,
           71.15240168543025,
           71.12940428614692,
           71.1064068868636,
           71.08340948758025,
           71.06041208829693,
           71.0374146890136,
           71.01441728973029,
           70.99141989044695,
           70.96842249116362,
           70.9454250918803,
           70.92242769259695,
           70.89943029331363,
           70.8764328940303,
           70.85343549474698,
           70.83043809546365,
           70.80744069618032,
           70.784443296897,
           70.76144589761367,
           70.73844849833034,
           70.71545109904702,
           70.69245369976369,
           70.66945630048036,
           70.64645890119702,
           70.62346150191371,
           70.60046410263037,
           70.57746670334704,
           70.5544693040637,
           70.53147190478039,
           70.50847450549705,
           70.48547710621374,
           70.149423486085,
           69.50031364511088,
           68.85120380413679,
           68.20209396316272,
           67.55298412218859,
           66.90387428121451,
           66.25476444024045,
           65.60565459926632,
           64.95654475829218,
           64.30743491731818,
           63.658325076344035,
           63.00921523536991,
           62.36010539439583,
           61.71099555342175,
           61.06188571244763,
           60.412775871473556,
           59.76366603049948,
           59.114556189525345,
           58.46544634855128,
           57.8163365075772,
           57.16722666660307,
           56.51811682562895,
           55.86900698465492,
           55.2198971436808,
           54.57078730270666,
           53.921677461732585,
           53.272567620758515,
           52.62345777978439,
           51.974347938810325,
           51.32523809783625,
           50.67612825686211,
           50.02701841588798,
           49.37790857491396,
           48.728798733939826,
           48.079688892965706,
           47.43057905199163,
           46.78146921101755,
           46.132359370043424,
           45.483249529069354,
           44.83413968809528,
           44.18502984712114,
           43.53592000614708,
           42.886810165173,
           42.23770032419886,
           41.588590483224735,
           40.93948064225073,
           40.29037080127659,
           39.64126096030246,
           38.99215111932839,
           38.34304127835431,
           37.693931437380186,
           37.044821596406116,
           36.39571175543204,
           35.746601914457905,
           35.09894086243534,
           34.452093514577186,
           33.8052461667189,
           33.15839881886063,
           32.51155147100242,
           31.8647041231442,
           31.217856775285927,
           30.57100942742771,
           29.924162079569502,
           29.277314731711222,
           28.630467383853006,
           27.983620035994793,
           27.33677268813652,
           26.689925340278243,
           26.043077992420088,
           25.39623064456181,
           24.749383296703538,
           24.102535948845325,
           23.45568860098711,
           22.80884125312883,
           22.161993905270617,
           21.5151465574124,
           20.868299209554124,
           20.22145186169591,
           19.574604513837695,
           18.927757165979422,
           18.280909818121145,
           17.634062470262933,
           16.987215122404717,
           16.52862486845505,
           16.446548802322457,
           16.364472736189864,
           16.28239667005726,
           16.200320603924666,
           16.118244537792073,
           16.03616847165947,
           15.954092405526866,
           15.872016339394277,
           15.789940273261676,
           15.707864207129072,
           15.62578814099648,
           15.543712074863883,
           15.461636008731281,
           15.379559942598688,
           15.297483876466098,
           15.215407810333486,
           15.133331744200897,
           15.051255678068301,
           14.969179611935695,
           14.887103545803095,
           14.805027479670498,
           14.722951413537906,
           14.640875347405302,
           14.558799281272707,
           14.476723215140112,
           14.394647149007511,
           14.312571082874914,
           14.230495016742323,
           14.148418950609718,
           14.066342884477116,
           13.98426681834453,
           13.902190752211927,
           13.820114686079323,
           13.738038619946732,
           13.655962553814135,
           13.573886487681532,
           13.491810421548937,
           13.40973435541634,
           13.327658289283738,
           13.245582223151144,
           13.16350615701855,
           13.081430090885945,
           12.999354024753343,
           12.91727795862075,
           12.835201892488156,
           12.753125826355552,
           12.671049760222958,
           12.588973694090365,
           12.50689762795776,
           12.425514215945674,
           12.344270370274966,
           12.26302652460426,
           12.181782678933544,
           12.100538833262844,
           12.019294987592136,
           11.938051141921422,
           11.856807296250715,
           11.775563450580012,
           11.694319604909298,
           11.613075759238592,
           11.53183191356789,
           11.450588067897177,
           11.36934422222647,
           11.288100376555768,
           11.206856530885055,
           11.12561268521434,
           11.04436883954364,
           10.963124993872931,
           10.881881148202218,
           10.800637302531511,
           10.719393456860807,
           10.638149611190098,
           10.556905765519389,
           10.475661919848685,
           10.394418074177976,
           10.313174228507261,
           10.231930382836563,
           10.150686537165848,
           10.069442691495139,
           9.988198845824433,
           9.906955000153726,
           9.825711154483017,
           9.744467308812316,
           9.663393077961299,
           9.583363034293638,
           9.503332990625978,
           9.423302946958332,
           9.343272903290671,
           9.263242859623015,
           9.18321281595537,
           9.103182772287708,
           9.023152728620051,
           8.943122684952403,
           8.863092641284744,
           8.783062597617086,
           8.703032553949424,
           8.62300251028178,
           8.54297246661412,
           8.462942422946458,
           8.382912379278817,
           8.302882335611157,
           8.222852291943497,
           8.217231565450302,
           8.360429473306077,
           8.50362738116185,
           8.646825289017599,
           8.790023196873378,
           8.933221104729151,
           9.076419012584925,
           9.219616920440673,
           9.362814828296452,
           9.506012736152226,
           9.649210644007976,
           9.792408551863751,
           9.935606459719523,
           10.078804367575273,
           10.222002275431048,
           10.365200183286824,
           10.508398091142599,
           10.651595998998348,
           10.794793906854125,
           10.9379918147099,
           11.081189722565647,
           11.224387630421422,
           11.367585538277199,
           11.510783446132947,
           11.653981353988723,
           11.627808417135894,
           11.334207971944942,
           11.040607526753938,
           10.747007081562936,
           10.453406636371945,
           10.162781722966491,
           9.872517479943387,
           9.58225323692028,
           9.293468356351028,
           9.007571755110586,
           8.721675153870146,
           8.43845376065284,
           8.158374675982124,
           7.878920982667884,
           7.60665928701232,
           7.335019566990166,
           7.070556489168281,
           6.809067176457139,
           6.552534139495631,
           6.304187496247458,
           6.062948326762022,
           5.830648071130696,
           5.608124110973457,
           5.395823089551896,
           5.198111541579969,
           5.01990613567445,
           4.860696015754667,
           4.720379238321925,
           4.600652925164018,
           4.5038572136941175,
           4.426774037222506,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           65.00577384906519,
           65.05628168246963,
           65.10678951587408,
           65.15729734927852,
           65.20780518268296,
           65.25831301608741,
           65.30882084949185,
           65.35932868289629,
           65.40983651630074,
           65.46034434970518,
           65.51085218310963,
           65.56136001651407,
           65.61199302194638,
           65.66275119989862,
           65.71350937785088,
           65.76426755580312,
           65.81502573375538,
           65.86578391170764,
           65.91654208965988,
           65.96730026761213,
           66.01805844556439,
           66.06881662351665,
           66.11957480146889,
           66.17033297942115,
           66.2210911573734,
           66.27184933532564,
           66.3226075132779,
           66.37336569123016,
           66.42412386918241,
           66.47488204713466,
           66.52564022508692,
           66.57639840303915,
           66.62715658099141,
           66.67791475894367,
           66.72867293689592,
           66.77943111484817,
           66.83018929280043,
           66.88094747075269,
           66.93170564870493,
           66.98246382665718,
           67.03322200460943,
           67.08398018256167,
           67.13473836051395,
           67.1854965384662,
           67.23625471641844,
           67.28701289437069,
           67.33777107232294,
           67.3885292502752,
           67.43928742822746,
           67.4900456061797,
           67.54080378413195,
           67.5915619620842,
           67.64232014003646,
           67.69307831798871,
           67.74383649594097,
           67.79459467389322,
           67.84535285184548,
           67.89611102979772,
           67.94686920774997,
           67.99762738570223,
           68.04838556365448,
           68.09914374160672,
           68.14990191955899,
           68.20066009751123,
           68.2514182754635,
           68.30217645341574,
           68.35293463136799,
           68.40369280932025,
           68.4544509872725,
           68.50520916522476,
           68.555967343177,
           68.60672552112925,
           68.65748369908151,
           68.70824187703376,
           68.75900005498602,
           68.80975823293826,
           68.86051641089051,
           68.91127458884277,
           68.96203276679502,
           69.01279094474728,
           69.06354912269953,
           69.11430730065177,
           69.16506547860402,
           69.2158236565563,
           69.25573450945835,
           69.29347589735039,
           69.33121728524243,
           69.36895867313447,
           69.40670006102651,
           69.44444144891855,
           69.48218283681058,
           69.51992422470262,
           69.55766561259466,
           69.59540700048669,
           69.63314838837874,
           69.67088977627077,
           69.70863116416282,
           69.74637255205485,
           69.7841139399469,
           69.82185532783893,
           69.85959671573097,
           69.89733810362301,
           69.93507949151505,
           69.97282087940708,
           70.01056226729912,
           70.04830365519116,
           70.0860450430832,
           70.12378643097524,
           70.16152781886728,
           70.19926920675931,
           70.23701059465135,
           70.27475198254339,
           70.31249337043542,
           70.35023475832747,
           70.3879761462195,
           70.42571753411156,
           70.46345892200358,
           70.50120030989562,
           70.53894169778766,
           70.5766830856797,
           70.61442447357175,
           70.65216586146377,
           70.68990724935581,
           70.72764863724785,
           70.76539002513988,
           70.80313141303193,
           70.84087280092398,
           70.87861418881602,
           70.91635557670804,
           70.95409696460008,
           70.99183835249212,
           71.02957974038416,
           71.0673211282762,
           71.10506251616825,
           71.14280390406027,
           71.18054529195231,
           71.21828667984435,
           71.2560280677364,
           71.29376945562844,
           71.33151084352048,
           71.36925223141252,
           71.40699361930454,
           71.44473500719658,
           71.48247639508863,
           71.52021778298067,
           71.55795917087269,
           71.59570055876473,
           71.63344194665677,
           71.67118333454881,
           71.70892472244087,
           71.74666611033288,
           71.78440749822492,
           71.82214888611696,
           71.85989027400902,
           71.89763166190104,
           71.9350641792042,
           71.97095235449129,
           72.00684052977837,
           72.04272870506546,
           72.07861688035256,
           72.11450505563963,
           72.15039323092672,
           72.1862814062138,
           72.22216958150088,
           72.25805775678796,
           72.29394593207505,
           72.32983410736213,
           72.3217182587106,
           72.29160039808978,
           72.26148253746895,
           72.23136467684813,
           72.2012468162273,
           72.17112895560648,
           72.14101109498564,
           72.11089323436482,
           72.08077537374399,
           72.05065751312317,
           72.02053965250234,
           71.99042179188152,
           71.96030393126068,
           71.93018607063986,
           71.90006821001903,
           71.86995034939821,
           71.83983248877738,
           71.80971462815656,
           71.77959676753574,
           71.7494789069149,
           71.71936104629407,
           71.68924318567323,
           71.65912532505243,
           71.62900746443158,
           71.59888960381076,
           71.56877174318993,
           71.53865388256911,
           71.50853602194829,
           71.47841816132744,
           71.44830030070662,
           71.4181824400858,
           71.38806457946497,
           71.35794671884416,
           71.32782885822331,
           71.29771099760248,
           71.26759313698166,
           71.23747527636084,
           71.20735741574,
           71.17723955511919,
           71.14712169449835,
           71.11700383387753,
           71.0868859732567,
           71.05676811263587,
           71.02665025201506,
           71.00068596701476,
           70.97768856773143,
           70.95469116844811,
           70.93169376916478,
           70.90869636988144,
           70.88569897059813,
           70.86270157131479,
           70.83970417203146,
           70.81670677274815,
           70.79370937346481,
           70.77071197418148,
           70.74771457489815,
           70.72471717561481,
           70.7017197763315,
           70.67872237704816,
           70.65572497776483,
           70.63272757848151,
           70.60973017919818,
           70.58673277991485,
           70.56373538063153,
           70.5407379813482,
           70.51774058206487,
           70.49474318278155,
           70.47174578349822,
           70.4487483842149,
           70.42575098493157,
           70.40275358564823,
           70.3797561863649,
           70.35675878708159,
           70.33376138779825,
           70.31076398851492,
           70.28776658923158,
           70.26476918994825,
           70.24177179066493,
           70.2187743913816,
           70.19577699209827,
           70.17277959281495,
           70.14978219353162,
           70.1267847942483,
           69.79073117411956,
           69.14162133314544,
           68.49251149217136,
           67.84340165119728,
           67.19429181022316,
           66.54518196924909,
           65.89607212827502,
           65.24696228730087,
           64.59785244632674,
           63.948742605352734,
           63.2996327643786,
           62.65052292340447,
           62.0014130824304,
           61.352303241456326,
           60.70319340048219,
           60.054083559508115,
           59.40497371853405,
           58.75586387755992,
           58.10675403658585,
           57.45764419561176,
           56.808534354637644,
           56.161528238202266,
           55.51468089034411,
           54.86783354248584,
           54.220986194627564,
           53.57413884676935,
           52.92729149891113,
           52.280444151052855,
           51.63359680319464,
           50.98674945533643,
           50.33990210747815,
           49.693054759619876,
           49.04620741176172,
           48.399360063903444,
           47.752512716045175,
           47.10566536818696,
           46.45881802032874,
           45.81197067247047,
           45.16512332461225,
           44.51827597675404,
           43.87142862889577,
           43.22458128103755,
           42.57773393317934,
           41.93088658532106,
           41.284039237462785,
           40.63719188960462,
           39.99034454174635,
           39.343497193888076,
           38.69664984602986,
           38.04980249817165,
           37.402955150313375,
           36.75610780245516,
           36.10926045459694,
           35.46241310673867,
           34.815565758880396,
           34.16871841102224,
           33.521871063163964,
           32.87502371530569,
           32.228176367447475,
           31.581329019589262,
           30.934481671730982,
           30.287634323872773,
           29.640786976014557,
           28.993939628156284,
           28.347092280298064,
           27.70024493243985,
           27.05339758458157,
           26.406550236723298,
           25.759702888865146,
           25.112855541006873,
           24.466008193148596,
           23.819160845290376,
           23.172313497432164,
           22.525466149573887,
           21.878618801715675,
           21.231771453857462,
           20.584924105999185,
           19.93807675814097,
           19.291229410282753,
           18.644382062424484,
           17.997534714566207,
           17.35068736670799,
           16.703840018849775,
           16.24524976490011,
           16.163173698767515,
           16.081097632634922,
           15.999021566502321,
           15.916945500369723,
           15.83486943423713,
           15.752793368104523,
           15.670717301971926,
           15.588641235839335,
           15.506565169706734,
           15.424489103574128,
           15.342413037441538,
           15.260336971308941,
           15.178260905176339,
           15.096184839043746,
           15.014108772911154,
           14.932032706778546,
           14.849956640645955,
           14.76788057451336,
           14.685804508380754,
           14.603728442248153,
           14.521652376115556,
           14.439576309982964,
           14.35750024385036,
           14.275424177717765,
           14.19334811158517,
           14.111608033374509,
           14.030364187703803,
           13.949120342033098,
           13.867876496362387,
           13.786632650691674,
           13.705388805020974,
           13.624144959350263,
           13.542901113679552,
           13.461657268008846,
           13.380413422338139,
           13.299169576667428,
           13.217925730996722,
           13.136681885326015,
           13.055438039655304,
           12.974194193984598,
           12.892950348313892,
           12.811706502643183,
           12.730462656972469,
           12.649218811301765,
           12.567974965631063,
           12.486731119960346,
           12.40548727428964,
           12.324243428618939,
           12.242999582948224,
           12.161755737277518,
           12.080511891606811,
           11.999268045936105,
           11.91802420026539,
           11.836780354594687,
           11.755536508923981,
           11.674292663253265,
           11.59304881758256,
           11.51180497191186,
           11.430561126241143,
           11.349317280570437,
           11.268073434899735,
           11.186829589229022,
           11.105585743558315,
           11.024341897887613,
           10.9430980522169,
           10.861854206546186,
           10.780610360875484,
           10.700230488489751,
           10.620200444822093,
           10.540170401154437,
           10.460140357486784,
           10.380110313819126,
           10.300080270151472,
           10.220050226483822,
           10.140020182816162,
           10.059990139148502,
           9.979960095480855,
           9.899930051813195,
           9.819900008145538,
           9.739869964477885,
           9.659839920810231,
           9.579809877142571,
           9.499779833474927,
           9.41974978980727,
           9.339719746139611,
           9.25968970247195,
           9.179659658804304,
           9.099629615136642,
           9.019599571468985,
           8.96437263352611,
           9.107570541381886,
           9.250768449237661,
           9.393966357093406,
           9.537164264949185,
           9.680362172804958,
           9.823560080660734,
           9.966757988516484,
           10.109955896372258,
           10.253153804228035,
           10.396351712083783,
           10.539549619939557,
           10.682747527795335,
           10.825945435651084,
           10.96914334350686,
           11.112341251362631,
           11.255539159218383,
           11.398737067074158,
           11.541934974929934,
           11.685132882785707,
           11.828330790641456,
           11.971528698497234,
           12.114726606353008,
           12.257924514208757,
           12.401122422064532,
           12.544320329920305,
           12.687518237776056,
           12.830716145631833,
           12.973914053487604,
           13.11711196134338,
           13.202367164731639,
           12.908766719540637,
           12.615166274349633,
           12.321565829158693,
           12.027965383967679,
           11.734364938776677,
           11.443199019638948,
           11.152934776615844,
           10.862670533592741,
           10.572406290569685,
           10.284149753747155,
           9.998253152506713,
           9.712356551266273,
           9.42645995002589,
           9.14638086496281,
           8.866301780292076,
           8.587317130366262,
           8.315055434710699,
           8.042793739055137,
           7.776273357115672,
           7.511810279293787,
           7.25279910430875,
           6.9962660673471895,
           6.748063045083531,
           6.504394973479339,
           6.267213078912525,
           6.040132793734128,
           5.820606415737429,
           5.609693136544335,
           5.410657032788314,
           5.228074155945182,
           5.061406900552412,
           4.910364332146947,
           4.775155982179863,
           4.657725954582973,
           4.559332592364925,
           4.479504461556123,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           65.13215941456794,
           65.18266724797238,
           65.23317508137681,
           65.28368291478125,
           65.3341907481857,
           65.38469858159016,
           65.43520641499458,
           65.48571424839903,
           65.53622208180349,
           65.58672991520793,
           65.63723774861236,
           65.6877455820168,
           65.73825341542124,
           65.7887612488257,
           65.83926908223015,
           65.88977691563458,
           65.94028474903902,
           65.99079258244348,
           66.04130041584791,
           66.09180824925235,
           66.1423160826568,
           66.19282391606124,
           66.24333174946568,
           66.29383958287013,
           66.34434741627457,
           66.39485524967901,
           66.44536308308346,
           66.49587091648789,
           66.54637874989234,
           66.59713692755724,
           66.64789510550949,
           66.69865328346174,
           66.74941146141398,
           66.80016963936626,
           66.8509278173185,
           66.90168599527075,
           66.95244417322301,
           67.00320235117526,
           67.05396052912752,
           67.10471870707977,
           67.15547688503202,
           67.20623506298426,
           67.25699324093651,
           67.30775141888878,
           67.35850959684103,
           67.40926777479328,
           67.46002595274554,
           67.51078413069777,
           67.56154230865003,
           67.6123004866023,
           67.66305866455454,
           67.7138168425068,
           67.76457502045905,
           67.81533319841128,
           67.86609137636356,
           67.91684955431579,
           67.96760773226805,
           68.0183659102203,
           68.06912408817256,
           68.11988226612482,
           68.17064044407707,
           68.22139862202931,
           68.27215679998156,
           68.3229149779338,
           68.37367315588608,
           68.42443133383833,
           68.47518951179057,
           68.52594768974282,
           68.57670586769508,
           68.62746404564734,
           68.67822222359958,
           68.72898040155184,
           68.77973857950408,
           68.83049675745634,
           68.88125493540859,
           68.93201311336085,
           68.9827712913131,
           69.03352946926535,
           69.08428764721761,
           69.13504582516987,
           69.1858040031221,
           69.23656218107435,
           69.28732035902661,
           69.33807853697886,
           69.37798938988094,
           69.41573077777298,
           69.453472165665,
           69.49121355355706,
           69.52895494144909,
           69.56669632934113,
           69.60443771723317,
           69.6421791051252,
           69.67992049301725,
           69.71766188090928,
           69.75540326880133,
           69.79314465669336,
           69.83088604458541,
           69.86862743247744,
           69.90636882036948,
           69.94411020826152,
           69.98185159615355,
           70.0195929840456,
           70.05733437193763,
           70.09507575982967,
           70.13281714772171,
           70.17055853561374,
           70.20829992350578,
           70.24604131139782,
           70.28378269928986,
           70.3215240871819,
           70.35926547507394,
           70.39700686296598,
           70.43474825085801,
           70.47248963875006,
           70.51023102664209,
           70.54797241453413,
           70.58571380242617,
           70.6234551903182,
           70.66119657821025,
           70.69893796610228,
           70.73667935399432,
           70.77442074188636,
           70.8121621297784,
           70.84990351767044,
           70.88764490556247,
           70.92538629345451,
           70.96312768134655,
           71.00086906923859,
           71.03861045713063,
           71.07635184502267,
           71.1140932329147,
           71.15183462080674,
           71.18957600869878,
           71.22731739659082,
           71.26505878448286,
           71.3028001723749,
           71.34054156026694,
           71.37828294815897,
           71.41602433605101,
           71.45253024674591,
           71.488418422033,
           71.52430659732008,
           71.56019477260718,
           71.59608294789425,
           71.63197112318134,
           71.66785929846841,
           71.70374747375551,
           71.73963564904258,
           71.77552382432967,
           71.81141199961677,
           71.84730017490384,
           71.88318835019092,
           71.919076525478,
           71.95496470076509,
           71.99085287605217,
           72.02674105133926,
           72.06262922662636,
           72.09851740191343,
           72.13440557720051,
           72.1702937524876,
           72.20618192777468,
           72.24207010306176,
           72.27795827834885,
           72.31384645363593,
           72.34973462892302,
           72.3856228042101,
           72.42151097949719,
           72.41339513084567,
           72.38327727022484,
           72.35315940960402,
           72.32304154898318,
           72.29292368836236,
           72.26280582774153,
           72.23268796712071,
           72.20257010649988,
           72.17245224587904,
           72.14233438525822,
           72.1122165246374,
           72.08209866401657,
           72.05198080339574,
           72.02186294277492,
           71.9917450821541,
           71.96162722153326,
           71.93150936091243,
           71.90139150029161,
           71.87127363967079,
           71.84115577904996,
           71.81103791842912,
           71.7809200578083,
           71.75080219718747,
           71.72068433656665,
           71.69056647594581,
           71.66044861532498,
           71.63033075470416,
           71.60021289408334,
           71.57009503346251,
           71.53997717284167,
           71.50985931222085,
           71.47974145160002,
           71.4496235909792,
           71.41950573035837,
           71.38938786973755,
           71.35927000911673,
           71.3291521484959,
           71.29903428787506,
           71.26891642725423,
           71.2387985666334,
           71.20868070601259,
           71.17856284539175,
           71.14844498477092,
           71.11832712415011,
           71.08820926352928,
           71.05809140290845,
           71.02797354228763,
           70.99785568166679,
           70.96773782104597,
           70.93761996042514,
           70.90750209980432,
           70.87738423918348,
           70.84726637856267,
           70.81714851794183,
           70.787030657321,
           70.75691279670018,
           70.72679493607936,
           70.69667707545852,
           70.66655921483769,
           70.63644135421687,
           70.60632349359605,
           70.57620563297522,
           70.54608777235438,
           70.51596991173356,
           70.48585205111273,
           70.45573419049191,
           70.42561632987108,
           70.39549846925026,
           70.36538060862944,
           70.3352627480086,
           70.30514488738777,
           70.27502702676695,
           70.24490916614612,
           70.2147913055253,
           70.1839068304766,
           70.12772545546147,
           70.07154408044636,
           70.01536270543124,
           69.95918133041611,
           69.902999955401,
           69.84681858038589,
           69.79063720537076,
           69.73445583035564,
           69.38759742824027,
           68.75006199902464,
           68.11252656980909,
           67.47499114059352,
           66.8374557113779,
           66.19992028216234,
           65.56238485294678,
           64.92484942373116,
           64.28731399451553,
           63.6467361271133,
           62.99977505965066,
           62.352813992188025,
           61.70585292472545,
           61.05889185726287,
           60.41193078980023,
           59.764969722337646,
           59.11800865487508,
           58.47104758741243,
           57.82408651994986,
           57.17712545248728,
           56.53016438502464,
           55.883203317562,
           55.23624225009949,
           54.589281182636846,
           53.94232011517421,
           53.29535904771163,
           52.64839798024905,
           52.00143691278642,
           51.35447584532384,
           50.70751477786126,
           50.06055371039862,
           49.41359264293599,
           48.76663157547347,
           48.119670508010834,
           47.47270944054819,
           46.82574837308562,
           46.17878730562304,
           45.5318262381604,
           44.884865170697815,
           44.23790410323524,
           43.59094303577261,
           42.94398196831003,
           42.29702090084745,
           41.650059833384816,
           41.003098765922175,
           40.35613769845965,
           39.709176630997014,
           39.06221556353438,
           38.415254496071796,
           37.76829342860922,
           37.121332361146585,
           36.47437129368401,
           35.82741022622143,
           35.18044915875879,
           34.53348809129615,
           33.88652702383364,
           33.239565956371,
           32.59260488890836,
           31.94564382144578,
           31.298682753983208,
           30.651721686520567,
           30.00476061905799,
           29.357799551595413,
           28.710838484132772,
           28.063877416670195,
           27.416916349207618,
           26.77002248102663,
           26.12317513316836,
           25.476327785310204,
           24.829480437451927,
           24.182633089593654,
           23.535785741735438,
           22.888938393877226,
           22.24209104601895,
           21.595243698160733,
           20.94839635030252,
           20.301549002444244,
           19.654701654586027,
           19.007854306727815,
           18.361006958869538,
           17.71415961101126,
           17.06731226315305,
           16.420464915294833,
           15.961874661345167,
           15.879798595212574,
           15.797722529079977,
           15.716458005132633,
           15.635214159461931,
           15.553970313791224,
           15.472726468120513,
           15.3914826224498,
           15.310238776779101,
           15.228994931108387,
           15.14775108543768,
           15.066507239766972,
           14.985263394096267,
           14.904019548425554,
           14.822775702754848,
           14.741531857084142,
           14.660288011413435,
           14.579044165742728,
           14.497800320072022,
           14.416556474401307,
           14.335312628730595,
           14.254068783059893,
           14.172824937389183,
           14.091581091718478,
           14.010337246047769,
           13.929093400377063,
           13.847849554706352,
           13.766605709035646,
           13.68536186336494,
           13.60411801769423,
           13.522874172023519,
           13.441630326352819,
           13.360386480682106,
           13.279142635011397,
           13.19789878934069,
           13.116654943669982,
           13.03541109799927,
           12.954167252328567,
           12.87292340665786,
           12.791679560987149,
           12.710435715316443,
           12.629191869645737,
           12.547948023975025,
           12.466704178304314,
           12.385460332633606,
           12.304216486962908,
           12.222972641292191,
           12.141728795621484,
           12.060484949950782,
           11.979241104280069,
           11.897997258609362,
           11.817097942685864,
           11.737067899018207,
           11.657037855350545,
           11.577007811682899,
           11.496977768015238,
           11.41694772434758,
           11.336917680679925,
           11.256887637012275,
           11.17685759334461,
           11.096827549676963,
           11.01679750600931,
           10.936767462341649,
           10.856737418673996,
           10.776707375006342,
           10.696677331338682,
           10.616647287671022,
           10.53661724400338,
           10.456587200335724,
           10.376557156668063,
           10.296527113000408,
           10.216497069332755,
           10.136467025665096,
           10.056436981997443,
           9.976406938329795,
           9.896376894662135,
           9.816346850994472,
           9.736316807326828,
           9.854711609457702,
           9.997909517313474,
           10.141107425169237,
           10.284305333024998,
           10.427503240880775,
           10.570701148736521,
           10.713899056592297,
           10.857096964448074,
           11.000294872303847,
           11.143492780159596,
           11.286690688015373,
           11.429888595871148,
           11.573086503726898,
           11.716284411582674,
           11.859482319438447,
           12.002680227294194,
           12.145878135149973,
           12.289076043005748,
           12.432273950861521,
           12.57547185871727,
           12.718669766573045,
           12.86186767442882,
           13.005065582284569,
           13.148263490140344,
           13.291461397996121,
           13.434659305851872,
           13.577857213707645,
           13.72105512156342,
           13.864253029419169,
           14.007450937274944,
           14.15064884513072,
           14.293846752986495,
           14.437044660842242,
           14.58024256869802,
           14.723440476553794,
           14.483325467136392,
           14.189725021945378,
           13.896124576754376,
           13.602524131563424,
           13.308923686372431,
           13.015323241181429,
           12.723616316311336,
           12.433352073288292,
           12.143087830265188,
           11.852823587242082,
           11.562559344219029,
           11.274831151143292,
           10.98893454990285,
           10.703037948662459,
           10.41714134742201,
           10.134387053943481,
           9.854307969272813,
           9.574228884602089,
           9.295713278064596,
           9.02345158240904,
           8.751189886753524,
           8.481990225063008,
           8.217527147241125,
           7.953064069419292,
           7.69653103216036,
           7.439997995198801,
           7.191938593919609,
           6.945841620196655,
           6.708369727441477,
           6.476697801515957,
           6.251056356033139,
           6.033088720501405,
           5.823563183536779,
           5.624384596485437,
           5.437966085312247,
           5.265071388262671,
           5.10723133817319,
           4.961927987974793,
           4.8306809099965635,
           4.714798984001945,
           4.6156097350375065,
           4.53158283444689,
           4.455673632867041,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           65.25854498007067,
           65.3090528134751,
           65.35956064687954,
           65.410068480284,
           65.46057631368843,
           65.51108414709289,
           65.56159198049733,
           65.61209981390176,
           65.66260764730622,
           65.71311548071066,
           65.76362331411511,
           65.81413114751953,
           65.86463898092398,
           65.91514681432844,
           65.96565464773288,
           66.01616248113731,
           66.06667031454175,
           66.1171781479462,
           66.16768598135064,
           66.2181938147551,
           66.26870164815954,
           66.31920948156397,
           66.36971731496841,
           66.42022514837288,
           66.4707329817773,
           66.52124081518176,
           66.57174864858621,
           66.62225648199063,
           66.67276431539509,
           66.72327214879952,
           66.77377998220396,
           66.82428781560841,
           66.87479564901285,
           66.92530348241729,
           66.97581131582174,
           67.02631914922618,
           67.07682698263062,
           67.12733481603507,
           67.17784264943953,
           67.22835048284395,
           67.2788583162484,
           67.32936614965284,
           67.37987398305728,
           67.43038181646173,
           67.48088964986617,
           67.53152265521587,
           67.58228083316811,
           67.63303901112037,
           67.68379718907262,
           67.73455536702488,
           67.78531354497713,
           67.83607172292938,
           67.88682990088162,
           67.93758807883388,
           67.98834625678613,
           68.03910443473839,
           68.08986261269064,
           68.1406207906429,
           68.19137896859515,
           68.2421371465474,
           68.29289532449965,
           68.3436535024519,
           68.39441168040415,
           68.44516985835641,
           68.49592803630865,
           68.54668621426092,
           68.59744439221316,
           68.64820257016541,
           68.69896074811766,
           68.74971892606992,
           68.80047710402216,
           68.85123528197443,
           68.90199345992667,
           68.95275163787893,
           69.00350981583118,
           69.05426799378343,
           69.10502617173569,
           69.15578434968793,
           69.20654252764018,
           69.25730070559244,
           69.30805888354469,
           69.35881706149695,
           69.4095752394492,
           69.46033341740146,
           69.50024427030353,
           69.53798565819557,
           69.5757270460876,
           69.61346843397965,
           69.65120982187167,
           69.68895120976372,
           69.72669259765576,
           69.7644339855478,
           69.80217537343982,
           69.83991676133186,
           69.8776581492239,
           69.91539953711595,
           69.95314092500799,
           69.99088231290003,
           70.02862370079207,
           70.06636508868411,
           70.10410647657613,
           70.14184786446818,
           70.17958925236022,
           70.21733064025226,
           70.2550720281443,
           70.29281341603634,
           70.33055480392838,
           70.3682961918204,
           70.40603757971245,
           70.44377896760449,
           70.48152035549653,
           70.51926174338855,
           70.5570031312806,
           70.59474451917264,
           70.63248590706468,
           70.67022729495672,
           70.70796868284874,
           70.74571007074078,
           70.78345145863283,
           70.82119284652487,
           70.8589342344169,
           70.89667562230895,
           70.93410813900054,
           70.96999631428763,
           71.00588448957471,
           71.0417726648618,
           71.07766084014888,
           71.11354901543598,
           71.14943719072305,
           71.18532536601013,
           71.22121354129723,
           71.25710171658432,
           71.2929898918714,
           71.32887806715847,
           71.36476624244555,
           71.40065441773264,
           71.43654259301972,
           71.47243076830681,
           71.50831894359389,
           71.54420711888098,
           71.58009529416806,
           71.61598346945514,
           71.65187164474223,
           71.68775982002931,
           71.7236479953164,
           71.75953617060348,
           71.79542434589058,
           71.83131252117765,
           71.86720069646474,
           71.90308887175183,
           71.9389770470389,
           71.97486522232599,
           72.01075339761307,
           72.04664157290016,
           72.08252974818724,
           72.11841792347431,
           72.15430609876141,
           72.19019427404848,
           72.22608244933558,
           72.26197062462265,
           72.29785879990973,
           72.33374697519682,
           72.3696351504839,
           72.405523325771,
           72.44141150105808,
           72.47729967634515,
           72.51318785163224,
           72.50507200298074,
           72.4749541423599,
           72.44483628173907,
           72.41471842111824,
           72.38460056049743,
           72.3544826998766,
           72.32436483925576,
           72.29424697863493,
           72.26412911801411,
           72.23401125739329,
           72.20389339677246,
           72.17377553615162,
           72.14365767553082,
           72.11353981490998,
           72.08342195428915,
           72.05330409366832,
           72.0231862330475,
           71.99306837242668,
           71.96295051180584,
           71.93283265118501,
           71.90271479056419,
           71.87259692994337,
           71.84247906932254,
           71.8123612087017,
           71.78224334808087,
           71.75212548746006,
           71.72200762683923,
           71.6918897662184,
           71.66177190559756,
           71.63165404497676,
           71.60153618435592,
           71.57141832373509,
           71.54130046311427,
           71.51118260249343,
           71.48106474187261,
           71.45094688125178,
           71.42082902063095,
           71.39071116001013,
           71.3605932993893,
           71.33047543876847,
           71.30035757814764,
           71.2702397175268,
           71.24012185690599,
           71.21000399628517,
           71.17988613566433,
           71.14976827504351,
           71.1196504144227,
           71.08953255380186,
           71.05941469318103,
           71.02929683256019,
           70.99917897193937,
           70.96906111131855,
           70.92974431697104,
           70.87356294195591,
           70.8173815669408,
           70.76120019192567,
           70.70501881691055,
           70.64883744189544,
           70.59265606688031,
           70.5364746918652,
           70.48029331685008,
           70.42411194183495,
           70.36793056681984,
           70.31174919180472,
           70.2555678167896,
           70.19938644177448,
           70.14320506675935,
           70.08702369174422,
           70.0308423167291,
           69.97466094171399,
           69.91847956669888,
           69.86229819168375,
           69.80611681666863,
           69.74993544165352,
           69.69375406663839,
           69.63757269162328,
           69.58139131660815,
           69.52520994159303,
           69.4690285665779,
           69.41284719156279,
           69.35666581654768,
           69.30048444153255,
           69.24430306651743,
           68.89744466440206,
           68.25990923518644,
           67.62237380597088,
           66.9848383767553,
           66.34730294753969,
           65.70976751832413,
           65.07223208910857,
           64.43469665989295,
           63.79716123067732,
           63.159625801461814,
           62.5220903722462,
           61.88455494303057,
           61.24701951381502,
           60.60948408459945,
           59.97194865538383,
           59.334413226168266,
           58.696877796952705,
           58.059342367737074,
           57.42180693852152,
           56.78427150930596,
           56.146736080090335,
           55.50920065087471,
           54.87166522165921,
           54.23412979244359,
           53.59659436322796,
           52.959058934012404,
           52.321523504796836,
           51.68398807558122,
           51.04645264636565,
           50.40891721715009,
           49.77138178793447,
           49.13384635871884,
           48.49631092950334,
           47.85591202934266,
           47.20895096188003,
           46.56198989441745,
           45.915028826954874,
           45.26806775949223,
           44.62110669202965,
           43.97414562456708,
           43.327184557104445,
           42.68022348964186,
           42.033262422179284,
           41.38630135471665,
           40.739340287254,
           40.09237921979149,
           39.445418152328855,
           38.79845708486621,
           38.15149601740364,
           37.50453494994106,
           36.85757388247842,
           36.21061281501584,
           35.56365174755326,
           34.916690680090625,
           34.269729612627984,
           33.62276854516547,
           32.97580747770283,
           32.328846410240196,
           31.681885342777615,
           31.034924275315042,
           30.3879632078524,
           29.741002140389824,
           29.094041072927247,
           28.44708000546461,
           27.80011893800203,
           27.153157870539452,
           26.506196803076815,
           25.859235735614178,
           25.212274668151657,
           24.565313600689016,
           23.918352533226383,
           23.271391465763806,
           22.624430398301225,
           21.977469330838588,
           21.33050826337601,
           20.683547195913434,
           20.036586128450793,
           19.389625060988216,
           18.74266399352564,
           18.095702926062998,
           17.448741858600364,
           16.801780791137787,
           16.154819723675207,
           15.696431063476593,
           15.615187217805886,
           15.53394337213518,
           15.452699526464466,
           15.371455680793765,
           15.290211835123058,
           15.208967989452347,
           15.127724143781636,
           15.046480298110936,
           14.965236452440221,
           14.883992606769514,
           14.802748761098806,
           14.7215049154281,
           14.64026106975739,
           14.559017224086682,
           14.477773378415977,
           14.39652953274527,
           14.315285687074562,
           14.234041841403855,
           14.152797995733142,
           14.071554150062433,
           13.990310304391723,
           13.90906645872102,
           13.82782261305031,
           13.746578767379605,
           13.665334921708897,
           13.584091076038188,
           13.50284723036748,
           13.421603384696775,
           13.340359539026066,
           13.259115693355353,
           13.177871847684653,
           13.09662800201394,
           13.015384156343229,
           12.934140310672523,
           12.853935353214304,
           12.773905309546645,
           12.693875265878992,
           12.61384522221134,
           12.533815178543678,
           12.453785134876025,
           12.373755091208377,
           12.293725047540713,
           12.213695003873053,
           12.133664960205405,
           12.053634916537751,
           11.973604872870094,
           11.893574829202441,
           11.813544785534782,
           11.733514741867127,
           11.65348469819948,
           11.573454654531826,
           11.493424610864167,
           11.413394567196507,
           11.33336452352886,
           11.2533344798612,
           11.17330443619354,
           11.093274392525887,
           11.013244348858237,
           10.933214305190575,
           10.853184261522923,
           10.773154217855271,
           10.693124174187611,
           10.613094130519958,
           10.533064086852304,
           10.601852677533607,
           10.745050585389386,
           10.888248493245134,
           11.031446401100908,
           11.174644308956685,
           11.317842216812448,
           11.461040124668209,
           11.60423803252398,
           11.747435940379743,
           11.890633848235506,
           12.03383175609128,
           12.17702966394706,
           12.320227571802809,
           12.463425479658586,
           12.606623387514357,
           12.749821295370118,
           12.893019203225881,
           13.036217111081656,
           13.179415018937403,
           13.32261292679318,
           13.465810834648956,
           13.609008742504729,
           13.752206650360478,
           13.895404558216255,
           14.038602466072032,
           14.18180037392778,
           14.324998281783555,
           14.46819618963933,
           14.611394097495076,
           14.754592005350855,
           14.89778991320663,
           15.040987821062405,
           15.184185728918152,
           15.327383636773927,
           15.470581544629702,
           15.613779452485453,
           15.756977360341228,
           15.900175268197003,
           16.043373176052754,
           16.186571083908525,
           16.057884214732045,
           15.764283769541105,
           15.470683324350102,
           15.177082879159101,
           14.883482433968096,
           14.589881988777144,
           14.296281543586144,
           14.004033612983765,
           13.713769369960701,
           13.423505126937616,
           13.133240883914503,
           12.842976640891457,
           12.552712397868355,
           12.265512548539402,
           11.979615947298942,
           11.693719346058561,
           11.40782274481812,
           11.12239324292415,
           10.842314158253465,
           10.562235073582741,
           10.282155988912018,
           10.004109425762966,
           9.731847730107402,
           9.459586034451839,
           9.187707093010378,
           8.923244015188484,
           8.658780937366599,
           8.396795996973449,
           8.140262960011942,
           7.883729923050389,
           7.635814142755616,
           7.388329224908754,
           7.149816374158768,
           6.9132628092978035,
           6.686182524119417,
           6.463538660797099,
           6.246110702890531,
           6.0374332305292056,
           5.83811216018254,
           5.649625021747661,
           5.473014231932607,
           5.308336036744581,
           5.155320204884144,
           5.015081158646151,
           4.886205837813279,
           4.771872013420895,
           4.672063265821567,
           4.584954451393704,
           4.5113469929549925,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           65.3849305455734,
           65.43543837897784,
           65.48594621238229,
           65.53645404578673,
           65.58696187919116,
           65.63746971259562,
           65.68797754600006,
           65.7384853794045,
           65.78899321280895,
           65.8395010462134,
           65.89000887961784,
           65.94051671302228,
           65.99102454642671,
           66.04153237983115,
           66.0920402132356,
           66.14254804664006,
           66.19305588004448,
           66.24356371344894,
           66.29407154685339,
           66.34457938025781,
           66.39508721366226,
           66.44559504706672,
           66.49610288047114,
           66.5466107138756,
           66.59711854728003,
           66.64762638068447,
           66.69813421408892,
           66.74864204749336,
           66.79914988089782,
           66.84965771430225,
           66.9001655477067,
           66.95067338111114,
           67.00118121451558,
           67.05168904792004,
           67.10219688132446,
           67.15270471472891,
           67.20321254813337,
           67.25372038153779,
           67.30422821494226,
           67.35473604834668,
           67.40524388175113,
           67.45575171515557,
           67.50625954856002,
           67.55676738196446,
           67.6072752153689,
           67.65778304877335,
           67.70829088217779,
           67.75879871558223,
           67.80930654898668,
           67.85981438239112,
           67.91032221579556,
           67.96083004920001,
           68.01133788260445,
           68.06184571600889,
           68.11235354941334,
           68.16286138281778,
           68.21336921622222,
           68.26387704962667,
           68.31438488303112,
           68.36489271643555,
           68.41540054984,
           68.46590838324445,
           68.51666656082674,
           68.56742473877898,
           68.61818291673124,
           68.66894109468349,
           68.71969927263574,
           68.770457450588,
           68.82121562854024,
           68.87197380649249,
           68.92273198444475,
           68.973490162397,
           69.02424834034925,
           69.0750065183015,
           69.12576469625375,
           69.17652287420601,
           69.22728105215826,
           69.27803923011052,
           69.32879740806277,
           69.37955558601502,
           69.43031376396728,
           69.48107194191952,
           69.53183011987177,
           69.58258829782403,
           69.6224991507261,
           69.66024053861814,
           69.69798192651018,
           69.73572331440222,
           69.77346470229426,
           69.81120609018629,
           69.84894747807833,
           69.88668886597037,
           69.9244302538624,
           69.96217164175445,
           69.99991302964649,
           70.03765441753852,
           70.07539580543056,
           70.1131371933226,
           70.15087858121464,
           70.18861996910668,
           70.22636135699872,
           70.26410274489076,
           70.3018441327828,
           70.33958552067485,
           70.37732690856687,
           70.41506829645891,
           70.45157420654226,
           70.48746238182933,
           70.52335055711643,
           70.5592387324035,
           70.59512690769058,
           70.63101508297767,
           70.66690325826475,
           70.70279143355185,
           70.73867960883892,
           70.774567784126,
           70.81045595941309,
           70.84634413470017,
           70.88223230998726,
           70.91812048527434,
           70.95400866056143,
           70.98989683584851,
           71.0257850111356,
           71.0616731864227,
           71.09756136170978,
           71.13344953699686,
           71.16933771228395,
           71.20522588757103,
           71.2411140628581,
           71.2770022381452,
           71.31289041343227,
           71.34877858871937,
           71.38466676400644,
           71.42055493929352,
           71.45644311458061,
           71.49233128986769,
           71.52821946515478,
           71.56410764044186,
           71.59999581572895,
           71.63588399101603,
           71.67177216630311,
           71.70766034159021,
           71.74354851687728,
           71.77943669216437,
           71.81532486745145,
           71.85121304273854,
           71.88710121802562,
           71.92298939331272,
           71.9588775685998,
           71.99476574388689,
           72.03065391917397,
           72.06654209446106,
           72.10243026974813,
           72.1383184450352,
           72.1742066203223,
           72.21009479560936,
           72.24598297089646,
           72.28187114618355,
           72.31775932147062,
           72.35364749675772,
           72.38953567204479,
           72.42542384733188,
           72.46131202261897,
           72.49720019790604,
           72.53308837319314,
           72.56897654848021,
           72.6048647237673,
           72.5967488751158,
           72.56663101449496,
           72.53651315387413,
           72.5063952932533,
           72.47627743263249,
           72.44615957201165,
           72.41604171139082,
           72.38592385076998,
           72.35580599014916,
           72.32568812952834,
           72.29557026890751,
           72.26545240828669,
           72.23533454766587,
           72.20521668704504,
           72.1750988264242,
           72.14498096580337,
           72.11486310518255,
           72.08474524456173,
           72.0546273839409,
           72.02450952332006,
           71.99439166269924,
           71.96427380207841,
           71.93415594145759,
           71.90403808083676,
           71.87392022021594,
           71.8438023595951,
           71.81368449897428,
           71.78356663835346,
           71.75344877773263,
           71.72333091711181,
           71.67558180346549,
           71.61940042845036,
           71.56321905343525,
           71.50703767842013,
           71.450856303405,
           71.39467492838989,
           71.33849355337478,
           71.28231217835965,
           71.22613080334453,
           71.1699494283294,
           71.11376805331429,
           71.05758667829917,
           71.00140530328405,
           70.94522392826893,
           70.88904255325382,
           70.83286117823869,
           70.77667980322357,
           70.72049842820844,
           70.66431705319333,
           70.6081356781782,
           70.55195430316309,
           70.49577292814797,
           70.43959155313286,
           70.38341017811773,
           70.32722880310261,
           70.27104742808748,
           70.21486605307237,
           70.15868467805724,
           70.10250330304214,
           70.046321928027,
           69.99014055301188,
           69.93395917799677,
           69.87777780298165,
           69.82159642796653,
           69.76541505295141,
           69.70923367793628,
           69.65305230292117,
           69.59687092790604,
           69.54068955289092,
           69.48450817787581,
           69.42832680286068,
           69.37214542784557,
           69.31596405283045,
           69.25978267781532,
           69.20360130280021,
           69.14741992778508,
           69.09123855276997,
           69.03505717775484,
           68.97887580273972,
           68.92269442772461,
           68.86651305270948,
           68.81033167769435,
           68.75415030267924,
           68.40729190056388,
           67.76975647134826,
           67.13222104213268,
           66.49468561291712,
           65.8571501837015,
           65.21961475448593,
           64.58207932527039,
           63.94454389605475,
           63.307008466839136,
           62.66947303762363,
           62.031937608408015,
           61.39440217919239,
           60.75686674997682,
           60.11933132076127,
           59.48179589154564,
           58.844260462330084,
           58.206725033114516,
           57.56918960389889,
           56.93165417468333,
           56.29411874546776,
           55.65658331625215,
           55.01904788703652,
           54.38151245782102,
           53.7439770286054,
           53.10644159938977,
           52.46890617017421,
           51.83137074095865,
           51.19383531174303,
           50.55629988252746,
           49.918764453311894,
           49.28122902409628,
           48.64369359488066,
           48.006158165665155,
           47.36862273644953,
           46.73108730723391,
           46.093551878018346,
           45.456016448802785,
           44.81848101958716,
           44.1809455903716,
           43.54341016115603,
           42.905874731940415,
           42.268339302724854,
           41.63080387350928,
           40.99326844429366,
           40.355733015078044,
           39.71819758586254,
           39.08066215664692,
           38.44312672743129,
           37.805591298215745,
           37.16805586900017,
           36.530520439784546,
           35.89298501056899,
           35.255449581353425,
           34.6179141521378,
           33.980378722922175,
           33.34284329370668,
           32.70530786449105,
           32.06508793157204,
           31.41812686410946,
           30.771165796646887,
           30.124204729184243,
           29.47724366172167,
           28.830282594259092,
           28.18332152679645,
           27.53636045933387,
           26.889399391871297,
           26.242438324408656,
           25.595477256946022,
           24.948516189483502,
           24.301555122020865,
           23.654594054558228,
           23.007632987095647,
           22.36067191963307,
           21.71371085217043,
           21.066749784707856,
           20.419788717245275,
           19.772827649782638,
           19.12586658232006,
           18.478905514857484,
           17.831944447394847,
           17.184983379932206,
           16.53802231246963,
           15.891061245007052,
           15.432672584808437,
           15.35142873913773,
           15.270184893467025,
           15.18894104779631,
           15.10769720212561,
           15.026453356454903,
           14.945209510784192,
           14.863965665113477,
           14.782721819442777,
           14.701477973772066,
           14.620234128101359,
           14.538990282430651,
           14.457746436759944,
           14.376502591089233,
           14.295258745418527,
           14.214014899747822,
           14.132771054077114,
           14.051527208406407,
           13.970802807410415,
           13.890772763742756,
           13.810742720075094,
           13.73071267640745,
           13.650682632739795,
           13.570652589072136,
           13.49062254540448,
           13.410592501736831,
           13.330562458069167,
           13.250532414401517,
           13.170502370733864,
           13.090472327066205,
           13.010442283398547,
           12.930412239730899,
           12.850382196063238,
           12.770352152395578,
           12.690322108727926,
           12.610292065060277,
           12.530262021392616,
           12.450231977724963,
           12.370201934057311,
           12.29017189038965,
           12.210141846721996,
           12.130111803054348,
           12.050081759386684,
           11.970051715719023,
           11.890021672051375,
           11.809991628383722,
           11.729961584716065,
           11.649931541048414,
           11.569901497380753,
           11.4898714537131,
           11.40984141004545,
           11.329811366377797,
           11.348993745609421,
           11.492191653465195,
           11.635389561320945,
           11.778587469176719,
           11.9217853770325,
           12.06498328488826,
           12.208181192744025,
           12.351379100599797,
           12.494577008455558,
           12.63777491631132,
           12.780972824167094,
           12.924170732022857,
           13.067368639878618,
           13.210566547734395,
           13.353764455590172,
           13.49696236344592,
           13.640160271301696,
           13.78335817915747,
           13.926556087013232,
           14.069753994868995,
           14.212951902724766,
           14.35614981058053,
           14.499347718436288,
           14.642545626292065,
           14.785743534147846,
           14.928941442003596,
           15.07213934985937,
           15.215337257715142,
           15.358535165570904,
           15.501733073426667,
           15.64493098128244,
           15.78812888913819,
           15.931326796993964,
           16.07452470484974,
           16.217722612705515,
           16.360920520561262,
           16.50411842841704,
           16.647316336272816,
           16.790514244128566,
           16.93371215198434,
           17.076910059840113,
           17.220107967695863,
           17.363305875551642,
           17.506503783407414,
           17.64970169126319,
           17.632442962327783,
           17.3388425171368,
           17.045242071945797,
           16.751641626754843,
           16.458041181563832,
           16.16444073637285,
           15.870840291181885,
           15.577239845990896,
           15.284450909656222,
           14.99418666663316,
           14.703922423610054,
           14.41365818058696,
           14.123393937563845,
           13.833129694540792,
           13.542865451517699,
           13.256193945935529,
           12.970297344695128,
           12.684400743454697,
           12.398504142214248,
           12.112607540973855,
           11.830320347234146,
           11.550241262563437,
           11.270162177892706,
           10.99008309322202,
           10.712505573461296,
           10.440243877805734,
           10.167982182150226,
           9.895720486494655,
           9.628960883135836,
           9.364497805314002,
           9.100034727492103,
           8.840527924825066,
           8.583994887863552,
           8.327461850901994,
           8.079689691591689,
           7.832204773744788,
           7.59126302087609,
           7.353791128120907,
           7.122747531901241,
           6.895667246722854,
           6.676020965561079,
           6.45998074988297,
           6.251303277521686,
           6.051839723879656,
           5.861283958183088,
           5.681182252203337,
           5.512000524454842,
           5.353766660591681,
           5.206252080994896,
           5.069041701923794,
           4.941730765629977,
           4.828945042839848,
           4.72851679660565,
           4.63900342399873,
           4.563096438703814,
           4.4845732285115885,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           65.51131611107613,
           65.56182394448058,
           65.612331777885,
           65.66283961128946,
           65.71334744469391,
           65.76385527809835,
           65.81436311150279,
           65.86487094490724,
           65.91537877831169,
           65.96588661171612,
           66.01639444512057,
           66.066902278525,
           66.11741011192944,
           66.1679179453339,
           66.21842577873835,
           66.26893361214279,
           66.31944144554723,
           66.36994927895167,
           66.42045711235612,
           66.47096494576056,
           66.52147277916501,
           66.57198061256945,
           66.62248844597389,
           66.67299627937834,
           66.72350411278276,
           66.77401194618722,
           66.82451977959167,
           66.87502761299609,
           66.92553544640054,
           66.976043279805,
           67.02655111320944,
           67.07705894661387,
           67.12756678001833,
           67.17807461342278,
           67.2285824468272,
           67.27909028023166,
           67.3295981136361,
           67.38010594704053,
           67.43061378044499,
           67.48112161384942,
           67.53162944725386,
           67.58213728065832,
           67.63264511406275,
           67.68315294746719,
           67.73366078087165,
           67.78416861427608,
           67.83467644768052,
           67.88518428108497,
           67.93569211448941,
           67.98619994789385,
           68.0367077812983,
           68.08721561470274,
           68.13772344810718,
           68.18823128151163,
           68.23873911491607,
           68.28924694832051,
           68.33975478172496,
           68.3902626151294,
           68.44077044853385,
           68.49127828193829,
           68.54178611534275,
           68.59229394874718,
           68.64280178215162,
           68.69330961555606,
           68.74381744896051,
           68.79432528236495,
           68.84483311576939,
           68.89534094917383,
           68.94584878257828,
           68.99635661598272,
           69.04686444938717,
           69.09737228279161,
           69.14788011619606,
           69.19838794960049,
           69.24889578300494,
           69.29940361640938,
           69.34991144981383,
           69.40041928321827,
           69.45105228848534,
           69.5018104664376,
           69.55256864438986,
           69.60332682234211,
           69.65408500029436,
           69.70484317824662,
           69.74475403114869,
           69.78249541904073,
           69.82023680693277,
           69.85797819482481,
           69.89571958271685,
           69.93315209879688,
           69.96904027408395,
           70.00492844937105,
           70.04081662465812,
           70.07670479994522,
           70.11259297523229,
           70.14848115051939,
           70.18436932580647,
           70.22025750109356,
           70.25614567638064,
           70.29203385166772,
           70.32792202695481,
           70.3638102022419,
           70.39969837752898,
           70.43558655281606,
           70.47147472810315,
           70.50736290339023,
           70.54325107867732,
           70.5791392539644,
           70.61502742925148,
           70.65091560453857,
           70.68680377982565,
           70.72269195511274,
           70.75858013039982,
           70.7944683056869,
           70.83035648097399,
           70.86624465626107,
           70.90213283154816,
           70.93802100683524,
           70.97390918212233,
           71.00979735740941,
           71.0456855326965,
           71.08157370798358,
           71.11746188327065,
           71.15335005855775,
           71.18923823384483,
           71.22512640913192,
           71.261014584419,
           71.29690275970609,
           71.33279093499317,
           71.36867911028025,
           71.40456728556734,
           71.44045546085442,
           71.47634363614151,
           71.51223181142858,
           71.54811998671568,
           71.58400816200275,
           71.61989633728983,
           71.65578451257691,
           71.691672687864,
           71.72756086315108,
           71.76344903843818,
           71.79933721372527,
           71.83522538901234,
           71.87111356429942,
           71.9070017395865,
           71.94288991487359,
           71.97877809016069,
           72.01466626544777,
           72.05055444073484,
           72.08644261602194,
           72.12233079130903,
           72.15821896659611,
           72.19410714188318,
           72.22999531717026,
           72.26588349245735,
           72.30177166774443,
           72.33765984303152,
           72.3735480183186,
           72.40943619360569,
           72.44532436889277,
           72.48121254417985,
           72.51710071946694,
           72.55298889475402,
           72.58887707004111,
           72.62476524532819,
           72.66065342061528,
           72.69654159590236,
           72.68842574725085,
           72.65830788663001,
           72.62819002600918,
           72.59807216538836,
           72.56795430476754,
           72.5378364441467,
           72.50771858352589,
           72.47760066497507,
           72.42141928995996,
           72.36523791494483,
           72.3090565399297,
           72.2528751649146,
           72.19669378989947,
           72.14051241488436,
           72.08433103986923,
           72.0281496648541,
           71.971968289839,
           71.91578691482387,
           71.85960553980875,
           71.80342416479363,
           71.7472427897785,
           71.6910614147634,
           71.63488003974827,
           71.57869866473314,
           71.52251728971802,
           71.46633591470291,
           71.4101545396878,
           71.35397316467267,
           71.29779178965754,
           71.24161041464242,
           71.18542903962731,
           71.1292476646122,
           71.07306628959705,
           71.01688491458194,
           70.96070353956682,
           70.90452216455171,
           70.84834078953656,
           70.79215941452146,
           70.73597803950634,
           70.67979666449122,
           70.6236152894761,
           70.56743391446098,
           70.51125253944585,
           70.45507116443073,
           70.39888978941562,
           70.3427084144005,
           70.28652703938539,
           70.23034566437026,
           70.17416428935515,
           70.11798291434002,
           70.06180153932489,
           70.00562016430979,
           69.94943878929466,
           69.89325741427953,
           69.83707603926442,
           69.7808946642493,
           69.72471328923419,
           69.66853191421906,
           69.61235053920393,
           69.55616916418882,
           69.4999877891737,
           69.44380641415859,
           69.38762503914346,
           69.33144366412834,
           69.27526228911321,
           69.2190809140981,
           69.16289953908299,
           69.10671816406786,
           69.05053678905273,
           68.99435541403761,
           68.9381740390225,
           68.88199266400738,
           68.82581128899226,
           68.76962991397714,
           68.71344853896201,
           68.6572671639469,
           68.60108578893177,
           68.54490441391665,
           68.48872303890153,
           68.43254166388643,
           68.37636028887128,
           68.32017891385618,
           68.26399753884105,
           67.9171391367257,
           67.27960370751006,
           66.6420682782945,
           66.00453284907894,
           65.36699741986331,
           64.72946199064776,
           64.09192656143219,
           63.45439113221657,
           62.816855703000954,
           62.17932027378545,
           61.54178484456982,
           60.9042494153542,
           60.26671398613864,
           59.62917855692307,
           58.991643127707455,
           58.35410769849189,
           57.71657226927633,
           57.0790368400607,
           56.44150141084514,
           55.80396598162959,
           55.16643055241395,
           54.52889512319834,
           53.89135969398283,
           53.25382426476722,
           52.61628883555158,
           51.978753406336025,
           51.341217977120465,
           50.70368254790485,
           50.06614711868928,
           49.42861168947371,
           48.791076260258095,
           48.15354083104247,
           47.516005401826966,
           46.87846997261135,
           46.24093454339572,
           45.603399114180164,
           44.965863684964596,
           44.32832825574897,
           43.69079282653341,
           43.05325739731784,
           42.41572196810223,
           41.778186538886665,
           41.1406511096711,
           40.50311568045548,
           39.865580251239855,
           39.228044822024344,
           38.59050939280873,
           37.95297396359311,
           37.31543853437755,
           36.67790310516199,
           36.04036767594636,
           35.402832246730796,
           34.765296817515235,
           34.12776138829962,
           33.490225959084,
           32.85269052986849,
           32.215155100652865,
           31.577619671437244,
           30.94008424222168,
           30.302548813006116,
           29.665013383790495,
           29.027477954574938,
           28.389942525359373,
           27.752407096143752,
           27.114871666928188,
           26.477336237712624,
           25.839800808497003,
           25.20226537928138,
           24.56472995006588,
           23.927194520850257,
           23.289659091634636,
           22.652123662419072,
           22.014588233203504,
           21.377052803987887,
           20.73951737477232,
           20.101981945556762,
           19.46444651634114,
           18.826911087125573,
           18.189375657910006,
           17.55184022869438,
           16.91430479947876,
           16.274263833801474,
           15.627302766338893,
           15.168914106140281,
           15.08767026160652,
           15.00764021793887,
           14.927610174271212,
           14.847580130603552,
           14.767550086935904,
           14.687520043268245,
           14.607489999600586,
           14.527459955932937,
           14.447429912265278,
           14.367399868597618,
           14.287369824929968,
           14.20733978126231,
           14.127309737594652,
           14.047279693927004,
           13.96724965025935,
           13.887219606591689,
           13.807189562924034,
           13.727159519256388,
           13.647129475588727,
           13.567099431921068,
           13.487069388253417,
           13.407039344585765,
           13.327009300918107,
           13.246979257250452,
           13.166949213582804,
           13.086919169915138,
           13.00688912624749,
           12.926859082579835,
           12.846829038912178,
           12.76679899524452,
           12.68676895157687,
           12.60673890790921,
           12.52670886424155,
           12.446678820573897,
           12.366648776906247,
           12.286618733238587,
           12.206588689570935,
           12.126558645903282,
           12.096134813685234,
           12.239332721540993,
           12.382530629396756,
           12.525728537252533,
           12.668926445108307,
           12.812124352964068,
           12.95532226081983,
           13.098520168675604,
           13.241718076531363,
           13.384915984387131,
           13.528113892242907,
           13.671311800098668,
           13.81450970795443,
           13.957707615810206,
           14.100905523665979,
           14.244103431521726,
           14.387301339377503,
           14.530499247233283,
           14.673697155089043,
           14.816895062944806,
           14.960092970800579,
           15.10329087865634,
           15.246488786512103,
           15.389686694367878,
           15.532884602223639,
           15.676082510079402,
           15.819280417935179,
           15.962478325790956,
           16.105676233646705,
           16.24887414150248,
           16.392072049358255,
           16.535269957214016,
           16.678467865069777,
           16.82166577292555,
           16.964863680781313,
           17.108061588637074,
           17.25125949649285,
           17.39445740434863,
           17.537655312204375,
           17.680853220060154,
           17.824051127915926,
           17.967249035771687,
           18.110446943627448,
           18.253644851483223,
           18.396842759338973,
           18.54004066719475,
           18.683238575050524,
           18.8264364829063,
           18.96963439076205,
           19.11283229861782,
           19.207001709923496,
           18.913401264732535,
           18.619800819541553,
           18.326200374350528,
           18.032599929159588,
           17.738999483968584,
           17.44539903877758,
           17.15179859358658,
           16.858198148395616,
           16.56486820632866,
           16.274603963305577,
           15.984339720282511,
           15.694075477259409,
           15.403811234236304,
           15.113546991213259,
           14.823282748190136,
           14.53301850516705,
           14.246875343331707,
           13.960978742091264,
           13.675082140850826,
           13.389185539610367,
           13.103288938370003,
           12.818326536214832,
           12.538247451544109,
           12.258168366873424,
           11.978089282202717,
           11.698010197531993,
           11.420901721159693,
           11.148640025504115,
           10.876378329848567,
           10.604116634192987,
           10.33467775108322,
           10.070214673261333,
           9.805751595439448,
           9.541288517617616,
           9.284259852676673,
           9.027726815715118,
           8.771193778753604,
           8.52356524042776,
           8.276080322580867,
           8.032709667593402,
           7.795237774838224,
           7.559312539683107,
           7.332232254504684,
           7.106470905856777,
           6.888503270325051,
           6.673850796875409,
           6.465173324514124,
           6.265567287576772,
           6.072942894618521,
           5.88947956547997,
           5.717954307920075,
           5.555265172936737,
           5.401855527302645,
           5.257815736822769,
           5.123002245201409,
           4.9982485468442786,
           4.886018072258823,
           4.784970327389717,
           4.69398693852534,
           4.614786691358517,
           4.540246588599528,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           65.62788234757703,
           65.67839018098147,
           65.7288980143859,
           65.77940584779034,
           65.8299136811948,
           65.88042151459925,
           65.93092934800367,
           65.98143718140813,
           66.03194501481258,
           66.08245284821702,
           66.13296068162146,
           66.1834685150259,
           66.23397634843035,
           66.28448418183478,
           66.33499201523924,
           66.38549984864368,
           66.43600768204811,
           66.48651551545257,
           66.537023348857,
           66.58753118226144,
           66.6380390156659,
           66.68854684907033,
           66.73905468247477,
           66.78956251587923,
           66.84007034928366,
           66.8905781826881,
           66.94108601609256,
           66.991593849497,
           67.04210168290143,
           67.09260951630588,
           67.14311734971032,
           67.19362518311476,
           67.24413301651921,
           67.29464084992367,
           67.34514868332809,
           67.39565651673254,
           67.446164350137,
           67.49667218354142,
           67.54718001694587,
           67.59768785035031,
           67.64819568375475,
           67.6987035171592,
           67.74921135056364,
           67.79971918396808,
           67.85022701737253,
           67.90073485077698,
           67.95124268418141,
           68.00175051758586,
           68.0522583509903,
           68.10276618439475,
           68.15327401779919,
           68.20378185120364,
           68.25428968460807,
           68.30479751801252,
           68.35530535141696,
           68.40581318482141,
           68.45632101822585,
           68.5068288516303,
           68.55733668503474,
           68.60784451843918,
           68.65835235184363,
           68.70886018524807,
           68.75936801865251,
           68.80987585205695,
           68.8603836854614,
           68.91089151886584,
           68.96139935227028,
           69.01190718567472,
           69.06241501907917,
           69.1129228524836,
           69.16343068588806,
           69.21393851929251,
           69.26444635269695,
           69.31458703610718,
           69.36454414562854,
           69.4145012551499,
           69.46445836467126,
           69.5144154741926,
           69.56437258371398,
           69.61432969323532,
           69.66428680275668,
           69.71424391227804,
           69.7642010217994,
           69.81415813132074,
           69.85096689959339,
           69.8851459996163,
           69.9193250996392,
           69.95350419966209,
           69.987683299685,
           70.02186239970791,
           70.05604149973081,
           70.0902205997537,
           70.12439969977662,
           70.15857879979953,
           70.19275789982242,
           70.22864607281674,
           70.26453424810383,
           70.30042242339091,
           70.336310598678,
           70.37219877396508,
           70.40808694925218,
           70.44397512453925,
           70.47986329982633,
           70.51575147511342,
           70.55163965040052,
           70.5875278256876,
           70.62341600097469,
           70.65930417626176,
           70.69519235154885,
           70.73108052683592,
           70.76696870212301,
           70.8028568774101,
           70.83874505269718,
           70.87463322798428,
           70.91052140327135,
           70.94640957855843,
           70.98229775384551,
           71.01818592913261,
           71.0540741044197,
           71.08996227970678,
           71.12585045499387,
           71.16173863028095,
           71.19762680556802,
           71.23351498085512,
           71.2694031561422,
           71.30529133142929,
           71.34117950671636,
           71.37706768200344,
           71.41295585729053,
           71.44884403257761,
           71.4847322078647,
           71.5206203831518,
           71.55650855843886,
           71.59239673372595,
           71.62828490901303,
           71.66417308430012,
           71.7000612595872,
           71.7359494348743,
           71.77183761016138,
           71.80772578544847,
           71.84361396073554,
           71.87950213602262,
           71.91539031130971,
           71.95127848659679,
           71.98716666188388,
           72.02305483717096,
           72.05894301245804,
           72.09483118774513,
           72.13071936303221,
           72.1666075383193,
           72.20249571360638,
           72.23838388889345,
           72.27427206418055,
           72.31016023946765,
           72.34604841475472,
           72.38193659004182,
           72.41782476532887,
           72.45371294061596,
           72.48960111590306,
           72.52548929119014,
           72.56137746647723,
           72.59726564176431,
           72.6331538170514,
           72.66904199233848,
           72.70493016762556,
           72.74081834291265,
           72.77670651819973,
           72.7487367492815,
           72.68883800826062,
           72.62893926723974,
           72.56904052621887,
           72.509141785198,
           72.44924304417711,
           72.38934430315624,
           72.32944556213536,
           72.26954682111447,
           72.20964808009359,
           72.14974933907273,
           72.08985059805184,
           72.02995185703097,
           71.97005311601009,
           71.9101543749892,
           71.85025563396833,
           71.79035689294744,
           71.73045815192657,
           71.6705594109057,
           71.61066066988482,
           71.55076192886392,
           71.49086318784306,
           71.43096444682219,
           71.3710657058013,
           71.31116696478043,
           71.25126822375954,
           71.19136948273866,
           71.13147074171778,
           71.07157200069692,
           71.01167325967603,
           70.95177451865514,
           70.89187577763428,
           70.8319770366134,
           70.77207829559251,
           70.71217955457163,
           70.65228081355076,
           70.59238207252989,
           70.53248333150901,
           70.47258459048811,
           70.41268584946724,
           70.35278710844636,
           70.29288836742549,
           70.23298962640462,
           70.17309088538373,
           70.11319214436286,
           70.05329340334197,
           69.9933946623211,
           69.93349592130022,
           69.87359718027933,
           69.81369843925846,
           69.75379969823759,
           69.6939009572167,
           69.63400221619582,
           69.57410347517495,
           69.51420473415406,
           69.45430599313319,
           69.3944072521123,
           69.33450851109143,
           69.27460977007055,
           69.21471102904968,
           69.1548122880288,
           69.09491354700792,
           69.03501480598703,
           68.97511606496616,
           68.91521732394528,
           68.85531858292441,
           68.79541984190352,
           68.73552110088265,
           68.67562235986178,
           68.61572361884089,
           68.55582487782002,
           68.49592613679914,
           68.43602739577825,
           68.37612865475738,
           68.31622991373649,
           68.25633117271562,
           68.19643243169473,
           68.13653369067386,
           68.07663494965298,
           68.01673620863211,
           67.95683746761124,
           67.87829894018978,
           67.78200823322153,
           67.4209391442284,
           66.79509167321037,
           66.1692442021924,
           65.54339673117441,
           64.91445440287762,
           64.27932236002339,
           63.644190317169155,
           63.00905827431486,
           62.373926231460565,
           61.73879418860638,
           61.1036621457521,
           60.4685301028978,
           59.83339806004357,
           59.198266017189326,
           58.56313397433504,
           57.9280019314808,
           57.29286988862657,
           56.657737845772274,
           56.02260580291804,
           55.3874737600638,
           54.752341717209504,
           54.117209674355216,
           53.48207763150104,
           52.84694558864673,
           52.21181354579244,
           51.576681502938214,
           50.941549460083976,
           50.30641741722969,
           49.671285374375444,
           49.03615333152121,
           48.40102128866692,
           47.765889245812616,
           47.13075720295844,
           46.49562516010415,
           45.86049311724986,
           45.22536107439563,
           44.590229031541384,
           43.955096988687096,
           43.31996494583286,
           42.68483290297862,
           42.04970086012433,
           41.41456881727009,
           40.779436774415856,
           40.144304731561554,
           39.50917268870727,
           38.87404064585309,
           38.23890860299879,
           37.6037765601445,
           36.968644517290265,
           36.33351247443603,
           35.69838043158174,
           35.0632483887275,
           34.42811634587327,
           33.79298430301897,
           33.157852260164674,
           32.5227202173105,
           31.887588174456212,
           31.25245613160191,
           30.617324088747683,
           29.982192045893445,
           29.347060003039154,
           28.711927960184905,
           28.076795917330674,
           27.44166387447638,
           26.806531831622145,
           26.171399788767907,
           25.536267745913612,
           24.901135703059325,
           24.266003660205143,
           23.630871617350856,
           22.995739574496554,
           22.360607531642323,
           21.725475488788085,
           21.090343445933794,
           20.455211403079556,
           19.82007936022532,
           19.184947317371027,
           18.54981527451679,
           17.91468323166255,
           17.279551188808263,
           16.644419145953968,
           16.00928710309973,
           15.374155060245494,
           14.92405701712014,
           14.844026973452483,
           14.763996929784833,
           14.683966886117172,
           14.603936842449514,
           14.523906798781866,
           14.443876755114207,
           14.363846711446547,
           14.2838166677789,
           14.20378662411124,
           14.12375658044358,
           14.04372653677593,
           13.963696493108273,
           13.883666449440614,
           13.803636405772965,
           13.723606362105311,
           13.643576318437653,
           13.563546274769998,
           13.483516231102348,
           13.40348618743469,
           13.323456143767029,
           13.24342610009938,
           13.163396056431727,
           13.083366012764067,
           13.003335969096415,
           12.923305925428766,
           12.8432758817611,
           12.986473789616904,
           13.129671697472666,
           13.272869605328445,
           13.416067513184217,
           13.559265421039969,
           13.70246332889574,
           13.845661236751516,
           13.988859144607275,
           14.132057052463038,
           14.275254960318813,
           14.418452868174576,
           14.561650776030337,
           14.704848683886118,
           14.848046591741877,
           14.99124449959764,
           15.134442407453413,
           15.277640315309188,
           15.420838223164951,
           15.564036131020714,
           15.707234038876486,
           15.850431946732247,
           15.993629854588015,
           16.13682776244379,
           16.28002567029955,
           16.423223578155316,
           16.566421486011087,
           16.709619393866863,
           16.85281730172261,
           16.996015209578385,
           17.139213117434167,
           17.282411025289925,
           17.42560893314569,
           17.56880684100146,
           17.712004748857222,
           17.855202656712986,
           17.99840056456876,
           18.141598472424523,
           18.284796380280284,
           18.42799428813606,
           18.571192195991838,
           18.714390103847588,
           18.85758801170336,
           19.000785919559135,
           19.1439838274149,
           19.287181735270657,
           19.430379643126432,
           19.573577550982197,
           19.716775458837954,
           19.85997336669373,
           20.00317127454951,
           20.146369182405262,
           20.289567090261038,
           20.43276499811681,
           20.57596290597257,
           20.71916081382833,
           20.4879600123282,
           20.19435956713726,
           19.900759121946255,
           19.607158676755255,
           19.313558231564247,
           19.019957786373308,
           18.726357341182283,
           18.4327568959913,
           18.139156450800343,
           17.845556005609357,
           17.555021259977984,
           17.264757016954924,
           16.974492773931836,
           16.684228530908733,
           16.393964287885627,
           16.103700044862585,
           15.81343580183946,
           15.523453341968198,
           15.237556740727815,
           14.951660139487357,
           14.665763538246916,
           14.379866937006533,
           14.093970335766095,
           13.808073734525653,
           13.526253640524827,
           13.246174555854084,
           12.966095471183362,
           12.686016386512636,
           12.40593730184197,
           12.129297868857993,
           11.857036173202427,
           11.584774477546906,
           11.312512781891359,
           11.04039461903054,
           10.775931541208692,
           10.511468463386823,
           10.247005385564922,
           9.984524817489753,
           9.727991780528253,
           9.4714587435667,
           9.21492570711068,
           8.967440789263824,
           8.719955871416918,
           8.474156314310655,
           8.236684421555514,
           7.999212528800337,
           7.768797262286531,
           7.541716977108134,
           7.318953210620741,
           7.100985575089007,
           6.8877208438678394,
           6.679043371506555,
           6.479294851273874,
           6.2846018310539336,
           6.10113850191539,
           5.926122328190798,
           5.758929660646984,
           5.600301983010198,
           5.450576174015023,
           5.309783078970382,
           5.177778989014422,
           5.054868159025511,
           4.94309110167777,
           4.841697086618316,
           4.74946231719616,
           4.667241055740488,
           4.595919948687465,
           4.5134728241561195,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           65.73931232202312,
           65.78982015542755,
           65.840327988832,
           65.89083582223644,
           65.94134365564088,
           65.99185148904533,
           66.04235932244977,
           66.09286715585422,
           66.14337498925866,
           66.1938828226631,
           66.24439065606755,
           66.29489848947199,
           66.34540632287644,
           66.3959141562809,
           66.44642198968532,
           66.49692982308977,
           66.54743765649421,
           66.59794548989865,
           66.6484533233031,
           66.69896115670754,
           66.74946899011198,
           66.79997682351643,
           66.85048465692086,
           66.90099249032532,
           66.95150032372975,
           67.0020081571342,
           67.05251599053865,
           67.10302382394309,
           67.15353165734753,
           67.20403949075197,
           67.25454732415642,
           67.30505515756086,
           67.3555629909653,
           67.40607082436975,
           67.45657865777419,
           67.50708649117863,
           67.55759432458308,
           67.60810215798752,
           67.65860999139197,
           67.70911782479641,
           67.75962565820085,
           67.8101334916053,
           67.86064132500974,
           67.91114915841418,
           67.96165699181861,
           68.01216482522307,
           68.0626726586275,
           68.11318049203196,
           68.1636883254364,
           68.21419615884083,
           68.26470399224527,
           68.31521182564973,
           68.36571965905416,
           68.41622749245862,
           68.46673532586306,
           68.5172431592675,
           68.56765920491955,
           68.61761631444091,
           68.66757342396225,
           68.71753053348363,
           68.76748764300497,
           68.81744475252634,
           68.86740186204769,
           68.91735897156904,
           68.9673160810904,
           69.01727319061176,
           69.0672303001331,
           69.11718740965446,
           69.16714451917582,
           69.21710162869718,
           69.26705873821854,
           69.3170158477399,
           69.36697295726124,
           69.4169300667826,
           69.46688717630396,
           69.51684428582531,
           69.56680139534666,
           69.61675850486802,
           69.66671561438937,
           69.71667272391073,
           69.76662983343209,
           69.81658694295345,
           69.8665440524748,
           69.91650116199615,
           69.9533099302688,
           69.9874890302917,
           70.02166813031461,
           70.0558472303375,
           70.09002633036042,
           70.12420543038331,
           70.15838453040622,
           70.19256363042912,
           70.22674273045203,
           70.26092183047493,
           70.29510093049784,
           70.32928003052074,
           70.36345913054365,
           70.39763823056654,
           70.43181733058944,
           70.46599643061235,
           70.50017553063526,
           70.53435463065816,
           70.56853373068105,
           70.60271283070396,
           70.63689193072686,
           70.67107103074977,
           70.70525013077267,
           70.73942923079558,
           70.77360833081849,
           70.80778743084137,
           70.84196653086428,
           70.87700016715834,
           70.91288834244543,
           70.94877651773251,
           70.9846646930196,
           71.02055286830668,
           71.05644104359376,
           71.09232921888085,
           71.12821739416793,
           71.16410556945502,
           71.1999937447421,
           71.23588192002919,
           71.27177009531626,
           71.30765827060335,
           71.34354644589044,
           71.37943462117752,
           71.41532279646461,
           71.45121097175169,
           71.48709914703878,
           71.52298732232586,
           71.55887549761295,
           71.59476367290003,
           71.63065184818711,
           71.6665400234742,
           71.70242819876128,
           71.73831637404837,
           71.77420454933545,
           71.81009272462254,
           71.84598089990962,
           71.8818690751967,
           71.91775725048379,
           71.95364542577087,
           71.98953360105796,
           72.02542177634504,
           72.06130995163213,
           72.09719812691921,
           72.1330863022063,
           72.16897447749338,
           72.20486265278046,
           72.24075082806755,
           72.27663900335463,
           72.31252717864172,
           72.3484153539288,
           72.38430352921588,
           72.42019170450297,
           72.45607987979005,
           72.49196805507714,
           72.52785623036422,
           72.56374440565129,
           72.59963258093839,
           72.63552075622547,
           72.67140893151256,
           72.70729710679964,
           72.74318528208673,
           72.77907345737381,
           72.8149616326609,
           72.85084980794798,
           72.82288003902974,
           72.76298129800887,
           72.703082556988,
           72.6431838159671,
           72.58328507494625,
           72.52338633392536,
           72.46348759290449,
           72.4035888518836,
           72.34369011086272,
           72.28379136984185,
           72.22389262882098,
           72.16399388780007,
           72.1040951467792,
           72.04419640575833,
           71.98429766473745,
           71.92439892371658,
           71.86450018269569,
           71.8046014416748,
           71.74470270065393,
           71.68480395963306,
           71.62490521861218,
           71.5650064775913,
           71.50510773657044,
           71.44520899554955,
           71.38531025452866,
           71.32541151350779,
           71.26551277248691,
           71.20561403146604,
           71.14571529044515,
           71.08581654942428,
           71.02591780840339,
           70.96601906738252,
           70.90612032636164,
           70.84622158534076,
           70.78632284431988,
           70.726424103299,
           70.66652536227812,
           70.60662662125725,
           70.54672788023636,
           70.48682913921549,
           70.4269303981946,
           70.36703165717373,
           70.30713291615285,
           70.24723417513198,
           70.1873354341111,
           70.12743669309022,
           70.06753795206934,
           70.00763921104846,
           69.94774047002758,
           69.8878417290067,
           69.82794298798582,
           69.76804424696495,
           69.70814550594406,
           69.64824676492319,
           69.58834802390231,
           69.52844928288144,
           69.46855054186055,
           69.40865180083968,
           69.3487530598188,
           69.28885431879792,
           69.22895557777704,
           69.16905683675617,
           69.10827049737598,
           69.01197979040771,
           68.91568908343947,
           68.81939837647121,
           68.72310766950295,
           68.6268169625347,
           68.53052625556646,
           68.4342355485982,
           68.33794484162995,
           68.24165413466169,
           68.14536342769344,
           68.04907272072518,
           67.95278201375693,
           67.85649130678868,
           67.76020059982042,
           67.66390989285216,
           67.56761918588391,
           67.47132847891565,
           67.3750377719474,
           67.27874706497914,
           67.1824563580109,
           66.82138726901776,
           66.19553979799971,
           65.56969232698174,
           64.94384485596377,
           64.31799738494573,
           63.69214991392776,
           63.06630244290978,
           62.440454971891754,
           61.81460750087371,
           61.1887600298558,
           60.56291255883776,
           59.93706508781973,
           59.311217616801756,
           58.68537014578378,
           58.059522674765745,
           57.43367520374777,
           56.80782773272979,
           56.18198026171176,
           55.55613279069378,
           54.93028531967581,
           54.30443784865777,
           53.678590377639736,
           53.052742906621816,
           52.42689543560379,
           51.80104796458575,
           51.17520049356778,
           50.549353022549795,
           49.92350555153176,
           49.29765808051379,
           48.67181060949581,
           48.04596313847778,
           47.420115667459754,
           46.794268196441834,
           46.1684207254238,
           45.54257325440576,
           44.916725783387776,
           44.29087831236981,
           43.66503084135178,
           43.0391833703338,
           42.41333589931582,
           41.78748842829778,
           41.16164095727981,
           40.53579348626184,
           39.90066144340753,
           39.265529400553234,
           38.63039735769906,
           37.995265314844765,
           37.36013327199047,
           36.72500122913624,
           36.08986918628201,
           35.454737143427714,
           34.819605100573476,
           34.18447305771924,
           33.54934101486495,
           32.91420897201065,
           32.279076929156474,
           31.643944886302176,
           31.008812843447885,
           30.373680800593647,
           29.738548757739416,
           29.10341671488512,
           28.468284672030883,
           27.83315262917665,
           27.198020586322354,
           26.56288854346812,
           25.92775650061388,
           25.292624457759587,
           24.6574924149053,
           24.022360372051118,
           23.387228329196827,
           22.752096286342532,
           22.116964243488297,
           21.481832200634056,
           20.846700157779768,
           20.211568114925527,
           19.576436072071296,
           18.941304029217,
           18.306171986362767,
           17.67103994350853,
           17.035907900654237,
           16.40077585779994,
           15.765643814945705,
           15.130511772091468,
           14.68041372896611,
           14.600383685298453,
           14.520353641630804,
           14.440323597963145,
           14.360293554295486,
           14.280263510627837,
           14.200233466960178,
           14.120203423292518,
           14.040173379624871,
           13.960143335957211,
           13.880113292289552,
           13.800083248621902,
           13.720053204954244,
           13.640023161286585,
           13.733614857692714,
           13.876812765548477,
           14.020010673404252,
           14.163208581260015,
           14.306406489115776,
           14.449604396971552,
           14.592802304827327,
           14.736000212683088,
           14.87919812053885,
           15.022396028394626,
           15.165593936250389,
           15.308791844106148,
           15.451989751961923,
           15.595187659817688,
           15.738385567673447,
           15.881583475529228,
           16.024781383384997,
           16.167979291240755,
           16.311177199096523,
           16.4543751069523,
           16.59757301480806,
           16.74077092266382,
           16.883968830519596,
           17.027166738375357,
           17.17036464623112,
           17.3135625540869,
           17.45676046194266,
           17.599958369798422,
           17.743156277654197,
           17.886354185509973,
           18.029552093365734,
           18.172750001221498,
           18.315947909077266,
           18.45914581693303,
           18.6023437247888,
           18.74554163264457,
           18.888739540500335,
           19.031937448356093,
           19.17513535621187,
           19.318333264067643,
           19.461531171923394,
           19.60472907977917,
           19.747926987634948,
           19.89112489549071,
           20.034322803346473,
           20.177520711202245,
           20.320718619058006,
           20.46391652691377,
           20.607114434769542,
           20.750312342625303,
           20.893510250481068,
           21.036708158336843,
           21.17990606619262,
           21.32310397404837,
           21.466301881904144,
           21.60949978975992,
           21.75269769761568,
           21.89589560547144,
           22.039093513327213,
           22.182291421182974,
           22.062518759923954,
           21.768918314732954,
           21.475317869541954,
           21.18171742435099,
           20.888116979160007,
           20.594516533969003,
           20.30091608877803,
           20.00731564358704,
           19.713715198396038,
           19.420114753205095,
           19.12651430801409,
           18.835438556650445,
           18.545174313627342,
           18.254910070604275,
           17.96464582758119,
           17.674381584558066,
           17.384117341535024,
           17.09385309851192,
           16.803588855488815,
           16.514134739364373,
           16.228238138123935,
           15.942341536883493,
           15.656444935643052,
           15.370548334402653,
           15.084651733162229,
           14.798755131921789,
           14.514259829505496,
           14.234180744834774,
           13.954101660164065,
           13.674022575493382,
           13.393943490822657,
           13.113864406151915,
           12.837694016556371,
           12.565432320900808,
           12.293170625245246,
           12.020908929589696,
           11.748647233934175,
           11.48164840915604,
           11.217185331334154,
           10.952722253512322,
           10.688259175690435,
           10.42825674534137,
           10.171723708379856,
           9.915190671418301,
           9.658801255946754,
           9.411316338099848,
           9.163831420252992,
           8.916346502406086,
           8.67813106827279,
           8.44065917551766,
           8.205362270068395,
           7.978281984889963,
           7.751201699711565,
           7.531435515384723,
           7.313467879852979,
           7.1015908908603205,
           6.8929134184989955,
           6.693022414971006,
           6.496408527078694,
           6.312797438350816,
           6.134290348461528,
           5.9628943839075035,
           5.802194309128907,
           5.648390849721161,
           5.50213982984287,
           5.363743622248022,
           5.233303916831151,
           5.111487771206726,
           5.000164131096727,
           4.89860599800591,
           4.804937695866968,
           4.720838457947061,
           4.646688415851522,
           4.56914618424406,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           65.8507422964692,
           65.90125012987366,
           65.95175796327808,
           66.00226579668254,
           66.05277363008697,
           66.10328146349143,
           66.15378929689587,
           66.20429713030032,
           66.25480496370476,
           66.3053127971092,
           66.35582063051365,
           66.40632846391809,
           66.45683629732252,
           66.50734413072698,
           66.55785196413142,
           66.60835979753585,
           66.6588676309403,
           66.70937546434476,
           66.75988329774918,
           66.81039113115364,
           66.86089896455807,
           66.91140679796251,
           66.96191463136697,
           67.01242246477142,
           67.06293029817584,
           67.1134381315803,
           67.16394596498475,
           67.21445379838917,
           67.26496163179362,
           67.31546946519808,
           67.3659772986025,
           67.41648513200695,
           67.4669929654114,
           67.51750079881585,
           67.56800863222028,
           67.61851646562474,
           67.66902429902918,
           67.7195321324336,
           67.77003996583807,
           67.82054779924249,
           67.87068848325326,
           67.92064559277462,
           67.97060270229598,
           68.02055981181734,
           68.0705169213387,
           68.12047403086004,
           68.17043114038141,
           68.22038824990275,
           68.27034535942411,
           68.32030246894547,
           68.37025957846683,
           68.42021668798819,
           68.47017379750953,
           68.52013090703089,
           68.57008801655225,
           68.62004512607359,
           68.67000223559496,
           68.71995934511631,
           68.76991645463767,
           68.81987356415904,
           68.86983067368038,
           68.91978778320174,
           68.96974489272309,
           69.01970200224444,
           69.06965911176582,
           69.11961622128716,
           69.16957333080852,
           69.21953044032988,
           69.26948754985123,
           69.31944465937258,
           69.36940176889394,
           69.4193588784153,
           69.46931598793665,
           69.51927309745801,
           69.56923020697937,
           69.61918731650073,
           69.66914442602207,
           69.71910153554343,
           69.76905864506479,
           69.81901575458613,
           69.86897286410749,
           69.91892997362885,
           69.96888708315021,
           70.01884419267157,
           70.0556529609442,
           70.08983206096711,
           70.12401116099002,
           70.15819026101292,
           70.19236936103582,
           70.22654846105873,
           70.26072756108162,
           70.29490666110453,
           70.32908576112743,
           70.36326486115034,
           70.39744396117324,
           70.43162306119615,
           70.46580216121905,
           70.49998126124196,
           70.53416036126485,
           70.56833946128776,
           70.60251856131066,
           70.63669766133357,
           70.67087676135647,
           70.70505586137938,
           70.73923496140227,
           70.77341406142517,
           70.80759316144808,
           70.841772261471,
           70.87595136149389,
           70.91013046151679,
           70.9443095615397,
           70.97848866156261,
           71.0126677615855,
           71.0468468616084,
           71.08102596163131,
           71.11520506165422,
           71.14938416167712,
           71.18356326170002,
           71.21774236172293,
           71.25192146174582,
           71.28610056176872,
           71.32027966179163,
           71.35445876181454,
           71.38863786183744,
           71.42281696186033,
           71.45699606188325,
           71.49117516190616,
           71.52535426192905,
           71.56124243678703,
           71.5971306120741,
           71.6330187873612,
           71.66890696264828,
           71.70479513793536,
           71.74068331322243,
           71.77657148850952,
           71.8124596637966,
           71.84834783908369,
           71.88423601437077,
           71.92012418965786,
           71.95601236494494,
           71.99190054023204,
           72.02778871551911,
           72.0636768908062,
           72.09956506609328,
           72.13545324138038,
           72.17134141666745,
           72.20722959195453,
           72.24311776724161,
           72.2790059425287,
           72.3148941178158,
           72.35078229310287,
           72.38667046838995,
           72.42255864367704,
           72.45844681896412,
           72.4943349942512,
           72.53022316953829,
           72.56611134482539,
           72.60199952011246,
           72.63788769539954,
           72.67377587068663,
           72.70966404597371,
           72.7455522212608,
           72.78144039654788,
           72.81732857183496,
           72.85321674712205,
           72.88910492240913,
           72.92499309769622,
           72.89702332877799,
           72.83712458775712,
           72.77722584673623,
           72.71732710571536,
           72.65742836469448,
           72.5975296236736,
           72.53763088265272,
           72.47773214163185,
           72.41783340061096,
           72.35793465959009,
           72.29803591856921,
           72.23813717754834,
           72.17823843652745,
           72.11833969550658,
           72.0584409544857,
           71.99854221346482,
           71.93864347244394,
           71.87874473142307,
           71.81884599040218,
           71.7589472493813,
           71.69904850836042,
           71.63914976733955,
           71.57925102631867,
           71.51935228529778,
           71.45945354427691,
           71.39955480325602,
           71.33965606223515,
           71.27975732121428,
           71.2198585801934,
           71.15995983917253,
           71.10006109815164,
           71.04016235713077,
           70.9802636161099,
           70.920364875089,
           70.86046613406812,
           70.80056739304725,
           70.74066865202637,
           70.6807699110055,
           70.6208711699846,
           70.56097242896374,
           70.50107368794285,
           70.44117494692198,
           70.3812762059011,
           70.32137746488021,
           70.2419513475939,
           70.14566064062565,
           70.0493699336574,
           69.95307922668914,
           69.85678851972088,
           69.76049781275262,
           69.66420710578436,
           69.56791639881612,
           69.47162569184786,
           69.3753349848796,
           69.27904427791135,
           69.1827535709431,
           69.08646286397484,
           68.9901721570066,
           68.89388145003835,
           68.79759074307009,
           68.70130003610186,
           68.60500932913358,
           68.50871862216533,
           68.41242791519707,
           68.31613720822882,
           68.21984650126056,
           68.12355579429232,
           68.02726508732405,
           67.9309743803558,
           67.83468367338756,
           67.7383929664193,
           67.64210225945104,
           67.54581155248279,
           67.44952084551454,
           67.35323013854628,
           67.25693943157802,
           67.16064872460979,
           67.06435801764152,
           66.96806731067326,
           66.87177660370503,
           66.77548589673677,
           66.6791951897685,
           66.58290448280025,
           66.22183539380711,
           65.59598792278908,
           64.9701404517711,
           64.34429298075312,
           63.71844550973509,
           63.092598038717114,
           62.46675056769914,
           61.8409030966811,
           61.21505562566307,
           60.589208154645156,
           59.96336068362712,
           59.33751321260908,
           58.711665741591105,
           58.08581827057313,
           57.4599707995551,
           56.834123328537125,
           56.20827585751915,
           55.582428386501114,
           54.956580915483144,
           54.33073344446517,
           53.704885973447126,
           53.0790385024291,
           52.45319103141118,
           51.827343560393146,
           51.20149608937511,
           50.575648618357135,
           49.94980114733916,
           49.323953676321125,
           48.69810620530315,
           48.07225873428517,
           47.44641126326714,
           46.820563792249104,
           46.19471632123119,
           45.56886885021315,
           44.943021379195116,
           44.31717390817714,
           43.69132643715916,
           43.06547896614113,
           42.43963149512316,
           41.813784024105175,
           41.18793655308714,
           40.562089082069164,
           39.93624161105119,
           39.310394140033154,
           38.68454666901512,
           38.0586991979972,
           37.43285172697917,
           36.80700425596113,
           36.181156784943155,
           35.55530931392518,
           34.929461842907145,
           34.30361437188917,
           33.6777669008712,
           33.051919429853164,
           32.42607195883513,
           31.80022448781721,
           31.174377016799177,
           30.548529545781143,
           29.922682074763166,
           29.29683460374519,
           28.670987132727156,
           28.045139661709186,
           27.41929219069121,
           26.793444719673168,
           26.16759724865519,
           25.541749777637214,
           24.915902306619188,
           24.290054835601154,
           23.664207364583234,
           23.0383598935652,
           22.412512422547167,
           21.78666495152919,
           21.160817480511213,
           20.53497000949318,
           19.909122538475206,
           19.28327506745723,
           18.657427596439195,
           18.03158012542122,
           17.405732654403238,
           16.779885183385204,
           16.15403771236717,
           15.522000526791675,
           14.886868483937441,
           14.436770440812083,
           14.480755925768523,
           14.623953833624286,
           14.767151741480065,
           14.910349649335828,
           15.05354755719159,
           15.19674546504736,
           15.339943372903136,
           15.483141280758883,
           15.62633918861466,
           15.76953709647044,
           15.912735004326203,
           16.055932912181962,
           16.199130820037738,
           16.342328727893502,
           16.48552663574926,
           16.62872454360504,
           16.771922451460803,
           16.91512035931656,
           17.05831826717234,
           17.201516175028114,
           17.344714082883872,
           17.487911990739637,
           17.631109898595412,
           17.774307806451173,
           17.917505714306934,
           18.06070362216271,
           18.20390153001847,
           18.347099437874235,
           18.490297345730013,
           18.63349525358578,
           18.776693161441536,
           18.919891069297307,
           19.063088977153082,
           19.206286885008847,
           19.349484792864605,
           19.492682700720383,
           19.635880608576144,
           19.779078516431905,
           19.922276424287684,
           20.065474332143445,
           20.20867223999921,
           20.35187014785498,
           20.495068055710757,
           20.63826596356652,
           20.781463871422282,
           20.924661779278054,
           21.067859687133815,
           21.211057594989583,
           21.35425550284536,
           21.49745341070112,
           21.64065131855688,
           21.783849226412656,
           21.927047134268427,
           22.070245042124178,
           22.213442949979953,
           22.356640857835735,
           22.499838765691496,
           22.643036673547257,
           22.78623458140303,
           22.929432489258794,
           23.07263039711455,
           23.21582830497033,
           23.35902621282609,
           23.502224120681852,
           23.645422028537627,
           23.63707750751965,
           23.343477062328713,
           23.049876617137706,
           22.756276171946702,
           22.46267572675573,
           22.169075281564762,
           21.875474836373737,
           21.581874391182765,
           21.28827394599179,
           20.99467350080079,
           20.70107305560979,
           20.407472610418825,
           20.11585585332288,
           19.825591610299796,
           19.535327367276707,
           19.24506312425363,
           18.954798881230545,
           18.66453463820748,
           18.374270395184375,
           18.084006152161272,
           17.79374190913817,
           17.504816136760514,
           17.218919535520055,
           16.93302293427963,
           16.647126333039232,
           16.361229731798808,
           16.07533313055835,
           15.789436529317967,
           15.503539928077528,
           15.22218693381546,
           14.942107849144737,
           14.662028764474051,
           14.381949679803345,
           14.10187059513262,
           13.821791510461935,
           13.54609016425471,
           13.273828468599149,
           13.00156677294364,
           12.729305077288078,
           12.457043381632513,
           12.187365277103439,
           11.922902199281538,
           11.658439121459667,
           11.393976043637766,
           11.129512965815934,
           10.871988673192975,
           10.615455636231422,
           10.358922599269908,
           10.102676804782838,
           9.85519188693592,
           9.607706969089064,
           9.360222051242157,
           9.1195777149901,
           8.882105822234934,
           8.644633929479793,
           8.414846992671828,
           8.187766707493395,
           7.961885455680419,
           7.7439178201486945,
           7.52595018461696,
           7.315460937852759,
           7.106783465491434,
           6.906749978668122,
           6.710136090775857,
           6.524456374786243,
           6.342458368732258,
           6.1710624041782385,
           6.005858796839164,
           5.846837305428699,
           5.69647971643212,
           5.553703485670747,
           5.417704165525638,
           5.28882884464785,
           5.168107383387969,
           5.057237160515697,
           4.955514909393484,
           4.8605092861676145,
           4.7748874305521,
           4.697990548270131,
           4.624819544332,
           4.542372419800655,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           65.9621722709153,
           66.01268010431974,
           66.06318793772418,
           66.11369577112863,
           66.16420360453307,
           66.21471143793752,
           66.26521927134196,
           66.3157271047464,
           66.36623493815085,
           66.41674277155529,
           66.46725060495974,
           66.51775843836418,
           66.56826627176862,
           66.61877410517307,
           66.66928193857751,
           66.71978977198195,
           66.77029760538639,
           66.82080543879084,
           66.87131327219528,
           66.92182110559973,
           66.97232893900417,
           67.02283677240861,
           67.07334460581306,
           67.12376065206563,
           67.17371776158699,
           67.22367487110836,
           67.2736319806297,
           67.32358909015106,
           67.37354619967242,
           67.42350330919378,
           67.47346041871512,
           67.52341752823648,
           67.57337463775784,
           67.6233317472792,
           67.67328885680055,
           67.72324596632191,
           67.77320307584326,
           67.82316018536461,
           67.87311729488597,
           67.92307440440733,
           67.97303151392867,
           68.02298862345003,
           68.07294573297139,
           68.12290284249275,
           68.17285995201411,
           68.22281706153545,
           68.27277417105682,
           68.32273128057817,
           68.37268839009953,
           68.42264549962088,
           68.47260260914223,
           68.5225597186636,
           68.57251682818494,
           68.6224739377063,
           68.67243104722766,
           68.72238815674902,
           68.77234526627038,
           68.82230237579174,
           68.87225948531308,
           68.92221659483445,
           68.97217370435578,
           69.02213081387715,
           69.0720879233985,
           69.12204503291986,
           69.17200214244122,
           69.22195925196257,
           69.27191636148393,
           69.32187347100529,
           69.37183058052665,
           69.42178769004799,
           69.47174479956936,
           69.52170190909072,
           69.57165901861205,
           69.62161612813343,
           69.67157323765477,
           69.72153034717613,
           69.77148745669749,
           69.82144456621884,
           69.8714016757402,
           69.92135878526155,
           69.97131589478292,
           70.02127300430426,
           70.0712301138256,
           70.12118722334698,
           70.15799599161961,
           70.19217509164253,
           70.22635419166542,
           70.26053329168832,
           70.29471239171123,
           70.32889149173413,
           70.36307059175704,
           70.39724969177993,
           70.43142879180284,
           70.46560789182574,
           70.49978699184865,
           70.53396609187155,
           70.56814519189446,
           70.60232429191736,
           70.63650339194027,
           70.67068249196316,
           70.70486159198607,
           70.73904069200898,
           70.77321979203188,
           70.80739889205478,
           70.84157799207767,
           70.87575709210059,
           70.9099361921235,
           70.94411529214639,
           70.9782943921693,
           71.0124734921922,
           71.04665259221511,
           71.08083169223801,
           71.11501079226092,
           71.14918989228381,
           71.18336899230671,
           71.21754809232962,
           71.25172719235252,
           71.28590629237543,
           71.32008539239834,
           71.35426449242124,
           71.38844359244413,
           71.42262269246704,
           71.45680179248996,
           71.49098089251285,
           71.52515999253575,
           71.55933909255866,
           71.59351819258156,
           71.62769729260447,
           71.66187639262736,
           71.69605549265027,
           71.73023459267317,
           71.76441369269608,
           71.79859279271898,
           71.83277189274189,
           71.86695099276479,
           71.9011300927877,
           71.93530919281059,
           71.9694882928335,
           72.00366739285639,
           72.0378464928793,
           72.07202559290221,
           72.1062046929251,
           72.140383792948,
           72.17456289297093,
           72.2095965311286,
           72.2454847064157,
           72.28137288170277,
           72.31726105698986,
           72.35314923227695,
           72.38903740756403,
           72.42492558285112,
           72.4608137581382,
           72.49670193342527,
           72.53259010871237,
           72.56847828399945,
           72.60436645928654,
           72.64025463457362,
           72.6761428098607,
           72.71203098514779,
           72.74791916043486,
           72.78380733572195,
           72.81969551100903,
           72.85558368629611,
           72.8914718615832,
           72.92736003687028,
           72.96324821215737,
           72.99913638744447,
           72.97116661852624,
           72.91126787750537,
           72.85136913648448,
           72.7914703954636,
           72.73157165444272,
           72.67167291342184,
           72.61177417240097,
           72.5518754313801,
           72.49197669035921,
           72.43207794933834,
           72.37217920831745,
           72.31228046729657,
           72.2523817262757,
           72.19248298525481,
           72.13258424423394,
           72.07268550321305,
           72.01278676219218,
           71.9528880211713,
           71.89298928015043,
           71.83309053912954,
           71.77319179810867,
           71.7132930570878,
           71.65339431606691,
           71.59349557504603,
           71.53359683402516,
           71.47192290478007,
           71.37563219781183,
           71.27934149084356,
           71.18305078387532,
           71.08676007690705,
           70.99046936993881,
           70.89417866297055,
           70.7978879560023,
           70.70159724903405,
           70.60530654206579,
           70.50901583509753,
           70.41272512812928,
           70.31643442116103,
           70.22014371419277,
           70.12385300722451,
           70.02756230025626,
           69.93127159328802,
           69.83498088631976,
           69.73869017935151,
           69.64239947238326,
           69.546108765415,
           69.44981805844675,
           69.35352735147849,
           69.25723664451023,
           69.16094593754198,
           69.06465523057372,
           68.96836452360547,
           68.87207381663723,
           68.77578310966896,
           68.67949240270072,
           68.58320169573247,
           68.48691098876421,
           68.39062028179596,
           68.2943295748277,
           68.19803886785944,
           68.10174816089119,
           68.00545745392293,
           67.9091667469547,
           67.81287603998643,
           67.71658533301817,
           67.62029462604993,
           67.52400391908168,
           67.42771321211342,
           67.33142250514517,
           67.23513179817692,
           67.13884109120866,
           67.0425503842404,
           66.94625967727214,
           66.84996897030389,
           66.75367826333564,
           66.65738755636738,
           66.56109684939912,
           66.46480614243087,
           66.36851543546263,
           66.27222472849436,
           66.1759340215261,
           66.07964331455786,
           65.98335260758961,
           65.62228351859646,
           64.99643604757843,
           64.37058857656046,
           63.74474110554249,
           63.118893634524454,
           62.49304616350648,
           61.8671986924885,
           61.24135122147047,
           60.61550375045243,
           59.98965627943451,
           59.36380880841648,
           58.737961337398445,
           58.11211386638047,
           57.48626639536249,
           56.86041892434445,
           56.23457145332648,
           55.608723982308504,
           54.98287651129046,
           54.3570290402725,
           53.73118156925452,
           53.10533409823648,
           52.47948662721845,
           51.85363915620053,
           51.227791685182495,
           50.60194421416447,
           49.976096743146485,
           49.350249272128515,
           48.72440180111048,
           48.0985543300925,
           47.47270685907453,
           46.846859388056494,
           46.22101191703845,
           45.59516444602055,
           44.969316975002506,
           44.34346950398447,
           43.7176220329665,
           43.09177456194852,
           42.46592709093049,
           41.840079619912515,
           41.21423214889453,
           40.5883846778765,
           39.96253720685852,
           39.336689735840544,
           38.71084226482251,
           38.08499479380448,
           37.459147322786556,
           36.83236615728484,
           36.20448152950947,
           35.576596901734156,
           34.94871227395885,
           34.320827646183474,
           33.692943018408165,
           33.065058390632856,
           32.4371737628575,
           31.809289135082125,
           31.181404507306873,
           30.553519879531507,
           29.92563525175614,
           29.297750623980825,
           28.669865996205516,
           28.04198136843015,
           27.41409674065484,
           26.786212112879532,
           26.158327485104166,
           25.53044285732885,
           24.90255822955354,
           24.274673601778176,
           23.64678897400281,
           23.018904346227554,
           22.391019718452185,
           21.76313509067682,
           21.1330091142414,
           20.50126512388769,
           19.869521133533922,
           19.23777714318021,
           18.6060331528265,
           17.971627223720994,
           17.335890325321014,
           16.69823989979082,
           16.373480256690467,
           16.516678164546246,
           16.65987607240201,
           16.803073980257768,
           16.94627188811354,
           17.089469795969304,
           17.23266770382506,
           17.375865611680844,
           17.519063519536605,
           17.66226142739237,
           17.805459335248138,
           17.948657243103916,
           18.09185515095966,
           18.23505305881544,
           18.378250966671217,
           18.52144887452698,
           18.664646782382743,
           18.807844690238515,
           18.95104259809428,
           19.09424050595004,
           19.237438413805815,
           19.38063632166158,
           19.523834229517337,
           19.667032137373116,
           19.81023004522889,
           19.953427953084653,
           20.096625860940414,
           20.23982376879619,
           20.38302167665195,
           20.52621958450771,
           20.669417492363486,
           20.81261540021925,
           20.95581330807501,
           21.09901121593079,
           21.242209123786562,
           21.385407031642316,
           21.528604939498084,
           21.67180284735386,
           21.815000755209624,
           21.958198663065385,
           22.10139657092116,
           22.24459447877692,
           22.387792386632682,
           22.53099029448846,
           22.674188202344222,
           22.817386110199983,
           22.960584018055762,
           23.103781925911534,
           23.2469798337673,
           23.39017774162306,
           23.533375649478828,
           23.676573557334592,
           23.81977146519036,
           23.962969373046136,
           24.106167280901893,
           24.249365188757658,
           24.392563096613436,
           24.535761004469208,
           24.678958912324955,
           24.822156820180734,
           24.96535472803651,
           25.108552635892273,
           25.211636255115405,
           24.918035809924405,
           24.624435364733408,
           24.330834919542433,
           24.037234474351436,
           23.74363402916046,
           23.45003358396949,
           23.15643313877849,
           22.862832693587485,
           22.569232248396546,
           22.275631803205542,
           21.982031358014538,
           21.688430912823566,
           21.396273149995345,
           21.106008906972235,
           20.815744663949182,
           20.525480420926087,
           20.23521617790298,
           19.94495193487988,
           19.654687691856836,
           19.36442344883371,
           19.074159205810624,
           18.783894962787535,
           18.49549753415663,
           18.209600932916207,
           17.923704331675808,
           17.637807730435366,
           17.351911129194928,
           17.066014527954504,
           16.780117926714105,
           16.494221325473646,
           16.21019312279613,
           15.93011403812548,
           15.650034953454739,
           15.369955868784015,
           15.089876784113333,
           14.809797699442624,
           14.529718614771898,
           14.254486311953036,
           13.982224616297541,
           13.709962920641964,
           13.437701224986418,
           13.165439529330893,
           12.893177833675331,
           12.62861906722888,
           12.364155989407035,
           12.099692911585164,
           11.835229833763265,
           11.572253638006131,
           11.31572060104459,
           11.059187564083038,
           10.802654527121472,
           10.54655235361891,
           10.299067435772004,
           10.051582517925098,
           9.80409760007823,
           9.561024361707421,
           9.323552468952244,
           9.086080576197103,
           8.851412000453692,
           8.624331715275261,
           8.397251430096837,
           8.174367760444401,
           7.956400124912667,
           7.738432489380932,
           7.529330984845206,
           7.32065351248388,
           7.120477542365239,
           6.9238636544729735,
           6.736115311221676,
           6.552651982083095,
           6.379230424448996,
           6.209523284549423,
           6.04912344532106,
           5.894926172139662,
           5.746463922863009,
           5.605267141498592,
           5.471664708803252,
           5.3443537724645696,
           5.224726995569181,
           5.114310189934654,
           5.012423820781077,
           4.916962816951695,
           4.828936403157124,
           4.750444912652108,
           4.6795119258351745,
           4.598045779888595,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           66.0736022453614,
           66.12411007876584,
           66.17461791217028,
           66.22512574557473,
           66.27563357897917,
           66.32614141238362,
           66.37664924578806,
           66.42678993039935,
           66.47674703992072,
           66.52670414944208,
           66.57666125896343,
           66.62661836848478,
           66.67657547800614,
           66.7265325875275,
           66.77648969704885,
           66.8264468065702,
           66.87640391609156,
           66.92636102561292,
           66.97631813513426,
           67.02627524465564,
           67.07623235417698,
           67.12618946369834,
           67.1761465732197,
           67.22610368274105,
           67.27606079226241,
           67.32601790178376,
           67.37597501130512,
           67.42593212082647,
           67.47588923034783,
           67.52584633986918,
           67.57580344939055,
           67.62576055891189,
           67.67571766843325,
           67.72567477795461,
           67.77563188747595,
           67.82558899699731,
           67.87554610651867,
           67.92550321604003,
           67.97546032556139,
           68.02541743508274,
           68.07537454460409,
           68.12533165412546,
           68.17528876364682,
           68.22524587316816,
           68.27520298268952,
           68.32516009221087,
           68.37511720173224,
           68.42507431125358,
           68.47503142077494,
           68.5249885302963,
           68.57494563981766,
           68.62490274933901,
           68.67485985886036,
           68.72481696838172,
           68.77477407790307,
           68.82473118742442,
           68.87468829694579,
           68.92464540646714,
           68.9746025159885,
           69.02455962550985,
           69.07451673503121,
           69.12447384455257,
           69.17443095407391,
           69.22438806359527,
           69.27434517311663,
           69.32430228263799,
           69.37425939215935,
           69.42421650168069,
           69.47417361120206,
           69.5241307207234,
           69.57408783024476,
           69.62404493976612,
           69.67400204928748,
           69.72395915880884,
           69.7739162683302,
           69.82387337785154,
           69.8738304873729,
           69.92378759689426,
           69.97374470641562,
           70.02370181593696,
           70.07365892545832,
           70.12361603497968,
           70.17357314450103,
           70.22353025402238,
           70.26033902229503,
           70.29451812231794,
           70.32869722234084,
           70.36287632236375,
           70.39705542238664,
           70.43123452240954,
           70.46541362243245,
           70.49959272245536,
           70.53377182247826,
           70.56795092250115,
           70.60213002252407,
           70.63630912254696,
           70.67048822256987,
           70.70466732259277,
           70.7388464226157,
           70.77302552263859,
           70.80720462266149,
           70.84138372268438,
           70.87556282270731,
           70.9097419227302,
           70.9439210227531,
           70.978100122776,
           71.01227922279891,
           71.0464583228218,
           71.08063742284472,
           71.11481652286761,
           71.14899562289052,
           71.18317472291344,
           71.21735382293633,
           71.25153292295923,
           71.28571202298214,
           71.31989112300504,
           71.35407022302795,
           71.38824932305084,
           71.42242842307375,
           71.45660752309665,
           71.49078662311956,
           71.52496572314246,
           71.55914482316537,
           71.59332392318827,
           71.62750302321118,
           71.66168212323407,
           71.69586122325697,
           71.73004032327988,
           71.76421942330279,
           71.79839852332569,
           71.83257762334858,
           71.8667567233715,
           71.9009358233944,
           71.9351149234173,
           71.9692940234402,
           72.0034731234631,
           72.037652223486,
           72.07183132350892,
           72.10601042353181,
           72.14018952355472,
           72.17436862357762,
           72.20854772360053,
           72.24272682362343,
           72.27690592364632,
           72.31108502366924,
           72.34526412369215,
           72.37944322371504,
           72.41362232373794,
           72.44780142376085,
           72.48198052378376,
           72.51615962380666,
           72.55033872382957,
           72.58451782385247,
           72.61869692387536,
           72.65287602389827,
           72.68705512392118,
           72.72123422394408,
           72.75541332396698,
           72.78959242398989,
           72.82377152401278,
           72.85795062547021,
           72.8938388007573,
           72.92972697604438,
           72.96561515133146,
           73.00150332661855,
           73.03739150190563,
           73.0732796771927,
           73.04530990827449,
           72.9854111672536,
           72.92551242623274,
           72.86561368521184,
           72.80571494419097,
           72.7458162031701,
           72.68591746214922,
           72.60560375499797,
           72.50931304802971,
           72.41302234106146,
           72.3167316340932,
           72.22044092712495,
           72.12415022015671,
           72.02785951318845,
           71.9315688062202,
           71.83527809925195,
           71.7389873922837,
           71.64269668531544,
           71.54640597834718,
           71.45011527137893,
           71.35382456441069,
           71.25753385744241,
           71.16124315047418,
           71.0649524435059,
           70.96866173653765,
           70.87237102956941,
           70.77608032260115,
           70.6797896156329,
           70.58349890866464,
           70.48720820169639,
           70.39091749472814,
           70.29462678775988,
           70.19833608079163,
           70.10204537382337,
           70.00575466685513,
           69.90946395988686,
           69.81317325291862,
           69.71688254595037,
           69.62059183898212,
           69.52430113201386,
           69.42801042504561,
           69.33171971807735,
           69.23542901110909,
           69.13913830414083,
           69.04284759717258,
           68.94655689020433,
           68.85026618323609,
           68.75397547626783,
           68.65768476929958,
           68.56139406233132,
           68.46510335536306,
           68.36881264839482,
           68.27252194142656,
           68.1762312344583,
           68.07994052749004,
           67.98364982052179,
           67.88735911355354,
           67.79106840658528,
           67.69477769961703,
           67.59848699264877,
           67.50219628568053,
           67.40590557871228,
           67.30961487174402,
           67.21332416477577,
           67.11703345780752,
           67.02074275083926,
           66.92445204387101,
           66.82816133690275,
           66.73187062993449,
           66.63557992296624,
           66.53928921599798,
           66.44299850902974,
           66.34670780206147,
           66.25041709509323,
           66.15412638812496,
           66.05783568115672,
           65.96154497418846,
           65.86525426722021,
           65.76896356025196,
           65.67267285328371,
           65.57638214631545,
           65.4800914393472,
           65.38380073237894,
           65.0227316433858,
           64.39688417236776,
           63.77103670134979,
           63.145189230331816,
           62.51934175931378,
           61.893494288295805,
           61.26764681727783,
           60.63978341476536,
           60.01189878699,
           59.38401415921475,
           58.756129531439385,
           58.12824490366401,
           57.50036027588871,
           56.872475648113394,
           56.24459102033802,
           55.61670639256272,
           54.98882176478742,
           54.360937137012044,
           53.73305250923673,
           53.10516788146141,
           52.47728325368605,
           51.84939862591068,
           51.22151399813543,
           50.59362937036007,
           49.965744742584704,
           49.337860114809395,
           48.70997548703407,
           48.08209085925871,
           47.454206231483404,
           46.82632160370809,
           46.19843697593272,
           45.57055234815735,
           44.94266772038211,
           44.31478309260674,
           43.68689846483137,
           43.059013837056064,
           42.431129209280755,
           41.80324458150538,
           41.17535995373007,
           40.547475325954764,
           39.91959069817939,
           39.291706070404096,
           38.66382144262877,
           38.03593681485341,
           37.40805218707804,
           36.78016755930279,
           36.152282931527424,
           35.52439830375206,
           34.89651367597675,
           34.26862904820143,
           33.64074442042607,
           33.01285979265075,
           32.38497516487545,
           31.757090537100083,
           31.129205909324714,
           30.50132128154946,
           29.873436653774085,
           29.245552025998723,
           28.615266899916467,
           27.983522909562755,
           27.351778919208986,
           26.720034928855277,
           26.088290938501565,
           25.456546948147796,
           24.824802957794088,
           24.193058967440372,
           23.561314977086603,
           22.929570986732838,
           22.295929132566215,
           21.660192234166175,
           21.024455335766135,
           20.388718437366155,
           19.75251059326897,
           19.113397757011995,
           18.474284920755075,
           18.409402495468278,
           18.552600403324046,
           18.695798311179807,
           18.838996219035568,
           18.982194126891347,
           19.12539203474713,
           19.26858994260289,
           19.411787850458655,
           19.554985758314423,
           19.698183666170184,
           19.84138157402595,
           19.984579481881728,
           20.127777389737492,
           20.27097529759325,
           20.414173205449025,
           20.557371113304796,
           20.700569021160543,
           20.843766929016322,
           20.9869648368721,
           21.130162744727862,
           21.273360652583623,
           21.416558560439398,
           21.55975646829516,
           21.702954376150924,
           21.8461522840067,
           21.98935019186246,
           22.13254809971822,
           22.275746007574,
           22.41894391542977,
           22.562141823285536,
           22.705339731141297,
           22.848537638997072,
           22.991735546852833,
           23.134933454708595,
           23.27813136256437,
           23.421329270420134,
           23.564527178275892,
           23.707725086131674,
           23.850922993987446,
           23.9941209018432,
           24.137318809698968,
           24.280516717554747,
           24.423714625410504,
           24.56691253326627,
           24.71011044112204,
           24.853308348977805,
           24.99650625683357,
           25.139704164689345,
           25.282902072545106,
           25.42609998040087,
           25.569297888256642,
           25.71249579611242,
           25.855693703968175,
           25.99889161182394,
           26.142089519679715,
           26.28528742753548,
           26.42848533539124,
           26.57168324324702,
           26.71488115110278,
           26.492594557520107,
           26.198994112329128,
           25.9053936671381,
           25.61179322194716,
           25.318192776756156,
           25.02459233156516,
           24.730991886374184,
           24.437391441183212,
           24.143790995992212,
           23.850190550801212,
           23.556590105610248,
           23.26298966041924,
           22.96938921522827,
           22.676690446667767,
           22.386426203644668,
           22.096161960621565,
           21.805897717598498,
           21.515633474575413,
           21.225369231552285,
           20.935104988529215,
           20.64484074550614,
           20.354576502483035,
           20.06431225945998,
           19.774048016436886,
           19.48617893155274,
           19.2002823303123,
           18.914385729071917,
           18.62848912783148,
           18.342592526591034,
           18.056695925350624,
           17.770799324110197,
           17.484902722869773,
           17.19900612162937,
           16.918120227106122,
           16.638041142435398,
           16.35796205776466,
           16.077882973094006,
           15.797803888423283,
           15.517724803752543,
           15.237645719081891,
           14.962882459651404,
           14.690620763995858,
           14.418359068340333,
           14.146097372684755,
           13.873835677029208,
           13.60157398137363,
           13.334335935176242,
           13.069872857354369,
           12.80540977953247,
           12.540946701710638,
           12.276483623888753,
           12.015985565857672,
           11.759452528896158,
           11.50291949193462,
           11.246386454973067,
           10.990427902454961,
           10.742942984608067,
           10.495458066761149,
           10.247973148914255,
           10.002471008424713,
           9.764999115669536,
           9.527527222914358,
           9.290055330159229,
           9.060896723057107,
           8.833816437878685,
           8.606736152700286,
           8.386850065208364,
           8.168882429676621,
           7.951878504198914,
           7.74320103183763,
           7.534523559476295,
           7.33420510606234,
           7.137591218170075,
           6.9477742476570885,
           6.764310918518508,
           6.587398444719719,
           6.416002480165689,
           6.252787933031307,
           6.09337262784722,
           5.943015038850641,
           5.798027578690846,
           5.658445542572224,
           5.525625252080885,
           5.399878700281265,
           5.281346607750393,
           5.171383219353618,
           5.0693327321686485,
           4.973416347735756,
           4.884116663356576,
           4.8028992770340935,
           4.730280392999215,
           4.653719139976531,
           4.571272015445188,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           66.17590726063412,
           66.22484797162568,
           66.27378868261725,
           66.32272939360882,
           66.37167010460038,
           66.42061081559194,
           66.46955152658352,
           66.51849223757509,
           66.56743294856665,
           66.61637365955822,
           66.6653143705498,
           66.71510208127866,
           66.76505919080003,
           66.81501630032137,
           66.86497340984273,
           66.91493051936408,
           66.96488762888544,
           67.0148447384068,
           67.06480184792815,
           67.11475895744951,
           67.16471606697087,
           67.21467317649221,
           67.26463028601357,
           67.31458739553493,
           67.36454450505629,
           67.41450161457765,
           67.46445872409899,
           67.51441583362035,
           67.5643729431417,
           67.61433005266306,
           67.66428716218442,
           67.71424427170578,
           67.76420138122714,
           67.81415849074848,
           67.86411560026984,
           67.9140727097912,
           67.96402981931256,
           68.0139869288339,
           68.06394403835526,
           68.11390114787662,
           68.16385825739798,
           68.21381536691933,
           68.26377247644069,
           68.31372958596205,
           68.36368669548341,
           68.41364380500475,
           68.46360091452611,
           68.51355802404746,
           68.56351513356881,
           68.61347224309017,
           68.66342935261153,
           68.71338646213289,
           68.76334357165425,
           68.81330068117559,
           68.86325779069696,
           68.9132149002183,
           68.96317200973967,
           69.01312911926102,
           69.06308622878237,
           69.11304333830374,
           69.16300044782508,
           69.21295755734644,
           69.2629146668678,
           69.31287177638914,
           69.36282888591052,
           69.41278599543188,
           69.46274310495322,
           69.51270021447459,
           69.56265732399594,
           69.61261443351728,
           69.66257154303865,
           69.71252865256,
           69.76248576208135,
           69.81244287160271,
           69.86239998112407,
           69.91235709064543,
           69.96231420016679,
           70.01227130968813,
           70.06222841920949,
           70.11218552873085,
           70.1621426382522,
           70.21209974777355,
           70.26205685729491,
           70.31201396681627,
           70.34882273508892,
           70.38300183511181,
           70.41718093513472,
           70.45136003515762,
           70.48553913518052,
           70.51971823520343,
           70.55389733522634,
           70.58807643524923,
           70.62225553527213,
           70.65643463529504,
           70.69061373531795,
           70.72479283534085,
           70.75897193536376,
           70.79315103538664,
           70.82733013540957,
           70.86150923543246,
           70.89568833545538,
           70.92986743547827,
           70.96404653550118,
           70.99822563552408,
           71.03240473554698,
           71.06658383556989,
           71.1007629355928,
           71.1349420356157,
           71.16912113563859,
           71.2033002356615,
           71.2374793356844,
           71.27165843570731,
           71.3058375357302,
           71.3400166357531,
           71.37419573577601,
           71.40837483579892,
           71.44255393582182,
           71.47673303584472,
           71.51091213586764,
           71.54509123589052,
           71.57927033591344,
           71.61344943593633,
           71.64762853595924,
           71.68180763598215,
           71.71598673600505,
           71.75016583602795,
           71.78434493605086,
           71.81852403607377,
           71.85270313609666,
           71.88688223611956,
           71.92106133614246,
           71.95524043616538,
           71.98941953618828,
           72.02359863621118,
           72.05777773623409,
           72.09195683625698,
           72.1261359362799,
           72.16031503630279,
           72.19449413632569,
           72.2286732363486,
           72.2628523363715,
           72.2970314363944,
           72.3312105364173,
           72.36538963644021,
           72.39956873646311,
           72.43374783648602,
           72.46792693650892,
           72.50210603653181,
           72.53628513655474,
           72.57046423657765,
           72.60464333660053,
           72.63882243662344,
           72.67300153664635,
           72.70718063666924,
           72.74135973669215,
           72.77553883671506,
           72.80971793673797,
           72.84273987431057,
           72.87553037781518,
           72.9083208813198,
           72.94111138482441,
           72.97390188832904,
           73.00669239183367,
           73.03948289533827,
           73.0722733988429,
           73.10506390234752,
           73.13785440585214,
           73.06049691376022,
           72.92806542387007,
           72.79563393397991,
           72.66320244408973,
           72.53077095419958,
           72.39833946430942,
           72.26590797441926,
           72.1334764845291,
           72.00104499463895,
           71.86861350474878,
           71.73618201485861,
           71.60375052496845,
           71.47229010790446,
           71.37578719711607,
           71.27928428632768,
           71.18278137553929,
           71.08627846475089,
           70.9897755539625,
           70.89327264317413,
           70.79676973238573,
           70.70026682159735,
           70.60376391080895,
           70.50726100002058,
           70.41075808923217,
           70.31425517844379,
           70.2177522676554,
           70.12124935686701,
           70.02474644607862,
           69.92824353529022,
           69.83174062450183,
           69.73523771371345,
           69.63873480292506,
           69.54223189213667,
           69.44572898134828,
           69.3492260705599,
           69.2527231597715,
           69.15622024898312,
           69.05971733819473,
           68.96321442740634,
           68.86671151661794,
           68.77020860582955,
           68.67370569504118,
           68.57720278425278,
           68.48069987346439,
           68.384196962676,
           68.28769405188763,
           68.19119114109922,
           68.09468823031084,
           67.99818531952245,
           67.90168240873405,
           67.80517949794566,
           67.70867658715727,
           67.61217367636888,
           67.5156707655805,
           67.41916785479211,
           67.32266494400372,
           67.22616203321533,
           67.12965912242694,
           67.03315621163856,
           66.93665330085015,
           66.84015039006178,
           66.74364747927339,
           66.64714456848499,
           66.5506416576966,
           66.45413874690823,
           66.35763583611983,
           66.26113292533142,
           66.16463001454305,
           66.06812710375465,
           65.97162419296626,
           65.87512128217789,
           65.77861837138948,
           65.6821154606011,
           65.58561254981271,
           65.48910963902432,
           65.39260672823593,
           65.29610381744754,
           65.19960090665916,
           65.10309799587077,
           65.00659508508238,
           64.91009217429398,
           64.8135892635056,
           64.7170863527172,
           64.35489258343533,
           63.72700795565996,
           63.099123327884655,
           62.47123870010934,
           61.84335407233397,
           61.215469444558664,
           60.58758481678336,
           59.95970018900798,
           59.33181556123262,
           58.70393093345736,
           58.076046305682006,
           57.44816167790663,
           56.82027705013132,
           56.19239242235601,
           55.564507794580635,
           54.93662316680534,
           54.30873853903002,
           53.68085391125465,
           53.05296928347934,
           52.42508465570403,
           51.79720002792867,
           51.169315400153295,
           50.54143077237805,
           49.913546144602684,
           49.28566151682732,
           48.65777688905201,
           48.02989226127669,
           47.40200763350133,
           46.77412300572601,
           46.14623837795071,
           45.518353750175336,
           44.89046912239997,
           44.262584494624726,
           43.634699866849346,
           43.00681523907398,
           42.37893061129868,
           41.751045983523355,
           41.123161355747996,
           40.49527672797269,
           39.86739210019738,
           39.239507472422005,
           38.611622844646696,
           37.98373821687139,
           37.35585358909602,
           36.727968961320656,
           36.097524685591615,
           35.46578069523785,
           34.83403670488407,
           34.202292714530365,
           33.57054872417666,
           32.93880473382288,
           32.30706074346917,
           31.675316753115464,
           31.043572762761695,
           30.41182877240793,
           29.780084782054274,
           29.148340791700505,
           28.516596801346736,
           27.884852810993024,
           27.253108820639316,
           26.620231041411344,
           25.98449414301136,
           25.34875724461138,
           24.713020346211344,
           24.077283447811364,
           23.441546549411385,
           22.805809651011348,
           22.16766845049017,
           21.528555614233312,
           20.88944277797633,
           20.302126826390243,
           20.445324734246007,
           20.588522642101765,
           20.73172054995755,
           20.87491845781331,
           21.01811636566907,
           21.161314273524837,
           21.3045121813806,
           21.447710089236356,
           21.590907997092142,
           21.734105904947917,
           21.87730381280368,
           22.020501720659443,
           22.163699628515214,
           22.306897536370975,
           22.450095444226736,
           22.59329335208252,
           22.73649125993828,
           22.87968916779404,
           23.022887075649813,
           23.166084983505588,
           23.309282891361335,
           23.45248079921711,
           23.59567870707289,
           23.738876614928653,
           23.882074522784414,
           24.02527243064019,
           24.16847033849595,
           24.311668246351715,
           24.45486615420749,
           24.59806406206325,
           24.741261969919012,
           24.884459877774788,
           25.027657785630563,
           25.170855693486324,
           25.314053601342085,
           25.457251509197864,
           25.60044941705362,
           25.743647324909386,
           25.886845232765165,
           26.030043140620922,
           26.173241048476683,
           26.316438956332465,
           26.459636864188234,
           26.60283477204399,
           26.746032679899763,
           26.889230587755534,
           27.032428495611295,
           27.175626403467056,
           27.31882431132283,
           27.462022219178596,
           27.605220127034357,
           27.748418034890136,
           27.891615942745894,
           28.034813850601658,
           28.178011758457437,
           28.06715330511582,
           27.77355285992485,
           27.479952414733837,
           27.186351969542834,
           26.892751524351862,
           26.599151079160908,
           26.305550633969887,
           26.011950188778933,
           25.718349743587943,
           25.42474929839696,
           25.131148853205936,
           24.837548408014996,
           24.543947962823992,
           24.250347517632996,
           23.957107743340195,
           23.666843500317103,
           23.376579257293997,
           23.086315014270923,
           22.79605077124787,
           22.505786528224764,
           22.215522285201672,
           21.925258042178598,
           21.634993799155495,
           21.344729556132386,
           21.054465313109326,
           20.76420107008624,
           20.476860328948877,
           20.190963727708464,
           19.905067126468037,
           19.61917052522761,
           19.333273923987186,
           19.047377322746772,
           18.76148072150633,
           18.475584120265893,
           18.189687519025508,
           17.906126416086796,
           17.626047331416085,
           17.34596824674537,
           17.06588916207468,
           16.785810077403955,
           16.505730992733287,
           16.225651908062563,
           15.945572823391839,
           15.671278607349763,
           15.399016911694222,
           15.126755216038674,
           14.854493520383096,
           14.58223182472759,
           14.309970129072028,
           14.040052803123572,
           13.775589725301755,
           13.511126647479854,
           13.246663569657981,
           12.982200491836084,
           12.717737414014252,
           12.459717493709292,
           12.203184456747726,
           11.946651419786223,
           11.690118382824673,
           11.434303451290996,
           11.18681853344414,
           10.939333615597223,
           10.691848697750327,
           10.444363779903458,
           10.206445762386846,
           9.968973869631668,
           9.731501976876492,
           9.497461730838983,
           9.27038144566055,
           9.043301160482116,
           8.81730000550406,
           8.599332369972336,
           8.381364734440602,
           8.165748551191395,
           7.957071078830069,
           7.748393606468742,
           7.547932669759457,
           7.351318781867192,
           7.159433184092515,
           6.975969854953934,
           6.795566464990449,
           6.624170500436424,
           6.456452420741565,
           6.29605258151323,
           6.141461494558179,
           5.991103905561601,
           5.849591234518725,
           5.7124060858498655,
           5.580401995849015,
           5.455403628097964,
           5.337966219931633,
           5.228456248772575,
           5.126241643556222,
           5.029869878519839,
           4.939592042027384,
           4.8567224645004305,
           4.7811944051817585,
           4.709392500064488,
           4.626945375533129,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           66.2725278735828,
           66.32146858457438,
           66.37040929556593,
           66.41935000655751,
           66.46829071754907,
           66.51723142854064,
           66.5661721395322,
           66.61511285052377,
           66.66405356151533,
           66.7129942725069,
           66.76193498349848,
           66.81087569449004,
           66.85981640548161,
           66.90875711647317,
           66.95769782746474,
           67.0066385384563,
           67.05557924944787,
           67.10451996043943,
           67.153460671431,
           67.20240138242258,
           67.25134209341415,
           67.30028280440571,
           67.34922351539728,
           67.39816422638884,
           67.44710493738042,
           67.49604564837198,
           67.54498635936355,
           67.59426587065983,
           67.64422298018118,
           67.69418008970254,
           67.74413719922389,
           67.79409430874524,
           67.84405141826662,
           67.89400852778796,
           67.94396563730932,
           67.99392274683068,
           68.04387985635204,
           68.09383696587338,
           68.14379407539474,
           68.1937511849161,
           68.24370829443745,
           68.2936654039588,
           68.34362251348016,
           68.39357962300153,
           68.44353673252287,
           68.49349384204422,
           68.54345095156559,
           68.59340806108693,
           68.64336517060829,
           68.69332228012965,
           68.74327938965101,
           68.79323649917237,
           68.84319360869371,
           68.89315071821507,
           68.94310782773643,
           68.99306493725778,
           69.04302204677914,
           69.0929791563005,
           69.14293626582185,
           69.1928933753432,
           69.24285048486456,
           69.29280759438592,
           69.34276470390728,
           69.39272181342864,
           69.44267892295,
           69.49263603247134,
           69.5425931419927,
           69.59255025151406,
           69.64250736103541,
           69.69246447055677,
           69.74242158007812,
           69.79237868959947,
           69.84233579912083,
           69.89229290864219,
           69.94225001816355,
           69.9922071276849,
           70.04216423720626,
           70.09212134672761,
           70.14207845624897,
           70.19203556577033,
           70.24199267529167,
           70.29194978481303,
           70.34190689433439,
           70.39186400385574,
           70.42867277212838,
           70.46285187215129,
           70.49703097217419,
           70.5312100721971,
           70.56538917222001,
           70.5995682722429,
           70.6337473722658,
           70.66792647228871,
           70.70210557231161,
           70.73628467233452,
           70.77046377235743,
           70.80464287238033,
           70.83882197240322,
           70.87300107242613,
           70.90718017244905,
           70.94135927247194,
           70.97553837249484,
           71.00971747251774,
           71.04389657254066,
           71.07807567256356,
           71.11225477258645,
           71.14643387260935,
           71.18061297263226,
           71.21479207265517,
           71.24897117267807,
           71.28315027270096,
           71.31732937272388,
           71.35150847274679,
           71.38568757276968,
           71.41986667279258,
           71.45404577281548,
           71.4882248728384,
           71.5224039728613,
           71.5565830728842,
           71.5907621729071,
           71.62494127293,
           71.65912037295291,
           71.69329947297581,
           71.7274785729987,
           71.76165767302163,
           71.79583677304453,
           71.83001587306742,
           71.86419497309033,
           71.89837407311325,
           71.93255317313613,
           71.96673227315904,
           72.00091137318195,
           72.03509047320486,
           72.06926957322774,
           72.10344867325065,
           72.13762777327356,
           72.17180687329646,
           72.20598597331936,
           72.24016507334227,
           72.27434417336518,
           72.30852327338808,
           72.34223950899072,
           72.37503001249533,
           72.40782051599994,
           72.44061101950457,
           72.47340152300919,
           72.5061920265138,
           72.53898253001842,
           72.57177303352304,
           72.60456353702766,
           72.63735404053229,
           72.6701445440369,
           72.70293504754152,
           72.73572555104613,
           72.76851605455074,
           72.80130655805537,
           72.83409706155999,
           72.8668875650646,
           72.89967806856922,
           72.93246857207384,
           72.96525907557846,
           72.99804957908307,
           73.0308400825877,
           73.06363058609232,
           73.09642108959693,
           73.12921159310156,
           73.16200209660617,
           73.19479260011079,
           73.1174351080189,
           72.98500361812873,
           72.85257212823856,
           72.7201406383484,
           72.58770914845825,
           72.45527765856808,
           72.32284616867793,
           72.19041467878776,
           72.0579831888976,
           71.92555169900744,
           71.79312020911728,
           71.66068871922711,
           71.52825722933696,
           71.39582573944679,
           71.26339424955663,
           71.13096275966647,
           70.99853126977631,
           70.86609977988614,
           70.73366828999598,
           70.60123680010582,
           70.46880531021566,
           70.3363738203255,
           70.20394233043534,
           70.07151084054517,
           69.93907935065502,
           69.80664786076485,
           69.67421637087469,
           69.54178488098454,
           69.40935339109436,
           69.2769219012042,
           69.14449041131405,
           69.01205892142389,
           68.87962743153372,
           68.7656457555909,
           68.66914284480251,
           68.5726399340141,
           68.47613702322573,
           68.37963411243734,
           68.28313120164896,
           68.18662829086055,
           68.09012538007217,
           67.99362246928378,
           67.89711955849539,
           67.800616647707,
           67.70411373691861,
           67.60761082613023,
           67.51110791534184,
           67.41460500455345,
           67.31810209376505,
           67.22159918297666,
           67.12509627218827,
           67.02859336139988,
           66.9320904506115,
           66.83558753982311,
           66.73908462903472,
           66.64258171824633,
           66.54607880745795,
           66.44957589666956,
           66.35307298588116,
           66.25657007509277,
           66.16006716430438,
           66.063564253516,
           65.9670613427276,
           65.87055843193923,
           65.77405552115083,
           65.67755261036244,
           65.58104969957405,
           65.48454678878566,
           65.38804387799726,
           65.29154096720887,
           65.1950380564205,
           65.0985351456321,
           65.00203223484371,
           64.90552932405532,
           64.80902641326693,
           64.71252350247855,
           64.61602059169016,
           64.51951768090177,
           64.42301477011338,
           64.326511859325,
           64.2300089485366,
           64.1335060377482,
           64.0370031269598,
           63.674809357677944,
           63.04692472990257,
           62.41904010212727,
           61.79115547435195,
           61.16327084657659,
           60.53538621880127,
           59.90750159102597,
           59.2796169632506,
           58.65173233547523,
           58.02384770769997,
           57.395963079924606,
           56.76807845214925,
           56.14019382437393,
           55.512309196598615,
           54.88442456882325,
           54.25653994104795,
           53.62865531327263,
           53.00077068549727,
           52.372886057721956,
           51.74500142994664,
           51.11711680217128,
           50.48923217439591,
           49.861347546620664,
           49.2334629188453,
           48.60557829106993,
           47.97769366329462,
           47.34980903551929,
           46.72192440774394,
           46.094039779968625,
           45.46615515219332,
           44.83827052441795,
           44.210385896642585,
           43.579782471266704,
           42.948038480912935,
           42.316294490559166,
           41.68455050020546,
           41.05280650985175,
           40.42106251949798,
           39.78931852914427,
           39.157574538790556,
           38.52583054843679,
           37.894086558083075,
           37.262342567729355,
           36.6305985773756,
           35.99885458702183,
           35.36711059666818,
           34.73536660631441,
           34.10362261596064,
           33.47187862560693,
           32.84013463525322,
           32.20839064489944,
           31.576646654545733,
           30.944532950256587,
           30.308796051856547,
           29.673059153456506,
           29.037322255056587,
           28.401585356656554,
           27.765848458256514,
           27.13011155985653,
           26.494374661456554,
           25.858637763056517,
           25.221939143968406,
           24.582826307711485,
           23.943713471454508,
           23.304600635197588,
           22.665487798940674,
           22.33804906516795,
           22.48124697302372,
           22.624444880879473,
           22.76764278873525,
           22.910840696591027,
           23.05403860444678,
           23.197236512302545,
           23.340434420158324,
           23.48363232801409,
           23.626830235869853,
           23.770028143725614,
           23.913226051581375,
           24.05642395943714,
           24.199621867292922,
           24.3428197751487,
           24.486017683004466,
           24.629215590860223,
           24.772413498715995,
           24.915611406571756,
           25.058809314427517,
           25.2020072222833,
           25.345205130139057,
           25.48840303799482,
           25.63160094585059,
           25.77479885370637,
           25.917996761562115,
           26.06119466941789,
           26.20439257727367,
           26.347590485129434,
           26.490788392985195,
           26.63398630084097,
           26.777184208696735,
           26.920382116552492,
           27.063580024408267,
           27.206777932264032,
           27.349975840119793,
           27.49317374797557,
           27.636371655831347,
           27.7795695636871,
           27.922767471542866,
           28.06596537939864,
           28.209163287254405,
           28.352361195110166,
           28.49555910296594,
           28.638757010821703,
           28.781954918677467,
           28.925152826533246,
           29.068350734389014,
           29.211548642244768,
           29.354746550100536,
           29.497944457956315,
           29.641142365812076,
           29.64171205271156,
           29.348111607520536,
           29.054511162329582,
           28.760910717138614,
           28.467310271947607,
           28.17370982675664,
           27.880109381565624,
           27.586508936374663,
           27.29290849118366,
           26.99930804599269,
           26.705707600801674,
           26.41210715561067,
           26.118506710419698,
           25.824906265228744,
           25.531305820037723,
           25.237705374846772,
           24.947260796989582,
           24.656996553966458,
           24.366732310943352,
           24.07646806792029,
           23.786203824897225,
           23.4959395818741,
           23.205675338851023,
           22.915411095827935,
           22.625146852804832,
           22.334882609781754,
           22.044618366758698,
           21.754354123735595,
           21.467541726345043,
           21.181645125104616,
           20.895748523864192,
           20.609851922623747,
           20.32395532138333,
           20.038058720142907,
           19.75216211890247,
           19.466265517662055,
           19.180368916421628,
           18.8944723151812,
           18.614053520396787,
           18.333974435726077,
           18.053895351055367,
           17.773816266384625,
           17.49373718171398,
           17.213658097043236,
           16.933579012372526,
           16.653499927701816,
           16.379674755048125,
           16.10741305939256,
           15.835151363737053,
           15.562889668081489,
           15.290627972425911,
           15.01836627677038,
           14.746104581114842,
           14.481306593249084,
           14.216843515427215,
           13.952380437605367,
           13.687917359783494,
           13.423454281961583,
           13.159982458522435,
           12.903449421560882,
           12.64691638459933,
           12.390383347637803,
           12.133850310676287,
           11.87817900012708,
           11.630694082280163,
           11.383209164433307,
           11.135724246586388,
           10.888239328739495,
           10.647892409104157,
           10.41042051634898,
           10.172948623593815,
           9.935476730838673,
           9.706946453442415,
           9.479866168263982,
           9.252785883085549,
           9.029782310268054,
           8.8118146747363,
           8.593847039204576,
           8.379618598183841,
           8.170941125822516,
           7.962263653461182,
           7.76166023345662,
           7.565046345564316,
           7.371092120527941,
           7.187628791389353,
           7.004165462250816,
           6.832338520707147,
           6.660942556153129,
           6.499717069223482,
           6.339907950265717,
           6.189550361269143,
           6.042351671710982,
           5.90115489034657,
           5.766366629127477,
           5.6359269236657425,
           5.510928555914692,
           5.394585832112849,
           5.285529278191532,
           5.183150554943817,
           5.086323409303903,
           4.9950674206981915,
           4.910771437105472,
           4.8336487695637365,
           4.763103902982868,
           4.682618735621083,
           4.600171611089723,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           66.3691484865315,
           66.41808919752307,
           66.46702990851463,
           66.5159706195062,
           66.56491133049776,
           66.61385204148934,
           66.6627927524809,
           66.71173346347247,
           66.76067417446403,
           66.8096148854556,
           66.85855559644718,
           66.90749630743873,
           66.95643701843031,
           67.00537772942187,
           67.05431844041344,
           67.10325915140501,
           67.15219986239657,
           67.20114057338814,
           67.2500812843797,
           67.29902199537128,
           67.34796270636284,
           67.39690341735441,
           67.44584412834598,
           67.49478483933754,
           67.54372555032911,
           67.59266626132069,
           67.64160697231225,
           67.6905476833038,
           67.73948839429538,
           67.78842910528695,
           67.83736981627851,
           67.88631052727008,
           67.93525123826166,
           67.98419194925322,
           68.03313266024479,
           68.08207337123635,
           68.13101408222792,
           68.1799547932195,
           68.22889550421107,
           68.27783621520263,
           68.32677692619419,
           68.37571763718576,
           68.42465834817732,
           68.4735990591689,
           68.52338676956236,
           68.57334387908371,
           68.62330098860507,
           68.67325809812642,
           68.72321520764777,
           68.77317231716913,
           68.8231294266905,
           68.87308653621184,
           68.9230436457332,
           68.97300075525456,
           69.02295786477592,
           69.07291497429726,
           69.12287208381862,
           69.17282919333998,
           69.22278630286134,
           69.2727434123827,
           69.32270052190404,
           69.3726576314254,
           69.42261474094676,
           69.47257185046811,
           69.52252895998947,
           69.57248606951083,
           69.62244317903217,
           69.67240028855355,
           69.72235739807489,
           69.77231450759625,
           69.82227161711761,
           69.87222872663897,
           69.92218583616031,
           69.97214294568167,
           70.02210005520303,
           70.07205716472438,
           70.12201427424574,
           70.17197138376709,
           70.22192849328846,
           70.2718856028098,
           70.32184271233116,
           70.37179982185252,
           70.42175693137386,
           70.47171404089522,
           70.50852280916787,
           70.54270190919078,
           70.57688100921368,
           70.61106010923658,
           70.64523920925949,
           70.6794183092824,
           70.7135974093053,
           70.74777650932819,
           70.7819556093511,
           70.816134709374,
           70.85031380939691,
           70.8844929094198,
           70.91867200944272,
           70.95285110946561,
           70.98703020948852,
           71.02120930951142,
           71.05538840953433,
           71.08956750955724,
           71.12374660958014,
           71.15792570960303,
           71.19210480962593,
           71.22628390964884,
           71.26046300967175,
           71.29464210969465,
           71.32882120971756,
           71.36300030974046,
           71.39717940976335,
           71.43135850978626,
           71.46553760980918,
           71.49971670983207,
           71.53389580985497,
           71.56807490987788,
           71.60225400990078,
           71.63643310992367,
           71.6706122099466,
           71.70479130996948,
           71.73897040999239,
           71.7731495100153,
           71.8073286100382,
           71.8415077100611,
           71.87452964717548,
           71.90732015068009,
           71.94011065418472,
           71.97290115768934,
           72.00569166119394,
           72.03848216469858,
           72.07127266820318,
           72.1040631717078,
           72.13685367521244,
           72.16964417871704,
           72.20243468222166,
           72.23522518572628,
           72.2680156892309,
           72.30080619273551,
           72.33359669624014,
           72.36638719974475,
           72.39917770324936,
           72.43196820675398,
           72.4647587102586,
           72.49754921376322,
           72.53033971726785,
           72.56313022077246,
           72.59592072427708,
           72.62871122778171,
           72.66150173128631,
           72.69429223479094,
           72.72708273829556,
           72.75987324180018,
           72.7926637453048,
           72.82545424880941,
           72.85824475231402,
           72.89103525581864,
           72.92382575932326,
           72.95661626282788,
           72.98940676633251,
           73.02219726983712,
           73.05498777334174,
           73.08777827684636,
           73.12056878035098,
           73.1533592838556,
           73.18614978736022,
           73.21894029086482,
           73.25173079436945,
           73.17437330227754,
           73.04194181238739,
           72.90951032249723,
           72.77707883260706,
           72.64464734271691,
           72.51221585282673,
           72.37978436293658,
           72.24735287304642,
           72.11492138315626,
           71.9824898932661,
           71.85005840337594,
           71.71762691348577,
           71.58519542359562,
           71.45276393370546,
           71.32033244381529,
           71.18790095392512,
           71.05546946403497,
           70.92303797414479,
           70.79060648425464,
           70.65817499436449,
           70.52574350447432,
           70.39331201458415,
           70.26088052469402,
           70.12844903480384,
           69.99601754491368,
           69.86358605502352,
           69.73115456513335,
           69.5987230752432,
           69.46629158535302,
           69.33386009546288,
           69.2014286055727,
           69.06899711568255,
           68.9365656257924,
           68.80413413590222,
           68.67170264601206,
           68.5392711561219,
           68.40683966623175,
           68.27440817634158,
           68.14197668645141,
           68.00954519656126,
           67.8771137066711,
           67.74468221678094,
           67.61225072689078,
           67.47981923700061,
           67.34738774711045,
           67.2149562572203,
           67.08252476733014,
           66.95009327743998,
           66.81766178754981,
           66.68523029765964,
           66.55279880776948,
           66.42036731787934,
           66.28793582798916,
           66.15550433809899,
           66.0590014032773,
           65.96249849248892,
           65.86599558170053,
           65.76949267091213,
           65.67298976012374,
           65.57648684933535,
           65.47998393854697,
           65.38348102775859,
           65.28697811697019,
           65.1904752061818,
           65.09397229539341,
           64.99746938460503,
           64.90096647381664,
           64.80446356302824,
           64.70796065223985,
           64.61145774145147,
           64.51495483066307,
           64.41845191987468,
           64.3219490090863,
           64.22544609829791,
           64.12894318750952,
           64.03244027672113,
           63.93593736593273,
           63.83943445514435,
           63.74293154435596,
           63.64642863356758,
           63.549925722779186,
           63.45342281199079,
           63.3569199012024,
           62.99472613192053,
           62.36684150414516,
           61.738956876369855,
           61.11107224859454,
           60.48318762081917,
           59.855302993043864,
           59.227418365268555,
           58.599533737493175,
           57.971649109717816,
           57.34376448194256,
           56.715879854167206,
           56.08799522639184,
           55.46011059861652,
           54.8322259708412,
           54.204341343065835,
           53.57645671529054,
           52.94857208751523,
           52.32068745973986,
           51.69280283196454,
           51.06204025694177,
           50.430296266588,
           49.798552276234226,
           49.166808285880585,
           48.53506429552681,
           47.90332030517304,
           47.271576314819335,
           46.63983232446562,
           46.00808833411185,
           45.376344343758134,
           44.74460035340443,
           44.11285636305066,
           43.48111237269689,
           42.84936838234323,
           42.21762439198947,
           41.58588040163569,
           40.95413641128199,
           40.322392420928274,
           39.69064843057451,
           39.0589044402208,
           38.42716044986708,
           37.79541645951332,
           37.16367246915961,
           36.53192847880589,
           35.90018448845213,
           35.268440498098364,
           34.63309796070176,
           33.99736106230173,
           33.361624163901695,
           32.72588726550171,
           32.09015036710173,
           31.4544134687017,
           30.818676570301708,
           30.182939671901735,
           29.547202773501695,
           28.911465875101655,
           28.275728976701732,
           27.637097001189638,
           26.99798416493266,
           26.35887132867574,
           25.719758492418816,
           25.080645656161842,
           24.44153281990492,
           24.37397130394576,
           24.517169211801523,
           24.660367119657284,
           24.80356502751305,
           24.94676293536883,
           25.089960843224596,
           25.23315875108035,
           25.37635665893613,
           25.519554566791903,
           25.66275247464766,
           25.805950382503422,
           25.949148290359208,
           26.09234619821497,
           26.23554410607073,
           26.378742013926495,
           26.521939921782256,
           26.665137829638017,
           26.8083357374938,
           26.951533645349578,
           27.094731553205342,
           27.2379294610611,
           27.38112736891687,
           27.524325276772636,
           27.667523184628394,
           27.810721092484176,
           27.953919000339937,
           28.097116908195698,
           28.24031481605147,
           28.38351272390725,
           28.52671063176299,
           28.669908539618767,
           28.813106447474546,
           28.95630435533031,
           29.099502263186075,
           29.24270017104185,
           29.385898078897608,
           29.529095986753372,
           29.672293894609147,
           29.815491802464912,
           29.95868971032067,
           30.101887618176445,
           30.24508552603222,
           30.388283433887985,
           30.531481341743746,
           30.67467924959952,
           30.817877157455282,
           30.961075065311043,
           31.104272973166818,
           31.21627080030727,
           30.92267035511624,
           30.62906990992528,
           30.335469464734278,
           30.041869019543295,
           29.74826857435229,
           29.45466812916133,
           29.161067683970334,
           28.867467238779366,
           28.57386679358834,
           28.28026634839739,
           27.98666590320642,
           27.69306545801541,
           27.399465012824447,
           27.105864567633432,
           26.81226412244247,
           26.518663677251464,
           26.227678093661964,
           25.937413850638904,
           25.647149607615802,
           25.356885364592706,
           25.066621121569614,
           24.77635687854655,
           24.486092635523455,
           24.19582839250038,
           23.905564149477257,
           23.615299906454155,
           23.32503566343109,
           23.034771420408028,
           22.7445071773849,
           22.458223123741135,
           22.172326522500743,
           21.886429921260262,
           21.600533320019874,
           21.31463671877944,
           21.028740117539023,
           20.742843516298606,
           20.45694691505818,
           20.171050313817755,
           19.885153712577313,
           19.602059709377464,
           19.321980624706732,
           19.04190154003601,
           18.7618224553653,
           18.48174337069462,
           18.201664286023878,
           17.921585201353203,
           17.641506116682486,
           17.36142703201178,
           17.08807090274644,
           16.815809207090933,
           16.54354751143537,
           16.271285815779805,
           15.99902412012424,
           15.72676242446872,
           15.454500728813157,
           15.187023461196446,
           14.922560383374588,
           14.658097305552703,
           14.39363422773079,
           14.129171149908956,
           13.86470807208707,
           13.603714386374007,
           13.347181349412478,
           13.090648312450924,
           12.834115275489372,
           12.577582238527857,
           12.322054548963145,
           12.074569631116216,
           11.827084713269308,
           11.579599795422451,
           11.332114877575556,
           11.089339055821423,
           10.851867163066293,
           10.614395270311116,
           10.376923377555928,
           10.143511461224271,
           9.916431176045839,
           9.689350890867406,
           9.46227060568902,
           9.242264615032,
           9.024296979500281,
           8.806329343968528,
           8.593488645176265,
           8.384811172814938,
           8.176133700453612,
           7.975387797153715,
           7.77877390926141,
           7.582751056963355,
           7.399287727824811,
           7.215824398686229,
           7.040506540977871,
           6.869110576423847,
           6.70338155693374,
           6.542981717705372,
           6.387996816976666,
           6.237639227980116,
           6.093915327538829,
           5.95314746289645,
           5.820327172405114,
           5.691451851482438,
           5.567089928391938,
           5.451205444294084,
           5.3426023076105,
           5.240059466331388,
           5.142776940087963,
           5.050542799369008,
           4.964820409710492,
           4.886103133945706,
           4.813872370146925,
           4.738292095709019,
           4.655844971177659,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           66.4657690994802,
           66.51470981047176,
           66.56365052146333,
           66.61259123245489,
           66.66153194344646,
           66.71047265443804,
           66.7594133654296,
           66.80835407642115,
           66.85729478741274,
           66.9062354984043,
           66.95517620939587,
           67.00411692038743,
           67.053057631379,
           67.10199834237056,
           67.15093905336214,
           67.19987976435371,
           67.24882047534527,
           67.29776118633683,
           67.34670189732842,
           67.39564260831997,
           67.44458331931153,
           67.4935240303031,
           67.54246474129468,
           67.59140545228624,
           67.64034616327781,
           67.68928687426937,
           67.73822758526094,
           67.7871682962525,
           67.83610900724408,
           67.88504971823565,
           67.93399042922721,
           67.98293114021877,
           68.03187185121034,
           68.08081256220191,
           68.12975327319349,
           68.17869398418505,
           68.22763469517662,
           68.27657540616818,
           68.32551611715975,
           68.37445682815132,
           68.42339753914288,
           68.47233825013446,
           68.52127896112601,
           68.57021967211759,
           68.61916038310915,
           68.66810109410072,
           68.7170418050923,
           68.76598251608387,
           68.81492322707543,
           68.863863938067,
           68.91280464905856,
           68.96174536005012,
           69.01068607104169,
           69.05962678203325,
           69.10856749302482,
           69.1575082040164,
           69.20644891500795,
           69.25538962599953,
           69.30433033699109,
           69.35327104798266,
           69.40255055894353,
           69.45250766846488,
           69.50246477798623,
           69.55242188750759,
           69.60237899702895,
           69.65233610655031,
           69.70229321607167,
           69.75225032559301,
           69.80220743511437,
           69.85216454463573,
           69.90212165415709,
           69.95207876367844,
           70.00203587319979,
           70.05199298272115,
           70.1019500922425,
           70.15190720176386,
           70.20186431128522,
           70.25182142080658,
           70.30177853032794,
           70.35173563984928,
           70.40169274937064,
           70.451649858892,
           70.50160696841334,
           70.5515640779347,
           70.58837284620735,
           70.62255194623026,
           70.65673104625316,
           70.69091014627605,
           70.72508924629896,
           70.75926834632186,
           70.79344744634477,
           70.82762654636767,
           70.86180564639058,
           70.89598474641348,
           70.93016384643639,
           70.96434294645928,
           70.9985220464822,
           71.03270114650509,
           71.066880246528,
           71.10105934655091,
           71.13523844657381,
           71.1694175465967,
           71.20359664661962,
           71.23777574664251,
           71.27195484666542,
           71.30613394668832,
           71.34031304671123,
           71.37402928185561,
           71.40681978536023,
           71.43961028886486,
           71.47240079236947,
           71.50519129587408,
           71.5379817993787,
           71.57077230288334,
           71.60356280638794,
           71.63635330989257,
           71.66914381339718,
           71.70193431690181,
           71.73472482040643,
           71.76751532391104,
           71.80030582741566,
           71.83309633092028,
           71.8658868344249,
           71.89867733792951,
           71.93146784143413,
           71.96425834493874,
           71.99704884844338,
           72.02983935194798,
           72.06262985545261,
           72.09542035895723,
           72.12821086246184,
           72.16100136596647,
           72.19379186947108,
           72.2265823729757,
           72.25937287648031,
           72.29216337998493,
           72.32495388348954,
           72.35774438699417,
           72.3905348904988,
           72.42332539400341,
           72.45611589750803,
           72.48890640101264,
           72.52169690451726,
           72.55448740802188,
           72.58727791152651,
           72.62006841503111,
           72.65285891853574,
           72.68564942204036,
           72.71843992554497,
           72.7512304290496,
           72.7840209325542,
           72.81681143605884,
           72.84960193956346,
           72.88239244306807,
           72.91518294657268,
           72.94797345007731,
           72.98076395358191,
           73.01355445708654,
           73.04634496059116,
           73.07913546409577,
           73.1119259676004,
           73.144716471105,
           73.17750697460964,
           73.21029747811426,
           73.24308798161887,
           73.27587848512349,
           73.30866898862811,
           73.23131149653621,
           73.09888000664604,
           72.96644851675588,
           72.83401702686572,
           72.70158553697556,
           72.5691540470854,
           72.43672255719524,
           72.30429106730507,
           72.17185957741492,
           72.03942808752475,
           71.90699659763459,
           71.77456510774444,
           71.64213361785427,
           71.50970212796412,
           71.37727063807395,
           71.24483914818379,
           71.11240765829362,
           70.97997616840345,
           70.8475446785133,
           70.71511318862315,
           70.58268169873297,
           70.45025020884282,
           70.31781871895265,
           70.18538722906248,
           70.05295573917233,
           69.92052424928217,
           69.78809275939201,
           69.65566126950185,
           69.52322977961168,
           69.39079828972153,
           69.25836679983136,
           69.12593530994121,
           68.99350382005105,
           68.86107233016088,
           68.72864084027071,
           68.59620935038055,
           68.4637778604904,
           68.33134637060024,
           68.19891488071008,
           68.06648339081991,
           67.93405190092976,
           67.8016204110396,
           67.66918892114944,
           67.53675743125928,
           67.40432594136911,
           67.27189445147894,
           67.13946296158879,
           67.00703147169862,
           66.87459998180847,
           66.7421684919183,
           66.60973700202814,
           66.47730551213799,
           66.34487402224782,
           66.21244253235766,
           66.0800110424675,
           65.94757955257735,
           65.81514806268719,
           65.68271657279702,
           65.55028508290685,
           65.41785359301669,
           65.28542210312654,
           65.15299061323637,
           65.02055912334622,
           64.88812763345605,
           64.7556961435659,
           64.62326465367573,
           64.49083316378557,
           64.3584016738954,
           64.22597018400523,
           64.09353869411508,
           63.96110720422492,
           63.828675714334764,
           63.6962442244446,
           63.56381273455443,
           63.448859961752134,
           63.35235705096375,
           63.255854140175344,
           63.159351229386964,
           63.062848318598576,
           62.96634540781019,
           62.8698424970218,
           62.773339586233405,
           62.67683667544501,
           62.31464290616314,
           61.686758278387764,
           61.05887365061247,
           60.43098902283715,
           59.80310439506179,
           59.17521976728647,
           58.54429804261686,
           57.91255405226308,
           57.28081006190933,
           56.64906607155568,
           56.01732208120189,
           55.38557809084813,
           54.75383410049442,
           54.12209011014072,
           53.49034611978694,
           52.85860212943324,
           52.226858139079525,
           51.59511414872575,
           50.96337015837203,
           50.33162616801833,
           49.69988217766456,
           49.06813818731078,
           48.43639419695714,
           47.80465020660338,
           47.1729062162496,
           46.54116222589589,
           45.90941823554218,
           45.27767424518841,
           44.645930254834695,
           44.01418626448099,
           43.38244227412722,
           42.750698283773445,
           42.11895429341979,
           41.48721030306603,
           40.85546631271225,
           40.223722322358554,
           39.591978332004835,
           38.95739986954689,
           38.321662971146914,
           37.68592607274694,
           37.0501891743469,
           36.41445227594692,
           35.778715377546945,
           35.1429784791469,
           34.507241580746864,
           33.871504682346945,
           33.235767783946905,
           32.60003088554687,
           31.96429398714689,
           31.328557088746912,
           30.691367694667818,
           30.052254858410897,
           29.413142022153984,
           28.774029185897,
           28.134916349640022,
           27.49580351338316,
           26.85669067712618,
           26.266695634867723,
           26.409893542723488,
           26.553091450579245,
           26.69628935843503,
           26.83948726629079,
           26.982685174146553,
           27.125883082002318,
           27.269080989858082,
           27.412278897713836,
           27.55547680556962,
           27.698674713425387,
           27.841872621281144,
           27.985070529136923,
           28.128268436992695,
           28.271466344848456,
           28.414664252704217,
           28.55786216056,
           28.70106006841576,
           28.84425797627152,
           28.987455884127286,
           29.130653791983047,
           29.27385169983881,
           29.417049607694594,
           29.56024751555037,
           29.703445423406134,
           29.846643331261895,
           29.989841239117663,
           30.133039146973427,
           30.276237054829192,
           30.419434962684967,
           30.56263287054073,
           30.705830778396493,
           30.84902868625226,
           30.99222659410804,
           31.135424501963787,
           31.278622409819558,
           31.421820317675344,
           31.565018225531105,
           31.708216133386866,
           31.85141404124264,
           31.994611949098402,
           32.13780985695416,
           32.28100776480994,
           32.42420567266571,
           32.567403580521464,
           32.710601488377236,
           32.497229102712,
           32.203628657520966,
           31.910028212330012,
           31.616427767139008,
           31.322827321948054,
           31.029226876757065,
           30.73562643156606,
           30.442025986375107,
           30.14842554118407,
           29.854825095993114,
           29.56122465080211,
           29.26762420561113,
           28.974023760420128,
           28.680423315229163,
           28.38682287003817,
           28.093222424847202,
           27.799621979656177,
           27.508095390334397,
           27.217831147311344,
           26.92756690428824,
           26.63730266126515,
           26.347038418242086,
           26.056774175218948,
           25.76650993219588,
           25.476245689172792,
           25.185981446149732,
           24.89571720312663,
           24.605452960103534,
           24.31518871708044,
           24.024924474057375,
           23.734801122377693,
           23.448904521137266,
           23.16300791989686,
           22.877111318656418,
           22.591214717416037,
           22.30531811617556,
           22.019421514935118,
           21.733524913694726,
           21.44762831245433,
           21.161731711213854,
           20.875835109973465,
           20.590065898358162,
           20.309986813687438,
           20.029907729016728,
           19.749828644346014,
           19.469749559675286,
           19.189670475004597,
           18.909591390333897,
           18.62951230566317,
           18.34943322099245,
           18.069354136321735,
           17.79646705044482,
           17.524205354789288,
           17.251943659133737,
           16.979681963478185,
           16.707420267822624,
           16.43515857216706,
           16.162896876511553,
           15.892740329143804,
           15.628277251321919,
           15.363814173500044,
           15.099351095678173,
           14.834888017856287,
           14.570424940034453,
           14.305961862212595,
           14.047446314225583,
           13.790913277264028,
           13.534380240302529,
           13.277847203340974,
           13.02131416637945,
           12.765930097799215,
           12.518445179952288,
           12.270960262105378,
           12.023475344258522,
           11.77599042641164,
           11.530785702538731,
           11.293313809783555,
           11.055841917028426,
           10.818370024273227,
           10.580898131518072,
           10.352996183827704,
           10.125915898649271,
           9.898835613470839,
           9.672714555327705,
           9.45474691979597,
           9.236779284264252,
           9.018811648732544,
           8.807358692168703,
           8.598681219807377,
           8.39000374744605,
           8.189115360850831,
           7.9925014729585415,
           7.795887585066238,
           7.610946664260236,
           7.427483335121655,
           7.248674561248599,
           7.077278596694609,
           6.907046044643998,
           6.7466462054156295,
           6.586443272684203,
           6.436085683687654,
           6.28667576473109,
           6.145478983366674,
           6.007108006174089,
           5.874287715682728,
           5.746976779299137,
           5.623709540573168,
           5.507825056475292,
           5.3996753370294535,
           5.296968377718975,
           5.199230470872045,
           5.106018178039822,
           5.01886938231552,
           4.938557498448778,
           4.864640837310965,
           4.793965455796959,
           4.711518331265615,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           66.56238971242888,
           66.61133042342044,
           66.660271134412,
           66.70921184540357,
           66.75815255639515,
           66.8070932673867,
           66.85603397837828,
           66.90497468936984,
           66.95391540036141,
           67.00285611135298,
           67.05179682234456,
           67.10073753333612,
           67.14967824432767,
           67.19861895531925,
           67.24755966631082,
           67.29650037730238,
           67.34544108829395,
           67.39438179928551,
           67.44332251027708,
           67.49226322126864,
           67.54120393226022,
           67.59014464325179,
           67.63908535424335,
           67.68802606523492,
           67.7369667762265,
           67.78590748721805,
           67.83484819820963,
           67.88378890920119,
           67.93272962019276,
           67.98167033118432,
           68.03061104217589,
           68.07955175316746,
           68.12849246415902,
           68.1774331751506,
           68.22637388614217,
           68.27531459713373,
           68.32425530812529,
           68.37319601911688,
           68.42213673010843,
           68.4710774411,
           68.52001815209157,
           68.56895886308314,
           68.6178995740747,
           68.66684028506627,
           68.71578099605783,
           68.7647217070494,
           68.81366241804096,
           68.86260312903254,
           68.91154384002411,
           68.96048455101567,
           69.00942526200724,
           69.0583659729988,
           69.10730668399037,
           69.15624739498193,
           69.2051881059735,
           69.25412881696508,
           69.30306952795664,
           69.35201023894821,
           69.40095094993978,
           69.44989166093134,
           69.4988323719229,
           69.54777308291447,
           69.59671379390605,
           69.6456545048976,
           69.69459521588918,
           69.74353592688075,
           69.79247663787231,
           69.84141734886389,
           69.89035805985544,
           69.93929877084702,
           69.98823948183858,
           70.03718019283015,
           70.08612090382171,
           70.13506161481328,
           70.18400232580485,
           70.23294303679643,
           70.28188374778799,
           70.33167145784606,
           70.3816285673674,
           70.43158567688876,
           70.48154278641013,
           70.53149989593147,
           70.58145700545282,
           70.63141411497418,
           70.66822288324683,
           70.70240198326974,
           70.73658108329263,
           70.77076018331555,
           70.80493928333844,
           70.83911838336134,
           70.87329748338425,
           70.90631942004039,
           70.939109923545,
           70.97190042704962,
           71.00469093055423,
           71.03748143405886,
           71.07027193756348,
           71.10306244106809,
           71.1358529445727,
           71.16864344807733,
           71.20143395158195,
           71.23422445508656,
           71.26701495859118,
           71.2998054620958,
           71.33259596560042,
           71.36538646910503,
           71.39817697260966,
           71.43096747611426,
           71.46375797961889,
           71.4965484831235,
           71.52933898662812,
           71.56212949013275,
           71.59491999363736,
           71.62771049714199,
           71.6605010006466,
           71.69329150415122,
           71.72608200765583,
           71.75887251116046,
           71.79166301466508,
           71.82445351816969,
           71.85724402167432,
           71.89003452517893,
           71.92282502868355,
           71.95561553218816,
           71.98840603569279,
           72.0211965391974,
           72.05398704270203,
           72.08677754620663,
           72.11956804971126,
           72.15235855321589,
           72.1851490567205,
           72.21793956022512,
           72.25073006372973,
           72.28352056723435,
           72.31631107073898,
           72.3491015742436,
           72.3818920777482,
           72.41468258125283,
           72.44747308475745,
           72.48026358826206,
           72.51305409176669,
           72.54584459527129,
           72.57863509877592,
           72.61142560228055,
           72.64421610578516,
           72.67700660928978,
           72.7097971127944,
           72.74258761629902,
           72.77537811980363,
           72.80816862330826,
           72.84095912681288,
           72.87374963031749,
           72.90654013382209,
           72.93933063732672,
           72.97212114083133,
           73.00491164433595,
           73.03770214784058,
           73.07049265134519,
           73.1032831548498,
           73.13607365835443,
           73.16886416185905,
           73.20165466536368,
           73.23444516886829,
           73.2672356723729,
           73.30002617587753,
           73.33281667938213,
           73.36560718288676,
           73.28824969079487,
           73.1558182009047,
           73.02338671101454,
           72.89095522112437,
           72.75852373123422,
           72.62609224134405,
           72.4936607514539,
           72.36122926156374,
           72.22879777167357,
           72.09636628178342,
           71.96393479189325,
           71.83150330200309,
           71.69907181211293,
           71.56664032222277,
           71.4342088323326,
           71.30177734244245,
           71.16934585255228,
           71.03691436266212,
           70.90448287277195,
           70.77205138288178,
           70.63961989299165,
           70.50718840310148,
           70.37475691321131,
           70.24232542332115,
           70.10989393343098,
           69.97746244354083,
           69.84503095365068,
           69.71259946376051,
           69.58016797387035,
           69.4477364839802,
           69.31530499409003,
           69.18287350419986,
           69.0504420143097,
           68.91801052441954,
           68.78557903452939,
           68.65314754463921,
           68.51241719257476,
           68.37064950866976,
           68.22888182476478,
           68.08711414085978,
           67.94534645695481,
           67.80357877304981,
           67.66181108914482,
           67.52004340523982,
           67.37827572133483,
           67.23650803742983,
           67.09474035352484,
           66.95297266961985,
           66.81120498571487,
           66.66943730180986,
           66.52766961790488,
           66.38590193399989,
           66.2441342500949,
           66.1023665661899,
           65.96059888228493,
           65.81883119837993,
           65.67706351447494,
           65.53529583056995,
           65.39352814666495,
           65.25176046275996,
           65.10999277885497,
           64.96822509494997,
           64.826457411045,
           64.68468972713998,
           64.54292204323501,
           64.40115435933002,
           64.25938667542503,
           64.11761899152003,
           63.97585130761503,
           63.83408362371005,
           63.692315939805056,
           63.55054825590007,
           63.408780571995074,
           63.26701288809008,
           63.12524520418509,
           62.983477520280104,
           62.8417098363751,
           62.699942152470115,
           62.55817446856512,
           62.41640678466014,
           62.274639100755145,
           62.13287141685015,
           61.991103732945156,
           61.60434789581579,
           60.97260390546204,
           60.34085991510833,
           59.70911592475461,
           59.07737193440084,
           58.44562794404714,
           57.81388395369343,
           57.182139963339644,
           56.55039597298589,
           55.918651982632234,
           55.28690799227845,
           54.65516400192469,
           54.023420011570984,
           53.39167602121728,
           52.7599320308635,
           52.128188040509784,
           51.49644405015608,
           50.86470005980231,
           50.23295606944859,
           49.60121207909489,
           48.969468088741124,
           48.33772409838734,
           47.7059801080337,
           47.07423611767994,
           46.44249212732616,
           45.81074813697245,
           45.17900414661874,
           44.54726015626497,
           43.91551616591126,
           43.28170177839214,
           42.64596487999209,
           42.01022798159207,
           41.37449108319215,
           40.738754184792114,
           40.103017286392074,
           39.46728038799208,
           38.831543489592114,
           38.19580659119207,
           37.56006969279209,
           36.924332794392114,
           36.288595895992074,
           35.6528589975921,
           35.01712209919212,
           34.38138520079208,
           33.745638388146,
           33.106525551889135,
           32.46741271563216,
           31.828299879375177,
           31.189187043118253,
           30.550074206861343,
           29.910961370604355,
           29.27184853434744,
           28.632735698090528,
           28.302617873645428,
           28.445815781501192,
           28.589013689356953,
           28.73221159721272,
           28.8754095050685,
           29.018607412924265,
           29.161805320780022,
           29.305003228635808,
           29.44820113649157,
           29.591399044347327,
           29.734596952203095,
           29.877794860058856,
           30.020992767914613,
           30.1641906757704,
           30.30738858362617,
           30.45058649148192,
           30.5937843993377,
           30.73698230719347,
           30.880180215049233,
           31.023378122904994,
           31.166576030760776,
           31.309773938616537,
           31.4529718464723,
           31.596169754328063,
           31.739367662183827,
           31.882565570039592,
           32.02576347789537,
           32.168961385751146,
           32.31215929360691,
           32.455357201462675,
           32.59855510931844,
           32.741753017174204,
           32.88495092502996,
           33.02814883288575,
           33.171346740741505,
           33.31454464859727,
           33.45774255645304,
           33.60094046430882,
           33.744138372164564,
           33.88733628002034,
           34.03053418787612,
           34.17373209573188,
           34.07178785030773,
           33.778187405116725,
           33.48458695992574,
           33.190986514734746,
           32.89738606954378,
           32.603785624352746,
           32.3101851791618,
           32.016584733970795,
           31.72298428877983,
           31.4293838435888,
           31.135783398397848,
           30.842182953206844,
           30.54858250801589,
           30.2549820628249,
           29.9613816176339,
           29.667781172442947,
           29.37418072725191,
           29.080580282060954,
           28.78851268700683,
           28.49824844398378,
           28.207984200960716,
           27.917719957937575,
           27.627455714914518,
           27.337191471891423,
           27.04692722886832,
           26.75666298584523,
           26.46639874282217,
           26.17613449979907,
           25.885870256775977,
           25.59560601375292,
           25.305341770729775,
           25.015077527706715,
           24.72548251977385,
           24.43958591853342,
           24.15368931729298,
           23.867792716052552,
           23.581896114812153,
           23.29599951357171,
           23.010102912331288,
           22.724206311090853,
           22.43830970985045,
           22.15241310861001,
           21.86651650736963,
           21.58061990612915,
           21.29799300266811,
           21.0179139179974,
           20.73783483332672,
           20.457755748655995,
           20.177676663985316,
           19.8975975793146,
           19.61751849464388,
           19.337439409973168,
           19.057360325302454,
           18.777281240631726,
           18.504863198143145,
           18.232601502487636,
           17.960339806832074,
           17.68807811117651,
           17.41581641552099,
           17.14355471986544,
           16.871293024209905,
           16.599031328554354,
           16.333994119269303,
           16.069531041447416,
           15.805067963625529,
           15.540604885803699,
           15.276141807981814,
           15.011678730159929,
           14.747711279038725,
           14.491178242077186,
           14.23464520511566,
           13.978112168154158,
           13.721579131192605,
           13.465046094231026,
           13.209805646635239,
           12.962320728788383,
           12.714835810941452,
           12.467350893094546,
           12.219865975247714,
           11.972381057400787,
           11.734760456500867,
           11.497288563745736,
           11.259816670990562,
           11.022344778235384,
           10.789561191609524,
           10.562480906431135,
           10.335400621252703,
           10.10832033607427,
           9.885196860091677,
           9.667229224559943,
           9.449261589028225,
           9.231293953496515,
           9.021228739161142,
           8.812551266799815,
           8.603873794438531,
           8.402842924547963,
           8.206229036655643,
           8.009615148763354,
           7.822605600695676,
           7.639142271557081,
           7.456842581519342,
           7.285446616965351,
           7.114050652411315,
           6.950310693125887,
           6.789910853897552,
           6.634532139395191,
           6.4841745503986115,
           6.338239420558937,
           6.197042639194547,
           6.061068549451704,
           5.928248258960343,
           5.802501707115861,
           5.680329152754391,
           5.564444668656515,
           5.456748366448427,
           5.353877289106555,
           5.255684001656115,
           5.161862368081817,
           5.074246388187799,
           4.9926064710538025,
           4.916852626475351,
           4.846695880130576,
           4.767191691353555,
           4.684744566822194,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           66.64846887130173,
           66.6974095822933,
           66.74635029328486,
           66.79529100427644,
           66.84423171526801,
           66.89317242625957,
           66.94211313725114,
           66.9910538482427,
           67.03999455923427,
           67.08893527022585,
           67.1378759812174,
           67.18681669220896,
           67.23575740320055,
           67.28469811419211,
           67.33363882518368,
           67.38257953617524,
           67.43152024716682,
           67.48046095815837,
           67.52940166914995,
           67.57834238014152,
           67.62728309113308,
           67.67622380212464,
           67.72516451311621,
           67.77410522410779,
           67.82304593509934,
           67.87198664609092,
           67.92092735708249,
           67.96986806807405,
           68.01880877906562,
           68.06774949005718,
           68.11669020104875,
           68.16563091204031,
           68.21457162303189,
           68.26351233402346,
           68.31245304501502,
           68.36139375600659,
           68.41033446699817,
           68.45927517798972,
           68.5082158889813,
           68.55715659997286,
           68.60609731096443,
           68.655038021956,
           68.70397873294756,
           68.75291944393913,
           68.8018601549307,
           68.85080086592227,
           68.89974157691384,
           68.9486822879054,
           68.99762299889696,
           69.04656370988853,
           69.0955044208801,
           69.14444513187166,
           69.19338584286324,
           69.2423265538548,
           69.29126726484637,
           69.34020797583793,
           69.3891486868295,
           69.43808939782107,
           69.48703010881263,
           69.5359708198042,
           69.58491153079576,
           69.63385224178734,
           69.68279295277891,
           69.73173366377047,
           69.78067437476204,
           69.82961508575362,
           69.87855579674518,
           69.92749650773675,
           69.97643721872831,
           70.02537792971987,
           70.07431864071144,
           70.123259351703,
           70.17220006269457,
           70.22114077368614,
           70.26995613095289,
           70.31852078063238,
           70.36708543031189,
           70.4156500799914,
           70.4642147296709,
           70.5127793793504,
           70.56134402902991,
           70.6099086787094,
           70.65847332838892,
           70.70703797806841,
           70.74074327235773,
           70.77147669556902,
           70.80221011878031,
           70.83294354199158,
           70.86367696520287,
           70.89441038841414,
           70.92514381162543,
           70.95587723483672,
           70.986610658048,
           71.01802977494127,
           71.0508202784459,
           71.08361078195051,
           71.11640128545513,
           71.14919178895974,
           71.18198229246438,
           71.214772795969,
           71.2475632994736,
           71.28035380297823,
           71.31314430648284,
           71.34593480998747,
           71.37872531349208,
           71.4115158169967,
           71.44430632050131,
           71.47709682400593,
           71.50988732751055,
           71.54267783101517,
           71.57546833451978,
           71.6082588380244,
           71.64104934152903,
           71.67383984503365,
           71.70663034853825,
           71.73942085204288,
           71.7722113555475,
           71.80500185905213,
           71.83779236255674,
           71.87058286606135,
           71.90337336956597,
           71.9361638730706,
           71.96895437657521,
           72.00174488007983,
           72.03453538358445,
           72.06732588708907,
           72.10011639059368,
           72.1329068940983,
           72.16569739760293,
           72.19848790110754,
           72.23127840461217,
           72.26406890811677,
           72.2968594116214,
           72.32964991512601,
           72.36244041863063,
           72.39523092213526,
           72.42802142563987,
           72.46081192914448,
           72.49360243264911,
           72.52639293615373,
           72.55918343965834,
           72.59197394316297,
           72.62476444666758,
           72.6575549501722,
           72.69034545367683,
           72.72313595718144,
           72.75592646068606,
           72.78871696419067,
           72.82150746769528,
           72.85429797119991,
           72.88708847470454,
           72.91987897820914,
           72.95266948171377,
           72.98545998521838,
           73.01825048872301,
           73.05104099222763,
           73.08383149573224,
           73.11662199923686,
           73.14941250274148,
           73.1822030062461,
           73.21499350975071,
           73.24778401325533,
           73.28057451675994,
           73.31336502026457,
           73.34615552376918,
           73.37894602727381,
           73.41173653077843,
           73.30790249786536,
           73.13575619674344,
           72.96360989562154,
           72.79146359449962,
           72.61931729337772,
           72.4471709922558,
           72.2750246911339,
           72.10287839001198,
           71.93073208889007,
           71.75858578776815,
           71.58643948664624,
           71.41429318552434,
           71.24214688440243,
           71.07000058328052,
           70.90089214956113,
           70.75912446565614,
           70.61735678175114,
           70.47558909784615,
           70.33382141394117,
           70.19205373003618,
           70.05028604613119,
           69.90851836222619,
           69.7667506783212,
           69.6249829944162,
           69.48321531051121,
           69.34144762660623,
           69.19967994270124,
           69.05791225879625,
           68.91614457489126,
           68.77437689098626,
           68.63260920708127,
           68.49084152317627,
           68.34907383927128,
           68.2073061553663,
           68.06553847146131,
           67.92377078755631,
           67.78200310365132,
           67.64023541974633,
           67.49846773584134,
           67.35670005193634,
           67.21493236803137,
           67.07316468412637,
           66.93139700022138,
           66.78962931631638,
           66.64786163241139,
           66.50609394850639,
           66.3643262646014,
           66.22255858069643,
           66.08079089679143,
           65.93902321288644,
           65.79725552898144,
           65.65548784507645,
           65.51372016117148,
           65.37195247726646,
           65.23018479336147,
           65.08841710945649,
           64.9466494255515,
           64.80488174164651,
           64.6631140577415,
           64.52134637383651,
           64.37957868993153,
           64.23781100602653,
           64.09604332212155,
           63.954275638216544,
           63.81250795431157,
           63.670740270406576,
           63.52897258650158,
           63.38720490259659,
           63.24543721869159,
           63.10366953478661,
           62.96190185088162,
           62.82013416697662,
           62.67836648307163,
           62.53659879916664,
           62.39483111526165,
           62.25306343135666,
           62.11129574745166,
           61.969528063546676,
           61.82776037964169,
           61.685992695736694,
           61.5442250118317,
           61.402457327926705,
           61.260689644021724,
           60.87393380689236,
           60.2421898165386,
           59.61044582618489,
           58.97870183583117,
           58.3469578454774,
           57.7152138551237,
           57.08346986476999,
           56.4517258744162,
           55.81998188406245,
           55.188237893708795,
           54.55649390335501,
           53.92474991300124,
           53.29300592264754,
           52.66126193229384,
           52.029517941940064,
           51.39777395158636,
           50.76602996123265,
           50.13428597087887,
           49.50254198052515,
           48.870797990171454,
           48.239053999817685,
           47.606003687237276,
           46.97026678883735,
           46.3345298904373,
           45.698792992037276,
           45.06305609363728,
           44.427319195237324,
           43.79158229683728,
           43.155845398437286,
           42.52010850003732,
           41.88437160163727,
           41.248634703237244,
           40.612897804837324,
           39.97716090643729,
           39.34142400803725,
           38.70568710963726,
           38.06995021123729,
           37.434213312837244,
           36.798476414437275,
           36.160796245367315,
           35.52168340911034,
           34.88257057285342,
           34.24345773659649,
           33.60434490033951,
           32.96523206408254,
           32.32611922782568,
           31.687006391568694,
           31.047893555311717,
           30.408780719054796,
           30.33854011242313,
           30.48173802027891,
           30.624935928134672,
           30.768133835990433,
           30.911331743846215,
           31.054529651701984,
           31.19772755955774,
           31.34092546741351,
           31.48412337526929,
           31.62732128312505,
           31.770519190980814,
           31.913717098836592,
           32.05691500669236,
           32.200112914548114,
           32.343310822403886,
           32.486508730259644,
           32.62970663811541,
           32.77290454597119,
           32.91610245382696,
           33.05930036168271,
           33.202498269538495,
           33.34569617739426,
           33.488894085250024,
           33.63209199310579,
           33.77528990096156,
           33.918487808817325,
           34.06168571667308,
           34.204883624528854,
           34.34808153238462,
           34.491279440240376,
           34.634477348096155,
           34.77767525595194,
           34.9208731638077,
           35.06407107166346,
           35.20726897951923,
           35.35046688737499,
           35.49366479523076,
           35.636862703086535,
           35.64634659790342,
           35.35274615271246,
           35.05914570752146,
           34.76554526233046,
           34.471944817139516,
           34.17834437194851,
           33.88474392675747,
           33.59114348156652,
           33.297543036375565,
           33.00394259118457,
           32.71034214599357,
           32.416741700802575,
           32.123141255611614,
           31.829540810420585,
           31.535940365229635,
           31.24233992003863,
           30.94873947484767,
           30.655139029656635,
           30.361538584465684,
           30.068929983679304,
           29.77866574065621,
           29.48840149763312,
           29.198137254610057,
           28.90787301158696,
           28.6176087685639,
           28.327344525540763,
           28.037080282517657,
           27.74681603949461,
           27.456551796471548,
           27.166287553448406,
           26.876023310425346,
           26.585759067402254,
           26.29549482437915,
           26.005230581356052,
           25.71616391717001,
           25.430267315929576,
           25.144370714689146,
           24.858474113448715,
           24.572577512208273,
           24.286680910967867,
           24.000784309727436,
           23.71488770848701,
           23.42899110724657,
           23.143094506006143,
           22.857197904765744,
           22.571301303525306,
           22.28599919164883,
           22.005920106978113,
           21.72584102230739,
           21.445761937636664,
           21.165682852966,
           20.885603768295272,
           20.60552468362455,
           20.325445598953838,
           20.04536651428316,
           19.76528742961243,
           19.485521041497076,
           19.21325934584155,
           18.940997650185988,
           18.66873595453044,
           18.39647425887492,
           18.124212563219324,
           17.85195086756376,
           17.579689171908257,
           17.30742747625269,
           17.039710987216633,
           16.77524790939479,
           16.510784831572916,
           16.24632175375103,
           15.981858675929157,
           15.717395598107313,
           15.452932520285426,
           15.191443206890316,
           14.934910169928816,
           14.678377132967261,
           14.42184409600571,
           14.165311059044168,
           13.908778022082629,
           13.653681195471313,
           13.406196277624456,
           13.158711359777527,
           12.911226441930644,
           12.663741524083736,
           12.416256606236882,
           12.176207103218177,
           11.938735210463024,
           11.701263317707872,
           11.463791424952696,
           11.226319532197516,
           10.999045914213,
           10.771965629034568,
           10.544885343856135,
           10.317805058677703,
           10.097679164855666,
           9.879711529323934,
           9.661743893792181,
           9.443776258514925,
           9.235098786153598,
           9.026421313792273,
           8.817743841430987,
           8.61657048824508,
           8.419956600352776,
           8.22334271246051,
           8.034264537131088,
           7.850801207992522,
           7.667337878853926,
           7.493614637236081,
           7.322218672682044,
           7.153975180836146,
           6.99357534160781,
           6.833175502379442,
           6.6826210061061495,
           6.5322634171096,
           6.389803076386819,
           6.248606295022393,
           6.115029092729319,
           5.983025002683611,
           5.8580266349325605,
           5.736948764935607,
           5.621064280837754,
           5.513821395867382,
           5.41078620049413,
           5.312137532440192,
           5.218315898865881,
           5.129721766858607,
           5.0466554436588416,
           4.9693069908573415,
           4.89746434729462,
           4.822865051441495,
           4.740417926910149,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           66.72678064254269,
           66.77572135353427,
           66.82466206452582,
           66.87360277551738,
           66.92254348650896,
           66.97148419750053,
           67.02042490849209,
           67.06936561948366,
           67.11830633047524,
           67.1672470414668,
           67.21618775245837,
           67.26512846344993,
           67.3140691744415,
           67.36300988543306,
           67.41195059642465,
           67.4608913074162,
           67.50983201840776,
           67.55877272939932,
           67.60771344039091,
           67.65665415138247,
           67.70559486237404,
           67.7545355733656,
           67.80347628435717,
           67.85241699534875,
           67.9013577063403,
           67.95029841733188,
           67.99923912832344,
           68.04817983931501,
           68.09712055030658,
           68.14606126129814,
           68.1950019722897,
           68.24394268328128,
           68.29288339427285,
           68.34182410526442,
           68.39076481625598,
           68.43970552724755,
           68.48864623823911,
           68.53758694923067,
           68.58652766022226,
           68.63546837121382,
           68.68440908220538,
           68.73334979319695,
           68.78229050418851,
           68.83123121518008,
           68.88017192617164,
           68.92911263716321,
           68.97805334815479,
           69.02699405914636,
           69.07593477013792,
           69.1248754811295,
           69.17381619212105,
           69.22275690311263,
           69.27169761410418,
           69.32063832509574,
           69.36957903608733,
           69.41851974707889,
           69.46746045807046,
           69.51640116906202,
           69.56502849561069,
           69.6135931452902,
           69.66215779496969,
           69.71072244464919,
           69.7592870943287,
           69.8078517440082,
           69.85641639368771,
           69.90498104336721,
           69.95354569304672,
           70.00211034272621,
           70.05067499240572,
           70.09923964208522,
           70.14780429176473,
           70.19636894144423,
           70.24493359112374,
           70.29349824080325,
           70.34206289048274,
           70.39062754016224,
           70.43919218984175,
           70.48775683952125,
           70.53632148920076,
           70.58488613888025,
           70.63345078855977,
           70.68201543823926,
           70.73058008791877,
           70.77914473759827,
           70.81285003188758,
           70.84358345509887,
           70.87431687831015,
           70.90505030152144,
           70.93578372473272,
           70.966517147944,
           70.99725057115529,
           71.02798399436656,
           71.05871741757785,
           71.08945084078914,
           71.12018426400041,
           71.1509176872117,
           71.18165111042299,
           71.21238453363426,
           71.24311795684555,
           71.27385138005684,
           71.30458480326811,
           71.3353182264794,
           71.36605164969069,
           71.39678507290196,
           71.42751849611325,
           71.45825191932454,
           71.48898534253583,
           71.5197187657471,
           71.55045218895839,
           71.58118561216966,
           71.61363326887019,
           71.6464237723748,
           71.67921427587942,
           71.71200477938405,
           71.74479528288866,
           71.77758578639327,
           71.8103762898979,
           71.84316679340252,
           71.87595729690713,
           71.90874780041175,
           71.94153830391636,
           71.97432880742099,
           72.0071193109256,
           72.03990981443022,
           72.07270031793485,
           72.10549082143946,
           72.13828132494409,
           72.1710718284487,
           72.20386233195332,
           72.23665283545793,
           72.26944333896255,
           72.30223384246717,
           72.33502434597179,
           72.36781484947642,
           72.40060535298103,
           72.43339585648565,
           72.46618635999026,
           72.49897686349487,
           72.5317673669995,
           72.56455787050412,
           72.59734837400873,
           72.63013887751336,
           72.66292938101797,
           72.69571988452259,
           72.72851038802722,
           72.76130089153183,
           72.79409139503645,
           72.82688189854107,
           72.85967240204569,
           72.8924629055503,
           72.92525340905493,
           72.95804391255953,
           72.99083441606416,
           73.02362491956879,
           73.0564154230734,
           73.08920592657802,
           73.12199643008263,
           73.15478693358725,
           73.18757743709187,
           73.22036794059649,
           73.2531584441011,
           73.28594894760573,
           73.31873945111035,
           73.35152995461496,
           73.38432045811959,
           73.4171109616242,
           73.44990146512882,
           73.34606743221575,
           73.17392113109385,
           73.00177482997194,
           72.82962852885001,
           72.65748222772811,
           72.4853359266062,
           72.31318962548428,
           72.14104332436239,
           71.96889702324046,
           71.79675072211856,
           71.62460442099665,
           71.45245811987473,
           71.28031181875284,
           71.10816551763091,
           70.93601921650901,
           70.7638729153871,
           70.59172661426518,
           70.41958031314327,
           70.24743401202136,
           70.07528771089946,
           69.90314140977755,
           69.73099510865563,
           69.55884880753374,
           69.38670250641181,
           69.21455620528991,
           69.04240990416798,
           68.87026360304608,
           68.69811730192417,
           68.52597100080224,
           68.35382469968035,
           68.18167839855843,
           68.00953209743653,
           67.83738579631462,
           67.66523949519271,
           67.4930931940708,
           67.32094689294888,
           67.14880059182697,
           66.97665429070506,
           66.80450798958316,
           66.63236168846123,
           66.4845182791079,
           66.3427505952029,
           66.20098291129791,
           66.05921522739291,
           65.91744754348792,
           65.77567985958294,
           65.63391217567795,
           65.49214449177296,
           65.35037680786796,
           65.20860912396297,
           65.06684144005797,
           64.92507375615298,
           64.783306072248,
           64.641538388343,
           64.49977070443802,
           64.35800302053303,
           64.21623533662803,
           64.07446765272304,
           63.93269996881804,
           63.790932284913055,
           63.64916460100807,
           63.50739691710307,
           63.36562923319808,
           63.22386154929308,
           63.0820938653881,
           62.94032618148311,
           62.798558497578114,
           62.656790813673126,
           62.51502312976813,
           62.37325544586315,
           62.23148776195815,
           62.08972007805316,
           61.94795239414817,
           61.80618471024317,
           61.664417026338185,
           61.5226493424332,
           61.380881658528196,
           61.23911397462321,
           61.09734629071822,
           60.95557860681323,
           60.81381092290823,
           60.672043239003244,
           60.53027555509824,
           60.143519717968886,
           59.51177572761513,
           58.880031737261426,
           58.24828774690771,
           57.61654375655393,
           56.98479976620023,
           56.35305577584652,
           55.72131178549274,
           55.08956779513898,
           54.45782380478533,
           53.826079814431544,
           53.19433582407778,
           52.56259183372408,
           51.930305596082476,
           51.29456869768246,
           50.65883179928247,
           50.02309490088248,
           49.38735800248246,
           48.751621104082474,
           48.115884205682505,
           47.48014730728246,
           46.84441040888243,
           46.2086735104825,
           45.57293661208245,
           44.93719971368242,
           44.30146281528243,
           43.66572591688247,
           43.029989018482425,
           42.394252120082434,
           41.758515221682465,
           41.12277832328242,
           40.48704142488239,
           39.85130452648247,
           39.21506693884545,
           38.57595410258849,
           37.93684126633156,
           37.29772843007465,
           36.65861559381766,
           36.019502757560744,
           35.38038992130383,
           34.741277085046846,
           34.10216424878993,
           33.463051412533005,
           32.82393857627603,
           32.231264443345204,
           32.37446235120094,
           32.517660259056726,
           32.66085816691249,
           32.804056074768255,
           32.94725398262401,
           33.0904518904798,
           33.233649798335556,
           33.37684770619132,
           33.5200456140471,
           33.663243521902864,
           33.80644142975862,
           33.94963933761439,
           34.09283724547017,
           34.236035153325936,
           34.3792330611817,
           34.52243096903747,
           34.66562887689324,
           34.808826784749,
           34.95202469260476,
           35.095222600460524,
           35.23842050831629,
           35.38161841617207,
           35.52481632402784,
           35.668014231883596,
           35.81121213973937,
           35.95441004759514,
           36.097607955450904,
           36.24080586330667,
           36.38400377116245,
           36.527201679018205,
           36.67039958687398,
           36.813597494729734,
           36.9567954025855,
           37.099993310441256,
           37.220905345499105,
           36.92730490030811,
           36.633704455117154,
           36.340104009926165,
           36.04650356473516,
           35.75290311954421,
           35.45930267435321,
           35.165702229162214,
           34.87210178397122,
           34.57850133878027,
           34.28490089358926,
           33.99130044839826,
           33.697700003207316,
           33.40409955801632,
           33.11049911282528,
           32.81689866763433,
           32.52329822244337,
           32.22969777725237,
           31.93609733206138,
           31.642496886870386,
           31.349347280351715,
           31.05908303732866,
           30.768818794305567,
           30.47855455128246,
           30.188290308259358,
           29.8980260652363,
           29.60776182221321,
           29.317497579190103,
           29.027233336167008,
           28.736969093143916,
           28.446704850120852,
           28.156440607097757,
           27.8661763640747,
           27.57591212105156,
           27.285647878028456,
           26.99538363500541,
           26.706845314566067,
           26.42094871332563,
           26.13505211208523,
           25.849155510844838,
           25.56325890960436,
           25.277362308363976,
           24.991465707123574,
           24.705569105883136,
           24.41967250464271,
           24.133775903402277,
           23.847879302161836,
           23.561982700921433,
           23.276086099681002,
           22.993926295958758,
           22.713847211288034,
           22.43376812661732,
           22.15368904194664,
           21.873609957275914,
           21.59353087260524,
           21.31345178793452,
           21.0333727032638,
           20.753293618593077,
           20.47321453392241,
           20.19391718919541,
           19.921655493539852,
           19.649393797884304,
           19.37713210222878,
           19.104870406573216,
           18.83260871091767,
           18.560347015262145,
           18.288085319606584,
           18.015823623951032,
           17.745427855163992,
           17.48096477734211,
           17.21650169952025,
           16.952038621698392,
           16.68757554387653,
           16.42311246605462,
           16.158649388232774,
           15.8941863104109,
           15.6351751347419,
           15.37864209778036,
           15.122109060818847,
           14.865576023857267,
           14.60904298689574,
           14.352509949934241,
           14.097556744307363,
           13.850071826460455,
           13.602586908613587,
           13.355101990766695,
           13.107617072919789,
           12.86013215507293,
           12.617653749935489,
           12.380181857180292,
           12.142709964425112,
           11.905238071669984,
           11.667766178914807,
           11.435610921994824,
           11.208530636816416,
           10.981450351637983,
           10.754370066459572,
           10.528129105151354,
           10.31016146961962,
           10.092193834087887,
           9.874226198556153,
           9.657646305507331,
           9.448968833146004,
           9.240291360784695,
           9.03161388842341,
           8.830298051942181,
           8.63368416404986,
           8.437070276157597,
           8.245923473566517,
           8.062460144427922,
           7.878996815289392,
           7.701782657506786,
           7.530386692952774,
           7.35899072839875,
           7.197239829318068,
           7.0368399900897,
           6.881067461813678,
           6.730709872817129,
           6.582563513579064,
           6.4413667322146555,
           6.301809926498313,
           6.168989636006961,
           6.038549930500302,
           5.9135515627492605,
           5.79356837711684,
           5.677683893018964,
           5.570894425286328,
           5.467695111881717,
           5.3687081612664445,
           5.274769429649946,
           5.185197145529427,
           5.100704416263861,
           5.02176135523931,
           4.948232814458675,
           4.878538411529448,
           4.796091286998086,
           4.713644162466727,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           66.80509241378365,
           66.85403312477521,
           66.90297383576677,
           66.95191454675835,
           67.00085525774992,
           67.04979596874148,
           67.09873667973305,
           67.14767739072461,
           67.19661810171618,
           67.24555881270776,
           67.29449952369932,
           67.34344023469089,
           67.39238094568245,
           67.44132165667402,
           67.4902623676656,
           67.53920307865715,
           67.58814378964873,
           67.63708450064028,
           67.68602521163186,
           67.73496592262342,
           67.783906633615,
           67.83284734460656,
           67.88178805559812,
           67.9307287665897,
           67.97966947758125,
           68.02861018857283,
           68.0775508995644,
           68.12649161055596,
           68.17543232154753,
           68.22437303253909,
           68.27331374353066,
           68.32225445452224,
           68.3711951655138,
           68.42013587650537,
           68.46907658749693,
           68.5180172984885,
           68.56695800948006,
           68.61589872047163,
           68.66483943146321,
           68.71378014245477,
           68.76272085344634,
           68.81153621058898,
           68.86010086026847,
           68.90866550994798,
           68.95723015962749,
           69.00579480930698,
           69.0543594589865,
           69.10292410866599,
           69.1514887583455,
           69.20005340802501,
           69.2486180577045,
           69.29718270738402,
           69.3457473570635,
           69.39431200674301,
           69.44287665642253,
           69.49144130610202,
           69.54000595578154,
           69.58857060546102,
           69.63713525514052,
           69.68569990482004,
           69.73426455449953,
           69.78282920417905,
           69.83139385385854,
           69.87995850353805,
           69.92852315321755,
           69.97708780289706,
           70.02565245257657,
           70.07421710225606,
           70.12278175193556,
           70.17134640161507,
           70.21991105129457,
           70.26847570097408,
           70.31704035065357,
           70.36560500033309,
           70.41416965001258,
           70.46273429969209,
           70.5112989493716,
           70.5598635990511,
           70.6084282487306,
           70.6569928984101,
           70.70555754808962,
           70.7541221977691,
           70.80268684744861,
           70.85125149712812,
           70.88495679141744,
           70.91569021462871,
           70.94642363784,
           70.97715706105129,
           71.00789048426256,
           71.03862390747385,
           71.06935733068512,
           71.10009075389641,
           71.1308241771077,
           71.16155760031899,
           71.19229102353026,
           71.22302444674155,
           71.25375786995284,
           71.28449129316411,
           71.3152247163754,
           71.34595813958668,
           71.37669156279796,
           71.40742498600925,
           71.43815840922053,
           71.46889183243181,
           71.4996252556431,
           71.53035867885438,
           71.56109210206566,
           71.59182552527695,
           71.62255894848823,
           71.65329237169952,
           71.6840257949108,
           71.71475921812208,
           71.74549264133336,
           71.77622606454464,
           71.80695948775593,
           71.8376929109672,
           71.8684263341785,
           71.89915975738977,
           71.92989318060106,
           71.96062660381234,
           71.99136002702362,
           72.02209345023492,
           72.0528268734462,
           72.08356029665748,
           72.11429371986877,
           72.14502714308004,
           72.17644625929448,
           72.2092367627991,
           72.24202726630371,
           72.27481776980834,
           72.30760827331295,
           72.34039877681758,
           72.3731892803222,
           72.4059797838268,
           72.43877028733142,
           72.47156079083604,
           72.50435129434067,
           72.53714179784528,
           72.5699323013499,
           72.60272280485451,
           72.63551330835914,
           72.66830381186375,
           72.70109431536837,
           72.73388481887298,
           72.76667532237761,
           72.79946582588222,
           72.83225632938685,
           72.86504683289147,
           72.89783733639608,
           72.93062783990071,
           72.96341834340532,
           72.99620884690994,
           73.02899935041455,
           73.06178985391918,
           73.0945803574238,
           73.12737086092841,
           73.16016136443304,
           73.19295186793765,
           73.22574237144227,
           73.25853287494688,
           73.29132337845151,
           73.32411388195612,
           73.35690438546075,
           73.38969488896535,
           73.42248539246998,
           73.4552758959746,
           73.48806639947921,
           73.38423236656614,
           73.21208606544424,
           73.03993976432233,
           72.86779346320041,
           72.69564716207852,
           72.52350086095659,
           72.35135455983469,
           72.17920825871278,
           72.00706195759086,
           71.83491565646895,
           71.66276935534704,
           71.49062305422513,
           71.31847675310323,
           71.1463304519813,
           70.9741841508594,
           70.8020378497375,
           70.62989154861557,
           70.45774524749366,
           70.28559894637175,
           70.11345264524985,
           69.94130634412794,
           69.76916004300602,
           69.59701374188411,
           69.4248674407622,
           69.2527211396403,
           69.08057483851839,
           68.90842853739647,
           68.73628223627458,
           68.56413593515265,
           68.39198963403074,
           68.21984333290884,
           68.04769703178692,
           67.87555073066503,
           67.7034044295431,
           67.53125812842119,
           67.35911182729927,
           67.18696552617736,
           67.01481922505546,
           66.84267292393355,
           66.67052662281164,
           66.49838032168974,
           66.32623402056782,
           66.15408771944591,
           65.981941418324,
           65.80979511720207,
           65.63764881608017,
           65.46550251495827,
           65.29335621383636,
           65.12120991271445,
           64.94906361159254,
           64.77691731047062,
           64.60477100934871,
           64.4326247082268,
           64.2604784071049,
           64.08833210598299,
           63.91618580486107,
           63.74403950373916,
           63.57189320261725,
           63.399746901495334,
           63.22760060037342,
           63.05545429925152,
           62.88330799812961,
           62.7111616970077,
           62.539015395885784,
           62.36686909476387,
           62.20991209255966,
           62.06814440865468,
           61.92637672474968,
           61.784609040844686,
           61.6428413569397,
           61.50107367303471,
           61.359305989129716,
           61.21753830522473,
           61.075770621319734,
           60.934002937414746,
           60.79223525350975,
           60.65046756960476,
           60.50869988569977,
           60.36693220179478,
           60.22516451788978,
           60.08339683398479,
           59.9416291500798,
           59.79986146617481,
           59.41310562904545,
           58.781361638691685,
           58.14961764833798,
           57.51787365798426,
           56.88612966763049,
           56.254385677276794,
           55.618870606527686,
           54.98313370812767,
           54.34739680972761,
           53.71165991132769,
           53.075923012927674,
           52.44018611452761,
           51.80444921612765,
           51.16871231772766,
           50.532975419327634,
           49.897238520927644,
           49.26150162252765,
           48.625764724127635,
           47.99002782572765,
           47.35429092732768,
           46.718554028927635,
           46.0828171305276,
           45.44708023212768,
           44.81134333372763,
           44.175606435327595,
           43.539869536927604,
           42.90413263852765,
           42.2683957401276,
           41.63022479606672,
           40.99111195980979,
           40.35199912355284,
           39.71288628729585,
           39.073773451038996,
           38.434660614782,
           37.795547778525034,
           37.156434942268106,
           36.51732210601119,
           35.8782092697542,
           35.23909643349729,
           34.599983597240374,
           34.267186682122905,
           34.41038458997867,
           34.55358249783443,
           34.6967804056902,
           34.839978313545984,
           34.98317622140172,
           35.1263741292575,
           35.26957203711327,
           35.412769944969035,
           35.55596785282479,
           35.69916576068057,
           35.842363668536336,
           35.985561576392094,
           36.12875948424788,
           36.271957392103644,
           36.415155299959395,
           36.55835320781517,
           36.70155111567095,
           36.84474902352671,
           36.987946931382474,
           37.13114483923826,
           37.27434274709401,
           37.417540654949775,
           37.56073856280555,
           37.70393647066131,
           37.84713437851706,
           37.990332286372855,
           38.13353019422861,
           38.27672810208436,
           38.419926009940156,
           38.56312391779592,
           38.706321825651685,
           38.50186364790384,
           38.208263202712885,
           37.91466275752189,
           37.6210623123309,
           37.32746186713989,
           37.03386142194894,
           36.740260976757995,
           36.44666053156695,
           36.153060086375945,
           35.85945964118499,
           35.565859195994,
           35.272258750803,
           34.97865830561204,
           34.68505786042105,
           34.39145741523005,
           34.09785697003906,
           33.80425652484811,
           33.5106560796571,
           33.2170556344661,
           32.92345518927516,
           32.629854744084156,
           32.33950033400109,
           32.049236090978,
           31.7589718479549,
           31.468707604931794,
           31.178443361908702,
           30.888179118885688,
           30.597914875862546,
           30.307650632839486,
           30.01738638981639,
           29.72712214679329,
           29.436857903770186,
           29.146593660747133,
           28.856329417724037,
           28.56606517470093,
           28.27580093167784,
           27.985536688654747,
           27.697526711962226,
           27.41163011072179,
           27.125733509481368,
           26.83983690824096,
           26.553940307000524,
           26.26804370576014,
           25.98214710451966,
           25.696250503279224,
           25.410353902038825,
           25.124457300798433,
           24.83856069955796,
           24.552664098317564,
           24.266767497077172,
           23.981932484939463,
           23.701853400268753,
           23.42177431559807,
           23.141695230927347,
           22.861616146256623,
           22.581537061585912,
           22.3014579769152,
           22.021378892244474,
           21.741299807573764,
           21.461220722903082,
           21.181141638232358,
           20.902313336893783,
           20.630051641238232,
           20.35778994558267,
           20.08552824992714,
           19.8132665542716,
           19.541004858616034,
           19.268743162960476,
           18.996481467304925,
           18.724219771649402,
           18.451958075993844,
           18.18668164528948,
           17.922218567467638,
           17.657755489645748,
           17.393292411823875,
           17.128829334002003,
           16.864366256180116,
           16.59990317835826,
           16.3354401005364,
           16.0789070625935,
           15.822374025631976,
           15.565840988670438,
           15.309307951708897,
           15.052774914747344,
           14.796241877785803,
           14.541432293143437,
           14.293947375296531,
           14.046462457449625,
           13.798977539602769,
           13.55149262175586,
           13.304007703908956,
           13.059100396652768,
           12.821628503897603,
           12.584156611142426,
           12.346684718387294,
           12.109212825632142,
           11.872175929776688,
           11.645095644598257,
           11.418015359419847,
           11.190935074241436,
           10.963854789063003,
           10.740611409915328,
           10.522643774383592,
           10.30467613885186,
           10.086708503320168,
           9.871516352499786,
           9.66283888013846,
           9.454161407777118,
           9.245483935415832,
           9.044025615639299,
           8.847411727746994,
           8.650797839854729,
           8.45758241000193,
           8.274119080863361,
           8.090655751724805,
           7.909950677777528,
           7.738554713223503,
           7.567158748669511,
           7.400904317028326,
           7.240504477799947,
           7.080104638571591,
           6.929156328524677,
           6.778798739528087,
           6.634127169406909,
           6.49293038804252,
           6.355770469775928,
           6.222950179284568,
           6.094074858317027,
           5.969076490565977,
           5.850187989298055,
           5.734303505200186,
           5.627967454705303,
           5.524604023269292,
           5.425617072654024,
           5.331222960434028,
           5.240672524200235,
           5.154753388868889,
           5.074441505002152,
           5.000056483386979,
           4.930287857278269,
           4.851764647086042,
           4.769317522554684,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           66.8834041850246,
           66.93234489601616,
           66.98128560700773,
           67.03022631799931,
           67.07916702899087,
           67.12810773998244,
           67.177048450974,
           67.22598916196557,
           67.27492987295713,
           67.3238705839487,
           67.37281129494028,
           67.42175200593184,
           67.47069271692341,
           67.51963342791498,
           67.56857413890654,
           67.6175148498981,
           67.66645556088967,
           67.71539627188125,
           67.7643369828728,
           67.81327769386438,
           67.86221840485595,
           67.91115911584751,
           67.96009982683907,
           68.00904053783066,
           68.05798124882222,
           68.10660857524677,
           68.15517322492627,
           68.20373787460578,
           68.25230252428528,
           68.30086717396479,
           68.34943182364428,
           68.3979964733238,
           68.44656112300329,
           68.4951257726828,
           68.5436904223623,
           68.59225507204181,
           68.64081972172131,
           68.6893843714008,
           68.73794902108031,
           68.78651367075982,
           68.83507832043932,
           68.88364297011883,
           68.93220761979832,
           68.98077226947782,
           69.02933691915733,
           69.07790156883684,
           69.12646621851634,
           69.17503086819583,
           69.22359551787534,
           69.27216016755486,
           69.32072481723435,
           69.36928946691386,
           69.41785411659336,
           69.46641876627285,
           69.51498341595237,
           69.56354806563186,
           69.61211271531137,
           69.66067736499087,
           69.70924201467037,
           69.75780666434989,
           69.80637131402938,
           69.8549359637089,
           69.90350061338839,
           69.95206526306788,
           70.0006299127474,
           70.04919456242689,
           70.09775921210641,
           70.1463238617859,
           70.19488851146542,
           70.24345316114491,
           70.29201781082442,
           70.34058246050392,
           70.38914711018342,
           70.43771175986294,
           70.48627640954243,
           70.53484105922195,
           70.58340570890144,
           70.63197035858093,
           70.68053500826045,
           70.72909965793994,
           70.77766430761946,
           70.82622895729895,
           70.87479360697846,
           70.92335825665796,
           70.95706355094728,
           70.98779697415856,
           71.01853039736983,
           71.04926382058112,
           71.0799972437924,
           71.11073066700368,
           71.14146409021498,
           71.17219751342626,
           71.20293093663753,
           71.23366435984882,
           71.2643977830601,
           71.29513120627138,
           71.32586462948268,
           71.35659805269395,
           71.38733147590524,
           71.41806489911653,
           71.4487983223278,
           71.47953174553909,
           71.51026516875038,
           71.54099859196165,
           71.57173201517294,
           71.60246543838423,
           71.6331988615955,
           71.66393228480678,
           71.69466570801806,
           71.72539913122935,
           71.75613255444064,
           71.78686597765193,
           71.8175994008632,
           71.84833282407449,
           71.87906624728578,
           71.90979967049705,
           71.94053309370834,
           71.97126651691963,
           72.0019999401309,
           72.03273336334219,
           72.06346678655346,
           72.09420020976475,
           72.12493363297602,
           72.15566705618733,
           72.1864004793986,
           72.21713390260989,
           72.24786732582116,
           72.27860074903245,
           72.30933417224374,
           72.34006759545503,
           72.3708010186663,
           72.40153444187759,
           72.43226786508886,
           72.46300128830015,
           72.49373471151142,
           72.52446813472272,
           72.555201557934,
           72.58593498114529,
           72.61666840435657,
           72.64740182756785,
           72.67813525077914,
           72.70886867399041,
           72.7396020972017,
           72.77204975322338,
           72.80484025672801,
           72.83763076023263,
           72.87042126373724,
           72.90321176724186,
           72.93600227074649,
           72.9687927742511,
           73.00158327775571,
           73.03437378126033,
           73.06716428476494,
           73.09995478826957,
           73.13274529177419,
           73.1655357952788,
           73.19832629878343,
           73.23111680228804,
           73.26390730579266,
           73.29669780929729,
           73.3294883128019,
           73.36227881630651,
           73.39506931981114,
           73.42785982331576,
           73.46065032682037,
           73.49344083032499,
           73.52623133382961,
           73.42239730091654,
           73.25025099979463,
           73.07810469867272,
           72.9059583975508,
           72.7338120964289,
           72.56166579530698,
           72.38951949418508,
           72.21737319306317,
           72.04522689194125,
           71.87308059081936,
           71.70093428969743,
           71.52878798857553,
           71.35664168745362,
           71.1844953863317,
           71.01234908520979,
           70.8402027840879,
           70.66805648296597,
           70.49591018184407,
           70.32376388072214,
           70.15161757960026,
           69.97947127847834,
           69.80732497735643,
           69.63517867623452,
           69.4630323751126,
           69.29088607399069,
           69.11873977286878,
           68.94659347174687,
           68.77444717062497,
           68.60230086950304,
           68.43015456838114,
           68.25800826725923,
           68.08586196613732,
           67.9137156650154,
           67.74156936389349,
           67.56942306277159,
           67.39727676164968,
           67.22513046052777,
           67.05298415940585,
           66.88083785828394,
           66.70869155716204,
           66.53654525604013,
           66.36439895491822,
           66.1922526537963,
           66.02010635267439,
           65.84796005155249,
           65.67581375043056,
           65.50366744930867,
           65.33152114818675,
           65.15937484706484,
           64.98722854594293,
           64.81508224482101,
           64.64293594369911,
           64.4707896425772,
           64.29864334145529,
           64.12649704033338,
           63.95435073921147,
           63.78220443808956,
           63.61005813696765,
           63.437911835845725,
           63.26576553472381,
           63.09361923360191,
           62.92147293248,
           62.7493266313581,
           62.577180330236175,
           62.405034029114276,
           62.23288772799236,
           62.06074142687045,
           61.888595125748544,
           61.716448824626625,
           61.54114140579991,
           61.3521359066868,
           61.163130407573675,
           60.97412490846057,
           60.78511940934746,
           60.59611391023435,
           60.407108411121236,
           60.21810291200812,
           60.029097412895005,
           59.8400919137819,
           59.65108641466878,
           59.46208091555567,
           59.27307541644255,
           59.08406991732944,
           58.67169871857288,
           58.03596182017282,
           57.40022492177285,
           56.76448802337288,
           56.12875112497282,
           55.49301422657285,
           54.85727732817287,
           54.221540429772844,
           53.58580353137279,
           52.95006663297287,
           52.314329734572844,
           51.67859283617279,
           51.04285593777283,
           50.40711903937284,
           49.77138214097281,
           49.13564524257282,
           48.49990834417284,
           47.86417144577281,
           47.22843454737283,
           46.59269764897286,
           45.95696075057282,
           45.321223852172785,
           44.68449548954496,
           44.04538265328797,
           43.406269817031,
           42.76715698077408,
           42.12804414451717,
           41.48893130826019,
           40.849818472003264,
           40.21070563574634,
           39.57159279948937,
           38.932479963232396,
           38.29336712697554,
           37.65425429071854,
           37.01514145446158,
           36.37602861820465,
           36.30310892090061,
           36.4463068287564,
           36.58950473661215,
           36.73270264446791,
           36.8759005523237,
           37.01909846017946,
           37.16229636803522,
           37.30549427589099,
           37.44869218374678,
           37.591890091602515,
           37.73508799945829,
           37.878285907314066,
           38.02148381516983,
           38.16468172302559,
           38.30787963088137,
           38.45107753873713,
           38.59427544659289,
           38.73747335444867,
           38.88067126230444,
           39.02386917016019,
           39.16706707801597,
           39.31026498587175,
           39.453462893727504,
           39.59666080158326,
           39.73985870943905,
           39.88305661729481,
           40.02625452515057,
           40.169452433006335,
           40.07642239549956,
           39.782821950308616,
           39.48922150511762,
           39.1956210599266,
           38.90202061473567,
           38.60842016954467,
           38.31481972435367,
           38.02121927916271,
           37.727618833971675,
           37.43401838878072,
           37.14041794358972,
           36.84681749839873,
           36.55321705320773,
           36.25961660801677,
           35.96601616282583,
           35.67241571763478,
           35.37881527244378,
           35.08521482725282,
           34.79161438206184,
           34.498013936870834,
           34.20441349167988,
           33.91081304648888,
           33.61991763067353,
           33.32965338765047,
           33.03938914462737,
           32.749124901604276,
           32.45886065858113,
           32.16859641555808,
           31.878332172535018,
           31.588067929511915,
           31.297803686488823,
           31.007539443465728,
           30.71727520044262,
           30.427010957419526,
           30.136746714396516,
           29.84648247137337,
           29.556218228350314,
           29.26595398532722,
           28.975689742304116,
           28.688208109358378,
           28.402311508117947,
           28.116414906877523,
           27.83051830563708,
           27.54462170439665,
           27.25872510315626,
           26.972828501915817,
           26.686931900675386,
           26.401035299434955,
           26.115138698194553,
           25.829242096954115,
           25.54334549571373,
           25.257448894473253,
           24.971552293232815,
           24.68985958924942,
           24.40978050457874,
           24.129701419908017,
           23.849622335237335,
           23.569543250566625,
           23.2894641658959,
           23.00938508122519,
           22.72930599655451,
           22.449226911883784,
           22.16914782721306,
           21.88906874254235,
           21.61070948459215,
           21.338447788936588,
           21.066186093281008,
           20.793924397625485,
           20.521662701969923,
           20.249401006314407,
           19.977139310658853,
           19.70487761500329,
           19.432615919347757,
           19.160354223692217,
           18.89239851323685,
           18.627935435414965,
           18.36347235759312,
           18.099009279771245,
           17.83454620194936,
           17.57008312412749,
           17.30562004630564,
           17.041156968483758,
           16.77917202740665,
           16.522638990445135,
           16.266105953483553,
           16.009572916522004,
           15.7530398795605,
           15.496506842598947,
           15.23997380563742,
           14.985307841979472,
           14.737822924132601,
           14.490338006285695,
           14.242853088438824,
           13.99536817059193,
           13.747883252745027,
           13.500547043370062,
           13.263075150614913,
           13.025603257859757,
           12.78813136510458,
           12.550659472349416,
           12.313187579594253,
           12.08166065238012,
           11.854580367201732,
           11.627500082023301,
           11.400419796844867,
           11.173339511666434,
           10.953093714679317,
           10.735126079147582,
           10.51715844361583,
           10.299190808084138,
           10.085386399492222,
           9.876708927130899,
           9.668031454769613,
           9.459353982408286,
           9.257753179336415,
           9.061139291444125,
           8.864525403551859,
           8.669241346437369,
           8.485778017298788,
           8.302314688160244,
           8.118851359021651,
           7.94672273349423,
           7.775326768940229,
           7.604568804738584,
           7.444168965510215,
           7.2837691262818804,
           7.127602784232213,
           6.977245195235634,
           6.826887606599171,
           6.685690825234792,
           6.544494043870365,
           6.409731013053552,
           6.276910722562217,
           6.149599786133733,
           6.024601418382675,
           5.906807601479294,
           5.791029803893846,
           5.685040484124255,
           5.581512934656866,
           5.482525984041618,
           5.387676491218093,
           5.296147902871042,
           5.208900734348207,
           5.128490477607175,
           5.052510847768954,
           4.981056324442326,
           4.907438007173983,
           4.8249908826426235,
           4.742543758111277,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           66.96171595626555,
           67.01065666725712,
           67.05959737824868,
           67.10853808924026,
           67.15747880023181,
           67.20641951122339,
           67.25536022221496,
           67.30430093320653,
           67.35311629022506,
           67.40168093990458,
           67.45024558958407,
           67.49881023926358,
           67.54737488894308,
           67.59593953862257,
           67.64450418830208,
           67.69306883798158,
           67.74163348766109,
           67.7901981373406,
           67.8387627870201,
           67.8873274366996,
           67.9358920863791,
           67.9844567360586,
           68.03302138573811,
           68.08158603541762,
           68.13015068509712,
           68.17871533477663,
           68.22727998445613,
           68.27584463413564,
           68.32440928381513,
           68.37297393349463,
           68.42153858317414,
           68.47010323285363,
           68.51866788253315,
           68.56723253221264,
           68.61579718189215,
           68.66436183157165,
           68.71292648125116,
           68.76149113093066,
           68.81005578061016,
           68.85862043028966,
           68.90718507996917,
           68.95574972964867,
           69.00431437932818,
           69.05287902900768,
           69.10144367868718,
           69.15000832836668,
           69.19857297804619,
           69.24713762772569,
           69.29570227740518,
           69.3442669270847,
           69.3928315767642,
           69.4413962264437,
           69.4899608761232,
           69.5385255258027,
           69.58709017548222,
           69.63565482516171,
           69.68421947484123,
           69.73278412452072,
           69.78134877420023,
           69.82991342387973,
           69.87847807355922,
           69.92704272323874,
           69.97560737291823,
           70.02417202259774,
           70.07273667227724,
           70.12130132195675,
           70.16986597163626,
           70.21843062131575,
           70.26699527099527,
           70.31555992067476,
           70.36412457035428,
           70.41268922003377,
           70.46125386971327,
           70.50981851939278,
           70.55838316907227,
           70.60694781875178,
           70.65551246843128,
           70.70407711811079,
           70.7526417677903,
           70.8012064174698,
           70.84977106714929,
           70.8983357168288,
           70.9469003665083,
           70.99546501618781,
           71.02917031047713,
           71.05990373368842,
           71.09063715689969,
           71.12137058011098,
           71.15210400332225,
           71.18283742653354,
           71.21357084974483,
           71.2443042729561,
           71.27503769616739,
           71.30577111937868,
           71.33650454258996,
           71.36723796580124,
           71.39797138901253,
           71.4287048122238,
           71.4594382354351,
           71.49017165864637,
           71.52090508185766,
           71.55163850506895,
           71.58237192828022,
           71.6131053514915,
           71.64383877470279,
           71.67457219791407,
           71.70530562112536,
           71.73603904433664,
           71.76677246754792,
           71.79750589075921,
           71.82823931397049,
           71.85897273718177,
           71.88970616039305,
           71.92043958360435,
           71.95117300681562,
           71.98190643002691,
           72.01263985323818,
           72.04337327644947,
           72.07410669966076,
           72.10484012287205,
           72.13557354608332,
           72.1663069692946,
           72.19704039250588,
           72.22777381571717,
           72.25850723892846,
           72.28924066213975,
           72.31997408535102,
           72.35070750856231,
           72.38144093177358,
           72.41217435498487,
           72.44290777819616,
           72.47364120140743,
           72.50437462461872,
           72.53510804783001,
           72.56584147104128,
           72.59657489425257,
           72.62730831746386,
           72.65804174067515,
           72.68877516388642,
           72.7195085870977,
           72.75024201030898,
           72.78097543352027,
           72.81170885673156,
           72.84244227994283,
           72.87317570315412,
           72.90390912636539,
           72.9346425495767,
           72.96537597278797,
           72.99610939599924,
           73.02684281921054,
           73.05757624242182,
           73.08830966563309,
           73.11904308884439,
           73.14977651205567,
           73.18050993526695,
           73.21124335847824,
           73.2419767816895,
           73.2727102049008,
           73.30344362811208,
           73.33486274364768,
           73.3676532471523,
           73.40044375065692,
           73.43323425416155,
           73.46602475766615,
           73.49881526117079,
           73.5316057646754,
           73.56439626818002,
           73.46056223526693,
           73.28841593414504,
           73.11626963302311,
           72.94412333190121,
           72.7719770307793,
           72.59983072965738,
           72.42768442853547,
           72.25553812741356,
           72.08339182629166,
           71.91124552516975,
           71.73909922404783,
           71.56695292292592,
           71.39480662180401,
           71.22266032068211,
           71.05051401956021,
           70.87836771843828,
           70.70622141731637,
           70.53407511619446,
           70.36192881507255,
           70.18978251395065,
           70.01763621282873,
           69.84548991170682,
           69.66280658576136,
           69.47380108664822,
           69.28479558753513,
           69.095790088422,
           68.9067845893089,
           68.71777909019579,
           68.52877359108267,
           68.33976809196956,
           68.15076259285644,
           67.96175709374333,
           67.77275159463022,
           67.58374609551711,
           67.39474059640399,
           67.20573509729088,
           67.01672959817778,
           66.82772409906467,
           66.63871859995155,
           66.44971310083844,
           66.26070760172533,
           66.07170210261222,
           65.88269660349911,
           65.69369110438598,
           65.50468560527287,
           65.31568010615976,
           65.12667460704665,
           64.93766910793354,
           64.74866360882042,
           64.5596581097073,
           64.37065261059419,
           64.18164711148108,
           63.992641612367976,
           63.80363611325485,
           63.614630614141745,
           63.42562511502864,
           63.236619615915515,
           63.04761411680241,
           62.858608617689285,
           62.66960311857617,
           62.48059761946307,
           62.29159212034996,
           62.102586621236846,
           61.91358112212373,
           61.72457562301062,
           61.535570123897514,
           61.34656462478439,
           61.15755912567128,
           60.96855362655817,
           60.779548127445054,
           60.590542628331946,
           60.40153712921883,
           60.212531630105715,
           60.02352613099261,
           59.83452063187949,
           59.64551513276638,
           59.45650963365326,
           59.267504134540154,
           59.07849863542704,
           58.88949313631393,
           58.70048763720082,
           58.5114821380877,
           58.32247663897459,
           57.91010544021802,
           57.274368541817964,
           56.638631643417995,
           56.002894745018025,
           55.36715784661797,
           54.731420948218,
           54.09568404981801,
           53.459947151418,
           52.824210253017945,
           52.18847335461802,
           51.552736456218,
           50.91699955781794,
           50.28126265941797,
           49.645525761017986,
           49.00978886261796,
           48.374051964217976,
           47.73831506581798,
           47.09965334676613,
           46.46054051050922,
           45.82142767425227,
           45.182314837995314,
           44.54320200173834,
           43.90408916548147,
           43.26497632922448,
           42.62586349296752,
           41.98675065671059,
           41.347637820453684,
           40.70852498419671,
           40.06941214793978,
           39.43029931168285,
           38.79118647542589,
           38.195833251822684,
           38.33903115967843,
           38.482229067534206,
           38.62542697538998,
           38.768624883245735,
           38.9118227911015,
           39.05502069895728,
           39.19821860681304,
           39.3414165146688,
           39.48461442252458,
           39.62781233038035,
           39.7710102382361,
           39.91420814609188,
           40.05740605394765,
           40.20060396180339,
           40.34380186965918,
           40.486999777514946,
           40.63019768537071,
           40.77339559322647,
           40.91659350108225,
           41.05979140893801,
           41.20298931679377,
           41.346187224649555,
           41.48938513250532,
           41.63258304036108,
           41.6509811430953,
           41.3573806979043,
           41.063780252713315,
           40.77017980752236,
           40.47657936233136,
           40.182978917140325,
           39.88937847194937,
           39.59577802675837,
           39.30217758156737,
           39.008577136376424,
           38.71497669118542,
           38.421376245994416,
           38.12777580080348,
           37.83417535561248,
           37.54057491042147,
           37.24697446523052,
           36.95337402003948,
           36.65977357484853,
           36.366173129657525,
           36.072572684466536,
           35.77897223927553,
           35.485371794084585,
           35.19177134889363,
           34.90033492734594,
           34.610070684322835,
           34.319806441299775,
           34.02954219827669,
           33.73927795525358,
           33.44901371223048,
           33.15874946920743,
           32.868485226184326,
           32.578220983161266,
           32.28795674013818,
           31.99769249711507,
           31.70742825409193,
           31.417164011068884,
           31.12689976804582,
           30.83663552502271,
           30.54637128199962,
           30.256107038976527,
           29.96584279595342,
           29.678889506754484,
           29.392992905514088,
           29.10709630427365,
           28.821199703033216,
           28.535303101792792,
           28.249406500552347,
           27.96350989931194,
           27.677613298071513,
           27.391716696831086,
           27.105820095590644,
           26.819923494350213,
           26.534026893109818,
           26.248130291869384,
           25.96223369062895,
           25.67786577823011,
           25.397786693559418,
           25.117707608888693,
           24.837628524218026,
           24.55754943954727,
           24.27747035487655,
           23.99739127020583,
           23.717312185535157,
           23.43723310086443,
           23.15715401619375,
           22.87707493152304,
           22.596995846852316,
           22.319105632290466,
           22.04684393663491,
           21.77458224097938,
           21.50232054532382,
           21.230058849668268,
           20.957797154012745,
           20.685535458357183,
           20.413273762701603,
           20.14101206704608,
           19.86875037139052,
           19.598115381184197,
           19.333652303362353,
           19.069189225540438,
           18.804726147718554,
           18.540263069896724,
           18.275799992074838,
           18.01133691425295,
           17.746873836431106,
           17.48241075860923,
           17.222903955258218,
           16.966370918296676,
           16.709837881335133,
           16.45330484437361,
           16.19677180741207,
           15.940238770450554,
           15.683705733488976,
           15.429183390815533,
           15.181698472968653,
           14.934213555121747,
           14.686728637274864,
           14.43924371942795,
           14.191758801581077,
           13.944273883734173,
           13.704521797332214,
           13.467049904577049,
           13.229578011821873,
           12.992106119066694,
           12.754634226311545,
           12.518225660161967,
           12.291145374983536,
           12.064065089805114,
           11.836984804626713,
           11.609904519448282,
           11.38354365497499,
           11.165576019443256,
           10.947608383911538,
           10.729640748379804,
           10.511673112848113,
           10.299256446484648,
           10.09057897412334,
           9.881901501762053,
           9.67322402940071,
           9.471480743033515,
           9.274866855141251,
           9.078252967248947,
           8.881639079356642,
           8.6974369537342,
           8.513973624595657,
           8.330510295457078,
           8.154890753764949,
           7.983494789210959,
           7.812098824656934,
           7.647833453220475,
           7.487433613992127,
           7.32703377476376,
           7.175691650943162,
           7.025334061946603,
           6.8784512624270455,
           6.737254481062629,
           6.596511846822511,
           6.463691556331176,
           6.330871265839823,
           6.2051247139504255,
           6.080126346199391,
           5.963427213660504,
           5.848102833312801,
           5.742113513543231,
           5.638421846044453,
           5.539434895429187,
           5.444130022002152,
           5.351623281541863,
           5.264376113019016,
           5.182539450212195,
           5.10496521215094,
           5.031824791606367,
           4.963111367261917,
           4.880664242730574,
           4.798217118199215,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           67.03386863598935,
           67.08191093252714,
           67.1299532290649,
           67.17799552560268,
           67.22603782214046,
           67.27408011867823,
           67.322122415216,
           67.37016471175379,
           67.41820700829156,
           67.46633636331906,
           67.51490101299855,
           67.56346566267806,
           67.61203031235756,
           67.66059496203707,
           67.70915961171657,
           67.75772426139606,
           67.80628891107557,
           67.85485356075507,
           67.90341821043458,
           67.95198286011409,
           68.00054750979358,
           68.04911215947308,
           68.0976768091526,
           68.1462414588321,
           68.1948061085116,
           68.2433707581911,
           68.29193540787061,
           68.34050005755012,
           68.38906470722961,
           68.43762935690911,
           68.48619400658862,
           68.53475865626812,
           68.58332330594763,
           68.63188795562714,
           68.68045260530664,
           68.72901725498613,
           68.77758190466564,
           68.82614655434514,
           68.87471120402465,
           68.92327585370415,
           68.97184050338365,
           69.02040515306315,
           69.06896980274266,
           69.11753445242216,
           69.16609910210167,
           69.21466375178117,
           69.26322840146068,
           69.31179305114017,
           69.36035770081968,
           69.40892235049918,
           69.45748700017869,
           69.5060516498582,
           69.55461629953768,
           69.60318094921719,
           69.6517455988967,
           69.7003102485762,
           69.7488748982557,
           69.7974395479352,
           69.8460041976147,
           69.89456884729421,
           69.94313349697372,
           69.99169814665322,
           70.04026279633271,
           70.08882744601223,
           70.13739209569172,
           70.18595674537124,
           70.23452139505073,
           70.28308604473024,
           70.33165069440975,
           70.38021534408925,
           70.42877999376876,
           70.47734464344825,
           70.52590929312777,
           70.57447394280726,
           70.62303859248676,
           70.67160324216627,
           70.72016789184576,
           70.76873254152528,
           70.81729719120477,
           70.86586184088428,
           70.91442649056378,
           70.96299114024329,
           71.0115557899228,
           71.06012043960229,
           71.0938257338916,
           71.1245591571029,
           71.15529258031418,
           71.18602600352546,
           71.21675942673674,
           71.24749284994803,
           71.2782262731593,
           71.3089596963706,
           71.33969311958187,
           71.37042654279315,
           71.40115996600444,
           71.43189338921573,
           71.46262681242702,
           71.49336023563829,
           71.52409365884958,
           71.55482708206085,
           71.58556050527214,
           71.61629392848343,
           71.6470273516947,
           71.67776077490599,
           71.70849419811728,
           71.73922762132855,
           71.76996104453984,
           71.80069446775113,
           71.8314278909624,
           71.8621613141737,
           71.89289473738498,
           71.92362816059625,
           71.95436158380754,
           71.98509500701883,
           72.0158284302301,
           72.0465618534414,
           72.07729527665266,
           72.10802869986395,
           72.13876212307524,
           72.16949554628653,
           72.2002289694978,
           72.23096239270907,
           72.26169581592036,
           72.29242923913165,
           72.32316266234294,
           72.35389608555423,
           72.3846295087655,
           72.41536293197679,
           72.44609635518808,
           72.47682977839935,
           72.50756320161064,
           72.53829662482191,
           72.5690300480332,
           72.59976347124449,
           72.63049689445577,
           72.66123031766705,
           72.69196374087834,
           72.72269716408962,
           72.7534305873009,
           72.78416401051219,
           72.81489743372346,
           72.84563085693475,
           72.87636428014603,
           72.90709770335731,
           72.9378311265686,
           72.96856454977987,
           72.99929797299117,
           73.03003139620246,
           73.06076481941373,
           73.09149824262502,
           73.1222316658363,
           73.15296508904758,
           73.18369851225887,
           73.21443193547016,
           73.24516535868145,
           73.27589878189272,
           73.306632205104,
           73.33736562831528,
           73.36698043030356,
           73.39547661421456,
           73.42397279812556,
           73.45246898203656,
           73.48096516594757,
           73.50946134985858,
           73.53795753376957,
           73.56645371768057,
           73.59494990159158,
           73.46262946687237,
           73.24990072283806,
           73.03717197880373,
           72.82444323476942,
           72.61171449073511,
           72.3989857467008,
           72.18625700266648,
           71.97352825863216,
           71.76079951459785,
           71.54807077056356,
           71.33534202652922,
           71.12261328249491,
           70.9098845384606,
           70.69715579442628,
           70.48442705039197,
           70.27169830635766,
           70.05896956232334,
           69.84624081828903,
           69.65723530385898,
           69.46822980474586,
           69.27922430563275,
           69.09021880651963,
           68.90121330740654,
           68.7122078082934,
           68.5232023091803,
           68.3341968100672,
           68.14519131095406,
           67.95618581184097,
           67.76718031272785,
           67.57817481361474,
           67.38916931450163,
           67.2001638153885,
           67.01115831627541,
           66.82215281716229,
           66.63314731804917,
           66.44414181893606,
           66.25513631982295,
           66.06613082070984,
           65.87712532159672,
           65.68811982248361,
           65.4991143233705,
           65.3101088242574,
           65.12110332514428,
           64.93209782603115,
           64.74309232691805,
           64.55408682780494,
           64.36508132869183,
           64.1760758295787,
           63.9870703304656,
           63.79806483135248,
           63.60905933223937,
           63.42005383312626,
           63.231048334013146,
           63.042042834900045,
           62.85303733578691,
           62.664031836673814,
           62.47502633756069,
           62.286020838447584,
           62.09701533933447,
           61.908009840221354,
           61.71900434110825,
           61.52999884199513,
           61.34099334288203,
           61.15198784376891,
           60.9629823446558,
           60.773976845542684,
           60.584971346429576,
           60.39596584731646,
           60.20696034820334,
           60.017954849090245,
           59.82894934997712,
           59.639943850864015,
           59.45093835175089,
           59.261932852637784,
           59.072927353524676,
           58.883921854411554,
           58.694916355298446,
           58.505910856185324,
           58.31690535707222,
           58.12789985795911,
           57.938894358846,
           57.74988885973288,
           57.56088336061976,
           57.148512161863195,
           56.51277526346314,
           55.87703836506318,
           55.2413014666632,
           54.60556456826315,
           53.96982766986318,
           53.33409077146319,
           52.69835387306317,
           52.062616974663115,
           51.426880076263195,
           50.79114317786318,
           50.15392404024431,
           49.5148112039874,
           48.87569836773047,
           48.236585531473494,
           47.59747269521657,
           46.95835985895966,
           46.319247022702676,
           45.68013418644577,
           45.041021350188814,
           44.40190851393186,
           43.76279567767488,
           43.12368284141802,
           42.484570005161025,
           41.84545716890406,
           41.206344332647134,
           40.56723149639023,
           40.23175549060038,
           40.374953398456135,
           40.5181513063119,
           40.66134921416768,
           40.80454712202346,
           40.9477450298792,
           41.09094293773499,
           41.23414084559075,
           41.377338753446516,
           41.52053666130227,
           41.66373456915806,
           41.80693247701382,
           41.950130384869574,
           42.09332829272536,
           42.23652620058112,
           42.37972410843688,
           42.52292201629265,
           42.66611992414843,
           42.809317832004176,
           42.952515739859955,
           43.09571364771573,
           43.22553989069099,
           42.931939445500035,
           42.63833900030899,
           42.34473855511804,
           42.051138109927095,
           41.757537664736084,
           41.46393721954504,
           41.17033677435414,
           40.87673632916314,
           40.58313588397213,
           40.289535438781144,
           39.99593499359019,
           39.70233454839919,
           39.408734103208154,
           39.11513365801721,
           38.8215332128262,
           38.52793276763521,
           38.23433232244426,
           37.940731877253256,
           37.647131432062245,
           37.35353098687131,
           37.05993054168031,
           36.76633009648931,
           36.47272965129835,
           36.18075222401841,
           35.89048798099527,
           35.600223737972215,
           35.309959494949155,
           35.01969525192605,
           34.729431008902964,
           34.43916676587987,
           34.148902522856766,
           33.85863827983366,
           33.5683740368106,
           33.278109793787515,
           32.987845550764405,
           32.69758130774131,
           32.40731706471826,
           32.117052821695154,
           31.826788578672097,
           31.536524335649005,
           31.246260092625896,
           30.955995849602754,
           30.66957090415065,
           30.383674302910173,
           30.09777770166973,
           29.811881100429336,
           29.525984499188947,
           29.24008789794847,
           28.954191296708075,
           28.668294695467683,
           28.38239809422724,
           28.09650149298681,
           27.81060489174638,
           27.52470829050594,
           27.238811689265535,
           26.952915088025104,
           26.667018486784677,
           26.385792882540095,
           26.10571379786941,
           25.8256347131987,
           25.54555562852798,
           25.26547654385726,
           24.98539745918655,
           24.70531837451586,
           24.425239289845138,
           24.145160205174466,
           23.86508112050371,
           23.58500203583299,
           23.304922951162272,
           23.027501779988828,
           22.755240084333266,
           22.482978388677743,
           22.210716693022196,
           21.938454997366634,
           21.666193301711083,
           21.393931606055528,
           21.1216699104,
           20.849408214744436,
           20.577146519088885,
           20.304884823433365,
           20.039369171309655,
           19.774906093487807,
           19.510443015665935,
           19.24597993784408,
           18.981516860022207,
           18.71705378220036,
           18.452590704378448,
           18.18812762655656,
           17.92366454873473,
           17.66663588310982,
           17.410102846148266,
           17.153569809186752,
           16.89703677222521,
           16.64050373526366,
           16.383970698302118,
           16.12743766134058,
           15.873058939651607,
           15.625574021804713,
           15.37808910395782,
           15.130604186110938,
           14.883119268264029,
           14.63563435041715,
           14.388149432570243,
           14.14596844404949,
           13.908496551294347,
           13.67102465853918,
           13.433552765784025,
           13.196080873028862,
           12.958608980273699,
           12.727710382765398,
           12.500630097586967,
           12.273549812408579,
           12.046469527230146,
           11.819389242051715,
           11.596025959738949,
           11.378058324207228,
           11.16009068867551,
           10.9421230531438,
           10.724155417612067,
           10.513126493477086,
           10.30444902111576,
           10.095771548754474,
           9.887094076393149,
           9.685208306730633,
           9.488594418838368,
           9.291980530946077,
           9.095366643053758,
           8.909095890169663,
           8.725632561031084,
           8.542169231892501,
           8.363058774035677,
           8.191662809481688,
           8.020266844927663,
           7.851497940930721,
           7.691098101702384,
           7.530698262474017,
           7.374138106650699,
           7.22378051765414,
           7.073422928657571,
           6.930014918254891,
           6.788818136890502,
           6.650472390100161,
           6.517652099608799,
           6.385648009518176,
           6.260649641767149,
           6.135931309939602,
           6.020046825841726,
           5.9051758627317685,
           5.799186542962177,
           5.695330757432028,
           5.59634380681678,
           5.500583552786234,
           5.40709866021267,
           5.319851491689823,
           5.236588422817235,
           5.1574195765329165,
           5.083260340298592,
           5.013879834425971,
           4.936337602818513,
           4.853890478287154,
           4.771443353755808,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           67.10067568991397,
           67.14871798645174,
           67.19676028298952,
           67.24480257952729,
           67.29284487606508,
           67.34088717260283,
           67.38892946914062,
           67.4369717656784,
           67.48501406221617,
           67.53305635875394,
           67.58109865529173,
           67.6291409518295,
           67.67718324836727,
           67.72522554490504,
           67.77326784144283,
           67.8213101379806,
           67.86935243451838,
           67.91739473105615,
           67.96543702759392,
           68.01347932413171,
           68.06152162066948,
           68.10956391720725,
           68.15760621374503,
           68.2056485102828,
           68.25369080682057,
           68.30173310335836,
           68.35012363487053,
           68.39868828455003,
           68.44725293422954,
           68.49581758390904,
           68.54438223358855,
           68.59294688326804,
           68.64151153294756,
           68.69007618262705,
           68.73864083230656,
           68.78720548198606,
           68.83577013166556,
           68.88433478134507,
           68.93289943102457,
           68.98146408070407,
           69.03002873038358,
           69.07859338006307,
           69.12715802974259,
           69.17572267942208,
           69.22428732910159,
           69.27285197878109,
           69.3214166284606,
           69.3699812781401,
           69.4185459278196,
           69.4671105774991,
           69.5156752271786,
           69.56423987685811,
           69.61280452653762,
           69.66136917621712,
           69.70993382589663,
           69.75849847557612,
           69.80706312525562,
           69.85562777493513,
           69.90419242461464,
           69.95275707429414,
           70.00132172397365,
           70.04988637365314,
           70.09845102333264,
           70.14701567301216,
           70.19558032269165,
           70.24414497237116,
           70.29270962205067,
           70.34127427173016,
           70.38983892140966,
           70.43840357108917,
           70.48696822076867,
           70.53553287044818,
           70.58409752012768,
           70.63266216980719,
           70.68122681948668,
           70.72979146916619,
           70.77835611884569,
           70.8269207685252,
           70.8754854182047,
           70.9240500678842,
           70.97261471756372,
           71.0211793672432,
           71.06974401692271,
           71.11830866660222,
           71.15201396089154,
           71.18274738410281,
           71.2134808073141,
           71.24421423052539,
           71.27494765373666,
           71.30568107694795,
           71.33641450015924,
           71.36714792337051,
           71.3978813465818,
           71.42861476979309,
           71.45934819300437,
           71.49008161621565,
           71.52081503942694,
           71.55154846263821,
           71.58228188584951,
           71.61301530906078,
           71.64374873227206,
           71.67448215548335,
           71.70521557869463,
           71.73594900190591,
           71.7666824251172,
           71.79741584832848,
           71.82814927153976,
           71.85888269475105,
           71.88961611796233,
           71.92034954117361,
           71.9510829643849,
           71.98181638759618,
           72.01254981080746,
           72.04328323401874,
           72.07401665723003,
           72.1047500804413,
           72.1354835036526,
           72.16621692686388,
           72.19695035007517,
           72.22768377328644,
           72.25841719649773,
           72.289150619709,
           72.3198840429203,
           72.35061746613158,
           72.38135088934285,
           72.41208431255414,
           72.44281773576543,
           72.4735511589767,
           72.50428458218799,
           72.53501800539928,
           72.56575142861057,
           72.59648485182184,
           72.62721827503313,
           72.65795169824442,
           72.68868512145569,
           72.71941854466698,
           72.75015196787825,
           72.78088539108954,
           72.81161881430083,
           72.8423522375121,
           72.87308566072339,
           72.90381908199265,
           72.93231526590365,
           72.96081144981466,
           72.98930763372567,
           73.01780381763666,
           73.04630000154768,
           73.07479618545867,
           73.10329236936968,
           73.13178855328069,
           73.16028473719169,
           73.18878092110268,
           73.2172771050137,
           73.2457732889247,
           73.2742694728357,
           73.3027656567467,
           73.3312618406577,
           73.35975802456869,
           73.38825420847971,
           73.41675039239071,
           73.44524657630171,
           73.47374276021272,
           73.50223894412372,
           73.53073512803473,
           73.55923131194572,
           73.58772749585673,
           73.61622367976773,
           73.48390324504852,
           73.27117450101422,
           73.05844575697989,
           72.84571701294558,
           72.63298826891128,
           72.42025952487695,
           72.20753078084263,
           71.99480203680831,
           71.782073292774,
           71.56934454873969,
           71.35661580470537,
           71.14388706067106,
           70.93115831663675,
           70.71842957260245,
           70.50570082856814,
           70.29297208453382,
           70.0802433404995,
           69.86751459646518,
           69.65478585243088,
           69.44205710839655,
           69.22932836436225,
           69.01659962032792,
           68.80387087629363,
           68.5911421322593,
           68.378413388225,
           68.16568464419068,
           67.95295590015637,
           67.74022715612206,
           67.52749841208774,
           67.31476966805343,
           67.10204092401911,
           66.88931217998478,
           66.67658343595048,
           66.46385469191617,
           66.25112594788186,
           66.03839720384755,
           65.82566845981322,
           65.61293971577892,
           65.4002109717446,
           65.18748222771029,
           64.97475348367598,
           64.76202473964166,
           64.54929599560735,
           64.33656725157303,
           64.12383850753872,
           63.9111097635044,
           63.69838101947009,
           63.48565227543578,
           63.27292353140146,
           63.06019478736714,
           62.84746605388454,
           62.65846055477144,
           62.46945505565832,
           62.280449556545214,
           62.09144405743209,
           61.90243855831899,
           61.713433059205876,
           61.52442756009276,
           61.33542206097965,
           61.14641656186652,
           60.95741106275342,
           60.76840556364031,
           60.5794000645272,
           60.390394565414084,
           60.201389066300976,
           60.01238356718786,
           59.823378068074746,
           59.63437256896164,
           59.44536706984852,
           59.256361570735415,
           59.0673560716223,
           58.87835057250919,
           58.68934507339607,
           58.50033957428296,
           58.31133407516985,
           58.12232857605673,
           57.93332307694362,
           57.74431757783051,
           57.5553120787174,
           57.366306579604284,
           57.177301080491176,
           56.98829558137806,
           56.79929008226494,
           56.38691888350838,
           55.75118198510832,
           55.11544508670835,
           54.479708188308386,
           53.84397128990833,
           53.20819473372253,
           52.56908189746562,
           51.92996906120863,
           51.29085622495167,
           50.65174338869481,
           50.01263055243783,
           49.37351771618086,
           48.73440487992394,
           48.095292043667015,
           47.45617920741004,
           46.8170663711531,
           46.177953534896204,
           45.53884069863922,
           44.899727862382306,
           44.26061502612536,
           43.6215021898684,
           42.982389353611424,
           42.34327651735456,
           42.26767772937808,
           42.410875637233865,
           42.55407354508962,
           42.69727145294539,
           42.84046936080116,
           42.983667268656916,
           43.12686517651268,
           43.27006308436846,
           43.41326099222424,
           43.55645890007998,
           43.69965680793577,
           43.84285471579153,
           43.986052623647296,
           44.129250531503054,
           44.27244843935883,
           44.41564634721459,
           44.55884425507036,
           44.70204216292614,
           44.50649819309576,
           44.21289774790481,
           43.91929730271377,
           43.62569685752277,
           43.332096412331815,
           43.03849596714082,
           42.74489552194982,
           42.451295076758825,
           42.15769463156787,
           41.864094186376825,
           41.57049374118588,
           41.276893295994924,
           40.98329285080393,
           40.689692405612874,
           40.39609196042198,
           40.10249151523097,
           39.80889107003998,
           39.51529062484899,
           39.221690179658026,
           38.92808973446702,
           38.63448928927599,
           38.34088884408504,
           38.04728839889404,
           37.75368795370304,
           37.461169520690845,
           37.17090527766774,
           36.88064103464465,
           36.590376791621566,
           36.30011254859849,
           36.00984830557539,
           35.7195840625523,
           35.42931981952924,
           35.1390555765061,
           34.84879133348304,
           34.55852709045999,
           34.26826284743688,
           33.977998604413784,
           33.687734361390696,
           33.39747011836759,
           33.10720587534449,
           32.81694163232143,
           32.52667738929834,
           32.23641314627523,
           31.94614890325214,
           31.660252301546766,
           31.374355700306324,
           31.088459099065894,
           30.80256249782547,
           30.51666589658506,
           30.230769295344622,
           29.94487269410424,
           29.65897609286376,
           29.37307949162332,
           29.087182890382927,
           28.801286289142535,
           28.51538968790206,
           28.229493086661666,
           27.94359648542127,
           27.657699884180833,
           27.37379907152077,
           27.093719986850093,
           26.81364090217937,
           26.53356181750864,
           26.25348273283793,
           25.973403648167253,
           25.693324563496525,
           25.413245478825846,
           25.133166394155136,
           24.853087309484415,
           24.573008224813698,
           24.292929140142984,
           24.012850055472295,
           23.735897927687155,
           23.463636232031647,
           23.19137453637608,
           22.919112840720523,
           22.646851145065,
           22.37458944940945,
           22.102327753753887,
           21.830066058098364,
           21.557804362442816,
           21.285542666787254,
           21.013280971131707,
           20.74508603925704,
           20.48062296143518,
           20.216159883613297,
           19.95169680579142,
           19.68723372796958,
           19.422770650147665,
           19.158307572325818,
           18.89384449450395,
           18.62938141668209,
           18.366900847922967,
           18.110367810961424,
           17.85383477399987,
           17.59730173703832,
           17.340768700076815,
           17.084235663115265,
           16.827702626153712,
           16.5711695891922,
           16.31693448848768,
           16.06944957064077,
           15.82196465279388,
           15.57447973494701,
           15.326994817100104,
           15.07950989925321,
           14.832024981406317,
           14.587415090766802,
           14.349943198011621,
           14.112471305256491,
           13.874999412501337,
           13.63752751974614,
           13.400055626990996,
           13.164275390547266,
           12.937195105368833,
           12.710114820190434,
           12.483034535012013,
           12.25595424983358,
           12.028873964655148,
           11.80850826450295,
           11.590540628971217,
           11.372572993439464,
           11.15460535790776,
           10.936637722376037,
           10.726996540469543,
           10.518319068108257,
           10.309641595746914,
           10.100964123385587,
           9.898935870427763,
           9.702321982535484,
           9.505708094643179,
           9.309094206750876,
           9.12075482660509,
           8.93729149746651,
           8.75382816832793,
           8.57122679430644,
           8.39983082975243,
           8.228434865198393,
           8.057038900644368,
           7.894762589412654,
           7.734362750184285,
           7.573962910955908,
           7.422226973361688,
           7.271869384365109,
           7.122775355447153,
           6.9815785740827545,
           6.840381792718347,
           6.704432933377776,
           6.57161264288644,
           6.441172937334899,
           6.316174569583849,
           6.192550922120811,
           6.076666438022958,
           5.962248892150727,
           5.856259572381137,
           5.752239668819621,
           5.65325271820436,
           5.557037083570299,
           5.463215449996007,
           5.375326870360648,
           5.290637395422258,
           5.210325511555506,
           5.135714704680582,
           5.064648301590019,
           4.992010962906453,
           4.90956383837511,
           4.82711671384375,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           67.16748274383858,
           67.21552504037636,
           67.26356733691412,
           67.31160963345191,
           67.35965192998968,
           67.40769422652745,
           67.45573652306524,
           67.503778819603,
           67.55182111614079,
           67.59986341267856,
           67.64790570921633,
           67.69594800575412,
           67.74399030229188,
           67.79203259882966,
           67.84007489536744,
           67.88811719190522,
           67.936159488443,
           67.98420178498075,
           68.03224408151854,
           68.08028637805631,
           68.12832867459409,
           68.17637097113187,
           68.22441326766963,
           68.27245556420742,
           68.32049786074519,
           68.36854015728296,
           68.41658245382075,
           68.46462475035852,
           68.5126670468963,
           68.56070934343407,
           68.60875163997184,
           68.65679393650963,
           68.70483623304739,
           68.75287852958517,
           68.80092082612295,
           68.84896312266073,
           68.8970054191985,
           68.94504771573628,
           68.99309001227405,
           69.04113230881183,
           69.0891746053496,
           69.13721690188738,
           69.1853462567425,
           69.23391090642201,
           69.28247555610152,
           69.33104020578102,
           69.37960485546051,
           69.42816950514003,
           69.47673415481952,
           69.52529880449903,
           69.57386345417854,
           69.62242810385803,
           69.67099275353755,
           69.71955740321704,
           69.76812205289654,
           69.81668670257605,
           69.86525135225554,
           69.91381600193506,
           69.96238065161455,
           70.01094530129406,
           70.05950995097356,
           70.10807460065307,
           70.15663925033257,
           70.20520390001207,
           70.25376854969159,
           70.30233319937108,
           70.35089784905058,
           70.39946249873009,
           70.4480271484096,
           70.4965917980891,
           70.5451564477686,
           70.5937210974481,
           70.6422857471276,
           70.69085039680711,
           70.73941504648661,
           70.78797969616612,
           70.83654434584562,
           70.88510899552512,
           70.93367364520462,
           70.98223829488413,
           71.03080294456363,
           71.07936759424314,
           71.12793224392263,
           71.17649689360215,
           71.21020218789145,
           71.24093561110274,
           71.27166903431402,
           71.30240245752532,
           71.33313588073659,
           71.36386930394787,
           71.39460272715915,
           71.42533615037044,
           71.45606957358173,
           71.486802996793,
           71.51753642000429,
           71.54826984321556,
           71.57900326642687,
           71.60973668963814,
           71.64047011284943,
           71.67120353606072,
           71.70193695927199,
           71.73267038248328,
           71.76340380569457,
           71.79413722890584,
           71.82487065211713,
           71.85560407532842,
           71.88633749853969,
           71.91707092175098,
           71.94780434496225,
           71.97853776817354,
           72.00927119138481,
           72.0400046145961,
           72.07073803780739,
           72.10147146101868,
           72.13220488422996,
           72.16293830744124,
           72.19367173065251,
           72.2244051538638,
           72.25513857707509,
           72.28587200028637,
           72.31660542349766,
           72.34733884670894,
           72.37807226992021,
           72.4088056931315,
           72.43953911634279,
           72.46915391759276,
           72.49765010150377,
           72.52614628541477,
           72.55464246932577,
           72.58313865323677,
           72.61163483714778,
           72.64013102105878,
           72.6686272049698,
           72.69712338888078,
           72.72561957279179,
           72.75411575670279,
           72.78261194061379,
           72.8111081245248,
           72.83960430843581,
           72.8681004923468,
           72.89659667625781,
           72.9250928601688,
           72.95358904407982,
           72.98208522799082,
           73.01058141190182,
           73.03907759581283,
           73.06757377972383,
           73.09606996363483,
           73.12456614754583,
           73.15306233145684,
           73.18155851536784,
           73.21005469927884,
           73.23855088318984,
           73.26704706710085,
           73.29554325101185,
           73.32403943492285,
           73.35253561883385,
           73.38103180274487,
           73.40952798665586,
           73.43802417056686,
           73.46652035447786,
           73.49501653838887,
           73.52351272229988,
           73.55200890621089,
           73.58050509012187,
           73.60900127403289,
           73.63749745794388,
           73.50517702322468,
           73.29244827919037,
           73.07971953515604,
           72.86699079112172,
           72.65426204708741,
           72.44153330305312,
           72.2288045590188,
           72.01607581498446,
           71.80334707095015,
           71.59061832691584,
           71.37788958288154,
           71.16516083884723,
           70.9524320948129,
           70.7397033507786,
           70.52697460674429,
           70.31424586270998,
           70.10151711867564,
           69.88878837464134,
           69.67605963060703,
           69.46333088657272,
           69.2506021425384,
           69.03787339850409,
           68.82514465446978,
           68.61241591043546,
           68.39968716640115,
           68.18695842236683,
           67.97422967833252,
           67.76150093429821,
           67.54877219026389,
           67.33604344622958,
           67.12331470219527,
           66.91058595816094,
           66.69785721412664,
           66.48512847009232,
           66.27239972605801,
           66.0596709820237,
           65.84694223798938,
           65.63421349395507,
           65.42148474992075,
           65.20875600588644,
           64.99602726185213,
           64.78329851781783,
           64.57056977378349,
           64.3578410297492,
           64.14511228571487,
           63.93238354168056,
           63.71965479764624,
           63.506926053611934,
           63.29419730957761,
           63.0814685655433,
           62.86873982150898,
           62.65601107747468,
           62.443282333440365,
           62.23055358940605,
           62.017824845371734,
           61.805096101337426,
           61.59236735730311,
           61.3796386132688,
           61.16690986923448,
           60.95418112520017,
           60.74145238116586,
           60.52872363713154,
           60.31599489309722,
           60.10326614906292,
           59.8905374050286,
           59.67780866099428,
           59.46507991695997,
           59.25235117292565,
           59.039622428891334,
           58.82689368485703,
           58.61416494082272,
           58.401436196788396,
           58.18870745275409,
           57.97597870871977,
           57.76324996468547,
           57.550521220651156,
           57.33779247661684,
           57.12506373258252,
           56.91233498854821,
           56.699606244513895,
           56.48687750047958,
           56.274148756445264,
           56.06142001241095,
           55.623352590943824,
           54.98423975468682,
           54.34512691842991,
           53.706014082172985,
           53.06690124591601,
           52.42778840965908,
           51.788675573402166,
           51.149562737145175,
           50.51044990088821,
           49.871337064631355,
           49.23222422837438,
           48.5931113921174,
           47.95399855586049,
           47.31488571960356,
           46.67577288334658,
           46.036660047089654,
           45.39754721083274,
           44.75843437457576,
           44.16040206030005,
           44.303599968155815,
           44.44679787601158,
           44.58999578386736,
           44.7331936917231,
           44.87639159957888,
           45.01958950743466,
           45.162787415290424,
           45.30598532314619,
           45.44918323100195,
           45.59238113885772,
           45.735579046713475,
           45.87877695456926,
           46.02197486242504,
           46.16517277028078,
           46.08105694069149,
           45.787456495500486,
           45.49385605030953,
           45.2002556051185,
           44.9066551599275,
           44.61305471473654,
           44.31945426954555,
           44.02585382435455,
           43.732253379163595,
           43.43865293397265,
           43.1450524887816,
           42.851452043590605,
           42.55785159839966,
           42.26425115320866,
           41.97065070801765,
           41.67705026282666,
           41.38344981763571,
           41.08984937244467,
           40.796248927253714,
           40.50264848206277,
           40.209048036871756,
           39.91544759168072,
           39.62184714648981,
           39.328246701298816,
           39.03464625610781,
           38.74158681736328,
           38.45132257434019,
           38.16105833131708,
           37.870794088294026,
           37.58052984527093,
           37.290265602247864,
           37.00000135922477,
           36.70973711620168,
           36.41947287317858,
           36.129208630155475,
           35.838944387132386,
           35.548680144109326,
           35.25841590108622,
           34.96815165806313,
           34.67788741504007,
           34.38762317201693,
           34.09735892899387,
           33.80709468597081,
           33.516830442947715,
           33.22656619992462,
           32.936830300183324,
           32.650933698942886,
           32.36503709770248,
           32.07914049646205,
           31.793243895221625,
           31.507347293981184,
           31.221450692740788,
           30.93555409150036,
           30.64965749025992,
           30.36376088901949,
           30.077864287779065,
           29.791967686538655,
           29.506071085298217,
           29.220174484057832,
           28.934277882817355,
           28.648381281576913,
           28.362484680336518,
           28.0817261758308,
           27.801647091160035,
           27.52156800648936,
           27.241488921818647,
           26.961409837147926,
           26.681330752477212,
           26.401251667806534,
           26.12117258313581,
           25.841093498465085,
           25.561014413794368,
           25.280935329123697,
           25.00085624445297,
           24.72077715978229,
           24.444294075385567,
           24.172032379730005,
           23.89977068407445,
           23.627508988418935,
           23.35524729276337,
           23.08298559710778,
           22.81072390145227,
           22.538462205796705,
           22.266200510141143,
           21.99393881448562,
           21.721677118830073,
           21.450802907204398,
           21.186339829382526,
           20.92187675156068,
           20.657413673738766,
           20.392950595916925,
           20.12848751809505,
           19.86402444027319,
           19.599561362451308,
           19.33509828462943,
           19.070635206807587,
           18.81063277577453,
           18.554099738813015,
           18.2975667018515,
           18.041033664889948,
           17.78450062792841,
           17.527967590966867,
           17.271434554005314,
           17.014901517043764,
           16.76081003732375,
           16.513325119476846,
           16.265840201629942,
           16.01835528378305,
           15.770870365936178,
           15.52338544808927,
           15.275900530242378,
           15.028861737484112,
           14.791389844728956,
           14.553917951973792,
           14.316446059218649,
           14.078974166463452,
           13.841502273708272,
           13.60403038095314,
           13.373760113150698,
           13.146679827972264,
           12.919599542793865,
           12.692519257615443,
           12.465438972437012,
           12.238958204798646,
           12.020990569266925,
           11.80302293373519,
           11.585055298203455,
           11.367087662671764,
           11.14954405982329,
           10.94086658746198,
           10.732189115100667,
           10.52351164273937,
           10.314834170378045,
           10.112663434124904,
           9.916049546232616,
           9.719435658340311,
           9.522821770448008,
           9.332413763040517,
           9.14895043390195,
           8.965487104763355,
           8.782023775624813,
           8.607998850023147,
           8.436602885469123,
           8.265206920915132,
           8.098427077122901,
           7.9380272378945325,
           7.777627398666177,
           7.620673429069225,
           7.470315840072647,
           7.319958251076068,
           7.174339011275027,
           7.033142229910619,
           6.891945448546193,
           6.758393476655417,
           6.625573186164047,
           6.4966978651515985,
           6.371699497400565,
           6.249170534302056,
           6.133286050204174,
           6.0193219215696745,
           5.913332601800105,
           5.809148580207196,
           5.710161629591928,
           5.613490614354381,
           5.51966898078007,
           5.430802249031456,
           5.344686368027298,
           5.264374484160545,
           5.188169069062558,
           5.115416768754063,
           5.046703344409626,
           4.965237198463051,
           4.882790073931689,
           4.8003429494003464,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           67.2342897977632,
           67.28233209430098,
           67.33037439083876,
           67.37841668737653,
           67.4264589839143,
           67.47450128045207,
           67.52254357698985,
           67.57058587352762,
           67.6186281700654,
           67.66667046660318,
           67.71471276314095,
           67.76275505967874,
           67.81079735621651,
           67.85883965275428,
           67.90688194929206,
           67.95492424582983,
           68.00296654236762,
           68.05100883890539,
           68.09905113544316,
           68.14709343198093,
           68.19513572851871,
           68.2431780250565,
           68.29122032159427,
           68.33926261813204,
           68.38730491466981,
           68.43534721120758,
           68.48338950774536,
           68.53143180428314,
           68.57947410082092,
           68.62751639735869,
           68.67555869389646,
           68.72360099043425,
           68.77164328697202,
           68.8196855835098,
           68.86772788004757,
           68.91577017658534,
           68.96381247312313,
           69.01185476966089,
           69.05989706619867,
           69.10793936273646,
           69.15598165927423,
           69.204023955812,
           69.25206625234978,
           69.30010854888755,
           69.34815084542532,
           69.39619314196311,
           69.44423543850087,
           69.49227773503866,
           69.54032003157644,
           69.5883623281142,
           69.63640462465199,
           69.68444692118976,
           69.73248921772753,
           69.7805315142653,
           69.82857381080308,
           69.87661610734087,
           69.92465840387864,
           69.97270070041642,
           70.0207429969542,
           70.06913352829397,
           70.1176981779735,
           70.166262827653,
           70.21482747733249,
           70.263392127012,
           70.31195677669149,
           70.36052142637101,
           70.4090860760505,
           70.45765072573,
           70.50621537540951,
           70.55478002508902,
           70.60334467476852,
           70.65190932444803,
           70.70047397412753,
           70.74903862380702,
           70.79760327348653,
           70.84616792316604,
           70.89473257284554,
           70.94329722252505,
           70.99186187220455,
           71.04042652188406,
           71.08899117156355,
           71.13755582124305,
           71.18612047092256,
           71.23468512060207,
           71.26839041489137,
           71.29912383810266,
           71.32985726131395,
           71.36059068452523,
           71.39132410773651,
           71.4220575309478,
           71.45279095415907,
           71.48352437737037,
           71.51425780058165,
           71.54499122379293,
           71.57572464700422,
           71.6064580702155,
           71.63719149342678,
           71.66792491663806,
           71.69865833984935,
           71.72939176306065,
           71.7601251862719,
           71.79085860948321,
           71.82159203269447,
           71.85232545590577,
           71.88305887911704,
           71.91379230232833,
           71.94452572553962,
           71.9752591487509,
           72.00599256928187,
           72.03448875319287,
           72.06298493710388,
           72.09148112101488,
           72.11997730492588,
           72.14847348883688,
           72.17696967274789,
           72.20546585665889,
           72.23396204056988,
           72.2624582244809,
           72.2909544083919,
           72.3194505923029,
           72.34794677621392,
           72.3764429601249,
           72.40493914403591,
           72.43343532794691,
           72.46193151185791,
           72.49042769576891,
           72.51892387967992,
           72.54742006359092,
           72.57591624750194,
           72.60441243141292,
           72.63290861532393,
           72.66140479923493,
           72.68990098314595,
           72.71839716705693,
           72.74689335096795,
           72.77538953487894,
           72.80388571878996,
           72.83238190270096,
           72.86087808661196,
           72.88937427052296,
           72.91787045443397,
           72.94636663834497,
           72.97486282225597,
           73.00335900616697,
           73.03185519007798,
           73.06035137398898,
           73.08884755789998,
           73.117343741811,
           73.14583992572199,
           73.17433610963299,
           73.20283229354399,
           73.231328477455,
           73.25982466136601,
           73.288320845277,
           73.316817029188,
           73.34531321309902,
           73.37380939701,
           73.40230558092102,
           73.43080176483203,
           73.45929794874301,
           73.48779413265402,
           73.51629031656503,
           73.54478650047602,
           73.57328268438704,
           73.60177886829804,
           73.63027505220904,
           73.65877123612003,
           73.52645080140083,
           73.31372205736653,
           73.10099331333221,
           72.8882645692979,
           72.67553582526358,
           72.46280708122926,
           72.25007833719495,
           72.03734959316063,
           71.82462084912632,
           71.61189210509201,
           71.39916336105769,
           71.18643461702338,
           70.97370587298906,
           70.76097712895475,
           70.54824838492044,
           70.33551964088613,
           70.12279089685182,
           69.9100621528175,
           69.69733340878318,
           69.48460466474887,
           69.27187592071456,
           69.05914717668024,
           68.84641843264593,
           68.63368968861161,
           68.42096094457732,
           68.20823220054298,
           67.99550345650867,
           67.78277471247436,
           67.57004596844004,
           67.35731722440573,
           67.14458848037143,
           66.9318597363371,
           66.7191309923028,
           66.50640224826849,
           66.29367350423416,
           66.08094476019986,
           65.86821601616553,
           65.65548727213124,
           65.44275852809692,
           65.2300297840626,
           65.01730104002829,
           64.80457229599398,
           64.59184355195966,
           64.37911480792535,
           64.16638606389103,
           63.95365731985671,
           63.74092857582241,
           63.52819983178809,
           63.31547108775378,
           63.10274233744545,
           62.865720258268226,
           62.62869817909102,
           62.39167609991381,
           62.15465402073659,
           61.91763194155938,
           61.68060986238218,
           61.44358778320495,
           61.20656570402774,
           60.969543624850516,
           60.7325215456733,
           60.4954994664961,
           60.25847738731888,
           60.02145530814167,
           59.784433228964446,
           59.547411149787244,
           59.31038907061002,
           59.07336699143281,
           58.83634491225559,
           58.599322833078375,
           58.362300753901174,
           58.12527867472396,
           57.888256595546736,
           57.65123451636952,
           57.414212437192305,
           57.1771903580151,
           56.94016827883789,
           56.703146199660665,
           56.46612412048345,
           56.22910204130624,
           55.992079962129026,
           55.75505788295181,
           55.518035803774595,
           55.28101372459738,
           54.84294626688033,
           54.203833430623334,
           53.56472059436642,
           52.9256077581095,
           52.28649492185252,
           51.64738208559559,
           51.008269249338674,
           50.36915641308169,
           49.73004357682473,
           49.09093074056787,
           48.451817904310886,
           47.812705068053916,
           47.173592231797,
           46.534479395540075,
           46.196324299077865,
           46.33952220693362,
           46.48272011478939,
           46.62591802264517,
           46.76911593050093,
           46.91231383835669,
           47.05551174621246,
           47.19870965406824,
           47.34190756192399,
           47.48510546977976,
           47.62830337763555,
           47.655615688287135,
           47.36201524309619,
           47.068414797905184,
           46.774814352714195,
           46.48121390752324,
           46.18761346233224,
           45.89401301714124,
           45.60041257195025,
           45.30681212675929,
           45.013211681568286,
           44.71961123637735,
           44.42601079118631,
           44.132410345995304,
           43.83880990080435,
           43.54520945561335,
           43.25160901042236,
           42.9580085652314,
           42.664408120040456,
           42.37080767484941,
           42.077207229658406,
           41.78360678446746,
           41.49000633927646,
           41.19640589408546,
           40.90280544889446,
           40.609205003703515,
           40.31560455851247,
           40.02200411403569,
           39.731739871012635,
           39.441475627989526,
           39.15121138496642,
           38.86094714194334,
           38.57068289892023,
           38.28041865589714,
           37.99015441287408,
           37.69989016985098,
           37.40962592682788,
           37.11936168380482,
           36.82909744078173,
           36.53883319775866,
           36.24856895473557,
           35.95830471171248,
           35.66804046868937,
           35.37777622566627,
           35.087511982643186,
           34.79724773962012,
           34.506983496597016,
           34.21671925357393,
           33.927511697579455,
           33.64161509633902,
           33.355718495098586,
           33.06982189385819,
           32.78392529261775,
           32.498028691377314,
           32.21213209013689,
           31.92623548889645,
           31.640338887656046,
           31.354442286415615,
           31.068545685175188,
           30.782649083934743,
           30.49675248269435,
           30.210855881453924,
           29.924959280213482,
           29.639062678973055,
           29.353166077732624,
           29.06973236481144,
           28.789653280140715,
           28.50957419547005,
           28.22949511079929,
           27.9494160261286,
           27.669336941457885,
           27.38925785678721,
           27.10917877211645,
           26.829099687445773,
           26.549020602775062,
           26.268941518104338,
           25.988862433433624,
           25.708783348762942,
           25.42870426409222,
           25.152690223083866,
           24.880428527428315,
           24.608166831772763,
           24.335905136117233,
           24.06364344046168,
           23.791381744806163,
           23.519120049150597,
           23.246858353495046,
           22.974596657839527,
           22.702334962183965,
           22.43007326652837,
           22.157811570872862,
           21.892056697329902,
           21.62759361950799,
           21.363130541686143,
           21.098667463864267,
           20.834204386042384,
           20.569741308220514,
           20.305278230398667,
           20.04081515257675,
           19.77635207475491,
           19.51188899693303,
           19.254364703626138,
           18.997831666664585,
           18.741298629703046,
           18.484765592741528,
           18.228232555779954,
           17.971699518818433,
           17.715166481856922,
           17.45863344489537,
           17.20468558615979,
           16.957200668312893,
           16.709715750466014,
           16.462230832619085,
           16.214745914772227,
           15.967260996925319,
           15.719776079078416,
           15.47229116123152,
           15.232836491446246,
           14.995364598691069,
           14.757892705935905,
           14.52042081318074,
           14.282948920425586,
           14.045477027670422,
           13.810325120932546,
           13.58324483575411,
           13.356164550575677,
           13.129084265397292,
           12.90200398021886,
           12.674923695040423,
           12.4514405095626,
           12.233472874030877,
           12.015505238499143,
           11.79753760296744,
           11.579569967435717,
           11.36341410681573,
           11.154736634454387,
           10.946059162093121,
           10.737381689731777,
           10.528704217370464,
           10.326390997821994,
           10.129777109929718,
           9.933163222037397,
           9.736549334145131,
           9.544072699475944,
           9.360609370337349,
           9.177146041198782,
           8.993682712060224,
           8.816166870293863,
           8.644770905739852,
           8.47337494118586,
           8.302091564833159,
           8.14169172560479,
           7.9812918863764555,
           7.820892047148076,
           7.668762295780175,
           7.518404706783606,
           7.368047117787047,
           7.225902667102863,
           7.084705885738456,
           6.945174310424385,
           6.812354019933023,
           6.679533729441663,
           6.552222792968315,
           6.427224425217263,
           6.305790146483266,
           6.189905662385412,
           6.076394950988648,
           5.970405631219059,
           5.86605749159477,
           5.767070540979522,
           5.669944145138441,
           5.576122511564135,
           5.486277627702275,
           5.399030459179428,
           5.318423456765564,
           5.240623433444549,
           5.166464197210219,
           5.097471811573667,
           5.020910558550986,
           4.938463434019641,
           4.856016309488282,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           67.30109685168782,
           67.34913914822559,
           67.39718144476336,
           67.44522374130115,
           67.49326603783892,
           67.5413083343767,
           67.58935063091447,
           67.63739292745224,
           67.68543522399001,
           67.7334775205278,
           67.78151981706557,
           67.82956211360334,
           67.87760441014112,
           67.92564670667889,
           67.97368900321668,
           68.02173129975445,
           68.06977359629222,
           68.11781589283,
           68.16585818936777,
           68.21390048590555,
           68.26194278244333,
           68.3099850789811,
           68.35802737551887,
           68.40606967205665,
           68.45411196859442,
           68.50215426513219,
           68.55019656166998,
           68.59823885820775,
           68.64628115474552,
           68.69432345128331,
           68.74236574782108,
           68.79040804435886,
           68.83845034089663,
           68.8864926374344,
           68.93453493397217,
           68.98257723050996,
           69.03061952704773,
           69.07866182358552,
           69.12670412012329,
           69.17474641666107,
           69.22278871319884,
           69.27083100973661,
           69.31887330627438,
           69.36691560281217,
           69.41495789934994,
           69.46300019588773,
           69.5110424924255,
           69.55908478896328,
           69.60712708550105,
           69.65516938203882,
           69.7032116785766,
           69.75125397511437,
           69.79929627165215,
           69.84733856818993,
           69.8953808647277,
           69.94342316126549,
           69.99146545780326,
           70.03950775434103,
           70.0875500508788,
           70.13559234741658,
           70.18363464395435,
           70.23167694049212,
           70.27971923702991,
           70.32776153356768,
           70.37580383010545,
           70.42384612664324,
           70.47188842318101,
           70.51993071971877,
           70.56797301625656,
           70.61601531279433,
           70.66405760933212,
           70.71209990586989,
           70.76014220240766,
           70.80818449894544,
           70.85622679548321,
           70.90435615016597,
           70.95292079984546,
           71.00148544952498,
           71.05005009920447,
           71.09861474888397,
           71.14717939856348,
           71.19574404824297,
           71.24430869792249,
           71.29287334760198,
           71.32657864189132,
           71.3573120651026,
           71.38804548831388,
           71.41877891152515,
           71.44951233473644,
           71.48024575794773,
           71.510979181159,
           71.54171260437029,
           71.57132740488197,
           71.59982358879297,
           71.62831977270397,
           71.65681595661498,
           71.68531214052598,
           71.71380832443698,
           71.74230450834798,
           71.77080069225899,
           71.79929687616999,
           71.827793060081,
           71.856289243992,
           71.88478542790301,
           71.91328161181401,
           71.94177779572502,
           71.97027397963602,
           71.99877016354702,
           72.02726634745802,
           72.05576253136903,
           72.08425871528003,
           72.11275489919103,
           72.14125108310203,
           72.16974726701304,
           72.19824345092404,
           72.22673963483504,
           72.25523581874604,
           72.28373200265705,
           72.31222818656805,
           72.34072437047905,
           72.36922055439007,
           72.39771673830106,
           72.42621292221207,
           72.45470910612306,
           72.48320529003408,
           72.51170147394507,
           72.54019765785608,
           72.56869384176707,
           72.59719002567809,
           72.62568620958908,
           72.65418239350008,
           72.68267857741108,
           72.7111747613221,
           72.73967094523309,
           72.7681671291441,
           72.79666331305509,
           72.82515949696611,
           72.85365568087711,
           72.88215186478811,
           72.91064804869912,
           72.93914423261012,
           72.96764041652112,
           72.99613660043212,
           73.02463278434313,
           73.05312896825413,
           73.08162515216513,
           73.11012133607613,
           73.13861751998714,
           73.16711370389814,
           73.19560988780914,
           73.22410607172014,
           73.25260225563115,
           73.28109843954215,
           73.30959462345317,
           73.33809080736415,
           73.36658699127516,
           73.39508317518617,
           73.42357935909718,
           73.45207554300818,
           73.48057172691918,
           73.50906791083017,
           73.53756409474119,
           73.56606027865219,
           73.59455646256319,
           73.62305264647419,
           73.6515488303852,
           73.68004501429618,
           73.54772457957698,
           73.33499583554267,
           73.12226709150836,
           72.90953834747404,
           72.69680960343973,
           72.48408085940542,
           72.2713521153711,
           72.0586233713368,
           71.84589462730247,
           71.63316588326816,
           71.42043713923384,
           71.20770839519955,
           70.99497965116522,
           70.7822509071309,
           70.5695221630966,
           70.35679341906229,
           70.14406462623005,
           69.90704254705284,
           69.67002046787562,
           69.43299838869841,
           69.1959763095212,
           68.95895423034398,
           68.72193215116678,
           68.48491007198955,
           68.24788799281234,
           68.01086591363513,
           67.7738438344579,
           67.53682175528071,
           67.29979967610349,
           67.06277759692627,
           66.82575551774906,
           66.58873343857184,
           66.35171135939463,
           66.11468928021742,
           65.8776672010402,
           65.64064512186299,
           65.40362304268578,
           65.16660096350856,
           64.92957888433135,
           64.69255680515414,
           64.45553472597692,
           64.21851264679971,
           63.981490567622494,
           63.74446848844528,
           63.50744640926806,
           63.27042433009085,
           63.03340225091363,
           62.796380171736416,
           62.55935809255921,
           62.32233601338199,
           62.08531393420477,
           61.84829185502757,
           61.61126977585035,
           61.37424769667313,
           61.137225617495915,
           60.90020353831871,
           60.6631814591415,
           60.42615937996428,
           60.18913730078705,
           59.95211522160985,
           59.71509314243264,
           59.47807106325542,
           59.24104898407821,
           59.00402690490098,
           58.76700482572379,
           58.52998274654657,
           58.29296066736935,
           58.055938588192134,
           57.818916509014926,
           57.58189442983771,
           57.344872350660495,
           57.10785027148329,
           56.870828192306064,
           56.633806113128855,
           56.39678403395165,
           56.159761954774424,
           55.922739875597216,
           55.68571779641999,
           55.448695717242785,
           55.21167363806557,
           54.974651558888354,
           54.73762947971114,
           54.50060740053392,
           54.062539942816876,
           53.423427106559885,
           52.78431427030297,
           52.14520143404604,
           51.506088597789066,
           50.86697576153213,
           50.227862925275225,
           49.588750089018234,
           48.94963725276127,
           48.31052441650441,
           48.23224653785557,
           48.37544444571134,
           48.51864235356712,
           48.661840261422874,
           48.805038169278646,
           48.9482360771344,
           49.091433984990175,
           49.23017443588291,
           48.936573990691926,
           48.64297354550092,
           48.34937310030996,
           48.055772655118965,
           47.762172209927975,
           47.46857176473697,
           47.174971319545975,
           46.88137087435498,
           46.587770429164024,
           46.29416998397302,
           46.00056953878203,
           45.70696909359108,
           45.41336864840008,
           45.11976820320907,
           44.82616775801809,
           44.532567312827126,
           44.23896686763613,
           43.945366422445176,
           43.65176597725414,
           43.35816553206314,
           43.064565086872186,
           42.770964641681196,
           42.47736419649019,
           42.18376375129924,
           41.89016330610829,
           41.596562860917246,
           41.30296241572625,
           41.012157167685075,
           40.721892924661965,
           40.43162868163886,
           40.14136443861581,
           39.85110019559272,
           39.560835952569605,
           39.270571709546516,
           38.98030746652346,
           38.69004322350035,
           38.39977898047725,
           38.10951473745417,
           37.81925049443107,
           37.52898625140796,
           37.238722008384904,
           36.948457765361816,
           36.658193522338706,
           36.367929279315646,
           36.07766503629256,
           35.78740079326949,
           35.497136550246395,
           35.20687230722331,
           34.91819309497558,
           34.63229649373513,
           34.34639989249475,
           34.060503291254314,
           33.77460669001387,
           33.48871008877347,
           33.20281348753305,
           32.916916886292604,
           32.63102028505217,
           32.345123683811785,
           32.05922708257134,
           31.773330481330913,
           31.487433880090485,
           31.20153727885004,
           30.915640677609638,
           30.62974407636921,
           30.34384747512878,
           30.057950873888338,
           29.777659469121435,
           29.49758038445072,
           29.217501299779993,
           28.937422215109283,
           28.657343130438573,
           28.377264045767877,
           28.097184961097156,
           27.81710587642649,
           27.537026791755732,
           27.256947707085036,
           26.976868622414326,
           26.696789537743648,
           26.416710453072888,
           26.136631368402213,
           25.861086370782246,
           25.58882467512668,
           25.31656297947116,
           25.04430128381561,
           24.772039588160048,
           24.499777892504483,
           24.22751619684893,
           23.955254501193384,
           23.68299280553785,
           23.4107311098823,
           23.13846941422678,
           22.866207718571218,
           22.597773565277244,
           22.33331048745537,
           22.068847409633488,
           21.804384331811626,
           21.539921253989768,
           21.275458176167913,
           21.010995098345997,
           20.74653202052415,
           20.48206894270228,
           20.217605864880397,
           19.954629668439278,
           19.69809663147774,
           19.44156359451619,
           19.185030557554647,
           18.928497520593105,
           18.671964483631584,
           18.415431446670027,
           18.15889840970849,
           17.902365372746974,
           17.648561134995823,
           17.401076217148958,
           17.153591299302086,
           16.906106381455157,
           16.658621463608288,
           16.411136545761394,
           16.16365162791451,
           15.916166710067582,
           15.674283138163558,
           15.436811245408379,
           15.199339352653205,
           14.96186745989806,
           14.724395567142897,
           14.486923674387718,
           14.249451781632555,
           14.019809843535976,
           13.792729558357543,
           13.565649273179144,
           13.338568988000723,
           13.11148870282229,
           12.884408417643856,
           12.663922814326602,
           12.445955178794868,
           12.227987543263115,
           12.010019907731413,
           11.79205227219969,
           11.57728415380817,
           11.368606681446856,
           11.159929209085558,
           10.951251736724233,
           10.74257426436289,
           10.540118561519122,
           10.343504673626834,
           10.14689078573453,
           9.950276897842237,
           9.755731635911356,
           9.57226830677279,
           9.38880497763423,
           9.205341648495665,
           9.024334890564607,
           8.85293892601058,
           8.681542961456579,
           8.510146996902554,
           8.34535621331505,
           8.184956374086703,
           8.024556534858347,
           7.867208751487713,
           7.716851162491163,
           7.5664935734945935,
           7.418663104295126,
           7.27746632293071,
           7.13626954156632,
           6.999134853702,
           6.866314563210638,
           6.7334942727193035,
           6.607747720785014,
           6.482749353033963,
           6.362409758664504,
           6.246525274566628,
           6.133467980407596,
           6.027478660638026,
           5.922966402982357,
           5.823979452367096,
           5.72639767592251,
           5.632576042348212,
           5.541753006373089,
           5.4545058378502365,
           5.3724724293706085,
           5.29307779782652,
           5.2189185615921945,
           5.148240278737728,
           5.076583918638942,
           4.994136794107582,
           4.911689669576221,
           4.8292425450448775,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           67.36311773599539,
           67.41001170998855,
           67.45690568398173,
           67.50379965797491,
           67.55069363196807,
           67.59758760596125,
           67.64448157995442,
           67.6913755539476,
           67.73826952794077,
           67.78612043603675,
           67.83416273257453,
           67.88220502911231,
           67.93024732565007,
           67.97828962218784,
           68.02633191872563,
           68.0743742152634,
           68.12241651180118,
           68.17045880833896,
           68.21850110487674,
           68.26654340141451,
           68.31458569795228,
           68.36262799449005,
           68.41067029102784,
           68.45871258756561,
           68.50675488410339,
           68.55479718064116,
           68.60283947717893,
           68.65088177371672,
           68.69892407025449,
           68.74696636679226,
           68.79500866333004,
           68.84305095986782,
           68.8910932564056,
           68.93913555294337,
           68.98717784948114,
           69.03522014601893,
           69.0832624425567,
           69.13130473909447,
           69.17934703563225,
           69.22738933217002,
           69.27543162870779,
           69.32347392524557,
           69.37151622178335,
           69.41955851832113,
           69.4676008148589,
           69.51564311139668,
           69.56368540793446,
           69.61172770447223,
           69.65977000101,
           69.70781229754778,
           69.75585459408555,
           69.80389689062334,
           69.8519391871611,
           69.89998148369888,
           69.94802378023667,
           69.99606607677443,
           70.04410837331221,
           70.09215066984999,
           70.14019296638776,
           70.18823526292555,
           70.2362775594633,
           70.28431985600109,
           70.33236215253886,
           70.38040444907664,
           70.42844674561442,
           70.4764890421522,
           70.52453133868997,
           70.57257363522774,
           70.62061593176551,
           70.6686582283033,
           70.71670052484107,
           70.76474282137886,
           70.81278511791663,
           70.8608274144544,
           70.90886971099218,
           70.95691200752995,
           71.00495430406772,
           71.0529966006055,
           71.10103889714327,
           71.14908119368106,
           71.19712349021883,
           71.2451657867566,
           71.29320808329439,
           71.34125037983216,
           71.37300424918095,
           71.40150043309195,
           71.42999661700296,
           71.45849280091396,
           71.48698898482496,
           71.51548516873598,
           71.54398135264697,
           71.57247753655797,
           71.60097372046897,
           71.62946990437999,
           71.65796608829099,
           71.68646227220198,
           71.714958456113,
           71.74345464002398,
           71.771950823935,
           71.800447007846,
           71.828943191757,
           71.85743937566801,
           71.88593555957901,
           71.91443174349001,
           71.94292792740102,
           71.97142411131202,
           71.99992029522302,
           72.02841647913402,
           72.05691266304503,
           72.08540884695603,
           72.11390503086703,
           72.14240121477803,
           72.17089739868905,
           72.19939358260004,
           72.22788976651104,
           72.25638595042204,
           72.28488213433305,
           72.31337831824405,
           72.34187450215506,
           72.37037068606605,
           72.39886686997707,
           72.42736305388806,
           72.45585923779907,
           72.48435542171008,
           72.51285160562107,
           72.54134778953207,
           72.56984397344308,
           72.59834015735409,
           72.62683634126509,
           72.65533252517609,
           72.6838287090871,
           72.7123248929981,
           72.7408210769091,
           72.7693172608201,
           72.7978134447311,
           72.82630962864211,
           72.85480581255311,
           72.88330199646411,
           72.91179818037511,
           72.94029436428612,
           72.96879054819712,
           72.99728673210812,
           73.02578291601912,
           73.05427909993013,
           73.08277528384113,
           73.11127146775215,
           73.13976765166313,
           73.16826383557414,
           73.19676001948514,
           73.22525620339616,
           73.25375238730716,
           73.28224857121816,
           73.31074475512916,
           73.33924093904017,
           73.36773712295117,
           73.39623330686217,
           73.42472949077317,
           73.45322567468416,
           73.48172185859518,
           73.50857525399535,
           73.53510009447653,
           73.56162493495773,
           73.58814977543892,
           73.61467461592011,
           73.6411994564013,
           73.66772429688248,
           73.69424913736368,
           73.53402895024583,
           73.28043624932847,
           73.02684354841112,
           72.77325084749376,
           72.51965814657642,
           72.26606544565905,
           72.0124727447417,
           71.75888004382432,
           71.50528734290697,
           71.25169464198962,
           70.99810194107226,
           70.74450924015491,
           70.49091653923755,
           70.23732383832018,
           69.98373113740284,
           69.73013843648548,
           69.47654573556812,
           69.22295303465076,
           68.9693603337334,
           68.71576763281605,
           68.46217493189869,
           68.20858223098134,
           67.95498953006398,
           67.70450374792608,
           67.46748166874889,
           67.23045958957168,
           66.99343751039446,
           66.75641543121725,
           66.51939335204003,
           66.28237127286282,
           66.04534919368561,
           65.80832711450839,
           65.57130503533118,
           65.33428295615397,
           65.09726087697675,
           64.86023879779952,
           64.62321671862232,
           64.38619463944511,
           64.14917256026789,
           63.91215048109067,
           63.675128401913476,
           63.438106322736246,
           63.20108424355903,
           62.96406216438183,
           62.72704008520461,
           62.49001800602739,
           62.252995926850176,
           62.01597384767297,
           61.778951768495745,
           61.541929689318536,
           61.30490761014131,
           61.06788553096411,
           60.8308634517869,
           60.593841372609674,
           60.356819293432466,
           60.11979721425526,
           59.882775135078035,
           59.645753055900826,
           59.408730976723604,
           59.171708897546395,
           58.93468681836919,
           58.697664739191964,
           58.46064266001475,
           58.22362058083753,
           57.986598501660325,
           57.749576422483116,
           57.512554343305894,
           57.275532264128685,
           57.03851018495146,
           56.801488105774254,
           56.56446602659704,
           56.32744394741982,
           56.090421868242615,
           55.85339978906539,
           55.61637770988819,
           55.37935563071097,
           55.14233355153375,
           54.90531147235654,
           54.66828939317933,
           54.43126731400211,
           54.194245234824905,
           53.95722315564768,
           53.72020107647046,
           53.28213361875342,
           52.64302078249642,
           52.00390794623951,
           51.36479510998259,
           50.7256822737256,
           50.12497086877752,
           50.26816877663329,
           50.41136668448905,
           50.55456459234483,
           50.69776250020057,
           50.51113273828764,
           50.21753229309659,
           49.92393184790569,
           49.630331402714695,
           49.33673095752369,
           49.043130512332695,
           48.74953006714175,
           48.455929621950744,
           48.162329176759755,
           47.86872873156875,
           47.5751282863778,
           47.2815278411868,
           46.98792739599581,
           46.6943269508048,
           46.400726505613804,
           46.10712606042281,
           45.81352561523186,
           45.51992517004086,
           45.22632472484987,
           44.93272427965891,
           44.63912383446791,
           44.34552338927691,
           44.05192294408592,
           43.75832249889496,
           43.46472205370396,
           43.17112160851302,
           42.87752116332198,
           42.583920718130976,
           42.292574464357536,
           42.00231022133444,
           41.712045978311295,
           41.42178173528825,
           41.131517492265154,
           40.841253249242044,
           40.55098900621894,
           40.2607247631959,
           39.97046052017279,
           39.68019627714969,
           39.38993203412664,
           39.09966779110354,
           38.80940354808043,
           38.519139305057344,
           38.22887506203429,
           37.93861081901118,
           37.64834657598808,
           37.358082332965,
           37.067818089941895,
           36.77755384691879,
           36.48728960389573,
           36.19702536087264,
           35.908874492371694,
           35.6229778911313,
           35.33708128989087,
           35.05118468865043,
           34.76528808740999,
           34.479391486169604,
           34.193494884929166,
           33.90759828368872,
           33.62170168244835,
           33.3358050812079,
           33.04990847996746,
           32.76401187872707,
           32.47811527748664,
           32.1922186762462,
           31.906322075005768,
           31.620425473765376,
           31.33452887252493,
           31.048632271284504,
           30.76566565810215,
           30.485586573431394,
           30.20550748876067,
           29.92542840408996,
           29.645349319419275,
           29.365270234748554,
           29.085191150077875,
           28.80511206540716,
           28.525032980736437,
           28.244953896065724,
           27.964874811395013,
           27.684795726724317,
           27.404716642053597,
           27.12463755738293,
           26.844558472712173,
           26.569482518480598,
           26.297220822825047,
           26.02495912716953,
           25.752697431513937,
           25.480435735858382,
           25.208174040202866,
           24.9359123445473,
           24.66365064889178,
           24.39138895323623,
           24.11912725758067,
           23.846865561925103,
           23.574603866269555,
           23.30349043322459,
           23.03902735540273,
           22.774564277580886,
           22.51010119975901,
           22.245638121937127,
           21.981175044115254,
           21.716711966293378,
           21.452248888471495,
           21.187785810649636,
           20.923322732827774,
           20.65885965500592,
           20.398361596290847,
           20.141828559329305,
           19.885295522367816,
           19.62876248540624,
           19.37222944844472,
           19.115696411483185,
           18.859163374521632,
           18.602630337560093,
           18.34609730059855,
           18.0924366838319,
           17.84495176598499,
           17.59746684813812,
           17.34998193029125,
           17.102497012444324,
           16.855012094597452,
           16.607527176750583,
           16.360042258903654,
           16.115729784880834,
           15.87825789212569,
           15.640785999370515,
           15.403314106615337,
           15.165842213860207,
           14.928370321105028,
           14.690898428349852,
           14.456374851317829,
           14.229294566139409,
           14.002214280960995,
           13.775133995782577,
           13.548053710604155,
           13.320973425425723,
           13.094372754622295,
           12.876405119090554,
           12.658437483558838,
           12.440469848027105,
           12.222502212495414,
           12.00453457696368,
           11.791154200800625,
           11.582476728439294,
           11.373799256077996,
           11.16512178371667,
           10.956444311355355,
           10.753846125216253,
           10.55723223732395,
           10.360618349431661,
           10.164004461539365,
           9.967390573647076,
           9.783927243208215,
           9.600463914069646,
           9.417000584931078,
           9.233537255792509,
           9.061106946281344,
           8.889710981727307,
           8.718315017173294,
           8.549020701025306,
           8.388620861796971,
           8.228221022568603,
           8.067821183340236,
           7.9152976181987,
           7.764940029202131,
           7.614582440205542,
           7.470226760123008,
           7.329029978758593,
           7.1878331973941645,
           7.053095396979614,
           6.92027510648828,
           6.788271016352764,
           6.663272648601721,
           6.538274280850687,
           6.419029370845713,
           6.303144886747845,
           6.190541009826576,
           6.084551690056985,
           5.979875314369938,
           5.880888363754689,
           5.782851206706592,
           5.689029573132281,
           5.597228385043897,
           5.509981216521066,
           5.426521401975627,
           5.3462095181088785,
           5.271372925974185,
           5.199008745901768,
           5.130295321557322,
           5.049810154195537,
           4.9673630296641775,
           4.884915905132817,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           67.42025477546761,
           67.46714874946078,
           67.51404272345395,
           67.56093669744712,
           67.6078306714403,
           67.65472464543348,
           67.70161861942664,
           67.74851259341982,
           67.79540656741298,
           67.84230054140616,
           67.88919451539932,
           67.9360884893925,
           67.98298246338567,
           68.02987643737885,
           68.07677041137202,
           68.12366438536519,
           68.17055835935837,
           68.21745233335153,
           68.26434630734471,
           68.31124028133787,
           68.35813425533105,
           68.40502822932423,
           68.4519222033174,
           68.49881617731056,
           68.54571015130375,
           68.59298689875351,
           68.64102919529128,
           68.68907149182905,
           68.73711378836683,
           68.7851560849046,
           68.83319838144239,
           68.88124067798017,
           68.92928297451793,
           68.97732527105572,
           69.02536756759349,
           69.07340986413126,
           69.12145216066904,
           69.16949445720681,
           69.2175367537446,
           69.26557905028235,
           69.31362134682014,
           69.36166364335791,
           69.4097059398957,
           69.45774823643347,
           69.50579053297125,
           69.55383282950902,
           69.60187512604679,
           69.64991742258456,
           69.69795971912235,
           69.74600201566012,
           69.7940443121979,
           69.84208660873568,
           69.89012890527344,
           69.93817120181123,
           69.986213498349,
           70.03425579488677,
           70.08229809142455,
           70.13034038796232,
           70.17838268450011,
           70.22642498103788,
           70.27446727757567,
           70.32250957411344,
           70.37055187065121,
           70.41859416718899,
           70.46663646372676,
           70.51467876026453,
           70.56272105680232,
           70.61076335334009,
           70.65880564987786,
           70.70684794641564,
           70.75489024295342,
           70.8029325394912,
           70.85097483602897,
           70.89901713256674,
           70.94705942910451,
           70.99510172564229,
           71.04314402218007,
           71.09118631871785,
           71.13922861525562,
           71.18727091179339,
           71.23531320833118,
           71.28335550486895,
           71.33139780140672,
           71.3794400979445,
           71.4111939672933,
           71.4396901512043,
           71.46818633511529,
           71.49668251902631,
           71.52517870293731,
           71.55367488684831,
           71.58217107075932,
           71.61066725467032,
           71.63916343858132,
           71.66765962249232,
           71.69615580640334,
           71.72465199031433,
           71.75314817422534,
           71.78164435813633,
           71.81014054204735,
           71.83863672595834,
           71.86713290986935,
           71.89562909378034,
           71.92412527769136,
           71.95262146160235,
           71.98111764551336,
           72.00961382942437,
           72.03811001333536,
           72.06660619724636,
           72.09510238115737,
           72.12359856506838,
           72.15209474897938,
           72.18059093289038,
           72.20908711680138,
           72.23758330071239,
           72.26607948462339,
           72.29457566853439,
           72.3230718524454,
           72.3515680363564,
           72.3800642202674,
           72.4085604041784,
           72.43705658808942,
           72.4655527720004,
           72.49404895591141,
           72.52254513982243,
           72.55104132373341,
           72.57953750764442,
           72.60803369155542,
           72.63652987546642,
           72.66502605937742,
           72.69352224328844,
           72.72201842719943,
           72.75051461111045,
           72.77901079502145,
           72.80750697893244,
           72.83600316284345,
           72.86449934675446,
           72.89299553066544,
           72.92149171457646,
           72.94998789848746,
           72.97848408239845,
           73.00698026630947,
           73.03547645022047,
           73.06331551841035,
           73.08984035889154,
           73.11636519937272,
           73.14289003985392,
           73.16941488033511,
           73.1959397208163,
           73.22246456129749,
           73.24898940177869,
           73.27551424225987,
           73.30203908274108,
           73.32856392322225,
           73.35508876370344,
           73.38161360418462,
           73.40813844466582,
           73.43466328514701,
           73.4611881256282,
           73.48771296610938,
           73.51423780659059,
           73.54076264707177,
           73.56728748755296,
           73.59381232803416,
           73.62033716851535,
           73.64686200899654,
           73.67338684947772,
           73.69991168995891,
           73.53969150284107,
           73.28609880192371,
           73.03250610100636,
           72.77891340008901,
           72.52532069917166,
           72.27172799825428,
           72.01813529733694,
           71.76454259641959,
           71.51094989550221,
           71.25735719458487,
           71.0037644936675,
           70.75017179275015,
           70.49657909183279,
           70.24298639091543,
           69.98939368999808,
           69.73580098908073,
           69.48220828816336,
           69.22861558724601,
           68.97502288632865,
           68.7214301854113,
           68.46783748449394,
           68.21424478357658,
           67.96065208265922,
           67.70705938174186,
           67.4534666808245,
           67.19987397990715,
           66.94628127898979,
           66.69268857807243,
           66.43909587715508,
           66.18550317623772,
           65.93191047532036,
           65.67831777440301,
           65.42472507348566,
           65.1711323725683,
           64.91753967165093,
           64.66394697073358,
           64.41035426981622,
           64.15676156889887,
           63.903168867981506,
           63.649576167064154,
           63.3959834661468,
           63.14239076522944,
           62.888798064312084,
           62.63520536339473,
           62.381612662477366,
           62.128019961560014,
           61.87442726064266,
           61.62083455972531,
           61.367241858807944,
           61.11364915789059,
           60.860056456973226,
           60.606463756055874,
           60.352871055138515,
           60.099278354221155,
           59.84568565330379,
           59.59209295238645,
           59.338500251469085,
           59.08490755055173,
           58.83131484963437,
           58.577722148717015,
           58.32412944779966,
           58.0705367468823,
           57.816944045964945,
           57.56335134504759,
           57.30975864413024,
           57.05616594321288,
           56.80257324229552,
           56.54898054137816,
           56.2953878404608,
           56.04179513954345,
           55.788202438626094,
           55.54703762335634,
           55.31001554417912,
           55.0729934650019,
           54.8359713858247,
           54.598949306647484,
           54.36192722747026,
           54.12490514829305,
           53.887883069115844,
           53.650860989938636,
           53.41383891076141,
           53.1768168315842,
           52.93979475240698,
           52.501727294689935,
           52.16089310755533,
           52.08569148588334,
           51.7920910406923,
           51.498490595501345,
           51.20489015031035,
           50.91128970511944,
           50.617689259928355,
           50.3240888147374,
           50.030488369546454,
           49.73688792435546,
           49.4432874791644,
           49.14968703397349,
           48.8560865887825,
           48.56248614359151,
           48.26888569840051,
           47.975285253209556,
           47.68168480801855,
           47.388084362827556,
           47.09448391763656,
           46.800883472445605,
           46.5072830272546,
           46.21368258206361,
           45.92008213687261,
           45.626481691681605,
           45.33288124649062,
           45.03928080129967,
           44.745680356108664,
           44.45207991091767,
           44.15847946572672,
           43.86487902053572,
           43.572991761029904,
           43.28272751800685,
           42.99246327498371,
           42.70219903196061,
           42.411934788937515,
           42.121670545914455,
           41.831406302891345,
           41.54114205986834,
           41.25087781684525,
           40.9606135738221,
           40.67034933079905,
           40.38008508777596,
           40.08982084475284,
           39.79955660172974,
           39.5092923587067,
           39.21902811568359,
           38.92876387266049,
           38.63849962963744,
           38.34823538661435,
           38.05797114359123,
           37.76770690056814,
           37.47744265754509,
           37.18717841452198,
           36.899555889767775,
           36.6136592885274,
           36.32776268728696,
           36.041866086046554,
           35.75596948480609,
           35.4700728835657,
           35.184176282325254,
           34.898279681084865,
           34.612383079844435,
           34.326486478604,
           34.04058987736356,
           33.75469327612317,
           33.46879667488273,
           33.18290007364228,
           32.897003472401906,
           32.61110687116147,
           32.32521026992102,
           32.03931366868063,
           31.753671847082792,
           31.473592762412036,
           31.193513677741358,
           30.913434593070676,
           30.63335550839995,
           30.35327642372924,
           30.073197339058563,
           29.793118254387803,
           29.51303916971708,
           29.23296008504637,
           28.95288100037569,
           28.672801915704962,
           28.392722831034284,
           28.112643746363574,
           27.832564661692846,
           27.552485577022136,
           27.277878666178925,
           27.005616970523388,
           26.73335527486783,
           26.46109357921229,
           26.18883188355676,
           25.91657018790119,
           25.644308492245642,
           25.372046796590123,
           25.099785100934525,
           24.827523405278978,
           24.55526170962346,
           24.283000013967897,
           24.010738318312374,
           23.74474422335009,
           23.480281145528206,
           23.21581806770632,
           22.951354989884447,
           22.686891912062574,
           22.422428834240712,
           22.15796575641887,
           21.893502678597,
           21.629039600775116,
           21.364576522953236,
           21.100113445131367,
           20.842093524142456,
           20.5855604871809,
           20.32902745021937,
           20.07249441325782,
           19.815961376296265,
           19.559428339334726,
           19.30289530237324,
           19.046362265411663,
           18.789829228450145,
           18.53631223266797,
           18.28882731482104,
           18.041342396974173,
           17.793857479127304,
           17.546372561280375,
           17.298887643433467,
           17.0514027255866,
           16.80391780773973,
           16.557176431598133,
           16.31970453884297,
           16.082232646087807,
           15.84476075333263,
           15.607288860577466,
           15.369816967822322,
           15.132345075067144,
           14.894873182311967,
           14.665859573921276,
           14.438779288742843,
           14.211699003564409,
           13.984618718385988,
           13.757538433207568,
           13.530458148029155,
           13.306855059386233,
           13.08888742385451,
           12.870919788322794,
           12.65295215279109,
           12.43498451725935,
           12.217016881727634,
           12.005024247793031,
           11.796346775431747,
           11.58766930307042,
           11.37899183070911,
           11.17031435834778,
           10.96757368891337,
           10.770959801021052,
           10.574345913128775,
           10.377732025236483,
           10.181118137344178,
           9.995586179643627,
           9.812122850505084,
           9.628659521366503,
           9.445196192227922,
           9.269274966552038,
           9.097879001998038,
           8.926483037444013,
           8.75508707289002,
           8.592285349507229,
           8.431885510278851,
           8.271485671050483,
           8.113744073906227,
           7.963386484909659,
           7.81302889591307,
           7.662987197315262,
           7.5217904159508455,
           7.380593634586429,
           7.239876230748608,
           7.107055940257256,
           6.974235649765886,
           6.843795944169456,
           6.718797576418437,
           6.593799208667378,
           6.475648983026929,
           6.359764498929076,
           6.247614039245523,
           6.141624719475933,
           6.03678422575752,
           5.937797275142259,
           5.839304737490652,
           5.745483103916358,
           5.652703763714716,
           5.565456595191868,
           5.4805703745806476,
           5.4002584907139095,
           5.323827290356161,
           5.249777213065809,
           5.181063788721373,
           5.105483514283474,
           5.023036389752114,
           4.940589265220771,
           4.85814214068941,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           67.4773918149398,
           67.52428578893299,
           67.57117976292616,
           67.61807373691933,
           67.6649677109125,
           67.71186168490567,
           67.75875565889885,
           67.80564963289203,
           67.85254360688519,
           67.89943758087837,
           67.94633155487153,
           67.99322552886471,
           68.04011950285788,
           68.08701347685106,
           68.13390745084423,
           68.18080142483741,
           68.22769539883058,
           68.27458937282375,
           68.32148334681692,
           68.3683773208101,
           68.41527129480326,
           68.46216526879644,
           68.50905924278962,
           68.55595321678278,
           68.60284719077595,
           68.64974116476913,
           68.6966351387623,
           68.74352911275547,
           68.79042308674865,
           68.83731706074181,
           68.88421103473499,
           68.93110500872817,
           68.97799898272133,
           69.0248929567145,
           69.07178693070767,
           69.11868090470084,
           69.16557487869402,
           69.2124688526872,
           69.25936282668036,
           69.30625680067352,
           69.3531507746667,
           69.4000447486599,
           69.44789565800804,
           69.49593795454582,
           69.54398025108358,
           69.59202254762137,
           69.64006484415914,
           69.68810714069691,
           69.73614943723469,
           69.78419173377247,
           69.83223403031023,
           69.88027632684802,
           69.92831862338579,
           69.97636091992356,
           70.02440321646135,
           70.07244551299912,
           70.1204878095369,
           70.16853010607467,
           70.21657240261246,
           70.26461469915021,
           70.312656995688,
           70.36069929222577,
           70.40874158876355,
           70.45678388530132,
           70.5048261818391,
           70.5528684783769,
           70.60091077491465,
           70.64895307145242,
           70.69699536799021,
           70.74503766452798,
           70.79307996106576,
           70.84112225760353,
           70.8891645541413,
           70.93720685067909,
           70.98524914721686,
           71.03329144375463,
           71.08133374029241,
           71.12937603683018,
           71.17741833336797,
           71.22546062990574,
           71.27350292644351,
           71.32154522298129,
           71.36958751951906,
           71.41762981605683,
           71.44938368540564,
           71.47787986931664,
           71.50637605322765,
           71.53487223713864,
           71.56336842104965,
           71.59186460496065,
           71.62036078887165,
           71.64885697278265,
           71.67735315669366,
           71.70584934060466,
           71.73434552451567,
           71.76284170842666,
           71.79133789233768,
           71.81983407624867,
           71.84833026015968,
           71.87682644407069,
           71.90532262798169,
           71.93381881189269,
           71.9623149958037,
           71.9908111797147,
           72.0193073636257,
           72.0478035475367,
           72.0762997314477,
           72.10479591535871,
           72.13329209926971,
           72.16178828318073,
           72.19028446709171,
           72.21878065100272,
           72.24727683491373,
           72.27577301882472,
           72.30426920273572,
           72.33276538664674,
           72.36126157055773,
           72.38975775446873,
           72.41825393837975,
           72.44675012229074,
           72.47524630620175,
           72.50374249011276,
           72.53223867402376,
           72.56073485793476,
           72.58923104184575,
           72.61772722575677,
           72.64458062330657,
           72.67110546378774,
           72.69763030426893,
           72.72415514475011,
           72.75067998523132,
           72.7772048257125,
           72.8037296661937,
           72.83025450667486,
           72.85677934715608,
           72.88330418763726,
           72.90982902811845,
           72.93635386859964,
           72.96287870908084,
           72.98940354956203,
           73.01592839004321,
           73.0424532305244,
           73.0689780710056,
           73.09550291148678,
           73.12202775196798,
           73.14855259244916,
           73.17507743293037,
           73.20160227341155,
           73.22812711389274,
           73.25465195437393,
           73.28117679485513,
           73.30770163533631,
           73.3342264758175,
           73.36075131629869,
           73.38727615677988,
           73.41380099726106,
           73.44032583774225,
           73.46685067822345,
           73.49337551870464,
           73.51990035918583,
           73.54642519966701,
           73.57295004014821,
           73.5994748806294,
           73.62599972111059,
           73.65252456159178,
           73.67904940207296,
           73.70557424255415,
           73.5453540554363,
           73.29176135451895,
           73.03816865360162,
           72.78457595268425,
           72.5309832517669,
           72.27739055084952,
           72.02379784993218,
           71.77020514901481,
           71.51661244809746,
           71.26301974718011,
           71.00942704626274,
           70.75583434534539,
           70.50224164442803,
           70.24864894351067,
           69.99505624259332,
           69.74146354167596,
           69.4878708407586,
           69.23427813984125,
           68.98068543892389,
           68.72709273800653,
           68.47350003708918,
           68.21990733617181,
           67.96631463525446,
           67.7127219343371,
           67.45912923341976,
           67.20553653250239,
           66.95194383158503,
           66.69835113066769,
           66.44475842975031,
           66.19116572883297,
           65.93757302791562,
           65.68398032699825,
           65.4303876260809,
           65.17679492516355,
           64.92320222424618,
           64.66960952332883,
           64.41601682241146,
           64.16242412149413,
           63.90883142057676,
           63.655238719659394,
           63.40164601874205,
           63.14805331782468,
           62.89446061690734,
           62.64086791598997,
           62.387275215072606,
           62.133682514155254,
           61.88008981323791,
           61.62649711232055,
           61.372904411403184,
           61.11931171048583,
           60.865719009568465,
           60.61212630865111,
           60.358533607733754,
           60.104940906816395,
           59.851348205899036,
           59.59775550498169,
           59.34416280406433,
           59.09057010314697,
           58.83697740222962,
           58.583384701312255,
           58.3297920003949,
           58.07619929947754,
           57.822606598560185,
           57.56901389764283,
           57.307200779122724,
           57.02278169835547,
           56.73836261758822,
           56.45394353682097,
           56.16952445605372,
           55.885105375286486,
           55.600686294519235,
           55.316267213751985,
           55.031848132984734,
           54.747429052217484,
           54.46300997145025,
           54.178590890683,
           53.89417180991575,
           53.6097527291485,
           53.325333648381246,
           53.04091456761401,
           52.75649548684676,
           52.472076406079495,
           52.18765732531226,
           51.898647562333124,
           51.60504711714216,
           51.31144667195117,
           51.017846226760135,
           50.72424578156918,
           50.43064533637818,
           50.13704489118727,
           49.843444445996184,
           49.54984400080523,
           49.25624355561428,
           48.962643110423286,
           48.66904266523223,
           48.37544222004133,
           48.08184177485033,
           47.788241329659336,
           47.49464088446834,
           47.20104043927739,
           46.90743999408638,
           46.6138395488954,
           46.320239103704395,
           46.02663865851344,
           45.73303821332244,
           45.43943776813145,
           45.145837322940444,
           44.853409057702336,
           44.56314481467925,
           44.27288057165623,
           43.98261632863312,
           43.69235208561003,
           43.40208784258694,
           43.111823599563834,
           42.821559356540725,
           42.53129511351768,
           42.24103087049454,
           41.95076662747143,
           41.660502384448336,
           41.37023814142528,
           41.07997389840218,
           40.78970965537916,
           40.499445412356074,
           40.20918116933292,
           39.918916926309876,
           39.62865268328678,
           39.33838844026367,
           39.04812419724057,
           38.75785995421753,
           38.46759571119442,
           38.17733146817131,
           37.89023728716395,
           37.60434068592355,
           37.31844408468307,
           37.032547483442684,
           36.74665088220225,
           36.46075428096185,
           36.17485767972137,
           35.888961078480996,
           35.60306447724055,
           35.31716787600015,
           35.03127127475968,
           34.745374673519294,
           34.45947807227884,
           34.17358147103845,
           33.88768486979802,
           33.601788268557584,
           33.31589166731715,
           33.029995066076765,
           32.74409846483632,
           32.461598951392745,
           32.18151986672207,
           31.901440782051314,
           31.62136169738066,
           31.34128261270991,
           31.061203528039233,
           30.781124443368473,
           30.501045358697798,
           30.220966274027116,
           29.940887189356392,
           29.660808104685678,
           29.380729020015004,
           29.10064993534424,
           28.82057085067352,
           28.540491766002805,
           28.260412681332127,
           27.98627481387731,
           27.714013118221757,
           27.441751422566206,
           27.169489726910644,
           26.897228031255093,
           26.62496633559954,
           26.35270463994401,
           26.080442944288446,
           25.80818124863291,
           25.53591955297738,
           25.26365785732181,
           24.991396161666263,
           24.719134466010743,
           24.45046109129742,
           24.185998013475544,
           23.9215349356537,
           23.657071857831845,
           23.39260878000997,
           23.128145702188096,
           22.863682624366213,
           22.599219546544326,
           22.334756468722453,
           22.07029339090058,
           21.805830313078722,
           21.542358488955543,
           21.285825451994086,
           21.029292415032508,
           20.77275937807099,
           20.51622634110945,
           20.2596933041479,
           20.003160267186345,
           19.746627230224817,
           19.490094193263264,
           19.233561156301715,
           18.980187781504032,
           18.73270286365714,
           18.485217945810206,
           18.23773302796334,
           17.990248110116468,
           17.74276319226954,
           17.49527827442267,
           17.247793356575798,
           17.000308438728872,
           16.76115118556029,
           16.523679292805102,
           16.28620740004996,
           16.048735507294783,
           15.811263614539618,
           15.573791721784453,
           15.336319829029277,
           15.10242458170313,
           14.875344296524688,
           14.648264011346257,
           14.421183726167843,
           14.194103440989457,
           13.967023155811024,
           13.73994287063259,
           13.519337364150223,
           13.301369728618502,
           13.083402093086764,
           12.865434457555043,
           12.647466822023322,
           12.429499186491604,
           12.2188942947855,
           12.010216822424184,
           11.801539350062859,
           11.592861877701532,
           11.384184405340246,
           11.181301252610488,
           10.98468736471817,
           10.78807347682589,
           10.591459588933613,
           10.394845701041294,
           10.207245116079067,
           10.02378178694051,
           9.840318457801931,
           9.65685512866335,
           9.477442986822776,
           9.306047022268764,
           9.134651057714741,
           8.963255093160727,
           8.795949837217487,
           8.635549997989107,
           8.475150158760771,
           8.314750319532415,
           8.161832940617197,
           8.011475351620609,
           7.861117762624059,
           7.714550853143107,
           7.57335407177869,
           7.432157290414302,
           7.293836774026223,
           7.161016483534862,
           7.028196193043527,
           6.899320871986188,
           6.774322504235137,
           6.649324136484077,
           6.532268595208167,
           6.4163841111102915,
           6.304687068664476,
           6.198697748894907,
           6.093693137145099,
           5.994706186529832,
           5.895758268274735,
           5.801936634700423,
           5.708179142385523,
           5.620931973862689,
           5.534619347185691,
           5.454307463318938,
           5.376281654738137,
           5.302122418503826,
           5.23183225588542,
           5.161156874371411,
           5.078709749840067,
           4.996262625308708,
           4.913815500777348,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           67.53452885441203,
           67.58142282840521,
           67.62831680239837,
           67.67521077639154,
           67.72210475038472,
           67.7689987243779,
           67.81589269837106,
           67.86278667236422,
           67.9096806463574,
           67.95657462035058,
           68.00346859434376,
           68.05036256833692,
           68.0972565423301,
           68.14415051632326,
           68.19104449031644,
           68.23793846430962,
           68.28483243830279,
           68.33172641229595,
           68.37862038628913,
           68.4255143602823,
           68.47240833427549,
           68.51930230826865,
           68.56619628226181,
           68.61309025625499,
           68.65998423024817,
           68.70687820424135,
           68.75377217823451,
           68.80066615222769,
           68.84756012622086,
           68.89445410021403,
           68.9413480742072,
           68.98824204820038,
           69.03513602219354,
           69.08202999618672,
           69.1289239701799,
           69.17581794417306,
           69.22271191816624,
           69.2696058921594,
           69.31649986615258,
           69.36339384014575,
           69.41028781413893,
           69.45718178813209,
           69.50407576212527,
           69.55096973611845,
           69.59786371011161,
           69.64475768410477,
           69.69165165809797,
           69.73854563209113,
           69.7854396060843,
           69.83233358007747,
           69.87922755407065,
           69.92612152806382,
           69.973015502057,
           70.01990947605016,
           70.06680345004334,
           70.11369742403652,
           70.16059139802968,
           70.20748537202286,
           70.25476212072479,
           70.30280441726256,
           70.35084671380034,
           70.39888901033812,
           70.44693130687588,
           70.49497360341367,
           70.54301589995144,
           70.59105819648923,
           70.63910049302699,
           70.68714278956477,
           70.73518508610255,
           70.78322738264032,
           70.83126967917809,
           70.87931197571588,
           70.92735427225365,
           70.97539656879142,
           71.0234388653292,
           71.07148116186698,
           71.11952345840476,
           71.16756575494253,
           71.2156080514803,
           71.26365034801807,
           71.31169264455585,
           71.35973494109363,
           71.40777723763141,
           71.45581953416918,
           71.48757340351798,
           71.51606958742899,
           71.54456577133999,
           71.57306195525099,
           71.601558139162,
           71.630054323073,
           71.658550506984,
           71.687046690895,
           71.715542874806,
           71.74403905871701,
           71.77253524262801,
           71.801031426539,
           71.82952761045001,
           71.85802379436102,
           71.88651997827202,
           71.91501616218302,
           71.94351234609404,
           71.97200853000503,
           72.00050471391604,
           72.02900089782705,
           72.05749708173803,
           72.08599326564905,
           72.11448944956004,
           72.14298563347104,
           72.17148181738206,
           72.19932088772156,
           72.22584572820274,
           72.25237056868393,
           72.27889540916512,
           72.30542024964632,
           72.3319450901275,
           72.35846993060869,
           72.3849947710899,
           72.41151961157108,
           72.43804445205227,
           72.46456929253345,
           72.49109413301466,
           72.51761897349584,
           72.54414381397703,
           72.57066865445822,
           72.5971934949394,
           72.6237183354206,
           72.65024317590179,
           72.676768016383,
           72.70329285686417,
           72.72981769734537,
           72.75634253782655,
           72.78286737830774,
           72.80939221878894,
           72.83591705927012,
           72.86244189975132,
           72.8889667402325,
           72.91549158071369,
           72.9420164211949,
           72.96854126167608,
           72.99506610215727,
           73.02159094263845,
           73.04811578311964,
           73.07464062360084,
           73.10116546408202,
           73.12769030456322,
           73.15421514504442,
           73.1807399855256,
           73.20726482600679,
           73.23378966648798,
           73.26031450696917,
           73.28683934745037,
           73.31336418793157,
           73.33988902841274,
           73.36641386889393,
           73.39293870937513,
           73.41946354985632,
           73.44598839033749,
           73.47251323081869,
           73.49903807129988,
           73.52556291178107,
           73.55208775226225,
           73.57861259274344,
           73.60513743322464,
           73.63166227370584,
           73.65818711418702,
           73.68471195466822,
           73.7112367951494,
           73.55101660803156,
           73.29742390711421,
           73.04383120619686,
           72.79023850527949,
           72.53664580436215,
           72.28305310344477,
           72.02946040252742,
           71.77586770161007,
           71.5222750006927,
           71.26868229977535,
           71.01508959885798,
           70.76149689794063,
           70.50790419702328,
           70.25431149610591,
           70.00071879518856,
           69.74712609427121,
           69.49353339335384,
           69.23994069243649,
           68.98634799151914,
           68.73275529060179,
           68.47916258968442,
           68.22556988876707,
           67.97197718784972,
           67.71838448693234,
           67.464791786015,
           67.21119908509763,
           66.95760638418028,
           66.70401368326293,
           66.45042098234556,
           66.19682828142821,
           65.94323558051084,
           65.68964287959349,
           65.43605017867614,
           65.18245747775879,
           64.92886477684142,
           64.67527207592406,
           64.4216793750067,
           64.16808667408935,
           63.914493973172,
           63.64343298437174,
           63.359013903604506,
           63.074594822837255,
           62.79017574207,
           62.50575666130275,
           62.2213375805355,
           61.93691849976825,
           61.65249941900101,
           61.36808033823377,
           61.08366125746652,
           60.79924217669926,
           60.51482309593201,
           60.23040401516478,
           59.945984934397515,
           59.66156585363027,
           59.37714677286303,
           59.09272769209578,
           58.80830861132854,
           58.523889530561284,
           58.23947044979403,
           57.95505136902679,
           57.67063228825954,
           57.386213207492304,
           57.10179412672505,
           56.81737504595779,
           56.53295596519057,
           56.24853688442331,
           55.96411780365605,
           55.67969872288881,
           55.39527964212155,
           55.11086056135432,
           54.826441480587064,
           54.542022399819814,
           54.25760331905257,
           53.97318423828531,
           53.688765157518084,
           53.40434607675083,
           53.119926995983576,
           52.835507915216326,
           52.5510888344491,
           52.26666975368184,
           51.98225067291459,
           51.69783159214734,
           51.41341251138009,
           51.12440274840096,
           50.83080230321,
           50.53720185801901,
           50.24360141282797,
           49.95000096763701,
           49.65640052244601,
           49.36280007725511,
           49.06919963206402,
           48.775599186873066,
           48.481998741682126,
           48.188398296491116,
           47.89479785130007,
           47.601197406109165,
           47.30759696091817,
           47.01399651572717,
           46.72039607053618,
           46.42679562534523,
           46.13382635437481,
           45.84356211135172,
           45.55329786832866,
           45.263033625305525,
           44.972769382282415,
           44.68250513925937,
           44.39224089623627,
           44.101976653213164,
           43.811712410190076,
           43.52144816716705,
           43.231183924143956,
           42.94091968112086,
           42.650655438097765,
           42.36039119507466,
           42.07012695205156,
           41.779862709028514,
           41.48959846600536,
           41.19933422298226,
           40.90906997995917,
           40.61880573693611,
           40.32854149391301,
           40.03827725089,
           39.7480130078669,
           39.45774876484376,
           39.167484521820704,
           38.880918684560115,
           38.59502208331971,
           38.30912548207924,
           38.02322888083885,
           37.73733227959838,
           37.451435678358,
           37.16553907711754,
           36.87964247587715,
           36.59374587463667,
           36.30784927339628,
           36.02195267215585,
           35.736056070915446,
           35.45015946967496,
           35.16426286843459,
           34.878366267194146,
           34.59246966595374,
           34.30657306471327,
           34.02067646347288,
           33.73477986223244,
           33.44960514037345,
           33.16952605570278,
           32.889446971032015,
           32.60936788636134,
           32.329288801690595,
           32.04920971701994,
           31.769130632349178,
           31.489051547678507,
           31.20897246300775,
           30.928893378337097,
           30.648814293666348,
           30.368735208995666,
           30.08865612432491,
           29.80857703965423,
           29.528497954983553,
           29.24841887031283,
           28.96833978564212,
           28.69467096157566,
           28.422409265920095,
           28.150147570264565,
           27.877885874609014,
           27.605624178953462,
           27.333362483297932,
           27.06110078764238,
           26.78883909198683,
           26.516577396331268,
           26.244315700675717,
           25.972054005020166,
           25.699792309364632,
           25.427530613709067,
           25.156177959244804,
           24.89171488142295,
           24.62725180360103,
           24.362788725779158,
           24.098325647957346,
           23.83386257013543,
           23.569399492313558,
           23.30493641449171,
           23.040473336669855,
           22.77601025884798,
           22.51154718102611,
           22.247084103204227,
           21.98609041680716,
           21.729557379845623,
           21.473024342884084,
           21.21649130592253,
           20.95995826896099,
           20.703425231999528,
           20.44689219503795,
           20.190359158076433,
           19.933826121114894,
           19.677293084153344,
           19.424063330340093,
           19.17657841249321,
           18.92909349464628,
           18.681608576799402,
           18.434123658952526,
           18.186638741105636,
           17.939153823258707,
           17.691668905411838,
           17.444183987564966,
           17.202597832277576,
           16.965125939522437,
           16.72765404676725,
           16.49018215401207,
           16.25271026125694,
           16.015238368501752,
           15.77776647574661,
           15.540294582991434,
           15.311909304306543,
           15.084829019128142,
           14.857748733949709,
           14.63066844877131,
           14.403588163592866,
           14.176507878414434,
           13.949787304445879,
           13.731819668914225,
           13.513852033382474,
           13.29588439785072,
           13.077916762319036,
           12.859949126787315,
           12.641981491255578,
           12.432764341777936,
           12.22408686941664,
           12.015409397055315,
           11.806731924694,
           11.598054452332685,
           11.395028816307605,
           11.198414928415284,
           11.00180104052302,
           10.805187152630731,
           10.60857326473841,
           10.418904052514492,
           10.235440723375937,
           10.051977394237342,
           9.868514065098788,
           9.685611007093518,
           9.514215042539506,
           9.342819077985459,
           9.171423113431468,
           9.000027148877455,
           8.839214485699388,
           8.678814646471032,
           8.518414807242674,
           8.360279396324735,
           8.209921807328174,
           8.059564218331607,
           7.909206629335028,
           7.766114508970963,
           7.624917727606565,
           7.483720946242148,
           7.347797317303847,
           7.2149770268125035,
           7.082156736321142,
           6.954845799802878,
           6.82984743205186,
           6.704849064300809,
           6.5888882073893775,
           6.473003723291509,
           6.361760098083451,
           6.255770778313861,
           6.150602048532674,
           6.051615097917426,
           5.952628147302159,
           5.858390165484488,
           5.764568531910195,
           5.676407352533501,
           5.5891601840106535,
           5.508356435923977,
           5.428736019120123,
           5.354576782885802,
           5.282600723049461,
           5.213887298705025,
           5.134383109928009,
           5.051935985396649,
           4.969488860865305,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           67.59166589388424,
           67.6385598678774,
           67.68545384187058,
           67.73234781586376,
           67.77924178985693,
           67.8261357638501,
           67.87302973784327,
           67.91992371183645,
           67.96681768582961,
           68.01371165982279,
           68.06060563381597,
           68.10749960780913,
           68.15439358180231,
           68.20128755579549,
           68.24818152978867,
           68.29507550378182,
           68.341969477775,
           68.38886345176817,
           68.43575742576135,
           68.48265139975452,
           68.52954537374768,
           68.57643934774086,
           68.62333332173404,
           68.67022729572722,
           68.71712126972037,
           68.76401524371354,
           68.81090921770672,
           68.85780319169989,
           68.90469716569308,
           68.95159113968623,
           68.99848511367941,
           69.04537908767259,
           69.09227306166575,
           69.13916703565893,
           69.1860610096521,
           69.23295498364527,
           69.27984895763845,
           69.32674293163161,
           69.37363690562479,
           69.42053087961796,
           69.46742485361113,
           69.51431882760431,
           69.56121280159748,
           69.60810677559064,
           69.65500074958382,
           69.701894723577,
           69.74878869757016,
           69.79568267156334,
           69.84257664555652,
           69.88947061954968,
           69.93636459354286,
           69.98325856753603,
           70.03015254152919,
           70.07704651552237,
           70.12394048951555,
           70.17083446350871,
           70.2177284375019,
           70.26462241149507,
           70.31151638548823,
           70.35841035948141,
           70.40530433347459,
           70.45219830746775,
           70.49909228146093,
           70.5459862554541,
           70.59288022944727,
           70.63977420344045,
           70.68666817743362,
           70.73356215142678,
           70.78045612541997,
           70.82735009941314,
           70.8742440734063,
           70.92113804739947,
           70.96803202139266,
           71.01492599538582,
           71.061819969379,
           71.1096708799793,
           71.15771317651709,
           71.20575547305486,
           71.25379776959264,
           71.30184006613042,
           71.3498823626682,
           71.39792465920597,
           71.44596695574374,
           71.49400925228151,
           71.52576312163032,
           71.55425930554132,
           71.58275548945232,
           71.61125167336333,
           71.63974785727433,
           71.66824404118533,
           71.69674022509633,
           71.72523640900734,
           71.75373259291834,
           71.78058599261774,
           71.80711083309895,
           71.83363567358013,
           71.86016051406133,
           71.88668535454251,
           71.91321019502371,
           71.9397350355049,
           71.9662598759861,
           71.99278471646727,
           72.01930955694847,
           72.04583439742967,
           72.07235923791085,
           72.09888407839205,
           72.12540891887323,
           72.15193375935442,
           72.17845859983561,
           72.2049834403168,
           72.231508280798,
           72.25803312127917,
           72.28455796176037,
           72.31108280224157,
           72.33760764272276,
           72.36413248320395,
           72.39065732368513,
           72.41718216416632,
           72.44370700464752,
           72.4702318451287,
           72.4967566856099,
           72.52328152609108,
           72.54980636657228,
           72.57633120705346,
           72.60285604753466,
           72.62938088801585,
           72.65590572849703,
           72.68243056897823,
           72.70895540945942,
           72.73548024994061,
           72.76200509042181,
           72.788529930903,
           72.81505477138418,
           72.84157961186537,
           72.86810445234656,
           72.89462929282774,
           72.92115413330895,
           72.94767897379013,
           72.97420381427132,
           73.0007286547525,
           73.02725349523371,
           73.0537783357149,
           73.08030317619608,
           73.10682801667727,
           73.13335285715846,
           73.15987769763964,
           73.18640253812084,
           73.21292737860203,
           73.23945221908323,
           73.26597705956442,
           73.29250190004561,
           73.3190267405268,
           73.34555158100798,
           73.37207642148917,
           73.39860126197036,
           73.42512610245156,
           73.45165094293274,
           73.47817578341393,
           73.50470062389512,
           73.53122546437632,
           73.5577503048575,
           73.5842751453387,
           73.61079998581988,
           73.63732482630108,
           73.66384966678227,
           73.69037450726346,
           73.71689934774466,
           73.5566791606268,
           73.30308645970945,
           73.0494937587921,
           72.79590105787473,
           72.54230835695738,
           72.28871565604,
           72.03512295512266,
           71.78153025420531,
           71.52793755328794,
           71.2743448523706,
           71.02075215145322,
           70.76715945053589,
           70.51356674961852,
           70.25997404870117,
           69.97966518962077,
           69.69524610885351,
           69.41082702808626,
           69.12640794731902,
           68.84198886655177,
           68.55756978578454,
           68.27315070501729,
           67.98873162425002,
           67.7043125434828,
           67.41989346271552,
           67.1354743819483,
           66.85105530118103,
           66.56663622041378,
           66.28221713964655,
           65.99779805887928,
           65.71337897811206,
           65.4289598973448,
           65.14454081657755,
           64.86012173581031,
           64.57570265504306,
           64.29128357427581,
           64.00686449350856,
           63.722445412741315,
           63.43802633197407,
           63.15360725120683,
           62.869188170439585,
           62.58476908967234,
           62.300350008905085,
           62.01593092813784,
           61.73151184737059,
           61.44709276660333,
           61.16267368583608,
           60.87825460506884,
           60.593835524301596,
           60.30941644353435,
           60.0249973627671,
           59.740578281999845,
           59.4561592012326,
           59.17174012046536,
           58.887321039698115,
           58.60290195893086,
           58.31848287816362,
           58.03406379739637,
           57.74964471662912,
           57.46522563586188,
           57.18080655509462,
           56.896387474327376,
           56.611968393560126,
           56.32754931279288,
           56.04313023202563,
           55.758711151258396,
           55.474292070491146,
           55.189872989723895,
           54.905453908956645,
           54.621034828189394,
           54.33661574742216,
           54.05219666665491,
           53.76777758588766,
           53.48335850512041,
           53.198939424353156,
           52.91452034358591,
           52.63010126281867,
           52.34568218205142,
           52.06126310128417,
           51.77684402051692,
           51.49242493974968,
           51.20800585898243,
           50.92358677821518,
           50.639167697447924,
           50.3501579344688,
           50.056557489277836,
           49.76295704408684,
           49.46935659889581,
           49.17575615370485,
           48.88215570851385,
           48.588555263322945,
           48.294954818131856,
           48.0013543729409,
           47.707753927749955,
           47.41424365104721,
           47.12397940802414,
           46.83371516500102,
           46.54345092197796,
           46.25318667895482,
           45.96292243593183,
           45.67265819290875,
           45.38239394988564,
           45.09212970686254,
           44.80186546383949,
           44.51160122081635,
           44.22133697779325,
           43.9310727347702,
           43.640808491747094,
           43.35054424872399,
           43.060280005700896,
           42.77001576267788,
           42.479751519654776,
           42.18948727663168,
           41.89922303360859,
           41.60895879058549,
           41.31869454756238,
           41.028430304539334,
           40.73816606151619,
           40.44790181849309,
           40.15763757546999,
           39.87160008195623,
           39.58570348071582,
           39.29980687947536,
           39.013910278234974,
           38.72801367699453,
           38.44211707575413,
           38.1562204745137,
           37.8703238732733,
           37.584427272032826,
           37.29853067079244,
           37.01263406955197,
           36.7267374683116,
           36.44084086707113,
           36.154944265830736,
           35.869047664590255,
           35.583151063349874,
           35.297254462109436,
           35.01135786086903,
           34.72546125962855,
           34.43956465838818,
           34.15753224468341,
           33.87745316001265,
           33.59737407534198,
           33.3172949906713,
           33.03721590600057,
           32.757136821329894,
           32.47705773665921,
           32.19697865198846,
           31.91689956731778,
           31.636820482647032,
           31.356741397976375,
           31.076662313305615,
           30.79658322863495,
           30.516504143964188,
           30.236425059293534,
           29.956345974622785,
           29.676266889952107,
           29.403067109274012,
           29.13080541361843,
           28.85854371796291,
           28.586282022307376,
           28.31402032665183,
           28.041758630996277,
           27.76949693534071,
           27.497235239685182,
           27.22497354402963,
           26.95271184837408,
           26.680450152718546,
           26.408188457062998,
           26.135926761407447,
           25.863665065751885,
           25.59743174937026,
           25.332968671548475,
           25.068505593726556,
           24.804042515904644,
           24.539579438082814,
           24.275116360260956,
           24.010653282439037,
           23.746190204617164,
           23.481727126795356,
           23.217264048973433,
           22.952800971151564,
           22.688337893329717,
           22.42982234465877,
           22.173289307697253,
           21.91675627073569,
           21.660223233774165,
           21.403690196812605,
           21.14715715985107,
           20.89062412288953,
           20.634091085927977,
           20.377558048966435,
           20.121025012004974,
           19.867938879176165,
           19.620453961329293,
           19.372969043482374,
           19.12548412563547,
           18.87799920778859,
           18.630514289941708,
           18.383029372094775,
           18.135544454247896,
           17.888059536401023,
           17.64404447899489,
           17.40657258623973,
           17.169100693484545,
           16.931628800729403,
           16.694156907974225,
           16.456685015219083,
           16.219213122463895,
           15.98174122970872,
           15.748474312088396,
           15.521394026909997,
           15.294313741731555,
           15.067233456553122,
           14.840153171374723,
           14.613072886196322,
           14.38599260101789,
           14.162269609209883,
           13.944301973678181,
           13.726334338146462,
           13.50836670261469,
           13.290399067083039,
           13.072431431551284,
           12.855311861131687,
           12.646634388770359,
           12.437956916409062,
           12.229279444047751,
           12.020601971686439,
           11.81192449932514,
           11.608756380004706,
           11.412142492112428,
           11.215528604220165,
           11.018914716327847,
           10.822300828435527,
           10.630562988949931,
           10.447099659811363,
           10.2636363306728,
           10.080173001534215,
           9.896709672395659,
           9.722383062810211,
           9.550987098256234,
           9.379591133702208,
           9.208195169148196,
           9.042878973409634,
           8.882479134181299,
           8.72207929495292,
           8.561679455724574,
           8.408368263035692,
           8.258010674039156,
           8.107653085042566,
           7.958874946163253,
           7.817678164798826,
           7.6764813834344,
           7.535284602070002,
           7.401757860581479,
           7.2689375700901175,
           7.136117279598764,
           7.010370727619609,
           6.885372359868559,
           6.761392303668476,
           6.645507819570621,
           6.529623335472753,
           6.418833127502417,
           6.312843807732807,
           6.207510959920273,
           6.108524009305,
           6.009537058689732,
           5.914843696268571,
           5.821022062694265,
           5.731882731204304,
           5.644635562681474,
           5.5624054085289965,
           5.482093524662248,
           5.407031147267796,
           5.3333691902135225,
           5.264655765869069,
           5.19005647001595,
           5.1076093454846045,
           5.025162220953245,
           4.9427150964218844,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           67.64142735785283,
           67.68832133184601,
           67.73521530583918,
           67.78210927983235,
           67.82900325382553,
           67.8758972278187,
           67.92279120181186,
           67.96968517580504,
           68.01657914979822,
           68.0634731237914,
           68.11036709778458,
           68.15726107177774,
           68.2041550457709,
           68.25104901976408,
           68.29794299375726,
           68.34483696775042,
           68.39173094174359,
           68.43862491573677,
           68.48551888972995,
           68.53241286372312,
           68.57930683771629,
           68.62620081170945,
           68.67309478570263,
           68.71998875969581,
           68.76688273368897,
           68.81377670768215,
           68.86067068167533,
           68.9075646556685,
           68.95445862966167,
           69.00135260365485,
           69.04824657764802,
           69.09514055164118,
           69.14203452563436,
           69.18892849962754,
           69.2358224736207,
           69.28271644761386,
           69.32961042160704,
           69.37650439560022,
           69.4233983695934,
           69.47029234358656,
           69.51718631757974,
           69.5640802915729,
           69.61097426556609,
           69.65786823955926,
           69.70476221355243,
           69.75165618754559,
           69.79855016153877,
           69.84544413553195,
           69.89233810952513,
           69.93923208351829,
           69.98612605751147,
           70.03302003150463,
           70.07991400549781,
           70.12680797949098,
           70.17370195348416,
           70.22059592747732,
           70.2674899014705,
           70.31438387546368,
           70.36127784945684,
           70.40817182345002,
           70.4550657974432,
           70.50195977143636,
           70.54885374542954,
           70.5957477194227,
           70.64264169341588,
           70.68953566740905,
           70.73642964140222,
           70.78332361539539,
           70.83021758938857,
           70.87711156338173,
           70.92400553737491,
           70.97089951136807,
           71.01779348536125,
           71.06468745935443,
           71.1115814333476,
           71.15847540734077,
           71.20500158043882,
           71.25079214768583,
           71.29658271493282,
           71.34237328217985,
           71.38816384942685,
           71.43395441667386,
           71.47974498392087,
           71.52553555116788,
           71.55357417732085,
           71.57806241525505,
           71.60255065318923,
           71.62703889112342,
           71.65152712905761,
           71.67601536699178,
           71.70050360492597,
           71.7256707128742,
           71.75219555335539,
           71.77872039383658,
           71.80524523431777,
           71.83177007479895,
           71.85829491528015,
           71.88481975576134,
           71.91134459624253,
           71.93786943672372,
           71.96439427720492,
           71.9909191176861,
           72.01744395816729,
           72.04396879864849,
           72.07049363912968,
           72.09701847961087,
           72.12354332009205,
           72.15006816057324,
           72.17659300105443,
           72.20311784153563,
           72.22964268201682,
           72.256167522498,
           72.28269236297919,
           72.30921720346039,
           72.33574204394158,
           72.36226688442277,
           72.38879172490395,
           72.41531656538514,
           72.44184140586634,
           72.46836624634753,
           72.49489108682872,
           72.5214159273099,
           72.5479407677911,
           72.57446560827229,
           72.60099044875348,
           72.62751528923467,
           72.65404012971587,
           72.68056497019705,
           72.70708981067824,
           72.73361465115943,
           72.76013949164062,
           72.78666433212182,
           72.81318917260299,
           72.83971401308419,
           72.86623885356538,
           72.89276369404658,
           72.91928853452777,
           72.94581337500895,
           72.97233821549014,
           72.99886305597133,
           73.02538789645251,
           73.05191273693372,
           73.0784375774149,
           73.10496241789609,
           73.13148725837729,
           73.15801209885848,
           73.18453693933967,
           73.21106177982085,
           73.23758662030204,
           73.26411146078324,
           73.29063630126443,
           73.31716114174563,
           73.3436859822268,
           73.370210822708,
           73.39673566318919,
           73.42326050367038,
           73.44978534415156,
           73.47631018463275,
           73.50283502511394,
           73.52935986559514,
           73.55588470607633,
           73.58240954655753,
           73.60893438703872,
           73.63545922751989,
           73.66198406800109,
           73.68850890848228,
           73.71503374896348,
           73.52822829143958,
           73.23475768491318,
           72.94128707838676,
           72.64781647186034,
           72.35434586533393,
           72.0608752588075,
           71.7674046522811,
           71.47393404575467,
           71.18046343922825,
           70.88699283270185,
           70.59352222617542,
           70.30005161964901,
           70.00658101312258,
           69.71311040659617,
           69.41963980006976,
           69.12616919354335,
           68.83269858701692,
           68.53922798049051,
           68.24575737396408,
           67.95228676743768,
           67.65881616091126,
           67.36534555438485,
           67.07187494785843,
           66.778404341332,
           66.4849337348056,
           66.19146312827917,
           65.89799252175276,
           65.60452191522634,
           65.31105130869992,
           65.01758070217352,
           64.72411009564709,
           64.43063948912067,
           64.13716888259427,
           63.84369827606784,
           63.55022766954143,
           63.256757063014994,
           62.96328645648859,
           62.66981584996219,
           62.37936243727463,
           62.09494335650738,
           61.81052427574015,
           61.5261051949729,
           61.24168611420565,
           60.9572670334384,
           60.672847952671134,
           60.38842887190388,
           60.104009791136654,
           59.819590710369404,
           59.535171629602154,
           59.2507525488349,
           58.96633346806765,
           58.68191438730042,
           58.39749530653316,
           58.11307622576592,
           57.828657144998665,
           57.54423806423143,
           57.25981898346418,
           56.97539990269693,
           56.69098082192968,
           56.40656174116242,
           56.122142660395184,
           55.837723579627934,
           55.55330449886068,
           55.26888541809343,
           54.9844663373262,
           54.70004725655895,
           54.415628175791696,
           54.131209095024445,
           53.846790014257195,
           53.56237093348996,
           53.27795185272271,
           52.99353277195546,
           52.709113691188215,
           52.42469461042096,
           52.14027552965372,
           51.85585644888648,
           51.57143736811922,
           51.28701828735198,
           51.00259920658473,
           50.71818012581749,
           50.43376104505023,
           50.14934196428299,
           49.86492288351573,
           49.575913120536605,
           49.28231267534564,
           48.98871223015465,
           48.695111784963615,
           48.404396704696595,
           48.11413246167354,
           47.823868218650404,
           47.533603975627344,
           47.243339732604205,
           46.95307548958115,
           46.662811246558014,
           46.37254700353495,
           46.08228276051181,
           45.792018517488756,
           45.50175427446562,
           45.21149003144264,
           44.92122578841954,
           44.630961545396445,
           44.34069730237335,
           44.05043305935029,
           43.76016881632715,
           43.46990457330405,
           43.179640330281,
           42.889376087257894,
           42.59911184423479,
           42.3088476012117,
           42.01858335818868,
           41.728319115165576,
           41.43805487214249,
           41.1481780805928,
           40.862281479352326,
           40.57638487811192,
           40.29048827687154,
           40.00459167563113,
           39.71869507439066,
           39.43279847315027,
           39.1469018719098,
           38.861005270669395,
           38.57510866942893,
           38.28921206818854,
           38.003315466948095,
           37.7174188657077,
           37.43152226446727,
           37.14562566322686,
           36.85972906198639,
           36.57383246074601,
           36.28793585950553,
           36.00203925826516,
           35.7161426570247,
           35.43024605578431,
           35.14553843366413,
           34.865459348993376,
           34.5853802643227,
           34.30530117965194,
           34.025222094981245,
           33.745143010310585,
           33.465063925639825,
           33.184984840969065,
           32.90490575629839,
           32.62482667162771,
           32.344747586956984,
           32.0646685022863,
           31.784589417615624,
           31.504510332944868,
           31.22443124827419,
           30.944352163603448,
           30.664273078932787,
           30.38419399426203,
           30.11146325697237,
           29.839201561316774,
           29.566939865661244,
           29.29467817000572,
           29.02241647435014,
           28.750154778694608,
           28.47789308303903,
           28.20563138738351,
           27.933369691727975,
           27.661107996072424,
           27.388846300416873,
           27.11658460476131,
           26.844322909105777,
           26.57206121345023,
           26.30314861731761,
           26.038685539495752,
           25.774222461673908,
           25.509759383852057,
           25.245296306030145,
           24.980833228208247,
           24.71637015038646,
           24.45190707256454,
           24.18744399474263,
           23.9229809169208,
           23.658517839098945,
           23.394054761277026,
           23.130087309471836,
           22.873554272510376,
           22.617021235548847,
           22.36048819858728,
           22.103955161625766,
           21.847422124664188,
           21.590889087702674,
           21.334356050741107,
           21.077823013779582,
           20.821289976818026,
           20.564756939856487,
           20.31181442801224,
           20.064329510165262,
           19.81684459231839,
           19.569359674471524,
           19.32187475662464,
           19.07438983877777,
           18.826904920930854,
           18.57942000308395,
           18.331935085237067,
           18.085491125712156,
           17.848019232957,
           17.610547340201848,
           17.37307544744666,
           17.13560355469152,
           16.89813166193636,
           16.660659769181173,
           16.423187876426034,
           16.185715983670857,
           15.957959034691818,
           15.730878749513419,
           15.503798464335006,
           15.276718179156553,
           15.049637893978154,
           14.822557608799714,
           14.59547732362128,
           14.374751913973874,
           14.156784278442135,
           13.938816642910417,
           13.720849007378678,
           13.502881371846977,
           13.284913736315257,
           13.069181908124111,
           12.860504435762829,
           12.651826963401483,
           12.443149491040174,
           12.234472018678847,
           12.025794546317547,
           11.822483943701808,
           11.62587005580953,
           11.429256167917254,
           11.232642280024935,
           11.036028392132657,
           10.842221925385342,
           10.658758596246802,
           10.47529526710821,
           10.291831937969638,
           10.108368608831071,
           9.930551083080953,
           9.759155118526927,
           9.587759153972927,
           9.41636318941889,
           9.246543461119892,
           9.086143621891546,
           8.925743782663167,
           8.765343943434809,
           8.606814718743252,
           8.456457129746681,
           8.306099540750093,
           8.155741951753512,
           8.01043860199108,
           7.869241820626673,
           7.728045039262284,
           7.588538694350449,
           7.455718403859095,
           7.322898113367742,
           7.190894023187353,
           7.065895655436309,
           6.940897287685251,
           6.818011915849722,
           6.702127431751839,
           6.5862429476539575,
           6.475906156921372,
           6.369916837151788,
           6.264419871307837,
           6.1654329206925755,
           6.066445970077327,
           5.971297227052634,
           5.8774755934783185,
           5.787358109875124,
           5.700110941352282,
           5.61645438113402,
           5.536142497267283,
           5.459485511649756,
           5.385326275415435,
           5.315424233033131,
           5.245729830103901,
           5.16328270557254,
           5.080835581041182,
           4.9983884565098355,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           67.6823381284008,
           67.72923210239398,
           67.77612607638714,
           67.82302005038032,
           67.86991402437349,
           67.91680799836666,
           67.96370197235984,
           68.010595946353,
           68.05748992034619,
           68.10438389433935,
           68.15127786833253,
           68.1981718423257,
           68.24506581631887,
           68.29195979031205,
           68.33885376430521,
           68.38574773829839,
           68.43264171229156,
           68.47953568628473,
           68.5264296602779,
           68.57332363427108,
           68.62021760826426,
           68.66711158225743,
           68.7140055562506,
           68.76089953024378,
           68.80779350423694,
           68.85468747823012,
           68.9015814522233,
           68.94847542621645,
           68.99536940020963,
           69.0422633742028,
           69.08915734819598,
           69.13605132218916,
           69.18294529618231,
           69.22983927017549,
           69.27673324416867,
           69.32362721816183,
           69.37052119215501,
           69.41741516614817,
           69.46430914014135,
           69.51120311413452,
           69.5580970881277,
           69.60499106212087,
           69.65188503611405,
           69.69877901010722,
           69.7456729841004,
           69.79256695809356,
           69.83946093208674,
           69.8863549060799,
           69.93324888007308,
           69.98014285406624,
           70.02703682805942,
           70.0739308020526,
           70.12082477604577,
           70.16771875003894,
           70.21461272403211,
           70.26150669802529,
           70.30840067201846,
           70.35529464601163,
           70.40218862000481,
           70.44908259399797,
           70.49505706354087,
           70.5408476307879,
           70.58663819803489,
           70.6324287652819,
           70.67821933252891,
           70.72400989977592,
           70.76980046702292,
           70.81559103426994,
           70.86138160151694,
           70.90717216876395,
           70.95296273601096,
           70.99875330325797,
           71.04454387050498,
           71.09033443775199,
           71.13612500499899,
           71.181915572246,
           71.22770613949301,
           71.27349670674002,
           71.31928727398702,
           71.36507784123404,
           71.41086840848104,
           71.45665897572806,
           71.50244954297506,
           71.54824011022207,
           71.57627873637506,
           71.60076697430924,
           71.62525521224342,
           71.64974345017761,
           71.67423168811179,
           71.69871992604597,
           71.72320816398016,
           71.74769640191434,
           71.77218463984853,
           71.79667287778273,
           71.8211611157169,
           71.84564935365108,
           71.87013759158526,
           71.89462582951944,
           71.91911406745363,
           71.94360230538783,
           71.968090543322,
           71.99257878125619,
           72.01706701919036,
           72.04155525712456,
           72.06604349505875,
           72.09053173299291,
           72.11501997092711,
           72.1395082088613,
           72.16569361774698,
           72.19221845822818,
           72.21874329870937,
           72.24526813919056,
           72.27179297967176,
           72.29831782015295,
           72.32484266063413,
           72.35136750111532,
           72.3778923415965,
           72.4044171820777,
           72.4309420225589,
           72.45746686304008,
           72.48399170352127,
           72.51051654400247,
           72.53704138448366,
           72.56356622496484,
           72.59009106544603,
           72.61661590592723,
           72.64314074640842,
           72.66966558688961,
           72.6961904273708,
           72.72271526785198,
           72.74924010833317,
           72.77576494881437,
           72.80228978929556,
           72.82881462977674,
           72.85533947025795,
           72.88186431073912,
           72.90838915122032,
           72.9349139917015,
           72.96143883218271,
           72.9879636726639,
           73.01448851314508,
           73.04101335362627,
           73.06753819410747,
           73.09406303458864,
           73.12058787506984,
           73.14711271555103,
           73.17363755603222,
           73.2001623965134,
           73.2266872369946,
           73.2532120774758,
           73.279736917957,
           73.30626175843818,
           73.33278659891937,
           73.35931143940056,
           73.38583627988174,
           73.41236112036293,
           73.43888596084412,
           73.4654108013253,
           73.49193564180649,
           73.5184604822877,
           73.54498532276888,
           73.57151016325008,
           73.59803500373127,
           73.62455984421246,
           73.65108468469364,
           73.67760952517483,
           73.70413436565603,
           73.51732890813214,
           73.22385830160573,
           72.9303876950793,
           72.63691708855289,
           72.34344648202648,
           72.04997587550005,
           71.75650526897365,
           71.46303466244723,
           71.1695640559208,
           70.8760934493944,
           70.58262284286798,
           70.28915223634155,
           69.99568162981515,
           69.70221102328873,
           69.40874041676231,
           69.1152698102359,
           68.82179920370947,
           68.52832859718306,
           68.23485799065665,
           67.94138738413022,
           67.6479167776038,
           67.3544461710774,
           67.06097556455099,
           66.76750495802455,
           66.47403435149815,
           66.18056374497172,
           65.88709313844531,
           65.59362253191891,
           65.30015192539247,
           65.00668131886607,
           64.71321071233965,
           64.41974010581322,
           64.12626949928682,
           63.832798892760394,
           63.539328286233975,
           63.245857679707555,
           62.95238707318114,
           62.65891646665473,
           62.36544586012831,
           62.07197525360189,
           61.77850464707548,
           61.48503404054907,
           61.19156343402264,
           60.89809282749623,
           60.60462222096981,
           60.31115161444339,
           60.01768100791698,
           59.724210401390565,
           59.43073979486414,
           59.137269188337726,
           58.843798581811306,
           58.550327975284894,
           58.256857368758475,
           57.963386762232055,
           57.66991615570563,
           57.37644554917923,
           57.08297494265281,
           56.78950433612639,
           56.49603372959997,
           56.20256312307355,
           55.90909251654714,
           55.61562191002073,
           55.32215130349431,
           55.02868069696789,
           54.73521009044148,
           54.44173948391506,
           54.148268877388645,
           53.85479827086222,
           53.561327664335806,
           53.267857057809394,
           52.974386451282975,
           52.68091584475656,
           52.387445238230136,
           52.0900719309204,
           51.76050155859314,
           51.43093118626585,
           51.10136081393857,
           50.77179044161129,
           50.442220069284026,
           50.112649696956744,
           49.78307932462946,
           49.45350895230217,
           49.1239385799749,
           48.81402127229974,
           48.5237570292766,
           48.23349278625355,
           47.94322854323057,
           47.65296430020743,
           47.36270005718437,
           47.07243581416124,
           46.78217157113817,
           46.49190732811503,
           46.20164308509199,
           45.91137884206884,
           45.62111459904577,
           45.330850356022644,
           45.04058611299959,
           44.750321869976446,
           44.46005762695347,
           44.169793383930376,
           43.879529140907266,
           43.589264897884185,
           43.29900065486112,
           43.00873641183799,
           42.71847216881488,
           42.428207925791824,
           42.138859477988916,
           41.85296287674852,
           41.567066275508054,
           41.28116967426765,
           40.995273073027185,
           40.70937647178679,
           40.423479870546394,
           40.13758326930592,
           39.85168666806551,
           39.56579006682514,
           39.27989346558473,
           38.99399686434425,
           38.70810026310386,
           38.42220366186339,
           38.13630706062299,
           37.85041045938252,
           37.56451385814213,
           37.27861725690169,
           36.992720655661294,
           36.70682405442086,
           36.42092745318046,
           36.13503085193999,
           35.85346553797406,
           35.573386453303364,
           35.29330736863262,
           35.01322828396193,
           34.73314919929119,
           34.453070114620566,
           34.17299102994981,
           33.89291194527914,
           33.61283286060838,
           33.33275377593769,
           33.05267469126702,
           32.77259560659627,
           32.4925165219255,
           32.21243743725483,
           31.93235835258415,
           31.652279267913425,
           31.372200183242747,
           31.092121100326256,
           30.819859404670723,
           30.547597709015143,
           30.27533601335962,
           30.00307431770403,
           29.730812622048504,
           29.458550926392988,
           29.186289230737394,
           28.914027535081864,
           28.641765839426345,
           28.369504143770758,
           28.09724244811523,
           27.82498075245965,
           27.55271905680413,
           27.280457361148596,
           27.008865485265037,
           26.74440240744314,
           26.47993932962122,
           26.215476251799366,
           25.951013173977522,
           25.68655009615562,
           25.422087018333766,
           25.157623940511918,
           24.893160862690074,
           24.628697784868155,
           24.364234707046254,
           24.09977162922447,
           23.835308551402555,
           23.573819237323455,
           23.317286200361952,
           23.060753163400378,
           22.804220126438846,
           22.547687089477282,
           22.29115405251582,
           22.034621015554293,
           21.778087978592726,
           21.521554941631216,
           21.265021904669634,
           21.008488867708117,
           20.755689976848288,
           20.50820505900136,
           20.260720141154472,
           20.013235223307607,
           19.765750305460738,
           19.51826538761376,
           19.27078046976689,
           19.02329555192002,
           18.77581063407314,
           18.528325716226266,
           18.289465879674335,
           18.051993986919136,
           17.814522094163937,
           17.577050201408806,
           17.33957830865365,
           17.1021064158985,
           16.864634523143312,
           16.62716263038817,
           16.39452404247369,
           16.167443757295295,
           15.940363472116893,
           15.71328318693844,
           15.486202901759999,
           15.259122616581601,
           15.032042331403186,
           14.805201854269516,
           14.587234218737846,
           14.369266583206105,
           14.15129894767439,
           13.933331312142686,
           13.715363676610949,
           13.497396041079229,
           13.283051955116598,
           13.074374482755267,
           12.865697010393959,
           12.657019538032614,
           12.448342065671332,
           12.239664593309985,
           12.036211507398955,
           11.839597619506648,
           11.64298373161437,
           11.44636984372205,
           11.249755955829775,
           11.053880861820799,
           10.870417532682206,
           10.68695420354365,
           10.503490874405065,
           10.320027545266527,
           10.138719103351685,
           9.967323138797692,
           9.795927174243682,
           9.624531209689643,
           9.453135245135616,
           9.289808109601804,
           9.129408270373448,
           8.96900843114508,
           8.808608591916732,
           8.65490358545422,
           8.50454599645763,
           8.354188407461082,
           8.203830818464514,
           8.062002257818936,
           7.920805476454518,
           7.77960869509012,
           7.642499237628072,
           7.509678947136738,
           7.376858656645368,
           7.24641895100406,
           7.121420583253001,
           6.996422215501974,
           6.874631528030918,
           6.758747043933049,
           6.642862559835209,
           6.532979186340333,
           6.426989866570736,
           6.32132878269543,
           6.222341832080156,
           6.123354881464896,
           6.027750757836694,
           5.933929124262413,
           5.842833488545938,
           5.755586320023085,
           5.6705033537390594,
           5.590191469872302,
           5.511939876031736,
           5.437780639797426,
           5.366192700197163,
           5.297479275852725,
           5.218956065660496,
           5.1365089411291365,
           5.054061816597775,
           4.971614692066417,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           67.72324889894877,
           67.77014287294193,
           67.81703684693511,
           67.86393082092829,
           67.91082479492145,
           67.95771876891463,
           68.0046127429078,
           68.05150671690097,
           68.09840069089414,
           68.14529466488732,
           68.19218863888048,
           68.23908261287366,
           68.28597658686684,
           68.33287056086002,
           68.37976453485318,
           68.42665850884634,
           68.47355248283952,
           68.5204464568327,
           68.56734043082587,
           68.61423440481903,
           68.66112837881221,
           68.70802235280539,
           68.75491632679855,
           68.80181030079173,
           68.8487042747849,
           68.89559824877807,
           68.94249222277125,
           68.98938619676441,
           69.0362801707576,
           69.08317414475076,
           69.13006811874394,
           69.17696209273711,
           69.22385606673028,
           69.27075004072346,
           69.31764401471663,
           69.3645379887098,
           69.41143196270298,
           69.45832593669614,
           69.50521991068932,
           69.55211388468248,
           69.59900785867566,
           69.64590183266883,
           69.69279580666202,
           69.73932197939594,
           69.78511254664294,
           69.83090311388993,
           69.87669368113696,
           69.92248424838395,
           69.96827481563096,
           70.01406538287797,
           70.05985595012498,
           70.10564651737201,
           70.15143708461899,
           70.197227651866,
           70.24301821911301,
           70.28880878636002,
           70.33459935360703,
           70.38038992085404,
           70.42618048810104,
           70.47197105534806,
           70.51776162259506,
           70.56355218984208,
           70.60934275708908,
           70.65513332433608,
           70.7009238915831,
           70.74671445883011,
           70.79250502607712,
           70.83829559332413,
           70.88408616057114,
           70.92987672781815,
           70.97566729506516,
           71.02145786231216,
           71.06724842955916,
           71.11303899680618,
           71.15882956405318,
           71.20462013130019,
           71.2504106985472,
           71.29620126579421,
           71.34199183304122,
           71.38778240028823,
           71.43357296753524,
           71.47936353478224,
           71.52515410202926,
           71.57094466927626,
           71.59898329542925,
           71.62347153336344,
           71.64795977129762,
           71.6724480092318,
           71.69693624716598,
           71.72142448510017,
           71.74591272303435,
           71.77040096096854,
           71.79488919890272,
           71.8193774368369,
           71.8438656747711,
           71.86835391270527,
           71.89284215063945,
           71.91733038857365,
           71.94181862650782,
           71.966306864442,
           71.99079510237621,
           72.01528334031039,
           72.03977157824457,
           72.06425981617875,
           72.08874805411293,
           72.11323629204712,
           72.1377245299813,
           72.16221276791548,
           72.18670100584967,
           72.21118924378385,
           72.23567748171804,
           72.26016571965222,
           72.2846539575864,
           72.3091421955206,
           72.33363043345477,
           72.35811867138895,
           72.38260690932314,
           72.40709514725732,
           72.43158338519152,
           72.4560716231257,
           72.48055986105987,
           72.50504809899407,
           72.52953633692825,
           72.55402457486244,
           72.57919168213859,
           72.60571652261979,
           72.63224136310097,
           72.65876620358216,
           72.68529104406335,
           72.71181588454454,
           72.73834072502574,
           72.76486556550692,
           72.79139040598811,
           72.8179152464693,
           72.84444008695048,
           72.87096492743169,
           72.89748976791287,
           72.92401460839406,
           72.95053944887525,
           72.97706428935645,
           73.00358912983764,
           73.03011397031882,
           73.05663881080001,
           73.08316365128121,
           73.1096884917624,
           73.13621333224359,
           73.16273817272477,
           73.18926301320596,
           73.21578785368716,
           73.24231269416835,
           73.26883753464953,
           73.29536237513072,
           73.32188721561192,
           73.34841205609311,
           73.3749368965743,
           73.40146173705548,
           73.42798657753667,
           73.45451141801787,
           73.48103625849906,
           73.50756109898025,
           73.53408593946143,
           73.56061077994264,
           73.58713562042382,
           73.61366046090501,
           73.6401853013862,
           73.66671014186738,
           73.69323498234857,
           73.50642952482468,
           73.21295891829828,
           72.91948831177186,
           72.62601770524543,
           72.33254709871903,
           72.0390764921926,
           71.7456058856662,
           71.45213527913978,
           71.15866467261336,
           70.86519406608696,
           70.57172345956052,
           70.27825285303412,
           69.98478224650769,
           69.69131163998128,
           69.39784103345488,
           69.10437042692845,
           68.81089982040203,
           68.51742921387562,
           68.22395860734919,
           67.93048800082278,
           67.63701739429635,
           67.34354678776994,
           67.05007618124354,
           66.7566055747171,
           66.4631349681907,
           66.16966436166427,
           65.87619375513786,
           65.58272314861145,
           65.28925254208502,
           64.99578193555863,
           64.70231132903218,
           64.40884072250577,
           64.11537011597937,
           63.82189950945295,
           63.528428902926535,
           63.2349582964001,
           62.941487689873696,
           62.648017083347284,
           62.35454647682086,
           62.06107587029444,
           61.76760526376803,
           61.47413465724162,
           61.180664050715194,
           60.887193444188775,
           60.593722837662355,
           60.30025223113594,
           60.00678162460954,
           59.71331101808312,
           59.41984041155669,
           59.12636980503027,
           58.83289919850385,
           58.53942859197745,
           58.24595798545103,
           57.93004697297681,
           57.600476600649536,
           57.27090622832226,
           56.941335855994986,
           56.61176548366771,
           56.28219511134042,
           55.95262473901313,
           55.62305436668587,
           55.29348399435859,
           54.96391362203131,
           54.63434324970402,
           54.304772877376756,
           53.975202505049474,
           53.64563213272219,
           53.31606176039491,
           52.98649138806763,
           52.656921015740366,
           52.32735064341308,
           51.9977802710858,
           51.66820989875852,
           51.33863952643123,
           51.00906915410397,
           50.67949878177668,
           50.3499284094494,
           50.02035803712212,
           49.690787664794854,
           49.36121729246757,
           49.03164692014029,
           48.70207654781301,
           48.372506175485725,
           48.062588867810575,
           47.77232462478743,
           47.48206038176437,
           47.1917961387414,
           46.90153189571826,
           46.6112676526952,
           46.32100340967207,
           46.030739166649006,
           45.74047492362586,
           45.45021068060281,
           45.15994643757968,
           44.8696821945566,
           44.57941795153347,
           44.28915370851042,
           43.998889465487274,
           43.7086252224643,
           43.4183609794412,
           43.12954087538504,
           42.843644274144644,
           42.55774767290418,
           42.271851071663775,
           41.98595447042337,
           41.700057869182984,
           41.41416126794251,
           41.12826466670211,
           40.84236806546164,
           40.55647146422125,
           40.27057486298077,
           39.98467826174038,
           39.69878166049998,
           39.41288505925951,
           39.1269884580191,
           38.84109185677872,
           38.55519525553832,
           38.269298654297835,
           37.983402053057446,
           37.69750545181698,
           37.41160885057658,
           37.12571224933612,
           36.8414717269548,
           36.56139264228404,
           36.281313557613366,
           36.001234472942684,
           35.721155388271924,
           35.44107630360117,
           35.1609972189305,
           34.88091813425981,
           34.600839049589055,
           34.32075996491837,
           34.04068088024763,
           33.760601795577,
           33.48052271090626,
           33.20044362623558,
           32.92036454156482,
           32.64028545689413,
           32.360206372223466,
           32.080127287552706,
           31.80051724802461,
           31.528255552369025,
           31.255993856713506,
           30.983732161057976,
           30.711470465402396,
           30.439208769746873,
           30.16694707409134,
           29.89468537843576,
           29.622423682780237,
           29.350161987124647,
           29.07790029146912,
           28.805638595813612,
           28.533376900158014,
           28.26111520450248,
           27.98885350884696,
           27.71659181319138,
           27.4501192753905,
           27.185656197568594,
           26.921193119746754,
           26.656730041924895,
           26.392266964103047,
           26.12780388628115,
           25.86334080845923,
           25.59887773063738,
           25.334414652815532,
           25.06995157499363,
           24.805488497171773,
           24.54102541934993,
           24.276562341528084,
           24.01755116517508,
           23.761018128213568,
           23.504485091252004,
           23.247952054290472,
           22.991419017328894,
           22.734885980367395,
           22.478352943405817,
           22.22181990644429,
           21.96528686948272,
           21.708753832521264,
           21.452220795559732,
           21.199565525684324,
           20.952080607837456,
           20.70459568999053,
           20.457110772143654,
           20.20962585429679,
           19.96214093644986,
           19.714656018602973,
           19.467171100756104,
           19.219686182909236,
           18.97220126506226,
           18.73091252639161,
           18.49344063363647,
           18.255968740881272,
           18.01849684812613,
           17.781024955370984,
           17.543553062615786,
           17.306081169860587,
           17.06860927710546,
           16.8311373843503,
           16.604008765077126,
           16.37692847989868,
           16.14984819472028,
           15.92276790954187,
           15.69568762436347,
           15.46860733918507,
           15.24152705400662,
           15.017684159033534,
           14.799716523501832,
           14.581748887970079,
           14.363781252438327,
           14.14581361690666,
           13.92784598137492,
           13.709878345843203,
           13.496922002109004,
           13.288244529747708,
           13.079567057386397,
           12.870889585025099,
           12.66221211266377,
           12.453534640302461,
           12.24993907109607,
           12.053325183203777,
           11.856711295311484,
           11.660097407419197,
           11.46348351952689,
           11.266869631634613,
           11.082076469117627,
           10.898613139979073,
           10.715149810840519,
           10.531686481701925,
           10.348223152563367,
           10.175491159068423,
           10.004095194514386,
           9.832699229960374,
           9.661303265406385,
           9.493472597312063,
           9.333072758083706,
           9.17267291885536,
           9.012273079626992,
           8.853350041161756,
           8.702992452165176,
           8.552634863168619,
           8.40227727417205,
           8.254762695011198,
           8.11356591364681,
           7.972369132282383,
           7.831172350917976,
           7.696459780905703,
           7.563639490414358,
           7.430819199922989,
           7.301943878820767,
           7.176945511069724,
           7.0519471433186816,
           6.931251140212138,
           6.8153666561142865,
           6.699482172016403,
           6.59005221575928,
           6.48406289598971,
           6.378237694082999,
           6.2792507434677365,
           6.180263792852489,
           6.084204288620777,
           5.990382655046471,
           5.89830886721675,
           5.811061698693919,
           5.724552326344089,
           5.64424044247734,
           5.564394240413726,
           5.4902350041794055,
           5.416961167361212,
           5.348247743016774,
           5.274629425748436,
           5.192182301217076,
           5.1097351766857315,
           5.027288052154372,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           67.76415966949672,
           67.81105364348988,
           67.85794761748306,
           67.90484159147624,
           67.95173556546942,
           67.99862953946258,
           68.04552351345575,
           68.09241748744893,
           68.1393114614421,
           68.18620543543528,
           68.23309940942845,
           68.27999338342161,
           68.32688735741479,
           68.37378133140797,
           68.42067530540113,
           68.46756927939431,
           68.51446325338748,
           68.56135722738065,
           68.60825120137383,
           68.655145175367,
           68.70203914936016,
           68.74893312335335,
           68.7958270973465,
           68.84272107133968,
           68.88961504533286,
           68.93650901932604,
           68.9834029933192,
           69.02937746249798,
           69.07516802974499,
           69.120958596992,
           69.16674916423901,
           69.21253973148602,
           69.25833029873301,
           69.30412086598004,
           69.34991143322705,
           69.39570200047405,
           69.44149256772107,
           69.48728313496807,
           69.53307370221508,
           69.57886426946209,
           69.6246548367091,
           69.6704454039561,
           69.7162359712031,
           69.76202653845012,
           69.80781710569713,
           69.85360767294412,
           69.89939824019115,
           69.94518880743814,
           69.99097937468515,
           70.03676994193216,
           70.08256050917916,
           70.12835107642618,
           70.17414164367318,
           70.2199322109202,
           70.26572277816722,
           70.31151334541421,
           70.35730391266124,
           70.40309447990823,
           70.44888504715524,
           70.49467561440225,
           70.54046618164925,
           70.58625674889628,
           70.63204731614327,
           70.67783788339028,
           70.72362845063729,
           70.7694190178843,
           70.8152095851313,
           70.86100015237832,
           70.90679071962532,
           70.95258128687234,
           70.99837185411934,
           71.04416242136635,
           71.08995298861336,
           71.13574355586036,
           71.18153412310738,
           71.22732469035438,
           71.27311525760139,
           71.3189058248484,
           71.36469639209541,
           71.41048695934242,
           71.45627752658943,
           71.50206809383644,
           71.54785866108344,
           71.59364922833045,
           71.62168785448344,
           71.64617609241762,
           71.6706643303518,
           71.69515256828599,
           71.71964080622017,
           71.74412904415436,
           71.76861728208854,
           71.79310552002272,
           71.81759375795691,
           71.84208199589109,
           71.86657023382529,
           71.89105847175946,
           71.91554670969366,
           71.94003494762782,
           71.96452318556203,
           71.98901142349621,
           72.01349966143039,
           72.03798789936457,
           72.06247613729875,
           72.08696437523295,
           72.11145261316713,
           72.13594085110131,
           72.16042908903549,
           72.18491732696967,
           72.20940556490386,
           72.23389380283805,
           72.25838204077223,
           72.28287027870641,
           72.3073585166406,
           72.33184675457477,
           72.35633499250896,
           72.38082323044316,
           72.40531146837733,
           72.42979970631151,
           72.4542879442457,
           72.47877618217989,
           72.50326442011408,
           72.52775265804826,
           72.55224089598244,
           72.57672913391663,
           72.60121737185081,
           72.625705609785,
           72.65019384771917,
           72.67468208565336,
           72.69917032358755,
           72.72365856152172,
           72.74814679945591,
           72.7726350373901,
           72.79712327532428,
           72.82161151325846,
           72.84609975119265,
           72.87058798912685,
           72.89507622706101,
           72.9195644649952,
           72.94405270292938,
           72.96854094086358,
           72.99302917879776,
           73.01921458701138,
           73.04573942749256,
           73.07226426797375,
           73.09878910845494,
           73.12531394893614,
           73.15183878941733,
           73.17836362989851,
           73.2048884703797,
           73.2314133108609,
           73.25793815134209,
           73.28446299182329,
           73.31098783230446,
           73.33751267278566,
           73.36403751326685,
           73.39056235374804,
           73.41708719422923,
           73.44361203471043,
           73.47013687519161,
           73.4966617156728,
           73.52318655615399,
           73.54971139663519,
           73.57623623711638,
           73.60276107759756,
           73.62928591807875,
           73.65581075855994,
           73.68233559904112,
           73.49553014151724,
           73.20205953499084,
           72.90858892846441,
           72.615118321938,
           72.32164771541159,
           72.02817710888516,
           71.73470650235875,
           71.44123589583234,
           71.14776528930591,
           70.8542946827795,
           70.56082407625307,
           70.26735346972666,
           69.97388286320025,
           69.68041225667382,
           69.38694165014742,
           69.093471043621,
           68.80000043709458,
           68.50652983056817,
           68.21305922404174,
           67.91958861751533,
           67.62611801098892,
           67.33264740446249,
           67.0391767979361,
           66.74570619140965,
           66.45223558488325,
           66.15876497835683,
           65.86529437183042,
           65.57182376530402,
           65.27835315877758,
           64.98488255225116,
           64.69141194572474,
           64.39794133919833,
           64.09959238736049,
           63.77002201503319,
           63.440451642705916,
           63.110881270378634,
           62.78131089805135,
           62.45174052572409,
           62.1221701533968,
           61.79259978106952,
           61.46302940874226,
           61.13345903641496,
           60.80388866408769,
           60.47431829176041,
           60.14474791943313,
           59.81517754710583,
           59.48560717477857,
           59.1560368024513,
           58.826466430124,
           58.496896057796725,
           58.16732568546944,
           57.837755313142175,
           57.5081849408149,
           57.17861456848761,
           56.849044196160335,
           56.51947382383307,
           56.18990345150578,
           55.8603330791785,
           55.53076270685122,
           55.20119233452394,
           54.87162196219667,
           54.54205158986939,
           54.212481217542106,
           53.88291084521482,
           53.553340472887555,
           53.22377010056027,
           52.894199728233,
           52.56462935590571,
           52.235058983578426,
           51.905488611251165,
           51.575918238923876,
           51.2463478665966,
           50.91677749426931,
           50.58720712194203,
           50.25763674961476,
           49.92806637728748,
           49.5984960049602,
           49.268925632632914,
           48.93935526030565,
           48.609784887978364,
           48.28021451565108,
           47.95064414332381,
           47.62107377099652,
           47.31115646332137,
           47.02089222029823,
           46.73062797727517,
           46.440363734252195,
           46.15009949122906,
           45.85983524820599,
           45.569571005182866,
           45.2793067621598,
           44.98904251913665,
           44.69877827611361,
           44.40851403309047,
           44.12022227278113,
           43.83432567154081,
           43.548429070300344,
           43.26253246905994,
           42.97663586781948,
           42.69073926657909,
           42.4048426653386,
           42.11894606409822,
           41.833049462857744,
           41.54715286161734,
           41.26125626037694,
           40.97535965913656,
           40.68946305789607,
           40.403566456655675,
           40.11766985541521,
           39.83177325417481,
           39.54587665293434,
           39.259980051693944,
           38.97408345045355,
           38.688186849213075,
           38.402290247972665,
           38.116393646732284,
           37.83049704549189,
           37.54939883126469,
           37.269319746594014,
           36.98924066192327,
           36.70916157725264,
           36.4290824925819,
           36.149003407911216,
           35.868924323240456,
           35.58884523856978,
           35.3087661538991,
           35.02868706922833,
           34.74860798455759,
           34.46852889988691,
           34.188449815216224,
           33.908370730545464,
           33.62829164587479,
           33.34821256120404,
           33.06813347653342,
           32.788054391862666,
           32.50891339572297,
           32.23665170006737,
           31.964390004411843,
           31.69212830875633,
           31.419866613100737,
           31.147604917445204,
           30.875343221789628,
           30.603081526134105,
           30.33081983047857,
           30.05855813482299,
           29.78629643916747,
           29.51403474351194,
           29.241773047856356,
           28.969511352200833,
           28.697249656545242,
           28.424987960889712,
           28.155836143337797,
           27.891373065515992,
           27.62690998769408,
           27.36244690987218,
           27.097983832050392,
           26.83352075422848,
           26.56905767640658,
           26.304594598584735,
           26.040131520762877,
           25.77566844294103,
           25.51120536511913,
           25.246742287297213,
           24.98227920947536,
           24.717816131653514,
           24.46128309302669,
           24.204750056065116,
           23.9482170191036,
           23.691683982142088,
           23.435150945180506,
           23.17861790821899,
           22.92208487125743,
           22.665551834295897,
           22.40901879733432,
           22.152485760372816,
           21.89595272341124,
           21.64344107452034,
           21.395956156673467,
           21.1484712388266,
           20.900986320979715,
           20.653501403132797,
           20.406016485285928,
           20.158531567439,
           19.91104664959213,
           19.66356173174526,
           19.416076813898332,
           19.172359173108866,
           18.934887280353724,
           18.697415387598582,
           18.459943494843426,
           18.222471602088238,
           17.984999709333096,
           17.7475278165779,
           17.510055923822755,
           17.272584031067613,
           17.040573772858952,
           16.81349348768054,
           16.58641320250215,
           16.35933291732374,
           16.13225263214529,
           15.905172346966845,
           15.678092061788444,
           15.451011776610033,
           15.230166463797525,
           15.012198828265785,
           14.794231192734033,
           14.576263557202326,
           14.358295921670624,
           14.140328286138873,
           13.922360650607121,
           13.710792049101425,
           13.502114576740126,
           13.293437104378818,
           13.084759632017487,
           12.876082159656189,
           12.66740468729488,
           12.463666634793185,
           12.267052746900875,
           12.07043885900859,
           11.873824971116298,
           11.677211083224002,
           11.480597195331711,
           11.293735405553042,
           11.110272076414486,
           10.926808747275933,
           10.743345418137338,
           10.559882088998783,
           10.383659179339137,
           10.212263214785102,
           10.0408672502311,
           9.8694712856771,
           9.698075321123063,
           9.536737245793953,
           9.376337406565593,
           9.215937567337239,
           9.055537728108881,
           8.901438907872706,
           8.751081318876146,
           8.60072372987958,
           8.450366140882998,
           8.306326350839061,
           8.165129569474654,
           8.023932788110228,
           7.88324061467468,
           7.750420324183327,
           7.617600033691959,
           7.484779743200614,
           7.357468806637467,
           7.232470438886409,
           7.107472071135382,
           6.987870752393372,
           6.871986268295503,
           6.75610178419762,
           6.647125245178259,
           6.541135925408662,
           6.435146605639066,
           6.336159654855324,
           6.237172704240051,
           6.140657819404842,
           6.046836185830548,
           5.95378424588757,
           5.866537077364717,
           5.779289908841875,
           5.698289415082366,
           5.617977531215617,
           5.542689368561373,
           5.4685301323270625,
           5.399016210180818,
           5.330302785836365,
           5.247855661305027,
           5.1654085367736675,
           5.082961412242307,
           5.000514287710963,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           67.80507044004469,
           67.85196441403785,
           67.89885838803103,
           67.9457523620242,
           67.99264633601737,
           68.03954031001055,
           68.08643428400372,
           68.13332825799688,
           68.18022223199006,
           68.22711620598324,
           68.27364237835302,
           68.31943294560004,
           68.36522351284704,
           68.41101408009405,
           68.45680464734107,
           68.50259521458807,
           68.54838578183508,
           68.59417634908209,
           68.6399669163291,
           68.68575748357611,
           68.73154805082311,
           68.77733861807012,
           68.82312918531713,
           68.86891975256414,
           68.91471031981115,
           68.96050088705816,
           69.00629145430517,
           69.05208202155217,
           69.09787258879919,
           69.14366315604619,
           69.1894537232932,
           69.23524429054021,
           69.28103485778722,
           69.32682542503423,
           69.37261599228123,
           69.41840655952824,
           69.46419712677525,
           69.50998769402226,
           69.55577826126927,
           69.60156882851628,
           69.64735939576329,
           69.69314996301028,
           69.73894053025731,
           69.7847310975043,
           69.83052166475132,
           69.87631223199833,
           69.92210279924534,
           69.96789336649235,
           70.01368393373934,
           70.05947450098635,
           70.10526506823336,
           70.15105563548038,
           70.19684620272737,
           70.24263676997438,
           70.2884273372214,
           70.3342179044684,
           70.38000847171543,
           70.42579903896242,
           70.47158960620942,
           70.51738017345644,
           70.56317074070344,
           70.60896130795047,
           70.65475187519746,
           70.70054244244446,
           70.74633300969148,
           70.79212357693851,
           70.8379141441855,
           70.8837047114325,
           70.92949527867952,
           70.97528584592652,
           71.02107641317355,
           71.06686698042054,
           71.11265754766754,
           71.15844811491456,
           71.20423868216156,
           71.25002924940858,
           71.2958198166556,
           71.34161038390259,
           71.38740095114962,
           71.43319151839661,
           71.47898208564362,
           71.52477265289063,
           71.57056322013763,
           71.61635378738464,
           71.64439241353763,
           71.66888065147181,
           71.693368889406,
           71.71785712734018,
           71.74234536527436,
           71.76683360320855,
           71.79132184114273,
           71.81581007907691,
           71.8402983170111,
           71.86478655494528,
           71.88927479287948,
           71.91376303081364,
           71.93825126874785,
           71.96273950668201,
           71.9872277446162,
           72.01171598255038,
           72.03620422048458,
           72.06069245841876,
           72.08518069635295,
           72.10966893428713,
           72.13415717222131,
           72.15864541015549,
           72.18313364808968,
           72.20762188602386,
           72.23211012395805,
           72.25659836189223,
           72.28108659982641,
           72.3055748377606,
           72.3300630756948,
           72.35455131362897,
           72.37903955156315,
           72.40352778949733,
           72.42801602743151,
           72.4525042653657,
           72.4769925032999,
           72.50148074123408,
           72.52596897916825,
           72.55045721710245,
           72.57494545503663,
           72.59943369297082,
           72.623921930905,
           72.64841016883918,
           72.67289840677336,
           72.69738664470755,
           72.72187488264174,
           72.74636312057592,
           72.7708513585101,
           72.7953395964443,
           72.81982783437847,
           72.84431607231267,
           72.86880431024684,
           72.89329254818102,
           72.9177807861152,
           72.9422690240494,
           72.96675726198357,
           72.99124549991777,
           73.01573373785195,
           73.04022197578612,
           73.06471021372032,
           73.0891984516545,
           73.11368668958868,
           73.13817492752287,
           73.16266316545705,
           73.18715140339123,
           73.21163964132542,
           73.23612787925961,
           73.26061611719378,
           73.28510435512797,
           73.30959259306216,
           73.33408083099633,
           73.35856906893052,
           73.38305730686471,
           73.40754554479888,
           73.43271265140298,
           73.45923749188417,
           73.48576233236535,
           73.51228717284654,
           73.53881201332774,
           73.56533685380893,
           73.59186169429012,
           73.6183865347713,
           73.64491137525249,
           73.67143621573369,
           73.48463075820979,
           73.19116015168339,
           72.89768954515696,
           72.60421893863055,
           72.31074833210414,
           72.01727772557771,
           71.7238071190513,
           71.43033651252487,
           71.13686590599846,
           70.84339529947206,
           70.54992469294562,
           70.25645408641923,
           69.93956742941687,
           69.60999705708959,
           69.28042668476233,
           68.95085631243505,
           68.62128594010777,
           68.29171556778047,
           67.9621451954532,
           67.63257482312594,
           67.30300445079864,
           66.97343407847137,
           66.6438637061441,
           66.3142933338168,
           65.98472296148954,
           65.65515258916226,
           65.32558221683497,
           64.9960118445077,
           64.66644147218041,
           64.33687109985314,
           64.00730072752586,
           63.67773035519858,
           63.34815998287131,
           63.018589610544026,
           62.689019238216744,
           62.35944886588946,
           62.02987849356218,
           61.70030812123491,
           61.37073774890763,
           61.04116737658035,
           60.711597004253086,
           60.3820266319258,
           60.05245625959852,
           59.72288588727123,
           59.39331551494395,
           59.06374514261667,
           58.7341747702894,
           58.40460439796212,
           58.075034025634835,
           57.74546365330757,
           57.41589328098027,
           57.086322908653,
           56.75675253632573,
           56.42718216399844,
           56.09761179167116,
           55.768041419343895,
           55.438471047016606,
           55.10890067468932,
           54.77933030236204,
           54.449759930034766,
           54.1201895577075,
           53.79061918538021,
           53.46104881305294,
           53.13147844072565,
           52.80190806839839,
           52.4723376960711,
           52.142767323743826,
           51.813196951416536,
           51.48362657908926,
           51.15405620676199,
           50.8244858344347,
           50.49491546210743,
           50.165345089780146,
           49.835774717452864,
           49.506204345125596,
           49.176633972798314,
           48.847063600471024,
           48.51749322814375,
           48.187922855816474,
           47.8583524834892,
           47.52878211116192,
           47.199211738834634,
           46.869641366507345,
           46.559724058832195,
           46.26945981580906,
           45.979195572786,
           45.68893132976302,
           45.398667086739884,
           45.11090367017733,
           44.82500706893694,
           44.53911046769647,
           44.25321386645599,
           43.9673172652156,
           43.6814206639752,
           43.39552406273472,
           43.1096274614944,
           42.82373086025393,
           42.53783425901353,
           42.25193765777307,
           41.966041056532674,
           41.680144455292194,
           41.394247854051805,
           41.10835125281134,
           40.82245465157093,
           40.53655805033053,
           40.250661449090146,
           39.96476484784966,
           39.67886824660926,
           39.39297164536879,
           39.1070750441284,
           38.82117844288793,
           38.53740502024543,
           38.257325935574755,
           37.977246850904,
           37.697167766233235,
           37.417088681562575,
           37.137009596891886,
           36.85693051222112,
           36.57685142755045,
           36.2967723428797,
           36.016693258209074,
           35.73661417353833,
           35.456535088867646,
           35.176456004196886,
           34.89637691952621,
           34.61629783485553,
           34.33621875018477,
           34.05613966551402,
           33.77606058084335,
           33.495981496172654,
           33.21730954342126,
           32.945047847765736,
           32.67278615211022,
           32.40052445645462,
           32.1282627607991,
           31.856001065143584,
           31.58373936948799,
           31.31147767383246,
           31.03921597817695,
           30.766954282521354,
           30.494692586865824,
           30.222430891210244,
           29.950169195554718,
           29.67790749989919,
           29.40564580424361,
           29.133384108588086,
           28.861553011285157,
           28.597089933463312,
           28.332626855641468,
           28.068163777819553,
           27.803700699997695,
           27.539237622175808,
           27.274774544354006,
           27.01031146653209,
           26.74584838871019,
           26.481385310888403,
           26.216922233066487,
           25.952459155244586,
           25.687996077422746,
           25.423532999600887,
           25.16154805783978,
           24.905015020878267,
           24.648481983916685,
           24.391948946955157,
           24.13541590999365,
           23.878882873032133,
           23.622349836070555,
           23.36581679910904,
           23.109283762147527,
           22.852750725185945,
           22.596217688224435,
           22.339684651262868,
           22.087316623356433,
           21.83983170550955,
           21.592346787662695,
           21.344861869815766,
           21.097376951968833,
           20.849892034121968,
           20.602407116275096,
           20.354922198428213,
           20.107437280581294,
           19.859952362734425,
           19.6138058198262,
           19.376333927071055,
           19.13886203431587,
           18.901390141560714,
           18.663918248805516,
           18.426446356050374,
           18.188974463295235,
           17.951502570540075,
           17.714030677784887,
           17.477138780640836,
           17.250058495462422,
           17.02297821028398,
           16.79589792510558,
           16.56881763992713,
           16.341737354748716,
           16.11465706957033,
           15.887576784391916,
           15.660616404093162,
           15.442648768561497,
           15.224681133029758,
           15.006713497498005,
           14.788745861966337,
           14.570778226434598,
           14.352810590902845,
           14.13484295537114,
           13.924662096093876,
           13.715984623732567,
           13.507307151371258,
           13.298629679009926,
           13.08995220664863,
           12.88127473428732,
           12.6773941984903,
           12.480780310598025,
           12.284166422705704,
           12.087552534813426,
           11.89093864692112,
           11.69432475902883,
           11.505394341988495,
           11.32193101284995,
           11.138467683711355,
           10.955004354572761,
           10.771541025434207,
           10.591827199609869,
           10.420431235055856,
           10.249035270501832,
           10.077639305947827,
           9.906243341393793,
           9.74040173350422,
           9.580001894275851,
           9.419602055047495,
           9.25920221581914,
           9.099885363580274,
           8.949527774583684,
           8.799170185587116,
           8.648812596590535,
           8.499086788031324,
           8.357890006666917,
           8.2166932253025,
           8.075496443938102,
           7.937201157952286,
           7.804380867460934,
           7.671560576969597,
           7.538740286478245,
           7.412993734454158,
           7.287995366703139,
           7.162996998952089,
           7.044490364574594,
           6.928605880476741,
           6.812721396378858,
           6.704198274597207,
           6.598208954827623,
           6.492219635058053,
           6.3930685662429045,
           6.294081615627631,
           6.197111350188923,
           6.1032897166146185,
           6.009468083040302,
           5.922012456035542,
           5.834765287512699,
           5.752338387687393,
           5.6720265038206374,
           5.595143732943371,
           5.520984496709042,
           5.449784677344867,
           5.38107125300043,
           5.303529021392967,
           5.221081896861609,
           5.1386347723302634,
           5.056187647798903,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           67.83972265332471,
           67.88438651082765,
           67.92905036833059,
           67.97371422583353,
           68.01837808333646,
           68.0630419408394,
           68.10770579834232,
           68.15255744125525,
           68.19834800850226,
           68.24413857574928,
           68.28992914299627,
           68.3357197102433,
           68.38151027749029,
           68.4273008447373,
           68.47309141198431,
           68.51888197923132,
           68.56467254647833,
           68.61046311372533,
           68.65625368097234,
           68.70204424821935,
           68.74783481546636,
           68.79362538271337,
           68.83941594996038,
           68.8852065172074,
           68.93099708445439,
           68.9767876517014,
           69.02257821894841,
           69.06836878619542,
           69.11415935344243,
           69.15994992068943,
           69.20574048793645,
           69.25153105518345,
           69.29732162243046,
           69.34311218967747,
           69.38890275692448,
           69.43469332417149,
           69.4804838914185,
           69.52627445866551,
           69.57206502591251,
           69.61785559315953,
           69.66364616040653,
           69.70943672765354,
           69.75522729490055,
           69.80101786214756,
           69.84680842939457,
           69.89259899664158,
           69.93838956388859,
           69.98418013113559,
           70.0299706983826,
           70.07576126562961,
           70.12155183287662,
           70.16734240012363,
           70.21313296737064,
           70.25892353461765,
           70.30471410186465,
           70.35050466911167,
           70.39629523635867,
           70.44208580360569,
           70.48787637085269,
           70.53366693809969,
           70.57945750534671,
           70.6252480725937,
           70.67103863984073,
           70.71682920708773,
           70.76261977433474,
           70.80841034158175,
           70.85420090882874,
           70.89999147607577,
           70.94578204332277,
           70.99157261056979,
           71.03736317781679,
           71.0831537450638,
           71.12894431231081,
           71.1747348795578,
           71.22052544680483,
           71.26631601405182,
           71.31210658129883,
           71.35789714854585,
           71.40368771579286,
           71.44947828303987,
           71.49526885028688,
           71.54105941753387,
           71.58684998478088,
           71.6326405520279,
           71.65893087564658,
           71.68132115053959,
           71.70371142543257,
           71.72610170032559,
           71.7484919752186,
           71.77088225011161,
           71.79327252584747,
           71.81776076378165,
           71.84224900171584,
           71.86673723965004,
           71.89122547758421,
           71.9157137155184,
           71.94020195345257,
           71.96469019138677,
           71.98917842932094,
           72.01366666725514,
           72.03815490518932,
           72.0626431431235,
           72.08713138105767,
           72.11161961899187,
           72.13610785692606,
           72.16059609486022,
           72.18508433279442,
           72.2095725707286,
           72.23406080866279,
           72.25854904659697,
           72.28303728453116,
           72.30752552246534,
           72.33201376039952,
           72.35650199833371,
           72.38099023626789,
           72.40547847420207,
           72.42996671213626,
           72.45445495007044,
           72.47894318800462,
           72.50343142593881,
           72.527919663873,
           72.55240790180719,
           72.57689613974136,
           72.60138437767554,
           72.62587261560974,
           72.6503608535439,
           72.6748490914781,
           72.69933732941227,
           72.72382556734647,
           72.74831380528065,
           72.77280204321482,
           72.79729028114902,
           72.82177851908321,
           72.84626675701739,
           72.87075499495157,
           72.89524323288576,
           72.91973147081995,
           72.94421970875412,
           72.96870794668831,
           72.99319618462249,
           73.01768442255667,
           73.04217266049086,
           73.06666089842504,
           73.09114913635923,
           73.11563737429341,
           73.14012561222759,
           73.16461385016179,
           73.18910208809598,
           73.21359032603016,
           73.23807856396434,
           73.26256680189852,
           73.28705503983271,
           73.3115432777669,
           73.33603151570107,
           73.36051975363526,
           73.38500799156945,
           73.40949622950362,
           73.43398446743781,
           73.458472705372,
           73.48296094330618,
           73.50744918124036,
           73.53193741917454,
           73.55642565710873,
           73.58091389504291,
           73.60540213297709,
           73.62989037091128,
           73.65437860884546,
           73.41766980346614,
           73.0503624764301,
           72.68305514939402,
           72.31574782235796,
           71.94844049532192,
           71.58113316828583,
           71.21382584124979,
           70.84651853816409,
           70.51687772000237,
           70.18723690184063,
           69.85759608367889,
           69.52795526551716,
           69.19831444735544,
           68.8686736291937,
           68.53903281103197,
           68.20939199287024,
           67.8797511747085,
           67.55011035654677,
           67.22046953838503,
           66.89082872022331,
           66.56118790206158,
           66.23154708389984,
           65.90190626573812,
           65.57226544757637,
           65.24262462941465,
           64.91298381125291,
           64.58334299309116,
           64.25370217492946,
           63.924061356767695,
           63.59442053860597,
           63.26477972044424,
           62.9351389022825,
           62.60549808412078,
           62.27585726595904,
           61.94621644779731,
           61.61657562963558,
           61.286934811473834,
           60.95729399331212,
           60.62765317515037,
           60.298012356988636,
           59.96837153882693,
           59.63873072066518,
           59.30908990250345,
           58.97944908434171,
           58.649808266179974,
           58.32016744801824,
           57.99052662985651,
           57.66088581169478,
           57.33124499353304,
           57.0016041753713,
           56.67196335720956,
           56.34232253904784,
           56.01268172088612,
           55.68304090272438,
           55.35340008456264,
           55.023759266400916,
           54.69411844823918,
           54.364477630077445,
           54.03483681191571,
           53.70519599375397,
           53.375555175592254,
           53.04591435743051,
           52.71627353926877,
           52.38663272110705,
           52.05699190294532,
           51.727351084783585,
           51.39771026662185,
           51.06806944846011,
           50.73842863029837,
           50.40878781213665,
           50.079146993974916,
           49.74950617581318,
           49.419865357651446,
           49.090224539489704,
           48.76058372132798,
           48.43094290316625,
           48.10130208500451,
           47.77166126684277,
           47.44202044868105,
           47.112379630519314,
           46.78273881235758,
           46.45309799419584,
           46.12345717603411,
           45.81568846633298,
           45.529791865092584,
           45.24389526385212,
           44.95799866261179,
           44.67210206137132,
           44.386205460130924,
           44.10030885889053,
           43.814412257650055,
           43.528515656409574,
           43.24261905516919,
           42.95672245392879,
           42.67082585268832,
           42.384929251447986,
           42.099032650207526,
           41.813136048967124,
           41.52723944772666,
           41.24134284648627,
           40.95544624524579,
           40.6695496440054,
           40.383653042764934,
           40.097756441524524,
           39.81185984028412,
           39.52596323904374,
           39.245332124555354,
           38.96525303988474,
           38.68517395521399,
           38.40509487054331,
           38.125015785872556,
           37.844936701201874,
           37.56485761653119,
           37.28477853186044,
           37.00469944718968,
           36.72462036251902,
           36.44454127784832,
           36.16446219317756,
           35.88438310850689,
           35.60430402383614,
           35.32422493916551,
           35.04414585449477,
           34.76406676982408,
           34.48398768515333,
           34.20390860048265,
           33.9257056911197,
           33.6534439954641,
           33.38118229980858,
           33.10892060415306,
           32.83665890849747,
           32.56439721284188,
           32.29213551718636,
           32.019873821530844,
           31.747612125875246,
           31.47535043021972,
           31.203088734564204,
           30.93082703890861,
           30.65856534325308,
           30.386303647597572,
           30.114041951941974,
           29.841780256286448,
           29.56951856063086,
           29.302806801410686,
           29.03834372358877,
           28.77388064576698,
           28.509417567945082,
           28.244954490123167,
           27.980491412301323,
           27.71602833447948,
           27.451565256657563,
           27.187102178835705,
           26.922639101013818,
           26.658176023192013,
           26.3937129453701,
           26.1292498675482,
           25.864786789726413,
           25.6052799856914,
           25.348746948729836,
           25.092213911768322,
           24.83568087480679,
           24.579147837845227,
           24.322614800883713,
           24.066081763922135,
           23.809548726960603,
           23.553015689999096,
           23.296482653037575,
           23.039949616076,
           22.783416579114487,
           22.531192172192483,
           22.2837072543456,
           22.03622233649873,
           21.788737418651863,
           21.541252500804934,
           21.293767582958047,
           21.046282665111193,
           20.798797747264267,
           20.551312829417334,
           20.303827911570465,
           20.056342993723597,
           19.817780573788333,
           19.58030868103319,
           19.34283678827805,
           19.10536489552285,
           18.867893002767705,
           18.63042111001252,
           18.392949217257364,
           18.155477324502165,
           17.918005431747023,
           17.686623503244267,
           17.459543218065814,
           17.232462932887415,
           17.005382647709016,
           16.778302362530603,
           16.55122207735216,
           16.324141792173762,
           16.09706150699531,
           15.873098708857174,
           15.655131073325482,
           15.43716343779373,
           15.219195802261979,
           15.001228166730307,
           14.78326053119857,
           14.565292895666818,
           14.347325260135152,
           14.13853214308635,
           13.929854670725042,
           13.721177198363742,
           13.51249972600238,
           13.30382225364107,
           13.095144781279757,
           12.891121762187415,
           12.694507874295141,
           12.49789398640282,
           12.301280098510544,
           12.104666210618266,
           11.908052322725947,
           11.717053278423908,
           11.533589949285352,
           11.350126620146781,
           11.166663291008218,
           10.983199961869671,
           10.799995219880596,
           10.628599255326561,
           10.457203290772584,
           10.285807326218558,
           10.114411361664548,
           9.944066221214477,
           9.783666381986132,
           9.623266542757753,
           9.462866703529407,
           9.302466864301039,
           9.147974230291222,
           8.997616641294652,
           8.847259052298103,
           8.696901463301515,
           8.55065044385918,
           8.40945366249478,
           8.268256881130363,
           8.127060099765957,
           7.9911617012299185,
           7.858341410738575,
           7.725521120247205,
           7.593517030021925,
           7.468518662270898,
           7.343520294519855,
           7.21852192676878,
           7.101109976755826,
           6.985225492657964,
           6.869341008560081,
           6.761271304016182,
           6.655281984246583,
           6.549292664476999,
           6.449977477630473,
           6.350990527015226,
           6.2535648809729825,
           6.159743247398678,
           6.0659216138243846,
           5.977487834706355,
           5.8902406661835025,
           5.806387360292433,
           5.7260754764256765,
           5.647598097325343,
           5.573438861091022,
           5.500553144508925,
           5.431839720164471,
           5.35920238148091,
           5.2767552569495635,
           5.194308132418204,
           5.111861007886846,
           5.029413883355501,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           67.86552129674712,
           67.91018515425006,
           67.95484901175298,
           67.99951286925592,
           68.04417672675886,
           68.0888405842618,
           68.13350444176473,
           68.17816829926767,
           68.22283215677061,
           68.26749601427355,
           68.31215987177647,
           68.3568237292794,
           68.40148758678234,
           68.44615144428528,
           68.49081530178822,
           68.53547915929116,
           68.58014301679408,
           68.62480687429702,
           68.66947073179996,
           68.7141345893029,
           68.75879844680583,
           68.80346230430877,
           68.84812616181169,
           68.89279001931463,
           68.93820501691368,
           68.9839955841607,
           69.0297861514077,
           69.0755767186547,
           69.12136728590173,
           69.16715785314872,
           69.21294842039573,
           69.25873898764276,
           69.30452955488975,
           69.35032012213676,
           69.39611068938378,
           69.44190125663077,
           69.4876918238778,
           69.53348239112479,
           69.5792729583718,
           69.62506352561883,
           69.67085409286582,
           69.71664466011282,
           69.76243522735984,
           69.80822579460686,
           69.85401636185385,
           69.89980692910086,
           69.94559749634787,
           69.99138806359488,
           70.0371786308419,
           70.0829691980889,
           70.1287597653359,
           70.17455033258292,
           70.22034089982992,
           70.26613146707693,
           70.31192203432394,
           70.35771260157095,
           70.40350316881796,
           70.44929373606497,
           70.49508430331198,
           70.54087487055898,
           70.58666543780599,
           70.632456005053,
           70.6782465723,
           70.72403713954702,
           70.76982770679402,
           70.81561827404104,
           70.86140884128804,
           70.90719940853505,
           70.95298997578206,
           70.99878054302907,
           71.04457111027608,
           71.09036167752308,
           71.1361522447701,
           71.1819428120171,
           71.22773337926411,
           71.27352394651112,
           71.31931451375813,
           71.36510508100514,
           71.41089564825214,
           71.45668621549916,
           71.50247678274616,
           71.54826734999317,
           71.59405791724018,
           71.63984848448719,
           71.66613880810587,
           71.68852908299887,
           71.71091935789188,
           71.7333096327849,
           71.75569990767791,
           71.77809018257092,
           71.80048045746392,
           71.82287073235693,
           71.84526100724995,
           71.86765128214296,
           71.89004155703597,
           71.91243183192898,
           71.934822106822,
           71.95721238171501,
           71.97960265660802,
           72.00199293150104,
           72.02438320639403,
           72.04677348128705,
           72.06916375618006,
           72.09155403107307,
           72.11394430596609,
           72.13633458085909,
           72.1587248557521,
           72.18216411266238,
           72.20665235059656,
           72.23114058853074,
           72.25562882646493,
           72.28011706439911,
           72.3046053023333,
           72.32909354026748,
           72.35358177820166,
           72.37807001613585,
           72.40255825407002,
           72.42704649200421,
           72.4515347299384,
           72.47602296787258,
           72.50051120580676,
           72.52499944374094,
           72.54948768167513,
           72.57397591960932,
           72.5984641575435,
           72.62295239547768,
           72.64744063341188,
           72.67192887134607,
           72.69641710928023,
           72.72090534721443,
           72.7453935851486,
           72.76988182308278,
           72.79437006101698,
           72.81885829895117,
           72.84334653688535,
           72.86783477481953,
           72.89232301275372,
           72.91681125068789,
           72.94129948862208,
           72.96578772655627,
           72.99027596449045,
           73.01476420242463,
           73.03925244035882,
           73.063740678293,
           73.0882289162272,
           73.11271715416137,
           73.13720539209555,
           73.16169363002975,
           73.18618186796392,
           73.21067010589812,
           73.23515834383228,
           73.25964658176648,
           73.28413481970067,
           73.30862305763483,
           73.33311129556903,
           73.35759953350322,
           73.3820877714374,
           73.40657600937158,
           73.43106424730577,
           73.45555248523995,
           73.48004072317414,
           73.50452896110832,
           73.5290171990425,
           73.55350543697669,
           73.57799367491087,
           73.60248191284505,
           73.62697015077924,
           73.39026134539992,
           73.02295401836386,
           72.65564669132779,
           72.28833936429173,
           71.92103203725569,
           71.5537247102196,
           71.18641738318355,
           70.81911005614748,
           70.45180272911142,
           70.08449540207538,
           69.71718807503927,
           69.34988074800324,
           68.98257342096717,
           68.6152660939311,
           68.24795876689505,
           67.880651439859,
           67.51334411282292,
           67.14603678578686,
           66.7787294587508,
           66.41142213171474,
           66.04411480467867,
           65.67680747764263,
           65.30950015060657,
           64.94219282357048,
           64.57488549653443,
           64.20757816949836,
           63.85864478304477,
           63.529003964883046,
           63.199363146721296,
           62.86972232855957,
           62.540081510397826,
           62.21044069223609,
           61.88079987407438,
           61.551159055912635,
           61.22151823775091,
           60.891877419589164,
           60.56223660142743,
           60.23259578326571,
           59.902954965103966,
           59.57331414694223,
           59.24367332878052,
           58.914032510618775,
           58.58439169245704,
           58.254750874295304,
           57.92511005613356,
           57.59546923797183,
           57.265828419810106,
           56.93618760164838,
           56.60654678348663,
           56.2769059653249,
           55.94726514716316,
           55.617624329001444,
           55.28798351083971,
           54.95834269267796,
           54.62870187451623,
           54.2990610563545,
           53.969420238192775,
           53.63977942003104,
           53.3101386018693,
           52.98049778370756,
           52.65085696554584,
           52.321216147384106,
           51.99157532922237,
           51.661934511060636,
           51.33229369289891,
           51.00265287473718,
           50.673012056575445,
           50.3433712384137,
           50.01373042025197,
           49.68408960209024,
           49.354448783928504,
           49.02480796576677,
           48.695167147605034,
           48.3655263294433,
           48.03588551128158,
           47.70624469311984,
           47.37660387495811,
           47.04696305679637,
           46.71732223863464,
           46.38768142047291,
           46.058040602311166,
           45.72839978414944,
           45.398758965987696,
           45.09099025628658,
           44.80509365504618,
           44.51919705380571,
           44.23330045256539,
           43.947403851324914,
           43.66150725008452,
           43.37561064884412,
           43.08971404760365,
           42.803817446363176,
           42.51792084512279,
           42.23202424388239,
           41.946127642641905,
           41.66023104140159,
           41.37433444016112,
           41.08843783892071,
           40.80254123768025,
           40.51664463643986,
           40.233338313536095,
           39.95325922886541,
           39.673180144194674,
           39.393101059523985,
           39.113021974853226,
           38.83294289018256,
           38.5528638055118,
           38.27278472084118,
           37.99270563617043,
           37.712626551499746,
           37.43254746682899,
           37.15246838215831,
           36.87238929748763,
           36.59231021281688,
           36.31223112814612,
           36.03215204347545,
           35.75207295880476,
           35.471993874134,
           35.191914789463326,
           34.91183570479258,
           34.634101838818,
           34.36184014316242,
           34.08957844750696,
           33.81731675185136,
           33.54505505619585,
           33.27279336054032,
           33.000531664884726,
           32.728269969229196,
           32.45600827357369,
           32.183746577918086,
           31.911484882262503,
           31.639223186606976,
           31.36696149095146,
           31.09469979529587,
           30.822438099640344,
           30.55017640398483,
           30.27791470832923,
           30.008523669358045,
           29.744060591536208,
           29.479597513714296,
           29.21513443589244,
           28.95067135807059,
           28.686208280248692,
           28.42174520242678,
           28.157282124604997,
           27.89281904678309,
           27.628355968961177,
           27.36389289113933,
           27.09942981331749,
           26.834966735495573,
           26.570503657673715,
           26.306040579851828,
           26.04901191354303,
           25.792478876581455,
           25.535945839619938,
           25.279412802658374,
           25.022879765696842,
           24.766346728735282,
           24.50981369177377,
           24.253280654812237,
           23.996747617850673,
           23.74021458088916,
           23.483681543927577,
           23.227148506966053,
           22.975067721028566,
           22.727582803181697,
           22.480097885334814,
           22.232612967487896,
           21.98512804964098,
           21.7376431317941,
           21.490158213947232,
           21.24267329610036,
           20.99518837825343,
           20.747703460406544,
           20.500218542559693,
           20.259227220505622,
           20.021755327750466,
           19.784283434995324,
           19.546811542240185,
           19.309339649484983,
           19.07186775672984,
           18.8343958639747,
           18.5969239712195,
           18.359452078464358,
           18.123188511026157,
           17.896108225847705,
           17.669027940669288,
           17.44194765549089,
           17.214867370312447,
           16.987787085134,
           16.760706799955596,
           16.533626514777197,
           16.306546229598784,
           16.085581013621194,
           15.867613378089455,
           15.649645742557702,
           15.431678107025986,
           15.213710471494295,
           14.995742835962542,
           14.777775200430789,
           14.561079662440086,
           14.35240219007879,
           14.143724717717479,
           13.93504724535615,
           13.72636977299485,
           13.517692300633541,
           13.309014828272245,
           13.104849325884576,
           12.908235437992257,
           12.71162155009997,
           12.51500766220766,
           12.318393774315382,
           12.121779886423065,
           11.928712214859361,
           11.745248885720779,
           11.561785556582212,
           11.378322227443629,
           11.194858898305073,
           11.011395569166506,
           10.836767275597316,
           10.665371311043325,
           10.49397534648929,
           10.32257938193525,
           10.151183417381274,
           9.98733086969639,
           9.826931030468012,
           9.666531191239667,
           9.506131352011318,
           9.34642068599876,
           9.196063097002199,
           9.045705508005643,
           8.895347919009055,
           8.744990330012484,
           8.602214099687036,
           8.461017318322646,
           8.319820536958218,
           8.178623755593822,
           8.045122244507551,
           7.912301954016183,
           7.779481663524837,
           7.649041957838648,
           7.524043590087604,
           7.399045222336547,
           7.27404685458552,
           7.157729588937056,
           7.04184510483916,
           6.9259606207413125,
           6.818344333435141,
           6.712355013665544,
           6.606365693895974,
           6.506886389018078,
           6.407899438402806,
           6.310018411757053,
           6.216196778182761,
           6.122375144608443,
           6.032963213377158,
           5.945716044854327,
           5.860436332897453,
           5.780124449030705,
           5.700052461707333,
           5.625893225473012,
           5.551733989238683,
           5.48260818732852,
           5.413894762984082,
           5.332428617037503,
           5.249981492506143,
           5.167534367974797,
           5.0850872434434375,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           67.89131994016952,
           67.93598379767246,
           67.98064765517539,
           68.02531151267833,
           68.06997537018125,
           68.1146392276842,
           68.15930308518713,
           68.20396694269007,
           68.248630800193,
           68.29329465769594,
           68.33795851519888,
           68.3826223727018,
           68.42728623020474,
           68.47195008770768,
           68.51661394521062,
           68.56127780271356,
           68.60594166021649,
           68.65060551771943,
           68.69526937522235,
           68.73993323272529,
           68.78459709022823,
           68.82926094773117,
           68.8739248052341,
           68.91858866273704,
           68.96325252023998,
           69.0079163777429,
           69.05258023524586,
           69.09724409274878,
           69.14190795025172,
           69.18657180775466,
           69.23123566525759,
           69.27589952276053,
           69.32056338026347,
           69.36522723776639,
           69.40989109526933,
           69.45455495277227,
           69.4992188102752,
           69.54388266777813,
           69.58854652528107,
           69.63321038278401,
           69.67806202532512,
           69.72385259257213,
           69.76964315981914,
           69.81543372706614,
           69.86122429431316,
           69.90701486156016,
           69.95280542880718,
           69.99859599605418,
           70.04438656330119,
           70.0901771305482,
           70.13596769779521,
           70.18175826504222,
           70.22754883228922,
           70.27333939953623,
           70.31912996678324,
           70.36492053403025,
           70.41071110127726,
           70.45650166852427,
           70.50229223577128,
           70.54808280301827,
           70.5938733702653,
           70.6396639375123,
           70.6854545047593,
           70.73124507200632,
           70.77703563925333,
           70.82282620650034,
           70.86861677374735,
           70.91440734099436,
           70.96019790824135,
           71.00598847548838,
           71.05177904273538,
           71.09756960998239,
           71.1433601772294,
           71.18915074447641,
           71.23494131172342,
           71.28073187897041,
           71.32652244621742,
           71.37231301346444,
           71.41810358071145,
           71.46389414795846,
           71.50968471520545,
           71.55547528245246,
           71.60126584969947,
           71.64705641694648,
           71.67334674056517,
           71.69573701545818,
           71.71812729035119,
           71.74051756524419,
           71.7629078401372,
           71.7852981150302,
           71.80768838992321,
           71.83007866481623,
           71.85246893970924,
           71.87485921460225,
           71.89724948949527,
           71.91963976438828,
           71.94203003928129,
           71.9644203141743,
           71.98681058906732,
           72.00920086396033,
           72.03159113885334,
           72.05398141374636,
           72.07637168863937,
           72.09876196353237,
           72.12115223842537,
           72.14354251331838,
           72.16593278821139,
           72.1883230631044,
           72.21071333799742,
           72.23310361289043,
           72.25549388778344,
           72.27788416267646,
           72.30027443756947,
           72.32266471246248,
           72.3450549873555,
           72.36744526224851,
           72.38983553714151,
           72.41222581203452,
           72.43461608692752,
           72.45700636182053,
           72.47939663671355,
           72.50178691160656,
           72.52417718649957,
           72.5465674615431,
           72.57105569947728,
           72.59554393741146,
           72.62003217534564,
           72.64452041327984,
           72.66900865121401,
           72.69349688914821,
           72.71798512708239,
           72.74247336501656,
           72.76696160295076,
           72.79144984088494,
           72.81593807881913,
           72.84042631675331,
           72.86491455468749,
           72.88940279262167,
           72.91389103055586,
           72.93837926849005,
           72.96286750642423,
           72.98735574435841,
           73.01184398229259,
           73.03633222022678,
           73.06082045816098,
           73.08530869609515,
           73.10979693402933,
           73.13428517196353,
           73.1587734098977,
           73.18326164783188,
           73.20774988576606,
           73.23223812370026,
           73.25672636163443,
           73.28121459956861,
           73.3057028375028,
           73.330191075437,
           73.35467931337118,
           73.37916755130536,
           73.40365578923954,
           73.42814402717373,
           73.45263226510792,
           73.47712050304209,
           73.50160874097628,
           73.52609697891047,
           73.55058521684465,
           73.57507345477883,
           73.59956169271302,
           73.36285288733369,
           72.99554556029764,
           72.62823823326157,
           72.2609309062255,
           71.89362357918945,
           71.52631625215338,
           71.15900892511732,
           70.79170159808126,
           70.4243942710452,
           70.05708694400914,
           69.68977961697306,
           69.32247228993701,
           68.95516496290095,
           68.58785763586488,
           68.22055030882882,
           67.85324298179276,
           67.4859356547567,
           67.11862832772064,
           66.75132100068457,
           66.38401367364852,
           66.01670634661244,
           65.64939901957639,
           65.28209169254035,
           64.91478436550426,
           64.5474770384682,
           64.18016971143213,
           63.81286238439608,
           63.445555057360025,
           63.07824773032394,
           62.71094040328789,
           62.34363307625182,
           61.97632574921576,
           61.60901842217971,
           61.241711095143636,
           60.874403768107584,
           60.5070964410715,
           60.13978911403545,
           59.7724817869994,
           59.40517445996332,
           59.03786713292726,
           58.670559805891216,
           58.30325247885514,
           57.935945151819084,
           57.56863782478301,
           57.201330497746945,
           56.87077102792539,
           56.54113020976367,
           56.21148939160193,
           55.881848573440195,
           55.55220775527846,
           55.222566937116724,
           54.892926118955,
           54.56328530079326,
           54.23364448263153,
           53.90400366446979,
           53.57436284630807,
           53.244722028146334,
           52.91508120998459,
           52.585440391822864,
           52.25579957366112,
           51.92615875549941,
           51.596517937337666,
           51.26687711917593,
           50.937236301014195,
           50.607595482852474,
           50.27795466469074,
           49.948313846529004,
           49.61867302836726,
           49.289032210205534,
           48.959391392043806,
           48.62975057388207,
           48.300109755720335,
           47.9704689375586,
           47.64082811939686,
           47.31118730123514,
           46.9815464830734,
           46.651905664911666,
           46.32226484674993,
           45.99262402858821,
           45.662983210426475,
           45.33334239226473,
           45.003701574103005,
           44.67406075594126,
           44.36629204624014,
           44.08039544499974,
           43.79449884375927,
           43.50860224251895,
           43.22270564127847,
           42.93680904003808,
           42.65091243879768,
           42.36501583755721,
           42.07911923631673,
           41.793222635076354,
           41.50732603383595,
           41.22142943259547,
           40.941265417846,
           40.66118633317532,
           40.38110724850462,
           40.101028163833945,
           39.82094907916327,
           39.54086999449251,
           39.26079090982183,
           38.98071182515108,
           38.700632740480394,
           38.42055365580964,
           38.14047457113897,
           37.860395486468214,
           37.58031640179759,
           37.30023731712684,
           37.02015823245616,
           36.74007914778541,
           36.46000006311473,
           36.179920978444045,
           35.899841893773285,
           35.61976280910253,
           35.342497986516356,
           35.07023629086081,
           34.79797459520522,
           34.5257128995497,
           34.25345120389419,
           33.981189508238586,
           33.708927812583006,
           33.43666611692755,
           33.16440442127195,
           32.89214272561644,
           32.619881029960915,
           32.347619334305314,
           32.075357638649784,
           31.803095942994275,
           31.530834247338685,
           31.258572551683095,
           30.98631085602757,
           30.714240537305347,
           30.44977745948355,
           30.185314381661648,
           29.9208513038398,
           29.656388226017945,
           29.391925148196034,
           29.127462070374197,
           28.862998992552285,
           28.59853591473043,
           28.33407283690858,
           28.06960975908668,
           27.805146681264766,
           27.54068360344298,
           27.276220525621078,
           27.011757447799162,
           26.7492768783561,
           26.492743841394585,
           26.236210804433004,
           25.97967776747143,
           25.72314473050998,
           25.466611693548447,
           25.210078656586873,
           24.95354561962536,
           24.697012582663792,
           24.440479545702267,
           24.1839465087407,
           23.927413471779186,
           23.670880434817654,
           23.418943269864645,
           23.17145835201773,
           22.923973434170847,
           22.676488516323914,
           22.429003598477046,
           22.181518680630177,
           21.93403376278329,
           21.686548844936375,
           21.43906392708946,
           21.19157900924258,
           20.94409409139571,
           20.70067386722294,
           20.46320197446778,
           20.225730081712584,
           19.988258188957452,
           19.750786296202257,
           19.513314403447097,
           19.275842510691955,
           19.038370617936817,
           18.800898725181614,
           18.56342683242647,
           18.332673233629528,
           18.105592948451115,
           17.878512663272712,
           17.651432378094317,
           17.42435209291586,
           17.19727180773745,
           16.97019152255905,
           16.743111237380607,
           16.516030953916818,
           16.298063318385115,
           16.08009568285341,
           15.862128047321656,
           15.64416041178999,
           15.426192776258251,
           15.208225140726498,
           14.990257505194782,
           14.774949709432523,
           14.566272237071212,
           14.357594764709903,
           14.148917292348573,
           13.940239819987276,
           13.731562347625967,
           13.522884875264635,
           13.31857688958165,
           13.12196300168933,
           12.925349113797054,
           12.728735225904806,
           12.532121338012486,
           12.335507450120197,
           12.140371151294772,
           11.956907822156218,
           11.773444493017623,
           11.589981163879068,
           11.406517834740484,
           11.223054505601917,
           11.044935295868044,
           10.873539331314044,
           10.702143366760005,
           10.530747402205993,
           10.359351437652002,
           10.190995357406639,
           10.03059551817828,
           9.870195678949914,
           9.709795839721567,
           9.54939600049319,
           9.394509552709726,
           9.244151963713168,
           9.09379437471658,
           8.94343678572002,
           8.79497453687929,
           8.6537777555149,
           8.512580974150474,
           8.371384192786067,
           8.231903078276535,
           8.099082787785166,
           7.9662624972938225,
           7.833442206802461,
           7.704566885655332,
           7.579568517904313,
           7.454570150153263,
           7.330233685216127,
           7.214349201118258,
           7.098464717020404,
           6.982580232922536,
           6.875417362854082,
           6.769428043084504,
           6.663438723314927,
           6.56379530040563,
           6.464808349790381,
           6.36647194254113,
           6.272650308966824,
           6.1788286753925075,
           6.088438592047988,
           6.001191423525135,
           5.9144853055024775,
           5.8341734216357395,
           5.753861537768983,
           5.678347589854988,
           5.604188353620669,
           5.5333766544925655,
           5.464663230148119,
           5.388101977125441,
           5.305654852594097,
           5.223207728062736,
           5.140760603531376,
           5.058313479000031,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           67.91711858359191,
           67.96178244109485,
           68.00644629859778,
           68.05111015610072,
           68.09577401360366,
           68.1404378711066,
           68.18510172860952,
           68.22976558611246,
           68.2744294436154,
           68.31909330111834,
           68.36375715862128,
           68.40842101612421,
           68.45308487362715,
           68.49774873113009,
           68.54241258863303,
           68.58707644613595,
           68.63174030363888,
           68.67640416114183,
           68.72106801864476,
           68.7657318761477,
           68.81039573365064,
           68.85505959115358,
           68.8997234486565,
           68.94438730615944,
           68.98905116366238,
           69.0337150211653,
           69.07837887866825,
           69.12304273617119,
           69.16770659367411,
           69.21237045117707,
           69.25703430867999,
           69.30169816618292,
           69.34636202368586,
           69.3910258811888,
           69.43568973869174,
           69.48035359619467,
           69.5250174536976,
           69.56968131120054,
           69.61434516870348,
           69.6590090262064,
           69.70367288370934,
           69.74833674121228,
           69.79300059871521,
           69.83766445621815,
           69.88232831372109,
           69.92699217122401,
           69.97165602872695,
           70.0163198862299,
           70.06098374373283,
           70.10564760123577,
           70.15031145873871,
           70.19497531624165,
           70.23963917374458,
           70.2843030312475,
           70.32896688875044,
           70.37363074625338,
           70.41829460375632,
           70.46370960098356,
           70.50950016823057,
           70.55529073547757,
           70.6010813027246,
           70.6468718699716,
           70.6926624372186,
           70.73845300446561,
           70.78424357171262,
           70.83003413895963,
           70.87582470620664,
           70.92161527345365,
           70.96740584070065,
           71.01319640794767,
           71.05898697519467,
           71.10477754244168,
           71.15056810968868,
           71.1963586769357,
           71.24214924418271,
           71.28793981142971,
           71.33373037867672,
           71.37952094592373,
           71.42531151317074,
           71.47110208041775,
           71.51689264766476,
           71.56268321491176,
           71.60847378215877,
           71.65426434940578,
           71.68055467302446,
           71.70294494791747,
           71.72533522281049,
           71.74772549770348,
           71.7701157725965,
           71.79250604748951,
           71.81489632238252,
           71.83728659727554,
           71.85967687216855,
           71.88206714706155,
           71.90445742195458,
           71.92684769684757,
           71.94923797174059,
           71.9716282466336,
           71.99401852152661,
           72.01640879641963,
           72.03879907131264,
           72.06118934620565,
           72.08357962109866,
           72.10596989599166,
           72.12836017088468,
           72.15075044577769,
           72.1731407206707,
           72.19553099556371,
           72.21792127045673,
           72.24031154534973,
           72.26270182024274,
           72.28509209513575,
           72.30748237002877,
           72.32987264492178,
           72.35226291981479,
           72.3746531947078,
           72.3970434696008,
           72.41943374449382,
           72.44182401938683,
           72.46421429427983,
           72.48660456917285,
           72.50899484406585,
           72.53138511895887,
           72.55377539385188,
           72.57616566874489,
           72.5985559436379,
           72.62094621853092,
           72.64333649342393,
           72.66572676831694,
           72.68811704320994,
           72.71050731810296,
           72.73289759299597,
           72.75528786788898,
           72.777678142782,
           72.800068417675,
           72.82245869256802,
           72.84484896746103,
           72.86723924235403,
           72.88962951724704,
           72.91201979214006,
           72.935459048358,
           72.95994728629219,
           72.98443552422637,
           73.00892376216055,
           73.03341200009474,
           73.05790023802892,
           73.0823884759631,
           73.1068767138973,
           73.13136495183147,
           73.15585318976565,
           73.18034142769983,
           73.20482966563402,
           73.2293179035682,
           73.2538061415024,
           73.27829437943657,
           73.30278261737075,
           73.32727085530495,
           73.35175909323914,
           73.37624733117332,
           73.4007355691075,
           73.42522380704169,
           73.44971204497587,
           73.47420028291005,
           73.49868852084424,
           73.5231767587784,
           73.5476649967126,
           73.57215323464679,
           73.33544442926745,
           72.96813710223141,
           72.60082977519535,
           72.23352244815928,
           71.86621512112323,
           71.49890779408716,
           71.1316004670511,
           70.76429314001504,
           70.39698581297897,
           70.02967848594292,
           69.66237115890684,
           69.29506383187078,
           68.92775650483472,
           68.56044917779866,
           68.1931418507626,
           67.82583452372654,
           67.45852719669048,
           67.09121986965441,
           66.72391254261834,
           66.35660521558229,
           65.98929788854622,
           65.62199056151016,
           65.25468323447411,
           64.88737590743803,
           64.52006858040198,
           64.15276125336591,
           63.78545392632984,
           63.418146599293806,
           63.05083927225772,
           62.68353194522167,
           62.31622461818559,
           61.94891729114953,
           61.58160996411349,
           61.21430263707741,
           60.84699531004135,
           60.47968798300528,
           60.112380655969226,
           59.74507332893317,
           59.3777660018971,
           59.01045867486104,
           58.64315134782498,
           58.275844020788924,
           57.90853669375286,
           57.54122936671678,
           57.17392203968072,
           56.80661471264466,
           56.4393073856086,
           56.07200005857254,
           55.70469273153647,
           55.33738540450041,
           54.97007807746434,
           54.60277075042829,
           54.23546342339223,
           53.86815609635616,
           53.500848769320086,
           53.13354144228404,
           52.76623411524798,
           52.39892678821191,
           52.03161946117585,
           51.66431213413978,
           51.29700480710373,
           50.92969748006766,
           50.5623901530316,
           50.21253809096779,
           49.88289727280606,
           49.553256454644334,
           49.22361563648259,
           48.89397481832086,
           48.56433400015912,
           48.2346931819974,
           47.90505236383566,
           47.57541154567392,
           47.24577072751219,
           46.91612990935045,
           46.58648909118873,
           46.25684827302699,
           45.92720745486526,
           45.597566636703526,
           45.2679258185418,
           44.93828500038006,
           44.608644182218335,
           44.27900336405659,
           43.94936254589485,
           43.641593836193735,
           43.35569723495333,
           43.069800633712866,
           42.78390403247254,
           42.49800743123207,
           42.21211082999167,
           41.929271606826745,
           41.64919252215599,
           41.3691134374853,
           41.089034352814636,
           40.808955268143876,
           40.528876183473116,
           40.248797098802434,
           39.96871801413177,
           39.688638929461064,
           39.40855984479039,
           39.12848076011971,
           38.848401675448955,
           38.568322590778266,
           38.28824350610753,
           38.00816442143683,
           37.728085336766085,
           37.44800625209541,
           37.16792716742465,
           36.887848082754026,
           36.60776899808328,
           36.327689913412605,
           36.05089413421471,
           35.778632438559185,
           35.50637074290366,
           35.23410904724801,
           34.961847351592475,
           34.68958565593697,
           34.41732396028144,
           34.14506226462584,
           33.87280056897033,
           33.600538873314804,
           33.32827717765921,
           33.05601548200363,
           32.78375378634817,
           32.51149209069257,
           32.239230395037055,
           31.966968699381535,
           31.69470700372594,
           31.422445308070408,
           31.155494327430873,
           30.891031249609018,
           30.6265681717871,
           30.362105093965255,
           30.09764201614335,
           29.833178938321552,
           29.56871586049965,
           29.304252782677803,
           29.03978970485595,
           28.775326627034037,
           28.5108635492122,
           28.246400471390288,
           27.981937393568433,
           27.717474315746585,
           27.453011237924684,
           27.193008806207715,
           26.936475769246154,
           26.679942732284637,
           26.42340969532306,
           26.166876658361545,
           25.910343621400028,
           25.65381058443845,
           25.397277547476875,
           25.140744510515425,
           24.884211473553897,
           24.62767843659232,
           24.371145399630805,
           24.114612362669238,
           23.862818818700674,
           23.61533390085381,
           23.367848983006937,
           23.120364065160004,
           22.872879147313135,
           22.625394229466224,
           22.377909311619337,
           22.130424393772408,
           21.88293947592554,
           21.63545455807867,
           21.387969640231788,
           21.142120513940252,
           20.90464862118511,
           20.66717672842991,
           20.429704835674727,
           20.192232942919585,
           19.954761050164425,
           19.717289157409226,
           19.4798172646541,
           19.2423453718989,
           19.004873479143743,
           18.7692382414114,
           18.542157956233,
           18.31507767105455,
           18.087997385876147,
           17.86091710069771,
           17.633836815519295,
           17.406756530340893,
           17.179676245162497,
           16.95259595998404,
           16.728513258680824,
           16.510545623149085,
           16.292577987617378,
           16.074610352085628,
           15.856642716553925,
           15.638675081022221,
           15.420707445490466,
           15.2027398099588,
           14.988819756424958,
           14.780142284063649,
           14.571464811702306,
           14.362787339341022,
           14.154109866979711,
           13.945432394618399,
           13.736754922257072,
           13.532304453278762,
           13.335690565386475,
           13.139076677494167,
           12.94246278960189,
           12.74584890170957,
           12.549235013817292,
           12.352621125925044,
           12.168566758591643,
           11.985103429453051,
           11.801640100314495,
           11.61817677117594,
           11.434713442037346,
           11.25310331613877,
           11.081707351584745,
           10.910311387030733,
           10.73891542247673,
           10.567519457922732,
           10.396123493368695,
           10.234260005888538,
           10.073860166660202,
           9.913460327431823,
           9.753060488203467,
           9.592956008417264,
           9.442598419420706,
           9.292240830424117,
           9.141883241427559,
           8.991525652431001,
           8.846538192707143,
           8.705341411342745,
           8.564144629978326,
           8.422947848613937,
           8.285863621554142,
           8.153043331062792,
           8.020223040571455,
           7.887402750080085,
           7.760091813472063,
           7.635093445721013,
           7.510095077969956,
           7.386853297397359,
           7.270968813299498,
           7.155084329201614,
           7.039199845103746,
           6.9324903922730545,
           6.826501072503471,
           6.720511752733874,
           6.620704211793227,
           6.521717261177961,
           6.4229254733252,
           6.329103839750907,
           6.23528220617659,
           6.14391397071879,
           6.056666802195948,
           5.969419633673118,
           5.888222394240758,
           5.807910510374009,
           5.730801954236971,
           5.656642718002642,
           5.584145121656613,
           5.515431697312176,
           5.443775337213397,
           5.361328212682036,
           5.278881088150675,
           5.196433963619332,
           5.113986839087971,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           67.94291722701433,
           67.98758108451726,
           68.0322449420202,
           68.07690879952314,
           68.12157265702606,
           68.166236514529,
           68.21090037203194,
           68.25556422953487,
           68.30022808703782,
           68.34489194454075,
           68.38955580204369,
           68.43421965954661,
           68.47888351704955,
           68.52354737455249,
           68.56821123205543,
           68.61287508955837,
           68.6575389470613,
           68.70220280456424,
           68.74686666206716,
           68.7915305195701,
           68.83619437707304,
           68.88085823457598,
           68.92552209207891,
           68.97018594958186,
           69.01484980708477,
           69.05951366458771,
           69.10417752209065,
           69.14884137959359,
           69.19350523709653,
           69.23816909459946,
           69.2828329521024,
           69.32749680960534,
           69.37216066710826,
           69.4168245246112,
           69.46148838211414,
           69.50615223961708,
           69.55081609712002,
           69.59547995462295,
           69.64014381212588,
           69.68480766962881,
           69.72947152713175,
           69.77413538463469,
           69.81879924213763,
           69.86346309964057,
           69.9081269571435,
           69.95279081464642,
           69.99745467214936,
           70.0421185296523,
           70.08678238715524,
           70.13144624465818,
           70.17611010216112,
           70.22077395966406,
           70.26543781716698,
           70.31010167466991,
           70.35476553217285,
           70.39942938967579,
           70.44409324717873,
           70.48875710468167,
           70.5334209621846,
           70.57808481968753,
           70.62274867719047,
           70.66741253469341,
           70.71207639219634,
           70.75674024969928,
           70.80140410720222,
           70.84606796470516,
           70.89073182220808,
           70.93539567971102,
           70.98005953721396,
           71.0247233947169,
           71.06938725221983,
           71.11405110972275,
           71.15871496722569,
           71.20356660939498,
           71.24935717664201,
           71.295147743889,
           71.340938311136,
           71.38672887838302,
           71.43251944563004,
           71.47831001287703,
           71.52410058012404,
           71.56989114737105,
           71.61568171461806,
           71.66147228186507,
           71.68776260548375,
           71.71015288037675,
           71.73254315526977,
           71.75493343016278,
           71.77732370505579,
           71.7997139799488,
           71.82210425484182,
           71.84449452973482,
           71.86688480462783,
           71.88927507952084,
           71.91166535441387,
           71.93405562930687,
           71.95644590419988,
           71.9788361790929,
           72.00122645398591,
           72.02361672887892,
           72.04600700377193,
           72.06839727866493,
           72.09078755355794,
           72.11317782845096,
           72.13556810334397,
           72.15795837823698,
           72.18034865312998,
           72.202738928023,
           72.22512920291601,
           72.24751947780902,
           72.26990975270203,
           72.29230002759505,
           72.31469030248806,
           72.33708057738107,
           72.35947085227409,
           72.38186112716708,
           72.4042514020601,
           72.42664167695311,
           72.44903195184612,
           72.47142222673912,
           72.49381250163215,
           72.51620277652515,
           72.53859305141816,
           72.56098332631119,
           72.58337360120419,
           72.6057638760972,
           72.62815415099021,
           72.65054442588323,
           72.67293470077622,
           72.69532497566924,
           72.71771525056225,
           72.74010552545526,
           72.76249580034828,
           72.78488607524129,
           72.8072763501343,
           72.8296666250273,
           72.85205689992033,
           72.87444717481333,
           72.89683744970634,
           72.91922772459935,
           72.94161799949235,
           72.96400827438538,
           72.98639854927838,
           73.00878882417139,
           73.0311790990644,
           73.05356937395742,
           73.07595964885043,
           73.09834992374344,
           73.12074019863645,
           73.14313047352945,
           73.16552074842247,
           73.18791102331548,
           73.21030129820849,
           73.2326915731015,
           73.25508184799452,
           73.27747212288753,
           73.29986239778053,
           73.32435063517289,
           73.34883887310708,
           73.37332711104128,
           73.39781534897546,
           73.42230358690963,
           73.44679182484381,
           73.471280062778,
           73.49576830071219,
           73.52025653864636,
           73.54474477658056,
           73.30803597120124,
           72.94072864416518,
           72.57342131712912,
           72.20611399009306,
           71.83880666305701,
           71.47149933602093,
           71.10419200898488,
           70.73688468194881,
           70.36957735491274,
           70.00227002787669,
           69.63496270084062,
           69.26765537380456,
           68.9003480467685,
           68.53304071973243,
           68.16573339269638,
           67.79842606566032,
           67.43111873862425,
           67.06381141158818,
           66.69650408455212,
           66.32919675751607,
           65.96188943048,
           65.59458210344394,
           65.22727477640788,
           64.85996744937181,
           64.49266012233576,
           64.12535279529968,
           63.75804546826362,
           63.390738141227565,
           63.02343081419149,
           62.65612348715545,
           62.28881616011937,
           61.92150883308331,
           61.554201506047264,
           61.186894179011176,
           60.81958685197513,
           60.45227952493905,
           60.084972197902985,
           59.71766487086695,
           59.350357543830874,
           58.983050216794815,
           58.61574288975876,
           58.2484355627227,
           57.88112823568663,
           57.51382090865056,
           57.14651358161449,
           56.779206254578426,
           56.41189892754238,
           56.044591600506315,
           55.67728427347025,
           55.309976946434176,
           54.94266961939811,
           54.57536229236207,
           54.208054965326,
           53.84074763828993,
           53.47344031125387,
           53.106132984217815,
           52.73882565718175,
           52.37151833014569,
           52.00421100310962,
           51.63690367607356,
           51.269596349037506,
           50.90228902200144,
           50.53498169496537,
           50.167674367929315,
           49.80036704089326,
           49.43305971385719,
           49.065752386821124,
           48.69844505978505,
           48.331137732749,
           47.96383040571295,
           47.59652307867688,
           47.22921575164081,
           46.86190842460475,
           46.494601097568676,
           46.12729377053264,
           45.759986443496565,
           45.3926791164605,
           45.02537178942443,
           44.658064462388374,
           44.290757135352315,
           43.923449808316256,
           43.55614248128018,
           43.224664335848445,
           42.917277795807415,
           42.63719871113672,
           42.357119626466044,
           42.07704054179536,
           41.79696145712462,
           41.51688237245393,
           41.236803287783175,
           40.95672420311243,
           40.67664511844173,
           40.396566033771066,
           40.11648694910031,
           39.83640786442955,
           39.55632877975887,
           39.2762496950882,
           38.9961706104175,
           38.71609152574682,
           38.436012441076144,
           38.155933356405384,
           37.8758542717347,
           37.59577518706396,
           37.31569610239327,
           37.035617017722515,
           36.75929028191308,
           36.487028586257544,
           36.21476689060196,
           35.942505194946435,
           35.67024349929091,
           35.39798180363532,
           35.1257201079798,
           34.85345841232428,
           34.58119671666863,
           34.30893502101309,
           34.03667332535759,
           33.76441162970206,
           33.49214993404646,
           33.21988823839094,
           32.94762654273542,
           32.67536484707983,
           32.40310315142425,
           32.13084145576879,
           31.86121119537823,
           31.59674811755633,
           31.332285039734543,
           31.06782196191263,
           30.803358884090713,
           30.538895806268883,
           30.274432728447028,
           30.00996965062511,
           29.745506572803265,
           29.481043494981364,
           29.216580417159562,
           28.95211733933766,
           28.687654261515814,
           28.42319118369396,
           28.158728105872047,
           27.89426502805021,
           27.63674073405935,
           27.380207697097774,
           27.123674660136256,
           26.867141623174692,
           26.610608586213164,
           26.3540755492516,
           26.097542512290083,
           25.841009475328505,
           25.58447643836699,
           25.327943401405474,
           25.071410364443896,
           24.81487732748232,
           24.55834429052087,
           24.306694367536775,
           24.05920944968984,
           23.811724531842923,
           23.564239613996058,
           23.316754696149175,
           23.069269778302303,
           22.821784860455438,
           22.574299942608505,
           22.326815024761633,
           22.079330106914718,
           21.831845189067835,
           21.584360271220906,
           21.346095267902392,
           21.108623375147204,
           20.871151482392047,
           20.633679589636905,
           20.39620769688176,
           20.15873580412656,
           19.921263911371376,
           19.683792018616234,
           19.446320125861075,
           19.20884823310588,
           18.978722964014846,
           18.75164267883644,
           18.524562393658023,
           18.29748210847958,
           18.070401823301182,
           17.84332153812273,
           17.616241252944327,
           17.38916096776589,
           17.162080682587476,
           16.94099556344481,
           16.723027927913105,
           16.50506029238135,
           16.287092656849637,
           16.069125021317898,
           15.851157385786191,
           15.633189750254438,
           15.415222114722738,
           15.202689803417432,
           14.99401233105612,
           14.785334858694792,
           14.57665738633346,
           14.36797991397215,
           14.159302441610807,
           13.950624969249525,
           13.746032016975912,
           13.549418129083591,
           13.352804241191315,
           13.156190353299007,
           12.95957646540672,
           12.76296257751441,
           12.566348689622135,
           12.38022569502707,
           12.196762365888516,
           12.01329903674996,
           11.829835707611366,
           11.646372378472773,
           11.462909049334218,
           11.289875371855498,
           11.118479407301487,
           10.947083442747461,
           10.775687478193435,
           10.604291513639422,
           10.437924493598805,
           10.277524654370437,
           10.11712481514208,
           9.956724975913726,
           9.79632513668539,
           9.641044875128244,
           9.490687286131656,
           9.340329697135097,
           9.189972108138539,
           9.03961451914195,
           8.898101848535006,
           8.756905067170608,
           8.615708285806182,
           8.474511504441784,
           8.339824164831782,
           8.207003874340412,
           8.07418358384906,
           7.941363293357707,
           7.8156167412887605,
           7.690618373537704,
           7.565620005786684,
           7.443472909578588,
           7.3275884254807195,
           7.211703941382844,
           7.095819457284984,
           6.989563421692003,
           6.883574101922418,
           6.777584782152848,
           6.6776131231808025,
           6.57862617256554,
           6.479639221950286,
           6.385557370534977,
           6.29173573696066,
           6.199389349389615,
           6.112142180866773,
           6.02489501234392,
           5.942271366845787,
           5.861959482979049,
           5.783256318618951,
           5.709097082384622,
           5.6349378461503115,
           5.566200164476224,
           5.497486740131771,
           5.417001572769987,
           5.334554448238631,
           5.2521073237072695,
           5.16966019917591,
           5.087213074644565,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           67.96354277199393,
           68.00820662949687,
           68.0528704869998,
           68.09753434450273,
           68.14219820200567,
           68.18686205950861,
           68.23152591701154,
           68.27618977451448,
           68.32085363201742,
           68.36551748952036,
           68.4101813470233,
           68.45484520452622,
           68.49950906202916,
           68.5441729195321,
           68.58883677703504,
           68.63350063453797,
           68.6781644920409,
           68.72282834954385,
           68.76749220704677,
           68.81215606454971,
           68.85681992205264,
           68.90148377955558,
           68.94614763705852,
           68.99081149456146,
           69.03547535206438,
           69.08013920956732,
           69.12480306707026,
           69.16946692457319,
           69.21413078207614,
           69.25879463957907,
           69.303458497082,
           69.34812235458494,
           69.39278621208788,
           69.43745006959081,
           69.48211392709374,
           69.52677778459667,
           69.57144164209961,
           69.61610549960255,
           69.6607693571055,
           69.70543321460842,
           69.75009707211136,
           69.7947609296143,
           69.83942478711722,
           69.88408864462016,
           69.9287525021231,
           69.97341635962604,
           70.01808021712897,
           70.06274407463191,
           70.10740793213485,
           70.15207178963777,
           70.19673564714071,
           70.24139950464365,
           70.28606336214659,
           70.33072721964952,
           70.37539107715246,
           70.4200549346554,
           70.46471879215832,
           70.50938264966126,
           70.5540465071642,
           70.59871036466714,
           70.64337422217007,
           70.688038079673,
           70.73270193717595,
           70.77736579467887,
           70.82202965218181,
           70.86669350968475,
           70.91135736718769,
           70.95602122469062,
           71.00068508219356,
           71.04534893969651,
           71.09001279719944,
           71.13467665470236,
           71.1793405122053,
           71.22400436970824,
           71.26866822721118,
           71.31333208471412,
           71.35799594221704,
           71.40265979923959,
           71.44618863227373,
           71.48971746530788,
           71.53324629834202,
           71.57677513137618,
           71.62030396441033,
           71.66383279744448,
           71.68788356735071,
           71.70803872463136,
           71.728193881912,
           71.74834903919266,
           71.76850419647332,
           71.78865935375396,
           71.81030458849682,
           71.83269486338982,
           71.85508513828283,
           71.87747541317584,
           71.89986568806886,
           71.92225596296187,
           71.94464623785488,
           71.96703651274788,
           71.98942678764091,
           72.01181706253391,
           72.03420733742692,
           72.05659761231993,
           72.07898788721295,
           72.10137816210596,
           72.12376843699897,
           72.14615871189199,
           72.168548986785,
           72.190939261678,
           72.21332953657101,
           72.23571981146402,
           72.25811008635704,
           72.28050036125003,
           72.30289063614305,
           72.32528091103606,
           72.34767118592907,
           72.37006146082209,
           72.3924517357151,
           72.41484201060811,
           72.43723228550111,
           72.45962256039414,
           72.48201283528715,
           72.50440311018015,
           72.52679338507316,
           72.54918365996618,
           72.57157393485919,
           72.59396420975219,
           72.6163544846452,
           72.63874475953821,
           72.66113503443123,
           72.68352530932424,
           72.70591558421725,
           72.72830585911026,
           72.75069613400328,
           72.77308640889629,
           72.7954766837893,
           72.81786695868232,
           72.84025723357531,
           72.86264750846833,
           72.88503778336134,
           72.90742805825435,
           72.92981833314737,
           72.95220860804037,
           72.97459888293338,
           72.99698915782639,
           73.0193794327194,
           73.04176970761242,
           73.06415998250543,
           73.08655025739844,
           73.10894053229144,
           73.13133080718445,
           73.15372108207747,
           73.17611135697048,
           73.1985016318635,
           73.2208919067565,
           73.24328218164952,
           73.26567245654252,
           73.28806273143553,
           73.31045300632856,
           73.33284328122156,
           73.35523355611457,
           73.37762383100758,
           73.4000141059006,
           73.4224043807936,
           73.44479465568661,
           73.46718493057963,
           73.48957520547263,
           73.51196548036565,
           73.25226037261747,
           72.85150757354873,
           72.45075477447998,
           72.0500019754112,
           71.64924917634248,
           71.2484963772737,
           70.84774357820494,
           70.4469907791362,
           70.05564112397781,
           69.68395263934858,
           69.3122641547193,
           68.94057567009008,
           68.56888718546082,
           68.19719870083158,
           67.82551021620236,
           67.4538217315731,
           67.08213324694387,
           66.71044476231461,
           66.33875627768536,
           65.96706779305613,
           65.59537930842689,
           65.22369082379764,
           64.85200233916841,
           64.48031385453915,
           64.10862536990992,
           63.73693688528066,
           63.36524840065142,
           62.99355991602219,
           62.62187143139292,
           62.2501829467637,
           61.87849446213444,
           61.506805977505195,
           61.13511749287597,
           60.763429008246725,
           60.39174052361747,
           60.02005203898823,
           59.64836355435898,
           59.27667506972975,
           58.90498658510051,
           58.53329810047126,
           58.161609615842025,
           57.78992113121278,
           57.41823264658353,
           57.04654416195428,
           56.674855677325034,
           56.30316719269579,
           55.93147870806655,
           55.559790223437304,
           55.18810173880806,
           54.81641325417882,
           54.444724769549566,
           54.073036284920335,
           53.70134780029109,
           53.32965931566185,
           52.9579708310326,
           52.586282346403365,
           52.21459386177412,
           51.842905377144874,
           51.47121689251563,
           51.09952840788638,
           50.72783992325714,
           50.356151438627904,
           49.98446295399865,
           49.61277446936941,
           49.241085984740174,
           48.869397500110935,
           48.497709015481675,
           48.126020530852436,
           47.75433204622318,
           47.38264356159396,
           47.01095507696471,
           46.63926659233546,
           46.267578107706214,
           45.89588962307697,
           45.52420113844774,
           45.15251265381849,
           44.780824169189245,
           44.40913568456,
           44.03744719993077,
           43.665758715301514,
           43.29407023067226,
           42.92238174604302,
           42.55069326141377,
           42.22480947676383,
           41.944730392093135,
           41.66465130742246,
           41.38457222275178,
           41.104493138081025,
           40.824414053410344,
           40.54433496873959,
           40.264255884068845,
           39.98417679939814,
           39.70409771472748,
           39.42401863005672,
           39.14393954538597,
           38.86386046071528,
           38.58378137604461,
           38.30370229137391,
           38.02362320670323,
           37.74354412203256,
           37.46768642961142,
           37.19542473395589,
           36.92316303830031,
           36.65090134264478,
           36.378639646989186,
           36.10637795133368,
           35.83411625567815,
           35.56185456002255,
           35.28959286436704,
           35.01733116871151,
           34.74506947305592,
           34.4728077774004,
           34.200546081744875,
           33.928284386089224,
           33.656022690433694,
           33.383760994778186,
           33.111499299122656,
           32.839237603467055,
           32.56697590781154,
           32.30246498550373,
           32.038001907681824,
           31.773538829859977,
           31.509075752038132,
           31.24461267421622,
           30.98014959639432,
           30.71568651857253,
           30.451223440750613,
           30.186760362928702,
           29.922297285106865,
           29.65783420728501,
           29.393371129463098,
           29.128908051641247,
           28.86444497381935,
           28.59998189599755,
           28.337005698872417,
           28.08047266191085,
           27.823939624949325,
           27.5674065879878,
           27.310873551026294,
           27.05434051406477,
           26.79780747710319,
           26.541274440141674,
           26.28474140318011,
           26.028208366218582,
           25.771675329257018,
           25.5151422922955,
           25.258609255333923,
           25.002076218372412,
           24.750569916372804,
           24.50308499852587,
           24.25560008067899,
           24.008115162832134,
           23.760630244985247,
           23.513145327138318,
           23.265660409291403,
           23.018175491444534,
           22.77069057359765,
           22.523205655750786,
           22.275720737903917,
           22.02823582005698,
           21.78754191461966,
           21.550070021864517,
           21.312598129109315,
           21.075126236354162,
           20.83765434359902,
           20.600182450843835,
           20.36271055808868,
           20.125238665333534,
           19.887766772578395,
           19.650294879823193,
           19.415287971796698,
           19.1882076866183,
           18.96112740143985,
           18.734047116261394,
           18.506966831083005,
           18.279886545904596,
           18.05280626072618,
           17.82572597554774,
           17.59864569036934,
           17.37156540519089,
           17.153477868208764,
           16.93551023267706,
           16.717542597145307,
           16.499574961613604,
           16.2816073260819,
           16.063639690550147,
           15.845672055018433,
           15.627704419486692,
           15.416559850409856,
           15.207882378048545,
           14.999204905687215,
           14.790527433325918,
           14.581849960964608,
           14.373172488603279,
           14.164495016241945,
           13.959759580673014,
           13.763145692780691,
           13.566531804888427,
           13.36991791699614,
           13.173304029103821,
           12.976690141211543,
           12.780076253319237,
           12.591884631462456,
           12.4084213023239,
           12.224957973185344,
           12.041494644046779,
           11.858031314908223,
           11.674567985769666,
           11.498043392126219,
           11.326647427572182,
           11.15525146301818,
           10.983855498464177,
           10.812459533910166,
           10.641588981309054,
           10.481189142080707,
           10.32078930285233,
           10.160389463623982,
           9.999989624395614,
           9.839589785167256,
           9.689133741839184,
           9.538776152842654,
           9.388418563846065,
           9.238060974849477,
           9.090862285727262,
           8.949665504362862,
           8.808468722998436,
           8.667271941634038,
           8.526604998600751,
           8.393784708109383,
           8.260964417618037,
           8.128144127126692,
           7.99614003685652,
           7.871141669105446,
           7.746143301354435,
           7.621144933603375,
           7.500092521759806,
           7.38420803766193,
           7.268323553564068,
           7.152625770880553,
           7.0466364511109765,
           6.940647131341387,
           6.834657811571789,
           6.734522034568378,
           6.63553508395313,
           6.536548133337856,
           6.442010901319032,
           6.348189267744731,
           6.254864728060424,
           6.167617559537571,
           6.080370391014741,
           5.996320339450822,
           5.916008455584073,
           5.835710683000919,
           5.761551446766608,
           5.687392210532287,
           5.616968631640269,
           5.548255207295832,
           5.472674932857929,
           5.39022780832657,
           5.307780683795222,
           5.225333559263866,
           5.142886434732504,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           67.9754998825567,
           68.02016374005964,
           68.06482759756257,
           68.10949145506551,
           68.15415531256845,
           68.19881917007137,
           68.24348302757431,
           68.28814688507725,
           68.3328107425802,
           68.37747460008313,
           68.42213845758606,
           68.46680231508898,
           68.51146617259192,
           68.55613003009486,
           68.6007938875978,
           68.64545774510074,
           68.69012160260367,
           68.73478546010661,
           68.77944931760955,
           68.82411317511249,
           68.86877703261541,
           68.91344089011835,
           68.95810474762129,
           69.00276860512422,
           69.04743246262716,
           69.0920963201301,
           69.13676017763304,
           69.18142403513596,
           69.2260878926389,
           69.27075175014184,
           69.31541560764478,
           69.3600794651477,
           69.40474332265063,
           69.44940718015359,
           69.49407103765651,
           69.53873489515945,
           69.58339875266239,
           69.62806261016532,
           69.67272646766827,
           69.7173903251712,
           69.76205418267412,
           69.80671804017706,
           69.85138189768,
           69.89604575518294,
           69.94070961268588,
           69.9853734701888,
           70.03003732769174,
           70.07470118519468,
           70.11936504269761,
           70.16402890020055,
           70.20869275770349,
           70.25335661520643,
           70.29802047270935,
           70.34268433021228,
           70.38734818771522,
           70.43201204521816,
           70.4766759027211,
           70.52133976022404,
           70.56600361772698,
           70.6106674752299,
           70.65533133273284,
           70.6994276773337,
           70.74295651036785,
           70.786485343402,
           70.83001417643615,
           70.87354300947031,
           70.91707184250444,
           70.96060067553859,
           71.00412950857275,
           71.0476583416069,
           71.09118717464105,
           71.1347160076752,
           71.17824484070935,
           71.2217736737435,
           71.26530250677764,
           71.3088313398118,
           71.35236017284595,
           71.3958890058801,
           71.43941783891424,
           71.4829466719484,
           71.52647550498256,
           71.5700043380167,
           71.61353317105085,
           71.657062004085,
           71.68111277399123,
           71.70126793127189,
           71.72142308855254,
           71.74157824583318,
           71.76173340311384,
           71.78188856039449,
           71.80204371767513,
           71.82219887495579,
           71.84235403223644,
           71.86250918951708,
           71.88266434679774,
           71.9028195040784,
           71.92297466135904,
           71.94312981863969,
           71.96328497592035,
           71.98344013320099,
           72.00359529048164,
           72.0237504477623,
           72.04390560504295,
           72.06406076232359,
           72.08421591960425,
           72.1043710768849,
           72.12489875245278,
           72.14728902734579,
           72.1696793022388,
           72.19206957713182,
           72.21445985202482,
           72.23685012691783,
           72.25924040181084,
           72.28163067670386,
           72.30402095159687,
           72.32641122648988,
           72.3488015013829,
           72.3711917762759,
           72.39358205116892,
           72.41597232606192,
           72.43836260095495,
           72.46075287584793,
           72.48314315074094,
           72.50553342563397,
           72.52792370052697,
           72.55031397541998,
           72.572704250313,
           72.59509452520601,
           72.61748480009902,
           72.63987507499203,
           72.66226534988505,
           72.68465562477806,
           72.70704589967107,
           72.72943617456407,
           72.75182644945708,
           72.7742167243501,
           72.79660699924311,
           72.81899727413611,
           72.84138754902912,
           72.86377782392215,
           72.88616809881515,
           72.90855837370816,
           72.93094864860117,
           72.95333892349419,
           72.9757291983872,
           72.99811947328021,
           73.02050974817323,
           73.04290002306622,
           73.06529029795924,
           73.08768057285225,
           73.11007084774526,
           73.13246112263828,
           73.15485139753129,
           73.1772416724243,
           73.1996319473173,
           73.22202222221031,
           73.24441249710334,
           73.26680277199634,
           73.28919304688935,
           73.31158332178236,
           73.33397359667538,
           73.35636387156838,
           73.3787541464614,
           73.40114442135442,
           73.42353469624743,
           73.44592497114043,
           73.46831524603344,
           73.20861013828527,
           72.80785733921653,
           72.40710454014777,
           72.006351741079,
           71.60559894201027,
           71.20484614294149,
           70.80409334387274,
           70.403340544804,
           70.00258774573524,
           69.6018349466665,
           69.2010821475977,
           68.80032934852898,
           68.39957654946022,
           67.99882375039147,
           67.59807095132273,
           67.19731815225397,
           66.79656535318522,
           66.39581255411645,
           65.99505975504769,
           65.59430695597895,
           65.1935541569102,
           64.79280135784143,
           64.3920485587727,
           63.99129575970392,
           63.590542960635176,
           63.18979016156642,
           62.789037362497666,
           62.38828456342892,
           61.98753176436015,
           61.58677896529141,
           61.18602616622266,
           60.814337658461646,
           60.44264917383241,
           60.07096068920316,
           59.699272204573916,
           59.32758371994467,
           58.955895235315424,
           58.58420675068619,
           58.21251826605695,
           57.84082978142769,
           57.46914129679847,
           57.09745281216921,
           56.72576432753997,
           56.35407584291072,
           55.98238735828147,
           55.610698873652225,
           55.239010389022994,
           54.86732190439375,
           54.4956334197645,
           54.12394493513526,
           53.75225645050601,
           53.38056796587678,
           53.00887948124753,
           52.63719099661828,
           52.26550251198903,
           51.89381402735981,
           51.522125542730556,
           51.1504370581013,
           50.778748573472065,
           50.407060088842826,
           50.03537160421359,
           49.66368311958434,
           49.291994634955095,
           48.92030615032584,
           48.54861766569661,
           48.176929181067365,
           47.80524069643812,
           47.43355221180887,
           47.06186372717963,
           46.690175242550396,
           46.31848675792115,
           45.946798273291904,
           45.57510978866266,
           45.203421304033405,
           44.831732819404166,
           44.46004433477493,
           44.088355850145675,
           43.71666736551643,
           43.344978880887204,
           42.97329039625796,
           42.601601911628705,
           42.22991342699946,
           41.858224942370214,
           41.53234115772027,
           41.25226207304957,
           40.9721829883789,
           40.692103903708215,
           40.41202481903746,
           40.13194573436678,
           39.851866649696035,
           39.571787565025275,
           39.291708480354586,
           39.01162939568392,
           38.73155031101316,
           38.451471226342406,
           38.176082577309785,
           37.903820881654205,
           37.63155918599867,
           37.359297490343145,
           37.087035794687566,
           36.814774099032036,
           36.542512403376506,
           36.27025070772093,
           35.9979890120654,
           35.72572731640981,
           35.4534656207543,
           35.181203925098764,
           34.90894222944318,
           34.636680533787654,
           34.36441883813213,
           34.09215714247654,
           33.81989544682102,
           33.5476337511655,
           33.27537205550985,
           33.00818185345109,
           32.74371877562921,
           32.479255697807346,
           32.21479261998549,
           31.95032954216359,
           31.685866464341743,
           31.42140338651983,
           31.156940308697987,
           30.892477230876143,
           30.628014153054227,
           30.36355107523233,
           30.09908799741054,
           29.834624919588624,
           29.570161841766712,
           29.305698763944875,
           29.041235686123024,
           28.780737626723987,
           28.52420458976247,
           28.26767155280095,
           28.011138515839377,
           27.754605478877863,
           27.498072441916296,
           27.241539404954768,
           26.985006367993247,
           26.72847333103174,
           26.471940294070215,
           26.21540725710864,
           25.95887422014712,
           25.702341183185553,
           25.445808146224028,
           25.194445465208887,
           24.946960547361964,
           24.699475629515085,
           24.45199071166817,
           24.2045057938213,
           23.95702087597437,
           23.70953595812749,
           23.46205104028063,
           23.214566122433748,
           22.967081204586815,
           22.7195962867399,
           22.47211136889303,
           22.22898856133698,
           21.99151666858179,
           21.75404477582665,
           21.516572883071493,
           21.27910099031631,
           21.04162909756117,
           20.804157204805968,
           20.56668531205081,
           20.32921341929567,
           20.091741526540485,
           19.85426963378533,
           19.624772694400132,
           19.397692409221737,
           19.17061212404328,
           18.943531838864878,
           18.71645155368648,
           18.48937126850803,
           18.262290983329574,
           18.035210698151186,
           17.808130412972776,
           17.583927808504477,
           17.365960172972734,
           17.14799253744103,
           16.930024901909277,
           16.712057266377577,
           16.494089630845874,
           16.27612199531412,
           16.058154359782417,
           15.840186724250714,
           15.630429897402294,
           15.421752425040951,
           15.213074952679655,
           15.004397480318357,
           14.795720007957046,
           14.587042535595717,
           14.37836506323442,
           14.173487144370101,
           13.976873256477823,
           13.780259368585575,
           13.583645480693257,
           13.387031592800936,
           13.190417704908668,
           12.993803817016383,
           12.803543567897911,
           12.620080238759328,
           12.43661690962077,
           12.253153580482177,
           12.069690251343623,
           11.886226922205068,
           11.706211412396922,
           11.534815447842947,
           11.36341948328892,
           11.192023518734908,
           11.020627554180871,
           10.849231589626871,
           10.684853629790966,
           10.524453790562589,
           10.36405395133424,
           10.203654112105893,
           10.043254272877515,
           9.88758019754675,
           9.737222608550193,
           9.586865019553603,
           9.436507430557015,
           9.286149841560485,
           9.142425941555125,
           9.0012291601907,
           8.8600323788263,
           8.718835597461903,
           8.580565541878357,
           8.447745251387015,
           8.31492496089567,
           8.182104670404302,
           8.05166496467322,
           7.9266665969221854,
           7.801668229171142,
           7.676669861420068,
           7.556712133941044,
           7.440827649843161,
           7.324943165745292,
           7.209698800299508,
           7.103709480529931,
           6.9977201607603465,
           6.891730840990769,
           6.7914309459559705,
           6.692443995340709,
           6.593457044725437,
           6.498464432103114,
           6.404642798528797,
           6.310821164954492,
           6.22309293820839,
           6.135845769685554,
           6.05036931205585,
           5.970057428189113,
           5.8897455443223565,
           5.814005811148588,
           5.739846574914258,
           5.667737098804318,
           5.599023674459866,
           5.52834829294587,
           5.445901168414525,
           5.363454043883165,
           5.281006919351805,
           5.198559794820458,
           5.116112670289102,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           67.98745699311947,
           68.0321208506224,
           68.07678470812533,
           68.12144856562827,
           68.16611242313121,
           68.21077628063415,
           68.25544013813708,
           68.30010399564,
           68.34476785314295,
           68.38943171064588,
           68.43409556814882,
           68.47875942565176,
           68.5234232831547,
           68.56808714065764,
           68.61275099816056,
           68.6574148556635,
           68.70207871316643,
           68.74674257066937,
           68.79140642817231,
           68.83607028567525,
           68.88073414317817,
           68.92539800068111,
           68.97006185818405,
           69.01472571568699,
           69.05938957318992,
           69.10405343069286,
           69.1487172881958,
           69.19338114569872,
           69.23804500320168,
           69.28270886070459,
           69.32737271820753,
           69.37203657571047,
           69.41670043321339,
           69.46136429071635,
           69.50602814821927,
           69.55069200572221,
           69.59535586322515,
           69.64001972072808,
           69.68468357823103,
           69.72934743573396,
           69.77401129323688,
           69.81867515073982,
           69.86333900824276,
           69.9080028657457,
           69.95266672239367,
           69.99619555542782,
           70.03972438846198,
           70.08325322149611,
           70.12678205453027,
           70.17031088756443,
           70.21383972059856,
           70.25736855363272,
           70.30089738666688,
           70.344426219701,
           70.38795505273517,
           70.43148388576932,
           70.47501271880347,
           70.51854155183761,
           70.56207038487176,
           70.60559921790593,
           70.64912805094006,
           70.69265688397424,
           70.73618571700837,
           70.77971455004251,
           70.82324338307667,
           70.86677221611083,
           70.91030104914498,
           70.95382988217912,
           70.99735871521327,
           71.04088754824743,
           71.08441638128157,
           71.12794521431573,
           71.17147404734988,
           71.21500288038402,
           71.25853171341817,
           71.30206054645232,
           71.34558937948647,
           71.38911821252063,
           71.43264704555477,
           71.47617587858892,
           71.51970471162308,
           71.56323354465722,
           71.60676237769137,
           71.65029121072553,
           71.67434198063175,
           71.6944971379124,
           71.71465229519305,
           71.7348074524737,
           71.75496260975436,
           71.775117767035,
           71.79527292431565,
           71.81542808159631,
           71.83558323887696,
           71.85573839615762,
           71.87589355343826,
           71.89604871071892,
           71.91620386799957,
           71.93635902528021,
           71.95651418256087,
           71.97666933984152,
           71.99682449712216,
           72.01697965440282,
           72.03713481168347,
           72.05728996896411,
           72.07744512624477,
           72.09760028352542,
           72.11775544080608,
           72.13791059808673,
           72.15806575536737,
           72.17822091264803,
           72.19837606992868,
           72.21853122720933,
           72.23868638449,
           72.25884154177064,
           72.27899669905129,
           72.29915185633195,
           72.3193070136126,
           72.33946217089324,
           72.3596173281739,
           72.37977248545455,
           72.39992764273518,
           72.42008280001585,
           72.44023795729649,
           72.46188319130175,
           72.48427346619476,
           72.50666374108778,
           72.52905401598079,
           72.5514442908738,
           72.57383456576682,
           72.59622484065983,
           72.61861511555283,
           72.64100539044584,
           72.66339566533885,
           72.68578594023187,
           72.70817621512488,
           72.73056649001788,
           72.7529567649109,
           72.7753470398039,
           72.79773731469692,
           72.82012758958993,
           72.84251786448294,
           72.86490813937596,
           72.88729841426897,
           72.90968868916198,
           72.932078964055,
           72.95446923894801,
           72.976859513841,
           72.99924978873402,
           73.02164006362703,
           73.04403033852005,
           73.06642061341306,
           73.08881088830606,
           73.11120116319907,
           73.13359143809208,
           73.1559817129851,
           73.17837198787811,
           73.20076226277112,
           73.22315253766413,
           73.24554281255715,
           73.26793308745016,
           73.29032336234316,
           73.31271363723617,
           73.33510391212918,
           73.35749418702221,
           73.37988446191521,
           73.40227473680821,
           73.42466501170124,
           73.16495990395305,
           72.7642071048843,
           72.36345430581555,
           71.9627015067468,
           71.56194870767806,
           71.16119590860927,
           70.76044310954053,
           70.35969031047179,
           69.95893751140304,
           69.5581847123343,
           69.15743191326551,
           68.75667911419677,
           68.35592631512802,
           67.95517351605926,
           67.55442071699052,
           67.15366791792175,
           66.752915118853,
           66.35216231978424,
           65.95140952071547,
           65.55065672164673,
           65.14990392257798,
           64.74915112350922,
           64.3483983244405,
           63.94764552537171,
           63.54689272630297,
           63.146139927234216,
           62.74538712816546,
           62.34463432909672,
           61.943881530027944,
           61.543128730959204,
           61.14237593189044,
           60.74162313282169,
           60.340870333752946,
           59.940117534684184,
           59.539364735615436,
           59.13861193654667,
           58.73785913747792,
           58.337106338409185,
           57.93635353934042,
           57.53560074027166,
           57.13484794120293,
           56.734095142134166,
           56.33334234306541,
           55.93258954399664,
           55.53183674492789,
           55.13108394585913,
           54.73033114679039,
           54.32957834772163,
           53.92882554865288,
           53.52807274958411,
           53.127319950515364,
           52.726567151446616,
           52.32581435237787,
           51.94472267757472,
           51.57303419294547,
           51.201345708316246,
           50.82965722368699,
           50.45796873905775,
           50.08628025442851,
           49.714591769799256,
           49.34290328517003,
           48.971214800540785,
           48.59952631591153,
           48.22783783128228,
           47.856149346653055,
           47.48446086202381,
           47.112772377394556,
           46.74108389276531,
           46.369395408136064,
           45.99770692350683,
           45.62601843887759,
           45.254329954248334,
           44.882641469619095,
           44.51095298498984,
           44.13926450036061,
           43.76757601573137,
           43.39588753110212,
           43.02419904647287,
           42.65251056184364,
           42.280822077214395,
           41.90913359258515,
           41.537445107955904,
           41.16575662332666,
           40.839872838676705,
           40.55979375400601,
           40.27971466933534,
           39.99963558466466,
           39.71955649999391,
           39.43947741532322,
           39.15939833065248,
           38.88447872500815,
           38.61221702935255,
           38.33995533369704,
           38.06769363804152,
           37.795431942385854,
           37.5231702467304,
           37.25090855107482,
           36.978646855419285,
           36.70638515976376,
           36.43412346410818,
           36.16186176845265,
           35.88960007279712,
           35.61733837714155,
           35.34507668148602,
           35.072814985830426,
           34.80055329017492,
           34.52829159451939,
           34.256029898863794,
           33.98376820320827,
           33.713898721398415,
           33.44943564357657,
           33.18497256575472,
           32.92050948793282,
           32.65604641011097,
           32.3915833322891,
           32.12712025446722,
           31.862657176645357,
           31.598194098823498,
           31.3337310210016,
           31.069267943179756,
           30.80480486535784,
           30.540341787535997,
           30.275878709714153,
           30.011415631892238,
           29.74695255407034,
           29.48248947624855,
           29.224469554575613,
           28.96793651761408,
           28.71140348065258,
           28.454870443691004,
           28.19833740672943,
           27.941804369767908,
           27.685271332806398,
           27.428738295844816,
           27.172205258883302,
           26.915672221921735,
           26.65913918496021,
           26.402606147998686,
           26.146073111037182,
           25.889540074075654,
           25.638321014044873,
           25.390836096198008,
           25.143351178351136,
           24.895866260504256,
           24.648381342657384,
           24.400896424810462,
           24.153411506963582,
           23.905926589116667,
           23.658441671269802,
           23.410956753422862,
           23.163471835575983,
           22.915986917729132,
           22.67043520805427,
           22.432963315299112,
           22.19549142254397,
           21.958019529788782,
           21.72054763703363,
           21.48307574427844,
           21.245603851523303,
           21.008131958768146,
           20.770660066012958,
           20.53318817325782,
           20.295716280502614,
           20.061337702182005,
           19.834257417003563,
           19.607177131825164,
           19.38009684664671,
           19.153016561468313,
           18.925936276289914,
           18.698855991111458,
           18.471775705933055,
           18.244695420754656,
           18.017615135576204,
           17.796410113268447,
           17.578442477736758,
           17.360474842205004,
           17.14250720667329,
           16.92453957114155,
           16.706571935609844,
           16.48860430007809,
           16.27063666454639,
           16.052977416756043,
           15.844299944394733,
           15.635622472033404,
           15.426944999672106,
           15.218267527310795,
           15.009590054949454,
           14.800912582588156,
           14.59223511022686,
           14.387214708067216,
           14.19060082017494,
           13.993986932282663,
           13.797373044390344,
           13.600759156498066,
           13.40414526860582,
           13.2075313807135,
           13.015202504333335,
           12.831739175194791,
           12.648275846056196,
           12.464812516917632,
           12.281349187779046,
           12.097885858640492,
           11.914422529501898,
           11.74298346811365,
           11.571587503559673,
           11.400191539005611,
           11.228795574451636,
           11.057399609897612,
           10.888518117501226,
           10.728118278272868,
           10.5677184390445,
           10.407318599816152,
           10.246918760587775,
           10.086518921359428,
           9.935669064257727,
           9.785311475261139,
           9.63495388626458,
           9.484596297268022,
           9.335186378747387,
           9.193989597382961,
           9.052792816018592,
           8.911596034654165,
           8.770399253289739,
           8.63452608515599,
           8.501705794664646,
           8.368885504173278,
           8.236065213681933,
           8.107189892489936,
           7.982191524738893,
           7.857193156987842,
           7.732194789236808,
           7.613331746122266,
           7.497447262024384,
           7.38156277792653,
           7.266771829718475,
           7.16078250994889,
           7.0547931901793,
           6.948803870409723,
           6.848339857343552,
           6.749352906728285,
           6.65036595611303,
           6.554917962887183,
           6.461096329312866,
           6.367274695738573,
           6.2785683168792,
           6.191321148356357,
           6.104418284660875,
           6.024106400794133,
           5.943794516927384,
           5.866460175530578,
           5.792300939296248,
           5.718505565968368,
           5.649792141623914,
           5.5810787172794765,
           5.501574528502465,
           5.419127403971104,
           5.3366802794397605,
           5.2542331549084,
           5.17178603037704,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           67.99941410368224,
           68.04407796118517,
           68.0887418186881,
           68.13340567619105,
           68.17806953369399,
           68.22273339119693,
           68.26739724869984,
           68.31206110620278,
           68.35672496370572,
           68.40138882120866,
           68.4460526787116,
           68.49071653621452,
           68.53538039371746,
           68.5800442512204,
           68.62470810872334,
           68.66937196622628,
           68.7140358237292,
           68.75869968123214,
           68.80336353873508,
           68.84802739623802,
           68.89269125374095,
           68.93735511124387,
           68.98201896874681,
           69.02668282624977,
           69.07134668375268,
           69.11601054125563,
           69.16067439875856,
           69.2053382562615,
           69.24943460048779,
           69.29296343352195,
           69.33649226655609,
           69.38002109959024,
           69.42354993262438,
           69.46707876565856,
           69.5106075986927,
           69.55413643172685,
           69.59766526476099,
           69.64119409779515,
           69.6847229308293,
           69.72825176386345,
           69.77178059689759,
           69.81530942993174,
           69.8588382629659,
           69.90236709600005,
           69.94589592903421,
           69.98942476206834,
           70.0329535951025,
           70.07648242813664,
           70.12001126117079,
           70.16354009420495,
           70.20706892723909,
           70.25059776027325,
           70.2941265933074,
           70.33765542634154,
           70.3811842593757,
           70.42471309240985,
           70.468241925444,
           70.51177075847815,
           70.5552995915123,
           70.59882842454645,
           70.6423572575806,
           70.68588609061476,
           70.72941492364889,
           70.77294375668305,
           70.8164725897172,
           70.86000142275135,
           70.9035302557855,
           70.94705908881964,
           70.9905879218538,
           71.03411675488795,
           71.07764558792209,
           71.12117442095624,
           71.16470325399041,
           71.20823208702456,
           71.2517609200587,
           71.29528975309285,
           71.33881858612699,
           71.38234741916115,
           71.4258762521953,
           71.46940508522945,
           71.5129339182636,
           71.55646275129774,
           71.5999915843319,
           71.64352041736603,
           71.66757118727229,
           71.68772634455294,
           71.70788150183358,
           71.72803665911424,
           71.7481918163949,
           71.76834697367553,
           71.78850213095619,
           71.80865728823684,
           71.82881244551749,
           71.84896760279814,
           71.8691227600788,
           71.88927791735944,
           71.9094330746401,
           71.92958823192075,
           71.9497433892014,
           71.96989854648206,
           71.9900537037627,
           72.01020886104335,
           72.03036401832401,
           72.05051917560465,
           72.0706743328853,
           72.09082949016596,
           72.1109846474466,
           72.13113980472725,
           72.15129496200791,
           72.17145011928856,
           72.19160527656922,
           72.21176043384986,
           72.23191559113052,
           72.25207074841117,
           72.27222590569181,
           72.29238106297247,
           72.31253622025312,
           72.33269137753376,
           72.35284653481442,
           72.37300169209507,
           72.39315684937571,
           72.41331200665637,
           72.43346716393702,
           72.45362232121767,
           72.47377747849832,
           72.49393263577898,
           72.51408779305963,
           72.53424295034027,
           72.55439810762093,
           72.57455326490158,
           72.59470842218222,
           72.61486357946288,
           72.63501873674353,
           72.65517389402417,
           72.67532905130483,
           72.69548420858548,
           72.71563936586612,
           72.73579452314678,
           72.75594968042743,
           72.77647735525773,
           72.79886763015074,
           72.82125790504375,
           72.84364817993676,
           72.86603845482976,
           72.88842872972279,
           72.91081900461579,
           72.93320927950879,
           72.95559955440181,
           72.97798982929483,
           73.00038010418784,
           73.02277037908084,
           73.04516065397385,
           73.06755092886686,
           73.08994120375988,
           73.11233147865289,
           73.13472175354589,
           73.15711202843892,
           73.17950230333192,
           73.20189257822494,
           73.22428285311794,
           73.24667312801095,
           73.26906340290395,
           73.29145367779698,
           73.31384395269,
           73.336234227583,
           73.358624502476,
           73.38101477736902,
           73.12130966962084,
           72.7205568705521,
           72.31980407148336,
           71.91905127241458,
           71.51829847334585,
           71.11754567427707,
           70.71679287520833,
           70.31604007613957,
           69.91528727707082,
           69.51453447800208,
           69.1137816789333,
           68.71302887986457,
           68.31227608079581,
           67.91152328172704,
           67.51077048265832,
           67.11001768358955,
           66.70926488452079,
           66.30851208545202,
           65.90775928638328,
           65.50700648731453,
           65.10625368824577,
           64.70550088917702,
           64.30474809010828,
           63.90399529103951,
           63.50324249197077,
           63.10248969290201,
           62.70173689383324,
           62.30098409476451,
           61.90023129569574,
           61.499478496627,
           61.098725697558244,
           60.697972898489475,
           60.29722009942074,
           59.89646730035198,
           59.49571450128323,
           59.094961702214476,
           58.69420890314571,
           58.29345610407697,
           57.89270330500821,
           57.49195050593944,
           57.09119770687071,
           56.69044490780195,
           56.2896921087332,
           55.88893930966444,
           55.48818651059568,
           55.08743371152691,
           54.68668091245818,
           54.28592811338943,
           53.88517531432067,
           53.48442251525191,
           53.08366971618315,
           52.68291691711441,
           52.28216411804566,
           51.8814113189769,
           51.48065851990815,
           51.079905720839406,
           50.679152921770644,
           50.27840012270188,
           49.87764732363313,
           49.47689452456437,
           49.07614172549563,
           48.675388926426876,
           48.274636127358114,
           47.87388332828935,
           47.47313052922061,
           47.072377730151864,
           46.6716249310831,
           46.27087213201435,
           45.870119332945585,
           45.469366533876844,
           45.06861373480809,
           44.667860935739334,
           44.26710813667058,
           43.86635533760182,
           43.46560253853308,
           43.0751076966878,
           42.703419212058556,
           42.3317307274293,
           41.960042242800085,
           41.58835375817083,
           41.21666527354159,
           40.844976788912334,
           40.47328830428309,
           40.14740451963315,
           39.86732543496245,
           39.592874872706524,
           39.32061317705093,
           39.04835148139541,
           38.77608978573983,
           38.5038280900843,
           38.231566394428775,
           37.959304698773174,
           37.687043003117665,
           37.414781307462135,
           37.142519611806485,
           36.87025791615102,
           36.597996220495446,
           36.32573452483991,
           36.053472829184386,
           35.781211133528814,
           35.50894943787328,
           35.236687742217754,
           34.964426046562174,
           34.69216435090664,
           34.41990265525105,
           34.155152511523944,
           33.890689433702086,
           33.62622635588018,
           33.361763278058326,
           33.097300200236425,
           32.832837122414574,
           32.56837404459272,
           32.30391096677082,
           32.03944788894897,
           31.774984811127112,
           31.51052173330522,
           31.246058655483363,
           30.98159557766151,
           30.717132499839607,
           30.45266942201776,
           30.188206344195848,
           29.924734519388753,
           29.66820148242719,
           29.41166844546566,
           29.15513540850415,
           28.898602371542637,
           28.64206933458106,
           28.385536297619527,
           28.129003260658028,
           27.87247022369645,
           27.615937186734875,
           27.359404149773354,
           27.102871112811844,
           26.846338075850262,
           26.58980503888875,
           26.33327200192718,
           26.082196562880966,
           25.834711645034087,
           25.587226727187225,
           25.339741809340346,
           25.092256891493367,
           24.844771973646502,
           24.597287055799626,
           24.349802137952747,
           24.10231722010588,
           23.854832302258956,
           23.607347384412076,
           23.35986246656516,
           23.112377548718293,
           22.87440996201644,
           22.63693806926124,
           22.39946617650611,
           22.161994283750914,
           21.924522390995758,
           21.68705049824062,
           21.449578605485428,
           21.212106712730275,
           20.97463481997509,
           20.73716292721995,
           20.499691034464792,
           20.27082242478545,
           20.043742139607048,
           19.816661854428595,
           19.589581569250182,
           19.362501284071744,
           19.135420998893345,
           18.90834071371489,
           18.68126042853649,
           18.45418014335809,
           18.227099858179642,
           18.00889241803243,
           17.790924782500692,
           17.57295714696897,
           17.35498951143726,
           17.137021875905567,
           16.919054240373814,
           16.7010866048421,
           16.48311896931036,
           16.266847463748515,
           16.058169991387203,
           15.849492519025874,
           15.640815046664542,
           15.432137574303232,
           15.223460101941903,
           15.014782629580605,
           14.806105157219294,
           14.60094227176436,
           14.404328383872055,
           14.207714495979777,
           14.011100608087457,
           13.814486720195182,
           13.617872832302904,
           13.421258944410585,
           13.226861440768802,
           13.043398111630216,
           12.859934782491653,
           12.676471453353058,
           12.493008124214512,
           12.309544795075919,
           12.126081465937354,
           11.951151488384403,
           11.779755523830374,
           11.608359559276366,
           11.436963594722338,
           11.265567630168361,
           11.0941716656143,
           10.931782765983135,
           10.771382926754788,
           10.61098308752641,
           10.450583248298052,
           10.290183409069686,
           10.134115519965267,
           9.983757930968679,
           9.833400341972117,
           9.68304275297556,
           9.532685163978972,
           9.38675003457525,
           9.245553253210852,
           9.104356471846426,
           8.963159690482,
           8.82196290911763,
           8.688486628433623,
           8.55566633794227,
           8.42284604745091,
           8.290025756959565,
           8.162714820306629,
           8.037716452555609,
           7.912718084804558,
           7.787719717053514,
           7.669951358303483,
           7.554066874205622,
           7.4381823901077535,
           7.323844859137421,
           7.217855539367852,
           7.111866219598267,
           7.0058768998286824,
           6.905248768731136,
           6.806261818115869,
           6.70727486750061,
           6.611371493671248,
           6.517549860096949,
           6.423728226522643,
           6.334043695550012,
           6.246796527027181,
           6.159549358504329,
           6.07815537339916,
           5.997843489532409,
           5.918914539912558,
           5.8447553036782285,
           5.770596067443918,
           5.7005606087879706,
           5.631847184443524,
           5.5572478885904015,
           5.474800764059058,
           5.392353639527698,
           5.309906514996339,
           5.227459390464994,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           68.011371214245,
           68.05603507174794,
           68.10069892925087,
           68.14536278675381,
           68.19002664425675,
           68.23469050175969,
           68.27935435926261,
           68.32401821676555,
           68.36868207426849,
           68.41334593177143,
           68.45800978927437,
           68.50267364554776,
           68.54620247858192,
           68.58973131161606,
           68.63326014465022,
           68.67678897768437,
           68.72031781071851,
           68.76384664375266,
           68.80737547678683,
           68.85090430982098,
           68.8944331428551,
           68.93796197588927,
           68.98149080892343,
           69.02501964195757,
           69.06854847499172,
           69.11207730802587,
           69.15560614106002,
           69.19913497409416,
           69.24266380712832,
           69.28619264016247,
           69.32972147319663,
           69.37325030623077,
           69.41677913926492,
           69.46030797229906,
           69.50383680533321,
           69.54736563836737,
           69.59089447140151,
           69.63442330443567,
           69.67795213746982,
           69.72148097050396,
           69.76500980353812,
           69.80853863657227,
           69.85206746960641,
           69.89559630264057,
           69.93912513567471,
           69.98265396870886,
           70.02618280174302,
           70.06971163477716,
           70.11324046781132,
           70.15676930084547,
           70.20029813387961,
           70.24382696691377,
           70.2873557999479,
           70.33088463298206,
           70.37441346601622,
           70.41794229905037,
           70.46147113208453,
           70.50499996511866,
           70.5485287981528,
           70.59205763118698,
           70.6355864642211,
           70.67911529725527,
           70.72264413028941,
           70.76617296332357,
           70.80970179635771,
           70.85323062939187,
           70.89675946242602,
           70.94028829546016,
           70.98381712849432,
           71.02734596152848,
           71.07087479456263,
           71.11440362759677,
           71.15793246063092,
           71.20146129366506,
           71.24499012669922,
           71.28851895973337,
           71.33204779276751,
           71.37557662580167,
           71.41910545883582,
           71.46263429186996,
           71.50616312490412,
           71.54969195793826,
           71.59322079097241,
           71.63674962400657,
           71.6608003939128,
           71.68095555119345,
           71.7011107084741,
           71.72126586575476,
           71.7414210230354,
           71.76157618031606,
           71.78173133759671,
           71.80188649487735,
           71.822041652158,
           71.84219680943866,
           71.8623519667193,
           71.88250712399997,
           71.90266228128061,
           71.92281743856127,
           71.94297259584192,
           71.96312775312256,
           71.98328291040322,
           72.00343806768387,
           72.02359322496451,
           72.04374838224517,
           72.06390353952582,
           72.08405869680647,
           72.10421385408712,
           72.12436901136778,
           72.14452416864843,
           72.16467932592907,
           72.18483448320973,
           72.20498964049037,
           72.22514479777104,
           72.24529995505168,
           72.26545511233233,
           72.28561026961299,
           72.30576542689363,
           72.32592058417428,
           72.34607574145494,
           72.36623089873558,
           72.38638605601624,
           72.40654121329689,
           72.42669637057755,
           72.4468515278582,
           72.46700668513884,
           72.4871618424195,
           72.50731699970014,
           72.5274721569808,
           72.54762731426145,
           72.5677824715421,
           72.58793762882274,
           72.60809278610341,
           72.62824794338405,
           72.64840310066471,
           72.66855825794536,
           72.688713415226,
           72.70886857250666,
           72.7290237297873,
           72.74917888706796,
           72.76933404434861,
           72.78948920162925,
           72.8096443589099,
           72.82979951619056,
           72.8499546734712,
           72.87010983075186,
           72.89026498803251,
           72.91042014531315,
           72.93057530259381,
           72.95073045987448,
           72.97088561715512,
           72.99104077443577,
           73.01119593171641,
           73.03135108899707,
           73.05150624627771,
           73.07166140355837,
           73.09181656083902,
           73.1134617941067,
           73.13585206899971,
           73.15824234389272,
           73.18063261878574,
           73.20302289367874,
           73.22541316857175,
           73.24780344346478,
           73.27019371835779,
           73.29258399325079,
           73.3149742681438,
           73.33736454303681,
           73.07765943528862,
           72.6769066362199,
           72.27615383715114,
           71.87540103808237,
           71.47464823901365,
           71.07389543994486,
           70.67314264087611,
           70.27238984180737,
           69.87163704273861,
           69.47088424366987,
           69.07013144460109,
           68.66937864553235,
           68.26862584646359,
           67.86787304739484,
           67.4671202483261,
           67.06636744925734,
           66.66561465018859,
           66.26486185111982,
           65.86410905205106,
           65.46335625298232,
           65.06260345391357,
           64.66185065484481,
           64.26109785577607,
           63.860345056707295,
           63.459592257638555,
           63.0588394585698,
           62.65808665950104,
           62.2573338604323,
           61.85658106136352,
           61.45582826229479,
           61.055075463226025,
           60.65432266415726,
           60.25356986508854,
           59.85281706601977,
           59.45206426695101,
           59.05131146788226,
           58.6505586688135,
           58.24980586974475,
           57.849053070676,
           57.44830027160724,
           57.047547472538504,
           56.64679467346974,
           56.24122553329368,
           55.83084013200903,
           55.420454730724394,
           55.01006932943975,
           54.59968392815513,
           54.18929852687049,
           53.77891312558585,
           53.36852772430122,
           52.958142323016574,
           52.547756921731946,
           52.13737152044732,
           51.72698611916267,
           51.31660071787803,
           50.90621531659341,
           50.49582991530877,
           50.08544451402413,
           49.67505911273949,
           49.26467371145485,
           48.85428831017023,
           48.44390290888558,
           48.03351750760095,
           47.623132106316305,
           47.212746705031684,
           46.80236130374704,
           46.391975902462406,
           45.98159050117776,
           45.57120509989313,
           45.160819698608506,
           44.750434297323864,
           44.34004889603922,
           43.929663494754585,
           43.51927809346995,
           43.10889269218532,
           42.698507290900686,
           42.28812188961605,
           41.8777364883314,
           41.46735108704679,
           41.056965685762144,
           40.64658028447751,
           40.236194883192866,
           39.825809481908216,
           39.484485933438165,
           39.21222423778263,
           38.93996254212711,
           38.667700846471526,
           38.395439150815996,
           38.123177455160416,
           37.85091575950489,
           37.57865406384936,
           37.30639236819377,
           37.034130672538254,
           36.76186897688273,
           36.48960728122707,
           36.21734558557161,
           35.945083889916035,
           35.672822194260505,
           35.400560498604975,
           35.1282988029494,
           34.86086937947128,
           34.59640630164938,
           34.331943223827594,
           34.06748014600568,
           33.80301706818377,
           33.53855399036193,
           33.274090912540075,
           33.00962783471817,
           32.745164756896315,
           32.480701679074414,
           32.21623860125256,
           31.95177552343071,
           31.687312445608814,
           31.42284936778696,
           31.158386289965094,
           30.89392321214321,
           30.62946013432135,
           30.3684664472403,
           30.111933410278784,
           29.85540037331727,
           29.598867336355692,
           29.342334299394174,
           29.08580126243261,
           28.829268225471083,
           28.572735188509572,
           28.316202151548055,
           28.059669114586477,
           27.80313607762495,
           27.546603040663445,
           27.29007000370187,
           27.033536966740293,
           26.777003929778775,
           26.52607211171704,
           26.278587193870113,
           26.031102276023244,
           25.783617358176375,
           25.536132440329443,
           25.288647522482563,
           25.041162604635705,
           24.793677686788826,
           24.546192768941847,
           24.298707851094978,
           24.051222933248106,
           23.803738015401226,
           23.556253097554357,
           23.315856608733753,
           23.078384715978558,
           22.840912823223373,
           22.603440930468228,
           22.36596903771307,
           22.128497144957876,
           21.891025252202745,
           21.653553359447546,
           21.41608146669239,
           21.178609573937248,
           20.94113768118206,
           20.707387432567263,
           20.480307147388864,
           20.253226862210425,
           20.026146577032005,
           19.79906629185361,
           19.57198600667521,
           19.344905721496755,
           19.117825436318345,
           18.890745151139903,
           18.663664865961504,
           18.439342358328126,
           18.221374722796387,
           18.003407087264648,
           17.78543945173293,
           17.567471816201227,
           17.349504180669488,
           17.13153654513777,
           16.913568909606056,
           16.695601274074363,
           16.480717510740938,
           16.272040038379593,
           16.0633625660183,
           15.854685093656999,
           15.64600762129569,
           15.43733014893436,
           15.228652676573029,
           15.019975204211717,
           14.814669835461475,
           14.618055947569198,
           14.42144205967688,
           14.22482817178459,
           14.028214283892284,
           13.831600396000006,
           13.634986508107687,
           13.438520377204187,
           13.25505704806563,
           13.071593718927062,
           12.88813038978851,
           12.704667060649925,
           12.52120373151136,
           12.337740402372765,
           12.159319508655134,
           11.987923544101095,
           11.816527579547085,
           11.645131614993081,
           11.473735650439057,
           11.302339685885045,
           11.135447253693382,
           10.975047414465013,
           10.814647575236656,
           10.65424773600831,
           10.493847896779965,
           10.333448057551585,
           10.182204386676204,
           10.031846797679645,
           9.881489208683087,
           9.731131619686497,
           9.580774030689938,
           9.438313690403106,
           9.29711690903868,
           9.155920127674282,
           9.014723346309884,
           8.87526746220259,
           8.742447171711238,
           8.609626881219885,
           8.476806590728533,
           8.34398630023718,
           8.21823974812335,
           8.093241380372298,
           7.968243012621242,
           7.8432446448702215,
           7.726570970484692,
           7.610686486386825,
           7.494802002288963,
           7.380917888556402,
           7.274928568786818,
           7.168939249017208,
           7.0629499292476385,
           6.962157680118707,
           6.863170729503434,
           6.7641837788881904,
           6.667825024455319,
           6.574003390881003,
           6.480181757306703,
           6.389519074220832,
           6.30227190569798,
           6.2150247371751375,
           6.132204346004187,
           6.051892462137438,
           5.97158057827069,
           5.897209668060209,
           5.8230504318258935,
           5.7513290759520155,
           5.682615651607579,
           5.612921248678357,
           5.530474124146997,
           5.448026999615637,
           5.365579875084293,
           5.283132750552933,
           5.200685626021573,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           68.01861358698837,
           68.06109112599712,
           68.10356866500588,
           68.14604620401465,
           68.1885237430234,
           68.23100128203217,
           68.27400446699022,
           68.31753330002437,
           68.3610621330585,
           68.40459096609266,
           68.4481197991268,
           68.49164863216096,
           68.5351774651951,
           68.57870629822926,
           68.62223513126341,
           68.66576396429757,
           68.70929279733171,
           68.75282163036586,
           68.79635046340002,
           68.83987929643416,
           68.88340812946831,
           68.92693696250245,
           68.97046579553661,
           69.01399462857076,
           69.05752346160492,
           69.10105229463906,
           69.1445811276732,
           69.18810996070737,
           69.23163879374151,
           69.27516762677567,
           69.31869645980981,
           69.36222529284396,
           69.4057541258781,
           69.44928295891226,
           69.49281179194641,
           69.53634062498057,
           69.57986945801471,
           69.62339829104886,
           69.66692712408302,
           69.71045595711716,
           69.7539847901513,
           69.79751362318547,
           69.84104245621961,
           69.88457128925376,
           69.92810012228792,
           69.97162895532206,
           70.0151577883562,
           70.05868662139036,
           70.10221545442451,
           70.14574428745865,
           70.18927312049281,
           70.23280195352696,
           70.27633078656112,
           70.31985961959526,
           70.36338845262941,
           70.40691728566355,
           70.45044611869773,
           70.49397495173186,
           70.537503784766,
           70.58103261780016,
           70.6245614508343,
           70.66809028386847,
           70.71161911690261,
           70.75514794993676,
           70.79867678297092,
           70.84220561600506,
           70.88573444903922,
           70.92926328207336,
           70.97279211510752,
           71.01632094814167,
           71.05984978117581,
           71.10337861420996,
           71.1469074472441,
           71.19043628027826,
           71.23396511331242,
           71.27749394634657,
           71.32102277938071,
           71.36455161241487,
           71.40808044544902,
           71.45160927848316,
           71.49513811151732,
           71.53866694455147,
           71.58219577758561,
           71.62572461061977,
           71.649775380526,
           71.66993053780665,
           71.69008569508729,
           71.71024085236795,
           71.7303960096486,
           71.75055116692926,
           71.7707063242099,
           71.79086148149055,
           71.8110166387712,
           71.83117179605186,
           71.85132695333252,
           71.87148211061316,
           71.89163726789381,
           71.91179242517445,
           71.93194758245511,
           71.95210273973576,
           71.97225789701642,
           71.99241305429706,
           72.01256821157772,
           72.03272336885837,
           72.05287852613901,
           72.07303368341967,
           72.09318884070032,
           72.11334399798096,
           72.13349915526163,
           72.15365431254227,
           72.17380946982291,
           72.19396462710358,
           72.21411978438422,
           72.23427494166488,
           72.25443009894553,
           72.27458525622617,
           72.29474041350682,
           72.31489557078748,
           72.33505072806814,
           72.35520588534878,
           72.37536104262944,
           72.39551619991008,
           72.41567135719073,
           72.43582651447139,
           72.45598167175203,
           72.4761368290327,
           72.49629198631334,
           72.516447143594,
           72.53660230087465,
           72.55675745815529,
           72.57691261543594,
           72.5970677727166,
           72.61722292999724,
           72.6373780872779,
           72.65753324455855,
           72.67768840183919,
           72.69784355911985,
           72.7179987164005,
           72.73815387368114,
           72.7583090309618,
           72.77846418824245,
           72.79861934552311,
           72.81877450280376,
           72.8389296600844,
           72.85908481736506,
           72.87923997464571,
           72.89939513192635,
           72.91955028920701,
           72.93970544648766,
           72.9598606037683,
           72.98001576104896,
           73.00017091832962,
           73.02032607561027,
           73.04048123289093,
           73.06063639017158,
           73.08079154745222,
           73.10094670473286,
           73.12110186201352,
           73.14125701929417,
           73.16141217657483,
           73.18156733385548,
           73.20131953821063,
           73.21905699261164,
           73.23679444701266,
           73.25453190141366,
           73.27226935581469,
           73.29000681021569,
           73.00825424173316,
           72.57675666180887,
           72.14525908188455,
           71.71376150196025,
           71.28226392203595,
           70.85076634211163,
           70.41926876218734,
           69.98777118226303,
           69.55627360233873,
           69.13103144510728,
           68.72064604382263,
           68.310260642538,
           67.89987524125337,
           67.48948983996873,
           67.0791044386841,
           66.66871903739946,
           66.25833363611481,
           65.84794823483018,
           65.43756283354554,
           65.02717743226091,
           64.61679203097628,
           64.20640662969164,
           63.79602122840703,
           63.385635827122364,
           62.97525042583774,
           62.56486502455311,
           62.154479623268465,
           61.74409422198384,
           61.33370882069919,
           60.92332341941456,
           60.51293801812992,
           60.10255261684527,
           59.69216721556066,
           59.281781814276016,
           58.87139641299138,
           58.461011011706745,
           58.0506256104221,
           57.640240209137474,
           57.22985480785284,
           56.819469406568196,
           56.409084005283574,
           55.99869860399893,
           55.588313202714296,
           55.177927801429654,
           54.76754240014501,
           54.35715699886037,
           53.94677159757575,
           53.53638619629112,
           53.12600079500647,
           52.71561539372183,
           52.30522999243719,
           51.89484459115256,
           51.484459189867934,
           51.07407378858329,
           50.66368838729865,
           50.25330298601403,
           49.842917584729385,
           49.43253218344475,
           49.022146782160114,
           48.61176138087547,
           48.20137597959085,
           47.79099057830621,
           47.38060517702157,
           46.97021977573692,
           46.55983437445231,
           46.14944897316767,
           45.73906357188303,
           45.32867817059839,
           44.918292769313744,
           44.50790736802912,
           44.09752196674449,
           43.687136565459845,
           43.27675116417521,
           42.86636576289057,
           42.45598036160594,
           42.0455949603213,
           41.63520955903667,
           41.224824157752025,
           40.814438756467396,
           40.40405335518276,
           39.993667953898125,
           39.58328255261348,
           39.17289715132884,
           38.83157360285878,
           38.55931190720325,
           38.28705021154773,
           38.01478851589215,
           37.74252682023662,
           37.47026512458103,
           37.19800342892551,
           36.92574173326998,
           36.653480037614386,
           36.38121834195888,
           36.10895664630335,
           35.83669495064769,
           35.566586247418655,
           35.302123169596754,
           35.03766009177484,
           34.77319701395305,
           34.50873393613121,
           34.24427085830929,
           33.97980778048739,
           33.715344702665604,
           33.45088162484369,
           33.18641854702177,
           32.92195546919994,
           32.657492391378085,
           32.39302931355618,
           32.128566235734326,
           31.864103157912428,
           31.59964008009057,
           31.335177002268722,
           31.07071392444682,
           30.81219837509193,
           30.555665338130403,
           30.29913230116885,
           30.042599264207325,
           29.78606622724574,
           29.52953319028423,
           29.273000153322716,
           29.016467116361138,
           28.759934079399617,
           28.503401042438057,
           28.24686800547653,
           27.990334968515015,
           27.7338019315535,
           27.477268894591923,
           27.220735857630395,
           26.969947660553093,
           26.72246274270621,
           26.47497782485933,
           26.227492907012458,
           25.98000798916554,
           25.73252307131861,
           25.485038153471745,
           25.237553235624873,
           24.99006831777794,
           24.74258339993106,
           24.495098482084202,
           24.247613564237323,
           24.000128646390348,
           23.75730325545103,
           23.519831362695847,
           23.282359469940648,
           23.044887577185506,
           22.807415684430406,
           22.56994379167521,
           22.332471898920023,
           22.09500000616488,
           21.85752811340972,
           21.620056220654526,
           21.382584327899394,
           21.145112435144195,
           20.916872155170694,
           20.689791869992295,
           20.462711584813892,
           20.235631299635443,
           20.008551014457044,
           19.781470729278603,
           19.554390444100186,
           19.327310158921787,
           19.10022987374339,
           18.873149588564935,
           18.65182466309206,
           18.43385702756036,
           18.215889392028622,
           17.99792175649694,
           17.7799541209652,
           17.56198648543346,
           17.34401884990174,
           17.12605121437004,
           16.9080835788383,
           16.694587557733374,
           16.485910085372034,
           16.27723261301075,
           16.06855514064944,
           15.859877668288098,
           15.6512001959268,
           15.442522723565501,
           15.233845251204192,
           15.028397399158596,
           14.831783511266316,
           14.635169623374026,
           14.438555735481719,
           14.241941847589441,
           14.045327959697122,
           13.848714071804833,
           13.652100183912527,
           13.466715984501057,
           13.283252655362489,
           13.09978932622391,
           12.916325997085353,
           12.732862667946785,
           12.54939933880823,
           12.36748752892586,
           12.196091564371851,
           12.02469559981781,
           11.853299635263824,
           11.681903670709785,
           11.510507706155774,
           11.339111741601773,
           11.178711902175294,
           11.018312062946915,
           10.85791222371857,
           10.6975123844902,
           10.537112545261841,
           10.380650842383751,
           10.230293253387213,
           10.079935664390625,
           9.929578075394037,
           9.779220486397477,
           9.631074127595369,
           9.489877346230942,
           9.348680564866545,
           9.207483783502147,
           9.06628700213772,
           8.929228005480223,
           8.796407714988879,
           8.663587424497509,
           8.530767134006156,
           8.398763043691108,
           8.27376467594005,
           8.148766308188993,
           8.023767940437972,
           7.8990750667638,
           7.783190582665916,
           7.667306098568055,
           7.551421614470179,
           7.437990917975348,
           7.332001598205772,
           7.226012278436196,
           7.120022958666611,
           7.019066591506286,
           6.920079640891039,
           6.821092690275766,
           6.724278555239389,
           6.63045692166509,
           6.53663528809078,
           6.444994452891635,
           6.3577472843687985,
           6.2705001158459615,
           6.186253318609224,
           6.1059414347424585,
           6.0256295508757205,
           5.949664032442194,
           5.875504796207865,
           5.8020975431160675,
           5.733384118771626,
           5.664670694427173,
           5.586147484234954,
           5.503700359703592,
           5.421253235172232,
           5.338806110640872,
           5.256358986109529,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           68.01642648716162,
           68.05890402617038,
           68.10138156517914,
           68.1438591041879,
           68.18633664319665,
           68.22881418220541,
           68.27129172121417,
           68.31376926022293,
           68.35624679923168,
           68.39872433824046,
           68.4412018772492,
           68.48367941625796,
           68.52615695526671,
           68.56863449427549,
           68.61111203328424,
           68.65358957229299,
           68.69606711130176,
           68.73854465031052,
           68.78102218931927,
           68.82349972832803,
           68.86597726733677,
           68.90845480634555,
           68.9509323453543,
           68.99446117789823,
           69.03799001093238,
           69.08151884396653,
           69.12504767700068,
           69.16857651003484,
           69.21210534306898,
           69.25563417610313,
           69.29916300913729,
           69.34269184217143,
           69.38622067520558,
           69.42974950823972,
           69.47327834127388,
           69.51680717430803,
           69.56033600734219,
           69.60386484037633,
           69.64739367341048,
           69.69092250644462,
           69.73445133947878,
           69.77798017251293,
           69.82150900554709,
           69.86503783858123,
           69.90856667161538,
           69.95209550464953,
           69.99562433768368,
           70.03915317071784,
           70.08268200375198,
           70.12621083678613,
           70.16973966982027,
           70.21326850285443,
           70.25679733588858,
           70.30032616892274,
           70.34385500195688,
           70.38738383499103,
           70.43091266802517,
           70.47444150105933,
           70.51797033409348,
           70.56149916712764,
           70.60502800016178,
           70.64855683319593,
           70.69208566623008,
           70.73561449926423,
           70.77914333229839,
           70.82267216533253,
           70.86620099836668,
           70.90972983140082,
           70.95325866443498,
           70.99678749746914,
           71.04031633050329,
           71.08384516353743,
           71.12737399657158,
           71.17090282960574,
           71.21443166263988,
           71.25796049567404,
           71.30148932870819,
           71.34501816174233,
           71.38854699477648,
           71.43207582781064,
           71.47560466084478,
           71.51913349387893,
           71.56266232691308,
           71.60619115994723,
           71.63024192985347,
           71.65039708713411,
           71.67055224441476,
           71.69070740169542,
           71.71086255897607,
           71.73101771625673,
           71.75117287353737,
           71.77132803081801,
           71.79148318809867,
           71.81163834537932,
           71.83179350265998,
           71.85194865994063,
           71.87210381722127,
           71.89225897450193,
           71.91241413178258,
           71.93256928906322,
           71.9527244463439,
           71.97287960362453,
           71.99303476090518,
           72.01318991818584,
           72.03334507546649,
           72.05350023274713,
           72.0736553900278,
           72.09381054730844,
           72.11396570458909,
           72.13412086186973,
           72.15427601915039,
           72.17443117643104,
           72.1945863337117,
           72.21474149099234,
           72.234896648273,
           72.25505180555365,
           72.27520696283429,
           72.29536212011494,
           72.3155172773956,
           72.33567243467624,
           72.3558275919569,
           72.37598274923755,
           72.3961379065182,
           72.41629306379886,
           72.4364482210795,
           72.45660337836017,
           72.4767585356408,
           72.49691369292147,
           72.51706885020212,
           72.53722400748276,
           72.55737916476342,
           72.57753432204407,
           72.59768947932471,
           72.61784463660537,
           72.63799979388602,
           72.65815495116667,
           72.67831010844732,
           72.69846526572798,
           72.71862042300862,
           72.73877558028927,
           72.75893073756993,
           72.77908589485057,
           72.79924105213122,
           72.81939620941186,
           72.83955136669252,
           72.85809472092603,
           72.87583217532705,
           72.89356962972806,
           72.91130708412909,
           72.92904453853009,
           72.94678199293111,
           72.96451944733212,
           72.98225690173312,
           72.99999435613415,
           73.01773181053515,
           73.03546926493617,
           73.05320671933718,
           73.0709441737382,
           73.08868162813921,
           73.10641908254023,
           73.12415653694124,
           73.14189399134226,
           73.15963144574327,
           73.17736890014429,
           73.1951063545453,
           73.21284380894632,
           73.23058126334732,
           72.94882869486477,
           72.51733111494049,
           72.08583353501618,
           71.65433595509188,
           71.22283837516758,
           70.79134079524324,
           70.35984321531896,
           69.92834563539466,
           69.49684805547037,
           69.06535047554607,
           68.63385289562173,
           68.20235531569745,
           67.77085773577315,
           67.33936015584882,
           66.90786257592454,
           66.47636499600023,
           66.04486741607593,
           65.61336983615162,
           65.18187225622731,
           64.75037467630303,
           64.31887709637871,
           63.88737951645441,
           63.455881936530126,
           63.02438435660579,
           62.5928867766815,
           62.16138919675719,
           61.72989161683289,
           61.298394036908604,
           60.866896456984264,
           60.43539887705998,
           60.00390129713567,
           59.57240371721137,
           59.14090613728708,
           58.70940855736278,
           58.27791097743847,
           57.846413397514155,
           57.41491581758984,
           56.98732787855809,
           56.576942477273455,
           56.16655707598881,
           55.7561716747042,
           55.34578627341955,
           54.93540087213492,
           54.52501547085028,
           54.114630069565635,
           53.70424466828099,
           53.293859266996364,
           52.883473865711736,
           52.47308846442709,
           52.06270306314245,
           51.65231766185781,
           51.24193226057319,
           50.83154685928855,
           50.42116145800391,
           50.01077605671927,
           49.60039065543465,
           49.19000525415001,
           48.77961985286537,
           48.36923445158072,
           47.958849050296095,
           47.54846364901147,
           47.138078247726824,
           46.72769284644219,
           46.317307445157546,
           45.906922043872925,
           45.49653664258828,
           45.08615124130364,
           44.67576584001901,
           44.26538043873437,
           43.85499503744975,
           43.444609636165104,
           43.03422423488047,
           42.623838833595826,
           42.213453432311184,
           41.80306803102656,
           41.39268262974193,
           40.982297228457284,
           40.57191182717264,
           40.16152642588802,
           39.751141024603385,
           39.34075562331874,
           38.9303702220341,
           38.519984820749464,
           38.178661272279406,
           37.90639957662387,
           37.63413788096835,
           37.36187618531277,
           37.089614489657244,
           36.81735279400166,
           36.545091098346134,
           36.27282940269061,
           36.00784003754411,
           35.743376959722276,
           35.47891388190037,
           35.21445080407851,
           34.949987726256666,
           34.685524648434765,
           34.42106157061285,
           34.15659849279106,
           33.89213541496922,
           33.6276723371473,
           33.3632092593254,
           33.098746181503614,
           32.8342831036817,
           32.569820025859784,
           32.305356948037954,
           32.040893870216095,
           31.776430792394184,
           31.512463339905025,
           31.255930302943508,
           30.999397265981983,
           30.74286422902047,
           30.48633119205895,
           30.229798155097377,
           29.973265118135846,
           29.716732081174296,
           29.460199044212768,
           29.203666007251186,
           28.947132970289676,
           28.69059993332816,
           28.434066896366584,
           28.177533859405063,
           27.9210008224435,
           27.664467785481975,
           27.413823209389175,
           27.166338291542303,
           26.918853373695377,
           26.671368455848448,
           26.42388353800159,
           26.17639862015471,
           25.928913702307828,
           25.681428784460955,
           25.43394386661404,
           25.18645894876711,
           24.938974030920242,
           24.69148911307337,
           24.44400419522644,
           24.198749902168313,
           23.961278009413178,
           23.723806116657983,
           23.486334223902826,
           23.24886233114768,
           23.011390438392496,
           22.773918545637297,
           22.53644665288216,
           22.298974760127056,
           22.06150286737186,
           21.824030974616672,
           21.58655908186153,
           21.35343716295258,
           21.12635687777413,
           20.899276592595744,
           20.672196307417288,
           20.445116022238874,
           20.21803573706048,
           19.990955451882073,
           19.76387516670362,
           19.536794881525225,
           19.309714596346783,
           19.08263431116837,
           18.864306967856084,
           18.646339332324345,
           18.428371696792592,
           18.210404061260878,
           17.992436425729174,
           17.774468790197435,
           17.556501154665753,
           17.338533519134014,
           17.120565883602275,
           16.908457604725815,
           16.699780132364484,
           16.49110266000319,
           16.282425187641877,
           16.073747715280536,
           15.865070242919252,
           15.65639277055794,
           15.4477152981966,
           15.24212496285571,
           15.045511074963436,
           14.848897187071113,
           14.652283299178837,
           14.455669411286559,
           14.259055523394268,
           14.062441635501964,
           13.865827747609686,
           13.678374920936486,
           13.49491159179789,
           13.311448262659335,
           13.12798493352078,
           12.944521604382212,
           12.76105827524363,
           12.577594946105075,
           12.40425958464258,
           12.232863620088553,
           12.06146765553455,
           11.890071690980541,
           11.718675726426502,
           11.547279761872513,
           11.382376389885554,
           11.221976550657173,
           11.061576711428827,
           10.90117687220048,
           10.740777032972101,
           10.580377193743756,
           10.428739709094753,
           10.278382120098163,
           10.128024531101584,
           9.977666942105046,
           9.827309353108458,
           9.682637783423225,
           9.541441002058807,
           9.40024422069441,
           9.259047439329983,
           9.117850657965585,
           8.983188548757855,
           8.850368258266485,
           8.717547967775142,
           8.584727677283798,
           8.454287971507815,
           8.329289603756742,
           8.204291236005732,
           8.079292868254672,
           7.955694678945023,
           7.839810194847147,
           7.7239257107492865,
           7.6080412266514035,
           7.495063947394316,
           7.38907462762474,
           7.283085307855142,
           7.177095988085565,
           7.075975502893881,
           6.976988552278608,
           6.878001601663346,
           6.780732086023471,
           6.686910452449155,
           6.5930888188748495,
           6.500469831562464,
           6.413222663039617,
           6.325975494516765,
           6.240302291214258,
           6.159990407347507,
           6.079678523480759,
           6.002118396824167,
           5.927959160589856,
           5.853799924355535,
           5.784152585935667,
           5.715439161591226,
           5.641820844322892,
           5.55937371979153,
           5.4769265952601875,
           5.394479470728826,
           5.312032346197466,
           5.229585221666106,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           68.01423938733488,
           68.05671692634364,
           68.0991944653524,
           68.14167200436115,
           68.18414954336991,
           68.22662708237867,
           68.26910462138743,
           68.31158216039618,
           68.35405969940494,
           68.3965372384137,
           68.43901477742246,
           68.48149231643121,
           68.52396985543997,
           68.56644739444874,
           68.6089249334575,
           68.65140247246624,
           68.693880011475,
           68.73635755048377,
           68.77883508949252,
           68.82131262850127,
           68.86379016751005,
           68.9062677065188,
           68.94874524552756,
           68.9912227845363,
           69.03370032354508,
           69.07617786255383,
           69.11865540156258,
           69.16113294057135,
           69.20361047958009,
           69.24608801858886,
           69.28856555759762,
           69.33104309660636,
           69.37352063561514,
           69.41599817462388,
           69.45847571363265,
           69.50095325264141,
           69.54343079165017,
           69.58590833065892,
           69.62838586966767,
           69.6713890557721,
           69.71491788880626,
           69.7584467218404,
           69.80197555487455,
           69.8455043879087,
           69.88903322094286,
           69.93256205397701,
           69.97609088701115,
           70.0196197200453,
           70.06314855307946,
           70.1066773861136,
           70.15020621914775,
           70.19373505218189,
           70.23726388521605,
           70.2807927182502,
           70.32432155128436,
           70.3678503843185,
           70.41137921735266,
           70.4549080503868,
           70.49843688342095,
           70.54196571645511,
           70.58549454948925,
           70.62902338252341,
           70.67255221555756,
           70.7160810485917,
           70.75960988162586,
           70.80313871466001,
           70.84666754769415,
           70.89019638072831,
           70.93372521376246,
           70.9772540467966,
           71.02078287983076,
           71.0643117128649,
           71.10784054589905,
           71.15136937893321,
           71.19489821196736,
           71.23842704500152,
           71.28195587803566,
           71.3254847110698,
           71.36901354410395,
           71.41254237713811,
           71.45607121017227,
           71.49960004320641,
           71.54312887624056,
           71.5866577092747,
           71.61070847918093,
           71.63086363646158,
           71.65101879374222,
           71.6711739510229,
           71.69132910830353,
           71.71148426558419,
           71.73163942286484,
           71.75179458014549,
           71.77194973742614,
           71.7921048947068,
           71.81226005198745,
           71.83241520926809,
           71.85257036654875,
           71.87272552382939,
           71.89288068111006,
           71.9130358383907,
           71.93319099567135,
           71.95334615295201,
           71.97350131023265,
           71.9936564675133,
           72.01381162479396,
           72.0339667820746,
           72.05412193935526,
           72.07427709663591,
           72.09443225391657,
           72.1145874111972,
           72.13474256847786,
           72.15489772575852,
           72.17505288303917,
           72.19520804031981,
           72.21536319760047,
           72.23551835488112,
           72.25567351216176,
           72.27582866944242,
           72.29598382672307,
           72.31613898400371,
           72.33629414128438,
           72.35644929856501,
           72.37660445584567,
           72.39675961312633,
           72.41691477040698,
           72.43706992768763,
           72.45722508496827,
           72.47738024224893,
           72.49713244924042,
           72.51486990364144,
           72.53260735804245,
           72.55034481244347,
           72.56808226684448,
           72.5858197212455,
           72.6035571756465,
           72.62129463004752,
           72.63903208444853,
           72.65676953884956,
           72.67450699325056,
           72.69224444765158,
           72.70998190205259,
           72.7277193564536,
           72.74545681085462,
           72.76319426525563,
           72.78093171965665,
           72.79866917405765,
           72.81640662845868,
           72.83414408285968,
           72.85188153726071,
           72.86961899166171,
           72.88735644606274,
           72.90509390046375,
           72.92283135486475,
           72.94056880926576,
           72.95830626366677,
           72.97604371806779,
           72.99378117246881,
           73.01151862686982,
           73.02925608127083,
           73.04699353567185,
           73.06473099007286,
           73.08246844447388,
           73.10020589887489,
           73.1179433532759,
           73.13568080767692,
           73.15341826207793,
           73.17115571647895,
           72.88940314799639,
           72.4579055680721,
           72.02640798814781,
           71.59491040822351,
           71.16341282829922,
           70.73191524837488,
           70.30041766845059,
           69.8689200885263,
           69.43742250860198,
           69.0059249286777,
           68.57442734875336,
           68.14292976882908,
           67.71143218890477,
           67.27993460898045,
           66.84843702905617,
           66.41693944913187,
           65.98544186920756,
           65.55394428928324,
           65.12244670935894,
           64.69094912943466,
           64.25945154951035,
           63.827953969586034,
           63.39645638966175,
           62.96495880973741,
           62.533461229813135,
           62.101963649888816,
           61.670466069964505,
           61.23896849004022,
           60.807470910115896,
           60.375973330191606,
           59.9444757502673,
           59.51297817034299,
           59.0814805904187,
           58.649983010494395,
           58.21848543057009,
           57.78698785064578,
           57.355490270721475,
           56.923992690797185,
           56.49249511087287,
           56.060997530948576,
           55.62949995102427,
           55.198002371099975,
           54.76650479117566,
           54.33500721125136,
           53.90350963132705,
           53.47201205140274,
           53.04051447147845,
           52.60901689155415,
           52.17751931162984,
           51.746021731705525,
           51.314524151781214,
           50.88302657185693,
           50.45152899193262,
           50.02003141200831,
           49.58853383208401,
           49.15703625215971,
           48.725538672235416,
           48.294041092311105,
           47.86254351238679,
           47.43104593246249,
           46.9995483525382,
           46.56805077261389,
           46.136553192689576,
           45.705055612765264,
           45.27355803284098,
           44.843624312008885,
           44.43323891072424,
           44.0228535094396,
           43.61246810815496,
           43.20208270687034,
           42.7916973055857,
           42.38131190430106,
           41.970926503016415,
           41.56054110173178,
           41.15015570044716,
           40.739770299162515,
           40.32938489787787,
           39.91899949659324,
           39.508614095308616,
           39.09822869402397,
           38.68784329273933,
           38.277457891454695,
           37.86707249017006,
           37.525748941699995,
           37.253487246044465,
           36.98122555038895,
           36.71355690549147,
           36.44909382766962,
           36.18463074984771,
           35.92016767202587,
           35.65570459420402,
           35.391241516382095,
           35.126778438560265,
           34.86231536073836,
           34.5978522829165,
           34.33338920509465,
           34.06892612727275,
           33.80446304945084,
           33.539999971629044,
           33.27553689380721,
           33.011073815985284,
           32.74661073816339,
           32.4821476603416,
           32.21768458251969,
           31.956195267756613,
           31.699662230795116,
           31.443129193833535,
           31.186596156872007,
           30.930063119910443,
           30.673530082948925,
           30.4169970459874,
           30.160464009025887,
           29.903930972064373,
           29.6473979351028,
           29.390864898141267,
           29.134331861179714,
           28.87779882421819,
           28.62126578725661,
           28.364732750295094,
           28.108199713333576,
           27.857698758225194,
           27.61021384037832,
           27.362728922531456,
           27.115244004684524,
           26.86775908683765,
           26.620274168990786,
           26.372789251143857,
           26.125304333296924,
           25.877819415450066,
           25.630334497603183,
           25.382849579756304,
           25.135364661909435,
           24.887879744062513,
           24.640394826215587,
           24.402724656130438,
           24.165252763375296,
           23.92778087062014,
           23.690308977864944,
           23.45283708510981,
           23.21536519235461,
           22.977893299599454,
           22.740421406844312,
           22.502949514089128,
           22.26547762133393,
           22.02800572857879,
           21.790533835823688,
           21.562921885555998,
           21.335841600377556,
           21.108761315199157,
           20.88168103002074,
           20.654600744842288,
           20.4275204596639,
           20.20044017448545,
           19.973359889307034,
           19.746279604128635,
           19.519199318950232,
           19.294756908151744,
           19.07678927262004,
           18.8588216370883,
           18.640854001556548,
           18.42288636602488,
           18.20491873049314,
           17.986951094961384,
           17.768983459429673,
           17.55101582389797,
           17.33304818836623,
           17.12232765171824,
           16.913650179356907,
           16.704972706995612,
           16.4962952346343,
           16.287617762272973,
           16.078940289911674,
           15.870262817550364,
           15.661585345189021,
           15.455852526552825,
           15.259238638660534,
           15.062624750768217,
           14.866010862875939,
           14.669396974983663,
           14.472783087091342,
           14.276169199199067,
           14.079555311306788,
           13.890033857371897,
           13.706570528233343,
           13.523107199094786,
           13.339643869956191,
           13.156180540817596,
           12.972717211679043,
           12.789253882540487,
           12.612427604913295,
           12.441031640359295,
           12.26963567580527,
           12.098239711251258,
           11.926843746697232,
           11.755447782143229,
           11.5860408775958,
           11.425641038367443,
           11.265241199139085,
           11.10484135991073,
           10.94444152068235,
           10.784041681454003,
           10.62718616480228,
           10.47682857580569,
           10.326470986809111,
           10.176113397812571,
           10.025755808815983,
           9.875398220615487,
           9.73420143925109,
           9.593004657886663,
           9.451807876522256,
           9.310611095157839,
           9.169969382526823,
           9.037149092035452,
           8.904328801544109,
           8.771508511052765,
           8.638688220561395,
           8.509812899324508,
           8.384814531573475,
           8.25981616382243,
           8.134817796071358,
           8.01231429112624,
           7.896429807028371,
           7.780545322930502,
           7.664660838832627,
           7.5521369768132764,
           7.446147657043681,
           7.340158337274104,
           7.234169017504526,
           7.132884414281456,
           7.0338974636661895,
           6.934910513050935,
           6.8371856168075364,
           6.74336398323322,
           6.649542349658926,
           6.5559452102332685,
           6.468698041710416,
           6.381450873187589,
           6.294351263819279,
           6.21403937995253,
           6.133727496085788,
           6.054572761206153,
           5.980413524971824,
           5.906254288737503,
           5.8349210530997215,
           5.766207628755268,
           5.697494204410821,
           5.6150470798794725,
           5.532599955348123,
           5.45015283081676,
           5.3677057062854185,
           5.285258581754057,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           68.01205228750814,
           68.0545298265169,
           68.09700736552566,
           68.13948490453441,
           68.18196244354317,
           68.22443998255193,
           68.26691752156069,
           68.30939506056944,
           68.3518725995782,
           68.39435013858696,
           68.43682767759572,
           68.47930521660447,
           68.52178275561323,
           68.56426029462199,
           68.60673783363075,
           68.6492153726395,
           68.69169291164826,
           68.73417045065702,
           68.77664798966578,
           68.81912552867453,
           68.86160306768329,
           68.90408060669205,
           68.9465581457008,
           68.98903568470956,
           69.03151322371832,
           69.07399076272708,
           69.11646830173584,
           69.1589458407446,
           69.20142337975335,
           69.24390091876211,
           69.28637845777088,
           69.32885599677962,
           69.3713335357884,
           69.41381107479714,
           69.45628861380591,
           69.49876615281467,
           69.54124369182341,
           69.58372123083218,
           69.62619876984093,
           69.6686763088497,
           69.71115384785845,
           69.75363138686721,
           69.79610892587597,
           69.83858646488473,
           69.88106400389348,
           69.92354154290224,
           69.966019081911,
           70.00849662091976,
           70.05097415992851,
           70.09345169893727,
           70.13592923794603,
           70.17840677695479,
           70.22088431596354,
           70.2633618549723,
           70.30583939398107,
           70.34831693364598,
           70.39184576668012,
           70.43537459971427,
           70.47890343274842,
           70.52243226578257,
           70.56596109881671,
           70.60948993185087,
           70.65301876488502,
           70.69654759791916,
           70.74007643095332,
           70.78360526398747,
           70.82713409702163,
           70.87066293005577,
           70.91419176308992,
           70.95772059612406,
           71.00124942915822,
           71.04477826219237,
           71.08830709522653,
           71.13183592826067,
           71.17536476129482,
           71.21889359432896,
           71.26242242736312,
           71.30595126039726,
           71.34948009343142,
           71.39300892646557,
           71.43653775949973,
           71.48006659253387,
           71.52359542556802,
           71.56712425860218,
           71.5911750285084,
           71.61133018578906,
           71.6314853430697,
           71.65164050035035,
           71.67179565763101,
           71.69195081491165,
           71.7121059721923,
           71.73226112947296,
           71.7524162867536,
           71.77257144403426,
           71.79272660131491,
           71.81288175859557,
           71.83303691587622,
           71.85319207315686,
           71.87334723043753,
           71.89350238771817,
           71.91365754499883,
           71.93381270227948,
           71.95396785956012,
           71.97412301684078,
           71.99427817412143,
           72.01443333140207,
           72.03458848868273,
           72.05474364596337,
           72.07489880324403,
           72.09505396052468,
           72.11520911780534,
           72.13536427508598,
           72.15390763195583,
           72.17164508635686,
           72.18938254075786,
           72.20711999515888,
           72.22485744955988,
           72.2425949039609,
           72.26033235836191,
           72.27806981276294,
           72.29580726716395,
           72.31354472156497,
           72.33128217596597,
           72.34901963036698,
           72.366757084768,
           72.38449453916901,
           72.40223199357003,
           72.41996944797104,
           72.43770690237206,
           72.45544435677307,
           72.47318181117409,
           72.4909192655751,
           72.50865671997612,
           72.52639417437712,
           72.54413162877813,
           72.56186908317915,
           72.57960653758016,
           72.59734399198118,
           72.61508144638219,
           72.6328189007832,
           72.65055635518422,
           72.66829380958524,
           72.68603126398625,
           72.70376871838727,
           72.72150617278828,
           72.7392436271893,
           72.75698108159031,
           72.77471853599133,
           72.79245599039234,
           72.81019344479336,
           72.82793089919437,
           72.84566835359539,
           72.86340580799639,
           72.88114326239739,
           72.8988807167984,
           72.91661817119942,
           72.93435562560043,
           72.95209308000145,
           72.96983053440246,
           72.98756798880348,
           73.00530544320449,
           73.0230428976055,
           73.04078035200652,
           73.05851780640754,
           73.07625526080855,
           73.09399271520957,
           73.11173016961058,
           72.82997760112804,
           72.39848002120374,
           71.96698244127944,
           71.53548486135513,
           71.10398728143083,
           70.6724897015065,
           70.24099212158221,
           69.80949454165793,
           69.37799696173361,
           68.94649938180932,
           68.51500180188499,
           68.08350422196071,
           67.6520066420364,
           67.22050906211209,
           66.7890114821878,
           66.35751390226349,
           65.92601632233918,
           65.49451874241487,
           65.06302116249056,
           64.63152358256627,
           64.20002600264198,
           63.768528422717665,
           63.33703084279338,
           62.90553326286905,
           62.47403568294476,
           62.042538103020455,
           61.61104052309615,
           61.17954294317185,
           60.74804536324753,
           60.31654778332324,
           59.885050203398926,
           59.45355262347462,
           59.02205504355034,
           58.59055746362603,
           58.159059883701715,
           57.72756230377741,
           57.29606472385311,
           56.86456714392881,
           56.433069564004505,
           56.00157198408019,
           55.57007440415592,
           55.138576824231606,
           54.707079244307295,
           54.27558166438298,
           53.84408408445867,
           53.412586504534374,
           52.98108892461008,
           52.54959134468577,
           52.11809376476146,
           51.68659618483716,
           51.255098604912845,
           50.82360102498856,
           50.39210344506425,
           49.96060586513994,
           49.529108285215635,
           49.097610705291345,
           48.66611312536703,
           48.23461554544273,
           47.803117965518425,
           47.37162038559411,
           46.94012280566983,
           46.50862522574552,
           46.07712764582121,
           45.645630065896896,
           45.21413248597261,
           44.7826349060483,
           44.351137326124,
           43.91963974619969,
           43.481535384292314,
           43.03609012721741,
           42.59064487014249,
           42.14519961306757,
           41.699754355992646,
           41.254309098917716,
           40.80886384184281,
           40.36341858476789,
           39.91797332769297,
           39.47252807061804,
           39.027082813543146,
           38.581637556468216,
           38.136192299393294,
           37.690747042318364,
           37.24530178524345,
           36.890347617795136,
           36.62588453997322,
           36.36142146215133,
           36.096958384329476,
           35.832495306507624,
           35.56803222868572,
           35.30356915086387,
           35.03910607304203,
           34.774642995220105,
           34.510179917398276,
           34.24571683957636,
           33.9812537617545,
           33.71679068393266,
           33.45232760611076,
           33.18786452828884,
           32.923401450467054,
           32.65893837264521,
           32.39992719560825,
           32.14339415864673,
           31.88686112168517,
           31.630328084723637,
           31.373795047762062,
           31.11726201080056,
           30.86072897383898,
           30.604195936877453,
           30.34766289991589,
           30.091129862954375,
           29.834596825992847,
           29.578063789031333,
           29.32153075206982,
           29.064997715108245,
           28.80846467814671,
           28.55193164118516,
           28.301574307061287,
           28.054089389214404,
           27.806604471367482,
           27.55911955352057,
           27.311634635673688,
           27.06414971782682,
           26.816664799979947,
           26.569179882133017,
           26.321694964286152,
           26.074210046439276,
           25.82672512859235,
           25.57924021074542,
           25.33175529289856,
           25.08427037505168,
           24.844171302847712,
           24.606699410092567,
           24.369227517337425,
           24.131755624582226,
           23.89428373182708,
           23.656811839071942,
           23.41933994631679,
           23.18186805356159,
           22.944396160806455,
           22.70692426805126,
           22.469452375296104,
           22.23198048254096,
           21.99948689333784,
           21.77240660815943,
           21.54532632298103,
           21.318246037802584,
           21.091165752624175,
           20.864085467445733,
           20.637005182267337,
           20.40992489708892,
           20.18284461191047,
           19.95576432673208,
           19.728684041553628,
           19.507239212915714,
           19.28927157738401,
           19.071303941852268,
           18.853336306320557,
           18.63536867078885,
           18.417401035257114,
           18.199433399725358,
           17.98146576419369,
           17.763498128661954,
           17.545530493130197,
           17.336197698710677,
           17.12752022634938,
           16.91884275398808,
           16.71016528162674,
           16.501487809265406,
           16.29281033690411,
           16.0841328645428,
           15.87545539218147,
           15.66958009024997,
           15.472966202357648,
           15.276352314465363,
           15.079738426573066,
           14.883124538680775,
           14.686510650788458,
           14.48989676289618,
           14.293282875003904,
           14.101692793807352,
           13.918229464668766,
           13.734766135530212,
           13.551302806391618,
           13.367839477253064,
           13.184376148114508,
           13.000912818975914,
           12.820595625184025,
           12.649199660629998,
           12.477803696076023,
           12.306407731521984,
           12.135011766967985,
           11.963615802413958,
           11.792219837859946,
           11.62930552607771,
           11.468905686849364,
           11.308505847620983,
           11.148106008392629,
           10.98770616916427,
           10.827306329935915,
           10.675275031513227,
           10.524917442516648,
           10.374559853520111,
           10.224202264523521,
           10.073844675526942,
           9.92696187644335,
           9.785765095078924,
           9.644568313714526,
           9.503371532350128,
           9.362174750985702,
           9.22392992580443,
           9.091109635313087,
           8.958289344821742,
           8.825469054330373,
           8.692648763839028,
           8.565337827141224,
           8.440339459390167,
           8.31534109163913,
           8.190342723888097,
           8.068933903307464,
           7.953049419209595,
           7.837164935111726,
           7.721280451013858,
           7.609210006232236,
           7.5032206864626465,
           7.3972313666930685,
           7.291242046923473,
           7.189793325669029,
           7.090806375053763,
           6.991819424438514,
           6.8936391475916015,
           6.7998175140173025,
           6.705995880442996,
           6.61217424686868,
           6.524173420381249,
           6.436926251858397,
           6.349679083335545,
           6.268088352557555,
           6.187776468690812,
           6.107464584824063,
           6.03286788935381,
           5.958708653119492,
           5.885689520263769,
           5.8169760959193155,
           5.748262671574878,
           5.670720439967422,
           5.588273315436062,
           5.505826190904708,
           5.423379066373359,
           5.340931941841996,
           5.258484817310654,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           68.00986518768138,
           68.05234272669014,
           68.0948202656989,
           68.13729780470766,
           68.17977534371641,
           68.22225288272517,
           68.26473042173393,
           68.30720796074269,
           68.34968549975144,
           68.3921630387602,
           68.43464057776896,
           68.47711811677772,
           68.51959565578647,
           68.56207319479523,
           68.60455073380399,
           68.64702827281275,
           68.6895058118215,
           68.73198335083026,
           68.77446088983902,
           68.81693842884778,
           68.85941596785653,
           68.90189350686529,
           68.94437104587405,
           68.98684858488282,
           69.02932612389156,
           69.07180366290032,
           69.1142812019091,
           69.15675874091784,
           69.19923627992661,
           69.24171381893535,
           69.28419135794411,
           69.32666889695288,
           69.36914643596164,
           69.4116239749704,
           69.45410151397915,
           69.49657905298791,
           69.53905659199667,
           69.58153413100543,
           69.62401167001418,
           69.66648920902294,
           69.7089667480317,
           69.75144428704046,
           69.79392182604921,
           69.83639936505797,
           69.87887690406674,
           69.9213544430755,
           69.96383198208426,
           70.00630952109302,
           70.04878706010177,
           70.09126459911053,
           70.13374213811929,
           70.17621967712805,
           70.2186972161368,
           70.26117475514556,
           70.30365229415432,
           70.34612983316308,
           70.38860737217183,
           70.43108491118059,
           70.47356245018935,
           70.5160399891981,
           70.55851752820686,
           70.60099506721562,
           70.64347260622438,
           70.68595014523314,
           70.7284276842419,
           70.77090522325067,
           70.81338276225941,
           70.85586030126817,
           70.89833784027694,
           70.94081537928568,
           70.98329291829445,
           71.02577045730321,
           71.06877364455397,
           71.11230247758814,
           71.15583131062229,
           71.19936014365643,
           71.2428889766906,
           71.28641780972474,
           71.32994664275888,
           71.37347547579304,
           71.41700430882719,
           71.46053314186133,
           71.50406197489548,
           71.54759080792964,
           71.57164157783586,
           71.59179673511652,
           71.61195189239717,
           71.63210704967781,
           71.65226220695847,
           71.67241736423912,
           71.69257252151976,
           71.71272767880042,
           71.73288283608107,
           71.75303799336173,
           71.77319315064238,
           71.79294536027022,
           71.81068281467124,
           71.82842026907227,
           71.84615772347327,
           71.86389517787428,
           71.88163263227528,
           71.89937008667631,
           71.91710754107733,
           71.93484499547834,
           71.95258244987934,
           71.97031990428036,
           71.98805735868137,
           72.00579481308239,
           72.0235322674834,
           72.04126972188442,
           72.05900717628543,
           72.07674463068645,
           72.09448208508746,
           72.11221953948848,
           72.1299569938895,
           72.14769444829051,
           72.16543190269152,
           72.18316935709254,
           72.20090681149355,
           72.21864426589455,
           72.23638172029557,
           72.25411917469658,
           72.2718566290976,
           72.28959408349861,
           72.30733153789963,
           72.32506899230064,
           72.34280644670166,
           72.36054390110267,
           72.37828135550367,
           72.39601880990469,
           72.41375626430572,
           72.43149371870673,
           72.44923117310773,
           72.46696862750875,
           72.48470608190976,
           72.50244353631078,
           72.5201809907118,
           72.53791844511281,
           72.55565589951382,
           72.57339335391484,
           72.59113080831585,
           72.60886826271687,
           72.62660571711788,
           72.6443431715189,
           72.66208062591991,
           72.67981808032091,
           72.69755553472193,
           72.71529298912294,
           72.73303044352397,
           72.75076789792497,
           72.768505352326,
           72.786242806727,
           72.803980261128,
           72.82171771552902,
           72.83945516993003,
           72.85719262433105,
           72.87493007873206,
           72.89266753313308,
           72.9104049875341,
           72.92814244193511,
           72.94587989633611,
           72.96361735073714,
           72.98135480513814,
           72.99909225953917,
           73.01682971394018,
           73.03456716834118,
           73.0523046227422,
           72.77055205425965,
           72.33905447433537,
           71.90755689441107,
           71.47605931448676,
           71.04456173456246,
           70.61306415463814,
           70.18156657471384,
           69.75006899478956,
           69.31857141486525,
           68.88707383494095,
           68.45557625501662,
           68.02407867509234,
           67.59258109516803,
           67.16108351524372,
           66.72958593531942,
           66.29808835539512,
           65.86659077547081,
           65.4350931955465,
           65.00359561562219,
           64.5720980356979,
           64.1406004557736,
           63.70910287584929,
           63.277605295925,
           62.846107716000674,
           62.41461013607639,
           61.98311255615208,
           61.551614976227775,
           61.12011739630348,
           60.68274714612709,
           60.2373018890522,
           59.791856631977275,
           59.346411374902345,
           58.900966117827444,
           58.45552086075252,
           58.0100756036776,
           57.56463034660268,
           57.11918508952775,
           56.673739832452846,
           56.228294575377916,
           55.78284931830299,
           55.3374040612281,
           54.89195880415317,
           54.44651354707825,
           54.001068290003325,
           53.555623032928395,
           53.11017777585347,
           52.66473251877857,
           52.21928726170364,
           51.77384200462872,
           51.328396747553796,
           50.882951490478874,
           50.43750623340398,
           49.99206097632905,
           49.54661571925412,
           49.1011704621792,
           48.6557252051043,
           48.21027994802937,
           47.764834690954444,
           47.31938943387952,
           46.8739441768046,
           46.4284989197297,
           45.983053662654775,
           45.537608405579846,
           45.09216314850492,
           44.646717891430015,
           44.2012726343551,
           43.75582737728018,
           43.31038212020525,
           42.864936863130325,
           42.41949160605542,
           41.97404634898051,
           41.52860109190558,
           41.08315583483065,
           40.637710577755726,
           40.192265320680825,
           39.7468200636059,
           39.30137480653098,
           38.85592954945605,
           38.41048429238115,
           37.965039035306226,
           37.5195937782313,
           37.07414852115638,
           36.62870326408145,
           36.27374909663315,
           36.00928601881123,
           35.74482294098934,
           35.480359863167486,
           35.215896785345635,
           34.951433707523734,
           34.68697062970189,
           34.42250755188004,
           34.158044474058116,
           33.893581396236286,
           33.62911831841437,
           33.36465524059251,
           33.10019216277067,
           32.84365912345988,
           32.587126086498294,
           32.33059304953678,
           32.074060012575266,
           31.81752697561369,
           31.560993938652175,
           31.30446090169061,
           31.04792786472908,
           30.7913948277675,
           30.534861790806,
           30.278328753844423,
           30.021795716882895,
           29.765262679921328,
           29.508729642959818,
           29.25219660599829,
           28.995663569036775,
           28.745449855897334,
           28.497964938050455,
           28.250480020203522,
           28.002995102356664,
           27.75551018450978,
           27.508025266662898,
           27.260540348815983,
           27.013055430969068,
           26.76557051312219,
           26.518085595275313,
           26.270600677428448,
           26.023115759581515,
           25.775630841734646,
           25.528145923887774,
           25.285617949565047,
           25.048146056809887,
           24.81067416405476,
           24.57320227129956,
           24.335730378544362,
           24.09825848578922,
           23.860786593034074,
           23.623314700278875,
           23.385842807523737,
           23.148370914768595,
           22.91089902201344,
           22.673427129258236,
           22.436051901119722,
           22.208971615941312,
           21.98189133076286,
           21.754811045584418,
           21.52773076040602,
           21.300650475227602,
           21.073570190049207,
           20.84648990487076,
           20.61940961969235,
           20.392329334513914,
           20.165249049335515,
           19.938168764157098,
           19.719721517679687,
           19.501753882147995,
           19.28378624661624,
           19.065818611084527,
           18.847850975552824,
           18.62988334002108,
           18.411915704489367,
           18.193948068957663,
           17.975980433425924,
           17.75874521806446,
           17.550067745703128,
           17.34139027334183,
           17.13271280098052,
           16.92403532861918,
           16.71535785625788,
           16.50668038389658,
           16.298002911535242,
           16.08932543917391,
           15.883307653947085,
           15.686693766054765,
           15.49007987816249,
           15.293465990270214,
           15.096852102377893,
           14.900238214485604,
           14.703624326593308,
           14.507010438701018,
           14.313351730242777,
           14.12988840110422,
           13.946425071965638,
           13.762961742827072,
           13.579498413688487,
           13.396035084549931,
           13.212571755411336,
           13.029108426272783,
           12.857367680900763,
           12.685971716346726,
           12.514575751792714,
           12.34317978723869,
           12.171783822684713,
           12.000387858130674,
           11.832970013787946,
           11.672570174559599,
           11.51217033533122,
           11.351770496102896,
           11.19137065687455,
           11.030970817646171,
           10.873721487220765,
           10.723363898224214,
           10.573006309227647,
           10.42264872023106,
           10.272291131234478,
           10.12193354223794,
           9.978525532271206,
           9.837328750906789,
           9.69613196954239,
           9.554935188177964,
           9.413738406813565,
           9.27789046908207,
           9.1450701785907,
           9.012249888099348,
           8.879429597608004,
           8.746609307116659,
           8.620862754957916,
           8.495864387206879,
           8.370866019455844,
           8.245867651704787,
           8.125553515488694,
           8.009669031390832,
           7.893784547292949,
           7.77790006319508,
           7.6662830356511975,
           7.560293715881613,
           7.45430439611203,
           7.348315076342439,
           7.246702237056617,
           7.147715286441343,
           7.048728335826089,
           6.950092678375677,
           6.85627104480136,
           6.7624494112270614,
           6.668627777652762,
           6.579648799052053,
           6.49240163052921,
           6.405154462006379,
           6.322137325162588,
           6.24182544129584,
           6.161513557429089,
           6.085322253735793,
           6.011163017501472,
           5.937003781267149,
           5.867744563083373,
           5.799031138738926,
           5.726393800055363,
           5.6439466755240195,
           5.561499550992659,
           5.479052426461299,
           5.396605301929945,
           5.314158177398596,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           68.0034339954565,
           68.04591153446526,
           68.08838907347402,
           68.13086661248278,
           68.17334415149153,
           68.21582169050029,
           68.25829922950905,
           68.3007767685178,
           68.34325430752656,
           68.38573184653532,
           68.42820938554408,
           68.47068692455284,
           68.5131644635616,
           68.55564200257035,
           68.59811954157911,
           68.64059708058787,
           68.68307461959662,
           68.72555215860538,
           68.76802969761414,
           68.8105072366229,
           68.85298477563165,
           68.89546231464041,
           68.93793985364917,
           68.98041739265793,
           69.02289493166668,
           69.06537247067544,
           69.10785000968421,
           69.15032754869296,
           69.19280508770173,
           69.23528262671049,
           69.27776016571924,
           69.320237704728,
           69.36271524373676,
           69.40519278274553,
           69.44767032175427,
           69.49014786076303,
           69.5326253997718,
           69.57510293878055,
           69.61758047778932,
           69.66005801679806,
           69.70253555580682,
           69.74501309481559,
           69.78749063382435,
           69.8299681728331,
           69.87244571184186,
           69.91492325085062,
           69.95740078985938,
           69.99987832886814,
           70.04235586787689,
           70.08483340688565,
           70.12731094589441,
           70.16978848490317,
           70.21226602391192,
           70.25474356292068,
           70.29722110192944,
           70.3396986409382,
           70.38217617994695,
           70.42465371895571,
           70.46713125796447,
           70.50960879697323,
           70.55208633598198,
           70.59456387499074,
           70.6370414139995,
           70.67951895300826,
           70.72199649201701,
           70.76447403102577,
           70.80695157003453,
           70.84942910904329,
           70.89190664805204,
           70.9343841870608,
           70.97686172606956,
           71.01933926507832,
           71.06181680408707,
           71.10429434309583,
           71.14677188210459,
           71.18924942111336,
           71.2317269601221,
           71.27420449913087,
           71.31668203813963,
           71.35834800382268,
           71.39960818009192,
           71.44086835636114,
           71.48212853263037,
           71.5233887088996,
           71.54314297702457,
           71.55859606352068,
           71.57404915001679,
           71.5895022365129,
           71.60495532645047,
           71.62269278085148,
           71.64043023525248,
           71.65816768965351,
           71.67590514405451,
           71.69364259845553,
           71.71138005285654,
           71.72911750725756,
           71.74685496165857,
           71.76459241605959,
           71.7823298704606,
           71.80006732486162,
           71.81780477926263,
           71.83554223366365,
           71.85327968806466,
           71.87101714246567,
           71.88875459686668,
           71.90649205126769,
           71.9242295056687,
           71.94196696006972,
           71.95970441447074,
           71.97744186887175,
           71.99517932327277,
           72.01291677767378,
           72.0306542320748,
           72.04839168647581,
           72.06612914087682,
           72.08386659527783,
           72.10160404967884,
           72.11934150407987,
           72.13707895848088,
           72.15481641288189,
           72.1725538672829,
           72.19029132168392,
           72.20802877608493,
           72.22576623048595,
           72.24350368488696,
           72.26124113928796,
           72.27897859368898,
           72.29671604808999,
           72.31445350249099,
           72.33219095689202,
           72.34992841129304,
           72.36766586569405,
           72.38540332009507,
           72.40314077449607,
           72.4208782288971,
           72.43861568329811,
           72.45635313769912,
           72.47409059210014,
           72.49182804650115,
           72.50956550090217,
           72.52730295530318,
           72.5450404097042,
           72.5627778641052,
           72.58051531850622,
           72.59825277290723,
           72.61599022730825,
           72.63372768170927,
           72.65146513611028,
           72.66920259051129,
           72.6869400449123,
           72.70467749931332,
           72.72241495371432,
           72.74015240811534,
           72.75788986251634,
           72.77562731691737,
           72.79336477131837,
           72.8111022257194,
           72.82883968012041,
           72.84657713452143,
           72.86431458892244,
           72.88205204332345,
           72.89978949772446,
           72.91752695212548,
           72.9352644065265,
           72.9530018609275,
           72.97073931532853,
           72.98847676972953,
           72.68790191315654,
           72.22817090109658,
           71.7684398890366,
           71.30870887697661,
           70.84897786491665,
           70.38924685285666,
           69.9295158407967,
           69.46978482873672,
           69.01005381667673,
           68.55032280461677,
           68.09059179255678,
           67.63871799523875,
           67.19327273816383,
           66.7478274810889,
           66.302382224014,
           65.85693696693907,
           65.41149170986415,
           64.96604645278923,
           64.5206011957143,
           64.07515593863941,
           63.629710681564475,
           63.18426542448955,
           62.73882016741465,
           62.293374910339715,
           61.8479296532648,
           61.40248439618987,
           60.957039139114954,
           60.51159388204005,
           60.06614862496511,
           59.6207033678902,
           59.17525811081528,
           58.729812853740356,
           58.28436759666546,
           57.83892233959053,
           57.39347708251561,
           56.94803182544069,
           56.50258656836576,
           56.05714131129085,
           55.611696054215926,
           55.166250797141004,
           54.7208055400661,
           54.27536028299118,
           53.82991502591625,
           53.384469768841335,
           52.939024511766405,
           52.49357925469148,
           52.04813399761658,
           51.60268874054165,
           51.15724348346673,
           50.71179822639181,
           50.266352969316884,
           49.82090771224198,
           49.37546245516705,
           48.93001719809214,
           48.48457194101721,
           48.039126683942314,
           47.59368142686738,
           47.14823616979246,
           46.70279091271754,
           46.25734565564261,
           45.81190039856771,
           45.366455141492786,
           44.921009884417856,
           44.47556462734293,
           44.03011937026803,
           43.5846741131931,
           43.13922885611819,
           42.69378359904326,
           42.248338341968335,
           41.802893084893434,
           41.35744782781851,
           40.91200257074359,
           40.46655731366866,
           40.021112056593736,
           39.575666799518835,
           39.130221542443905,
           38.68477628536899,
           38.23933102829406,
           37.79388577121916,
           37.34844051414424,
           36.90299525706931,
           36.457549999994384,
           36.01210474291946,
           35.65715057547116,
           35.39268749764924,
           35.12822441982735,
           34.863761342005496,
           34.599298264183645,
           34.334835186361744,
           34.07037210853989,
           33.80590903071805,
           33.54392408827296,
           33.28739105131145,
           33.030858014349874,
           32.774324977388346,
           32.51779194042678,
           32.261258903465325,
           32.00472586650374,
           31.74819282954223,
           31.491659792580712,
           31.235126755619135,
           30.978593718657617,
           30.722060681696053,
           30.465527644734525,
           30.208994607772947,
           29.952461570811447,
           29.69592853384987,
           29.439395496888338,
           29.18932540473342,
           28.94184048688655,
           28.694355569039622,
           28.44687065119275,
           28.199385733345835,
           27.951900815498952,
           27.704415897652023,
           27.45693097980516,
           27.209446061958282,
           26.9619611441114,
           26.71447622626448,
           26.466991308417565,
           26.219506390570686,
           25.972021472723814,
           25.727064596282336,
           25.489592703527222,
           25.252120810772034,
           25.014648918016892,
           24.777177025261697,
           24.539705132506537,
           24.30223323975141,
           24.06476134699621,
           23.82728945424101,
           23.58981756148587,
           23.352345668730724,
           23.11487377597553,
           22.877401883220386,
           22.645536623723157,
           22.418456338544704,
           22.191376053366294,
           21.964295768187906,
           21.737215483009493,
           21.51013519783104,
           21.283054912652602,
           21.0559746274742,
           20.828894342295786,
           20.601814057117387,
           20.374733771938942,
           20.15017145797541,
           19.93220382244367,
           19.714236186911965,
           19.496268551380215,
           19.2783009158485,
           19.060333280316804,
           18.842365644785055,
           18.62439800925334,
           18.406430373721637,
           18.188462738189894,
           17.972615265056863,
           17.763937792695568,
           17.55526032033427,
           17.346582847972957,
           17.13790537561163,
           16.929227903250332,
           16.72055043088902,
           16.51187295852768,
           16.303195486166384,
           16.097035217644173,
           15.900421329751884,
           15.703807441859606,
           15.507193553967328,
           15.310579666075009,
           15.113965778182731,
           14.917351890290456,
           14.720738002398136,
           14.525010666678178,
           14.341547337539632,
           14.158084008401065,
           13.974620679262499,
           13.791157350123942,
           13.60769402098536,
           13.424230691846793,
           13.240767362708208,
           13.065535701171491,
           12.894139736617458,
           12.722743772063454,
           12.551347807509455,
           12.379951842955418,
           12.208555878401405,
           12.03715991384738,
           11.876234662269859,
           11.7158348230415,
           11.555434983813132,
           11.395035144584785,
           11.234635305356406,
           11.074235466128082,
           10.921810353931752,
           10.771452764935185,
           10.621095175938596,
           10.470737586942047,
           10.320379997945478,
           10.17128596946345,
           10.030089188099051,
           9.888892406734634,
           9.747695625370245,
           9.606498844005829,
           9.465302062641431,
           9.331851012359692,
           9.199030721868333,
           9.06621043137699,
           8.933390140885619,
           8.801386050525664,
           8.676387682774632,
           8.551389315023595,
           8.426390947272537,
           8.301392579521501,
           8.182173127669923,
           8.066288643572042,
           7.9504041594741794,
           7.83451967537632,
           7.723356065070159,
           7.6173667453005605,
           7.5113774255309895,
           7.405388105761406,
           7.303611148444185,
           7.204624197828942,
           7.105637247213675,
           7.006650296598402,
           6.9127245755854485,
           6.818902942011139,
           6.72508130843682,
           6.635124177722881,
           6.547877009200034,
           6.460629840677182,
           6.3761862977676085,
           6.29587441390087,
           6.215562530034123,
           6.137776618117774,
           6.063617381883449,
           5.989458145649133,
           5.918513030247421,
           5.849799605902971,
           5.78108618155853,
           5.699620035611959,
           5.6171729110805995,
           5.534725786549255,
           5.4522786620178945,
           5.369831537486535,
           5.2873844129551815,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           67.98675843760975,
           68.0292359766185,
           68.07171351562725,
           68.11419105463601,
           68.15666859364477,
           68.19914613265354,
           68.24162367166228,
           68.28410121067105,
           68.32657874967981,
           68.36905628868855,
           68.41153382769733,
           68.45401136670607,
           68.49648890571484,
           68.5389664447236,
           68.58144398373236,
           68.62392152274111,
           68.66639906174986,
           68.70887660075863,
           68.75135413976739,
           68.79383167877614,
           68.8363092177849,
           68.87878675679366,
           68.92126429580242,
           68.96374183481117,
           69.00621937381993,
           69.04869691282869,
           69.09117445183745,
           69.1336519908462,
           69.17612952985496,
           69.21860706886372,
           69.26108460787248,
           69.30356214688123,
           69.34603968588999,
           69.38851722489876,
           69.43099476390752,
           69.47347230291626,
           69.51594984192504,
           69.55842738093378,
           69.60090491994255,
           69.6433824589513,
           69.68585999796005,
           69.72833753696882,
           69.77081507597758,
           69.81329261498634,
           69.8557701539951,
           69.89824769300385,
           69.94072523201261,
           69.98320277102137,
           70.02568031003013,
           70.06815784903888,
           70.11063538804764,
           70.1531129270564,
           70.19559046606516,
           70.23806800507391,
           70.28054554408267,
           70.32302308309143,
           70.36550062210019,
           70.40797816110894,
           70.4504557001177,
           70.49293323912646,
           70.53541077813523,
           70.57788831714397,
           70.62016296399594,
           70.66142314026517,
           70.70268331653439,
           70.74394349280362,
           70.78520366907287,
           70.8264638453421,
           70.86772402161134,
           70.90898419788057,
           70.9502443741498,
           70.99150455041902,
           71.03276472668826,
           71.07402490295749,
           71.11528507922672,
           71.15654525549596,
           71.19780543176519,
           71.23906560803442,
           71.28032578430366,
           71.32158596057289,
           71.36284613684214,
           71.40410631311136,
           71.44536648938059,
           71.48662666564982,
           71.50638093377478,
           71.52183402027089,
           71.537287106767,
           71.5527401932631,
           71.56819327975921,
           71.58364636625532,
           71.59909945275143,
           71.61455253924754,
           71.63000562574365,
           71.64545871223974,
           71.66091179873587,
           71.67636488523196,
           71.69181797172807,
           71.70727105822418,
           71.72272414472029,
           71.7381772312164,
           71.7536303177125,
           71.76908340420862,
           71.78453649070472,
           71.79998957720082,
           71.81544266369693,
           71.83203793721002,
           71.84977539161103,
           71.86751284601205,
           71.88525030041306,
           71.90298775481408,
           71.92072520921509,
           71.93846266361611,
           71.95620011801712,
           71.97393757241814,
           71.99167502681915,
           72.00941248122015,
           72.02714993562117,
           72.0448873900222,
           72.06262484442321,
           72.08036229882421,
           72.09809975322523,
           72.11583720762624,
           72.13357466202726,
           72.15131211642827,
           72.16904957082929,
           72.1867870252303,
           72.20452447963132,
           72.22226193403233,
           72.23999938843335,
           72.25773684283436,
           72.27547429723538,
           72.29321175163639,
           72.3109492060374,
           72.32868666043841,
           72.34642411483942,
           72.36416156924044,
           72.38189902364145,
           72.39963647804247,
           72.41737393244348,
           72.4351113868445,
           72.45284884124551,
           72.47058629564653,
           72.48832375004754,
           72.50606120444854,
           72.52379865884957,
           72.54153611325057,
           72.55927356765159,
           72.5770110220526,
           72.59474847645362,
           72.61248593085463,
           72.63022338525565,
           72.64796083965666,
           72.66569829405766,
           72.68343574845868,
           72.70117320285969,
           72.71891065726071,
           72.73664811166172,
           72.75438556606274,
           72.77212302046375,
           72.78986047486477,
           72.80759792926578,
           72.8253353836668,
           72.84307283806781,
           72.86081029246883,
           72.87854774686984,
           72.89628520127086,
           72.91402265567186,
           72.61344779909886,
           72.15371678703892,
           71.69398577497893,
           71.23425476291895,
           70.77452375085898,
           70.31479273879899,
           69.85506172673902,
           69.39533071467906,
           68.93559970261906,
           68.47586869055911,
           68.0161376784991,
           67.55640666643914,
           67.09667565437917,
           66.63694464231918,
           66.17721363025923,
           65.71748261819926,
           65.25775160613927,
           64.79802059407929,
           64.3382895820193,
           63.878558569959345,
           63.41882755789936,
           62.95909654583939,
           62.499365533779425,
           62.03963452171942,
           61.57990350965947,
           61.120172497599484,
           60.66044148553951,
           60.200710473479546,
           59.74097946141955,
           59.28124844935958,
           58.821517437299605,
           58.36178642523962,
           57.90205541317966,
           57.44232440111968,
           56.9825933890597,
           56.522862376999726,
           56.06313136493974,
           55.60340035287979,
           55.143669340819805,
           54.68393832875983,
           54.22420731669987,
           53.764476304639885,
           53.3047452925799,
           52.84501428051992,
           52.38528326845994,
           51.92555225639996,
           51.465821244340006,
           51.00609023228002,
           50.54635922022004,
           50.09519970522979,
           49.649754448154866,
           49.20430919107997,
           48.75886393400505,
           48.31341867693011,
           47.86797341985519,
           47.422528162780296,
           46.977082905705366,
           46.53163764863044,
           46.08619239155552,
           45.64074713448059,
           45.19530187740569,
           44.749856620330775,
           44.304411363255845,
           43.85896610618092,
           43.41352084910602,
           42.96807559203109,
           42.52263033495617,
           42.077185077881246,
           41.63173982080632,
           41.186294563731416,
           40.7408493066565,
           40.29540404958158,
           39.84995879250665,
           39.404513535431725,
           38.959068278356824,
           38.513623021281894,
           38.06817776420697,
           37.62273250713205,
           37.17728725005714,
           36.73184199298222,
           36.286396735907296,
           35.84095147883237,
           35.39550622175745,
           35.040552054309146,
           34.77608897648723,
           34.511625898665336,
           34.247162820843485,
           33.98765601612457,
           33.731122979163004,
           33.47458994220148,
           33.218056905239955,
           32.96152386827838,
           32.70499083131688,
           32.4484577943553,
           32.19192475739377,
           31.935391720432204,
           31.678858683470743,
           31.422325646509165,
           31.16579260954765,
           30.909259572586137,
           30.65272653562456,
           30.39619349866304,
           30.13966046170148,
           29.883127424739946,
           29.63320095356948,
           29.38571603572258,
           29.138231117875648,
           28.89074620002877,
           28.643261282181896,
           28.395776364335028,
           28.1482914464881,
           27.900806528641226,
           27.65332161079431,
           27.40583669294743,
           27.158351775100503,
           26.91086685725364,
           26.66338193940676,
           26.41589702155988,
           26.168511242999678,
           25.93103935024449,
           25.693567457489294,
           25.456095564734152,
           25.218623671978964,
           24.981151779223854,
           24.743679886468666,
           24.506207993713524,
           24.268736100958325,
           24.03126420820317,
           23.793792315448037,
           23.556320422692842,
           23.318848529937643,
           23.082101631504976,
           22.855021346326573,
           22.627941061148164,
           22.400860775969722,
           22.17378049079132,
           21.946700205612867,
           21.719619920434454,
           21.49253963525607,
           21.265459350077656,
           21.038379064899203,
           20.81129877972076,
           20.58421849454236,
           20.36265376273937,
           20.144686127207628,
           19.92671849167592,
           19.70875085614421,
           19.49078322061247,
           19.272815585080764,
           19.05484794954901,
           18.836880314017296,
           18.618912678485607,
           18.400945042953847,
           18.18648531204932,
           17.97780783968799,
           17.769130367326692,
           17.56045289496535,
           17.351775422604053,
           17.14309795024276,
           16.934420477881446,
           16.725743005520116,
           16.51706553315882,
           16.310762781341307,
           16.114148893448988,
           15.917535005556712,
           15.720921117664403,
           15.524307229772115,
           15.327693341879835,
           15.131079453987557,
           14.93446556609524,
           14.737851678202961,
           14.553206273975075,
           14.36974294483648,
           14.186279615697886,
           14.00281628655934,
           13.819352957420774,
           13.635889628282206,
           13.452426299143651,
           13.273703721442212,
           13.1023077568882,
           12.930911792334172,
           12.759515827780172,
           12.588119863226137,
           12.416723898672133,
           12.245327934118134,
           12.079899149980127,
           11.91949931075175,
           11.759099471523403,
           11.598699632295034,
           11.438299793066678,
           11.277899953838308,
           11.120256809639303,
           10.969899220642713,
           10.819541631646134,
           10.669184042649574,
           10.518826453653007,
           10.368468864656418,
           10.222849625291314,
           10.08165284392689,
           9.94045606256248,
           9.799259281198083,
           9.658062499833665,
           9.51863184612866,
           9.385811555637318,
           9.252991265145955,
           9.120170974654602,
           8.987350684163243,
           8.856910978342396,
           8.731912610591339,
           8.60691424284028,
           8.481915875089246,
           8.35691750733821,
           8.238792739851126,
           8.122908255753265,
           8.007023771655405,
           7.891139287557522,
           7.7804290944891195,
           7.674439774719541,
           7.568450454949946,
           7.462461135180348,
           7.360520059831785,
           7.261533109216512,
           7.1625461586012396,
           7.063559207985996,
           6.969178106369509,
           6.875356472795204,
           6.781534839220903,
           6.6905995563936855,
           6.603352387870833,
           6.516105219348006,
           6.430235270372643,
           6.349923386505894,
           6.269611502639139,
           6.19023098249976,
           6.116071746265431,
           6.041912510031111,
           5.969281497411471,
           5.900568073067021,
           5.831854648722576,
           5.7552933956998995,
           5.672846271168551,
           5.59039914663719,
           5.50795202210583,
           5.425504897574486,
           5.343057773043126,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           67.97008287976297,
           68.01256041877173,
           68.0550379577805,
           68.09751549678924,
           68.13999303579801,
           68.18247057480677,
           68.22494811381553,
           68.26742565282429,
           68.30990319183304,
           68.3523807308418,
           68.39485826985056,
           68.43733580885932,
           68.47981334786807,
           68.52229088687685,
           68.5647684258856,
           68.60724596489436,
           68.6497235039031,
           68.69220104291188,
           68.73467858192063,
           68.77715612092939,
           68.81963365993815,
           68.8621111989469,
           68.90458873795566,
           68.94706627696442,
           68.98954381597318,
           69.03202135498194,
           69.0744988939907,
           69.11697643299945,
           69.15945397200821,
           69.20193151101697,
           69.24440905002572,
           69.28688658903448,
           69.32936412804324,
           69.371841667052,
           69.41431920606075,
           69.45679674506951,
           69.49927428407827,
           69.54175182308703,
           69.58422936209578,
           69.62670690110454,
           69.6691844401133,
           69.71166197912206,
           69.75413951813081,
           69.79661705713957,
           69.83909459614833,
           69.8815721351571,
           69.92323810043843,
           69.96449827670764,
           70.00575845297688,
           70.04701862924612,
           70.08827880551536,
           70.12953898178459,
           70.17079915805382,
           70.21205933432304,
           70.25331951059229,
           70.29457968686151,
           70.33583986313076,
           70.37710003939998,
           70.41836021566921,
           70.45962039193844,
           70.50088056820768,
           70.54214074447692,
           70.58340092074614,
           70.62466109701538,
           70.66592127328462,
           70.70718144955384,
           70.74844162582308,
           70.78970180209231,
           70.83096197836154,
           70.87222215463078,
           70.91348233090001,
           70.95474250716924,
           70.99600268343849,
           71.03726285970771,
           71.07852303597694,
           71.11978321224618,
           71.16104338851541,
           71.20230356478464,
           71.24356374105388,
           71.28482391732311,
           71.32608409359234,
           71.36734426986158,
           71.40860444613081,
           71.44986462240004,
           71.469618890525,
           71.48507197702111,
           71.50052506351722,
           71.51597815001332,
           71.53143123650943,
           71.54688432300553,
           71.56233740950164,
           71.57779049599775,
           71.59324358249387,
           71.60869666898998,
           71.62414975548607,
           71.63960284198218,
           71.65505592847829,
           71.6705090149744,
           71.68596210147051,
           71.70141518796662,
           71.71686827446271,
           71.73232136095882,
           71.74777444745493,
           71.76322753395104,
           71.77868062044715,
           71.79413370694326,
           71.80958679343937,
           71.82503987993547,
           71.84049296643157,
           71.85594605292769,
           71.87139913942379,
           71.8868522259199,
           71.902305312416,
           71.91775839891211,
           71.93321148540821,
           71.94866457190432,
           71.96411765840044,
           71.97957074489653,
           71.99502383139264,
           72.01047691788875,
           72.02593000438486,
           72.04138309356858,
           72.0591205479696,
           72.07685800237061,
           72.09459545677163,
           72.11233291117264,
           72.13007036557366,
           72.14780781997467,
           72.16554527437567,
           72.18328272877669,
           72.20102018317772,
           72.21875763757872,
           72.23649509197973,
           72.25423254638073,
           72.27197000078176,
           72.28970745518276,
           72.30744490958378,
           72.3251823639848,
           72.34291981838581,
           72.36065727278682,
           72.37839472718784,
           72.39613218158885,
           72.41386963598987,
           72.43160709039088,
           72.4493445447919,
           72.46708199919291,
           72.48481945359393,
           72.50255690799494,
           72.52029436239596,
           72.53803181679697,
           72.55576927119799,
           72.573506725599,
           72.59124418,
           72.60898163440102,
           72.62671908880203,
           72.64445654320303,
           72.66219399760405,
           72.67993145200506,
           72.69766890640608,
           72.71540636080711,
           72.73314381520812,
           72.75088126960914,
           72.76861872401014,
           72.78635617841115,
           72.80409363281217,
           72.82183108721318,
           72.8395685416142,
           72.53899368504119,
           72.07926267298124,
           71.61953166092125,
           71.15980064886128,
           70.70006963680133,
           70.24033862474133,
           69.78060761268137,
           69.32087660062138,
           68.8611455885614,
           68.40141457650144,
           67.94168356444145,
           67.48195255238147,
           67.0222215403215,
           66.56249052826152,
           66.10275951620157,
           65.64302850414158,
           65.18329749208159,
           64.72356648002162,
           64.26383546796164,
           63.80410445590168,
           63.3443734438417,
           62.88464243178172,
           62.42491141972176,
           61.96518040766176,
           61.5054493956018,
           61.045718383541825,
           60.58598737148184,
           60.12625635942189,
           59.66652534736188,
           59.20679433530192,
           58.74706332324194,
           58.287332311181956,
           57.827601299122,
           57.36787028706202,
           56.908139275002036,
           56.44840826294206,
           55.988677250882084,
           55.52894623882212,
           55.06921522676214,
           54.609484214702164,
           54.149753202642195,
           53.69002219058222,
           53.230291178522236,
           52.77056016646226,
           52.31082915440228,
           51.851098142342295,
           51.39136713028233,
           50.931636118222364,
           50.47190510616238,
           50.01217409410239,
           49.552443082042416,
           49.092712069982454,
           48.63298105792248,
           48.173250045862495,
           47.71351903380252,
           47.25378802174256,
           46.794057009682575,
           46.3343259976226,
           45.87459498556261,
           45.414863973502634,
           44.95513296144268,
           44.495401949382696,
           44.03567093732272,
           43.57593992526273,
           43.11620891320278,
           42.6564779011428,
           42.19674688908282,
           41.737015877022834,
           41.27728486496285,
           40.8175538529029,
           40.357822840842914,
           39.89809182878294,
           39.438360816722955,
           38.97862980466297,
           38.51889879260301,
           38.05916778054303,
           37.59943676848305,
           37.139705756423076,
           36.679974744363115,
           36.22024373230313,
           35.75248198806892,
           35.275350977824104,
           34.79821996757928,
           34.43138794397619,
           34.17485490701461,
           33.9183218700531,
           33.661788833091535,
           33.405255796130014,
           33.14872275916844,
           32.89218972220692,
           32.6356566852454,
           32.37912364828382,
           32.122590611322316,
           31.86605757436074,
           31.60952453739921,
           31.35299150043765,
           31.096458463476186,
           30.839925426514608,
           30.583392389553094,
           30.326859352591576,
           30.077076502405525,
           29.829591584558607,
           29.58210666671174,
           29.33462174886486,
           29.087136831017975,
           28.839651913171075,
           28.592166995324142,
           28.344682077477263,
           28.09719715963039,
           27.849712241783525,
           27.602227323936596,
           27.35474240608972,
           27.107257488242805,
           26.859772570395922,
           26.612287652548993,
           26.37248599696182,
           26.135014104206626,
           25.897542211451423,
           25.660070318696324,
           25.42259842594114,
           25.18512653318594,
           24.947654640430795,
           24.71018274767561,
           24.472710854920503,
           24.23523896216531,
           23.997767069410173,
           23.76029517665497,
           23.522823283899815,
           23.291586354108414,
           23.06450606893,
           22.837425783751552,
           22.610345498573153,
           22.38326521339475,
           22.156184928216337,
           21.9291046430379,
           21.702024357859496,
           21.474944072681044,
           21.24786378750263,
           21.020783502324242,
           20.793703217145833,
           20.575136067503337,
           20.357168431971594,
           20.13920079643989,
           19.921233160908177,
           19.703265525376437,
           19.48529788984473,
           19.267330254313016,
           19.049362618781277,
           18.83139498324957,
           18.61342734771782,
           18.40035535904176,
           18.191677886680473,
           17.98300041431916,
           17.77432294195782,
           17.56564546959649,
           17.35696799723519,
           17.14829052487385,
           16.939613052512552,
           16.730935580151254,
           16.52449034503842,
           16.327876457146143,
           16.131262569253835,
           15.934648681361546,
           15.738034793469225,
           15.54142090557695,
           15.34480701768464,
           15.148193129792356,
           14.951579241900076,
           14.764865210410498,
           14.581401881271905,
           14.397938552133347,
           14.214475222994793,
           14.031011893856197,
           13.847548564717606,
           13.664085235579059,
           13.481871741712938,
           13.310475777158901,
           13.139079812604924,
           12.9676838480509,
           12.796287883496888,
           12.624891918942861,
           12.45349595438886,
           12.283563637690383,
           12.123163798462038,
           11.96276395923367,
           11.802364120005311,
           11.641964280776934,
           11.481564441548587,
           11.32116460232022,
           11.168345676350249,
           11.01798808735367,
           10.867630498357132,
           10.717272909360542,
           10.566915320363963,
           10.416557731367403,
           10.274413281119168,
           10.133216499754743,
           9.992019718390353,
           9.850822937025926,
           9.709626155661521,
           9.572592389406294,
           9.43977209891495,
           9.30695180842358,
           9.174131517932235,
           9.041311227440875,
           8.91243590615909,
           8.787437538408053,
           8.66243917065702,
           8.53744080290596,
           8.412442435154903,
           8.295412352032358,
           8.179527867934482,
           8.063643383836613,
           7.947758899738753,
           7.837502123908085,
           7.731512804138488,
           7.625523484368911,
           7.519534164599333,
           7.417428971219352,
           7.31844202060409,
           7.219455069988843,
           7.12046811937357,
           7.025631637153568,
           6.931810003579267,
           6.837988370004968,
           6.746074935064487,
           6.658827766541652,
           6.571580598018815,
           6.484333429495963,
           6.403972359110929,
           6.323660475244177,
           6.243348591377428,
           6.168526110647411,
           6.094366874413099,
           6.02020763817877,
           5.951336540231061,
           5.882623115886627,
           5.810966755787849,
           5.728519631256489,
           5.646072506725136,
           5.563625382193785,
           5.481178257662426,
           5.398731133131065,
           5.316284008599721,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           67.95340732191622,
           67.99588486092497,
           68.03836239993373,
           68.08083993894249,
           68.12331747795125,
           68.16579501696,
           68.20827255596876,
           68.25075009497752,
           68.29322763398628,
           68.33570517299503,
           68.3781827120038,
           68.42066025101255,
           68.4631377900213,
           68.50561532903008,
           68.54809286803884,
           68.5905704070476,
           68.63304794605634,
           68.67552548506511,
           68.71800302407387,
           68.76048056308262,
           68.80295810209138,
           68.84543564110014,
           68.8879131801089,
           68.93039071911765,
           68.97286825812641,
           69.01534579713517,
           69.05782333614393,
           69.10030087515268,
           69.14277841416144,
           69.18505306061168,
           69.22631323688091,
           69.26757341315015,
           69.30883358941938,
           69.35009376568861,
           69.39135394195785,
           69.43261411822706,
           69.4738742944963,
           69.51513447076553,
           69.55639464703476,
           69.597654823304,
           69.63891499957323,
           69.68017517584246,
           69.7214353521117,
           69.76269552838093,
           69.80395570465016,
           69.8452158809194,
           69.88647605718863,
           69.92773623345786,
           69.96899640972708,
           70.01025658599633,
           70.05151676226555,
           70.0927769385348,
           70.13403711480403,
           70.17529729107326,
           70.2165574673425,
           70.25781764361173,
           70.29907781988096,
           70.34033799615018,
           70.38159817241942,
           70.42285834868866,
           70.46411852495788,
           70.50537870122713,
           70.54663887749636,
           70.58789905376558,
           70.62915923003482,
           70.67041940630406,
           70.71167958257328,
           70.75293975884253,
           70.79419993511175,
           70.835460111381,
           70.87672028765022,
           70.91798046391946,
           70.95924064018868,
           71.00050081645793,
           71.04176099272715,
           71.08302116899638,
           71.12428134526562,
           71.16554152153485,
           71.20680169780408,
           71.24806187407331,
           71.28932205034255,
           71.33058222661178,
           71.37184240288101,
           71.41310257915025,
           71.43285684727522,
           71.44830993377131,
           71.46376302026742,
           71.47921610676353,
           71.49466919325964,
           71.51012227975575,
           71.52557536625186,
           71.54102845274797,
           71.55648153924406,
           71.57193462574017,
           71.58738771223628,
           71.60284079873239,
           71.6182938852285,
           71.6337469717246,
           71.64920005822071,
           71.66465314471682,
           71.68010623121293,
           71.69555931770904,
           71.71101240420515,
           71.72646549070126,
           71.74191857719737,
           71.75737166369348,
           71.77282475018959,
           71.78827783668568,
           71.80373092318179,
           71.8191840096779,
           71.834637096174,
           71.85009018267012,
           71.86554326916622,
           71.88099635566232,
           71.89644944215843,
           71.91190252865454,
           71.92735561515065,
           71.94280870164675,
           71.95826178814286,
           71.97371487463897,
           71.98916796113507,
           72.00462104763118,
           72.02007413412728,
           72.0355272206234,
           72.0509803071195,
           72.06643339361561,
           72.08188648011172,
           72.09733956660783,
           72.11279265310394,
           72.12824573960005,
           72.14369882609614,
           72.15915191259225,
           72.17460499908836,
           72.19005808558447,
           72.20551117208058,
           72.22096425857669,
           72.2364173450728,
           72.2518704315689,
           72.26846570432815,
           72.28620315872917,
           72.30394061313018,
           72.3216780675312,
           72.33941552193221,
           72.35715297633323,
           72.37489043073424,
           72.39262788513525,
           72.41036533953627,
           72.42810279393728,
           72.44584024833829,
           72.4635777027393,
           72.48131515714032,
           72.49905261154133,
           72.51679006594235,
           72.53452752034336,
           72.55226497474438,
           72.57000242914539,
           72.5877398835464,
           72.60547733794742,
           72.62321479234842,
           72.64095224674944,
           72.65868970115045,
           72.67642715555147,
           72.69416460995248,
           72.7119020643535,
           72.72963951875451,
           72.74737697315553,
           72.76511442755654,
           72.46453957098355,
           72.00480855892357,
           71.5450775468636,
           71.08534653480362,
           70.62561552274366,
           70.16588451068367,
           69.70615349862369,
           69.24642248656372,
           68.78669147450373,
           68.32696046244378,
           67.86722945038377,
           67.40749843832381,
           66.94776742626384,
           66.48803641420385,
           66.0283054021439,
           65.56857439008391,
           65.10884337802393,
           64.64911236596396,
           64.18938135390398,
           63.72965034184402,
           63.26991932978404,
           62.810188317724055,
           62.3504573056641,
           61.89072629360409,
           61.43099528154414,
           60.97126426948415,
           60.511533257424176,
           60.051802245364215,
           59.59207123330421,
           59.13234022124426,
           58.67260920918427,
           58.21287819712429,
           57.75314718506433,
           57.29341617300435,
           56.83368516094438,
           56.37395414888439,
           55.91422313682442,
           55.45449212476446,
           54.99476111270448,
           54.5350301006445,
           54.075299088584536,
           53.61556807652455,
           53.15583706446458,
           52.69610605240459,
           52.23637504034461,
           51.776644028284636,
           51.316913016224674,
           50.8571820041647,
           50.39745099210471,
           49.93771998004473,
           49.47798896798475,
           49.00688106517402,
           48.52975005492921,
           48.05261904468438,
           47.575488034439566,
           47.09835702419477,
           46.621226013949936,
           46.144095003705125,
           45.6669639934603,
           45.18983298321548,
           44.712701972970684,
           44.235570962725866,
           43.75843995248104,
           43.28130894223622,
           42.80417793199143,
           42.3270469217466,
           41.84991591150179,
           41.37278490125696,
           40.895653891012145,
           40.41852288076735,
           39.94139187052253,
           39.464260860277705,
           38.987129850032886,
           38.50999883978806,
           38.03286782954327,
           37.555736819298446,
           37.07860580905363,
           36.60147479880881,
           36.12434378856401,
           35.64721277831919,
           35.17008176807437,
           34.69295075782955,
           34.215819747584725,
           33.84898772398164,
           33.59245468702006,
           33.335921650058545,
           33.07938861309698,
           32.82285557613546,
           32.56632253917389,
           32.30978950221237,
           32.05325646525085,
           31.796723428289265,
           31.540190391327766,
           31.283657354366184,
           31.027124317404656,
           30.770591280443096,
           30.520952051241625,
           30.273467133394693,
           30.025982215547778,
           29.77849729770091,
           29.531012379854026,
           29.283527462007108,
           29.03604254416024,
           28.78855762631336,
           28.541072708466476,
           28.293587790619572,
           28.046102872772643,
           27.79861795492576,
           27.55113303707889,
           27.303648119232022,
           27.05616320138509,
           26.8139326436791,
           26.57646075092391,
           26.33898885816876,
           26.1015169654136,
           25.86404507265847,
           25.626573179903275,
           25.389101287148073,
           25.151629394392973,
           24.91415750163779,
           24.676685608882593,
           24.439213716127448,
           24.201741823372263,
           23.964269930617153,
           23.72815136189029,
           23.501071076711888,
           23.27399079153344,
           23.046910506355026,
           22.819830221176595,
           22.59274993599818,
           22.365669650819733,
           22.138589365641334,
           21.91150908046293,
           21.684428795284518,
           21.457348510106076,
           21.230268224927674,
           21.005586007799064,
           20.78761837226731,
           20.569650736735614,
           20.351683101203864,
           20.13371546567215,
           19.91574783014041,
           19.697780194608704,
           19.47981255907699,
           19.26184492354525,
           19.043877288013544,
           18.82590965248183,
           18.614225406034212,
           18.40554793367291,
           18.1968704613116,
           17.98819298895026,
           17.779515516588972,
           17.570838044227663,
           17.362160571866323,
           17.153483099504992,
           16.944805627143694,
           16.738217908735535,
           16.54160402084326,
           16.344990132950983,
           16.14837624505866,
           15.951762357166386,
           15.75514846927408,
           15.55853458138179,
           15.36192069348947,
           15.165306805597194,
           14.976524146845925,
           14.793060817707332,
           14.609597488568774,
           14.42613415943022,
           14.242670830291626,
           14.05920750115307,
           13.875744172014517,
           13.692280842875922,
           13.518643797429654,
           13.347247832875642,
           13.175851868321628,
           13.00445590376759,
           12.833059939213616,
           12.66166397465959,
           12.490268010105579,
           12.326828286172296,
           12.166428446943948,
           12.006028607715571,
           11.845628768487224,
           11.685228929258855,
           11.524829090030499,
           11.366792132057787,
           11.21643454306121,
           11.066076954064672,
           10.91571936506808,
           10.765361776071503,
           10.615004187074964,
           10.467173718311432,
           10.325976936947033,
           10.184780155582615,
           10.043583374218208,
           9.902386592853782,
           9.761189811489393,
           9.626552932683927,
           9.493732642192558,
           9.360912351701213,
           9.22809206120987,
           9.0952717707185,
           8.967960833975804,
           8.842962466224769,
           8.717964098473711,
           8.592965730722675,
           8.467967362971642,
           8.35203196421359,
           8.236147480115706,
           8.120262996017845,
           8.00437851191997,
           7.8945751533270325,
           7.788585833557455,
           7.682596513787877,
           7.57660719401828,
           7.47433788260694,
           7.375350931991685,
           7.276363981376412,
           7.17737703076115,
           7.082085167937651,
           6.988263534363345,
           6.894441900789028,
           6.801550313735308,
           6.714303145212471,
           6.6270559766896175,
           6.539808808166782,
           6.458021331715962,
           6.377709447849214,
           6.297397563982463,
           6.220980475029393,
           6.14682123879508,
           6.072662002560751,
           6.0021050073951265,
           5.933391583050673,
           5.864678158706219,
           5.784192991344435,
           5.701745866813084,
           5.619298742281725,
           5.536851617750371,
           5.454404493219021,
           5.371957368687662,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           67.93673176406946,
           67.97920930307822,
           68.02168684208698,
           68.06416438109574,
           68.1066419201045,
           68.14911945911325,
           68.19159699812201,
           68.23407453713077,
           68.27655207613952,
           68.31902961514828,
           68.36150715415704,
           68.4039846931658,
           68.44646223217455,
           68.48812819705414,
           68.52938837332339,
           68.5706485495926,
           68.61190872586185,
           68.65316890213109,
           68.69442907840032,
           68.73568925466955,
           68.77694943093879,
           68.81820960720802,
           68.85946978347725,
           68.90072995974649,
           68.94199013601572,
           68.98325031228495,
           69.02451048855417,
           69.06577066482342,
           69.10703084109265,
           69.14829101736188,
           69.18955119363112,
           69.23081136990035,
           69.27207154616957,
           69.31333172243882,
           69.35459189870805,
           69.39585207497727,
           69.43711225124652,
           69.47837242751574,
           69.51963260378497,
           69.5608927800542,
           69.60215295632344,
           69.64341313259267,
           69.6846733088619,
           69.72593348513114,
           69.76719366140037,
           69.80845383766959,
           69.84971401393884,
           69.89097419020807,
           69.9322343664773,
           69.97349454274655,
           70.01475471901577,
           70.05601489528502,
           70.09727507155424,
           70.13853524782346,
           70.1797954240927,
           70.22105560036192,
           70.26231577663117,
           70.30357595290039,
           70.34483612916964,
           70.38609630543887,
           70.4273564817081,
           70.46861665797734,
           70.50987683424657,
           70.55113701051579,
           70.59239718678504,
           70.63365736305427,
           70.6749175393235,
           70.71617771559274,
           70.75743789186197,
           70.7986980681312,
           70.83995824440044,
           70.88121842066967,
           70.9224785969389,
           70.96373877320812,
           71.00499894947737,
           71.04625912574659,
           71.08751930201583,
           71.12877947828505,
           71.1700396545543,
           71.21129983082352,
           71.25256000709275,
           71.29382018336199,
           71.33508035963122,
           71.37634053590045,
           71.39609480402542,
           71.41154789052152,
           71.42700097701763,
           71.44245406351374,
           71.45790715000985,
           71.47336023650595,
           71.48881332300206,
           71.50426640949817,
           71.51971949599428,
           71.53517258249038,
           71.5506256689865,
           71.5660787554826,
           71.58153184197872,
           71.59698492847481,
           71.61243801497093,
           71.62789110146704,
           71.64334418796314,
           71.65879727445925,
           71.67425036095536,
           71.68970344745146,
           71.70515653394756,
           71.72060962044367,
           71.73606270693978,
           71.75151579343589,
           71.766968879932,
           71.7824219664281,
           71.79787505292421,
           71.81332813942032,
           71.82878122591643,
           71.84423431241254,
           71.85968739890865,
           71.87514048540476,
           71.89059357190085,
           71.90604665839696,
           71.92149974489307,
           71.93695283138918,
           71.95240591788529,
           71.9678590043814,
           71.98331209087749,
           71.9987651773736,
           72.01421826386971,
           72.02967135036582,
           72.04512443686193,
           72.06057752335803,
           72.07603060985414,
           72.09148369635025,
           72.10693678284636,
           72.12238986934247,
           72.13784295583858,
           72.15329604233469,
           72.1687491288308,
           72.18420221532689,
           72.199655301823,
           72.21510838831911,
           72.23056147481522,
           72.24601456131133,
           72.26146764780744,
           72.27692073430354,
           72.29237382079965,
           72.30782690729575,
           72.32327999379187,
           72.33873308028797,
           72.35418616678407,
           72.36963925328018,
           72.38509233977629,
           72.4005454262724,
           72.41599851276851,
           72.43145159926462,
           72.44690468576073,
           72.46235777225682,
           72.4778108606867,
           72.49554831508772,
           72.51328576948873,
           72.53102322388975,
           72.54876067829076,
           72.56649813269178,
           72.58423558709279,
           72.6019730414938,
           72.61971049589482,
           72.63744795029584,
           72.65518540469685,
           72.67292285909785,
           72.69066031349887,
           72.39008545692586,
           71.93035444486591,
           71.47062343280592,
           71.01089242074595,
           70.55116140868599,
           70.091430396626,
           69.63169938456603,
           69.17196837250606,
           68.71223736044607,
           68.2525063483861,
           67.79277533632612,
           67.33304432426614,
           66.87331331220616,
           66.41358230014619,
           65.95385128808623,
           65.49412027602625,
           65.03438926396628,
           64.57465825190629,
           64.11492723984631,
           63.65519622778634,
           63.19546521572637,
           62.73573420366638,
           62.261280142279105,
           61.784149132034266,
           61.30701812178946,
           60.829887111544636,
           60.35275610129982,
           59.87562509105502,
           59.39849408081018,
           58.92136307056538,
           58.444232060320566,
           57.96710105007573,
           57.48997003983094,
           57.012839029586125,
           56.5357080193413,
           56.05857700909648,
           55.581445998851656,
           55.10431498860686,
           54.62718397836204,
           54.15005296811722,
           53.672921957872425,
           53.19579094762761,
           52.71865993738278,
           52.24152892713796,
           51.764397916893145,
           51.28726690664832,
           50.81013589640352,
           50.333004886158704,
           49.85587387591388,
           49.37874286566906,
           48.90161185542424,
           48.42448084517944,
           47.94734983493463,
           47.4702188246898,
           46.99308781444498,
           46.51595680420019,
           46.03882579395536,
           45.56169478371055,
           45.08456377346572,
           44.60743276322091,
           44.1303017529761,
           43.65317074273129,
           43.17603973248647,
           42.69890872224164,
           42.22177771199685,
           41.74464670175203,
           41.26751569150721,
           40.79038468126238,
           40.31325367101756,
           39.836122660772766,
           39.35899165052794,
           38.88186064028312,
           38.404729630038304,
           37.927598619793486,
           37.45046760954869,
           36.97333659930387,
           36.496205589059045,
           36.01907457881423,
           35.54194356856943,
           35.06481255832461,
           34.587681548079786,
           34.11055053783497,
           33.63341952759015,
           33.266587503987054,
           33.010054467025476,
           32.75352143006396,
           32.4969883931024,
           32.24045535614088,
           31.983922319179307,
           31.727389282217793,
           31.47085624525626,
           31.214323208294683,
           30.964827600077655,
           30.717342682230726,
           30.46985776438384,
           30.222372846536974,
           29.9748879286901,
           29.72740301084317,
           29.479918092996254,
           29.23243317514939,
           28.984948257302502,
           28.737463339455584,
           28.489978421608715,
           28.242493503761835,
           27.995008585914952,
           27.747523668068048,
           27.50003875022112,
           27.255379290396355,
           27.017907397641217,
           26.78043550488603,
           26.54296361213087,
           26.30549171937573,
           26.068019826620542,
           25.83054793386539,
           25.593076041110233,
           25.355604148355102,
           25.118132255599907,
           24.880660362844708,
           24.643188470089605,
           24.40571657733442,
           24.168244684579225,
           23.9376360844937,
           23.71055579931526,
           23.48347551413685,
           23.25639522895845,
           23.029314943780047,
           22.802234658601595,
           22.575154373423185,
           22.348074088244758,
           22.12099380306634,
           21.89391351788789,
           21.666833232709493,
           21.43975294753109,
           21.218068312563016,
           21.000100677031277,
           20.782133041499574,
           20.564165405967856,
           20.346197770436106,
           20.12823013490441,
           19.91026249937266,
           19.692294863840946,
           19.474327228309207,
           19.2563595927775,
           19.038391957245786,
           18.828095453026634,
           18.619417980665332,
           18.410740508303995,
           18.202063035942697,
           17.9933855635814,
           17.78470809122009,
           17.576030618858745,
           17.367353146497464,
           17.158675674136152,
           16.95194547243264,
           16.75533158454036,
           16.558717696648085,
           16.362103808755766,
           16.16548992086349,
           15.968876032971211,
           15.772262145078892,
           15.575648257186616,
           15.379034369294308,
           15.18818308328131,
           15.004719754142771,
           14.821256425004186,
           14.63779309586563,
           14.454329766727037,
           14.27086643758848,
           14.087403108449925,
           13.903939779311331,
           13.72681181770036,
           13.555415853146384,
           13.384019888592347,
           13.212623924038333,
           13.04122795948432,
           12.869831994930307,
           12.69843603037627,
           12.53049277388252,
           12.370092934654172,
           12.20969309542582,
           12.049293256197473,
           11.888893416969125,
           11.728493577740748,
           11.5680937385124,
           11.414880998768744,
           11.264523409772197,
           11.114165820775609,
           10.963808231779028,
           10.813450642782492,
           10.6630930537859,
           10.518737374139286,
           10.37754059277487,
           10.236343811410462,
           10.095147030046064,
           9.953950248681647,
           9.813333766452876,
           9.680513475961524,
           9.547693185470187,
           9.414872894978837,
           9.282052604487466,
           9.149232313996123,
           9.02348576179251,
           8.898487394041453,
           8.773489026290418,
           8.648490658539384,
           8.524536060492672,
           8.408651576394812,
           8.292767092296938,
           8.176882608199069,
           8.060998124101184,
           7.951648182745993,
           7.8456588629764035,
           7.739669543206819,
           7.633680223437242,
           7.53124679399451,
           7.4322598433792475,
           7.333272892763993,
           7.234285942148739,
           7.138538698721715,
           7.044717065147409,
           6.950895431573105,
           6.857073797998799,
           6.769778523883279,
           6.682531355360433,
           6.5952841868375955,
           6.512070304320986,
           6.431758420454235,
           6.351446536587492,
           6.273434839411369,
           6.199275603177053,
           6.125116366942729,
           6.052873474559171,
           5.984160050214717,
           5.915446625870281,
           5.839866351432382,
           5.75741922690102,
           5.674972102369667,
           5.592524977838316,
           5.5100778533069565,
           5.427630728775602,
           5.345183604244253,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           67.9174595126874,
           67.95735643373892,
           67.99725335479044,
           68.03715027584195,
           68.07704719689347,
           68.11808016488887,
           68.1593403411581,
           68.20060051742733,
           68.24186069369657,
           68.2831208699658,
           68.32438104623502,
           68.36564122250425,
           68.40690139877348,
           68.44816157504272,
           68.48942175131195,
           68.53068192758118,
           68.57194210385042,
           68.61320228011965,
           68.65446245638888,
           68.69572263265812,
           68.73698280892735,
           68.77824298519658,
           68.81950316146582,
           68.86076333773505,
           68.90202351400428,
           68.94328369027352,
           68.98454386654275,
           69.02580404281198,
           69.06706421908122,
           69.10832439535045,
           69.14958457161968,
           69.19084474788892,
           69.23210492415815,
           69.27336510042738,
           69.31462527669662,
           69.35588545296585,
           69.39714562923508,
           69.43840580550432,
           69.47966598177354,
           69.52092615804278,
           69.562186334312,
           69.60344651058125,
           69.64470668685047,
           69.68596686311972,
           69.72722703938894,
           69.76848721565817,
           69.8097473919274,
           69.85100756819664,
           69.89226774446587,
           69.93352792073512,
           69.97478809700434,
           70.01604827327358,
           70.0573084495428,
           70.09856862581202,
           70.13982880208127,
           70.1810889783505,
           70.22234915461974,
           70.26360933088897,
           70.30486950715819,
           70.34612968342743,
           70.38738985969667,
           70.4286500359659,
           70.46991021223513,
           70.51117038850435,
           70.5524305647736,
           70.59369074104283,
           70.63495091731207,
           70.6762110935813,
           70.71747126985053,
           70.75873144611977,
           70.799991622389,
           70.84125179865822,
           70.88251197492747,
           70.9237721511967,
           70.96503232746593,
           71.00629250373517,
           71.04755268000439,
           71.08881285627362,
           71.13007303254285,
           71.17133320881209,
           71.21259338508132,
           71.25385356135057,
           71.2951137376198,
           71.33637391388903,
           71.35407967466394,
           71.36707455233997,
           71.38006943001602,
           71.39306430769206,
           71.40769799292346,
           71.42315107941957,
           71.43860416591568,
           71.45405725241179,
           71.4695103389079,
           71.484963425404,
           71.50041651190011,
           71.51586959839621,
           71.53132268489233,
           71.54677577138843,
           71.56222885788455,
           71.57768194438064,
           71.59313503087675,
           71.60858811737286,
           71.62404120386897,
           71.63949429036508,
           71.65494737686117,
           71.6704004633573,
           71.68585354985339,
           71.70130663634951,
           71.71675972284561,
           71.73221280934172,
           71.74766589583783,
           71.76311898233394,
           71.77857206883004,
           71.79402515532615,
           71.80947824182226,
           71.82493132831837,
           71.84038441481447,
           71.85583750131057,
           71.8712905878067,
           71.88674367430279,
           71.9021967607989,
           71.917649847295,
           71.9331029337911,
           71.94855602028723,
           71.96400910678332,
           71.97946219327943,
           71.99491527977554,
           72.01036836627165,
           72.02582145276776,
           72.04127453926387,
           72.05672762575998,
           72.07218071225608,
           72.0876337987522,
           72.1030868852483,
           72.11853997174441,
           72.1339930582405,
           72.14944614473661,
           72.16489923123272,
           72.18035231772883,
           72.19580540422494,
           72.21125849072105,
           72.22671157721716,
           72.24216466371327,
           72.25761775020936,
           72.27307083670547,
           72.28852392320158,
           72.30397700969769,
           72.3194300961938,
           72.33488318268991,
           72.35033626918602,
           72.36578935568213,
           72.38124244217823,
           72.39669552867434,
           72.41214861517044,
           72.42760170166656,
           72.44305478816266,
           72.45850787465876,
           72.47396096115487,
           72.48941404765098,
           72.50486713414709,
           72.5203202206432,
           72.5357733071393,
           72.55122639363542,
           72.56667948013151,
           72.58213256662762,
           72.59758565312373,
           72.61303873961984,
           72.29448008467358,
           71.80891555900618,
           71.32335103333877,
           70.83778650767138,
           70.35222198200398,
           69.86665745633654,
           69.38109293066915,
           68.89552840500174,
           68.40996387933433,
           67.92439935366693,
           67.4388348279995,
           66.9532703023321,
           66.46770577666469,
           65.98214125099727,
           65.49657672532989,
           65.01879699399825,
           64.54166598375342,
           64.0645349735086,
           63.58740396326378,
           63.11027295301898,
           62.63314194277416,
           62.15601093252934,
           61.678879922284544,
           61.201748912039704,
           60.72461790179491,
           60.24748689155008,
           59.770355881305264,
           59.29322487106047,
           58.81609386081563,
           58.33896285057082,
           57.861831840326,
           57.38470083008118,
           56.90756981983639,
           56.430438809591564,
           55.953307799346746,
           55.47617678910193,
           54.9990457788571,
           54.521914768612305,
           54.04478375836749,
           53.56765274812266,
           53.090521737877864,
           52.613390727633046,
           52.13625971738823,
           51.65912870714341,
           51.18199769689859,
           50.704866686653766,
           50.22773567640897,
           49.75060466616415,
           49.273473655919325,
           48.79634264567451,
           48.31921163542969,
           47.842080625184884,
           47.36494961494007,
           46.88781860469525,
           46.41068759445043,
           45.93355658420563,
           45.45642557396081,
           44.979294563715996,
           44.50216355347116,
           44.025032543226345,
           43.54790153298155,
           43.07077052273673,
           42.59363951249191,
           42.116508502247086,
           41.639377492002296,
           41.16224648175747,
           40.68511547151265,
           40.20798446126783,
           39.73085345102301,
           39.25372244077821,
           38.776591430533394,
           38.29946042028857,
           37.82232941004375,
           37.34519839979893,
           36.86806738955413,
           36.39093637930931,
           35.91380536906449,
           35.43667435881967,
           34.959543348574876,
           34.48241233833005,
           34.00528132808523,
           33.528150317840414,
           33.051019307595595,
           32.6841872839925,
           32.42765424703092,
           32.17112121006941,
           31.914588173107845,
           31.658055136146316,
           31.40870314891369,
           31.161218231066822,
           30.91373331321994,
           30.66624839537296,
           30.418763477526156,
           30.171278559679223,
           29.923793641832336,
           29.67630872398547,
           29.428823806138602,
           29.18133888829167,
           28.933853970444755,
           28.686369052597886,
           28.438884134751,
           28.191399216904085,
           27.943914299057216,
           27.69682593711369,
           27.45935404435849,
           27.221882151603364,
           26.984410258848207,
           26.746938366093005,
           26.509466473337866,
           26.271994580582682,
           26.034522687827522,
           25.79705079507238,
           25.559578902317195,
           25.322107009562043,
           25.084635116806883,
           24.84716322405175,
           24.609691331296556,
           24.374201092275577,
           24.147120807097135,
           23.920040521918736,
           23.692960236740284,
           23.465879951561885,
           23.238799666383443,
           23.01171938120503,
           22.78463909602663,
           22.557558810848228,
           22.33047852566978,
           22.103398240491366,
           21.876317955312935,
           21.64923767013452,
           21.43055061732699,
           21.212582981795247,
           20.994615346263544,
           20.77664771073183,
           20.558680075200087,
           20.340712439668383,
           20.12274480413667,
           19.90477716860492,
           19.686809533073223,
           19.468841897541473,
           19.25087426200976,
           19.041965500019074,
           18.833288027657773,
           18.62461055529643,
           18.415933082935137,
           18.20725561057384,
           17.998578138212494,
           17.7899006658512,
           17.581223193489897,
           17.372545721128592,
           17.165673036129757,
           16.96905914823749,
           16.772445260345172,
           16.575831372452885,
           16.379217484560606,
           16.182603596668326,
           15.985989708776007,
           15.789375820883732,
           15.592761932991454,
           15.399842019716766,
           15.21637869057818,
           15.032915361439628,
           14.849452032301032,
           14.66598870316249,
           14.482525374023908,
           14.299062044885353,
           14.11559871574676,
           13.934979837971113,
           13.76358387341709,
           13.592187908863076,
           13.42079194430905,
           13.249395979755075,
           13.078000015201036,
           12.906604050647026,
           12.73520808609301,
           12.573757422364432,
           12.413357583136076,
           12.252957743907707,
           12.09255790467936,
           11.932158065451006,
           11.77175822622266,
           11.613327454476282,
           11.462969865479735,
           11.312612276483156,
           11.162254687486575,
           11.011897098490028,
           10.86153950949344,
           10.71149781133155,
           10.570301029967151,
           10.429104248602725,
           10.287907467238327,
           10.14671068587391,
           10.005513904509504,
           9.867294309730509,
           9.734474019239165,
           9.601653728747795,
           9.468833438256443,
           9.336013147765108,
           9.20400905736026,
           9.079010689609204,
           8.954012321858169,
           8.829013954107134,
           8.704015586356075,
           8.581155672673903,
           8.465271188576043,
           8.34938670447816,
           8.2335022203803,
           8.117617736282424,
           8.00872121216496,
           7.902731892395376,
           7.796742572625785,
           7.6907532528561955,
           7.588155705382089,
           7.489168754766835,
           7.390181804151569,
           7.291194853536307,
           7.194992229505791,
           7.1011705959314915,
           7.007348962357175,
           6.913527328782869,
           6.8252539025541035,
           6.738006734031251,
           6.650759565508409,
           6.5661192769260115,
           6.485807393059269,
           6.405495509192519,
           6.325889203793354,
           6.251729967559038,
           6.177570731324709,
           6.103641941723216,
           6.034928517378775,
           5.966215093034329,
           5.895539711520321,
           5.813092586988976,
           5.730645462457616,
           5.648198337926256,
           5.565751213394902,
           5.483304088863552,
           5.400856964332192,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           67.89050104665614,
           67.93039796770766,
           67.97029488875918,
           68.01019180981069,
           68.05008873086223,
           68.08998565191374,
           68.12988257296526,
           68.16977949401678,
           68.20967641506829,
           68.24957333611981,
           68.28947025717133,
           68.32936717822285,
           68.36926409927437,
           68.40916102032588,
           68.4490579413774,
           68.48895486242893,
           68.52885178348043,
           68.56874870453196,
           68.60864562558348,
           68.648542546635,
           68.68843946768652,
           68.7287908078481,
           68.77005098411733,
           68.81131116038657,
           68.8525713366558,
           68.89383151292503,
           68.93509168919427,
           68.9763518654635,
           69.01761204173273,
           69.05887221800197,
           69.1001323942712,
           69.14139257054043,
           69.18265274680967,
           69.2239129230789,
           69.26517309934813,
           69.30643327561737,
           69.3476934518866,
           69.38895362815582,
           69.43021380442505,
           69.47147398069428,
           69.51273415696352,
           69.55399433323275,
           69.59525450950198,
           69.63651468577123,
           69.67777486204045,
           69.7190350383097,
           69.76029521457892,
           69.80155539084816,
           69.84281556711738,
           69.88407574338662,
           69.92533591965585,
           69.96659609592508,
           70.00785627219432,
           70.04911644846356,
           70.09037662473278,
           70.13163680100203,
           70.17289697727125,
           70.21415715354048,
           70.25541732980972,
           70.29667750607895,
           70.33793768234818,
           70.37919785861742,
           70.42045803488665,
           70.46171821115588,
           70.50297838742512,
           70.54423856369435,
           70.58549873996358,
           70.62675891623282,
           70.66801909250205,
           70.70927926877128,
           70.75053944504052,
           70.79179962130975,
           70.83305979757898,
           70.8743199738482,
           70.91558015011745,
           70.95684032638668,
           70.99810050265592,
           71.03936067892514,
           71.08062085519438,
           71.1218810314636,
           71.16314120773285,
           71.20440138400207,
           71.2456615602713,
           71.28692173654053,
           71.30462749731544,
           71.31762237499149,
           71.33061725266752,
           71.34361213034357,
           71.35660700801961,
           71.36960188569566,
           71.3825967633717,
           71.39559164104774,
           71.40858651872378,
           71.42158139639983,
           71.43457627407588,
           71.44757115175192,
           71.46056602942797,
           71.473560907104,
           71.48655578478005,
           71.49955066245609,
           71.51254554013214,
           71.52554041780817,
           71.53853529548422,
           71.55153017316026,
           71.56493475357604,
           71.58038784007215,
           71.59584092656826,
           71.61129401306437,
           71.62674709956048,
           71.64220018605657,
           71.65765327255268,
           71.67310635904879,
           71.6885594455449,
           71.704012532041,
           71.7194656185371,
           71.73491870503321,
           71.75037179152932,
           71.76582487802544,
           71.78127796452155,
           71.79673105101764,
           71.81218413751375,
           71.82763722400986,
           71.84309031050597,
           71.85854339700208,
           71.87399648349819,
           71.8894495699943,
           71.9049026564904,
           71.92035574298652,
           71.93580882948262,
           71.95126191597872,
           71.96671500247484,
           71.98216808897094,
           71.99762117546705,
           72.01307426196315,
           72.02852734845926,
           72.04398043495537,
           72.05943352145147,
           72.07488660794758,
           72.09033969444368,
           72.1057927809398,
           72.1212458674359,
           72.13669895393201,
           72.15215204042812,
           72.16760512692423,
           72.18305821342034,
           72.19851129991645,
           72.21396438641254,
           72.22941747290865,
           72.24487055940476,
           72.26032364590087,
           72.27577673239698,
           72.29122981889309,
           72.3066829053892,
           72.32213599188529,
           72.33758907838141,
           72.35304216487751,
           72.36849525137362,
           72.38394833786973,
           72.39940142436583,
           72.41485451086194,
           72.43030759735805,
           72.44576068385416,
           72.46121377035027,
           72.47666685684638,
           72.49211994334247,
           72.50757302983858,
           72.52302611633469,
           72.20446746138843,
           71.71890293572103,
           71.23333841005362,
           70.74777388438622,
           70.26220935871883,
           69.77664483305139,
           69.291080307384,
           68.8055157817166,
           68.31995125604918,
           67.83438673038178,
           67.34882220471435,
           66.86325767904695,
           66.37769315337954,
           65.89212862771213,
           65.40656410204474,
           64.92099957637733,
           64.4354350507099,
           63.9498705250425,
           63.464305999375085,
           62.978741473707686,
           62.49317694804028,
           62.00761242237286,
           61.52204789670547,
           61.03648337103804,
           60.550918845370646,
           60.06535431970323,
           59.57978979403582,
           59.09422526836843,
           58.608660742701,
           58.1230962170336,
           57.63753169136619,
           57.151967165698764,
           56.66640264003138,
           56.180838114363965,
           55.69527358869655,
           55.209709063029145,
           54.72414453736173,
           54.23858001169434,
           53.753015486026925,
           53.26745096035951,
           52.781886434692126,
           52.29632190902471,
           51.8107573833573,
           51.32519285768987,
           50.83962833202247,
           50.35406380635505,
           49.86849928068766,
           49.382934755020244,
           48.89737022935284,
           48.41180570368542,
           47.92624117801801,
           47.44067665235062,
           46.955112126683204,
           46.46954760101579,
           45.98398307534838,
           45.498418549680984,
           45.01285402401356,
           44.527289498346164,
           44.04172497267875,
           43.55616044701133,
           43.07059592134394,
           42.58503139567652,
           42.09946687000911,
           41.613902344341696,
           41.12833781867431,
           40.6427732930069,
           40.157208767339476,
           39.67164424167206,
           39.18607971600465,
           38.70051519033726,
           38.21495066466985,
           37.729386139002436,
           37.24382161333502,
           36.76279817980437,
           36.285667169559574,
           35.808536159314755,
           35.33140514906994,
           34.85427413882512,
           34.377143128580315,
           33.900012118335496,
           33.42288110809068,
           32.94575009784586,
           32.468619087601034,
           32.101787063997946,
           31.852578697749728,
           31.60509377990286,
           31.35760886205599,
           31.110123944209054,
           30.86263902636219,
           30.615154108515316,
           30.367669190668433,
           30.120184272821458,
           29.872699354974653,
           29.62521443712772,
           29.377729519280837,
           29.13024460143397,
           28.8827596835871,
           28.635274765740167,
           28.387789847893252,
           28.140304930046383,
           27.90080069107578,
           27.66332879832068,
           27.425856905565496,
           27.18838501281034,
           26.950913120055144,
           26.713441227300013,
           26.47596933454486,
           26.238497441789654,
           26.001025549034516,
           25.76355365627933,
           25.52608176352417,
           25.28860987076903,
           25.051137978013845,
           24.813666085258692,
           24.583685814878972,
           24.35660552970058,
           24.129525244522128,
           23.90244495934376,
           23.675364674165316,
           23.448284388986913,
           23.221204103808464,
           22.99412381863006,
           22.76704353345162,
           22.53996324827321,
           22.31288296309481,
           22.08580267791641,
           21.861000557622717,
           21.643032922090956,
           21.425065286559235,
           21.207097651027517,
           20.989130015495803,
           20.77116237996406,
           20.553194744432357,
           20.335227108900643,
           20.117259473368904,
           19.899291837837197,
           19.681324202305483,
           19.464513019372845,
           19.255835547011557,
           19.04715807465025,
           18.838480602288872,
           18.629803129927573,
           18.42112565756628,
           18.212448185204934,
           18.003770712843636,
           17.795093240482338,
           17.586415768120997,
           17.379400599826884,
           17.18278671193461,
           16.98617282404229,
           16.78955893615,
           16.592945048257736,
           16.396331160365413,
           16.199717272473126,
           16.003103384580847,
           15.806489496688572,
           15.611500956152192,
           15.428037627013637,
           15.244574297875053,
           15.061110968736488,
           14.877647639597903,
           14.694184310459349,
           14.510720981320754,
           14.327257652182215,
           14.14379432304363,
           13.971751893687843,
           13.800355929133808,
           13.628959964579805,
           13.45756400002578,
           13.286168035471766,
           13.114772070917741,
           12.943376106363765,
           12.777421910074713,
           12.617022070846334,
           12.456622231617999,
           12.29622239238962,
           12.135822553161262,
           11.975422713932895,
           11.815022874704548,
           11.661416321187273,
           11.511058732190694,
           11.360701143194115,
           11.210343554197566,
           11.059985965200989,
           10.909628376204408,
           10.763061467159414,
           10.62186468579499,
           10.48066790443059,
           10.339471123066192,
           10.198274341701765,
           10.057077560337367,
           9.921254853008142,
           9.788434562516771,
           9.655614272025426,
           9.522793981534083,
           9.389973691042712,
           9.259533985176953,
           9.134535617425927,
           9.009537249674882,
           8.884538881923826,
           8.759540514172791,
           8.637775284855135,
           8.521890800757237,
           8.40600631665939,
           8.29012183256153,
           8.174237348463645,
           8.065794241583916,
           7.959804921814337,
           7.853815602044753,
           7.747826282275169,
           7.645064616769675,
           7.546077666154421,
           7.447090715539149,
           7.348103764923895,
           7.251445760289867,
           7.157624126715561,
           7.063802493141251,
           6.9699808595669515,
           6.880729281224906,
           6.793482112702064,
           6.706234944179234,
           6.620168249531044,
           6.5398563656642885,
           6.459544481797545,
           6.379232597930803,
           6.304184331941011,
           6.230025095706694,
           6.155865859472378,
           6.085696984542816,
           6.0169835601983745,
           5.948270135853933,
           5.8687659470769145,
           5.786318822545557,
           5.703871698014211,
           5.6214245734828525,
           5.538977448951491,
           5.456530324420138,
           5.374083199888787,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           67.86354258062488,
           67.9034395016764,
           67.94333642272792,
           67.98323334377943,
           68.02313026483097,
           68.06302718588248,
           68.102924106934,
           68.14282102798552,
           68.18271794903703,
           68.22261487008856,
           68.26251179114007,
           68.30240871219159,
           68.34230563324311,
           68.38220255429462,
           68.42209947534616,
           68.46199639639767,
           68.50189331744917,
           68.54179023850071,
           68.58168715955222,
           68.62158408060374,
           68.66148100165526,
           68.70137792270678,
           68.74127484375829,
           68.78117176480981,
           68.82106868586133,
           68.86096560691286,
           68.90086252796438,
           68.94075944901589,
           68.98065637006741,
           69.02055329111893,
           69.06045021217045,
           69.10034713322197,
           69.14024405427348,
           69.180140975325,
           69.22003789637652,
           69.25993481742805,
           69.29983173847957,
           69.33972865953108,
           69.38076162707657,
           69.4220218033458,
           69.46328197961503,
           69.50454215588428,
           69.5458023321535,
           69.58706250842275,
           69.62832268469197,
           69.6695828609612,
           69.71084303723043,
           69.75210321349968,
           69.7933633897689,
           69.83462356603813,
           69.87588374230737,
           69.9171439185766,
           69.95840409484583,
           69.99966427111507,
           70.0409244473843,
           70.08218462365355,
           70.12344479992277,
           70.164704976192,
           70.20596515246123,
           70.24722532873047,
           70.2884855049997,
           70.32974568126893,
           70.37100585753817,
           70.4122660338074,
           70.45352621007663,
           70.49478638634587,
           70.5360465626151,
           70.57730673888433,
           70.61856691515356,
           70.6598270914228,
           70.70108726769203,
           70.74234744396125,
           70.7836076202305,
           70.82486779649972,
           70.86612797276896,
           70.90738814903818,
           70.94864832530743,
           70.98990850157665,
           71.0311686778459,
           71.07242885411512,
           71.11368903038436,
           71.15494920665358,
           71.19620938292283,
           71.23746955919205,
           71.25517531996697,
           71.268170197643,
           71.28116507531905,
           71.29415995299509,
           71.30715483067114,
           71.32014970834717,
           71.33314458602322,
           71.34613946369926,
           71.35913434137531,
           71.37212921905135,
           71.3851240967274,
           71.39811897440345,
           71.41111385207948,
           71.42410872975552,
           71.43710360743157,
           71.45009848510762,
           71.46309336278365,
           71.47608824045969,
           71.48908311813574,
           71.50207799581179,
           71.51507287348782,
           71.52806775116386,
           71.54106262883991,
           71.55405750651595,
           71.567052384192,
           71.58004726186803,
           71.59304213954408,
           71.60603701722013,
           71.61903189489617,
           71.6320267725722,
           71.64502165024825,
           71.6580165279243,
           71.67101140560034,
           71.68400628327637,
           71.69700116095242,
           71.70999603862847,
           71.72299091630451,
           71.7376246007247,
           71.75307768722081,
           71.76853077371693,
           71.78398386021303,
           71.79943694670914,
           71.81489003320524,
           71.83034311970135,
           71.84579620619746,
           71.86124929269357,
           71.87670237918968,
           71.89215546568579,
           71.90760855218188,
           71.92306163867799,
           71.9385147251741,
           71.95396781167021,
           71.96942089816632,
           71.98487398466243,
           72.00032707115854,
           72.01578015765465,
           72.03123324415074,
           72.04668633064685,
           72.06213941714296,
           72.07759250363907,
           72.09304559013518,
           72.10849867663129,
           72.1239517631274,
           72.1394048496235,
           72.15485793611961,
           72.17031102261572,
           72.18576410911183,
           72.20121719560794,
           72.21667028210403,
           72.23212336860014,
           72.24757645509625,
           72.26302954159236,
           72.27848262808847,
           72.29393571458456,
           72.30938880108069,
           72.3248418875768,
           72.3402949740729,
           72.35574806056901,
           72.37120114706512,
           72.38665423356122,
           72.40210732005733,
           72.41756040655343,
           72.43301349304954,
           72.11445483810328,
           71.6288903124359,
           71.14332578676847,
           70.65776126110107,
           70.17219673543369,
           69.68663220976623,
           69.20106768409885,
           68.71550315843145,
           68.22993863276403,
           67.74437410709663,
           67.2588095814292,
           66.7732450557618,
           66.28768053009439,
           65.80211600442698,
           65.31655147875958,
           64.83098695309216,
           64.34542242742477,
           63.85985790175735,
           63.37429337608993,
           62.88872885042254,
           62.40316432475513,
           61.91759979908771,
           61.432035273420325,
           60.94647074775288,
           60.4609062220855,
           59.975341696418084,
           59.48977717075067,
           59.00421264508328,
           58.51864811941584,
           58.03308359374845,
           57.54751906808104,
           57.06195454241363,
           56.57639001674623,
           56.09082549107882,
           55.605260965411404,
           55.119696439744,
           54.634131914076576,
           54.14856738840919,
           53.66300286274178,
           53.17743833707436,
           52.69187381140697,
           52.206309285739565,
           51.72074476007215,
           51.23518023440472,
           50.749615708737316,
           50.26405118306991,
           49.77848665740251,
           49.2929221317351,
           48.80735760606768,
           48.32179308040027,
           47.836228554732855,
           47.35066402906547,
           46.865099503398056,
           46.379534977730636,
           45.89397045206323,
           45.40840592639583,
           44.922841400728416,
           44.437276875061016,
           43.951712349393596,
           43.46614782372618,
           42.98058329805879,
           42.495018772391376,
           42.00945424672396,
           41.52388972105655,
           41.02750971617077,
           40.522116864051725,
           40.01672401193269,
           39.51133115981365,
           39.005938307694606,
           38.50054545557559,
           37.995152603456546,
           37.48975975133751,
           36.98436689921847,
           36.478974047099435,
           35.97358119498041,
           35.46818834286138,
           34.96279549074234,
           34.45740263862329,
           33.952009786504284,
           33.44661693438524,
           32.9412240822662,
           32.435831230147166,
           31.93043837802812,
           31.553999493045197,
           31.306514575198218,
           31.059029657351353,
           30.811544739504487,
           30.564059821657548,
           30.316574903810682,
           30.06908998596381,
           29.821605068116927,
           29.574120150269955,
           29.326635232423147,
           29.079150314576218,
           28.83166539672933,
           28.584180478882462,
           28.342247337793115,
           28.104775445037955,
           27.867303552282813,
           27.62983165952763,
           27.392359766772422,
           27.15488787401733,
           26.917415981262142,
           26.679944088506986,
           26.442472195751787,
           26.20500030299666,
           25.967528410241503,
           25.730056517486304,
           25.492584624731165,
           25.255112731975977,
           25.020250822660856,
           24.79317053748241,
           24.56609025230401,
           24.339009967125598,
           24.11192968194715,
           23.884849396768757,
           23.657769111590305,
           23.43068882641193,
           23.20360854123349,
           22.976528256055094,
           22.74944797087664,
           22.52236768569824,
           22.295287400519797,
           22.073482862386683,
           21.855515226854944,
           21.6375475913232,
           21.419579955791527,
           21.20161232025977,
           20.98364468472804,
           20.765677049196327,
           20.547709413664613,
           20.32974177813287,
           20.111774142601167,
           19.893806507069453,
           19.678383066365292,
           19.469705594003994,
           19.261028121642653,
           19.05235064928134,
           18.843673176920056,
           18.634995704558747,
           18.42631823219737,
           18.217640759836073,
           18.008963287474774,
           17.800285815113433,
           17.59312816352403,
           17.39651427563172,
           17.199900387739433,
           17.003286499847125,
           16.80667261195485,
           16.61005872406253,
           16.413444836170243,
           16.216830948277977,
           16.020217060385654,
           15.823603172493367,
           15.63969656344906,
           15.456233234310506,
           15.272769905171913,
           15.089306576033357,
           14.905843246894772,
           14.722379917756207,
           14.53891658861762,
           14.355453259479068,
           14.179919913958571,
           14.00852394940453,
           13.837127984850532,
           13.66573202029653,
           13.494336055742496,
           13.322940091188492,
           13.151544126634468,
           12.98108639778497,
           12.820686558556623,
           12.660286719328255,
           12.499886880099899,
           12.339487040871518,
           12.179087201643185,
           12.018687362414804,
           11.859862776894811,
           11.709505187898229,
           11.559147598901673,
           11.408790009905102,
           11.258432420908523,
           11.108074831911944,
           10.957717242915395,
           10.814625122987277,
           10.67342834162286,
           10.532231560258452,
           10.391034778894028,
           10.249837997529628,
           10.10864121616523,
           9.975215396285764,
           9.84239510579442,
           9.70957481530306,
           9.57675452481169,
           9.443934234320345,
           9.315058912993694,
           9.190060545242632,
           9.065062177491576,
           8.940063809740549,
           8.815065441989505,
           8.694394897036343,
           8.578510412938467,
           8.462625928840621,
           8.346741444742726,
           8.230856960644878,
           8.122867271002882,
           8.016877951233297,
           7.910888631463706,
           7.804899311694129,
           7.7019735281572625,
           7.602986577541989,
           7.503999626926734,
           7.405012676311479,
           7.307899291073927,
           7.214077657499626,
           7.120256023925327,
           7.026434390351021,
           6.936204659895725,
           6.848957491372888,
           6.7617103228500355,
           6.674463154327194,
           6.593905338269327,
           6.513593454402578,
           6.433281570535821,
           6.356638696322994,
           6.282479460088679,
           6.20832022385435,
           6.136465451706876,
           6.067752027362426,
           5.999038603017972,
           5.9244393071648656,
           5.841992182633515,
           5.7595450581021534,
           5.677097933570796,
           5.59465080903945,
           5.512203684508092,
           5.429756559976729,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           67.83658411459362,
           67.87648103564514,
           67.91637795669665,
           67.95627487774817,
           67.9961717987997,
           68.03606871985122,
           68.07596564090272,
           68.11586256195424,
           68.15575948300577,
           68.19565640405729,
           68.23555332510881,
           68.27545024616032,
           68.31534716721185,
           68.35524408826336,
           68.39514100931488,
           68.4350379303664,
           68.47493485141791,
           68.51483177246944,
           68.55472869352096,
           68.59462561457248,
           68.634522535624,
           68.67441945667552,
           68.71431637772704,
           68.75421329877855,
           68.79411021983007,
           68.8340071408816,
           68.8739040619331,
           68.91380098298463,
           68.95369790403615,
           68.99359482508765,
           69.03349174613919,
           69.0733886671907,
           69.11328558824222,
           69.15318250929374,
           69.19307943034525,
           69.23297635139679,
           69.2728732724483,
           69.31277019349982,
           69.35266711455134,
           69.39256403560285,
           69.43246095665437,
           69.47235787770589,
           69.51225479875743,
           69.55215171980893,
           69.59204864086044,
           69.63194556191196,
           69.67184248296348,
           69.71173940401502,
           69.75163632506653,
           69.79153324611804,
           69.83143016716956,
           69.87132708822108,
           69.91122400927259,
           69.95112093032412,
           69.99147227003581,
           70.03273244630505,
           70.07399262257428,
           70.11525279884351,
           70.15651297511273,
           70.19777315138198,
           70.2390333276512,
           70.28029350392045,
           70.32155368018968,
           70.36281385645891,
           70.40407403272815,
           70.44533420899738,
           70.48659438526661,
           70.52785456153585,
           70.56911473780507,
           70.6103749140743,
           70.65163509034355,
           70.69289526661278,
           70.73415544288201,
           70.77541561915123,
           70.81667579542048,
           70.85793597168971,
           70.89919614795895,
           70.94045632422817,
           70.98171650049741,
           71.02297667676663,
           71.06423685303588,
           71.1054970293051,
           71.14675720557435,
           71.18801738184357,
           71.20572314261848,
           71.21871802029452,
           71.23171289797057,
           71.24470777564662,
           71.25770265332265,
           71.27069753099869,
           71.28369240867474,
           71.29668728635079,
           71.30968216402682,
           71.32267704170286,
           71.33567191937891,
           71.34866679705496,
           71.361661674731,
           71.37465655240703,
           71.38765143008308,
           71.40064630775913,
           71.41364118543518,
           71.4266360631112,
           71.43963094078725,
           71.4526258184633,
           71.46562069613934,
           71.47861557381538,
           71.49161045149143,
           71.50460532916748,
           71.51760020684351,
           71.53059508451955,
           71.5435899621956,
           71.55658483987165,
           71.56957971754768,
           71.58257459522372,
           71.59556947289977,
           71.60856435057582,
           71.62155922825185,
           71.63455410592789,
           71.64754898360394,
           71.66054386127998,
           71.67353873895603,
           71.68653361663206,
           71.69952849430811,
           71.71252337198416,
           71.7255182496602,
           71.73851312733623,
           71.75150800501228,
           71.76450288268833,
           71.77749776036437,
           71.79049263804042,
           71.80348751571645,
           71.8164823933925,
           71.82947727106854,
           71.84247214874458,
           71.85546702642063,
           71.86846190409668,
           71.88145678177273,
           71.89486136137728,
           71.91031444787339,
           71.9257675343695,
           71.94122062086561,
           71.95667370736172,
           71.97212679385781,
           71.98757988035392,
           72.00303296685003,
           72.01848605334614,
           72.03393913984225,
           72.04939222633836,
           72.06484531283446,
           72.08029839933056,
           72.09575148582667,
           72.11120457232278,
           72.12665765881889,
           72.142110745315,
           72.1575638318111,
           72.17301691830721,
           72.18847000480332,
           72.20392309129942,
           72.21937617779552,
           72.23482926429163,
           72.25028235078774,
           72.26573543728385,
           72.28118852377996,
           72.29664161027608,
           72.31209469677218,
           72.32754778326829,
           72.34300086976438,
           72.02444221481814,
           71.53887768915074,
           71.05331316348332,
           70.56774863781591,
           70.08218411214852,
           69.59661958648108,
           69.11105506081368,
           68.6254905351463,
           68.13992600947887,
           67.65436148381148,
           67.16879695814404,
           66.68323243247664,
           66.19766790680924,
           65.71210338114182,
           65.22653885547444,
           64.74097432980702,
           64.2554098041396,
           63.7698452784722,
           63.284280752804776,
           62.79871622713739,
           62.31315170146998,
           61.82758717580256,
           61.34202265013517,
           60.856458124467736,
           60.37089359880034,
           59.88532907313293,
           59.39976454746552,
           58.91420002179812,
           58.42863549613069,
           57.943070970463296,
           57.45750644479589,
           56.971941919128476,
           56.48637739346108,
           56.00081286779366,
           55.51524834212625,
           55.02968381645884,
           54.54411929079143,
           54.058554765124036,
           53.57299023945662,
           53.087425713789216,
           52.60186118812182,
           52.10548119235703,
           51.600088340237996,
           51.09469548811895,
           50.58930263599992,
           50.08390978388087,
           49.578516931761854,
           49.07312407964282,
           48.56773122752378,
           48.062338375404735,
           47.5569455232857,
           47.05155267116669,
           46.546159819047645,
           46.04076696692861,
           45.53537411480957,
           45.02998126269055,
           44.52458841057151,
           44.019195558452466,
           43.513802706333436,
           43.00840985421439,
           42.503017002095376,
           41.99762414997633,
           41.492231297857295,
           40.98683844573826,
           40.48144559361924,
           39.976052741500204,
           39.47065988938116,
           38.96526703726212,
           38.459874185143086,
           37.95448133302406,
           37.449088480905026,
           36.94369562878599,
           36.43830277666696,
           35.93290992454791,
           35.4275170724289,
           34.922124220309854,
           34.41673136819081,
           33.91133851607178,
           33.40594566395276,
           32.90055281183372,
           32.395159959714675,
           31.88976710759564,
           31.3843742554766,
           31.007935370493676,
           30.760450452646698,
           30.512965534799832,
           30.265480616952964,
           30.017995699106027,
           29.77051078125916,
           29.523025863412293,
           29.275540945565407,
           29.028056027718428,
           28.78369398451043,
           28.546222091755265,
           28.30875019900007,
           28.071278306244885,
           27.833806413489743,
           27.596334520734583,
           27.358862627979445,
           27.12139073522426,
           26.883918842469058,
           26.646446949713958,
           26.40897505695877,
           26.171503164203617,
           25.93403127144842,
           25.69655937869329,
           25.459087485938134,
           25.22973554526427,
           25.002655260085866,
           24.775574974907467,
           24.54849468972902,
           24.321414404550573,
           24.094334119372174,
           23.86725383419376,
           23.640173549015312,
           23.41309326383692,
           23.186012978658468,
           22.958932693480094,
           22.731852408301652,
           22.504772123123256,
           22.285965167150604,
           22.0679975316189,
           21.850029896087158,
           21.632062260555482,
           21.41409462502374,
           21.196126989492,
           20.97815935396032,
           20.760191718428565,
           20.54222408289684,
           20.324256447365123,
           20.10628881183341,
           19.892253113357715,
           19.683575640996416,
           19.474898168635075,
           19.266220696273777,
           19.05754322391248,
           18.848865751551138,
           18.64018827918983,
           18.431510806828545,
           18.222833334467232,
           18.014155862105856,
           17.806855727221134,
           17.610241839328854,
           17.413627951436535,
           17.217014063544262,
           17.02040017565195,
           16.823786287759663,
           16.627172399867355,
           16.43055851197508,
           16.233944624082756,
           16.03733073619047,
           15.851355499884487,
           15.66789217074592,
           15.484428841607325,
           15.300965512468771,
           15.117502183330215,
           14.93403885419162,
           14.750575525053065,
           14.567112195914481,
           14.388087934229263,
           14.216691969675287,
           14.04529600512126,
           13.873900040567248,
           13.70250407601321,
           13.531108111459211,
           13.359712146905208,
           13.188316182351175,
           13.02435104626687,
           12.863951207038525,
           12.703551367810146,
           12.543151528581799,
           12.38275168935343,
           12.222351850125074,
           12.061952010896695,
           11.907951643605768,
           11.7575940546092,
           11.607236465612631,
           11.456878876616052,
           11.306521287619494,
           11.156163698622926,
           11.00738556017953,
           10.866188778815133,
           10.724991997450706,
           10.583795216086308,
           10.44259843472189,
           10.301401653357484,
           10.161996230054735,
           10.02917593956339,
           9.896355649072046,
           9.763535358580675,
           9.63071506808933,
           9.497894777597972,
           9.370583840810376,
           9.24558547305934,
           9.120587105308307,
           8.995588737557247,
           8.87059036980619,
           8.751014509217576,
           8.635130025119693,
           8.519245541021824,
           8.403361056923949,
           8.287476572826103,
           8.179940300421833,
           8.073950980652244,
           7.9679616608826676,
           7.861972341113083,
           7.758882439544843,
           7.659895488929589,
           7.560908538314317,
           7.4619215876990435,
           7.364352821858008,
           7.270531188283698,
           7.176709554709381,
           7.082887921135082,
           6.991680038566538,
           6.904432870043687,
           6.817185701520851,
           6.729938532998014,
           6.647954310874351,
           6.567642427007595,
           6.487330543140857,
           6.409093060704976,
           6.334933824470656,
           6.260774588236331,
           6.187233918870917,
           6.118520494526464,
           6.04980707018203,
           5.980112667252812,
           5.89766554272145,
           5.8152184181900965,
           5.732771293658747,
           5.650324169127385,
           5.5678770445960275,
           5.485429920064681,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           67.80962564856236,
           67.84952256961388,
           67.88941949066539,
           67.92931641171691,
           67.96921333276843,
           68.00911025381996,
           68.04900717487146,
           68.08890409592298,
           68.1288010169745,
           68.16869793802603,
           68.20859485907755,
           68.24849178012906,
           68.28838870118058,
           68.3282856222321,
           68.36818254328362,
           68.40807946433515,
           68.44797638538665,
           68.48787330643817,
           68.5277702274897,
           68.56766714854122,
           68.60756406959274,
           68.64746099064425,
           68.68735791169578,
           68.72725483274729,
           68.76715175379881,
           68.80704867485034,
           68.84694559590184,
           68.88684251695338,
           68.92673943800489,
           68.9666363590564,
           69.00653328010793,
           69.04643020115944,
           69.08632712221096,
           69.12622404326248,
           69.16612096431399,
           69.20601788536553,
           69.24591480641703,
           69.28581172746856,
           69.32570864852008,
           69.36560556957158,
           69.4055024906231,
           69.44539941167463,
           69.48529633272615,
           69.52519325377767,
           69.56509017482918,
           69.6049870958807,
           69.64488401693222,
           69.68478093798375,
           69.72467785903525,
           69.76457478008678,
           69.8044717011383,
           69.84436862218982,
           69.88426554324133,
           69.92416246429285,
           69.96405938534437,
           70.00395630639589,
           70.04385322744741,
           70.08375014849892,
           70.12364706955044,
           70.16354399060197,
           70.20344091165349,
           70.24333783270501,
           70.28323475375652,
           70.32313167480805,
           70.36302859585956,
           70.40292551691108,
           70.44282243796259,
           70.48271935901413,
           70.52261628006565,
           70.56251320111716,
           70.60241012216868,
           70.6434430892643,
           70.68470326553353,
           70.72596344180276,
           70.767223618072,
           70.80848379434123,
           70.84974397061046,
           70.8910041468797,
           70.93226432314891,
           70.97352449941816,
           71.0147846756874,
           71.05604485195663,
           71.09730502822586,
           71.1385652044951,
           71.15627096527,
           71.16926584294605,
           71.18226072062208,
           71.19525559829812,
           71.20825047597417,
           71.2212453536502,
           71.23424023132625,
           71.24723510900229,
           71.26022998667834,
           71.27322486435438,
           71.28621974203044,
           71.29921461970646,
           71.31220949738251,
           71.32520437505856,
           71.3381992527346,
           71.35119413041065,
           71.36418900808668,
           71.37718388576273,
           71.39017876343877,
           71.40317364111482,
           71.41616851879085,
           71.42916339646689,
           71.44215827414294,
           71.45515315181898,
           71.46814802949503,
           71.48114290717108,
           71.49413778484711,
           71.50713266252315,
           71.5201275401992,
           71.53312241787525,
           71.54611729555128,
           71.55911217322733,
           71.57210705090337,
           71.5851019285794,
           71.59809680625547,
           71.6110916839315,
           71.62408656160756,
           71.63708143928359,
           71.65007631695963,
           71.66307119463568,
           71.67606607231171,
           71.68906094998775,
           71.7020558276638,
           71.71505070533985,
           71.72804558301588,
           71.74104046069193,
           71.75403533836797,
           71.767030216044,
           71.78002509372006,
           71.79301997139609,
           71.80601484907214,
           71.81900972674818,
           71.83200460442423,
           71.84499948210028,
           71.85799435977631,
           71.87098923745236,
           71.8839841151284,
           71.89697899280445,
           71.90997387048048,
           71.92296874815653,
           71.93596362583257,
           71.94895850350862,
           71.96195338118466,
           71.9749482588607,
           71.98794313653674,
           72.00093801421279,
           72.01393289188883,
           72.02692776956488,
           72.03992264724091,
           72.05291752491696,
           72.06755120852596,
           72.08300429502206,
           72.09845738151817,
           72.11391046801427,
           72.12936355451038,
           72.14481664100649,
           72.1602697275026,
           72.1757228139987,
           72.19117590049481,
           72.20662898699092,
           72.22208207348703,
           72.23753515998314,
           72.25298824647925,
           71.93442959153299,
           71.44886506586559,
           70.96330054019818,
           70.47773601453076,
           69.99217148886338,
           69.50660696319594,
           69.02104243752855,
           68.53547791186114,
           68.04991338619372,
           67.56434886052634,
           67.0787843348589,
           66.5932198091915,
           66.1076552835241,
           65.62209075785668,
           65.13652623218928,
           64.65096170652187,
           64.16539718085446,
           63.67983265518705,
           63.183452668543296,
           62.67805981642428,
           62.17266696430524,
           61.6672741121862,
           61.16188126006719,
           60.656488407948125,
           60.1510955558291,
           59.645702703710064,
           59.140309851591034,
           58.63491699947201,
           58.129524147352946,
           57.62413129523393,
           57.11873844311489,
           56.613345590995856,
           56.10795273887684,
           55.6025598867578,
           55.09716703463876,
           54.59177418251972,
           54.086381330400684,
           53.58098847828167,
           53.07559562616263,
           52.57020277404359,
           52.06480992192458,
           51.559417069805534,
           51.05402421768649,
           50.54863136556745,
           50.043238513448415,
           49.53784566132937,
           49.032452809210355,
           48.52705995709132,
           48.02166710497228,
           47.516274252853236,
           47.0108814007342,
           46.505488548615176,
           46.000095696496146,
           45.4947028443771,
           44.98930999225806,
           44.48391714013905,
           43.978524288020004,
           43.47313143590097,
           42.96773858378193,
           42.462345731662886,
           41.95695287954387,
           41.45156002742483,
           40.946167175305796,
           40.44077432318676,
           39.93538147106774,
           39.4299886189487,
           38.92459576682966,
           38.419202914710624,
           37.91381006259158,
           37.40841721047257,
           36.90302435835353,
           36.39763150623449,
           35.892238654115445,
           35.38684580199641,
           34.88145294987739,
           34.376060097758355,
           33.87066724563931,
           33.365274393520274,
           32.85988154140126,
           32.35448868928222,
           31.84909583716318,
           31.34370298504414,
           30.838310132925095,
           30.461871247942177,
           30.214386330095195,
           29.966901412248326,
           29.719416494401457,
           29.471931576554525,
           29.22514063122774,
           28.987668738472557,
           28.750196845717404,
           28.512724952962248,
           28.275253060207078,
           28.037781167451918,
           27.800309274696723,
           27.56283738194153,
           27.325365489186392,
           27.087893596431236,
           26.850421703676094,
           26.61294981092091,
           26.375477918165704,
           26.138006025410608,
           25.90053413265542,
           25.666300553046153,
           25.439220267867658,
           25.212139982689312,
           24.98505969751086,
           24.757979412332446,
           24.530899127154044,
           24.303818841975644,
           24.076738556797196,
           23.84965827161875,
           23.62257798644035,
           23.395497701261938,
           23.16841741608349,
           22.941337130905097,
           22.71641510744633,
           22.498447471914574,
           22.280479836382874,
           22.06251220085113,
           21.84454456531942,
           21.626576929787714,
           21.408609294255974,
           21.190641658724292,
           20.97267402319255,
           20.75470638766081,
           20.536738752129136,
           20.31877111659738,
           20.106123160350165,
           19.897445687988856,
           19.688768215627515,
           19.480090743266217,
           19.27141327090492,
           19.062735798543578,
           18.854058326182276,
           18.64538085382098,
           18.43670338145964,
           18.22802590909833,
           18.02058329091826,
           17.82396940302594,
           17.62735551513365,
           17.430741627241375,
           17.2341277393491,
           17.03751385145678,
           16.840899963564503,
           16.64428607567219,
           16.447672187779908,
           16.251058299887596,
           16.06301443631991,
           15.879551107181317,
           15.696087778042749,
           15.512624448904207,
           15.32916111976564,
           15.145697790627045,
           14.962234461488489,
           14.778771132349934,
           14.596255954500016,
           14.42485998994599,
           14.253464025392015,
           14.082068060837953,
           13.910672096283978,
           13.739276131729952,
           13.567880167175938,
           13.396484202621902,
           13.228015533977107,
           13.06761569474876,
           12.907215855520406,
           12.746816016292057,
           12.586416177063713,
           12.426016337835332,
           12.265616498606988,
           12.106398099313305,
           11.956040510316736,
           11.80568292132017,
           11.6553253323236,
           11.50496774332703,
           11.35461015433046,
           11.20425256533388,
           11.058949216007395,
           10.917752434642969,
           10.776555653278571,
           10.635358871914173,
           10.494162090549747,
           10.352965309185349,
           10.215956773332373,
           10.083136482841004,
           9.950316192349652,
           9.817495901858306,
           9.684675611366963,
           9.551855320875593,
           9.42610876862709,
           9.301110400876055,
           9.176112033125,
           9.051113665373961,
           8.926115297622928,
           8.807634121398799,
           8.691749637300916,
           8.575865153203063,
           8.45998066910518,
           8.34409618500731,
           8.237013329840803,
           8.131024010071226,
           8.025034690301627,
           7.919045370532038,
           7.815791350932419,
           7.716804400317158,
           7.617817449701903,
           7.518830499086649,
           7.420806352642073,
           7.326984719067767,
           7.233163085493468,
           7.139341451919158,
           7.047155417237352,
           6.959908248714505,
           6.872661080191668,
           6.785413911668817,
           6.702003283479385,
           6.621691399612642,
           6.541379515745884,
           6.461547425086955,
           6.387388188852645,
           6.313228952618315,
           6.2390697163839945,
           6.169288961690516,
           6.100575537346074,
           6.031862113001622,
           5.9533389028093975,
           5.870891778278047,
           5.788444653746685,
           5.705997529215332,
           5.623550404683982,
           5.541103280152621,
           5.458656155621262,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           67.78063556616722,
           67.81917959314718,
           67.85772362012716,
           67.89626764710714,
           67.93548812092877,
           67.97538504198029,
           68.01528196303181,
           68.05517888408333,
           68.09507580513484,
           68.13497272618636,
           68.17486964723788,
           68.21476656828939,
           68.25466348934093,
           68.29456041039244,
           68.33445733144396,
           68.37435425249548,
           68.41425117354699,
           68.45414809459851,
           68.49404501565003,
           68.53394193670155,
           68.57383885775306,
           68.61373577880458,
           68.6536326998561,
           68.69352962090763,
           68.73342654195915,
           68.77332346301066,
           68.81322038406218,
           68.8531173051137,
           68.89301422616522,
           68.93291114721674,
           68.97280806826825,
           69.01270498931977,
           69.0526019103713,
           69.09249883142282,
           69.13239575247434,
           69.17229267352585,
           69.21218959457737,
           69.25208651562889,
           69.29198343668041,
           69.33188035773193,
           69.37177727878344,
           69.41167419983496,
           69.45157112088648,
           69.49146804193799,
           69.53136496298951,
           69.57126188404104,
           69.61115880509256,
           69.65105572614408,
           69.69095264719559,
           69.73084956824711,
           69.77074648929863,
           69.81064341035015,
           69.85054033140167,
           69.89043725245318,
           69.9303341735047,
           69.97023109455623,
           70.01012801560775,
           70.05002493665927,
           70.08992185771078,
           70.1298187787623,
           70.16971569981382,
           70.20961262086534,
           70.24950954191686,
           70.28940646296837,
           70.3293033840199,
           70.36920030507142,
           70.40909722612292,
           70.44899414717445,
           70.48889106822597,
           70.52878798927749,
           70.56868491032901,
           70.60858183138052,
           70.64847875243204,
           70.68837567348356,
           70.72827259453508,
           70.7681695155866,
           70.80806643663813,
           70.84796335768965,
           70.88786027874116,
           70.92775719979267,
           70.9676541208442,
           71.00755104189571,
           71.04744796294723,
           71.08734488399875,
           71.10243136910587,
           71.11255576702409,
           71.12268016494232,
           71.13376138903463,
           71.14675626671068,
           71.15975114438672,
           71.17274602206277,
           71.1857408997388,
           71.19873577741485,
           71.21173065509089,
           71.22472553276694,
           71.23772041044298,
           71.25071528811903,
           71.26371016579506,
           71.27670504347111,
           71.28969992114716,
           71.30269479882318,
           71.31568967649923,
           71.32868455417528,
           71.34167943185132,
           71.35467430952735,
           71.3676691872034,
           71.38066406487945,
           71.39365894255549,
           71.40665382023154,
           71.41964869790758,
           71.43264357558361,
           71.44563845325966,
           71.4586333309357,
           71.47162820861175,
           71.4846230862878,
           71.49761796396383,
           71.51061284163987,
           71.52360771931592,
           71.53660259699197,
           71.549597474668,
           71.56259235234405,
           71.57558723002009,
           71.58858210769614,
           71.60157698537218,
           71.61457186304821,
           71.62756674072426,
           71.64056161840031,
           71.65355649607635,
           71.66655137375238,
           71.67954625142843,
           71.69254112910448,
           71.70553600678052,
           71.71853088445656,
           71.7315257621326,
           71.74452063980866,
           71.75751551748469,
           71.77051039516073,
           71.78350527283678,
           71.79650015051283,
           71.80949502818886,
           71.82248990586491,
           71.83548478354095,
           71.848479661217,
           71.86147453889303,
           71.87446941656908,
           71.88746429424512,
           71.90045917192117,
           71.9134540495972,
           71.92644892727324,
           71.93944380494929,
           71.95243868262534,
           71.96543356030138,
           71.97842843797741,
           71.99142331565346,
           72.00441819332951,
           72.01741307100555,
           72.0304079486816,
           72.04340282635764,
           72.05639770403369,
           72.06939258170972,
           72.08238745938577,
           72.0953823370618,
           72.10837721473786,
           72.12137209241389,
           72.13436697008994,
           72.14736184776598,
           72.16035672544203,
           71.82544177343365,
           71.31657190658312,
           70.80770203973258,
           70.29883217288203,
           69.7899623060315,
           69.28109243918092,
           68.7722225723304,
           68.26335270547986,
           67.7544828386293,
           67.24561297177878,
           66.7367431049282,
           66.22787323807768,
           65.71900337122712,
           65.21013350437657,
           64.70126363752604,
           64.1923937706755,
           63.68352390382494,
           63.17465403697439,
           62.665784170123835,
           62.15691430327331,
           61.648044436422765,
           61.13917456957221,
           60.63030470272169,
           60.121434835871106,
           59.61256496902058,
           59.10369510217003,
           58.59482523531948,
           58.088852876920484,
           57.583460024801425,
           57.07806717268241,
           56.57267432056337,
           56.067281468444335,
           55.56188861632531,
           55.056495764206275,
           54.55110291208723,
           54.045710059968194,
           53.54031720784916,
           53.03492435573014,
           52.5295315036111,
           52.02413865149206,
           51.51874579937305,
           51.013352947254,
           50.50796009513497,
           50.00256724301594,
           49.49717439089689,
           48.99178153877785,
           48.486388686658835,
           47.98099583453979,
           47.475602982420746,
           46.970210130301716,
           46.46481727818267,
           45.95942442606366,
           45.45403157394461,
           44.94863872182558,
           44.443245869706544,
           43.93785301758753,
           43.432460165468484,
           42.92706731334945,
           42.42167446123041,
           41.91628160911137,
           41.41088875699236,
           40.90549590487331,
           40.400103052754275,
           39.89471020063524,
           39.38931734851622,
           38.88392449639717,
           38.378531644278134,
           37.8731387921591,
           37.36774594004006,
           36.86235308792104,
           36.356960235802006,
           35.85156738368296,
           35.346174531563925,
           34.84078167944489,
           34.33538882732587,
           33.82999597520683,
           33.32460312308778,
           32.81921027096875,
           32.31381741884973,
           31.808424566730697,
           31.303031714611656,
           30.79763886249261,
           30.292246010373574,
           29.91580712539065,
           29.668322207543675,
           29.42911538518986,
           29.19164349243467,
           28.954171599679565,
           28.716699706924373,
           28.47922781416919,
           28.241755921414036,
           28.004284028658876,
           27.76681213590371,
           27.52934024314855,
           27.29186835039335,
           27.054396457638166,
           26.816924564883024,
           26.579452672127864,
           26.341980779372726,
           26.104508886617538,
           25.875785275649566,
           25.648704990471124,
           25.421624705292686,
           25.194544420114315,
           24.967464134935824,
           24.74038384975747,
           24.513303564579022,
           24.28622327940061,
           24.059142994222206,
           23.832062709043807,
           23.60498242386536,
           23.377902138686913,
           23.150821853508514,
           22.928897412210286,
           22.71092977667857,
           22.49296214114684,
           22.274994505615126,
           22.057026870083376,
           21.839059234551666,
           21.621091599019927,
           21.403123963488216,
           21.18515632795651,
           20.96718869242477,
           20.74922105689309,
           20.531253421361345,
           20.319993207342588,
           20.111315734981282,
           19.902638262619938,
           19.69396079025865,
           19.48528331789734,
           19.276605845536004,
           19.067928373174702,
           18.859250900813404,
           18.650573428452063,
           18.441895956090768,
           18.234310854615334,
           18.037696966723075,
           17.841083078830756,
           17.64446919093849,
           17.447855303046172,
           17.25124141515388,
           17.0546275272616,
           16.858013639369325,
           16.661399751477006,
           16.46478586358473,
           16.274673372755355,
           16.091210043616734,
           15.907746714478176,
           15.72428338533962,
           15.540820056201028,
           15.35735672706246,
           15.173893397923917,
           14.990430068785349,
           14.806966739646754,
           14.633028010216734,
           14.461632045662734,
           14.290236081108695,
           14.118840116554669,
           13.947444152000694,
           13.776048187446632,
           13.604652222892655,
           13.43325625833863,
           13.271280182459032,
           13.11088034323065,
           12.950480504002282,
           12.790080664773937,
           12.62968082554558,
           12.469280986317234,
           12.30888114708889,
           12.154486966024244,
           12.004129377027706,
           11.853771788031127,
           11.703414199034558,
           11.553056610037988,
           11.40269902104142,
           11.252341432044851,
           11.110512871835223,
           10.969316090470825,
           10.828119309106427,
           10.686922527742,
           10.545725746377602,
           10.404528965013204,
           10.269917316609973,
           10.137097026118628,
           10.004276735627284,
           9.871456445135916,
           9.738636154644563,
           9.606632064194836,
           9.481633696443799,
           9.356635328692741,
           9.231636960941705,
           9.10663859319067,
           8.981640225439614,
           8.864253733580007,
           8.748369249482147,
           8.63248476538428,
           8.516600281286395,
           8.400715797188543,
           8.29408635925975,
           8.188097039490167,
           8.08210771972059,
           7.9761183999510115,
           7.872700262319993,
           7.773713311704739,
           7.674726361089473,
           7.575739410474212,
           7.477259883426145,
           7.383438249851846,
           7.289616616277527,
           7.195794982703223,
           7.102630795908157,
           7.015383627385319,
           6.928136458862477,
           6.84088929033963,
           6.7560522560844145,
           6.675740372217666,
           6.595428488350915,
           6.515116604484172,
           6.439842553234613,
           6.3656833170002916,
           6.291524080765981,
           6.220057428854565,
           6.15134400451012,
           6.08263058016567,
           6.009012262897338,
           5.926565138365979,
           5.844118013834626,
           5.761670889303275,
           5.679223764771914,
           5.59677664024056,
           5.5143295157092105,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           67.74409948043166,
           67.78264350741163,
           67.82118753439161,
           67.85973156137158,
           67.89827558835154,
           67.93681961533153,
           67.97536364231149,
           68.01390766929146,
           68.05245169627145,
           68.09099572325141,
           68.12953975023139,
           68.16808377721135,
           68.20662780419133,
           68.24517183117129,
           68.28371585815127,
           68.32225988513125,
           68.36080391211121,
           68.39934793909119,
           68.43789196607116,
           68.47643599305113,
           68.51498002003109,
           68.55487694066528,
           68.59477386171679,
           68.63467078276831,
           68.67456770381983,
           68.71446462487135,
           68.75436154592288,
           68.79425846697438,
           68.8341553880259,
           68.87405230907743,
           68.91394923012895,
           68.95384615118047,
           68.99374307223198,
           69.0336399932835,
           69.07353691433502,
           69.11343383538654,
           69.15333075643805,
           69.19322767748957,
           69.2331245985411,
           69.27302151959262,
           69.31291844064414,
           69.35281536169566,
           69.39271228274717,
           69.43260920379869,
           69.47250612485021,
           69.51240304590173,
           69.55229996695326,
           69.59219688800476,
           69.63209380905629,
           69.67199073010781,
           69.71188765115933,
           69.75178457221085,
           69.79168149326236,
           69.83157841431387,
           69.8714753353654,
           69.91137225641693,
           69.95126917746845,
           69.99116609851995,
           70.03106301957146,
           70.07095994062298,
           70.11085686167452,
           70.15075378272604,
           70.19065070377755,
           70.23054762482906,
           70.27044454588058,
           70.31034146693212,
           70.35023838798362,
           70.39013530903514,
           70.43003223008667,
           70.46992915113817,
           70.50982607218971,
           70.54972299324122,
           70.58961991429274,
           70.62951683534425,
           70.66941375639577,
           70.7093106774473,
           70.74920759849881,
           70.78910451955034,
           70.82900144060186,
           70.86889836165338,
           70.90879528270489,
           70.94869220375641,
           70.98858912480793,
           71.02848604585945,
           71.04357253096656,
           71.05369692888479,
           71.06382132680301,
           71.07394572472124,
           71.08407012263946,
           71.09419452055769,
           71.10431891847591,
           71.11444331639414,
           71.12456771431238,
           71.1346921122306,
           71.14481651014884,
           71.15494090806706,
           71.1650653059853,
           71.17518970390351,
           71.18531410182175,
           71.19543849973996,
           71.2055628976582,
           71.21568729557643,
           71.22581169349465,
           71.23593609141288,
           71.24845255491047,
           71.26144743258652,
           71.27444231026256,
           71.2874371879386,
           71.30043206561464,
           71.3134269432907,
           71.32642182096673,
           71.33941669864276,
           71.35241157631881,
           71.36540645399486,
           71.3784013316709,
           71.39139620934695,
           71.40439108702299,
           71.41738596469904,
           71.43038084237507,
           71.44337572005111,
           71.45637059772716,
           71.46936547540321,
           71.48236035307924,
           71.49535523075528,
           71.50835010843133,
           71.52134498610737,
           71.53433986378343,
           71.54733474145945,
           71.5603296191355,
           71.57332449681155,
           71.58631937448759,
           71.59931425216362,
           71.61230912983967,
           71.62530400751572,
           71.63829888519176,
           71.6512937628678,
           71.66428864054384,
           71.6772835182199,
           71.69027839589593,
           71.70327327357198,
           71.71626815124802,
           71.72926302892405,
           71.7422579066001,
           71.75525278427614,
           71.76824766195219,
           71.78124253962822,
           71.79423741730427,
           71.80723229498032,
           71.82022717265636,
           71.8332220503324,
           71.84621692800845,
           71.8592118056845,
           71.87220668336053,
           71.88520156103657,
           71.89819643871263,
           71.91119131638867,
           71.9241861940647,
           71.93718107174075,
           71.95017594941679,
           71.96317082709282,
           71.97616570476887,
           71.98916058244492,
           72.00215546012096,
           72.015150337797,
           72.02814521547305,
           72.0411400931491,
           72.05413497082513,
           71.71922001881677,
           71.21035015196625,
           70.7014802851157,
           70.19261041826515,
           69.6837405514146,
           69.17487068456404,
           68.66600081771351,
           68.15713095086295,
           67.6482610840124,
           67.13939121716189,
           66.63052135031131,
           66.12165148346078,
           65.61278161661023,
           65.10391174975967,
           64.59504188290916,
           64.0861720160586,
           63.57730214920805,
           63.068432282357506,
           62.559562415506946,
           62.05069254865642,
           61.54182268180587,
           61.032952814955316,
           60.52408294810479,
           60.01521308125422,
           59.506343214403685,
           58.99747334755314,
           58.48860348070259,
           57.97973361385206,
           57.47086374700149,
           56.96199388015097,
           56.45312401330041,
           55.944254146449865,
           55.435384279599326,
           54.92651441274879,
           54.41764454589823,
           53.90877467904768,
           53.39990481219713,
           52.891034945346604,
           52.38216507849605,
           51.8732952116455,
           51.36442534479497,
           50.85555547794442,
           50.346685611093875,
           49.837815744243315,
           49.32894587739276,
           48.820076010542216,
           48.31120614369169,
           47.80233627684113,
           47.293466409990586,
           46.78459654314004,
           46.27572667628948,
           45.76685680943896,
           45.25798694258841,
           44.74911707573786,
           44.24024720888731,
           43.73137734203678,
           43.222507475186234,
           42.713637608335674,
           42.20476774148513,
           41.69589787463458,
           41.18702800778405,
           40.6781581409335,
           40.169288274082945,
           39.6604184072324,
           39.15154854038187,
           38.64267867353132,
           38.13380880668077,
           37.624938939830216,
           37.11606907297966,
           36.60719920612914,
           36.098329339278585,
           35.58945947242803,
           35.080059665033154,
           34.549992477198984,
           34.01992528936483,
           33.48985810153066,
           32.95979091369648,
           32.4297237258623,
           31.89965653802815,
           31.36958935019398,
           30.839522162359803,
           30.30945497452563,
           29.77938778669145,
           29.39561824639683,
           29.158146353641627,
           28.92067446088653,
           28.683202568131343,
           28.44573067537623,
           28.208258782621044,
           27.97078688986586,
           27.733314997110703,
           27.495843104355547,
           27.258371211600377,
           27.020899318845217,
           26.78342742609002,
           26.545955533334837,
           26.31235028343143,
           26.08526999825298,
           25.85818971307462,
           25.631109427896178,
           25.404029142717768,
           25.176948857539326,
           24.949868572360884,
           24.722788287182514,
           24.495708002004022,
           24.268627716825673,
           24.04154743164722,
           23.814467146468807,
           23.587386861290405,
           23.360306576112006,
           23.141379716974274,
           22.923412081442606,
           22.70544444591083,
           22.487476810379118,
           22.2695091748474,
           22.051541539315668,
           21.833573903783957,
           21.6156062682522,
           21.397638632720497,
           21.179670997188758,
           20.961703361657047,
           20.743735726125337,
           20.53386325433508,
           20.3251857819737,
           20.11650830961244,
           19.907830837251105,
           19.6991533648898,
           19.49047589252846,
           19.28179842016717,
           19.073120947805858,
           18.86444347544452,
           18.65576600308322,
           18.448038418312525,
           18.25142453042021,
           18.0548106425279,
           17.85819675463559,
           17.661582866743334,
           17.464968978851015,
           17.268355090958746,
           17.07174120306643,
           16.87512731517414,
           16.678513427281864,
           16.486332309190765,
           16.3028689800522,
           16.119405650913645,
           15.935942321775089,
           15.752478992636465,
           15.569015663497911,
           15.385552334359355,
           15.202089005220762,
           15.018625676082193,
           14.841196030487486,
           14.669800065933451,
           14.49840410137941,
           14.327008136825437,
           14.155612172271436,
           13.984216207717395,
           13.812820243163372,
           13.641424278609396,
           13.474944670169275,
           13.314544830940932,
           13.154144991712608,
           12.99374515248423,
           12.833345313255847,
           12.672945474027479,
           12.512545634799134,
           12.352933421731793,
           12.202575832735276,
           12.052218243738695,
           11.901860654742086,
           11.751503065745545,
           11.601145476748968,
           11.4507878877524,
           11.303273309027494,
           11.162076527663107,
           11.020879746298698,
           10.879682964934272,
           10.738486183569874,
           10.597289402205476,
           10.456698150378957,
           10.323877859887594,
           10.191057569396268,
           10.058237278904897,
           9.925416988413554,
           9.79259669792221,
           9.662156992011557,
           9.537158624260499,
           9.412160256509464,
           9.28716188875843,
           9.16216352100737,
           9.037165153256336,
           8.920873345761246,
           8.804988861663375,
           8.689104377565501,
           8.573219893467641,
           8.457335409369772,
           8.351159388678717,
           8.245170068909147,
           8.139180749139548,
           8.033191429369964,
           7.929609173707586,
           7.830622223092332,
           7.7316352724770585,
           7.632648321861804,
           7.533713414210227,
           7.439891780635898,
           7.34607014706161,
           7.252248513487311,
           7.158426879912993,
           7.070859006056127,
           6.9836118375332905,
           6.896364669010454,
           6.8101012286894385,
           6.729789344822696,
           6.649477460955952,
           6.569165577089204,
           6.492296917616594,
           6.4181376813822855,
           6.343978445147957,
           6.27082589601861,
           6.202112471674173,
           6.133399047329727,
           6.064685622985281,
           5.982238498453931,
           5.899791373922578,
           5.817344249391219,
           5.734897124859865,
           5.652450000328516,
           5.570002875797154,
           5.4875557512658,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           67.70756339469611,
           67.74610742167607,
           67.78465144865605,
           67.82319547563603,
           67.86173950261599,
           67.90028352959597,
           67.93882755657594,
           67.97737158355591,
           68.01591561053588,
           68.05445963751585,
           68.09300366449582,
           68.13154769147579,
           68.17009171845577,
           68.20863574543574,
           68.2471797724157,
           68.28572379939568,
           68.32426782637566,
           68.36281185335562,
           68.4013558803356,
           68.43989990731558,
           68.47844393429554,
           68.5169879612755,
           68.55553198825548,
           68.59407601523546,
           68.63262004221542,
           68.6711640691954,
           68.70970809617538,
           68.74825212315534,
           68.78679615013532,
           68.8253401771153,
           68.86388420409526,
           68.90242823107523,
           68.9409722580552,
           68.97951628503517,
           69.01806031201514,
           69.05660433899511,
           69.09514836597509,
           69.13436883935027,
           69.1742657604018,
           69.2141626814533,
           69.25405960250482,
           69.29395652355635,
           69.33385344460787,
           69.37375036565939,
           69.4136472867109,
           69.45354420776242,
           69.49344112881394,
           69.53333804986546,
           69.57323497091699,
           69.6131318919685,
           69.65302881302001,
           69.69292573407154,
           69.73282265512306,
           69.77271957617458,
           69.81261649722609,
           69.85251341827761,
           69.89241033932913,
           69.93230726038064,
           69.97220418143218,
           70.01210110248368,
           70.0519980235352,
           70.09189494458673,
           70.13179186563823,
           70.17168878668977,
           70.21158570774128,
           70.2514826287928,
           70.29137954984431,
           70.33127647089583,
           70.37117339194737,
           70.41107031299887,
           70.4509672340504,
           70.4908641551019,
           70.53076107615342,
           70.57065799720495,
           70.61055491825647,
           70.65045183930799,
           70.6903487603595,
           70.73024568141103,
           70.77014260246254,
           70.81003952351406,
           70.84993644456559,
           70.88983336561711,
           70.92973028666862,
           70.96962720772014,
           70.98471369282724,
           70.99483809074547,
           71.0049624886637,
           71.01508688658193,
           71.02521128450016,
           71.03533568241838,
           71.0454600803366,
           71.05558447825483,
           71.06570887617306,
           71.0758332740913,
           71.08595767200953,
           71.09608206992775,
           71.10620646784596,
           71.1163308657642,
           71.12645526368243,
           71.13657966160065,
           71.14670405951888,
           71.15682845743711,
           71.16695285535533,
           71.17707725327357,
           71.1872016511918,
           71.19732604911002,
           71.20745044702825,
           71.21757484494647,
           71.2276992428647,
           71.23782364078292,
           71.24794803870117,
           71.25807243661939,
           71.2681968345376,
           71.27832123245584,
           71.28844563037407,
           71.29857002829229,
           71.30869442621052,
           71.31881882412875,
           71.32894322204697,
           71.3390676199652,
           71.35014884311028,
           71.3631437207863,
           71.37613859846235,
           71.3891334761384,
           71.40212835381443,
           71.41512323149047,
           71.42811810916652,
           71.44111298684257,
           71.4541078645186,
           71.46710274219464,
           71.48009761987069,
           71.49309249754674,
           71.50608737522278,
           71.51908225289883,
           71.53207713057486,
           71.54507200825091,
           71.55806688592695,
           71.571061763603,
           71.58405664127903,
           71.59705151895508,
           71.61004639663112,
           71.62304127430717,
           71.6360361519832,
           71.64903102965926,
           71.66202590733529,
           71.67502078501133,
           71.68801566268738,
           71.70101054036343,
           71.71400541803946,
           71.72700029571551,
           71.73999517339155,
           71.7529900510676,
           71.76598492874363,
           71.77897980641968,
           71.79197468409572,
           71.80496956177177,
           71.8179644394478,
           71.83095931712386,
           71.84395419479989,
           71.85694907247593,
           71.86994395015199,
           71.88293882782803,
           71.89593370550406,
           71.9089285831801,
           71.92192346085615,
           71.9349183385322,
           71.94791321620825,
           71.61299826419987,
           71.10412839734934,
           70.5952585304988,
           70.08638866364824,
           69.5775187967977,
           69.06864892994713,
           68.55977906309661,
           68.05090919624605,
           67.54203932939551,
           67.03316946254498,
           66.52429959569442,
           66.01542972884388,
           65.50655986199334,
           64.99768999514279,
           64.48882012829226,
           63.9799502614417,
           63.47108039459115,
           62.9622105277406,
           62.45334066089005,
           61.944470794039525,
           61.43560092718897,
           60.92673106033842,
           60.417861193487894,
           59.90899132663733,
           59.40012145978679,
           58.89125159293625,
           58.3823817260857,
           57.873511859235165,
           57.364641992384584,
           56.85577212553406,
           56.346902258683514,
           55.83803239183296,
           55.32916252498243,
           54.82029265813188,
           54.31142279128133,
           53.80255292443078,
           53.29368305758023,
           52.7848131907297,
           52.275943323879154,
           51.7670734570286,
           51.25820359017807,
           50.749333723327524,
           50.24046385647697,
           49.73159398962642,
           49.22272412277587,
           48.71385425592532,
           48.204984389074795,
           47.69611452222424,
           47.18724465537369,
           46.67837478852314,
           46.16950492167259,
           45.660635054822066,
           45.15176518797152,
           44.64289530957901,
           44.11282812174484,
           43.58276093391069,
           43.052693746076514,
           42.522626558242344,
           41.992559370408166,
           41.462492182573996,
           40.93242499473984,
           40.40235780690566,
           39.87229061907149,
           39.342223431237315,
           38.81215624340316,
           38.28208905556899,
           37.75202186773481,
           37.22195467990064,
           36.691887492066456,
           36.161820304232315,
           35.63175311639814,
           35.10168592856396,
           34.57161874072979,
           34.04155155289561,
           33.511484365061456,
           32.981417177227286,
           32.45134998939311,
           31.921282801558934,
           31.391215613724782,
           30.86114842589061,
           30.331081238056434,
           29.801014050222257,
           29.27094686238808,
           28.887177322093457,
           28.64970542933825,
           28.41223353658316,
           28.17476164382797,
           27.937289751072857,
           27.699817858317672,
           27.462345965562484,
           27.22487407280733,
           26.987402180052175,
           26.749930287297005,
           26.52183500603488,
           26.29475472085639,
           26.067674435678033,
           25.84059415049959,
           25.613513865321135,
           25.38643358014278,
           25.159353294964337,
           24.932273009785924,
           24.705192724607482,
           24.478112439429044,
           24.251032154250677,
           24.023951869072178,
           23.796871583893832,
           23.571829657269944,
           23.353862021738227,
           23.13589438620656,
           22.917926750674784,
           22.699959115143063,
           22.481991479611402,
           22.26402384407962,
           22.04605620854791,
           21.828088573016192,
           21.610120937484464,
           21.392153301952746,
           21.174185666420996,
           20.956410773688795,
           20.747733301327536,
           20.53905582896616,
           20.33037835660482,
           20.121700884243563,
           19.913023411882183,
           19.704345939520923,
           19.49566846715959,
           19.286990994798284,
           19.07831352243694,
           18.869636050075652,
           18.661765982009626,
           18.465152094117308,
           18.268538206225,
           18.07192431833275,
           17.875310430440436,
           17.678696542548128,
           17.482082654655816,
           17.28546876676356,
           17.088854878871242,
           16.892240990978973,
           16.697991245626206,
           16.514527916487584,
           16.33106458734903,
           16.14760125821047,
           15.964137929071907,
           15.78067459993335,
           15.597211270794796,
           15.413747941656172,
           15.230284612517618,
           15.049364050758202,
           14.877968086204165,
           14.70657212165018,
           14.535176157096162,
           14.363780192542126,
           14.19238422798809,
           14.020988263434113,
           13.849592298880111,
           13.67860915787952,
           13.518209318651198,
           13.357809479422807,
           13.197409640194449,
           13.037009800966107,
           12.876609961737783,
           12.716210122509404,
           12.555810283281023,
           12.4010222884428,
           12.250664699446222,
           12.100307110449611,
           11.949949521453096,
           11.799591932456515,
           11.649234343459904,
           11.498876754463366,
           11.354836964855357,
           11.213640183490933,
           11.072443402126524,
           10.931246620762138,
           10.790049839397728,
           10.6488530580333,
           10.51065869365658,
           10.377838403165219,
           10.245018112673867,
           10.112197822182505,
           9.97937753169118,
           9.846557241199807,
           9.717681919828248,
           9.592683552077215,
           9.467685184326172,
           9.342686816575114,
           9.21768844882408,
           9.093377442040346,
           8.977492957942477,
           8.861608473844587,
           8.745723989746725,
           8.629839505648857,
           8.51422173786726,
           8.408232418097683,
           8.302243098328098,
           8.196253778558502,
           8.090264458788933,
           7.986518085095154,
           7.887531134479894,
           7.788544183864639,
           7.689557233249385,
           7.590570282634111,
           7.496345311419991,
           7.40252367784568,
           7.308702044271353,
           7.214880410697065,
           7.126334384726947,
           7.039087216204106,
           6.951840047681252,
           6.864592879158415,
           6.783838317427733,
           6.703526433560967,
           6.623214549694224,
           6.544751281998575,
           6.4705920457642545,
           6.39643280952993,
           6.322273573295622,
           6.252880938838224,
           6.184167514493764,
           6.115454090149327,
           6.037911858541878,
           5.955464734010516,
           5.873017609479167,
           5.790570484947812,
           5.708123360416454,
           5.6256762358851,
           5.5432291113537495,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           67.67102730896056,
           67.70957133594052,
           67.74811536292049,
           67.78665938990046,
           67.82520341688044,
           67.86374744386042,
           67.90229147084038,
           67.94083549782036,
           67.97937952480034,
           68.0179235517803,
           68.05646757876028,
           68.09501160574024,
           68.13355563272022,
           68.1720996597002,
           68.21064368668016,
           68.24918771366013,
           68.2877317406401,
           68.32627576762007,
           68.36481979460005,
           68.40336382158002,
           68.44190784855999,
           68.48045187553996,
           68.51899590251993,
           68.55753992949991,
           68.59608395647987,
           68.63462798345985,
           68.67317201043983,
           68.71171603741979,
           68.75026006439975,
           68.78880409137973,
           68.82734811835971,
           68.86589214533967,
           68.90443617231965,
           68.94298019929963,
           68.98152422627959,
           69.02006825325957,
           69.05861228023954,
           69.0971563072195,
           69.13570033419948,
           69.17424436117945,
           69.21278838815942,
           69.25133241513939,
           69.28987644211936,
           69.32842046909934,
           69.3669644960793,
           69.40550852305928,
           69.44405255003925,
           69.48259657701922,
           69.5211406039992,
           69.55968463097916,
           69.59822865795914,
           69.63677268493912,
           69.67531671191908,
           69.71386073889906,
           69.75375765908677,
           69.7936545801383,
           69.83355150118982,
           69.87344842224134,
           69.91334534329286,
           69.95324226434437,
           69.99313918539589,
           70.03303610644741,
           70.07293302749893,
           70.11282994855046,
           70.15272686960196,
           70.19262379065349,
           70.232520711705,
           70.27241763275651,
           70.31231455380805,
           70.35221147485956,
           70.39210839591108,
           70.4320053169626,
           70.47190223801412,
           70.51179915906563,
           70.55169608011715,
           70.59159300116868,
           70.63148992222018,
           70.67138684327172,
           70.71128376432323,
           70.75118068537475,
           70.79107760642627,
           70.83097452747779,
           70.8708714485293,
           70.91076836958082,
           70.92585485468794,
           70.93597925260616,
           70.94610365052438,
           70.95622804844261,
           70.96635244636084,
           70.97647684427906,
           70.9866012421973,
           70.99672564011553,
           71.00685003803375,
           71.01697443595198,
           71.02709883387021,
           71.03722323178843,
           71.04734762970668,
           71.05747202762488,
           71.06759642554312,
           71.07772082346135,
           71.08784522137957,
           71.0979696192978,
           71.10809401721603,
           71.11821841513425,
           71.12834281305248,
           71.1384672109707,
           71.14859160888894,
           71.15871600680715,
           71.16884040472539,
           71.17896480264362,
           71.18908920056185,
           71.19921359848007,
           71.2093379963983,
           71.21946239431652,
           71.22958679223476,
           71.23971119015299,
           71.2498355880712,
           71.25995998598944,
           71.27008438390766,
           71.28020878182589,
           71.29033317974412,
           71.30045757766234,
           71.31058197558058,
           71.32070637349881,
           71.33083077141703,
           71.34095516933526,
           71.35107956725348,
           71.36120396517171,
           71.37132836308994,
           71.38145276100818,
           71.3915771589264,
           71.40170155684463,
           71.41182595476286,
           71.42195035268108,
           71.4320747505993,
           71.44219914851753,
           71.45232354643576,
           71.4648400089861,
           71.47783488666214,
           71.49082976433819,
           71.50382464201422,
           71.51681951969027,
           71.52981439736631,
           71.54280927504234,
           71.5558041527184,
           71.56879903039443,
           71.58179390807048,
           71.59478878574652,
           71.60778366342257,
           71.62077854109862,
           71.63377341877465,
           71.6467682964507,
           71.65976317412674,
           71.67275805180279,
           71.68575292947882,
           71.69874780715487,
           71.71174268483091,
           71.72473756250696,
           71.737732440183,
           71.75072731785905,
           71.76372219553508,
           71.77671707321113,
           71.78971195088718,
           71.8027068285632,
           71.81570170623925,
           71.82869658391529,
           71.84169146159134,
           71.50677650958298,
           70.99790664273246,
           70.4890367758819,
           69.98016690903135,
           69.47129704218081,
           68.96242717533025,
           68.45355730847972,
           67.94468744162916,
           67.43581757477861,
           66.92694770792808,
           66.41807784107752,
           65.90920797422699,
           65.40033810737644,
           64.89146824052588,
           64.38259837367536,
           63.873728506824804,
           63.36485863997426,
           62.85598877312371,
           62.34711890627315,
           61.838249039422635,
           61.329379172572075,
           60.82050930572153,
           60.311639438871,
           59.80276957202042,
           59.29389970516989,
           58.785029838319346,
           58.27615997146879,
           57.76729010461826,
           57.25842023776769,
           56.74955037091717,
           56.24068050406661,
           55.73181063721607,
           55.22294077036553,
           54.714070903514994,
           54.205201036664434,
           53.675663766290704,
           53.14559657845653,
           52.61552939062238,
           52.08546220278821,
           51.55539501495402,
           51.02532782711988,
           50.4952606392857,
           49.96519345145153,
           49.43512626361735,
           48.90505907578318,
           48.374991887948994,
           47.84492470011485,
           47.31485751228068,
           46.784790324446504,
           46.25472313661233,
           45.72465594877815,
           45.194588760943994,
           44.66452157310982,
           44.134454385275646,
           43.604387197441476,
           43.07432000960732,
           42.54425282177314,
           42.014185633938965,
           41.48411844610479,
           40.954051258270624,
           40.423984070436475,
           39.89391688260229,
           39.36384969476812,
           38.83378250693394,
           38.303715319099794,
           37.77364813126562,
           37.24358094343144,
           36.71351375559727,
           36.18344656776309,
           35.65337937992894,
           35.123312192094765,
           34.59324500426059,
           34.06317781642642,
           33.53311062859224,
           33.00304344075809,
           32.472976252923914,
           31.94290906508974,
           31.412841877255566,
           30.882774689421417,
           30.35270750158724,
           29.822640313753062,
           29.292573125918885,
           28.76250593808471,
           28.37873639779009,
           28.141264505034886,
           27.903792612279794,
           27.666320719524602,
           27.428848826769492,
           27.191376934014304,
           26.95840001381671,
           26.73131972863822,
           26.50423944345984,
           26.277159158281457,
           26.050078873103043,
           25.82299858792455,
           25.595918302746192,
           25.368838017567754,
           25.141757732389298,
           24.914677447210938,
           24.687597162032496,
           24.460516876854083,
           24.233436591675645,
           24.006356306497203,
           23.784311962033936,
           23.56634432650222,
           23.348376690970532,
           23.130409055438744,
           22.912441419907026,
           22.694473784375358,
           22.47650614884358,
           22.258538513311866,
           22.040570877780198,
           21.822603242248423,
           21.60463560671671,
           21.38666797118499,
           21.17028082068127,
           20.961603348319894,
           20.752925875958617,
           20.544248403597283,
           20.335570931236024,
           20.126893458874648,
           19.918215986513314,
           19.70953851415205,
           19.500861041790674,
           19.29218356942941,
           19.08350609706808,
           18.8754935457067,
           18.678879657814413,
           18.482265769922176,
           18.285651882029857,
           18.089037994137538,
           17.892424106245233,
           17.695810218352985,
           17.499196330460666,
           17.302582442568358,
           17.105968554676046,
           16.90965018206159,
           16.72618685292302,
           16.542723523784453,
           16.359260194645913,
           16.17579686550729,
           15.992333536368733,
           15.80887020723018,
           15.625406878091614,
           15.441943548953057,
           15.258480219814505,
           15.086136106474934,
           14.91474014192086,
           14.743344177366883,
           14.571948212812845,
           14.400552248258858,
           14.229156283704844,
           14.057760319150807,
           13.886364354596768,
           13.72187380636145,
           13.561473967133058,
           13.4010741279047,
           13.240674288676377,
           13.080274449447986,
           12.919874610219628,
           12.759474770991284,
           12.599468744150297,
           12.44911115515377,
           12.298753566157139,
           12.148395977160622,
           11.998038388164042,
           11.847680799167431,
           11.697323210170916,
           11.547597402047613,
           11.406400620683206,
           11.26520383931879,
           11.124007057954392,
           10.982810276589966,
           10.841613495225555,
           10.70041671386117,
           10.564619236934204,
           10.431798946442834,
           10.29897865595149,
           10.166158365460129,
           10.033338074968777,
           9.900517784477415,
           9.773206847644973,
           9.648208479893915,
           9.523210112142863,
           9.39821174439183,
           9.273213376640786,
           9.149997054221545,
           9.034112570123686,
           8.918228086025826,
           8.802343601927955,
           8.686459117830067,
           8.571294767286247,
           8.465305447516613,
           8.359316127747048,
           8.253326807977471,
           8.147337488207887,
           8.043426996482731,
           7.944440045867483,
           7.845453095252209,
           7.7464661446369485,
           7.647479194021695,
           7.5527988422040515,
           7.458977208629745,
           7.365155575055446,
           7.271333941481136,
           7.181809763397766,
           7.094562594874919,
           7.007315426352074,
           6.920068257829232,
           6.837887290032759,
           6.757575406166008,
           6.677263522299265,
           6.5972056463805675,
           6.523046410146234,
           6.448887173911912,
           6.374727937677591,
           6.303649406002275,
           6.234935981657825,
           6.16622255731338,
           6.093585218629812,
           6.011138094098467,
           5.928690969567109,
           5.8462438450357475,
           5.763796720504397,
           5.681349595973044,
           5.5989024714416855,
           5.516455346910332,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           67.634491223225,
           67.67303525020498,
           67.71157927718494,
           67.75012330416492,
           67.7886673311449,
           67.82721135812487,
           67.86575538510482,
           67.9042994120848,
           67.94284343906477,
           67.98138746604475,
           68.01993149302471,
           68.05847552000469,
           68.09701954698467,
           68.13556357396463,
           68.17410760094461,
           68.21265162792459,
           68.25119565490455,
           68.28973968188451,
           68.32828370886449,
           68.36682773584447,
           68.40537176282443,
           68.44391578980441,
           68.48245981678438,
           68.52100384376435,
           68.55954787074432,
           68.59809189772429,
           68.63663592470428,
           68.67517995168423,
           68.7137239786642,
           68.75226800564418,
           68.79081203262415,
           68.82935605960412,
           68.86790008658409,
           68.90644411356408,
           68.94498814054404,
           68.983532167524,
           69.022076194504,
           69.06062022148396,
           69.09916424846392,
           69.1377082754439,
           69.17625230242386,
           69.21479632940384,
           69.25334035638382,
           69.29188438336378,
           69.33042841034376,
           69.36897243732372,
           69.4075164643037,
           69.44606049128367,
           69.48460451826364,
           69.52314854524361,
           69.56169257222359,
           69.60023659920355,
           69.63878062618353,
           69.6773246531635,
           69.71586868014347,
           69.75441270712344,
           69.79295673410341,
           69.83150076108339,
           69.87004478806335,
           69.90858881504333,
           69.94713284202331,
           69.98567686900327,
           70.02422089598325,
           70.06276492296321,
           70.10130894994319,
           70.13985297692315,
           70.17839700390313,
           70.2169410308831,
           70.25548505786308,
           70.29402908484305,
           70.33324955777178,
           70.37314647882329,
           70.41304339987481,
           70.45294032092633,
           70.49283724197785,
           70.53273416302937,
           70.57263108408088,
           70.6125280051324,
           70.65242492618393,
           70.69232184723545,
           70.73221876828696,
           70.77211568933849,
           70.81201261039,
           70.85190953144152,
           70.86699601654863,
           70.87712041446686,
           70.88724481238508,
           70.89736921030331,
           70.90749360822154,
           70.91761800613976,
           70.927742404058,
           70.93786680197623,
           70.94799119989445,
           70.95811559781268,
           70.96823999573091,
           70.97836439364913,
           70.98848879156736,
           70.99861318948558,
           71.00873758740381,
           71.01886198532205,
           71.02898638324027,
           71.0391107811585,
           71.04923517907673,
           71.05935957699495,
           71.06948397491318,
           71.07960837283142,
           71.08973277074963,
           71.09985716866787,
           71.10998156658609,
           71.12010596450432,
           71.13023036242255,
           71.14035476034077,
           71.150479158259,
           71.16060355617722,
           71.17072795409545,
           71.18085235201369,
           71.1909767499319,
           71.20110114785012,
           71.21122554576837,
           71.22134994368658,
           71.23147434160482,
           71.24159873952304,
           71.25172313744127,
           71.26184753535951,
           71.27197193327771,
           71.28209633119596,
           71.29222072911418,
           71.30234512703241,
           71.31246952495064,
           71.32259392286888,
           71.3327183207871,
           71.34284271870533,
           71.35296711662356,
           71.36309151454178,
           71.37321591246,
           71.38334031037823,
           71.39346470829646,
           71.40358910621468,
           71.41371350413291,
           71.42383790205115,
           71.43396229996937,
           71.4440866978876,
           71.45421109580582,
           71.46433549372405,
           71.47445989164228,
           71.4845842895605,
           71.49470868747873,
           71.50483308539697,
           71.51495748331519,
           71.52508188123342,
           71.53520627915165,
           71.54533067706987,
           71.5554550749881,
           71.56653629718589,
           71.57953117486194,
           71.59252605253798,
           71.60552093021403,
           71.61851580789006,
           71.6315106855661,
           71.64450556324215,
           71.6575004409182,
           71.67049531859423,
           71.68349019627028,
           71.69648507394632,
           71.70947995162237,
           71.7224748292984,
           71.73546970697446,
           71.40055475496608,
           70.89168488811556,
           70.382815021265,
           69.87394515441446,
           69.36507528756393,
           68.85620542071335,
           68.34733555386283,
           67.83846568701227,
           67.32959582016173,
           66.8207259533112,
           66.31185608646062,
           65.8029862196101,
           65.29411635275954,
           64.785246485909,
           64.27637661905847,
           63.76750675220792,
           63.238499410836596,
           62.708432223002426,
           62.178365035168255,
           61.6482978473341,
           61.11823065949992,
           60.58816347166575,
           60.058096283831595,
           59.528029095997404,
           58.99796190816325,
           58.46789472032908,
           57.9378275324949,
           57.40776034466075,
           56.87769315682655,
           56.3476259689924,
           55.817558781158226,
           55.28749159332405,
           54.7574244054899,
           54.22735721765573,
           53.697290029821545,
           53.167222841987375,
           52.6371556541532,
           52.107088466319055,
           51.57702127848487,
           51.0469540906507,
           50.51688690281655,
           49.986819714982374,
           49.4567525271482,
           48.92668533931402,
           48.39661815147984,
           47.866550963645665,
           47.336483775811516,
           46.806416587977346,
           46.27634940014317,
           45.746282212309,
           45.21621502447481,
           44.68614783664066,
           44.156080648806494,
           43.62601346097232,
           43.09594627313814,
           42.56587908530399,
           42.03581189746981,
           41.50574470963564,
           40.97567752180146,
           40.445610333967295,
           39.91554314613314,
           39.38547595829896,
           38.85540877046479,
           38.325341582630614,
           37.795274394796465,
           37.26520720696229,
           36.73514001912811,
           36.20507283129393,
           35.675005643459755,
           35.144938455625606,
           34.614871267791436,
           34.08480407995726,
           33.55473689212309,
           33.02466970428891,
           32.49460251645476,
           31.964535328620585,
           31.434468140786407,
           30.904400952952233,
           30.374333765118084,
           29.844266577283907,
           29.314199389449733,
           28.784132201615556,
           28.254065013781382,
           27.870295473486756,
           27.632823580731554,
           27.395351687976458,
           27.1678847364202,
           26.940804451241707,
           26.713724166063386,
           26.486643880884905,
           26.259563595706414,
           26.032483310528043,
           25.80540302534965,
           25.57832274017124,
           25.351242454992747,
           25.124162169814394,
           24.897081884635952,
           24.670001599457496,
           24.442921314279133,
           24.215841029100694,
           23.996794266797885,
           23.778826631266185,
           23.56085899573448,
           23.34289136020276,
           23.124923724671046,
           22.906956089139356,
           22.688988453607568,
           22.47102081807585,
           22.253053182544186,
           22.035085547012407,
           21.81711791148069,
           21.599150275949025,
           21.38415086767369,
           21.17547339531238,
           20.966795922951004,
           20.758118450589784,
           20.549440978228407,
           20.34076350586713,
           20.1320860335058,
           19.92340856114454,
           19.71473108878316,
           19.506053616421827,
           19.297376144060564,
           19.08922110940386,
           18.892607221511522,
           18.695993333619306,
           18.49937944572696,
           18.302765557834668,
           18.10615166994243,
           17.909537782050112,
           17.712923894157793,
           17.51631000626549,
           17.31969611837324,
           17.123082230480918,
           16.937845789358498,
           16.754382460219944,
           16.57091913108132,
           16.387455801942757,
           16.203992472804188,
           16.020529143665648,
           15.837065814527023,
           15.653602485388468,
           15.470139156249914,
           15.294304126745647,
           15.122908162191647,
           14.951512197637596,
           14.780116233083636,
           14.60872026852956,
           14.437324303975583,
           14.265928339421546,
           14.09453237486756,
           13.925538294071703,
           13.765138454843346,
           13.604738615614988,
           13.444338776386646,
           13.283938937158252,
           13.123539097929894,
           12.963139258701572,
           12.80273941947318,
           12.647557610861298,
           12.497200021864737,
           12.346842432868138,
           12.19648484387161,
           12.04612725487498,
           11.895769665878461,
           11.745412076881882,
           11.599161057875456,
           11.45796427651106,
           11.316767495146662,
           11.175570713782253,
           11.034373932417836,
           10.893177151053438,
           10.751980369689013,
           10.61857978021182,
           10.485759489720483,
           10.352939199229132,
           10.22011890873776,
           10.087298618246418,
           9.954478327755055,
           9.828731775461671,
           9.703733407710637,
           9.578735039959602,
           9.453736672208544,
           9.328738304457492,
           9.206616666402807,
           9.090732182304908,
           8.97484769820704,
           8.85896321410918,
           8.74307873001132,
           8.6283677967052,
           8.522378476935623,
           8.416389157166046,
           8.31039983739641,
           8.204410517626847,
           8.10033590787034,
           8.001348957255056,
           7.902362006639795,
           7.803375056024547,
           7.704388105409273,
           7.609252372988115,
           7.515430739413815,
           7.421609105839517,
           7.32778747226521,
           7.237285142068579,
           7.150037973545741,
           7.062790805022899,
           6.975543636500053,
           6.891936262637792,
           6.811624378771027,
           6.731312494904296,
           6.651000611037545,
           6.575500774528232,
           6.501341538293911,
           6.427182302059579,
           6.354417873166323,
           6.285704448821861,
           6.216991024477435,
           6.148277600132986,
           6.066811454186411,
           5.984364329655053,
           5.901917205123707,
           5.819470080592349,
           5.7370229560609864,
           5.6545758315296375,
           5.572128706998283,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           67.59471292189059,
           67.63204376273188,
           67.66937460357316,
           67.70690764092929,
           67.74545166790925,
           67.78399569488923,
           67.82253972186919,
           67.86108374884917,
           67.89962777582913,
           67.93817180280911,
           67.97671582978907,
           68.01525985676905,
           68.05380388374903,
           68.09234791072899,
           68.13089193770897,
           68.16943596468894,
           68.2079799916689,
           68.24652401864887,
           68.28506804562885,
           68.32361207260882,
           68.36215609958879,
           68.40070012656876,
           68.43924415354874,
           68.4777881805287,
           68.51633220750867,
           68.55487623448866,
           68.59342026146862,
           68.63196428844859,
           68.67050831542858,
           68.70905234240854,
           68.7475963693885,
           68.78614039636848,
           68.82468442334846,
           68.86322845032844,
           68.9017724773084,
           68.94031650428838,
           68.97886053126834,
           69.0174045582483,
           69.0559485852283,
           69.09449261220826,
           69.13303663918823,
           69.17158066616821,
           69.21012469314817,
           69.24866872012815,
           69.28721274710811,
           69.32575677408809,
           69.36430080106805,
           69.40284482804803,
           69.44138885502801,
           69.47993288200797,
           69.51847690898795,
           69.55702093596793,
           69.59556496294789,
           69.63410898992785,
           69.67265301690783,
           69.71119704388781,
           69.74974107086777,
           69.78828509784775,
           69.82682912482773,
           69.86537315180769,
           69.90391717878767,
           69.94246120576764,
           69.9810052327476,
           70.01954925972757,
           70.05809328670755,
           70.09663731368752,
           70.13518134066749,
           70.17372536764746,
           70.21226939462744,
           70.2508134216074,
           70.28935744858738,
           70.32790147556734,
           70.36644550254732,
           70.40498952952728,
           70.44353355650726,
           70.48207758348724,
           70.5206216104672,
           70.55916563744717,
           70.59770966442714,
           70.63625369140712,
           70.6747977183871,
           70.71334174536706,
           70.75188577234702,
           70.790429799327,
           70.80287942733587,
           70.81011017555049,
           70.81734092376512,
           70.82746531888091,
           70.83758971679913,
           70.84771411471736,
           70.8578385126356,
           70.86796291055381,
           70.87808730847205,
           70.88821170639028,
           70.8983361043085,
           70.90846050222673,
           70.91858490014496,
           70.92870929806318,
           70.93883369598142,
           70.94895809389965,
           70.95908249181787,
           70.9692068897361,
           70.97933128765432,
           70.98945568557255,
           70.99958008349077,
           71.009704481409,
           71.01982887932724,
           71.02995327724545,
           71.04007767516369,
           71.05020207308192,
           71.06032647100014,
           71.07045086891837,
           71.0805752668366,
           71.09069966475482,
           71.10082406267304,
           71.11094846059129,
           71.1210728585095,
           71.13119725642773,
           71.14132165434597,
           71.15144605226419,
           71.16157045018241,
           71.17169484810064,
           71.18181924601888,
           71.1919436439371,
           71.20206804185531,
           71.21219243977356,
           71.22231683769178,
           71.23244123561001,
           71.24256563352823,
           71.25269003144646,
           71.2628144293647,
           71.27293882728291,
           71.28306322520115,
           71.29318762311937,
           71.3033120210376,
           71.31343641895583,
           71.32356081687405,
           71.33368521479228,
           71.34380961271052,
           71.35393401062873,
           71.36405840854697,
           71.3741828064652,
           71.38430720438342,
           71.39443160230165,
           71.40455600021988,
           71.4146803981381,
           71.42480479605634,
           71.43492919397455,
           71.44505359189279,
           71.455177989811,
           71.46530238772924,
           71.47542678564747,
           71.48555118356569,
           71.49567558148392,
           71.50579997940216,
           71.51592437732037,
           71.5260487752386,
           71.53617317315683,
           71.54629757107506,
           71.55642196899328,
           71.56654636691151,
           71.57667076482974,
           71.58679516274798,
           71.5969195606662,
           71.60704395858443,
           71.61716835650265,
           71.62729275442088,
           71.26568713794171,
           70.7182165142639,
           70.17074589058603,
           69.62740856012417,
           69.09738970530015,
           68.56737085047608,
           68.03735199565205,
           67.507333140828,
           66.97731428600396,
           66.44729543117992,
           65.91727657635586,
           65.38725772153184,
           64.85723886670779,
           64.32722001188374,
           63.79720115705972,
           63.26718230223567,
           62.73716344741162,
           62.20714459258757,
           61.677125737763525,
           61.147106882939504,
           60.617088028115454,
           60.087069173291404,
           59.55705031846738,
           59.02703146364331,
           58.49701260881929,
           57.96699375399524,
           57.4369748991712,
           56.90695604434717,
           56.3769371895231,
           55.84691833469908,
           55.316899479875026,
           54.78688062505098,
           54.25686177022696,
           53.726842915402905,
           53.19682406057886,
           52.66680520575481,
           52.13678635093077,
           51.60676749610675,
           51.07674864128269,
           50.54672978645865,
           50.01671093163463,
           49.486692076810584,
           48.956673221986534,
           48.42665436716248,
           47.896635512338435,
           47.366616657514385,
           46.83659780269036,
           46.30657894786631,
           45.776560093042264,
           45.246541238218214,
           44.716522383394164,
           44.18650352857014,
           43.65648467374611,
           43.12646581892205,
           42.596446964098,
           42.066428109273986,
           41.536409254449936,
           41.006390399625886,
           40.476371544801836,
           39.946352689977786,
           39.416333835153765,
           38.886314980329715,
           38.35629612550568,
           37.82627727068162,
           37.296258415857594,
           36.76623956103355,
           36.23622070620951,
           35.70620185138546,
           35.17618299656141,
           34.64616414173739,
           34.11614528691334,
           33.58612643208929,
           33.056107577265244,
           32.526088722441195,
           31.996069867617166,
           31.466051012793123,
           30.936032157969073,
           30.40601330314503,
           29.875994448321002,
           29.345975593496952,
           28.81595673867291,
           28.28593788384886,
           27.755919029024813,
           27.377369459023573,
           27.15028917384516,
           26.92320888866668,
           26.69612860348836,
           26.469048318309866,
           26.24196803313155,
           26.014887747953072,
           25.78780746277458,
           25.560727177596206,
           25.333646892417818,
           25.106566607239404,
           24.87948632206091,
           24.652406036882553,
           24.427244207093594,
           24.209276571561805,
           23.99130893603017,
           23.773341300498473,
           23.555373664966677,
           23.337406029434977,
           23.119438393903273,
           22.901470758371552,
           22.68350312283984,
           22.465535487308152,
           22.247567851776363,
           22.029600216244642,
           21.811632580712978,
           21.598020914666144,
           21.389343442304767,
           21.18066596994347,
           20.97198849758217,
           20.763311025220865,
           20.55463355285949,
           20.34595608049827,
           20.137278608136892,
           19.928601135775615,
           19.71992366341428,
           19.51124619105302,
           19.302948673100932,
           19.10633478520865,
           18.909720897316376,
           18.713107009424085,
           18.51649312153175,
           18.319879233639533,
           18.123265345747182,
           17.926651457854895,
           17.730037569962658,
           17.53342368207034,
           17.33680979417802,
           17.149504725793943,
           16.96604139665533,
           16.782578067516763,
           16.599114738378212,
           16.415651409239654,
           16.232188080101032,
           16.048724750962467,
           15.865261421823895,
           15.681798092685355,
           15.50247214701634,
           15.331076182462338,
           15.15968021790834,
           14.988284253354326,
           14.816888288800325,
           14.645492324246272,
           14.474096359692311,
           14.302700395138235,
           14.131304430584258,
           13.968802942553614,
           13.808403103325215,
           13.648003264096877,
           13.48760342486852,
           13.327203585640163,
           13.166803746411817,
           13.006403907183428,
           12.846004067955068,
           12.695646477572247,
           12.545288888575685,
           12.394931299579119,
           12.244573710582559,
           12.09421612158596,
           11.943858532589433,
           11.793500943592802,
           11.65072471370333,
           11.50952793233893,
           11.368331150974488,
           11.22713436961009,
           11.08593758824569,
           10.944740806881281,
           10.805360613980811,
           10.672540323489436,
           10.539720032998083,
           10.406899742506733,
           10.274079452015394,
           10.141259161524042,
           10.00925507102943,
           9.884256703278396,
           9.75925833552733,
           9.634259967776288,
           9.509261600025253,
           9.384263232274218,
           9.263236278584008,
           9.147351794486148,
           9.031467310388289,
           8.91558282629039,
           8.79969834219252,
           8.685440826124148,
           8.57945150635457,
           8.473462186584985,
           8.367472866815408,
           8.261483547045831,
           8.157244819257901,
           8.058257868642649,
           7.959270918027393,
           7.8602839674121086,
           7.761297016796847,
           7.665705903772182,
           7.571884270197877,
           7.478062636623571,
           7.384241003049271,
           7.292760520739383,
           7.20551335221654,
           7.118266183693703,
           7.031019015170866,
           6.945985235242807,
           6.865673351376064,
           6.785361467509322,
           6.705049583642555,
           6.627955138910184,
           6.553795902675867,
           6.479636666441568,
           6.405477430207247,
           6.336472915985904,
           6.267759491641477,
           6.199046067297015,
           6.122484814274357,
           6.040037689743004,
           5.9575905652116425,
           5.875143440680284,
           5.792696316148938,
           5.71024919161758,
           5.627802067086218,
           5.5453549425548685,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           67.53929570452085,
           67.57662654536213,
           67.61395738620341,
           67.6512882270447,
           67.68861906788598,
           67.72594990872726,
           67.76328074956855,
           67.80061159040983,
           67.83794243125112,
           67.8752732720924,
           67.91260411293368,
           67.94993495377496,
           67.98726579461625,
           68.02459663545753,
           68.06192747629882,
           68.09925831714011,
           68.13658915798139,
           68.17391999882267,
           68.21125083966395,
           68.24858168050523,
           68.28672131073053,
           68.3252653377105,
           68.36380936469047,
           68.40235339167045,
           68.44089741865041,
           68.47944144563039,
           68.51798547261036,
           68.55652949959033,
           68.5950735265703,
           68.63361755355027,
           68.67216158053024,
           68.71070560751022,
           68.74924963449018,
           68.78779366147016,
           68.82633768845012,
           68.8648817154301,
           68.90342574241008,
           68.94196976939004,
           68.98051379637002,
           69.01905782334998,
           69.05760185032996,
           69.09614587730994,
           69.1346899042899,
           69.17323393126988,
           69.21177795824984,
           69.25032198522982,
           69.2888660122098,
           69.32741003918976,
           69.36595406616973,
           69.4044980931497,
           69.44304212012968,
           69.48158614710965,
           69.52013017408962,
           69.55867420106958,
           69.59721822804956,
           69.63576225502953,
           69.6743062820095,
           69.71285030898949,
           69.75139433596945,
           69.78993836294941,
           69.8284823899294,
           69.86702641690937,
           69.90557044388933,
           69.94411447086931,
           69.98265849784927,
           70.02120252482925,
           70.05974655180923,
           70.09829057878919,
           70.13683460576917,
           70.17537863274914,
           70.2139226597291,
           70.25246668670908,
           70.29101071368905,
           70.32955474066901,
           70.368098767649,
           70.40664279462897,
           70.44518682160894,
           70.48373084858892,
           70.52227487556888,
           70.56081890254886,
           70.59936292952882,
           70.6379069565088,
           70.67645098348876,
           70.71499501046874,
           70.72744463847759,
           70.73467538669222,
           70.74190613490686,
           70.74913688312148,
           70.7563676313361,
           70.76359837955073,
           70.77082912776537,
           70.77805987597999,
           70.78529062419463,
           70.79252137240925,
           70.79975212062388,
           70.8069828688385,
           70.81421361705314,
           70.82144436526777,
           70.82867511348239,
           70.83590586169703,
           70.84313660991165,
           70.85036735812628,
           70.8575981063409,
           70.86627567612746,
           70.87640007404568,
           70.88652447196391,
           70.89664886988213,
           70.90677326780036,
           70.91689766571858,
           70.92702206363681,
           70.93714646155505,
           70.94727085947328,
           70.9573952573915,
           70.96751965530973,
           70.97764405322795,
           70.98776845114618,
           70.9978928490644,
           71.00801724698263,
           71.01814164490088,
           71.02826604281908,
           71.03839044073732,
           71.04851483865554,
           71.05863923657375,
           71.068763634492,
           71.07888803241022,
           71.08901243032845,
           71.09913682824669,
           71.1092612261649,
           71.11938562408314,
           71.12951002200137,
           71.13963441991959,
           71.14975881783782,
           71.15988321575605,
           71.17000761367427,
           71.1801320115925,
           71.19025640951074,
           71.20038080742896,
           71.21050520534719,
           71.22062960326542,
           71.23075400118364,
           71.24087839910187,
           71.2510027970201,
           71.26112719493833,
           71.27125159285656,
           71.28137599077476,
           71.29150038869301,
           71.30162478661124,
           71.31174918452948,
           71.3218735824477,
           71.33199798036591,
           71.34212237828415,
           71.35224677620238,
           71.3623711741206,
           71.37249557203883,
           71.38261996995706,
           71.39274436787528,
           71.40286876579351,
           71.41299316371175,
           71.42311756162997,
           71.4332419595482,
           71.44336635746642,
           71.45349075538465,
           71.46361515330288,
           71.4737395512211,
           71.48386394913933,
           71.49398834705757,
           71.50411274497579,
           71.14250712849662,
           70.5950365048188,
           70.04756588114093,
           69.50009525746307,
           68.95262463378525,
           68.40515401010738,
           67.85768338642956,
           67.3102127627517,
           66.76274213907385,
           66.21527151539603,
           65.66780089171814,
           65.12033026804032,
           64.57285964436247,
           64.02538902068463,
           63.477918397006796,
           62.93044777332894,
           62.38297714965109,
           61.835506525973244,
           61.28803590229539,
           60.74056527861757,
           60.19309465493971,
           59.64562403126186,
           59.09815340758404,
           58.55527533071151,
           58.02525647588748,
           57.49523762106344,
           56.965218766239396,
           56.43519991141536,
           55.9051810565913,
           55.375162201767274,
           54.845143346943225,
           54.31512449211918,
           53.78510563729515,
           53.2550867824711,
           52.72506792764706,
           52.19504907282301,
           51.66503021799897,
           51.13501136317494,
           50.60499250835089,
           50.07497365352685,
           49.54495479870282,
           49.014935943878776,
           48.484917089054726,
           47.954898234230676,
           47.42487937940663,
           46.89486052458258,
           46.364841669758555,
           45.834822814934505,
           45.30480396011046,
           44.77478510528641,
           44.24476625046236,
           43.71474739563834,
           43.1847285408143,
           42.65470968599025,
           42.1246908311662,
           41.59467197634218,
           41.06465312151813,
           40.534634266694084,
           40.004615411870034,
           39.474596557045984,
           38.94457770222196,
           38.41455884739791,
           37.88453999257387,
           37.35452113774982,
           36.82450228292579,
           36.29448342810175,
           35.7644645732777,
           35.23444571845366,
           34.70442686362961,
           34.174408008805585,
           33.644389153981535,
           33.114370299157486,
           32.58435144433344,
           32.05433258950939,
           31.524313734685368,
           30.99429487986132,
           30.46427602503727,
           29.934257170213225,
           29.4042383153892,
           28.87421946056515,
           28.344200605741108,
           27.814181750917058,
           27.284162896093008,
           26.905613326091768,
           26.67853304091336,
           26.45145275573488,
           26.22437247055656,
           25.99729218537807,
           25.770211900199747,
           25.54313161502127,
           25.31605132984278,
           25.0889710446644,
           24.861890759486016,
           24.63972651185762,
           24.421758876325907,
           24.20379124079413,
           23.98582360526243,
           23.76785596973064,
           23.549888334199004,
           23.331920698667304,
           23.11395306313551,
           22.895985427603808,
           22.678017792072108,
           22.460050156540383,
           22.24208252100867,
           22.024114885476983,
           21.81189096165863,
           21.603213489297257,
           21.394536016935895,
           21.18585854457466,
           20.977181072213288,
           20.76850359985199,
           20.55982612749069,
           20.351148655129386,
           20.14247118276801,
           19.93379371040679,
           19.725116238045413,
           19.516676236798034,
           19.320062348905818,
           19.123448461013478,
           18.92683457312119,
           18.730220685228907,
           18.533606797336635,
           18.336992909444344,
           18.140379021552008,
           17.94376513365979,
           17.747151245767444,
           17.550537357875154,
           17.361163662229313,
           17.177700333090744,
           16.994237003952236,
           16.810773674813678,
           16.627310345675063,
           16.443847016536502,
           16.260383687397947,
           16.07692035825939,
           15.893457029120768,
           15.71064016728711,
           15.53924420273312,
           15.367848238179057,
           15.196452273625043,
           15.025056309071042,
           14.853660344517044,
           14.68226437996303,
           14.510868415409028,
           14.339472450854977,
           14.172467430263865,
           14.012067591035562,
           13.85166775180717,
           13.691267912578812,
           13.530868073350414,
           13.370468234122077,
           13.21006839489372,
           13.049668555665363,
           12.894092933279815,
           12.743735344283216,
           12.593377755286685,
           12.443020166290086,
           12.292662577293527,
           12.14230498829696,
           11.9919473993004,
           11.843485150895594,
           11.702288369531187,
           11.561091588166779,
           11.419894806802379,
           11.278698025437983,
           11.137501244073537,
           10.99630446270914,
           10.859321157258439,
           10.726500866767086,
           10.59368057627574,
           10.460860285784362,
           10.328039995293011,
           10.195219704801659,
           10.064779998846145,
           9.939781631095103,
           9.814783263344058,
           9.689784895593023,
           9.564786527841958,
           9.439788160090915,
           9.319855890765233,
           9.203971406667371,
           9.088086922569502,
           8.97220243847164,
           8.856317954373782,
           8.742513855543109,
           8.636524535773525,
           8.530535216003948,
           8.42454589623437,
           8.318556576464786,
           8.214153730645485,
           8.115166780030231,
           8.016179829414966,
           7.917192878799714,
           7.818205928184459,
           7.722159434556267,
           7.628337800981961,
           7.534516167407648,
           7.440694533833343,
           7.348235899410209,
           7.260988730887354,
           7.173741562364518,
           7.086494393841676,
           7.000034207847836,
           6.919722323981093,
           6.839410440114346,
           6.759098556247603,
           6.6804095032921875,
           6.606250267057849,
           6.532091030823528,
           6.4579317945892125,
           6.387241383149982,
           6.318527958805521,
           6.249814534461065,
           6.178158174362309,
           6.095711049830948,
           6.013263925299597,
           5.930816800768243,
           5.8483696762368815,
           5.765922551705524,
           5.683475427174178,
           5.60102830264282,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           67.48387848715112,
           67.5212093279924,
           67.55854016883367,
           67.59587100967497,
           67.63320185051624,
           67.67053269135752,
           67.70786353219881,
           67.74519437304009,
           67.78252521388137,
           67.81985605472266,
           67.85718689556396,
           67.89451773640522,
           67.93184857724651,
           67.96917941808779,
           68.00651025892908,
           68.04384109977036,
           68.08117194061165,
           68.11850278145292,
           68.15583362229421,
           68.1931644631355,
           68.23049530397678,
           68.26782614481806,
           68.30515698565935,
           68.34248782650063,
           68.37981866734191,
           68.4171495081832,
           68.45448034902448,
           68.49181118986577,
           68.52914203070704,
           68.56647287154833,
           68.6038037123896,
           68.6411345532309,
           68.67846539407218,
           68.71579623491347,
           68.75312707575475,
           68.79045791659603,
           68.8279909535518,
           68.86653498053177,
           68.90507900751174,
           68.94362303449171,
           68.98216706147169,
           69.02071108845166,
           69.05925511543163,
           69.0977991424116,
           69.13634316939157,
           69.17488719637154,
           69.21343122335152,
           69.25197525033148,
           69.29051927731146,
           69.32906330429142,
           69.3676073312714,
           69.40615135825138,
           69.44469538523134,
           69.48323941221132,
           69.52178343919128,
           69.56032746617126,
           69.59887149315122,
           69.6374155201312,
           69.67595954711118,
           69.71450357409114,
           69.75304760107113,
           69.7915916280511,
           69.83013565503106,
           69.86867968201103,
           69.907223708991,
           69.94576773597097,
           69.98431176295095,
           70.02285578993092,
           70.06139981691089,
           70.09994384389087,
           70.13848787087083,
           70.17703189785081,
           70.21557592483077,
           70.25411995181075,
           70.29266397879073,
           70.33120800577069,
           70.36975203275067,
           70.40829605973065,
           70.44684008671061,
           70.48538411369059,
           70.52392814067055,
           70.56247216765053,
           70.60101619463049,
           70.63956022161048,
           70.65200984961932,
           70.65924059783394,
           70.66647134604858,
           70.6737020942632,
           70.68093284247783,
           70.68816359069245,
           70.6953943389071,
           70.70262508712172,
           70.70985583533636,
           70.71708658355098,
           70.7243173317656,
           70.73154807998023,
           70.73877882819485,
           70.74600957640949,
           70.75324032462413,
           70.76047107283875,
           70.76770182105338,
           70.774932569268,
           70.78216331748263,
           70.78939406569727,
           70.79662481391189,
           70.80385556212653,
           70.81108631034115,
           70.81831705855578,
           70.8255478067704,
           70.83277855498504,
           70.84000930319966,
           70.84724005141429,
           70.85447079962893,
           70.86170154784355,
           70.86893229605818,
           70.8761630442728,
           70.88339379248744,
           70.89062454070206,
           70.8978552889167,
           70.90508603713133,
           70.91521043129221,
           70.92533482921044,
           70.93545922712866,
           70.9455836250469,
           70.95570802296511,
           70.96583242088334,
           70.97595681880156,
           70.98608121671981,
           70.99620561463803,
           71.00633001255626,
           71.0164544104745,
           71.02657880839271,
           71.03670320631095,
           71.04682760422916,
           71.0569520021474,
           71.06707640006562,
           71.07720079798385,
           71.08732519590208,
           71.0974495938203,
           71.10757399173853,
           71.11769838965677,
           71.12782278757498,
           71.13794718549322,
           71.14807158341145,
           71.15819598132967,
           71.16832037924789,
           71.17844477716612,
           71.18856917508435,
           71.19869357300257,
           71.2088179709208,
           71.21894236883904,
           71.22906676675726,
           71.23919116467549,
           71.24931556259372,
           71.25943996051195,
           71.26956435843017,
           71.2796887563484,
           71.28981315426662,
           71.29993755218486,
           71.31006195010309,
           71.32018634802131,
           71.33031074593954,
           71.34043514385777,
           71.35055954177598,
           71.36068393969421,
           71.37080833761244,
           71.38093273553068,
           71.01932711905151,
           70.47185649537369,
           69.92438587169583,
           69.37691524801797,
           68.82944462434014,
           68.28197400066227,
           67.73450337698445,
           67.1870327533066,
           66.63956212962874,
           66.09209150595092,
           65.54462088227304,
           64.99715025859521,
           64.44967963491736,
           63.90220901123951,
           63.35473838756169,
           62.807267763883836,
           62.25979714020599,
           61.71232651652814,
           61.164855892850284,
           60.61738526917246,
           60.069914645494606,
           59.52244402181675,
           58.97497339813893,
           58.42750277446105,
           57.88003215078322,
           57.332561527105376,
           56.78509090342753,
           56.237620279749706,
           55.690149656071824,
           55.14267903239399,
           54.59520840871615,
           54.047737785038294,
           53.50026716136047,
           52.952796537682616,
           52.40532591400477,
           51.85785529032692,
           51.31038466664907,
           50.76291404297124,
           50.21544341929339,
           49.66797279561554,
           49.120502171937716,
           48.57303154825986,
           48.02556092458201,
           47.48314210129883,
           46.95312324647479,
           46.42310439165074,
           45.89308553682672,
           45.36306668200267,
           44.833047827178625,
           44.303028972354575,
           43.773010117530525,
           43.242991262706504,
           42.712972407882454,
           42.182953553058404,
           41.65293469823436,
           41.12291584341034,
           40.59289698858629,
           40.06287813376224,
           39.5328592789382,
           39.002840424114154,
           38.47282156929012,
           37.942802714466076,
           37.41278385964203,
           36.88276500481798,
           36.35274614999396,
           35.822727295169905,
           35.29270844034586,
           34.76268958552181,
           34.23267073069776,
           33.70265187587374,
           33.1726330210497,
           32.64261416622565,
           32.112595311401606,
           31.582576456577552,
           31.052557601753527,
           30.52253874692948,
           29.992519892105435,
           29.462501037281385,
           28.93248218245736,
           28.402463327633313,
           27.872444472809264,
           27.342425617985217,
           26.81240676316117,
           26.43385719315993,
           26.206776907981524,
           25.97969662280304,
           25.752616337624723,
           25.525536052446228,
           25.29845576726791,
           25.07137548208943,
           24.852208816621538,
           24.634241181089823,
           24.41627354555813,
           24.19830591002641,
           23.9803382744947,
           23.762370638962924,
           23.54440300343122,
           23.326435367899432,
           23.108467732367796,
           22.890500096836096,
           22.6725324613043,
           22.454564825772604,
           22.236597190240904,
           22.025761008651017,
           21.81708353628971,
           21.60840606392836,
           21.399728591567115,
           21.191051119205742,
           20.982373646844373,
           20.773696174483145,
           20.56501870212177,
           20.356341229760474,
           20.147663757399172,
           19.938986285037867,
           19.730403800495164,
           19.5337899126029,
           19.337176024710608,
           19.14056213681826,
           18.94394824892604,
           18.747334361033708,
           18.550720473141414,
           18.354106585249134,
           18.15749269735686,
           17.96087880946457,
           17.764264921572238,
           17.572822598664754,
           17.38935926952619,
           17.205895940387567,
           17.022432611249023,
           16.838969282110455,
           16.655505952971943,
           16.47204262383339,
           16.288579294694774,
           16.10511596555621,
           15.921652636417654,
           15.74741222300381,
           15.576016258449847,
           15.404620293895787,
           15.233224329341795,
           15.061828364787734,
           14.89043240023372,
           14.719036435679719,
           14.54764047112572,
           14.376244506571705,
           14.215732078745738,
           14.055332239517437,
           13.894932400289036,
           13.734532561060737,
           13.574132721832346,
           13.413732882603988,
           13.253333043375587,
           13.09293320414725,
           12.942181799990763,
           12.791824210994196,
           12.641466621997637,
           12.491109033001038,
           12.340751444004507,
           12.19039385500791,
           12.040036266011349,
           11.895048806723455,
           11.753852025359022,
           11.612655243994624,
           11.471458462630217,
           11.330261681265808,
           11.189064899901409,
           11.04786811853701,
           10.913281700536066,
           10.780461410044687,
           10.647641119553345,
           10.514820829061994,
           10.382000538570647,
           10.24918024807927,
           10.12030492666286,
           9.995306558911784,
           9.87030819116076,
           9.745309823409716,
           9.620311455658673,
           9.495313087907638,
           9.376475502946441,
           9.260591018848572,
           9.144706534750712,
           9.028822050652849,
           8.912937566554982,
           8.799586884962055,
           8.693597565192478,
           8.587608245422894,
           8.481618925653311,
           8.375629605883734,
           8.271062642033053,
           8.172075691417792,
           8.073088740802538,
           7.974101790187284,
           7.875114839572021,
           7.778612965340351,
           7.684791331766051,
           7.590969698191723,
           7.4971480646174165,
           7.40371127808102,
           7.3164641095581775,
           7.229216941035334,
           7.141969772512479,
           7.054722603989642,
           6.973771296586108,
           6.893459412719365,
           6.813147528852623,
           6.732863867674155,
           6.658704631439838,
           6.584545395205524,
           6.510386158971185,
           6.438009850314018,
           6.369296425969562,
           6.300583001625136,
           6.2318695772806745,
           6.151384409918894,
           6.068937285387539,
           5.986490160856179,
           5.904043036324829,
           5.821595911793475,
           5.739148787262113,
           5.656701662730755,
           5.57425453819941,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           67.42846126978138,
           67.46579211062266,
           67.50312295146394,
           67.54045379230523,
           67.5777846331465,
           67.6151154739878,
           67.65244631482908,
           67.68977715567036,
           67.72710799651165,
           67.76443883735293,
           67.8017696781942,
           67.8391005190355,
           67.87643135987678,
           67.91376220071807,
           67.95109304155935,
           67.98842388240064,
           68.0257547232419,
           68.0630855640832,
           68.10041640492447,
           68.13774724576577,
           68.17507808660704,
           68.21240892744834,
           68.2497397682896,
           68.2870706091309,
           68.32440144997219,
           68.36173229081346,
           68.39906313165474,
           68.43639397249603,
           68.47372481333731,
           68.51105565417859,
           68.54838649501988,
           68.58571733586116,
           68.62304817670244,
           68.66037901754373,
           68.69770985838501,
           68.73504069922629,
           68.77237154006758,
           68.80970238090886,
           68.84703322175015,
           68.88436406259143,
           68.92169490343272,
           68.95902574427399,
           68.99635658511528,
           69.03368742595657,
           69.07101826679785,
           69.10834910763913,
           69.1456799484804,
           69.1830107893217,
           69.22034163016298,
           69.25767247100426,
           69.29500331184555,
           69.33233415268683,
           69.3696649935281,
           69.40780462335304,
           69.44634865033302,
           69.48489267731298,
           69.52343670429296,
           69.56198073127294,
           69.6005247582529,
           69.63906878523288,
           69.67761281221286,
           69.71615683919282,
           69.7547008661728,
           69.79324489315276,
           69.83178892013274,
           69.87033294711271,
           69.90887697409268,
           69.94742100107266,
           69.98596502805262,
           70.0245090550326,
           70.06305308201257,
           70.10159710899254,
           70.14014113597251,
           70.17868516295249,
           70.21722918993245,
           70.25577321691243,
           70.2943172438924,
           70.33286127087237,
           70.37140529785233,
           70.40994932483233,
           70.44849335181229,
           70.48703737879225,
           70.52558140577221,
           70.5641254327522,
           70.57657506076104,
           70.58380580897568,
           70.59103655719031,
           70.59826730540493,
           70.60549805361956,
           70.6127288018342,
           70.61995955004882,
           70.62719029826344,
           70.63442104647807,
           70.6416517946927,
           70.64888254290733,
           70.65611329112195,
           70.66334403933661,
           70.67057478755122,
           70.67780553576586,
           70.68503628398048,
           70.6922670321951,
           70.69949778040974,
           70.70672852862437,
           70.71395927683899,
           70.72119002505362,
           70.72842077326825,
           70.73565152148288,
           70.7428822696975,
           70.75011301791214,
           70.75734376612677,
           70.76457451434139,
           70.77180526255601,
           70.77903601077065,
           70.78626675898528,
           70.7934975071999,
           70.80072825541454,
           70.80795900362916,
           70.81518975184379,
           70.82242050005843,
           70.82965124827305,
           70.83688199648768,
           70.8441127447023,
           70.85134349291693,
           70.85857424113158,
           70.86580498934619,
           70.87303573756083,
           70.88026648577545,
           70.88749723399008,
           70.8947279822047,
           70.90195873041934,
           70.90918947863396,
           70.91642022684859,
           70.92365097506323,
           70.93088172327785,
           70.93811247149247,
           70.94534321970711,
           70.95402078853874,
           70.96414518645696,
           70.9742695843752,
           70.98439398229343,
           70.99451838021164,
           71.00464277812988,
           71.0147671760481,
           71.02489157396633,
           71.03501597188455,
           71.04514036980278,
           71.05526476772101,
           71.06538916563923,
           71.07551356355746,
           71.0856379614757,
           71.09576235939392,
           71.10588675731215,
           71.11601115523038,
           71.1261355531486,
           71.13625995106683,
           71.14638434898507,
           71.15650874690328,
           71.1666331448215,
           71.17675754273974,
           71.18688194065797,
           71.19700633857619,
           71.20713073649442,
           71.21725513441265,
           71.22737953233089,
           71.2375039302491,
           71.24762832816734,
           71.25775272608556,
           70.89614710960639,
           70.34867648592858,
           69.80120586225071,
           69.25373523857286,
           68.70626461489505,
           68.15879399121717,
           67.61132336753933,
           67.06385274386149,
           66.51638212018364,
           65.96891149650581,
           65.42144087282793,
           64.8739702491501,
           64.32649962547227,
           63.779029001794406,
           63.231558378116574,
           62.68408775443873,
           62.13661713076088,
           61.58914650708303,
           61.041675883405176,
           60.49420525972735,
           59.9467346360495,
           59.39926401237165,
           58.85179338869382,
           58.30432276501594,
           57.756852141338115,
           57.20938151766027,
           56.661910893982416,
           56.11444027030459,
           55.56696964662672,
           55.01949902294889,
           54.47202839927104,
           53.92455777559318,
           53.37708715191536,
           52.82961652823751,
           52.282145904559655,
           51.73467528088181,
           51.187204657203964,
           50.63973403352614,
           50.09226340984827,
           49.544792786170426,
           48.9973221624926,
           48.449851538814755,
           47.90238091513691,
           47.35491029145905,
           46.807439667781196,
           46.25996904410334,
           45.71249842042552,
           45.16502779674768,
           44.61755717306982,
           44.07008654939197,
           43.52261592571412,
           42.975145302036296,
           42.42767467835844,
           41.88020405468059,
           41.33273343100274,
           40.78526280732491,
           40.23779218364706,
           39.69032155996922,
           39.14285093629136,
           38.595380312613514,
           38.04790968893569,
           37.50043906525784,
           36.95296844157998,
           36.41100887188614,
           35.88099001706212,
           35.35097116223807,
           34.82095230741402,
           34.290933452589975,
           33.760914597765925,
           33.230895742941904,
           32.700876888117854,
           32.17085803329381,
           31.64083917846976,
           31.11082032364571,
           30.58080146882169,
           30.05078261399764,
           29.520763759173594,
           28.990744904349544,
           28.46072604952552,
           27.930707194701473,
           27.400688339877426,
           26.87066948505338,
           26.340650630229327,
           25.962101060228086,
           25.73502077504968,
           25.5079404898712,
           25.282658756917247,
           25.064691121385533,
           24.84672348585383,
           24.628755850322054,
           24.410788214790337,
           24.192820579258623,
           23.97485294372693,
           23.756885308195212,
           23.538917672663498,
           23.320950037131723,
           23.102982401600023,
           22.88501476606823,
           22.6670471305366,
           22.4490794950049,
           22.23963105564348,
           22.030953583282116,
           21.82227611092082,
           21.61359863855951,
           21.4049211661982,
           21.19624369383685,
           20.987566221475603,
           20.778888749114227,
           20.570211276752865,
           20.361533804391634,
           20.15285633203026,
           19.944178859668963,
           19.747517476300033,
           19.550903588407685,
           19.354289700515395,
           19.15767581262313,
           18.961061924730842,
           18.76444803683849,
           18.567834148946275,
           18.37122026105394,
           18.174606373161648,
           17.977992485269368,
           17.78448153510019,
           17.60101820596157,
           17.417554876823015,
           17.234091547684457,
           17.050628218545896,
           16.86716488940727,
           16.683701560268727,
           16.500238231130158,
           16.316774901991646,
           16.133311572853092,
           15.955580243274555,
           15.784184278720542,
           15.612788314166542,
           15.44139234961249,
           15.26999638505853,
           15.098600420504468,
           14.927204455950475,
           14.755808491396415,
           14.5844125268424,
           14.419396566456012,
           14.258996727227666,
           14.098596887999308,
           13.938197048770919,
           13.777797209542616,
           13.617397370314217,
           13.456997531085916,
           13.296597691857524,
           13.140628255698307,
           12.99027066670174,
           12.83991307770519,
           12.68955548870858,
           12.539197899712013,
           12.388840310715455,
           12.238482721718853,
           12.088125132722327,
           11.946612462551297,
           11.805415681186899,
           11.66421889982249,
           11.523022118458055,
           11.381825337093657,
           11.24062855572925,
           11.100062534305017,
           10.967242243813676,
           10.834421953322328,
           10.701601662830978,
           10.568781372339599,
           10.435961081848257,
           10.303140791356904,
           10.175829854479554,
           10.05083148672852,
           9.925833118977476,
           9.8008347512264,
           9.675836383475374,
           9.550838015724333,
           9.433095115127642,
           9.317210631029782,
           9.201326146931923,
           9.085441662834054,
           8.969557178736192,
           8.856659914381032,
           8.750670594611448,
           8.644681274841844,
           8.538691955072267,
           8.432702635302682,
           8.327971553420639,
           8.228984602805387,
           8.129997652190108,
           8.031010701574846,
           7.932023750959592,
           7.835066496124409,
           7.741244862550104,
           7.6474232289758035,
           7.5536015954015046,
           7.459779961827177,
           7.371939488228977,
           7.284692319706146,
           7.197445151183303,
           7.110197982660461,
           7.027820269191149,
           6.947508385324406,
           6.86719650145764,
           6.786884617590896,
           6.711158995821811,
           6.636999759587489,
           6.562840523353173,
           6.488778317478067,
           6.420064893133606,
           6.351351468789174,
           6.282638044444717,
           6.207057770006834,
           6.1246106454754745,
           6.042163520944126,
           5.959716396412771,
           5.87726927188141,
           5.79482214735006,
           5.712375022818707,
           5.629927898287345,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           67.37304405241164,
           67.41037489325292,
           67.4477057340942,
           67.48503657493549,
           67.52236741577677,
           67.55969825661806,
           67.59702909745934,
           67.63435993830062,
           67.67169077914191,
           67.70902161998319,
           67.74635246082448,
           67.78368330166575,
           67.82101414250704,
           67.85834498334833,
           67.89567582418961,
           67.93300666503089,
           67.97033750587217,
           68.00766834671346,
           68.04499918755474,
           68.08233002839603,
           68.11966086923731,
           68.15699171007859,
           68.19432255091988,
           68.23165339176117,
           68.26898423260243,
           68.30631507344373,
           68.34364591428502,
           68.38097675512628,
           68.41830759596758,
           68.45563843680887,
           68.49296927765013,
           68.53030011849143,
           68.5676309593327,
           68.604961800174,
           68.64229264101527,
           68.67962348185657,
           68.71695432269784,
           68.75428516353912,
           68.79161600438042,
           68.8289468452217,
           68.86627768606297,
           68.90360852690426,
           68.94093936774554,
           68.97827020858682,
           69.01560104942811,
           69.05293189026939,
           69.09026273111068,
           69.12759357195196,
           69.16492441279324,
           69.20225525363452,
           69.23958609447581,
           69.27691693531709,
           69.31424777615837,
           69.35157861699966,
           69.38890945784095,
           69.42624029868223,
           69.46357113952351,
           69.5009019803648,
           69.53823282120608,
           69.57556366204736,
           69.61289450288864,
           69.65022534372993,
           69.6875561845712,
           69.72488702541249,
           69.76221786625378,
           69.79954870709507,
           69.83687954793635,
           69.87421038877763,
           69.9115412296189,
           69.94907426617432,
           69.9876182931543,
           70.02616232013426,
           70.06470634711424,
           70.10325037409422,
           70.14179440107418,
           70.18033842805416,
           70.21888245503412,
           70.2574264820141,
           70.29597050899406,
           70.33451453597405,
           70.37305856295401,
           70.41160258993399,
           70.45014661691395,
           70.48869064389393,
           70.50114027190278,
           70.50837102011741,
           70.51560176833203,
           70.52283251654666,
           70.53006326476128,
           70.53729401297592,
           70.54452476119056,
           70.55175550940518,
           70.55898625761981,
           70.56621700583443,
           70.57344775404907,
           70.5806785022637,
           70.58790925047833,
           70.59513999869296,
           70.6023707469076,
           70.60960149512222,
           70.61683224333683,
           70.62406299155147,
           70.63129373976611,
           70.63852448798073,
           70.64575523619536,
           70.65298598440998,
           70.6602167326246,
           70.66744748083923,
           70.67467822905387,
           70.6819089772685,
           70.68913972548313,
           70.69637047369775,
           70.70360122191238,
           70.710831970127,
           70.71806271834163,
           70.72529346655627,
           70.73252421477089,
           70.73975496298551,
           70.74698571120015,
           70.75421645941478,
           70.76144720762942,
           70.76867795584403,
           70.77590870405866,
           70.7831394522733,
           70.79037020048793,
           70.79760094870255,
           70.80483169691718,
           70.8120624451318,
           70.81929319334643,
           70.82652394156106,
           70.8337546897757,
           70.84098543799033,
           70.84821618620495,
           70.85544693441958,
           70.86267768263421,
           70.86990843084884,
           70.87713917906348,
           70.8843699272781,
           70.89160067549273,
           70.89883142370735,
           70.90606217192197,
           70.91329292013661,
           70.92052366835124,
           70.92775441656588,
           70.9349851647805,
           70.94221591299512,
           70.94944666120975,
           70.95667740942437,
           70.96390815763901,
           70.97113890585365,
           70.97836965406827,
           70.9856004022829,
           70.99283115049752,
           71.00295554370351,
           71.01307994162174,
           71.02320433953997,
           71.03332873745819,
           71.04345313537641,
           71.05357753329464,
           71.06370193121288,
           71.0738263291311,
           71.08395072704933,
           71.09407512496756,
           71.10419952288578,
           71.11432392080401,
           71.12444831872224,
           71.13457271664046,
           70.7729671001613,
           70.22549647648347,
           69.67802585280562,
           69.13055522912775,
           68.58308460544994,
           68.03561398177206,
           67.48814335809423,
           66.94067273441638,
           66.39320211073854,
           65.8457314870607,
           65.29826086338284,
           64.75079023970501,
           64.20331961602716,
           63.655848992349306,
           63.10837836867149,
           62.56090774499363,
           62.013437121315775,
           61.46596649763792,
           60.918495873960076,
           60.371025250282244,
           59.8235546266044,
           59.276084002926545,
           58.72861337924871,
           58.18114275557084,
           57.63367213189302,
           57.08620150821517,
           56.538730884537316,
           55.99126026085949,
           55.44378963718161,
           54.896319013503785,
           54.34884838982594,
           53.801377766148086,
           53.25390714247026,
           52.70643651879241,
           52.15896589511456,
           51.61149527143671,
           51.064024647758856,
           50.51655402408103,
           49.96908340040318,
           49.42161277672533,
           48.8741421530475,
           48.326671529369655,
           47.77920090569181,
           47.23173028201395,
           46.6842596583361,
           46.13678903465825,
           45.589318410980425,
           45.04184778730257,
           44.49437716362472,
           43.946906539946866,
           43.39943591626902,
           42.85196529259119,
           42.30449466891334,
           41.7570240452355,
           41.209553421557644,
           40.66208279787982,
           40.114612174201966,
           39.56714155052411,
           39.01967092684626,
           38.472200303168414,
           37.92472967949059,
           37.37725905581273,
           36.829788432134876,
           36.28231780845704,
           35.73484718477921,
           35.18737656110136,
           34.63990593742351,
           34.09243531374565,
           33.5449646900678,
           32.997494066389976,
           32.45002344271212,
           31.90255281903427,
           31.355082195356424,
           30.807611571678574,
           30.260140948000746,
           29.712670324322893,
           29.165199700645047,
           28.617729076967194,
           28.07025845328937,
           27.522787829611516,
           26.975317205933667,
           26.427846582255814,
           25.879537348541334,
           25.495141061681196,
           25.27717342614948,
           25.05920579061785,
           24.84123815508607,
           24.623270519554357,
           24.405302884022657,
           24.18733524849088,
           23.969367612959164,
           23.751399977427447,
           23.533432341895757,
           23.31546470636404,
           23.097497070832326,
           22.87952943530055,
           22.66217857499721,
           22.453501102635897,
           22.244823630274603,
           22.03614615791324,
           21.82746868555199,
           21.61879121319063,
           21.41011374082934,
           21.201436268468022,
           20.992758796106713,
           20.784081323745365,
           20.57540385138412,
           20.36672637902274,
           20.158048906661378,
           19.96124503999713,
           19.76463115210484,
           19.568017264212564,
           19.371403376320288,
           19.17478948842794,
           18.97817560053565,
           18.781561712643384,
           18.584947824751094,
           18.388333936858746,
           18.19172004896653,
           17.996140471535604,
           17.81267714239704,
           17.62921381325848,
           17.445750484119927,
           17.262287154981305,
           17.07882382584275,
           16.895360496704193,
           16.711897167565628,
           16.528433838427006,
           16.344970509288462,
           16.16374826354532,
           15.992352298991257,
           15.820956334437255,
           15.649560369883254,
           15.478164405329242,
           15.306768440775242,
           15.13537247622119,
           14.96397651166723,
           14.792580547113168,
           14.623061054166312,
           14.462661214937956,
           14.302261375709598,
           14.141861536481207,
           13.981461697252861,
           13.821061858024505,
           13.660662018796113,
           13.500262179567812,
           13.339862340339412,
           13.188717122409276,
           13.038359533412718,
           12.888001944416146,
           12.737644355419581,
           12.587286766423032,
           12.436929177426423,
           12.286571588429855,
           12.139372899743549,
           11.998176118379149,
           11.85697933701474,
           11.715782555650343,
           11.574585774285945,
           11.433388992921536,
           11.292192211557104,
           11.154023077582684,
           11.021202787091333,
           10.888382496599945,
           10.755562206108603,
           10.622741915617256,
           10.489921625125904,
           10.357101334634525,
           10.23135478229626,
           10.106356414545216,
           9.981358046794181,
           9.856359679043146,
           9.731361311292105,
           9.60636294354103,
           9.489714727308904,
           9.373830243211035,
           9.257945759113138,
           9.142061275015278,
           9.026176790917416,
           8.913732943799983,
           8.807743624030406,
           8.70175430426083,
           8.595764984491245,
           8.489775664721641,
           8.38488046480825,
           8.285893514192965,
           8.186906563577704,
           8.08791961296245,
           7.988932662347171,
           7.8915200269084735,
           7.797698393334175,
           7.703876759759875,
           7.61005512618557,
           7.51623349261127,
           7.427414866899816,
           7.340167698376953,
           7.25292052985411,
           7.1656733613312795,
           7.081869241796193,
           7.001557357929428,
           6.921245474062685,
           6.840933590195943,
           6.763613360203804,
           6.689454123969487,
           6.615294887735155,
           6.541135651500834,
           6.470833360297683,
           6.402119935953227,
           6.333406511608766,
           6.262731130094777,
           6.180284005563427,
           6.097836881032073,
           6.015389756500715,
           5.9329426319693646,
           5.850495507438011,
           5.76804838290665,
           5.6856012583753,
           5.603154133843946,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           67.31615853657769,
           67.35348937741897,
           67.39082021826025,
           67.42815105910154,
           67.46548189994282,
           67.50281274078411,
           67.54014358162539,
           67.57747442246666,
           67.61480526330796,
           67.65213610414924,
           67.68946694499053,
           67.72679778583179,
           67.76412862667308,
           67.80145946751438,
           67.83879030835566,
           67.87612114919693,
           67.91345199003823,
           67.9507828308795,
           67.98811367172078,
           68.02544451256207,
           68.06277535340335,
           68.10010619424463,
           68.13743703508591,
           68.17476787592722,
           68.21209871676848,
           68.24942955760977,
           68.28676039845105,
           68.32409123929233,
           68.36142208013362,
           68.39875292097491,
           68.43608376181618,
           68.47341460265747,
           68.51074544349875,
           68.54807628434004,
           68.58540712518132,
           68.6227379660226,
           68.66006880686389,
           68.69739964770517,
           68.73473048854646,
           68.77206132938772,
           68.80939217022902,
           68.8467230110703,
           68.88405385191157,
           68.92138469275287,
           68.95871553359414,
           68.99604637443542,
           69.03337721527672,
           69.070708056118,
           69.10803889695927,
           69.14536973780056,
           69.18270057864186,
           69.22003141948313,
           69.25736226032441,
           69.29469310116569,
           69.33202394200698,
           69.36935478284826,
           69.40668562368954,
           69.44401646453083,
           69.48134730537211,
           69.5186781462134,
           69.55600898705468,
           69.59333982789596,
           69.63067066873725,
           69.66800150957853,
           69.70533235041981,
           69.7426631912611,
           69.77999403210238,
           69.81732487294366,
           69.85465571378495,
           69.89198655462623,
           69.9293173954675,
           69.9666482363088,
           70.00397907715008,
           70.04130991799137,
           70.07864075883265,
           70.11597159967394,
           70.15330244051522,
           70.1906332813565,
           70.22796412219779,
           70.26529496303907,
           70.30262580388035,
           70.33995664239058,
           70.3759164424753,
           70.41187624256003,
           70.42389516608633,
           70.43112591430096,
           70.43835666251559,
           70.44558741073021,
           70.45281815894485,
           70.46004890715948,
           70.4672796553741,
           70.47451040358874,
           70.48174115180336,
           70.48897190001799,
           70.49620264823261,
           70.50343339644725,
           70.51066414466187,
           70.51789489287651,
           70.52512564109114,
           70.53235638930576,
           70.5395871375204,
           70.54681788573502,
           70.55404863394966,
           70.56127938216429,
           70.56851013037891,
           70.57574087859354,
           70.58297162680816,
           70.5902023750228,
           70.59743312323742,
           70.60466387145205,
           70.61189461966669,
           70.61912536788131,
           70.62635611609593,
           70.63358686431056,
           70.6408176125252,
           70.64804836073982,
           70.65527910895446,
           70.66250985716908,
           70.66974060538371,
           70.67697135359835,
           70.68420210181296,
           70.6914328500276,
           70.69866359824223,
           70.70589434645686,
           70.71312509467148,
           70.72035584288611,
           70.72758659110073,
           70.73481733931537,
           70.74204808753,
           70.74927883574462,
           70.75650958395926,
           70.76374033217388,
           70.7709710803885,
           70.77820182860313,
           70.78543257681777,
           70.7926633250324,
           70.79989407324702,
           70.80712482146166,
           70.81435556967628,
           70.8215863178909,
           70.82881706610554,
           70.83604781432017,
           70.84327856253479,
           70.85050931074943,
           70.85774005896405,
           70.86497080717868,
           70.8722015553933,
           70.87943230360794,
           70.88666305182257,
           70.8938938000372,
           70.90112454825183,
           70.90835529646645,
           70.91558604468108,
           70.9228167928957,
           70.93004754111034,
           70.93727828932496,
           70.94450903753959,
           70.95173978575423,
           70.95897053396885,
           70.96620128218348,
           70.9734320303981,
           70.98066277861274,
           70.98789352682736,
           70.995124275042,
           71.00235502325663,
           71.00668791556964,
           71.0104412437972,
           70.63644807168211,
           70.07358164939579,
           69.51071522710942,
           68.95328686360608,
           68.40246192541754,
           67.85163698722896,
           67.30081204904042,
           66.74998711085186,
           66.19916217266329,
           65.64833723447477,
           65.09751229628617,
           64.54668735809763,
           63.99586241990907,
           63.44503748172051,
           62.89421254353197,
           62.34338760534341,
           61.79256266715485,
           61.241737728966285,
           60.69091279077774,
           60.1400878525892,
           59.589262914400635,
           59.038437976212066,
           58.48761303802353,
           57.93678809983494,
           57.38596316164641,
           56.83513822345785,
           56.28431328526929,
           55.733488347080744,
           55.18266340889217,
           54.63183847070362,
           54.081013532515065,
           53.530188594326496,
           52.97936365613796,
           52.4285387179494,
           51.877713779760846,
           51.32688884157228,
           50.776063903383715,
           50.22523896519518,
           49.67441402700663,
           49.12358908881806,
           48.572764150629524,
           48.021939212440955,
           47.4711142742524,
           46.92028933606383,
           46.36946439787528,
           45.818639459686715,
           45.267814521498174,
           44.71698958330962,
           44.16616464512105,
           43.615339706932495,
           43.064514768743926,
           42.513689830555386,
           41.96286489236683,
           41.41203995417827,
           40.861215015989714,
           40.31039007780117,
           39.759565139612604,
           39.20874020142405,
           38.65791526323548,
           38.107090325046926,
           37.556265386858385,
           37.00544044866982,
           36.45461551048127,
           35.9037905722927,
           35.352965634104166,
           34.802140695915604,
           34.25131575772704,
           33.70049081953849,
           33.14966588134992,
           32.598840943161385,
           32.04801600497282,
           31.49719106678426,
           30.9463661285957,
           30.395541190407133,
           29.844716252218596,
           29.293891314030038,
           28.743066375841476,
           28.192241437652914,
           27.641416499464377,
           27.090591561275815,
           26.539766623087253,
           25.98894168489869,
           25.43811674671013,
           25.053720459849988,
           24.835752824318277,
           24.617785188786645,
           24.399817553254863,
           24.181849917723152,
           23.96388228219145,
           23.745914646659674,
           23.527947011127957,
           23.309979375596242,
           23.09201174006455,
           22.876048621989664,
           22.667371149628288,
           22.45869367726699,
           22.250016204905695,
           22.04133873254438,
           21.832661260183087,
           21.62398378782172,
           21.415306315460477,
           21.206628843099114,
           20.99795137073782,
           20.789273898376504,
           20.5805964260152,
           20.37191895365385,
           20.174972603694204,
           19.978358715801974,
           19.781744827909694,
           19.585130940017358,
           19.388517052125067,
           19.19190316423279,
           18.995289276340515,
           18.798675388448167,
           18.602061500555877,
           18.40544761266361,
           18.20883372477132,
           18.024336078832476,
           17.840872749693865,
           17.65740942055531,
           17.473946091416746,
           17.29048276227819,
           17.107019433139637,
           16.923556104001015,
           16.74009277486246,
           16.556629445723903,
           16.373166116585335,
           16.200520319262,
           16.029124354708006,
           15.857728390153994,
           15.686332425599932,
           15.514936461045933,
           15.343540496491933,
           15.172144531937919,
           15.000748567383917,
           14.829352602829866,
           14.66632570264818,
           14.505925863419824,
           14.345526024191486,
           14.185126184963131,
           14.024726345734774,
           13.864326506506382,
           13.703926667278036,
           13.543526828049679,
           13.387163578116827,
           13.236805989120269,
           13.086448400123658,
           12.936090811127098,
           12.78573322213054,
           12.635375633133968,
           12.485018044137403,
           12.334660455140854,
           12.190936555571419,
           12.049739774206973,
           11.908542992842577,
           11.767346211478179,
           11.62614943011377,
           11.484952648749374,
           11.343755867384974,
           11.207983620860285,
           11.075163330368941,
           10.942343039877596,
           10.809522749386245,
           10.676702458894855,
           10.543882168403513,
           10.41187807786402,
           10.286879710112977,
           10.161881342361943,
           10.036882974610874,
           9.911884606859832,
           9.7868862391088,
           9.662218823588004,
           9.546334339490105,
           9.430449855392238,
           9.314565371294385,
           9.198680887196517,
           9.08279640309862,
           8.97080597321893,
           8.864816653449353,
           8.75882733367977,
           8.652838013910191,
           8.546848694140616,
           8.44178937619579,
           8.342802425580558,
           8.243815474965302,
           8.144828524350018,
           8.045841573734757,
           7.947973557692535,
           7.854151924118234,
           7.76033029054393,
           7.666508656969629,
           7.572687023395329,
           7.4828902455705935,
           7.395643077047757,
           7.30839590852494,
           7.221148740002079,
           7.135918214401208,
           7.055606330534471,
           6.975294446667723,
           6.894982562800957,
           6.816067724585793,
           6.74190848835146,
           6.66774925211714,
           6.593590015882823,
           6.5216018274617245,
           6.452888403117264,
           6.384174978772837,
           6.315461554428381,
           6.235957365651373,
           6.153510241120012,
           6.071063116588662,
           5.9886159920573085,
           5.906168867525951,
           5.8237217429946,
           5.741274618463247,
           5.658827493931884,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           67.24955967081665,
           67.28689051165793,
           67.32422135249922,
           67.3615521933405,
           67.3988830341818,
           67.43621387502307,
           67.47354471586435,
           67.51087555670563,
           67.54820639754692,
           67.58553723838821,
           67.62286807922949,
           67.66019892007077,
           67.69752976091205,
           67.73486060175334,
           67.77219144259462,
           67.80952228343591,
           67.84685312427717,
           67.88418396511847,
           67.92151480595976,
           67.95884564680104,
           67.99617648764232,
           68.03350732848361,
           68.07083816932489,
           68.10816901016616,
           68.14549985100746,
           68.18283069184874,
           68.22016153269003,
           68.2574923735313,
           68.29482321437258,
           68.33215405521386,
           68.36948489605516,
           68.40681573689645,
           68.44414657773771,
           68.481477418579,
           68.51880825942028,
           68.55613910026157,
           68.59346994110285,
           68.63080078194413,
           68.66813162278541,
           68.7054624636267,
           68.74279330446798,
           68.78012414530927,
           68.81745498615055,
           68.85478582699183,
           68.89211666783311,
           68.9294475086744,
           68.96677834951569,
           69.00410919035697,
           69.04144003119825,
           69.07877087203954,
           69.11610171288082,
           69.1534325537221,
           69.19076339456339,
           69.22809423540467,
           69.26542507624596,
           69.30275591708724,
           69.34008675792852,
           69.37741759876981,
           69.41474843961109,
           69.45207928045237,
           69.48941012129366,
           69.52674096213494,
           69.56407180297622,
           69.6014026438175,
           69.63873348465879,
           69.67537880353825,
           69.71133860362298,
           69.7472984037077,
           69.78325820379243,
           69.81921800387717,
           69.8551778039619,
           69.89113760404662,
           69.92709740413135,
           69.96305720421607,
           69.99901700430081,
           70.03497680438554,
           70.07093660447026,
           70.10689640455499,
           70.14285620463971,
           70.17881600472444,
           70.21477580480918,
           70.2507356048939,
           70.28669540497863,
           70.32265520506337,
           70.33467412858967,
           70.3419048768043,
           70.34913562501893,
           70.35636637323356,
           70.36359712144818,
           70.37082786966282,
           70.37805861787744,
           70.38528936609207,
           70.39252011430669,
           70.39975086252133,
           70.40698161073595,
           70.41421235895058,
           70.42144310716522,
           70.42867385537984,
           70.43590460359447,
           70.4431353518091,
           70.45036610002373,
           70.45759684823835,
           70.46482759645298,
           70.47205834466762,
           70.47928909288224,
           70.48651984109688,
           70.4937505893115,
           70.50098133752613,
           70.50821208574077,
           70.51544283395539,
           70.52267358217001,
           70.52990433038464,
           70.53713507859928,
           70.5443658268139,
           70.55159657502853,
           70.55882732324315,
           70.56605807145779,
           70.57328881967241,
           70.58051956788704,
           70.58775031610168,
           70.5949810643163,
           70.60221181253092,
           70.60944256074556,
           70.61667330896019,
           70.62390405717481,
           70.63113480538945,
           70.63836555360407,
           70.6455963018187,
           70.65282705003332,
           70.66005779824796,
           70.66728854646259,
           70.67451929467721,
           70.68175004289185,
           70.68898079110647,
           70.6962115393211,
           70.70344228753572,
           70.71067303575036,
           70.71790378396499,
           70.72513453217961,
           70.73236528039425,
           70.73959602860887,
           70.74682677682351,
           70.75405752503812,
           70.76128827325276,
           70.76851902146738,
           70.77574976968202,
           70.78298051789665,
           70.79021126611127,
           70.79628287031379,
           70.80003619854133,
           70.80378952676888,
           70.80754285499643,
           70.81129618322399,
           70.81504951145152,
           70.81880283967908,
           70.82255616790663,
           70.82630949613417,
           70.83006282436173,
           70.83381615258926,
           70.83756948081681,
           70.84132280904437,
           70.84507613727192,
           70.84882946549946,
           70.85258279372701,
           70.85633612195456,
           70.8600894501821,
           70.86384277840966,
           70.48984960629458,
           69.92698318400824,
           69.36411676172189,
           68.80125033943551,
           68.23838391714918,
           67.67551749486277,
           67.11265107257644,
           66.54978465029008,
           65.98691822800372,
           65.42405180571738,
           64.86118538343098,
           64.29831896114466,
           63.735452538858276,
           63.172586116571914,
           62.60971969428558,
           62.04685327199921,
           61.48398684971285,
           60.92112042742649,
           60.35825400514011,
           59.795387582853785,
           59.232521160567416,
           58.669654738281054,
           58.106788315994706,
           57.54392189370832,
           56.98105547142198,
           56.41818904913561,
           55.85532262684925,
           55.29245620456291,
           54.74124280706096,
           54.190417868872416,
           53.639592930683854,
           53.0887679924953,
           52.537943054306766,
           51.9871181161182,
           51.436293177929635,
           50.88546823974108,
           50.33464330155251,
           49.78381836336398,
           49.232993425175415,
           48.68216848698686,
           48.13134354879831,
           47.58051861060976,
           47.02969367242119,
           46.478868734232634,
           45.92804379604407,
           45.37721885785551,
           44.82639391966697,
           44.27556898147841,
           43.724744043289846,
           43.17391910510129,
           42.62309416691272,
           42.07226922872419,
           41.52144429053563,
           40.97061935234706,
           40.4197944141585,
           39.86896947596997,
           39.31814453778141,
           38.767319599592845,
           38.21649466140428,
           37.66566972321572,
           37.11484478502719,
           36.56401984683862,
           36.013194908650064,
           35.462369970461495,
           34.91154503227296,
           34.3607200940844,
           33.80989515589584,
           33.259070217707276,
           32.70824527951872,
           32.15742034133018,
           31.60659540314162,
           31.055770464953056,
           30.504945526764494,
           29.954120588575933,
           29.403295650387392,
           28.852470712198834,
           28.30164577401027,
           27.75082083582171,
           27.199995897633173,
           26.64917095944461,
           26.09834602125605,
           25.547521083067487,
           24.996696144878925,
           24.61229985801879,
           24.394332222487076,
           24.17636458695544,
           23.958396951423666,
           23.74042931589195,
           23.52246168036025,
           23.304494044828473,
           23.089918668982055,
           22.881241196620753,
           22.67256372425946,
           22.463886251898153,
           22.255208779536776,
           22.046531307175478,
           21.837853834814183,
           21.629176362452867,
           21.420498890091576,
           21.211821417730214,
           21.003143945368965,
           20.794466473007603,
           20.58578900064631,
           20.388700167391338,
           20.192086279499048,
           19.995472391606782,
           19.798858503714435,
           19.602244615822205,
           19.405630727929925,
           19.209016840037588,
           19.0124029521453,
           18.815789064253025,
           18.619175176360745,
           18.422561288468398,
           18.235995015267868,
           18.05253168612932,
           17.869068356990756,
           17.68560502785219,
           17.502141698713576,
           17.31867836957502,
           17.135215040436456,
           16.9517517112979,
           16.768288382159344,
           16.584825053020722,
           16.408688339532702,
           16.237292374978704,
           16.06589641042469,
           15.89450044587068,
           15.72310448131669,
           15.551708516762675,
           15.380312552208615,
           15.208916587654612,
           15.037520623100614,
           14.86999019035845,
           14.70959035113006,
           14.54919051190176,
           14.388790672673359,
           14.228390833445003,
           14.067990994216665,
           13.907591154988307,
           13.747191315759952,
           13.58679147653156,
           13.435252444827777,
           13.284894855831205,
           13.134537266834649,
           12.98417967783809,
           12.83382208884148,
           12.683464499844918,
           12.533106910848364,
           12.383696992763657,
           12.242500211399287,
           12.10130343003486,
           11.96010664867045,
           11.818909867306008,
           11.677713085941612,
           11.536516304577212,
           11.395319523212804,
           11.261944164137892,
           11.129123873646547,
           10.996303583155195,
           10.863483292663853,
           10.730663002172507,
           10.597842711681155,
           10.467403005680701,
           10.342404637929667,
           10.217406270178632,
           10.09240790242759,
           9.967409534676555,
           9.842411166925489,
           9.718838435769205,
           9.602953951671346,
           9.487069467573486,
           9.371184983475587,
           9.255300499377718,
           9.139416015279865,
           9.027879002637905,
           8.92188968286832,
           8.81590036309872,
           8.709911043329141,
           8.603921723559557,
           8.498698287583384,
           8.39971133696813,
           8.300724386352844,
           8.201737435737613,
           8.102750485122359,
           8.004427088476616,
           7.910605454902311,
           7.81678382132799,
           7.72296218775369,
           7.629140554179385,
           7.538365624241418,
           7.451118455718582,
           7.36387128719572,
           7.276624118672884,
           7.1899671870062365,
           7.109655303139488,
           7.029343419272739,
           6.949031535406002,
           6.868719651539255,
           6.794362852733428,
           6.72020361649913,
           6.646044380264797,
           6.572370294625763,
           6.503656870281306,
           6.434943445936879,
           6.366230021592418,
           6.291630725739317,
           6.209183601207963,
           6.126736476676605,
           6.044289352145244,
           5.961842227613893,
           5.8793951030825395,
           5.796947978551181,
           5.714500854019832,
           5.632053729488478,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           67.18296080505563,
           67.2202916458969,
           67.25762248673819,
           67.29495332757948,
           67.33228416842076,
           67.36961500926205,
           67.40694585010333,
           67.4442766909446,
           67.4816075317859,
           67.51893837262718,
           67.55626921346847,
           67.59360005430975,
           67.63093089515102,
           67.66826173599232,
           67.7055925768336,
           67.74292341767489,
           67.78025425851615,
           67.81758509935744,
           67.85491594019872,
           67.89224678104,
           67.9295776218813,
           67.96690846272259,
           68.00423930356386,
           68.04157014440514,
           68.07890098524642,
           68.11623182608771,
           68.153562666929,
           68.19089350777027,
           68.22822434861156,
           68.26555518945284,
           68.30288603029413,
           68.34021687113541,
           68.37754771197669,
           68.41487855281798,
           68.45220939365926,
           68.48954023450055,
           68.52687107534183,
           68.56420191618311,
           68.60153275702439,
           68.63886359786568,
           68.67619443870696,
           68.71352527954825,
           68.75085612038953,
           68.7881869612308,
           68.82551780207208,
           68.86284864291338,
           68.90017948375467,
           68.93751032459593,
           68.97484116460119,
           69.01080096468591,
           69.04676076477065,
           69.08272056485538,
           69.1186803649401,
           69.15464016502483,
           69.19059996510956,
           69.22655976519428,
           69.26251956527902,
           69.29847936536375,
           69.33443916544847,
           69.37039896553321,
           69.40635876561794,
           69.44231856570266,
           69.47827836578739,
           69.51423816587211,
           69.55019796595685,
           69.58615776604158,
           69.6221175661263,
           69.65807736621105,
           69.69403716629577,
           69.7299969663805,
           69.76595676646522,
           69.80191656654995,
           69.83787636663469,
           69.87383616671941,
           69.90979596680414,
           69.94575576688887,
           69.9817155669736,
           70.01767536705833,
           70.05363516714306,
           70.08959496722778,
           70.12555476731251,
           70.16151456739723,
           70.19747436748196,
           70.2334341675667,
           70.24545309109301,
           70.25268383930764,
           70.25991458752227,
           70.2671453357369,
           70.27437608395152,
           70.28160683216615,
           70.28883758038077,
           70.29606832859541,
           70.30329907681003,
           70.31052982502467,
           70.3177605732393,
           70.32499132145392,
           70.33222206966855,
           70.33945281788318,
           70.34668356609781,
           70.35391431431243,
           70.36114506252707,
           70.3683758107417,
           70.37560655895632,
           70.38283730717096,
           70.39006805538558,
           70.39729880360021,
           70.40452955181485,
           70.41176030002947,
           70.4189910482441,
           70.42622179645872,
           70.43345254467334,
           70.44068329288798,
           70.4479140411026,
           70.45514478931725,
           70.46237553753187,
           70.4696062857465,
           70.47683703396113,
           70.48406778217576,
           70.49129853039038,
           70.49852927860502,
           70.50576002681964,
           70.51299077503427,
           70.5202215232489,
           70.52745227146353,
           70.53468301967816,
           70.5419137678928,
           70.54914451610742,
           70.55637526432204,
           70.56360601253667,
           70.57083676075129,
           70.57806750896592,
           70.58529825718055,
           70.58963115328548,
           70.59338448151303,
           70.59713780974059,
           70.60089113796813,
           70.60464446619568,
           70.60839779442323,
           70.61215112265077,
           70.61590445087833,
           70.61965777910586,
           70.62341110733342,
           70.62716443556097,
           70.63091776378852,
           70.63467109201606,
           70.63842442024361,
           70.64217774847116,
           70.64593107669872,
           70.64968440492626,
           70.65343773315381,
           70.65719106138135,
           70.66094438960891,
           70.66469771783646,
           70.66845104606399,
           70.67220437429155,
           70.6759577025191,
           70.67971103074666,
           70.68346435897419,
           70.68721768720174,
           70.69097101542928,
           70.69472434365683,
           70.69847767188439,
           70.70223100011194,
           70.70598432833948,
           70.70973765656703,
           70.71349098479459,
           70.71724431302214,
           70.34325114090706,
           69.78038471862072,
           69.21751829633435,
           68.65465187404799,
           68.09178545176165,
           67.52891902947526,
           66.96605260718891,
           66.40318618490255,
           65.84031976261619,
           65.27745334032986,
           64.71458691804347,
           64.15172049575712,
           63.58885407347075,
           63.025987651184394,
           62.463121228898046,
           61.900254806611684,
           61.33738838432532,
           60.77452196203895,
           60.21165553975259,
           59.64878911746625,
           59.085922695179896,
           58.52305627289353,
           57.960189850607186,
           57.397323428320796,
           56.83445700603445,
           56.271590583748086,
           55.708724161461724,
           55.14585773917539,
           54.58299131688899,
           54.02012489460266,
           53.4572584723163,
           52.89439205002992,
           52.33152562774359,
           51.76865920545722,
           51.205792783170864,
           50.642926360884495,
           50.080059938598126,
           49.51719351631179,
           48.95432709402543,
           48.391460671739054,
           47.82859424945272,
           47.26572782716636,
           46.70286140488,
           46.13999498259363,
           45.57712856030726,
           45.0142621380209,
           44.451395715734556,
           43.888529293448194,
           43.325662871161825,
           42.76279644887546,
           42.1999300265891,
           41.63706360430275,
           41.08002368870446,
           40.52919875051589,
           39.978373812327334,
           39.42754887413879,
           38.87672393595024,
           38.325898997761676,
           37.775074059573114,
           37.22424912138455,
           36.67342418319601,
           36.12259924500745,
           35.571774306818895,
           35.020949368630326,
           34.47012443044179,
           33.91929949225323,
           33.36847455406467,
           32.81764961587611,
           32.26682467768755,
           31.715999739499008,
           31.165174801310446,
           30.614349863121884,
           30.063524924933322,
           29.512699986744764,
           28.961875048556223,
           28.411050110367665,
           27.860225172179103,
           27.30940023399054,
           26.758575295802004,
           26.207750357613442,
           25.65692541942488,
           25.106100481236318,
           24.555275543047756,
           24.170879256187618,
           23.952911620655904,
           23.734943985124268,
           23.51697634959249,
           23.30378871597454,
           23.09511124361318,
           22.886433771251948,
           22.677756298890568,
           22.469078826529266,
           22.26040135416798,
           22.05172388180667,
           21.843046409445293,
           21.63436893708399,
           21.4256914647227,
           21.217013992361384,
           21.00833652000009,
           20.799659047638727,
           20.602427731088497,
           20.40581384319622,
           20.20919995530388,
           20.012586067411593,
           19.815972179519303,
           19.619358291627037,
           19.42274440373469,
           19.22613051584246,
           19.02951662795018,
           18.832902740057843,
           18.636288852165556,
           18.44765395170334,
           18.264190622564787,
           18.080727293426225,
           17.8972639642876,
           17.713800635149052,
           17.53033730601049,
           17.346873976871926,
           17.16341064773331,
           16.979947318594757,
           16.796483989456192,
           16.616856359803467,
           16.445460395249466,
           16.274064430695454,
           16.102668466141402,
           15.931272501587403,
           15.759876537033389,
           15.588480572479378,
           15.41708460792539,
           15.245688643371373,
           15.074292678817313,
           14.913254838840349,
           14.752854999611957,
           14.592455160383647,
           14.432055321155255,
           14.271655481926954,
           14.111255642698556,
           13.950855803470196,
           13.790455964241861,
           13.633698900535343,
           13.483341311538734,
           13.332983722542217,
           13.182626133545618,
           13.032268544549046,
           12.88191095555249,
           12.73155336655593,
           12.58119577755932,
           12.435260648591546,
           12.294063867227148,
           12.152867085862704,
           12.011670304498335,
           11.870473523133908,
           11.7292767417695,
           11.588079960405056,
           11.448724997906856,
           11.315904707415546,
           11.183084416924196,
           11.050264126432817,
           10.917443835941471,
           10.78462354545012,
           10.651803254958777,
           10.522927933497447,
           10.397929565746372,
           10.27293119799533,
           10.147932830244295,
           10.02293446249326,
           9.897936094742217,
           9.775458047950426,
           9.659573563852566,
           9.543689079754698,
           9.427804595656836,
           9.311920111558978,
           9.196035627461079,
           9.084952032056883,
           8.978962712287313,
           8.872973392517702,
           8.766984072748118,
           8.660994752978517,
           8.555607198970963,
           8.456620248355701,
           8.357633297740447,
           8.258646347125193,
           8.159659396509907,
           8.06088061926071,
           7.967058985686409,
           7.873237352112081,
           7.779415718537776,
           7.685594084963455,
           7.593841002912251,
           7.506593834389388,
           7.419346665866552,
           7.332099497343716,
           7.244852328820853,
           7.163704275744533,
           7.083392391877774,
           7.003080508011025,
           6.922768624144276,
           6.84681721711543,
           6.77265798088111,
           6.698498744646773,
           6.624339508412473,
           6.554425337445369,
           6.485711913100923,
           6.416998488756467,
           6.347304085827265,
           6.264856961295903,
           6.1824098367645535,
           6.0999627122332,
           6.017515587701841,
           5.935068463170479,
           5.85262133863913,
           5.770174214107776,
           5.687727089576418,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           67.11636193929459,
           67.15369278013588,
           67.19102362097716,
           67.22835446181844,
           67.26568530265973,
           67.30301614350103,
           67.34034698434229,
           67.37767782518358,
           67.41500866602486,
           67.45233950686614,
           67.48967034770743,
           67.52700118854872,
           67.56433202939,
           67.60166287023128,
           67.63899371107257,
           67.67632455191385,
           67.71365539275513,
           67.75098623359642,
           67.7883170744377,
           67.82564791527898,
           67.86297875612027,
           67.90030959696155,
           67.93764043780283,
           67.97497127864412,
           68.0123021194854,
           68.04963296032668,
           68.08696380116797,
           68.12429464200925,
           68.16162548285054,
           68.19895632369182,
           68.2362871645331,
           68.27361800537439,
           68.31026332574886,
           68.34622312583359,
           68.38218292591831,
           68.41814272600304,
           68.45410252608777,
           68.4900623261725,
           68.52602212625723,
           68.56198192634197,
           68.5979417264267,
           68.63390152651142,
           68.66986132659616,
           68.70582112668089,
           68.74178092676561,
           68.77774072685034,
           68.81370052693507,
           68.84966032701979,
           68.88562012710452,
           68.92157992718926,
           68.95753972727398,
           68.99349952735871,
           69.02945932744345,
           69.06541912752817,
           69.1013789276129,
           69.13733872769762,
           69.17329852778236,
           69.20925832786709,
           69.2452181279518,
           69.28117792803656,
           69.31713772812127,
           69.353097528206,
           69.38905732829073,
           69.42501712837546,
           69.46097692846018,
           69.49693672854491,
           69.53289652862965,
           69.56885632871438,
           69.6048161287991,
           69.64077592888384,
           69.67673572896857,
           69.71269552905329,
           69.74865532913802,
           69.78461512922274,
           69.82057492930748,
           69.85653472939221,
           69.89249452947693,
           69.92845432956166,
           69.9644141296464,
           70.00037392973113,
           70.03633372981585,
           70.07229352990058,
           70.1082533299853,
           70.14421313007003,
           70.15623205359634,
           70.16346280181097,
           70.1706935500256,
           70.17792429824023,
           70.18515504645485,
           70.19238579466949,
           70.19961654288412,
           70.20684729109874,
           70.21407803931336,
           70.221308787528,
           70.22853953574264,
           70.23577028395725,
           70.24300103217189,
           70.25023178038651,
           70.25746252860115,
           70.26469327681578,
           70.2719240250304,
           70.27915477324503,
           70.28638552145966,
           70.29361626967429,
           70.30084701788891,
           70.30807776610354,
           70.31530851431818,
           70.3225392625328,
           70.32977001074744,
           70.33700075896206,
           70.34423150717669,
           70.35146225539131,
           70.35869300360594,
           70.36592375182057,
           70.3731545000352,
           70.37922610802961,
           70.38297943625716,
           70.38673276448472,
           70.39048609271225,
           70.39423942093981,
           70.39799274916734,
           70.4017460773949,
           70.40549940562246,
           70.40925273385,
           70.41300606207756,
           70.4167593903051,
           70.42051271853265,
           70.4242660467602,
           70.42801937498774,
           70.4317727032153,
           70.43552603144285,
           70.4392793596704,
           70.44303268789794,
           70.44678601612549,
           70.45053934435305,
           70.45429267258058,
           70.45804600080814,
           70.46179932903568,
           70.46555265726323,
           70.46930598549079,
           70.47305931371832,
           70.47681264194588,
           70.48056597017343,
           70.48431929840098,
           70.48807262662852,
           70.49182595485607,
           70.49557928308363,
           70.49933261131117,
           70.50308593953872,
           70.50683926776627,
           70.51059259599381,
           70.51434592422137,
           70.51809925244892,
           70.52185258067645,
           70.52560590890401,
           70.52935923713156,
           70.53311256535912,
           70.53686589358665,
           70.5406192218142,
           70.54437255004174,
           70.5481258782693,
           70.55187920649685,
           70.5556325347244,
           70.55938586295194,
           70.56313919117949,
           70.56689251940705,
           70.5706458476346,
           70.19665267551952,
           69.63378625323318,
           69.0709198309468,
           68.50805340866044,
           67.94518698637411,
           67.38232056408773,
           66.81945414180137,
           66.25658771951501,
           65.69372129722865,
           65.13085487494232,
           64.56798845265592,
           64.00512203036958,
           63.44225560808321,
           62.87938918579686,
           62.316522763510505,
           61.75365634122414,
           61.19078991893779,
           60.62792349665142,
           60.06505707436505,
           59.50219065207872,
           58.93932422979235,
           58.376457807505986,
           57.81359138521965,
           57.25072496293326,
           56.687858540646914,
           56.12499211836055,
           55.56212569607418,
           54.99925927378785,
           54.43639285150146,
           53.87352642921512,
           53.31066000692876,
           52.74779358464239,
           52.184927162356054,
           51.622060740069685,
           51.05919431778332,
           50.496327895496954,
           49.93346147321059,
           49.37059505092425,
           48.80772862863788,
           48.24486220635152,
           47.68199578406518,
           47.11912936177882,
           46.556262939492456,
           45.993396517206094,
           45.430530094919725,
           44.867663672633356,
           44.304797250347015,
           43.74193082806065,
           43.17906440577429,
           42.61619798348792,
           42.05333156120156,
           41.49046513891522,
           40.92759871662886,
           40.36473229434249,
           39.801865872056126,
           39.23899944976979,
           38.67613302748342,
           38.113266605197055,
           37.55040018291069,
           36.98753376062433,
           36.42466733833798,
           35.86180091605162,
           35.29893449376526,
           34.73606807147889,
           34.17320164919255,
           33.61033522690619,
           33.047468804619825,
           32.48460238233346,
           31.921735960047094,
           31.358869537760754,
           30.796003115474388,
           30.233136693188026,
           29.670270270901657,
           29.107403848615295,
           28.544537426328958,
           27.98167100404259,
           27.418804581756227,
           26.867979632159333,
           26.317154693970796,
           25.766329755782234,
           25.215504817593676,
           24.664679879405114,
           24.11385494121655,
           23.729458654356417,
           23.517658762966935,
           23.30898129060564,
           23.10030381824434,
           22.891626345883033,
           22.682948873521667,
           22.474271401160436,
           22.26559392879906,
           22.056916456437754,
           21.848238984076467,
           21.639561511715158,
           21.43088403935378,
           21.222206566992483,
           21.01352909463119,
           20.81615529478563,
           20.619541406893294,
           20.422927519001014,
           20.226313631108727,
           20.02969974321645,
           19.833085855324114,
           19.636471967431824,
           19.439858079539537,
           19.243244191647268,
           19.04663030375492,
           18.85001641586269,
           18.659312888138782,
           18.475849559000228,
           18.292386229861606,
           18.108922900723044,
           17.925459571584494,
           17.74199624244593,
           17.558532913307307,
           17.37506958416876,
           17.191606255030194,
           17.008142925891626,
           16.825024380074208,
           16.653628415520213,
           16.482232450966148,
           16.310836486412146,
           16.139440521858145,
           15.968044557304134,
           15.796648592750083,
           15.625252628196083,
           15.45385666364207,
           15.282460699088059,
           15.116919326550587,
           14.956519487322229,
           14.796119648093871,
           14.635719808865527,
           14.475319969637134,
           14.314920130408826,
           14.154520291180434,
           13.994120451952131,
           13.833720612723733,
           13.681787767246279,
           13.53143017824973,
           13.381072589253161,
           13.230715000256552,
           13.080357411260035,
           12.929999822263436,
           12.779642233266864,
           12.629284644270307,
           12.486824304419386,
           12.345627523054977,
           12.20443074169058,
           12.06323396032618,
           11.922037178961737,
           11.780840397597368,
           11.639643616232942,
           11.5026855411845,
           11.369865250693145,
           11.237044960201768,
           11.104224669710458,
           10.971404379219106,
           10.838584088727728,
           10.705763798236381,
           10.578452861314132,
           10.453454493563099,
           10.328456125812066,
           10.20345775806099,
           10.078459390309945,
           9.953461022558912,
           9.832077660131667,
           9.716193176033798,
           9.600308691935908,
           9.484424207838048,
           9.368539723740177,
           9.252655239642317,
           9.14202506147584,
           9.036035741706256,
           8.930046421936671,
           8.824057102167101,
           8.71806778239749,
           8.61251611035855,
           8.513529159743296,
           8.414542209128017,
           8.315555258512756,
           8.216568307897504,
           8.117581357282248,
           8.023512516470461,
           7.929690882896162,
           7.835869249321862,
           7.742047615747534,
           7.649316381583031,
           7.562069213060214,
           7.474822044537377,
           7.387574876014514,
           7.300327707491679,
           7.2177532483495375,
           7.137441364482807,
           7.057129480616064,
           6.976817596749305,
           6.8992715814973975,
           6.825112345263076,
           6.750953109028766,
           6.676793872794446,
           6.6051938046094225,
           6.536480380264965,
           6.467766955920523,
           6.399053531576078,
           6.320530321383849,
           6.238083196852497,
           6.155636072321135,
           6.0731889477897845,
           5.990741823258431,
           5.908294698727072,
           5.825847574195711,
           5.743400449664361,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           67.04976307353357,
           67.08709391437485,
           67.12442475521613,
           67.1617555960574,
           67.1990864368987,
           67.23641727773999,
           67.27374811858125,
           67.31107895942255,
           67.34840980026382,
           67.38574064110512,
           67.4230714819464,
           67.46040232278769,
           67.49773316362896,
           67.53506400447026,
           67.57239484531152,
           67.60972568615281,
           67.64568548689654,
           67.68164528698127,
           67.71760508706599,
           67.75356488715073,
           67.78952468723546,
           67.82548448732018,
           67.86144428740491,
           67.89740408748963,
           67.93336388757437,
           67.9693236876591,
           68.00528348774382,
           68.04124328782856,
           68.07720308791329,
           68.11316288799802,
           68.14912268808274,
           68.18508248816747,
           68.2210422882522,
           68.25700208833693,
           68.29296188842166,
           68.32892168850638,
           68.36488148859112,
           68.40084128867585,
           68.43680108876057,
           68.4727608888453,
           68.50872068893003,
           68.54468048901475,
           68.58064028909949,
           68.61660008918422,
           68.65255988926894,
           68.68851968935367,
           68.72447948943841,
           68.76043928952313,
           68.79639908960786,
           68.83235888969259,
           68.86831868977731,
           68.90427848986205,
           68.94023828994678,
           68.9761980900315,
           69.01215789011624,
           69.04811769020097,
           69.0840774902857,
           69.12003729037042,
           69.15599709045514,
           69.19195689053987,
           69.2279166906246,
           69.26387649070935,
           69.29983629079406,
           69.33579609087879,
           69.37175589096353,
           69.40771569104825,
           69.44367549113298,
           69.4796352912177,
           69.51559509130243,
           69.55155489138716,
           69.5875146914719,
           69.62347449155664,
           69.65943429164136,
           69.69539409172609,
           69.73135389181081,
           69.76731369189554,
           69.80327349198026,
           69.83923329206499,
           69.87519309214973,
           69.91115289223445,
           69.94711269231918,
           69.9830724924039,
           70.01903229248865,
           70.05499209257337,
           70.06701101609968,
           70.07424176431431,
           70.08147251252893,
           70.08870326074357,
           70.09593400895818,
           70.10316475717282,
           70.11039550538746,
           70.11762625360207,
           70.12485700181671,
           70.13208775003133,
           70.13931849824596,
           70.1465492464606,
           70.15377999467522,
           70.16101074288986,
           70.16824149110448,
           70.1725743910013,
           70.17632771922885,
           70.1800810474564,
           70.18383437568394,
           70.1875877039115,
           70.19134103213905,
           70.1950943603666,
           70.19884768859414,
           70.20260101682169,
           70.20635434504925,
           70.2101076732768,
           70.21386100150434,
           70.21761432973189,
           70.22136765795943,
           70.22512098618698,
           70.22887431441453,
           70.23262764264209,
           70.23638097086963,
           70.24013429909718,
           70.24388762732474,
           70.24764095555227,
           70.25139428377983,
           70.25514761200738,
           70.25890094023492,
           70.26265426846247,
           70.26640759669002,
           70.27016092491758,
           70.27391425314512,
           70.27766758137267,
           70.28142090960021,
           70.28517423782776,
           70.2889275660553,
           70.29268089428285,
           70.29643422251041,
           70.30018755073795,
           70.3039408789655,
           70.30769420719305,
           70.3114475354206,
           70.31520086364814,
           70.31895419187569,
           70.32270752010325,
           70.3264608483308,
           70.33021417655834,
           70.33396750478589,
           70.33772083301344,
           70.34147416124098,
           70.34522748946854,
           70.34898081769609,
           70.35273414592363,
           70.35648747415118,
           70.36024080237874,
           70.36399413060627,
           70.36774745883383,
           70.37150078706138,
           70.37525411528893,
           70.37900744351649,
           70.38276077174402,
           70.38651409997158,
           70.39026742819911,
           70.39402075642667,
           70.39777408465422,
           70.40152741288176,
           70.40528074110931,
           70.40903406933685,
           70.41278739756441,
           70.41654072579196,
           70.42029405401951,
           70.42404738224705,
           70.05005421013199,
           69.48718778784564,
           68.92432136555927,
           68.36145494327292,
           67.79858852098657,
           67.23572209870018,
           66.67285567641383,
           66.10998925412748,
           65.54712283184112,
           64.98425640955477,
           64.42138998726838,
           63.85852356498204,
           63.29565714269568,
           62.73279072040931,
           62.16992429812298,
           61.60705787583661,
           61.04419145355025,
           60.48132503126388,
           59.91845860897751,
           59.355592186691176,
           58.79272576440481,
           58.22985934211845,
           57.666992919832104,
           57.104126497545714,
           56.54126007525938,
           55.97839365297301,
           55.41552723068664,
           54.85266080840031,
           54.28979438611392,
           53.726927963827585,
           53.164061541541216,
           52.601195119254854,
           52.03832869696851,
           51.475462274682144,
           50.91259585239578,
           50.34972943010942,
           49.78686300782306,
           49.22399658553671,
           48.66113016325035,
           48.09826374096398,
           47.53539731867764,
           46.97253089639128,
           46.40966447410491,
           45.846798051818546,
           45.28393162953218,
           44.72106520724582,
           44.1546999212827,
           43.5865852001905,
           43.01847047909829,
           42.45035575800609,
           41.882241036913875,
           41.3141263158217,
           40.746011594729495,
           40.17789687363729,
           39.60978215254508,
           39.04166743145291,
           38.4735527103607,
           37.90543798926849,
           37.337323268176284,
           36.76920854708408,
           36.2010938259919,
           35.6329791048997,
           35.06486438380749,
           34.49674966271529,
           33.9286349416231,
           33.3605202205309,
           32.792405499438686,
           32.224290778346486,
           31.656176057254278,
           31.088061336162102,
           30.519946615069898,
           29.95183189397769,
           29.383717172885483,
           28.81560245179328,
           28.2474877307011,
           27.679373009608895,
           27.111258288516687,
           26.54314356742448,
           25.9750288463323,
           25.406914125240093,
           24.838799404147892,
           24.270684683055684,
           23.702569961963476,
           23.314173865236793,
           23.105496392875416,
           22.896818920514125,
           22.68814144815282,
           22.479463975791514,
           22.270786503430152,
           22.062109031068918,
           21.85343155870754,
           21.644754086346236,
           21.43607661398495,
           21.227399141623643,
           21.0298828584827,
           20.833268970590424,
           20.636655082698148,
           20.440041194805858,
           20.24342730691352,
           20.04681341902124,
           19.850199531128954,
           19.653585643236674,
           19.456971755344338,
           19.26035786745205,
           19.063743979559764,
           18.87097182457418,
           18.687508495435612,
           18.504045166297043,
           18.320581837158493,
           18.137118508019938,
           17.953655178881313,
           17.77019184974276,
           17.5867285206042,
           17.403265191465636,
           17.219801862327014,
           17.03633853318847,
           16.8617964357909,
           16.690400471236842,
           16.519004506682887,
           16.34760854212889,
           16.176212577574827,
           16.004816613020825,
           15.833420648466822,
           15.662024683912811,
           15.490628719358758,
           15.320583814260853,
           15.160183975032496,
           14.999784135804097,
           14.839384296575762,
           14.678984457347404,
           14.518584618119045,
           14.358184778890699,
           14.19778493966231,
           14.037385100434001,
           13.880234222953836,
           13.729876633957238,
           13.57951904496067,
           13.429161455964099,
           13.278803866967552,
           13.128446277970983,
           12.978088688974374,
           12.827731099977857,
           12.679584741611656,
           12.53838796024725,
           12.397191178882814,
           12.255994397518416,
           12.114797616154007,
           11.97360083478961,
           11.832404053425211,
           11.691207272060765,
           11.556646084462097,
           11.423825793970797,
           11.29100550347941,
           11.158185212988057,
           11.02536492249668,
           10.89254463200537,
           10.759724341514017,
           10.633977789130824,
           10.50897942137979,
           10.383981053628746,
           10.258982685877712,
           10.133984318126679,
           10.008985950375603,
           9.888697272312868,
           9.772812788215008,
           9.656928304117146,
           9.541043820019278,
           9.42515933592139,
           9.309274851823528,
           9.199098090894779,
           9.093108771125202,
           8.987119451355627,
           8.881130131586042,
           8.775140811816458,
           8.669425021746127,
           8.570438071130864,
           8.471451120515603,
           8.372464169900349,
           8.27347721928507,
           8.174490268669809,
           8.079966047254523,
           7.986144413680222,
           7.892322780105917,
           7.798501146531618,
           7.70479176025386,
           7.617544591731018,
           7.530297423208155,
           7.443050254685339,
           7.355803086162502,
           7.271802220954569,
           7.191490337087826,
           7.111178453221067,
           7.030866569354336,
           6.951725945879372,
           6.877566709645072,
           6.803407473410735,
           6.729248237176414,
           6.655962271773468,
           6.587248847429007,
           6.518535423084575,
           6.449821998740119,
           6.376203681471793,
           6.293756556940432,
           6.211309432409081,
           6.128862307877728,
           6.046415183346365,
           5.963968058815016,
           5.881520934283662,
           5.799073809752304,
           5.716626685220942,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           66.98234680960299,
           67.01672893306237,
           67.05189989635103,
           67.08785969643576,
           67.12381949652048,
           67.15977929660521,
           67.19573909668995,
           67.23169889677467,
           67.2676586968594,
           67.30361849694413,
           67.33957829702885,
           67.37553809711359,
           67.41149789719832,
           67.44745769728304,
           67.48341749736778,
           67.51937729745251,
           67.55533709753723,
           67.59129689762196,
           67.62725669770668,
           67.66321649779142,
           67.69917629787614,
           67.73513609796088,
           67.7710958980456,
           67.80705569813033,
           67.84301549821507,
           67.87897529829979,
           67.91493509838452,
           67.95089489846924,
           67.98685469855397,
           68.0228144986387,
           68.05877429872342,
           68.09473409880816,
           68.1306938988929,
           68.16665369897761,
           68.20261349906235,
           68.23857329914708,
           68.2745330992318,
           68.31049289931653,
           68.34645269940125,
           68.382412499486,
           68.41837229957072,
           68.45433209965545,
           68.49029189974019,
           68.52625169982491,
           68.56221149990964,
           68.59817129999436,
           68.6341311000791,
           68.67009090016381,
           68.70605070024854,
           68.74201050033328,
           68.777970300418,
           68.81393010050274,
           68.84988990058747,
           68.8858497006722,
           68.92180950075692,
           68.95776930084165,
           68.99372910092639,
           69.02968890101111,
           69.06564870109582,
           69.10160850118056,
           69.13756830126529,
           69.17352810135003,
           69.20948790143476,
           69.24544770151948,
           69.2814075016042,
           69.31736730168893,
           69.35332710177367,
           69.3892869018584,
           69.42524670194314,
           69.46120650202786,
           69.49716630211259,
           69.53312610219731,
           69.56908590228204,
           69.60504570236677,
           69.6410055024515,
           69.67696530253623,
           69.71292510262096,
           69.74888490270568,
           69.78484470279042,
           69.82080450287515,
           69.85676430295987,
           69.8927241030446,
           69.92868390312933,
           69.96464370321405,
           69.97376477675114,
           69.97751810497869,
           69.98127143320623,
           69.98502476143378,
           69.98877808966132,
           69.99253141788888,
           69.99628474611643,
           70.00003807434398,
           70.00379140257152,
           70.00754473079907,
           70.01129805902663,
           70.01505138725418,
           70.01880471548172,
           70.02255804370927,
           70.02631137193683,
           70.03006470016436,
           70.03381802839192,
           70.03757135661947,
           70.04132468484701,
           70.04507801307456,
           70.0488313413021,
           70.05258466952965,
           70.0563379977572,
           70.06009132598476,
           70.0638446542123,
           70.06759798243985,
           70.0713513106674,
           70.07510463889494,
           70.0788579671225,
           70.08261129535005,
           70.0863646235776,
           70.09011795180514,
           70.09387128003269,
           70.09762460826025,
           70.1013779364878,
           70.10513126471534,
           70.1088845929429,
           70.11263792117043,
           70.11639124939798,
           70.12014457762554,
           70.12389790585308,
           70.12765123408064,
           70.13140456230818,
           70.13515789053574,
           70.13891121876327,
           70.14266454699083,
           70.14641787521838,
           70.15017120344592,
           70.15392453167347,
           70.15767785990101,
           70.16143118812857,
           70.16518451635612,
           70.16893784458367,
           70.17269117281121,
           70.17644450103876,
           70.18019782926632,
           70.18395115749385,
           70.18770448572141,
           70.19145781394896,
           70.1952111421765,
           70.19896447040406,
           70.2027177986316,
           70.20647112685916,
           70.2102244550867,
           70.21397778331425,
           70.2177311115418,
           70.22148443976934,
           70.22523776799689,
           70.22899109622445,
           70.232744424452,
           70.23649775267954,
           70.24025108090709,
           70.24400440913463,
           70.24775773736219,
           70.25151106558974,
           70.25526439381728,
           70.25901772204483,
           70.26277105027238,
           70.26652437849992,
           70.27027770672748,
           70.27403103495503,
           70.27691267853112,
           70.27543586868346,
           69.89147332253441,
           69.3162679082347,
           68.74106249393498,
           68.1714705581558,
           67.60335583706363,
           67.03524111597139,
           66.46712639487922,
           65.899011673787,
           65.3308969526948,
           64.76278223160263,
           64.1946675105104,
           63.62655278941821,
           63.058438068326005,
           62.4903233472338,
           61.92220862614162,
           61.35409390504941,
           60.78597918395721,
           60.21786446286501,
           59.649749741772794,
           59.081635020680615,
           58.51352029958841,
           57.94540557849621,
           57.37729085740402,
           56.8091761363118,
           56.24106141521962,
           55.67294669412741,
           55.1048319730352,
           54.53671725194302,
           53.96860253085079,
           53.400487809758616,
           52.83237308866641,
           52.2642583675742,
           51.696143646482014,
           51.12802892538981,
           50.55991420429761,
           49.991799483205405,
           49.4236847621132,
           48.85557004102102,
           48.28745531992881,
           47.71934059883661,
           47.15122587774443,
           46.58311115665222,
           46.01499643556002,
           45.44688171446781,
           44.8787669933756,
           44.3106522722834,
           43.74253755119122,
           43.17442283009902,
           42.60630810900681,
           42.0381933879146,
           41.470078666822396,
           40.901963945730216,
           40.333849224638016,
           39.7657345035458,
           39.1976197824536,
           38.62950506136142,
           38.06139034026921,
           37.49327561917701,
           36.925160898084805,
           36.3570461769926,
           35.78893145590042,
           35.22081673480821,
           34.65270201371601,
           34.0845872926238,
           33.51647257153162,
           32.948357850439415,
           32.38024312934721,
           31.812128408255006,
           31.2440136871628,
           30.67589896607062,
           30.10778424497841,
           29.539669523886207,
           28.971554802794003,
           28.403440081701795,
           27.835325360609616,
           27.26721063951741,
           26.699095918425204,
           26.130981197332996,
           25.562866476240817,
           24.994751755148613,
           24.426637034056405,
           23.858522312964205,
           23.290407591871997,
           22.90201149514531,
           22.693334022783933,
           22.484656550422642,
           22.275979078061336,
           22.06730160570003,
           21.858624133338665,
           21.64994666097743,
           21.441269188616058,
           21.243610422179803,
           21.046996534287597,
           20.85038264639525,
           20.653768758502956,
           20.457154870610676,
           20.260540982718403,
           20.063927094826113,
           19.867313206933776,
           19.670699319041496,
           19.47408543114921,
           19.27747154325693,
           19.082630761009593,
           18.899167431871028,
           18.715704102732456,
           18.532240773593916,
           18.348777444455347,
           18.16531411531678,
           17.981850786178224,
           17.79838745703967,
           17.614924127901048,
           17.43146079876249,
           17.247997469623936,
           17.069964456061616,
           16.898568491507653,
           16.727172526953662,
           16.5557765623996,
           16.38438059784554,
           16.212984633291587,
           16.04158866873759,
           15.870192704183527,
           15.698796739629525,
           15.52740077507552,
           15.363848462742741,
           15.203448623514442,
           15.04304878428605,
           14.882648945057692,
           14.722249105829292,
           14.561849266600957,
           14.401449427372599,
           14.241049588144241,
           14.080649748915896,
           13.928323089664804,
           13.77796550066824,
           13.627607911671678,
           13.477250322675081,
           13.326892733678513,
           13.176535144681942,
           13.026177555685392,
           12.875819966688825,
           12.731148397439538,
           12.589951616075101,
           12.448754834710703,
           12.307558053346296,
           12.166361271981861,
           12.025164490617463,
           11.883967709253055,
           11.743426918231142,
           11.610606627739765,
           11.47778633724841,
           11.344966046757023,
           11.212145756265723,
           11.079325465774337,
           10.946505175282985,
           10.814501084698598,
           10.689502716947564,
           10.564504349196522,
           10.439505981445453,
           10.314507613694422,
           10.189509245943377,
           10.064510878192342,
           9.945316884494128,
           9.82943240039626,
           9.713547916298364,
           9.597663432200502,
           9.48177894810264,
           9.365894464004771,
           9.256171120313738,
           9.150181800544162,
           9.044192480774578,
           8.938203161005001,
           8.832213841235424,
           8.726333933133699,
           8.627346982518437,
           8.52836003190319,
           8.429373081287928,
           8.330386130672666,
           8.231399180057412,
           8.136419578038593,
           8.042597944464287,
           7.948776310889988,
           7.854954677315687,
           7.761133043741382,
           7.67301997040185,
           7.585772801878995,
           7.498525633356151,
           7.411278464833289,
           7.325851193559599,
           7.245539309692855,
           7.165227425826107,
           7.084915541959363,
           7.004603658092604,
           6.930021074027048,
           6.855861837792715,
           6.781702601558416,
           6.707543365324078,
           6.638017314593066,
           6.569303890248629,
           6.500590465904168,
           6.431877041559735,
           6.34942991702839,
           6.266982792497036,
           6.184535667965674,
           6.1020885434343235,
           6.019641418902971,
           5.93719429437161,
           5.854747169840259,
           5.7723000453089055,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           66.90675655812464,
           66.94113868158401,
           66.97552080504337,
           67.00990292850274,
           67.0442850519621,
           67.07866717542147,
           67.11304929888084,
           67.1474314223402,
           67.18181354579957,
           67.21619566925894,
           67.25057779271832,
           67.28495991617768,
           67.31934203963705,
           67.35372416309642,
           67.38810628655578,
           67.42248841001516,
           67.45687053347451,
           67.49125265693388,
           67.52563478164956,
           67.5615945817343,
           67.59755438181902,
           67.63351418190376,
           67.66947398198847,
           67.70543378207321,
           67.74139358215794,
           67.77735338224267,
           67.81331318232739,
           67.84927298241213,
           67.88523278249686,
           67.92119258258158,
           67.95715238266631,
           67.99311218275105,
           68.02907198283577,
           68.0650317829205,
           68.10099158300523,
           68.13695138308995,
           68.17291118317469,
           68.20887098325942,
           68.24483078334414,
           68.28079058342888,
           68.31675038351361,
           68.35271018359833,
           68.38866998368306,
           68.42462978376778,
           68.46058958385251,
           68.49654938393725,
           68.53250918402198,
           68.5684689841067,
           68.60442878419143,
           68.64038858427615,
           68.67634838436089,
           68.71230818444562,
           68.74826798453034,
           68.78422778461507,
           68.8201875846998,
           68.85614738478453,
           68.89210718486926,
           68.928066984954,
           68.96402678503873,
           68.99998658512345,
           69.03594638520818,
           69.0719061852929,
           69.10786598537763,
           69.14382578546237,
           69.1797855855471,
           69.21574538563183,
           69.25170518571655,
           69.28766498580129,
           69.32362478588601,
           69.35958458597074,
           69.39554438605546,
           69.43150418614019,
           69.46746398622491,
           69.50342378630965,
           69.53938358639438,
           69.57534338647912,
           69.61130318656383,
           69.64726298664857,
           69.6832227867333,
           69.71918258681802,
           69.75514238690275,
           69.79110218698749,
           69.82706198707221,
           69.86302178715694,
           69.87214286069401,
           69.87589618892156,
           69.87964951714912,
           69.88340284537665,
           69.88715617360421,
           69.89090950183176,
           69.8946628300593,
           69.89841615828685,
           69.9021694865144,
           69.90592281474196,
           69.90967614296952,
           69.91342947119705,
           69.91718279942461,
           69.92093612765214,
           69.9246894558797,
           69.92844278410726,
           69.9321961123348,
           69.93594944056235,
           69.93970276878989,
           69.94345609701745,
           69.94720942524499,
           69.95096275347254,
           69.9547160817001,
           69.95846940992763,
           69.96222273815519,
           69.96597606638272,
           69.96972939461028,
           69.97348272283783,
           69.97723605106538,
           69.98098937929292,
           69.98474270752048,
           69.98849603574803,
           69.99224936397557,
           69.99600269220312,
           69.99975602043068,
           70.00350934865821,
           70.00726267688577,
           70.0110160051133,
           70.01476933334087,
           70.01852266156843,
           70.02227598979596,
           70.02602931802352,
           70.02978264625105,
           70.03353597447861,
           70.03728930270616,
           70.0410426309337,
           70.04479595916126,
           70.0485492873888,
           70.05230261561636,
           70.0560559438439,
           70.05980927207145,
           70.063562600299,
           70.06731592852654,
           70.0710692567541,
           70.07482258498163,
           70.07857591320919,
           70.08232924143674,
           70.08608256966428,
           70.08983589789183,
           70.09358922611939,
           70.09734255434694,
           70.10109588257448,
           70.10484921080203,
           70.10860253902958,
           70.11235586725714,
           70.11262244093264,
           70.11114563108498,
           70.10966882123729,
           70.10819201138963,
           70.10671520154196,
           70.10523839169429,
           70.10376158184661,
           70.10228477199895,
           70.10080796215128,
           70.0993311523036,
           70.09785434245595,
           70.09637753260827,
           70.0949007227606,
           70.09342391291293,
           70.09194710306525,
           70.09047029321759,
           70.08899348336993,
           70.08751667352226,
           69.7035541273732,
           69.12834871307349,
           68.55314329877376,
           67.97793788447404,
           67.40273247017434,
           66.82752705587458,
           66.25232164157488,
           65.67711622727516,
           65.10191081297543,
           64.52670539867573,
           63.95149998437598,
           63.37629457007627,
           62.80108915577655,
           62.22588374147682,
           61.650678327177125,
           61.07547291287739,
           60.500267498577664,
           59.92506208427794,
           59.34985666997821,
           58.77465125567851,
           58.199445841378775,
           57.624240427079044,
           57.049035012779356,
           56.473829598479604,
           55.89862418417991,
           55.32341876988016,
           54.74821335558045,
           54.173007941280744,
           53.597802526980985,
           53.02259711268128,
           52.44739169838155,
           51.872186284081835,
           51.296980869782125,
           50.7217754554824,
           50.1477518342061,
           49.57963711311389,
           49.01152239202169,
           48.4434076709295,
           47.875292949837295,
           47.307178228745094,
           46.739063507652915,
           46.170948786560714,
           45.6028340654685,
           45.03471934437629,
           44.466604623284084,
           43.89848990219188,
           43.3303751810997,
           42.762260460007504,
           42.19414573891529,
           41.62603101782309,
           41.05791629673088,
           40.48980157563871,
           39.92168685454649,
           39.353572133454286,
           38.785457412362085,
           38.217342691269906,
           37.649227970177705,
           37.08111324908549,
           36.51299852799329,
           35.94488380690108,
           35.3767690858089,
           34.8086543647167,
           34.24053964362449,
           33.67242492253229,
           33.10431020144011,
           32.5361954803479,
           31.968080759255695,
           31.399966038163488,
           30.831851317071283,
           30.263736595979104,
           29.695621874886896,
           29.127507153794692,
           28.559392432702484,
           27.99127771161028,
           27.4231629905181,
           26.855048269425893,
           26.286933548333693,
           25.71881882724148,
           25.150704106149302,
           24.582589385057098,
           24.01447466396489,
           23.446359942872686,
           22.87824522178048,
           22.489849125053794,
           22.28117165269242,
           22.07249418033113,
           21.863816707969825,
           21.65513923560852,
           21.457337985876944,
           21.260724097984674,
           21.06411021009238,
           20.867496322200033,
           20.67088243430783,
           20.47426854641548,
           20.277654658523186,
           20.08104077063091,
           19.884426882738637,
           19.687812994846343,
           19.491199106954006,
           19.294585219061727,
           19.110826368306412,
           18.927363039167854,
           18.743899710029304,
           18.56043638089074,
           18.376973051752163,
           18.193509722613626,
           18.010046393475058,
           17.82658306433649,
           17.643119735197935,
           17.45965640605938,
           17.278132476332363,
           17.106736511778358,
           16.93534054722436,
           16.763944582670298,
           16.592548618116332,
           16.42115265356234,
           16.249756689008283,
           16.07836072445422,
           15.90696475990027,
           15.73556879534627,
           15.567512950453015,
           15.40711311122467,
           15.24671327199632,
           15.08631343276792,
           14.925913593539619,
           14.765513754311229,
           14.60511391508287,
           14.444714075854469,
           14.284314236626134,
           14.126769545372316,
           13.976411956375749,
           13.826054367379188,
           13.675696778382626,
           13.52533918938606,
           13.3749816003895,
           13.224624011392901,
           13.074266422396333,
           12.923908834631776,
           12.782712053267383,
           12.64151527190294,
           12.500318490538572,
           12.359121709174135,
           12.217924927809737,
           12.076728146445332,
           11.935531365080895,
           11.797387461508714,
           11.664567171017364,
           11.531746880526052,
           11.398926590034675,
           11.266106299543324,
           11.133286009051934,
           11.000465718560635,
           10.87002601251529,
           10.745027644764248,
           10.620029277013213,
           10.495030909262177,
           10.370032541511137,
           10.245034173760068,
           10.120035806009035,
           10.00193649667533,
           9.88605201257747,
           9.77016752847961,
           9.654283044381742,
           9.538398560283845,
           9.422514076185983,
           9.313244149732714,
           9.207254829963103,
           9.101265510193526,
           8.99527619042395,
           8.889286870654367,
           8.78329755088479,
           8.68425589390604,
           8.585268943290753,
           8.486281992675494,
           8.387295042060245,
           8.288308091444982,
           8.192873108822647,
           8.099051475248348,
           8.005229841674048,
           7.9114082080997425,
           7.817586574525444,
           7.728495349072655,
           7.6412481805498125,
           7.554001012026975,
           7.466753843504121,
           7.379900166164638,
           7.299588282297889,
           7.219276398431129,
           7.138964514564386,
           7.058652630697638,
           6.982475438409022,
           6.908316202174705,
           6.834156965940384,
           6.759997729706052,
           6.688785781757128,
           6.620072357412666,
           6.5513589330682205,
           6.482645508723784,
           6.40510327711633,
           6.322656152584971,
           6.240209028053621,
           6.1577619035222675,
           6.075314778990906,
           5.992867654459555,
           5.910420529928202,
           5.82797340539684,
           5.745526280865491,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           66.8311663066463,
           66.86554843010566,
           66.89993055356503,
           66.9343126770244,
           66.96869480048377,
           67.00307692394313,
           67.0374590474025,
           67.07184117086186,
           67.10622329432124,
           67.14060541778059,
           67.17498754123997,
           67.20936966469934,
           67.2437517881587,
           67.27813391161807,
           67.31251603507744,
           67.3468981585368,
           67.38128028199617,
           67.41566240545555,
           67.4500445289149,
           67.48442665237428,
           67.51880877583363,
           67.55319089929301,
           67.58757302275238,
           67.62195514621175,
           67.65633726967111,
           67.69071939313048,
           67.72510151658985,
           67.75948364004921,
           67.79386576350858,
           67.82824788696794,
           67.86263001042731,
           67.89701213388669,
           67.93139425734604,
           67.96577638080542,
           68.00015850426479,
           68.03532946703282,
           68.07128926711755,
           68.10724906720229,
           68.14320886728702,
           68.17916866737174,
           68.21512846745647,
           68.25108826754119,
           68.28704806762593,
           68.32300786771066,
           68.3589676677954,
           68.39492746788012,
           68.43088726796485,
           68.46684706804957,
           68.5028068681343,
           68.53876666821904,
           68.57472646830377,
           68.61068626838849,
           68.64664606847322,
           68.68260586855794,
           68.71856566864267,
           68.75452546872741,
           68.79048526881213,
           68.82644506889687,
           68.86240486898159,
           68.89836466906632,
           68.93432446915105,
           68.97028426923578,
           69.0062440693205,
           69.04220386940523,
           69.07816366948997,
           69.11412346957471,
           69.15008326965942,
           69.18604306974416,
           69.22200286982888,
           69.25796266991361,
           69.29392246999834,
           69.32988227008308,
           69.3658420701678,
           69.40180187025251,
           69.43776167033725,
           69.47372147042199,
           69.50968127050672,
           69.54564107059144,
           69.58160087067617,
           69.6175606707609,
           69.65352047084562,
           69.68948027093036,
           69.72544007101509,
           69.76139987109981,
           69.77052094463689,
           69.77427427286443,
           69.77802760109199,
           69.78178092931954,
           69.78553425754708,
           69.78928758577463,
           69.79304091400218,
           69.79679424222972,
           69.80054757045728,
           69.80430089868483,
           69.80805422691238,
           69.81180755513992,
           69.81556088336748,
           69.81931421159501,
           69.82306753982257,
           69.82682086805012,
           69.83057419627767,
           69.83432752450523,
           69.83808085273277,
           69.84183418096032,
           69.84558750918787,
           69.84934083741541,
           69.85309416564296,
           69.8568474938705,
           69.86060082209806,
           69.86435415032561,
           69.86810747855316,
           69.8718608067807,
           69.87561413500825,
           69.87936746323581,
           69.88312079146336,
           69.8868741196909,
           69.89062744791845,
           69.894380776146,
           69.89813410437354,
           69.90188743260109,
           69.90564076082865,
           69.90939408905619,
           69.91314741728374,
           69.91690074551128,
           69.92065407373883,
           69.92440740196639,
           69.92816073019392,
           69.93191405842148,
           69.93566738664903,
           69.93942071487658,
           69.94317404310414,
           69.94692737133167,
           69.94980901318183,
           69.94833220333415,
           69.94685539348649,
           69.94537858363881,
           69.94390177379114,
           69.94242496394348,
           69.9409481540958,
           69.93947134424813,
           69.93799453440047,
           69.9365177245528,
           69.93504091470513,
           69.93356410485745,
           69.93208729500978,
           69.93061048516212,
           69.92913367531445,
           69.92765686546677,
           69.92618005561911,
           69.92470324577144,
           69.92322643592377,
           69.9217496260761,
           69.92027281622842,
           69.91879600638075,
           69.91731919653307,
           69.91584238668541,
           69.91436557683775,
           69.91288876699008,
           69.9114119571424,
           69.90993514729473,
           69.90845833744707,
           69.9069815275994,
           69.90550471775173,
           69.90402790790407,
           69.90255109805639,
           69.90107428820872,
           69.89959747836104,
           69.515634932212,
           68.94042951791229,
           68.36522410361256,
           67.79001868931284,
           67.21481327501314,
           66.63960786071338,
           66.06440244641368,
           65.48919703211395,
           64.91399161781423,
           64.33878620351453,
           63.76358078921477,
           63.18837537491507,
           62.61316996061534,
           62.03796454631562,
           61.46275913201591,
           60.88755371771619,
           60.31234830341646,
           59.737142889116726,
           59.16193747481701,
           58.586732060517306,
           58.01152664621757,
           57.43632123191785,
           56.86111581761815,
           56.2859104033184,
           55.710704989018694,
           55.135499574718956,
           54.56029416041923,
           53.98508874611954,
           53.409883331819785,
           52.83467791752008,
           52.25947250322035,
           51.68426708892063,
           51.10906167462093,
           50.53385626032119,
           49.95865084602147,
           49.38344543172174,
           48.80824001742202,
           48.23303460312232,
           47.65782918882258,
           47.08262377452286,
           46.507418360223156,
           45.932212945923425,
           45.3570075316237,
           44.78180211732397,
           44.206596703024246,
           43.631391288724515,
           43.05618587442481,
           42.48098046012509,
           41.905775045825365,
           41.330569631525634,
           40.7553642172259,
           40.18015880292621,
           39.60495338862648,
           39.02974797432675,
           38.45454256002702,
           37.87933714572732,
           37.304131731427596,
           36.72892631712787,
           36.15372090282814,
           35.57851548852841,
           35.00331007422871,
           34.428104659928984,
           33.85289924562925,
           33.27769383132953,
           32.70248841702983,
           32.127283002730096,
           31.55591838916418,
           30.987803668071976,
           30.419688946979768,
           29.85157422588759,
           29.283459504795385,
           28.715344783703177,
           28.14723006261097,
           27.579115341518765,
           27.011000620426586,
           26.442885899334378,
           25.874771178242174,
           25.30665645714997,
           24.738541736057787,
           24.170427014965583,
           23.60231229387338,
           23.03419757278117,
           22.466082851688967,
           22.077686754962283,
           21.869009282600903,
           21.671065549574017,
           21.4744516616818,
           21.27783777378945,
           21.081223885897174,
           20.8846099980049,
           20.687996110112604,
           20.49138222222026,
           20.294768334328054,
           20.098154446435707,
           19.901540558543413,
           19.704926670651133,
           19.508312782758864,
           19.322485304741857,
           19.1390219756033,
           18.955558646464745,
           18.772095317326123,
           18.588631988187565,
           18.40516865904901,
           18.221705329910446,
           18.038242000771874,
           17.854778671633333,
           17.671315342494765,
           17.487852013356196,
           17.3149045320491,
           17.143508567495047,
           16.97211260294104,
           16.800716638387033,
           16.629320673833035,
           16.457924709278974,
           16.28652874472501,
           16.11513278017102,
           15.943736815616958,
           15.772340851062898,
           15.61077759893489,
           15.450377759706546,
           15.289977920478188,
           15.129578081249843,
           14.969178242021496,
           14.808778402793095,
           14.648378563564792,
           14.4879787243364,
           14.327578885108045,
           14.174858412083294,
           14.024500823086747,
           13.874143234090138,
           13.723785645093571,
           13.57342805609701,
           13.42307046710045,
           13.272712878103881,
           13.122355289107322,
           12.975472490459618,
           12.83427570909525,
           12.693078927730804,
           12.551882146366415,
           12.41068536500197,
           12.269488583637601,
           12.128291802273164,
           11.987095020908765,
           11.851348004786312,
           11.718527714295002,
           11.585707423803623,
           11.45288713331227,
           11.320066842820962,
           11.187246552329583,
           11.05442626183823,
           10.925550940332004,
           10.800552572580946,
           10.675554204829902,
           10.55055583707886,
           10.425557469327826,
           10.300559101576791,
           10.175560733825748,
           10.058556108856568,
           9.942671624758677,
           9.826787140660809,
           9.710902656562949,
           9.595018172465087,
           9.47913368836722,
           9.370317179151655,
           9.264327859382078,
           9.158338539612501,
           9.05234921984289,
           8.946359900073313,
           8.840370580303736,
           8.7411648052936,
           8.642177854678346,
           8.543190904063092,
           8.444203953447808,
           8.345217002832545,
           8.249326639606737,
           8.15550500603241,
           8.061683372458104,
           7.967861738883804,
           7.874040105309505,
           7.783970727743453,
           7.696723559220616,
           7.60947639069778,
           7.5222292221749365,
           7.4349820536521,
           7.353637254902916,
           7.273325371036167,
           7.193013487169418,
           7.112701603302657,
           7.0349298027910105,
           6.96077056655669,
           6.886611330322358,
           6.812452094088041,
           6.739554248921165,
           6.670840824576708,
           6.602127400232281,
           6.53341397588782,
           6.460776637204269,
           6.378329512672925,
           6.29588238814156,
           6.213435263610203,
           6.130988139078852,
           6.0485410145474985,
           5.966093890016138,
           5.883646765484787,
           5.801199640953433,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           66.75557605516795,
           66.78995817862733,
           66.82434030208668,
           66.85872242554606,
           66.89310454900541,
           66.9274866724648,
           66.96186879592416,
           66.99625091938353,
           67.03063304284291,
           67.06501516630226,
           67.09939728976164,
           67.13377941322099,
           67.16816153668036,
           67.20254366013974,
           67.2369257835991,
           67.27130790705847,
           67.30569003051784,
           67.3400721539772,
           67.37445427743657,
           67.40883640089594,
           67.4432185243553,
           67.47760064781468,
           67.51198277127403,
           67.54636489473341,
           67.58074701819277,
           67.61512914165215,
           67.6495112651115,
           67.68389338857088,
           67.71827551203025,
           67.75265763548961,
           67.78703975894898,
           67.82142188240834,
           67.85580400586771,
           67.89018612932708,
           67.92456825278644,
           67.95895037624582,
           67.99333249970519,
           68.02771462316454,
           68.06209674662392,
           68.09647887008329,
           68.13086099354265,
           68.16524311700202,
           68.19962524046139,
           68.23400736392075,
           68.26838948738013,
           68.30277161083949,
           68.33715373429887,
           68.37153585775822,
           68.4059179812176,
           68.44030010467695,
           68.47468222813633,
           68.50906435233138,
           68.5450241524161,
           68.58098395250083,
           68.61694375258556,
           68.6529035526703,
           68.68886335275502,
           68.72482315283975,
           68.76078295292447,
           68.7967427530092,
           68.83270255309394,
           68.86866235317866,
           68.90462215326339,
           68.94058195334812,
           68.97654175343284,
           69.01250155351758,
           69.0484613536023,
           69.08442115368705,
           69.12038095377176,
           69.15634075385648,
           69.19230055394122,
           69.22826035402595,
           69.26422015411069,
           69.30017995419541,
           69.33613975428014,
           69.37209955436487,
           69.40805935444959,
           69.44401915453432,
           69.47997895461906,
           69.51593875470378,
           69.55189855478851,
           69.58785835487325,
           69.62381815495797,
           69.6597779550427,
           69.66889902857977,
           69.67265235680732,
           69.67640568503487,
           69.68015901326243,
           69.68391234148997,
           69.68766566971752,
           69.69141899794506,
           69.69517232617261,
           69.69892565440016,
           69.7026789826277,
           69.70643231085526,
           69.71018563908281,
           69.71393896731036,
           69.7176922955379,
           69.72144562376546,
           69.72519895199301,
           69.72895228022055,
           69.7327056084481,
           69.73645893667565,
           69.74021226490319,
           69.74396559313075,
           69.7477189213583,
           69.75147224958585,
           69.75522557781339,
           69.75897890604094,
           69.76273223426848,
           69.76648556249604,
           69.77023889072359,
           69.77399221895114,
           69.77774554717868,
           69.78149887540624,
           69.78525220363379,
           69.78551877558336,
           69.78404196573568,
           69.78256515588801,
           69.78108834604035,
           69.77961153619268,
           69.778134726345,
           69.77665791649733,
           69.77518110664967,
           69.773704296802,
           69.77222748695434,
           69.77075067710666,
           69.76927386725899,
           69.76779705741131,
           69.76632024756364,
           69.76484343771598,
           69.76336662786831,
           69.76188981802065,
           69.76041300817296,
           69.7589361983253,
           69.75745938847763,
           69.75598257862995,
           69.75450576878228,
           69.7530289589346,
           69.75155214908695,
           69.75007533923927,
           69.7485985293916,
           69.74712171954394,
           69.74564490969627,
           69.7441680998486,
           69.74269129000092,
           69.74121448015326,
           69.73973767030559,
           69.73826086045791,
           69.73678405061025,
           69.73530724076258,
           69.7338304309149,
           69.73235362106723,
           69.73087681121956,
           69.7294000013719,
           69.72792319152423,
           69.72644638167657,
           69.7249695718289,
           69.72349276198122,
           69.72201595213355,
           69.72053914228587,
           69.7190623324382,
           69.71758552259053,
           69.71610871274287,
           69.7146319028952,
           69.71315509304753,
           69.71167828319986,
           69.3277157370508,
           68.75251032275109,
           68.17730490845138,
           67.60209949415164,
           67.02689407985194,
           66.45168866555218,
           65.8764832512525,
           65.30127783695276,
           64.72607242265303,
           64.15086700835333,
           63.57566159405357,
           63.00045617975388,
           62.425250765454145,
           61.85004535115442,
           61.27483993685472,
           60.699634522555,
           60.12442910825526,
           59.54922369395554,
           58.97401827965581,
           58.398812865356106,
           57.823607451056375,
           57.24840203675666,
           56.67319662245695,
           56.09799120815721,
           55.52278579385751,
           54.94758037955776,
           54.372374965258054,
           53.797169550958344,
           53.22196413665859,
           52.646758722358896,
           52.07155330805915,
           51.496347893759435,
           50.92114247945973,
           50.34593706516,
           49.770731650860284,
           49.195526236560546,
           48.62032082226082,
           48.04511540796112,
           47.46990999366139,
           46.894704579361665,
           46.319499165061956,
           45.74429375076224,
           45.16908833646251,
           44.59388292216278,
           44.01867750786305,
           43.44347209356333,
           42.86826667926363,
           42.293061264963896,
           41.71785585066417,
           41.14265043636445,
           40.56744502206472,
           39.992239607765015,
           39.417034193465284,
           38.84182877916556,
           38.266623364865836,
           37.69141795056613,
           37.1162125362664,
           36.54100712196668,
           35.96580170766695,
           35.39059629336722,
           34.81539087906752,
           34.24018546476779,
           33.66498005046806,
           33.08977463616834,
           32.51456922186864,
           31.93936380756891,
           31.364158393269186,
           30.786721424174136,
           30.20606108515161,
           29.62540074612911,
           29.04474040710658,
           28.46408006808405,
           27.883419729061522,
           27.302759390038993,
           26.722099051016496,
           26.141438711993967,
           25.56077837297144,
           24.980118033948912,
           24.39945769492641,
           23.818797355903882,
           23.238137016881353,
           22.657476677858824,
           22.076816338836295,
           21.688179225378903,
           21.491565337486616,
           21.29495144959428,
           21.09833756170206,
           20.90172367380971,
           20.70510978591743,
           20.50849589802516,
           20.311882010132866,
           20.11526812224052,
           19.918654234348317,
           19.722040346455966,
           19.534144241177316,
           19.350680912038765,
           19.16721758290015,
           18.983754253761585,
           18.800290924623027,
           18.616827595484473,
           18.43336426634585,
           18.249900937207297,
           18.06643760806874,
           17.882974278930178,
           17.699510949791602,
           17.523072552319828,
           17.35167658776582,
           17.180280623211804,
           17.008884658657806,
           16.837488694103754,
           16.666092729549746,
           16.494696764995737,
           16.32330080044174,
           16.151904835887677,
           15.980508871333713,
           15.814442086645197,
           15.654042247416838,
           15.49364240818848,
           15.333242568960088,
           15.172842729731745,
           15.012442890503388,
           14.852043051275043,
           14.691643212046696,
           14.531243372818293,
           14.373304867790827,
           14.22294727879431,
           14.0725896897977,
           13.922232100801132,
           13.771874511804585,
           13.621516922807974,
           13.471159333811407,
           13.320801744814846,
           13.170444155818286,
           13.027036146287506,
           12.885839364923068,
           12.744642583558669,
           12.603445802194301,
           12.462249020829857,
           12.321052239465466,
           12.179855458101022,
           12.038658676736652,
           11.905308548063969,
           11.772488257572627,
           11.63966796708124,
           11.506847676589928,
           11.37402738609855,
           11.241207095607198,
           11.108386805115888,
           10.981075868148721,
           10.856077500397678,
           10.731079132646634,
           10.606080764895578,
           10.481082397144533,
           10.356084029393491,
           10.231085661642458,
           10.11517572103779,
           9.999291236939921,
           9.883406752842063,
           9.767522268744171,
           9.651637784646304,
           9.535753300548443,
           9.427390208570648,
           9.321400888801065,
           9.215411569031456,
           9.109422249261879,
           9.0034329294923,
           8.89744360972269,
           8.798073716681206,
           8.699086766065951,
           8.600099815450665,
           8.501112864835411,
           8.402125914220159,
           8.30578017039082,
           8.211958536816493,
           8.1181369032422,
           8.024315269667872,
           7.930493636093567,
           7.839446106414286,
           7.752198937891431,
           7.664951769368589,
           7.577704600845752,
           7.4904574323229145,
           7.407686227507939,
           7.327374343641196,
           7.247062459774455,
           7.166750575907706,
           7.087384167172984,
           7.013224930938669,
           6.939065694704353,
           6.864906458470032,
           6.7907472222357,
           6.721609291740771,
           6.652895867396325,
           6.58418244305187,
           6.515469018707443,
           6.434002872760862,
           6.351555748229504,
           6.269108623698163,
           6.186661499166798,
           6.104214374635439,
           6.021767250104089,
           5.939320125572735,
           5.856873001041373,
           5.7744258765100245,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           66.67998580368962,
           66.71436792714898,
           66.74875005060835,
           66.7831321740677,
           66.81751429752708,
           66.85189642098645,
           66.88627854444582,
           66.92066066790518,
           66.95504279136455,
           66.98942491482393,
           67.02380703828328,
           67.05818916174266,
           67.09257128520203,
           67.1269534086614,
           67.16133553212076,
           67.19571765558013,
           67.23009977903949,
           67.26448190249886,
           67.29886402595822,
           67.33324614941759,
           67.36762827287697,
           67.40201039633632,
           67.4363925197957,
           67.47077464325506,
           67.50515676671444,
           67.53953889017379,
           67.57392101363317,
           67.60830313709253,
           67.6426852605519,
           67.67706738401127,
           67.71144950747063,
           67.74583163093,
           67.78021375438937,
           67.81459587784875,
           67.84897800130811,
           67.88336012476748,
           67.91774224822684,
           67.95212437168621,
           67.98650649514558,
           68.02088861860494,
           68.05527074206431,
           68.08965286552368,
           68.12403498898306,
           68.15841711244241,
           68.19279923590179,
           68.22718135936115,
           68.26156348282052,
           68.29594560627989,
           68.33032772973925,
           68.36470985319862,
           68.39909197665799,
           68.43347410011735,
           68.46785622357672,
           68.50223834703608,
           68.53662047049545,
           68.57100259395483,
           68.6053847174142,
           68.63976684087356,
           68.67414896433293,
           68.7085310877923,
           68.74291321125166,
           68.77729533471103,
           68.81167745817038,
           68.84605958162976,
           68.88044170508913,
           68.91482382854849,
           68.94920595200786,
           68.98358807546724,
           69.01875903771463,
           69.05471883779937,
           69.0906786378841,
           69.12663843796882,
           69.16259823805355,
           69.19855803813827,
           69.23451783822301,
           69.27047763830774,
           69.30643743839246,
           69.34239723847719,
           69.37835703856193,
           69.41431683864666,
           69.45027663873138,
           69.48623643881612,
           69.52219623890085,
           69.55815603898557,
           69.56727711252265,
           69.57103044075019,
           69.57478376897774,
           69.5785370972053,
           69.58229042543284,
           69.58604375366039,
           69.58979708188794,
           69.59355041011548,
           69.59730373834303,
           69.60105706657058,
           69.60481039479815,
           69.60856372302568,
           69.61231705125324,
           69.61607037948077,
           69.61982370770833,
           69.62270534783254,
           69.62122853798486,
           69.61975172813719,
           69.61827491828952,
           69.61679810844186,
           69.61532129859418,
           69.61384448874652,
           69.61236767889885,
           69.61089086905118,
           69.6094140592035,
           69.60793724935583,
           69.60646043950817,
           69.6049836296605,
           69.60350681981282,
           69.60203000996515,
           69.60055320011749,
           69.59907639026981,
           69.59759958042216,
           69.59612277057448,
           69.59464596072681,
           69.59316915087913,
           69.59169234103146,
           69.5902155311838,
           69.58873872133613,
           69.58726191148845,
           69.5857851016408,
           69.58430829179312,
           69.58283148194545,
           69.58135467209779,
           69.57987786225011,
           69.57840105240244,
           69.57692424255477,
           69.57544743270711,
           69.57397062285943,
           69.57249381301176,
           69.57101700316409,
           69.56954019331641,
           69.56806338346875,
           69.56658657362108,
           69.5651097637734,
           69.56363295392573,
           69.56215614407807,
           69.5606793342304,
           69.55920252438273,
           69.55772571453505,
           69.5562489046874,
           69.55477209483972,
           69.55329528499205,
           69.55181847514437,
           69.55034166529671,
           69.54886485544904,
           69.54738804560138,
           69.5459112357537,
           69.54443442590603,
           69.54295761605836,
           69.5414808062107,
           69.54000399636303,
           69.53852718651535,
           69.53705037666768,
           69.53557356682002,
           69.53409675697235,
           69.53261994712467,
           69.531143137277,
           69.52966632742934,
           69.52818951758167,
           69.52671270773399,
           69.52523589788632,
           69.52375908803864,
           69.1397965418896,
           68.56459112758989,
           67.98938571329016,
           67.41418029899043,
           66.83897488469074,
           66.26376947039098,
           65.68856405609128,
           65.11335864179156,
           64.53815322749182,
           63.96294781319212,
           63.38774239889237,
           62.81253698459267,
           62.237331570292945,
           61.662126155993214,
           61.08692074169351,
           60.51171532739379,
           59.936509913094056,
           59.36130449879433,
           58.78609908449461,
           58.210893670194906,
           57.63568825589517,
           57.06048284159545,
           56.48527742729575,
           55.91007201299599,
           55.334866598696294,
           54.75966118439656,
           54.18445577009683,
           53.60925035579714,
           53.03404494149739,
           52.45883952719769,
           51.88363411289795,
           51.308428698598235,
           50.73322328429853,
           50.15305885096012,
           49.57239851193759,
           48.99173817291507,
           48.41107783389254,
           47.83041749487004,
           47.24975715584752,
           46.66909681682499,
           46.08843647780248,
           45.50777613877996,
           44.92711579975743,
           44.3464554607349,
           43.76579512171237,
           43.185134782689836,
           42.60447444366734,
           42.02381410464482,
           41.44315376562229,
           40.86249342659976,
           40.28183308757723,
           39.701172748554725,
           39.120512409532196,
           38.53985207050967,
           37.95919173148715,
           37.37853139246465,
           36.797871053442115,
           36.21721071441959,
           35.636550375397064,
           35.055890036374535,
           34.475229697352034,
           33.894569358329505,
           33.313909019306976,
           32.73324868028445,
           32.152588341261946,
           31.571928002239424,
           30.991267663216895,
           30.410607324194366,
           29.829946985171837,
           29.249286646149336,
           28.668626307126807,
           28.08796596810428,
           27.507305629081753,
           26.926645290059223,
           26.345984951036726,
           25.765324612014197,
           25.184664272991668,
           24.60400393396914,
           24.02334359494664,
           23.44268325592411,
           22.86202291690158,
           22.281362577879054,
           21.70070223885653,
           21.31206512539913,
           21.11545123750684,
           20.918837349614503,
           20.722223461722287,
           20.525609573829936,
           20.32899568593766,
           20.132381798045383,
           19.935767910153093,
           19.745803177612704,
           19.56233984847416,
           19.378876519335595,
           19.195413190197026,
           19.011949861058472,
           18.82848653191986,
           18.645023202781296,
           18.461559873642738,
           18.278096544504184,
           18.094633215365562,
           17.911169886227004,
           17.731240572590572,
           17.55984460803651,
           17.388448643482494,
           17.217052678928503,
           17.045656714374495,
           16.874260749820483,
           16.70286478526648,
           16.53146882071243,
           16.36007285615842,
           16.188676891604413,
           16.018106574355464,
           15.857706735127108,
           15.697306895898706,
           15.536907056670369,
           15.376507217442013,
           15.216107378213655,
           15.055707538985263,
           14.89530769975692,
           14.734907860528562,
           14.574508021300218,
           14.42139373450182,
           14.27103614550521,
           14.120678556508649,
           13.970320967512134,
           13.819963378515522,
           13.669605789518954,
           13.519248200522407,
           13.368890611525796,
           13.219796583479775,
           13.078599802115377,
           12.937403020750939,
           12.796206239386533,
           12.655009458022098,
           12.5138126766577,
           12.37261589529333,
           12.231419113928887,
           12.092089381832965,
           11.959269091341579,
           11.826448800850256,
           11.693628510358879,
           11.560808219867537,
           11.427987929376151,
           11.29516763888484,
           11.16234734839346,
           11.036600795965436,
           10.911602428214369,
           10.786604060463336,
           10.661605692712293,
           10.536607324961249,
           10.411608957210191,
           10.28767981731689,
           10.171795333218995,
           10.055910849121133,
           9.940026365023273,
           9.824141880925403,
           9.708257396827541,
           9.592372912729651,
           9.484463237989589,
           9.378473918220012,
           9.272484598450433,
           9.16649527868085,
           9.060505958911241,
           8.954516639141664,
           8.85498262806875,
           8.755995677453512,
           8.657008726838258,
           8.558021776223004,
           8.459034825607718,
           8.362233701174882,
           8.268412067600583,
           8.174590434026275,
           8.080768800451947,
           7.9869471668776555,
           7.8949214850850895,
           7.807674316562249,
           7.720427148039411,
           7.633179979516556,
           7.545932810993714,
           7.461735200112978,
           7.381423316246234,
           7.301111432379468,
           7.220799548512725,
           7.140487664645983,
           7.065679295320659,
           6.991520059086321,
           6.917360822852006,
           6.843201586617689,
           6.772377758904824,
           6.703664334560367,
           6.634950910215925,
           6.566237485871479,
           6.48967623284881,
           6.40722910831746,
           6.324781983786098,
           6.24233485925474,
           6.159887734723397,
           6.077440610192032,
           5.9949934856606735,
           5.9125463611293245,
           5.83009923659797,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           66.60359063598578,
           66.63797275944515,
           66.67235488290453,
           66.7067370063639,
           66.74111912982326,
           66.77550125328263,
           66.80988337674198,
           66.84426550020136,
           66.87864762366073,
           66.91302974712009,
           66.94741187057946,
           66.98179399403882,
           67.01617611749819,
           67.05055824095756,
           67.08494036441692,
           67.1193224878763,
           67.15370461133566,
           67.18808673479504,
           67.2224688582544,
           67.25685098171377,
           67.29123310517313,
           67.3256152286325,
           67.35999735209187,
           67.39437947555123,
           67.4287615990106,
           67.46314372246997,
           67.49752584592935,
           67.5319079693887,
           67.56629009284808,
           67.60067221630744,
           67.63505433976681,
           67.66943646322618,
           67.70381858668554,
           67.73820071014492,
           67.77258283360428,
           67.80696495706364,
           67.84134708052301,
           67.87572920398237,
           67.91011132744175,
           67.94449345090112,
           67.97887557436047,
           68.01325769781985,
           68.04763982127922,
           68.08202194473859,
           68.11640406819797,
           68.15078619165733,
           68.1851683151167,
           68.21955043857606,
           68.25393256203543,
           68.2883146854948,
           68.32269680895416,
           68.35707893241353,
           68.3914610558729,
           68.42584317933226,
           68.46022530279163,
           68.49460742625101,
           68.52898954971036,
           68.56337167316974,
           68.59775379662909,
           68.63213592008847,
           68.66651804354784,
           68.7009001670072,
           68.73528229046657,
           68.76966441392594,
           68.8040465373853,
           68.83842866084467,
           68.87281078430404,
           68.9071929077634,
           68.94157503122278,
           68.97595715468215,
           69.01033927814152,
           69.04472140160087,
           69.07910352506025,
           69.11348564851961,
           69.14786777197898,
           69.18224989543835,
           69.21663201889771,
           69.25101414235708,
           69.28539626581644,
           69.31977838927581,
           69.35416051273519,
           69.38854263619456,
           69.42292475965392,
           69.45627940767554,
           69.45361122280383,
           69.45213441295614,
           69.45065760310848,
           69.44918079326081,
           69.44770398341315,
           69.44622717356548,
           69.4447503637178,
           69.44327355387013,
           69.44179674402245,
           69.4403199341748,
           69.43884312432712,
           69.43736631447945,
           69.43588950463177,
           69.4344126947841,
           69.43293588493644,
           69.43145907508877,
           69.4299822652411,
           69.42850545539342,
           69.42702864554576,
           69.42555183569809,
           69.42407502585041,
           69.42259821600274,
           69.42112140615508,
           69.4196445963074,
           69.41816778645973,
           69.41669097661206,
           69.4152141667644,
           69.41373735691673,
           69.41226054706905,
           69.41078373722138,
           69.40930692737372,
           69.40783011752605,
           69.40635330767839,
           69.40487649783071,
           69.40339968798304,
           69.40192287813537,
           69.40044606828769,
           69.39896925844002,
           69.39749244859236,
           69.3960156387447,
           69.39453882889703,
           69.39306201904935,
           69.39158520920168,
           69.390108399354,
           69.38863158950635,
           69.38715477965866,
           69.385677969811,
           69.38420115996333,
           69.38272435011565,
           69.38124754026799,
           69.37977073042032,
           69.37829392057266,
           69.37681711072499,
           69.37534030087731,
           69.37386349102964,
           69.37238668118198,
           69.3709098713343,
           69.36943306148663,
           69.36795625163896,
           69.3664794417913,
           69.36500263194363,
           69.36352582209595,
           69.36204901224828,
           69.36057220240062,
           69.35909539255294,
           69.35761858270527,
           69.3561417728576,
           69.35466496300994,
           69.35318815316226,
           69.35171134331459,
           69.35023453346693,
           69.34875772361926,
           69.34728091377158,
           69.34580410392391,
           69.34432729407624,
           69.34285048422858,
           69.3413736743809,
           69.33989686453323,
           69.33842005468556,
           69.3369432448379,
           69.33546643499022,
           69.33398962514256,
           69.33251281529489,
           68.94308719770257,
           68.35968717623798,
           67.77741526067857,
           67.19675492165604,
           66.61609458263354,
           66.03543424361098,
           65.45477390458846,
           64.87411356556595,
           64.29345322654342,
           63.71279288752091,
           63.132132548498355,
           62.55147220947586,
           61.97081187045334,
           61.3901515314308,
           60.8094911924083,
           60.22883085338578,
           59.64817051436325,
           59.06751017534072,
           58.48684983631819,
           57.90618949729569,
           57.32552915827316,
           56.74486881925064,
           56.16420848022814,
           55.58354814120558,
           55.00288780218308,
           54.42222746316055,
           53.841567124138024,
           53.26090678511552,
           52.68024644609297,
           52.099586107070465,
           51.518925768047936,
           50.93826542902542,
           50.357605090002906,
           49.776944750980384,
           49.196284411957855,
           48.615624072935326,
           48.0349637339128,
           47.454303394890296,
           46.873643055867774,
           46.292982716845245,
           45.712322377822744,
           45.13166203880022,
           44.551001699777686,
           43.970341360755164,
           43.38968102173263,
           42.8090206827101,
           42.2283603436876,
           41.647700004665076,
           41.06703966564254,
           40.48637932662002,
           39.905718987597496,
           39.32505864857499,
           38.74439830955246,
           38.16373797052993,
           37.5830776315074,
           37.00241729248491,
           36.42175695346237,
           35.84109661443985,
           35.26043627541732,
           34.6797759363948,
           34.09911559737229,
           33.51845525834976,
           32.93779491932724,
           32.35713458030471,
           31.7764742412822,
           31.195813902259676,
           30.61515356323715,
           30.034493224214625,
           29.4538328851921,
           28.87317254616959,
           28.292512207147066,
           27.711851868124537,
           27.13119152910201,
           26.550531190079482,
           25.96987085105698,
           25.389210512034452,
           24.808550173011923,
           24.2278898339894,
           23.647229494966897,
           23.066569155944368,
           22.485908816921842,
           21.905248477899313,
           21.324588138876784,
           20.935951025419385,
           20.739337137527095,
           20.542723249634758,
           20.34610936174254,
           20.149495473850195,
           19.957462114048184,
           19.773998784909626,
           19.59053545577106,
           19.407072126632436,
           19.223608797493895,
           19.04014546835533,
           18.856682139216762,
           18.673218810078207,
           18.489755480939593,
           18.30629215180103,
           18.122828822662473,
           17.939408592861284,
           17.768012628307268,
           17.59661666375327,
           17.425220699199272,
           17.25382473464521,
           17.082428770091195,
           16.911032805537204,
           16.739636840983195,
           16.56824087642918,
           16.39684491187518,
           16.225448947321127,
           16.06137122283735,
           15.900971383609003,
           15.740571544380659,
           15.580171705152305,
           15.419771865923902,
           15.259372026695566,
           15.098972187467208,
           14.93857234823885,
           14.77817250901046,
           14.619840190209388,
           14.469482601212775,
           14.319125012216178,
           14.16876742321966,
           14.01840983422305,
           13.868052245226488,
           13.717694656229973,
           13.567337067233364,
           13.416979478236795,
           13.271360239307601,
           13.130163457943231,
           12.988966676578823,
           12.847769895214425,
           12.706573113849988,
           12.565376332485583,
           12.424179551121144,
           12.282982769756746,
           12.146049925110614,
           12.013229634619227,
           11.880409344127893,
           11.747589053636505,
           11.614768763145184,
           11.481948472653807,
           11.349128182162465,
           11.217124091533178,
           11.092125723782145,
           10.96712735603111,
           10.842128988280066,
           10.717130620529,
           10.592132252777965,
           10.467133885026923,
           10.34429942949808,
           10.228414945400253,
           10.112530461302384,
           9.996645977204489,
           9.880761493106625,
           9.764877009008766,
           9.648992524910897,
           9.541536267408546,
           9.435546947638969,
           9.329557627869386,
           9.223568308099807,
           9.117578988330232,
           9.011589668560648,
           8.911891539456347,
           8.812904588841093,
           8.713917638225816,
           8.614930687610576,
           8.515943736995322,
           8.418687231958952,
           8.324865598384646,
           8.231043964810347,
           8.137222331236046,
           8.04340069766174,
           7.950396863755898,
           7.863149695233086,
           7.775902526710224,
           7.688655358187381,
           7.601408189664545,
           7.515784172718005,
           7.435472288851257,
           7.355160404984515,
           7.274848521117772,
           7.194536637251005,
           7.11813365970264,
           7.043974423468324,
           6.969815187234003,
           6.895655950999664,
           6.823146226068872,
           6.754432801724416,
           6.685719377379984,
           6.617005953035527,
           6.545349592936764,
           6.462902468405399,
           6.380455343874049,
           6.298008219342699,
           6.215561094811337,
           6.133113970279979,
           6.050666845748637,
           5.968219721217272,
           5.885772596685914,
           5.8033254721545635,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           66.51206304047668,
           66.54644516393604,
           66.58082728739541,
           66.61520941085477,
           66.64959153431414,
           66.68397365777352,
           66.71835578123287,
           66.75273790469224,
           66.78712002815162,
           66.82150215161099,
           66.85588427507035,
           66.89026639852972,
           66.92464852198908,
           66.95903064544845,
           66.99341276890782,
           67.02779489236718,
           67.06217701582655,
           67.09655913928592,
           67.1309412627453,
           67.16532338620466,
           67.19970550966403,
           67.23408763312338,
           67.26846975658276,
           67.30285188004214,
           67.3372340035015,
           67.37161612696086,
           67.40599825042023,
           67.44038037387959,
           67.47476249733896,
           67.50914462079832,
           67.54352674425769,
           67.57790886771707,
           67.61229099117642,
           67.6466731146358,
           67.68105523809517,
           67.71543736155454,
           67.7498194850139,
           67.78420160847327,
           67.81858373193263,
           67.852965855392,
           67.88734797885137,
           67.92173010231073,
           67.9561122257701,
           67.99049434922946,
           68.02487647268885,
           68.05925859614821,
           68.09364071960758,
           68.12802284306694,
           68.16240496652631,
           68.19678708998568,
           68.23116921344504,
           68.26555133690441,
           68.29993346036377,
           68.33431558382314,
           68.36869770728251,
           68.40307983074189,
           68.43746195420125,
           68.47184407766062,
           68.50622620111997,
           68.54060832457935,
           68.57499044803872,
           68.60937257149808,
           68.64375469495745,
           68.67813681841682,
           68.7125189418762,
           68.74690106533555,
           68.78102631983874,
           68.81386722982636,
           68.84670813981396,
           68.87954904980157,
           68.91238995978918,
           68.9452308697768,
           68.97807177976439,
           69.010912689752,
           69.04375359973962,
           69.07659450972723,
           69.10943541971484,
           69.14227632970245,
           69.17511723969005,
           69.20795814967767,
           69.24079905966528,
           69.27363996965289,
           69.30648087964049,
           69.3393217896281,
           69.336653603626,
           69.32688359842595,
           69.3171135932259,
           69.30734358802586,
           69.2975735828258,
           69.28780357762577,
           69.27803357242571,
           69.26826356722566,
           69.25849356202562,
           69.24872355682557,
           69.23895355162551,
           69.22918354642546,
           69.21941354122542,
           69.20964353602538,
           69.19987353082533,
           69.19010352562528,
           69.18033352042522,
           69.1747101126634,
           69.17323330281573,
           69.17175649296806,
           69.1702796831204,
           69.16880287327271,
           69.16732606342505,
           69.16584925357738,
           69.1643724437297,
           69.16289563388203,
           69.16141882403436,
           69.1599420141867,
           69.15846520433902,
           69.15698839449135,
           69.15551158464369,
           69.15403477479602,
           69.15255796494834,
           69.15108115510067,
           69.14960434525301,
           69.14812753540534,
           69.14665072555766,
           69.14517391570999,
           69.14369710586233,
           69.14222029601466,
           69.140743486167,
           69.13926667631932,
           69.13778986647165,
           69.13631305662398,
           69.1348362467763,
           69.13335943692864,
           69.13188262708097,
           69.1304058172333,
           69.12892900738562,
           69.12745219753796,
           69.12597538769029,
           69.12449857784262,
           69.12302176799494,
           69.12154495814727,
           69.12006814829961,
           69.11859133845194,
           69.11711452860428,
           69.1156377187566,
           69.11416090890893,
           69.11268409906125,
           69.11120728921358,
           69.10973047936591,
           69.10825366951825,
           69.10677685967057,
           69.10530004982292,
           69.10382323997524,
           69.10234643012757,
           69.1008696202799,
           69.09939281043222,
           69.09791600058456,
           69.09643919073689,
           69.09496238088921,
           69.09348557104155,
           69.09200876119388,
           69.09053195134621,
           69.08905514149853,
           69.08757833165086,
           69.08610152180319,
           69.08462471195553,
           69.08314790210787,
           69.0816710922602,
           69.08019428241252,
           69.07871747256485,
           68.68929185497252,
           68.10589183350794,
           67.52249181204333,
           66.9390917905787,
           66.35569176911412,
           65.77229174764946,
           65.18889172618486,
           64.60549170472025,
           64.02209168325564,
           63.43869166179104,
           62.8552916403264,
           62.27189161886181,
           61.68849159739719,
           61.10509157593257,
           60.52169155446798,
           59.93829153300336,
           59.35489151153874,
           58.77149149007412,
           58.18809146860951,
           57.604691447144916,
           57.02129142568029,
           56.43789140421568,
           55.854491382751085,
           55.27109136128644,
           54.687691339821846,
           54.10429131835723,
           53.52089129689261,
           52.93749127542802,
           52.354091253963375,
           51.77069123249878,
           51.187291211034164,
           50.603891189569545,
           50.02049116810495,
           49.437091146640334,
           48.853691125175715,
           48.27029110371109,
           47.68689108224648,
           47.103491060781884,
           46.520091039317265,
           45.93669101785265,
           45.353290996388054,
           44.76989097492344,
           44.18649095345882,
           43.603090931994196,
           43.019690910529576,
           42.43629088906496,
           41.852890867600365,
           41.2715859046853,
           40.690925565662766,
           40.110265226640244,
           39.52960488761772,
           38.948944548595215,
           38.368284209572685,
           37.787623870550156,
           37.206963531527634,
           36.626303192505134,
           36.045642853482605,
           35.464982514460075,
           34.884322175437546,
           34.30366183641502,
           33.723001497392524,
           33.14234115836999,
           32.561680819347465,
           31.981020480324936,
           31.400360141302432,
           30.819699802279906,
           30.23903946325738,
           29.65837912423485,
           29.077718785212323,
           28.497058446189822,
           27.916398107167296,
           27.335737768144767,
           26.755077429122238,
           26.17441709009971,
           25.59375675107721,
           25.01309641205468,
           24.43243607303215,
           23.851775734009625,
           23.271115394987124,
           22.690455055964595,
           22.10979471694207,
           21.52913437791954,
           20.94847403889701,
           20.55983692543962,
           20.363223037547325,
           20.169121050483625,
           19.985657721345067,
           19.802194392206445,
           19.61873106306789,
           19.435267733929336,
           19.251804404790768,
           19.068341075652146,
           18.884877746513602,
           18.701414417375037,
           18.517951088236472,
           18.334487759097918,
           18.151024429959307,
           17.976180648578016,
           17.804784684023964,
           17.633388719469966,
           17.461992754915947,
           17.29059679036195,
           17.11920082580795,
           16.94780486125389,
           16.776408896699873,
           16.605012932145886,
           16.433616967591878,
           16.265035710547625,
           16.104635871319232,
           15.94423603209093,
           15.783836192862532,
           15.623436353634181,
           15.463036514405838,
           15.30263667517748,
           15.14223683594908,
           14.981836996720745,
           14.821437157492387,
           14.667929056920286,
           14.517571467923768,
           14.36721387892721,
           14.2168562899306,
           14.066498700933998,
           13.916141111937481,
           13.765783522940872,
           13.615425933944312,
           13.465068344947795,
           13.32292389513547,
           13.18172711377106,
           13.040530332406634,
           12.899333551042263,
           12.758136769677856,
           12.616939988313456,
           12.475743206949021,
           12.334546425584614,
           12.200010468388188,
           12.067190177896876,
           11.934369887405525,
           11.801549596914137,
           11.668729306422804,
           11.535909015931416,
           11.403088725440094,
           11.27264901934987,
           11.147650651598834,
           11.022652283847792,
           10.89765391609676,
           10.772655548345725,
           10.64765718059468,
           10.522658812843614,
           10.400919041679327,
           10.285034557581428,
           10.169150073483559,
           10.053265589385733,
           9.937381105287866,
           9.82149662118997,
           9.705612137092107,
           9.598609296827522,
           9.492619977057938,
           9.386630657288334,
           9.280641337518759,
           9.174652017749175,
           9.068662697979597,
           8.968800450843949,
           8.869813500228663,
           8.770826549613403,
           8.67183959899815,
           8.57285264838287,
           8.475140762743006,
           8.381319129168707,
           8.287497495594407,
           8.1936758620201,
           8.099854228445801,
           8.006032594871503,
           7.918625073903866,
           7.831377905381023,
           7.744130736858213,
           7.656883568335351,
           7.569833145323022,
           7.489521261456279,
           7.409209377589536,
           7.3288974937227875,
           7.248585609856045,
           7.170588024084597,
           7.096428787850277,
           7.0222695516159765,
           6.94811031538166,
           6.873951079147339,
           6.805201268888468,
           6.736487844544026,
           6.667774420199571,
           6.5990609958551385,
           6.518575828493346,
           6.436128703961995,
           6.3536815794306305,
           6.271234454899281,
           6.18878733036793,
           6.106340205836569,
           6.023893081305211,
           5.941445956773869,
           5.858998832242503,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           66.42053544496756,
           66.45491756842692,
           66.48929969188629,
           66.52368181534565,
           66.55806393880502,
           66.5924460622644,
           66.62682818572375,
           66.66121030918313,
           66.69559243264248,
           66.72997455610187,
           66.76435667956123,
           66.7987388030206,
           66.83312092647996,
           66.86750304993933,
           66.90188517339871,
           66.93626729685806,
           66.97064942031743,
           67.0050315437768,
           67.03941366723618,
           67.07379579069554,
           67.10817791415491,
           67.14256003761427,
           67.17694216107364,
           67.21132428453302,
           67.24570640799237,
           67.28008853145174,
           67.31447065491112,
           67.34885277837047,
           67.38323490182985,
           67.41761702528922,
           67.45199914874858,
           67.48638127220795,
           67.52076339566732,
           67.55514551912668,
           67.58952764258605,
           67.62390976604541,
           67.6582918895048,
           67.69267401296415,
           67.72705613642353,
           67.76143825988288,
           67.79582038334226,
           67.83020250680163,
           67.86458463026099,
           67.89896675372036,
           67.93334887717972,
           67.96773100063909,
           68.00211312409846,
           68.03649524755784,
           68.07087737101719,
           68.10525949447657,
           68.13861414198956,
           68.17145505197718,
           68.20429596196477,
           68.23713687195239,
           68.26997778194001,
           68.30281869192761,
           68.33565960191522,
           68.36850051190282,
           68.40134142189044,
           68.43418233187806,
           68.46702324186566,
           68.49986415185327,
           68.53270506184089,
           68.56554597182848,
           68.59838688181611,
           68.63122779180371,
           68.66406870179132,
           68.69690961177893,
           68.72975052176653,
           68.76259143175416,
           68.79543234174176,
           68.82827325172937,
           68.86111416171698,
           68.8939550717046,
           68.9267959816922,
           68.9596368916798,
           68.99247780166742,
           69.02531871165503,
           69.05815962164264,
           69.09100053163024,
           69.12384144161786,
           69.15668235160547,
           69.18952326159308,
           69.2223641715807,
           69.21969598557858,
           69.20992598037853,
           69.20015597517849,
           69.19038596997844,
           69.18061596477838,
           69.17084595957834,
           69.16107595437829,
           69.15130594917824,
           69.1415359439782,
           69.13176593877816,
           69.1219959335781,
           69.11222592837805,
           69.102455923178,
           69.09268591797795,
           69.0829159127779,
           69.07314590757787,
           69.06337590237781,
           69.05360589717776,
           69.04383589197772,
           69.03406588677767,
           69.02429588157761,
           69.01452587637758,
           69.00475587117752,
           68.99498586597747,
           68.98521586077743,
           68.97544585557738,
           68.96567585037734,
           68.95590584517728,
           68.94613583997723,
           68.93636583477718,
           68.92659582957714,
           68.9168258243771,
           68.90705581917705,
           68.89728581397699,
           68.89580900252297,
           68.8943321926753,
           68.89285538282763,
           68.89137857297996,
           68.8899017631323,
           68.88842495328461,
           68.88694814343695,
           68.88547133358928,
           68.8839945237416,
           68.88251771389393,
           68.88104090404627,
           68.8795640941986,
           68.87808728435093,
           68.87661047450325,
           68.87513366465558,
           68.87365685480792,
           68.87218004496025,
           68.87070323511259,
           68.86922642526491,
           68.86774961541724,
           68.86627280556957,
           68.8647959957219,
           68.86331918587423,
           68.86184237602656,
           68.8603655661789,
           68.85888875633123,
           68.85741194648355,
           68.85593513663588,
           68.85445832678822,
           68.85298151694053,
           68.85150470709287,
           68.85002789724521,
           68.84855108739754,
           68.84707427754986,
           68.84559746770219,
           68.84412065785452,
           68.84264384800684,
           68.84116703815918,
           68.83969022831151,
           68.83821341846385,
           68.83673660861618,
           68.8352597987685,
           68.83378298892083,
           68.83230617907316,
           68.83082936922548,
           68.82935255937781,
           68.82787574953015,
           68.82639893968249,
           68.82492212983482,
           68.43549651224248,
           67.8520964907779,
           67.26869646931328,
           66.68529644784866,
           66.10189642638407,
           65.51849640491942,
           64.93509638345482,
           64.35169636199022,
           63.768296340525595,
           63.184896319061,
           62.601496297596356,
           62.018096276131764,
           61.43469625466715,
           60.851296233202525,
           60.26789621173795,
           59.68449619027332,
           59.101096168808695,
           58.51769614734408,
           57.93429612587946,
           57.35089610441487,
           56.76749608295026,
           56.18409606148563,
           55.60069604002104,
           55.0172960185564,
           54.4338959970918,
           53.85049597562719,
           53.26709595416257,
           52.68369593269798,
           52.10029591123333,
           51.51689588976874,
           50.933495868304114,
           50.35009584683951,
           49.76669582537491,
           49.18329580391028,
           48.59989578244568,
           48.01649576098105,
           47.43309573951644,
           46.84969571805185,
           46.26629569658723,
           45.68289567512261,
           45.09949565365802,
           44.5160956321934,
           43.93269561072878,
           43.34929558926416,
           42.76589556779954,
           42.18249554633492,
           41.599095524870336,
           41.015695503405716,
           40.4322954819411,
           39.84889546047648,
           39.26549543901186,
           38.682095417547266,
           38.09869539608265,
           37.51529537461803,
           36.93189535315341,
           36.34849533168882,
           35.7650953102242,
           35.18169528875958,
           34.59829526729496,
           34.01489524583034,
           33.43149522436575,
           32.848095202901135,
           32.264695181436515,
           31.681295159971896,
           31.097895138507305,
           30.51449511704268,
           29.931095095578065,
           29.347695074113446,
           28.764295052648826,
           28.180895031184235,
           27.597495009719616,
           27.014094988254996,
           26.430694966790384,
           25.847294945325764,
           25.26389492386117,
           24.680494902396553,
           24.097094880931934,
           23.513694859467314,
           22.928951988686787,
           22.342306729500773,
           21.755661470314763,
           21.169016211128742,
           20.58237095194273,
           20.19731665778045,
           20.01385332864189,
           19.830389999503335,
           19.646926670364778,
           19.463463341226156,
           19.280000012087598,
           19.096536682949047,
           18.91307335381048,
           18.729610024671857,
           18.546146695533313,
           18.362683366394748,
           18.184348668848706,
           18.012952704294708,
           17.841556739740657,
           17.670160775186694,
           17.49876481063264,
           17.32736884607864,
           17.155972881524626,
           16.984576916970628,
           16.813180952416626,
           16.641784987862568,
           16.47038902330855,
           16.30830035902951,
           16.14790051980111,
           15.987500680572797,
           15.827100841344407,
           15.666701002116104,
           15.506301162887706,
           15.345901323659357,
           15.185501484431011,
           15.025101645202655,
           14.866375512627833,
           14.716017923631286,
           14.565660334634718,
           14.415302745638108,
           14.26494515664159,
           14.114587567645032,
           13.964229978648419,
           13.813872389651822,
           13.663514800655305,
           13.515684332327739,
           13.37448755096334,
           13.233290769598904,
           13.092093988234497,
           12.95089720687009,
           12.809700425505664,
           12.668503644141294,
           12.527306862776886,
           12.38679130215717,
           12.253971011665824,
           12.121150721174473,
           11.988330430683096,
           11.855510140191782,
           11.722689849700433,
           11.589869559209045,
           11.457049268717713,
           11.328173947166594,
           11.20317557941555,
           11.078177211664483,
           10.953178843913449,
           10.828180476162405,
           10.703182108411372,
           10.578183740660336,
           10.457538653860528,
           10.341654169762666,
           10.225769685664805,
           10.109885201566907,
           9.994000717469039,
           9.878116233371212,
           9.762231749273344,
           9.655682326246463,
           9.549693006476886,
           9.443703686707309,
           9.337714366937725,
           9.231725047168121,
           9.125735727398544,
           9.02570936223151,
           8.926722411616256,
           8.827735461001001,
           8.728748510385715,
           8.629761559770454,
           8.531594293527068,
           8.437772659952767,
           8.34395102637846,
           8.250129392804162,
           8.156307759229861,
           8.062486125655557,
           7.974100452574691,
           7.8868532840518535,
           7.799606115528991,
           7.712358947006148,
           7.625111778483338,
           7.543570234061317,
           7.46325835019455,
           7.382946466327807,
           7.302634582461065,
           7.223042388466581,
           7.148883152232265,
           7.074723915997933,
           7.000564679763613,
           6.926405443529313,
           6.855969736052514,
           6.7872563117080675,
           6.718542887363622,
           6.649829463019181,
           6.574249188581293,
           6.491802064049927,
           6.409354939518577,
           6.326907814987226,
           6.2444606904558615,
           6.162013565924512,
           6.079566441393162,
           5.9971193168618,
           5.914672192330443,
           5.8322250677991,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           66.32900784945845,
           66.36338997291782,
           66.39777209637717,
           66.43215421983655,
           66.46653634329591,
           66.50091846675528,
           66.53530059021465,
           66.56968271367401,
           66.6040648371334,
           66.63844696059274,
           66.67282908405213,
           66.70721120751149,
           66.74159333097086,
           66.77597545443022,
           66.81035757788959,
           66.84473970134896,
           66.87912182480832,
           66.91350394826769,
           66.94788607172707,
           66.98226819518642,
           67.01665031864579,
           67.05103244210517,
           67.08541456556452,
           67.1197966890239,
           67.15417881248325,
           67.18856093594263,
           67.222943059402,
           67.25732518286136,
           67.29170730632075,
           67.32608942978011,
           67.36047155323946,
           67.39485367669883,
           67.42923580015821,
           67.46336105415278,
           67.4962019641404,
           67.52904287412801,
           67.56188378411561,
           67.59472469410323,
           67.62756560409083,
           67.66040651407845,
           67.69324742406606,
           67.72608833405367,
           67.75892924404128,
           67.7917701540289,
           67.8246110640165,
           67.8574519740041,
           67.89029288399172,
           67.92313379397933,
           67.95597470396693,
           67.98881561395456,
           68.02165652394216,
           68.05449743392978,
           68.08733834391738,
           68.12017925390498,
           68.1530201638926,
           68.1858610738802,
           68.21870198386782,
           68.25154289385543,
           68.28438380384303,
           68.31722471383065,
           68.35006562381825,
           68.38290653380588,
           68.41574744379348,
           68.44858835378108,
           68.48142926376869,
           68.5142701737563,
           68.54711108374391,
           68.57995199373153,
           68.61279290371914,
           68.64563381370675,
           68.67847472369436,
           68.71131563368196,
           68.74415654366958,
           68.77699745365719,
           68.80983836364479,
           68.8426792736324,
           68.87552018362001,
           68.90836109360762,
           68.94120200359524,
           68.97404291358285,
           69.00688382357046,
           69.03972473355806,
           69.07256564354567,
           69.10540655353329,
           69.10273836753117,
           69.09296836233112,
           69.08319835713108,
           69.07342835193103,
           69.06365834673099,
           69.05388834153094,
           69.04411833633088,
           69.03434833113084,
           69.0245783259308,
           69.01480832073074,
           69.0050383155307,
           68.99526831033064,
           68.98549830513059,
           68.97572829993055,
           68.96595829473051,
           68.95618828953044,
           68.9464182843304,
           68.93664827913037,
           68.92687827393031,
           68.91710826873026,
           68.90733826353022,
           68.89756825833015,
           68.88779825313011,
           68.87802824793008,
           68.86825824273002,
           68.85848823752997,
           68.84871823232993,
           68.83894822712986,
           68.82917822192982,
           68.81940821672978,
           68.80963821152973,
           68.79986820632968,
           68.79009820112964,
           68.78032819592958,
           68.77055819072955,
           68.76078818552949,
           68.75101818032944,
           68.74124817512939,
           68.73147816992935,
           68.7217081647293,
           68.71193815952925,
           68.7021681543292,
           68.69239814912916,
           68.68262814392911,
           68.67285813872905,
           68.663088133529,
           68.65331812832896,
           68.64354812312891,
           68.63377811792886,
           68.6240081127288,
           68.61838470223023,
           68.61690789238257,
           68.6154310825349,
           68.61395427268721,
           68.61247746283955,
           68.61100065299189,
           68.60952384314422,
           68.60804703329654,
           68.60657022344887,
           68.6050934136012,
           68.60361660375354,
           68.60213979390586,
           68.60066298405819,
           68.59918617421052,
           68.59770936436284,
           68.59623255451518,
           68.59475574466751,
           68.59327893481984,
           68.59180212497218,
           68.5903253151245,
           68.58884850527683,
           68.58737169542916,
           68.5858948855815,
           68.58441807573382,
           68.58294126588615,
           68.58146445603847,
           68.57998764619082,
           68.57851083634314,
           68.57703402649547,
           68.57555721664781,
           68.57408040680014,
           68.57260359695246,
           68.57112678710479,
           68.18170116951246,
           67.59830114804788,
           67.01490112658327,
           66.43150110511864,
           65.84810108365406,
           65.2647010621894,
           64.6813010407248,
           64.0979010192602,
           63.51450099779558,
           62.93110097633098,
           62.34770095486634,
           61.76430093340175,
           61.18090091193713,
           60.59750089047251,
           60.01410086900792,
           59.43070084754331,
           58.84730082607868,
           58.26390080461407,
           57.68050078314945,
           57.09710076168486,
           56.51370074022024,
           55.93030071875562,
           55.34690069729103,
           54.763500675826386,
           54.18010065436179,
           53.59670063289717,
           53.013300611432555,
           52.42990058996796,
           51.84650056850331,
           51.263100547038725,
           50.6797005255741,
           50.096300504109486,
           49.512900482644895,
           48.92950046118027,
           48.346100439715656,
           47.762700418251036,
           47.17930039678642,
           46.595900375321825,
           46.012500353857206,
           45.42910033239259,
           44.845700310927995,
           44.26230028946338,
           43.67890026799876,
           43.095500246534144,
           42.512100225069524,
           41.928700203604905,
           41.34530018214031,
           40.761900160675694,
           40.178500139211074,
           39.59510011774646,
           39.01170009628184,
           38.428300074817244,
           37.842997676542744,
           37.25635241735672,
           36.66970715817071,
           36.083061898984724,
           35.49641663979871,
           34.909771380612696,
           34.32312612142668,
           33.73648086224067,
           33.14983560305468,
           32.56319034386866,
           31.976545084682648,
           31.389899825496634,
           30.803254566310645,
           30.216609307124635,
           29.62996404793862,
           29.0433187887526,
           28.456673529566586,
           27.8700282703806,
           27.283383011194587,
           26.69673775200857,
           26.11009249282256,
           25.523447233636542,
           24.936801974450553,
           24.35015671526454,
           23.763511456078525,
           23.17686619689251,
           22.59022093770652,
           22.00357567852051,
           21.416930419334495,
           20.830285160148478,
           20.243639900962464,
           19.858585606800183,
           19.675122277661618,
           19.491658948523064,
           19.308195619384506,
           19.124732290245884,
           18.94126896110733,
           18.757805631968775,
           18.57434230283021,
           18.392516689119425,
           18.221120724565434,
           18.04972476001143,
           17.87832879545741,
           17.706932830903412,
           17.53553686634936,
           17.364140901795395,
           17.192744937241347,
           17.021348972687345,
           16.84995300813333,
           16.67855704357933,
           16.511964846739758,
           16.3515650075114,
           16.191165168283046,
           16.03076532905471,
           15.870365489826307,
           15.709965650597997,
           15.549565811369607,
           15.389165972141305,
           15.228766132912904,
           15.068366293684557,
           14.914464379338849,
           14.76410679034228,
           14.613749201345671,
           14.46339161234912,
           14.313034023352555,
           14.162676434355946,
           14.012318845359427,
           13.86196125636287,
           13.711603667366258,
           13.567247988155595,
           13.426051206791197,
           13.28485442542679,
           13.14365764406239,
           13.002460862697953,
           12.861264081333548,
           12.720067299969141,
           12.578870518604715,
           12.440751845434828,
           12.30793155494344,
           12.175111264452097,
           12.042290973960752,
           11.9094706834694,
           11.776650392978022,
           11.64383010248671,
           11.511009811995361,
           11.383698874983292,
           11.258700507232266,
           11.133702139481223,
           11.00870377173018,
           10.883705403979114,
           10.75870703622808,
           10.633708668477038,
           10.514158266041777,
           10.398273781943887,
           10.28238929784602,
           10.16650481374816,
           10.050620329650299,
           9.934735845552401,
           9.818851361454533,
           9.712755355665433,
           9.606766035895847,
           9.500776716126262,
           9.394787396356687,
           9.28879807658711,
           9.182808756817526,
           9.082618273619115,
           8.983631323003861,
           8.884644372388575,
           8.78565742177332,
           8.686670471158067,
           8.588047824311179,
           8.49422619073685,
           8.400404557162531,
           8.30658292358823,
           8.212761290013924,
           8.118939656439625,
           8.029575831245523,
           7.942328662722661,
           7.855081494199826,
           7.767834325676989,
           7.680587157154126,
           7.597619206666341,
           7.517307322799605,
           7.436995438932856,
           7.356683555066089,
           7.276371671199347,
           7.201337516614245,
           7.127178280379924,
           7.053019044145608,
           6.978859807911276,
           6.906738203216573,
           6.838024778872118,
           6.769311354527676,
           6.700597930183229,
           6.629922548669233,
           6.5474754241378825,
           6.465028299606532,
           6.382581175075167,
           6.300134050543818,
           6.217686926012467,
           6.135239801481101,
           6.0527926769497515,
           5.970345552418402,
           5.887898427887039,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           66.23748025394933,
           66.2718623774087,
           66.30624450086806,
           66.34062662432743,
           66.37500874778681,
           66.40939087124617,
           66.44377299470554,
           66.4781551181649,
           66.51253724162427,
           66.54691936508364,
           66.581301488543,
           66.61568361200237,
           66.65006573546174,
           66.6844478589211,
           66.71882998238048,
           66.75321210583985,
           66.78759422929922,
           66.8209488763036,
           66.85378978629123,
           66.88663069627884,
           66.91947160626644,
           66.95231251625405,
           66.98515342624167,
           67.01799433622928,
           67.05083524621688,
           67.08367615620449,
           67.1165170661921,
           67.14935797617972,
           67.18219888616733,
           67.21503979615494,
           67.24788070614254,
           67.28072161613015,
           67.31356252611776,
           67.34640343610536,
           67.37924434609299,
           67.41208525608059,
           67.4449261660682,
           67.47776707605581,
           67.51060798604342,
           67.54344889603104,
           67.57628980601865,
           67.60913071600626,
           67.64197162599386,
           67.67481253598147,
           67.70765344596909,
           67.74049435595668,
           67.77333526594431,
           67.80617617593191,
           67.83901708591952,
           67.87185799590713,
           67.90469890589473,
           67.93753981588236,
           67.97038072586996,
           68.00322163585757,
           68.03606254584518,
           68.06890345583278,
           68.1017443658204,
           68.134585275808,
           68.16742618579562,
           68.20026709578323,
           68.23310800577084,
           68.26594891575846,
           68.29878982574606,
           68.33163073573365,
           68.36447164572128,
           68.3973125557089,
           68.4301534656965,
           68.4629943756841,
           68.49583528567172,
           68.52867619565933,
           68.56151710564694,
           68.59435801563455,
           68.62719892562217,
           68.66003983560977,
           68.69288074559738,
           68.72572165558499,
           68.7585625655726,
           68.7914034755602,
           68.82424438554781,
           68.85708529553543,
           68.88992620552304,
           68.92276711551065,
           68.95560802549826,
           68.98844893548586,
           68.98578074948375,
           68.97601074428371,
           68.96624073908366,
           68.95647073388362,
           68.94670072868357,
           68.93693072348353,
           68.92716071828346,
           68.91739071308342,
           68.90762070788337,
           68.89785070268333,
           68.88808069748329,
           68.87831069228324,
           68.86854068708318,
           68.85877068188313,
           68.84900067668309,
           68.83923067148304,
           68.829460666283,
           68.81969066108294,
           68.80992065588289,
           68.80015065068285,
           68.7903806454828,
           68.78061064028275,
           68.7708406350827,
           68.76107062988265,
           68.7513006246826,
           68.74153061948255,
           68.7317606142825,
           68.72199060908247,
           68.7122206038824,
           68.70245059868236,
           68.69268059348232,
           68.68291058828227,
           68.67314058308222,
           68.66337057788218,
           68.65360057268212,
           68.64383056748207,
           68.63406056228203,
           68.62429055708199,
           68.61452055188192,
           68.60475054668188,
           68.59498054148183,
           68.58521053628178,
           68.57544053108174,
           68.56567052588169,
           68.55590052068163,
           68.5461305154816,
           68.53636051028154,
           68.5265905050815,
           68.51682049988145,
           68.5070504946814,
           68.49728048948135,
           68.4875104842813,
           68.47774047908126,
           68.46797047388121,
           68.45820046868116,
           68.4484304634811,
           68.43866045828106,
           68.42889045308101,
           68.41912044788097,
           68.40935044268092,
           68.39958043748086,
           68.38981043228081,
           68.38004042708077,
           68.37027042188072,
           68.36050041668067,
           68.35073041148061,
           68.34096040628057,
           68.3394835920898,
           68.33800678224213,
           68.33652997239447,
           68.33505316254679,
           68.33357635269913,
           68.33209954285145,
           68.33062273300379,
           68.32914592315612,
           68.32766911330845,
           68.32619230346077,
           68.3247154936131,
           68.32323868376542,
           68.32176187391777,
           68.32028506407009,
           68.31880825422243,
           68.31733144437476,
           67.92790582678244,
           67.34450580531784,
           66.76110578385324,
           66.17770576238861,
           65.59430574092403,
           65.01090571945937,
           64.42750569799477,
           63.844105676530155,
           63.26070565506554,
           62.67730563360095,
           62.09390561213631,
           61.51050559067172,
           60.92710556920709,
           60.34370554774248,
           59.76030552627789,
           59.17690550481326,
           58.59350548334865,
           58.010105461884024,
           57.42670544041941,
           56.84330541895483,
           56.2599053974902,
           55.67650537602558,
           55.093105354561,
           54.50970533309634,
           53.92630531163175,
           53.34290529016714,
           52.75704336439867,
           52.17039810521268,
           51.58375284602664,
           50.99710758684065,
           50.41046232765464,
           49.82381706846862,
           49.237171809282636,
           48.650526550096615,
           48.06388129091061,
           47.477236031724594,
           46.89059077253858,
           46.30394551335259,
           45.71730025416657,
           45.13065499498056,
           44.544009735794575,
           43.95736447660856,
           43.37071921742255,
           42.784073958236526,
           42.19742869905051,
           41.6107834398645,
           41.024138180678506,
           40.43749292149249,
           39.85084766230648,
           39.264202403120464,
           38.67755714393445,
           38.090911884748465,
           37.50426662556245,
           36.91762136637643,
           36.33097610719042,
           35.74433084800443,
           35.15768558881842,
           34.5710403296324,
           33.98439507044639,
           33.397749811260375,
           32.81110455207439,
           32.22445929288837,
           31.63781403370236,
           31.05116877451634,
           30.464523515330356,
           29.877878256144342,
           29.291232996958325,
           28.704587737772314,
           28.117942478586293,
           27.531297219400308,
           26.944651960214294,
           26.35800670102828,
           25.771361441842263,
           25.184716182656253,
           24.59807092347026,
           24.011425664284246,
           23.424780405098232,
           22.83813514591222,
           22.251489886726233,
           21.664844627540216,
           21.078199368354202,
           20.491554109168188,
           19.90490884998217,
           19.51985455581989,
           19.336391226681325,
           19.152927897542774,
           18.969464568404216,
           18.786001239265595,
           18.602537910127037,
           18.429288744836178,
           18.257892780282162,
           18.0864968157281,
           17.915100851174113,
           17.743704886620105,
           17.57230892206609,
           17.400912957512087,
           17.22951699295804,
           17.058121028404074,
           16.886725063850022,
           16.71562933445003,
           16.555229495221667,
           16.394829655993323,
           16.234429816764933,
           16.074029977536576,
           15.913630138308218,
           15.753230299079881,
           15.59283045985148,
           15.432430620623173,
           15.272030781394779,
           15.112910835046357,
           14.96255324604979,
           14.81219565705323,
           14.661838068056671,
           14.511480479060102,
           14.361122890063493,
           14.210765301066942,
           14.060407712070377,
           13.910050123073766,
           13.760008425347866,
           13.618811643983468,
           13.477614862619022,
           13.336418081254624,
           13.195221299890228,
           13.05402451852582,
           12.91282773716142,
           12.771630955796983,
           12.630434174432578,
           12.494712388712426,
           12.361892098221091,
           12.229071807729738,
           12.09625151723835,
           11.963431226747007,
           11.830610936255663,
           11.69779064576431,
           11.564970355272932,
           11.439223802800026,
           11.31422543504895,
           11.189227067297907,
           11.06422869954688,
           10.939230331795837,
           10.814231964044794,
           10.689233596293727,
           10.570777878222989,
           10.45489339412512,
           10.339008910027259,
           10.223124425929369,
           10.107239941831502,
           9.99135545773364,
           9.875817704853983,
           9.769828385084372,
           9.663839065314786,
           9.557849745545218,
           9.451860425775633,
           9.345871106006049,
           9.239881786236474,
           9.13952718500666,
           9.040540234391399,
           8.941553283776166,
           8.842566333160914,
           8.74357938254563,
           8.644592431930374,
           8.55067972152094,
           8.456858087946634,
           8.363036454372306,
           8.269214820797986,
           8.175393187223687,
           8.085051209916301,
           7.9978040413934846,
           7.910556872870648,
           7.8233097043477855,
           7.736062535824951,
           7.6516681792713666,
           7.571356295404636,
           7.491044411537869,
           7.410732527671134,
           7.330420643804384,
           7.25379188099623,
           7.179632644761914,
           7.1054734085275815,
           7.031314172293261,
           6.9575066703806145,
           6.888793246036173,
           6.820079821691727,
           6.751366397347271,
           6.6826529730028295,
           6.603148784225822,
           6.52070165969446,
           6.438254535163111,
           6.35580741063176,
           6.273360286100395,
           6.1909131615690445,
           6.108466037037695,
           6.02601891250633,
           5.94357178797498,
           5.861124663443629,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           66.14582284020568,
           66.17839213991898,
           66.2112330499066,
           66.24407395989421,
           66.27691486988182,
           66.30975577986943,
           66.34259668985703,
           66.37543759984464,
           66.40827850983226,
           66.44111941981987,
           66.47396032980747,
           66.5068012397951,
           66.5396421497827,
           66.5724830597703,
           66.60532396975792,
           66.63816487974553,
           66.67100578973313,
           66.70384669972074,
           66.73668760970835,
           66.76952851969597,
           66.80236942968358,
           66.83521033967119,
           66.86805124965879,
           66.9008921596464,
           66.93373306963402,
           66.96657397962161,
           66.99941488960924,
           67.03225579959684,
           67.06509670958445,
           67.09793761957206,
           67.13077852955968,
           67.16361943954728,
           67.19646034953489,
           67.2293012595225,
           67.26214216951011,
           67.29498307949773,
           67.32782398948532,
           67.36066489947294,
           67.39350580946055,
           67.42634671944816,
           67.45918762943577,
           67.49202853942339,
           67.524869449411,
           67.55771035939861,
           67.59055126938621,
           67.62339217937382,
           67.65623308936144,
           67.68907399934905,
           67.72191490933666,
           67.75475581932426,
           67.78759672931187,
           67.82043763929948,
           67.8532785492871,
           67.88611945927471,
           67.91896036926231,
           67.95180127924992,
           67.98464218923753,
           68.01748309922515,
           68.05032400921276,
           68.08316491920036,
           68.11600582918797,
           68.14884673917558,
           68.1816876491632,
           68.2145285591508,
           68.24736946913842,
           68.28021037912602,
           68.31305128911363,
           68.34589219910124,
           68.37873310908884,
           68.41157401907645,
           68.44441492906407,
           68.47725583905168,
           68.51009674903929,
           68.5429376590269,
           68.5757785690145,
           68.60861947900212,
           68.64146038898973,
           68.67430129897734,
           68.70714220896495,
           68.73998311895255,
           68.77282402894016,
           68.80566493892778,
           68.83850584891539,
           68.871346758903,
           68.86867857290089,
           68.85890856770084,
           68.84913856250078,
           68.83936855730076,
           68.8295985521007,
           68.81982854690065,
           68.8100585417006,
           68.80028853650055,
           68.7905185313005,
           68.78074852610045,
           68.77097852090041,
           68.76120851570036,
           68.75143851050032,
           68.74166850530025,
           68.73189850010021,
           68.72212849490018,
           68.71235848970012,
           68.70258848450007,
           68.69281847930003,
           68.68304847409998,
           68.67327846889992,
           68.66350846369988,
           68.65373845849983,
           68.64396845329978,
           68.63419844809974,
           68.62442844289968,
           68.61465843769963,
           68.60488843249959,
           68.59511842729954,
           68.58534842209949,
           68.57557841689945,
           68.56580841169941,
           68.55603840649934,
           68.5462684012993,
           68.53649839609926,
           68.5267283908992,
           68.51695838569916,
           68.50718838049912,
           68.49741837529906,
           68.48764837009901,
           68.47787836489896,
           68.4681083596989,
           68.45833835449886,
           68.44856834929882,
           68.43879834409876,
           68.42902833889872,
           68.41925833369866,
           68.40948832849863,
           68.39971832329857,
           68.38994831809852,
           68.38017831289847,
           68.37040830769843,
           68.36063830249839,
           68.35086829729833,
           68.34109829209828,
           68.33132828689823,
           68.32155828169819,
           68.31178827649813,
           68.3020182712981,
           68.29224826609804,
           68.28247826089799,
           68.27270825569795,
           68.26293825049791,
           68.25316824529786,
           68.2433982400978,
           68.23362823489775,
           68.2238582296977,
           68.21408822449766,
           68.20431821929762,
           68.19454821409757,
           68.18477820889751,
           68.17500820369746,
           68.16523819849742,
           68.15546819329737,
           68.14569818809733,
           68.13592818289727,
           68.12615817769722,
           68.11638817249718,
           68.10661816729713,
           68.09684816209707,
           68.08707815689704,
           68.07730815169698,
           68.06753814649694,
           67.67107903885987,
           67.0844437930686,
           66.49779853388259,
           65.91115327469657,
           65.32450801551059,
           64.73786275632455,
           64.15121749713856,
           63.56457223795255,
           62.977926978766526,
           62.39128171958053,
           61.8046364603945,
           61.21799120120851,
           60.6313459420225,
           60.04470068283648,
           59.45805542365049,
           58.87141016446448,
           58.28476490527847,
           57.69811964609246,
           57.11147438690644,
           56.524829127720444,
           55.93818386853443,
           55.351538609348424,
           54.76489335016243,
           54.17824809097639,
           53.591602831790404,
           53.00495757260439,
           52.418312313418376,
           51.83166705423239,
           51.24502179504634,
           50.658376535860356,
           50.07173127667434,
           49.48508601748833,
           48.89844075830234,
           48.31179549911633,
           47.725150239930315,
           47.1385049807443,
           46.55185972155829,
           45.965214462372295,
           45.37856920318628,
           44.79192394400027,
           44.20527868481428,
           43.61863342562827,
           43.03198816644225,
           42.44534290725623,
           41.85869764807022,
           41.272052388884205,
           40.68540712969822,
           40.0987618705122,
           39.512116611326185,
           38.92547135214017,
           38.33882609295416,
           37.75218083376817,
           37.16553557458215,
           36.578890315396144,
           35.99224505621013,
           35.40559979702414,
           34.818954537838124,
           34.23230927865211,
           33.645664019466096,
           33.05901876028008,
           32.4723735010941,
           31.88572824190808,
           31.299082982722066,
           30.712437723536052,
           30.125792464350063,
           29.539147205164046,
           28.952501945978035,
           28.365856686792018,
           27.779211427606004,
           27.19256616842002,
           26.605920909234,
           26.019275650047987,
           25.432630390861974,
           24.84598513167596,
           24.25933987248997,
           23.672694613303957,
           23.086049354117943,
           22.49940409493193,
           21.91275883574594,
           21.326113576559926,
           20.739468317373912,
           20.152823058187895,
           19.56617779900188,
           19.1811235048396,
           18.997660175701036,
           18.81419684656248,
           18.63745676510687,
           18.466060800552853,
           18.294664835998855,
           18.123268871444854,
           17.951872906890838,
           17.780476942336776,
           17.60908097778279,
           17.43768501322878,
           17.266289048674764,
           17.094893084120766,
           16.923497119566715,
           16.75889398293189,
           16.598494143703594,
           16.4380943044752,
           16.277694465246842,
           16.1172946260185,
           15.956894786790109,
           15.796494947561749,
           15.636095108333391,
           15.475695269105056,
           15.315295429876656,
           15.160999701757339,
           15.01064211276074,
           14.860284523764179,
           14.70992693476761,
           14.559569345771052,
           14.409211756774493,
           14.258854167777924,
           14.108496578781315,
           13.958138989784766,
           13.8115720811757,
           13.670375299811292,
           13.529178518446894,
           13.387981737082496,
           13.246784955718054,
           13.105588174353654,
           12.964391392989256,
           12.82319461162485,
           12.68199783026045,
           12.548672931990042,
           12.415852641498688,
           12.283032351007337,
           12.150212060516003,
           12.01739177002465,
           11.884571479533262,
           11.75175118904192,
           11.61974709836775,
           11.494748730616708,
           11.369750362865672,
           11.244751995114639,
           11.119753627363563,
           10.99475525961252,
           10.869756891861494,
           10.744758524110452,
           10.627397490404192,
           10.511513006306329,
           10.39562852220847,
           10.2797440381106,
           10.16385955401274,
           10.04797506991485,
           9.932890734272947,
           9.82690141450337,
           9.720912094733768,
           9.614922774964157,
           9.508933455194573,
           9.402944135425004,
           9.29695481565542,
           9.196436096394246,
           9.097449145778992,
           8.998462195163714,
           8.899475244548453,
           8.80048829393322,
           8.701501343317966,
           8.607133252304996,
           8.513311618730695,
           8.419489985156396,
           8.32566835158209,
           8.23184671800776,
           8.140526588587125,
           8.053279420064289,
           7.966032251541426,
           7.8787850830186095,
           7.791537914495772,
           7.705717151876399,
           7.625405268009638,
           7.545093384142896,
           7.464781500276166,
           7.384469616409399,
           7.306246245378208,
           7.232087009143887,
           7.1579277729095665,
           7.083768536675251,
           7.009609300440918,
           6.939561713200225,
           6.870848288855769,
           6.802134864511327,
           6.733421440166881,
           6.658822144313762,
           6.576375019782412,
           6.493927895251054,
           6.411480770719692,
           6.329033646188341,
           6.246586521656992,
           6.164139397125627,
           6.081692272594276,
           5.999245148062926,
           5.916798023531561,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           66.04144329245598,
           66.07265454753176,
           66.10386580260753,
           66.13507705768329,
           66.16628831275906,
           66.19749956783484,
           66.22871082291061,
           66.25992207798637,
           66.29113333306215,
           66.32234458813792,
           66.3535558432137,
           66.38476709828946,
           66.41597835336523,
           66.447189608441,
           66.47840086351677,
           66.50961211859254,
           66.54082337366832,
           66.5725778456568,
           66.60541875564441,
           66.63825966563202,
           66.67110057561963,
           66.70394148560725,
           66.73678239559484,
           66.76962330558246,
           66.80246421557007,
           66.83530512555768,
           66.8681460355453,
           66.9009869455329,
           66.93382785552052,
           66.96666876550812,
           66.99950967549573,
           67.03235058548334,
           67.06519149547094,
           67.09803240545855,
           67.13087331544617,
           67.16371422543378,
           67.19655513542139,
           67.229396045409,
           67.26223695539662,
           67.29507786538421,
           67.32791877537183,
           67.36075968535944,
           67.39360059534705,
           67.42644150533467,
           67.45928241532226,
           67.49212332530988,
           67.52496423529749,
           67.5578051452851,
           67.59064605527271,
           67.62348696526031,
           67.65632787524792,
           67.68916878523554,
           67.72200969522314,
           67.75485060521076,
           67.78769151519836,
           67.82053242518597,
           67.85337333517359,
           67.8862142451612,
           67.91905515514881,
           67.95189606513641,
           67.98473697512402,
           68.01757788511163,
           68.05041879509926,
           68.08325970508686,
           68.11610061507446,
           68.14894152506207,
           68.18178243504968,
           68.2146233450373,
           68.24746425502491,
           68.28030516501252,
           68.31314607500012,
           68.34598698498773,
           68.37882789497534,
           68.41166880496296,
           68.44450971495056,
           68.47735062493817,
           68.51019153492578,
           68.5430324449134,
           68.575873354901,
           68.60871426488862,
           68.64155517487622,
           68.67439608486383,
           68.70723699485144,
           68.74007790483904,
           68.73740971883694,
           68.7276397136369,
           68.71786970843685,
           68.7080997032368,
           68.69832969803674,
           68.6885596928367,
           68.67878968763665,
           68.66901968243661,
           68.65924967723655,
           68.6494796720365,
           68.63970966683647,
           68.62993966163641,
           68.62016965643637,
           68.61039965123632,
           68.60062964603627,
           68.59085964083621,
           68.58108963563618,
           68.57131963043614,
           68.56154962523608,
           68.55177962003603,
           68.54200961483599,
           68.53223960963592,
           68.52246960443588,
           68.51269959923584,
           68.50292959403579,
           68.49315958883574,
           68.4833895836357,
           68.47361957843563,
           68.46384957323559,
           68.45407956803555,
           68.4443095628355,
           68.43453955763545,
           68.42476955243541,
           68.41499954723535,
           68.4052295420353,
           68.39545953683525,
           68.38568953163522,
           68.37591952643515,
           68.36614952123512,
           68.35637951603508,
           68.34660951083501,
           68.33683950563497,
           68.32706950043493,
           68.31729949523488,
           68.30752949003482,
           68.29775948483477,
           68.28798947963473,
           68.27821947443468,
           68.26844946923464,
           68.25867946403459,
           68.24890945883453,
           68.2391394536345,
           68.22936944843444,
           68.21959944323439,
           68.20982943803435,
           68.2000594328343,
           68.19028942763424,
           68.1805194224342,
           68.17074941723415,
           68.16097941203411,
           68.15120940683406,
           68.141439401634,
           68.13166939643396,
           68.12189939123391,
           68.11212938603386,
           68.1023593808338,
           68.08824467520014,
           68.06544060208057,
           68.04263652896101,
           68.01983245584144,
           67.99702838272188,
           67.9742243096023,
           67.95142023648275,
           67.92861616336317,
           67.90581209024361,
           67.88300801712406,
           67.86020394400448,
           67.83739987088492,
           67.81459579776535,
           67.79179172464579,
           67.76898765152623,
           67.74618357840666,
           67.72337950528708,
           67.32474806197328,
           66.73820293356239,
           66.15165780515149,
           65.56511267674058,
           64.97856754832969,
           64.39202241991875,
           63.80547729150787,
           63.21893216309696,
           62.63238703468605,
           62.04584190627516,
           61.45929677786422,
           60.872751649453335,
           60.28620652104242,
           59.69966139263151,
           59.11311626422063,
           58.52657113580972,
           57.94002600739881,
           57.353480878987895,
           56.766935750576984,
           56.180390622166094,
           55.59384549375518,
           55.00730036534427,
           54.420755236933395,
           53.83421010852245,
           53.24766498011157,
           52.661119851700654,
           52.07457472328974,
           51.48802959487886,
           50.90148446646792,
           50.31493933805704,
           49.72839420964612,
           49.14184908123521,
           48.555303952824325,
           47.96875882441341,
           47.38221369600251,
           46.79566856759159,
           46.209123439180686,
           45.622578310769796,
           45.03603318235889,
           44.449488053947974,
           43.86294292553709,
           43.27639779712618,
           42.68985266871527,
           42.10330754030435,
           41.51676241189344,
           40.930217283482534,
           40.343672155071644,
           39.75712702666073,
           39.17058189824982,
           38.58403676983892,
           37.997491641428,
           37.41094651301712,
           36.82440138460621,
           36.2378562561953,
           35.65131112778439,
           35.0647659993735,
           34.47822087096259,
           33.891675742551676,
           33.305130614140765,
           32.718585485729854,
           32.13204035731897,
           31.54549522890806,
           30.958950100497148,
           30.372404972086237,
           29.78585984367535,
           29.199314715264435,
           28.612769586853524,
           28.026224458442613,
           27.4396793300317,
           26.85313420162082,
           26.26658907320991,
           25.680043944799,
           25.093498816388088,
           24.506953687977173,
           23.92040855956629,
           23.33386343115538,
           22.747318302744468,
           22.160673043951665,
           21.574027784765672,
           20.987382525579658,
           20.400737266393644,
           19.81409200720763,
           19.227446748021613,
           18.845624785377634,
           18.674228820823625,
           18.502832856269574,
           18.331436891715573,
           18.160040927161557,
           17.98864496260756,
           17.81724899805356,
           17.645853033499545,
           17.474457068945483,
           17.303061104391492,
           17.131665139837484,
           16.962558470642186,
           16.802158631413842,
           16.64175879218549,
           16.48135895295709,
           16.320959113728794,
           16.1605592745004,
           16.000159435272042,
           15.839759596043699,
           15.679359756815305,
           15.51895991758695,
           15.359446157464866,
           15.209088568468317,
           15.058730979471745,
           14.90837339047518,
           14.75801580147858,
           14.607658212482022,
           14.457300623485454,
           14.306943034488894,
           14.156585445492334,
           14.006227856495766,
           13.863135737003546,
           13.721938955639198,
           13.580742174274752,
           13.439545392910343,
           13.298348611545947,
           13.157151830181547,
           13.015955048817103,
           12.874758267452705,
           12.735453765759045,
           12.602633475267691,
           12.469813184776314,
           12.33699289428497,
           12.204172603793616,
           12.071352313302265,
           11.93853202281093,
           11.805711732319576,
           11.675272026184484,
           11.550273658433415,
           11.42527529068238,
           11.300276922931337,
           11.175278555180302,
           11.05028018742927,
           10.925281819678194,
           10.80028345192715,
           10.684017102585452,
           10.568132618487583,
           10.452248134389684,
           10.336363650291824,
           10.220479166193964,
           10.104594682096096,
           9.989963763691907,
           9.883974443922332,
           9.777985124152748,
           9.671995804383169,
           9.566006484613569,
           9.460017164843958,
           9.354027845074373,
           9.253345007781858,
           9.154358057166572,
           9.055371106551311,
           8.956384155936057,
           8.85739720532078,
           8.758410254705518,
           8.663586783089066,
           8.569765149514765,
           8.47594351594046,
           8.38212188236616,
           8.288300248791861,
           8.19600196725796,
           8.108754798735117,
           8.02150763021226,
           7.934260461689424,
           7.847013293166562,
           7.759766124643745,
           7.679454240614687,
           7.5991423567479375,
           7.518830472881177,
           7.438518589014435,
           7.3587006097601835,
           7.2845413735258635,
           7.210382137291552,
           7.136222901057232,
           7.06206366482291,
           6.990330180364274,
           6.9216167560198185,
           6.852903331675386,
           6.78418990733093,
           6.71449550440172,
           6.632048379870366,
           6.549601255339009,
           6.467154130807658,
           6.3847070062763,
           6.30225988174494,
           6.219812757213589,
           6.137365632682238,
           6.054918508150873,
           5.972471383619523,
           5.8900242590881735,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           65.93706374470628,
           65.96827499978204,
           65.99948625485781,
           66.03069750993359,
           66.06190876500936,
           66.09312002008514,
           66.1243312751609,
           66.15554253023667,
           66.18675378531243,
           66.21796504038821,
           66.24917629546398,
           66.28038755053976,
           66.31159880561552,
           66.34281006069129,
           66.37402131576707,
           66.40523257084283,
           66.4364438259186,
           66.46765508099438,
           66.49886633607014,
           66.53007759114591,
           66.56128884622169,
           66.59250010129745,
           66.62371135637322,
           66.654922611449,
           66.68613386652476,
           66.71734512160053,
           66.7485563766763,
           66.77976763175208,
           66.81097888682785,
           66.84219014190361,
           66.87340139697939,
           66.90461265205515,
           66.93582390713092,
           66.96703516220671,
           66.9996044613822,
           67.03244537136983,
           67.06528628135743,
           67.09812719134504,
           67.13096810133266,
           67.16380901132025,
           67.19664992130787,
           67.22949083129548,
           67.26233174128309,
           67.2951726512707,
           67.3280135612583,
           67.36085447124591,
           67.39369538123353,
           67.42653629122114,
           67.45937720120875,
           67.49221811119635,
           67.52505902118396,
           67.55789993117158,
           67.59074084115919,
           67.6235817511468,
           67.6564226611344,
           67.68926357112201,
           67.72210448110962,
           67.75494539109724,
           67.78778630108485,
           67.82062721107246,
           67.85346812106008,
           67.88630903104767,
           67.91914994103529,
           67.9519908510229,
           67.98483176101051,
           68.01767267099811,
           68.05051358098572,
           68.08335449097333,
           68.11619540096095,
           68.14903631094856,
           68.18187722093617,
           68.21471813092377,
           68.24755904091138,
           68.280399950899,
           68.3132408608866,
           68.3460817708742,
           68.37892268086182,
           68.41176359084943,
           68.44460450083704,
           68.47744541082466,
           68.51028632081227,
           68.54312723079987,
           68.57596814078748,
           68.6088090507751,
           68.60614086477298,
           68.59637085957294,
           68.58660085437289,
           68.57683084917284,
           68.5670608439728,
           68.55729083877274,
           68.54752083357269,
           68.53775082837265,
           68.52798082317258,
           68.51821081797254,
           68.5084408127725,
           68.49867080757245,
           68.48890080237241,
           68.47913079717236,
           68.46936079197232,
           68.45959078677227,
           68.44982078157221,
           68.44005077637217,
           68.43028077117212,
           68.42051076597207,
           68.41074076077203,
           68.40097075557198,
           68.39120075037192,
           68.38143074517187,
           68.37166073997183,
           68.36189073477178,
           68.35212072957174,
           68.34235072437168,
           68.33258071917163,
           68.32281071397159,
           68.31304070877154,
           68.3032707035715,
           68.29350069837145,
           68.28373069317139,
           68.27396068797135,
           68.26419068277129,
           68.25442067757126,
           68.24465067237121,
           68.23488066717115,
           68.22511066197112,
           68.21534065677106,
           68.20557065157101,
           68.19580064637097,
           68.18603064117092,
           68.17626063597086,
           68.16649063077081,
           68.15672062557077,
           68.14695062037072,
           68.13718061517068,
           68.12741060997062,
           68.10677886822657,
           68.08397479510701,
           68.06117072198745,
           68.03836664886788,
           68.0155625757483,
           67.99275850262875,
           67.96995442950917,
           67.94715035638961,
           67.92434628327004,
           67.90154221015048,
           67.87873813703092,
           67.85593406391135,
           67.83312999079179,
           67.81032591767223,
           67.78752184455266,
           67.7647177714331,
           67.74191369831352,
           67.71910962519397,
           67.69630555207439,
           67.67350147895483,
           67.65069740583526,
           67.6278933327157,
           67.60508925959613,
           67.58228518647657,
           67.559481113357,
           67.53667704023744,
           67.51387296711786,
           67.4910688939983,
           67.46826482087874,
           67.44546074775917,
           67.42265667463961,
           67.39985260152005,
           67.37704852840048,
           66.97841708508666,
           66.39187195667579,
           65.80532682826487,
           65.21878169985396,
           64.63223657144307,
           64.04569144303213,
           63.45914631462125,
           62.872601186210346,
           62.286056057799435,
           61.699510929388545,
           61.112965800977605,
           60.52642067256672,
           59.93987554415581,
           59.3533304157449,
           58.76678528733401,
           58.180240158923105,
           57.593695030512194,
           57.00714990210128,
           56.420604773690364,
           55.83405964527948,
           55.24751451686857,
           54.66096938845766,
           54.074424260046776,
           53.487879131635836,
           52.90133400322495,
           52.31478887481404,
           51.72824374640313,
           51.14169861799225,
           50.5551534895813,
           49.96860836117042,
           49.382063232759506,
           48.7955181043486,
           48.20897297593771,
           47.6224278475268,
           47.0358827191159,
           46.449337590704985,
           45.86279246229407,
           45.276247333883184,
           44.68970220547227,
           44.10315707706136,
           43.51661194865047,
           42.93006682023957,
           42.34352169182865,
           41.75697656341774,
           41.170431435006826,
           40.58388630659592,
           39.99734117818503,
           39.41079604977411,
           38.824250921363216,
           38.2377057929523,
           37.65116066454139,
           37.0646155361305,
           36.4780704077196,
           35.89152527930868,
           35.30498015089777,
           34.71843502248689,
           34.13188989407597,
           33.545344765665064,
           32.958799637254145,
           32.37225450884324,
           31.78570938043235,
           31.19916425202144,
           30.61261912361053,
           30.026073995199617,
           29.44101597189487,
           28.85638283256343,
           28.271749693231985,
           27.68711655390055,
           27.102483414569107,
           26.5178502752377,
           25.933217135906254,
           25.34858399657481,
           24.763950857243376,
           24.179317717911932,
           23.59468457858052,
           23.01005143924908,
           22.425418299917638,
           21.840785160586197,
           21.256152021254785,
           20.67151888192334,
           20.086885742591903,
           19.502252603260462,
           18.91761946392902,
           18.53960491198631,
           18.3682089474323,
           18.19681298287825,
           18.02541701832425,
           17.854021053770232,
           17.682625089216234,
           17.511229124662236,
           17.33983316010822,
           17.16843719555416,
           17.005823119124116,
           16.845423279895716,
           16.68502344066736,
           16.524623601439014,
           16.364223762210667,
           16.203823922982266,
           16.043424083753965,
           15.883024244525574,
           15.722624405297216,
           15.562224566068872,
           15.407535024175868,
           15.257177435179255,
           15.10681984618269,
           14.956462257186141,
           14.806104668189567,
           14.655747079193004,
           14.505389490196404,
           14.355031901199842,
           14.204674312203275,
           14.055896174195828,
           13.91469939283143,
           13.773502611467023,
           13.632305830102577,
           13.491109048738226,
           13.349912267373782,
           13.208715486009371,
           13.067518704644975,
           12.926321923280577,
           12.78941430903664,
           12.656594018545295,
           12.523773728053953,
           12.3909534375626,
           12.258133147071222,
           12.125312856579876,
           11.992492566088526,
           11.859672275597172,
           11.730796954001182,
           11.605798586250138,
           11.480800218499096,
           11.35580185074803,
           11.230803482996993,
           11.105805115245952,
           10.980806747494917,
           10.856521198864518,
           10.740636714766651,
           10.624752230668783,
           10.50886774657093,
           10.392983262473061,
           10.277098778375164,
           10.161214294277302,
           10.047036793110856,
           9.941047473341271,
           9.835058153571694,
           9.729068833802117,
           9.623079514032533,
           9.517090194262956,
           9.411100874493354,
           9.31025391916942,
           9.21126696855416,
           9.112280017938911,
           9.013293067323625,
           8.914306116708365,
           8.815319166093111,
           8.720040313873126,
           8.62621868029882,
           8.53239704672452,
           8.43857541315022,
           8.344753779575916,
           8.251477345928762,
           8.164230177405924,
           8.076983008883083,
           7.989735840360241,
           7.902488671837386,
           7.815241503314549,
           7.733503213219719,
           7.653191329352959,
           7.572879445486215,
           7.492567561619467,
           7.412255677752707,
           7.336995737907858,
           7.26283650167352,
           7.1886772654392,
           7.114518029204889,
           7.041098647528315,
           6.9723852231838555,
           6.903671798839428,
           6.834958374494972,
           6.76624495015054,
           6.6877217399583015,
           6.605274615426953,
           6.5228274908955965,
           6.44038036636424,
           6.357933241832891,
           6.275486117301531,
           6.19303899277017,
           6.11059186823882,
           6.02814474370747,
           5.945697619176105,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           65.83268419695656,
           65.86389545203232,
           65.8951067071081,
           65.92631796218386,
           65.95752921725963,
           65.98874047233541,
           66.01995172741118,
           66.05116298248694,
           66.08237423756272,
           66.11358549263849,
           66.14479674771427,
           66.17600800279003,
           66.2072192578658,
           66.23843051294158,
           66.26964176801735,
           66.30085302309311,
           66.33206427816889,
           66.36327553324466,
           66.39448678832042,
           66.4256980433962,
           66.45690929847197,
           66.48812055354774,
           66.5193318086235,
           66.55054306369928,
           66.58175431877505,
           66.61296557385081,
           66.64417682892659,
           66.67538808400236,
           66.70659933907812,
           66.7378105941539,
           66.76902184922967,
           66.80023310430543,
           66.83144435938121,
           66.86265561445698,
           66.89386686953274,
           66.92507812460853,
           66.95628937968429,
           66.98750063476005,
           67.01871188983584,
           67.0499231449116,
           67.08113439998738,
           67.11234565506315,
           67.14355691013891,
           67.17476816521469,
           67.20597942029045,
           67.23719067536622,
           67.268401930442,
           67.29961318551777,
           67.33082444059353,
           67.36203569566932,
           67.39379016712002,
           67.42663107710763,
           67.45947198709524,
           67.49231289708284,
           67.52515380707045,
           67.55799471705807,
           67.59083562704568,
           67.62367653703328,
           67.65651744702089,
           67.6893583570085,
           67.72219926699611,
           67.75504017698373,
           67.78788108697134,
           67.82072199695894,
           67.85356290694655,
           67.88640381693416,
           67.91924472692178,
           67.95208563690939,
           67.984926546897,
           68.0177674568846,
           68.05060836687221,
           68.08344927685982,
           68.11629018684744,
           68.14913109683505,
           68.18197200682265,
           68.21481291681026,
           68.24765382679787,
           68.28049473678549,
           68.3133356467731,
           68.3461765567607,
           68.37901746674831,
           68.41185837673592,
           68.44469928672353,
           68.47754019671113,
           68.47487201070903,
           68.46510200550898,
           68.45533200030893,
           68.44556199510889,
           68.43579198990884,
           68.4260219847088,
           68.41625197950874,
           68.40648197430869,
           68.39671196910865,
           68.3869419639086,
           68.37717195870854,
           68.3674019535085,
           68.35763194830847,
           68.3478619431084,
           68.33809193790836,
           68.3283219327083,
           68.31855192750825,
           68.30878192230821,
           68.29901191710816,
           68.28924191190812,
           68.27947190670807,
           68.26970190150801,
           68.25993189630796,
           68.25016189110792,
           68.24039188590787,
           68.23062188070783,
           68.22085187550778,
           68.21108187030772,
           68.20131186510768,
           68.19154185990764,
           68.18177185470759,
           68.17200184950754,
           68.16223184430748,
           68.14811713437257,
           68.125313061253,
           68.10250898813344,
           68.07970491501386,
           68.0569008418943,
           68.03409676877475,
           68.01129269565519,
           67.98848862253561,
           67.96568454941605,
           67.94288047629648,
           67.92007640317692,
           67.89727233005735,
           67.87446825693779,
           67.85166418381823,
           67.82886011069866,
           67.8060560375791,
           67.78325196445951,
           67.76044789133996,
           67.73764381822039,
           67.71483974510083,
           67.69203567198126,
           67.6692315988617,
           67.64642752574213,
           67.62362345262255,
           67.60081937950301,
           67.57801530638343,
           67.55521123326386,
           67.5324071601443,
           67.50960308702474,
           67.48679901390517,
           67.46399494078561,
           67.44119086766605,
           67.41838679454648,
           67.39558272142692,
           67.37277864830735,
           67.34997457518777,
           67.32717050206821,
           67.30436642894864,
           67.28156235582908,
           67.25875828270952,
           67.23595420958995,
           67.21315013647039,
           67.19034606335083,
           67.16754199023126,
           67.1447379171117,
           67.12193384399212,
           67.09912977087255,
           67.076325697753,
           67.05352162463343,
           67.03071755151387,
           66.63208610820004,
           66.04554097978917,
           65.45899585137826,
           64.87245072296734,
           64.28590559455645,
           63.69936046614552,
           63.112815337734645,
           62.52627020932373,
           61.93972508091281,
           61.35317995250193,
           60.766634824091,
           60.18008969568011,
           59.5935445672692,
           59.00699943885829,
           58.4204543104474,
           57.833909182036486,
           57.247364053625574,
           56.66081892521467,
           56.07427379680375,
           55.48772866839286,
           54.90118353998196,
           54.314638411571046,
           53.72809328316016,
           53.141548154749216,
           52.55500302633834,
           51.96845789792742,
           51.38191276951651,
           50.79536764110562,
           50.208822512694695,
           49.622277384283805,
           49.03573225587289,
           48.449187127461975,
           47.86264199905111,
           47.27609687064018,
           46.68955174222927,
           46.103006613818366,
           45.51646148540746,
           44.929916356996564,
           44.34337122858565,
           43.75682610017475,
           43.17028097176386,
           42.58373584335295,
           41.997190714942036,
           41.41229202446366,
           40.827658885132216,
           40.24302574580078,
           39.65839260646936,
           39.07375946713793,
           38.48912632780649,
           37.904493188475044,
           37.31986004914361,
           36.73522690981219,
           36.150593770480754,
           35.56596063114931,
           34.98132749181787,
           34.396694352486456,
           33.81206121315501,
           33.22742807382358,
           32.64279493449214,
           32.0581617951607,
           31.473528655829288,
           30.88889551649784,
           30.3042623771664,
           29.719629237834962,
           29.13499609850355,
           28.55036295917211,
           27.965729819840668,
           27.381096680509227,
           26.796463541177786,
           26.211830401846374,
           25.627197262514933,
           25.042564123183496,
           24.45793098385205,
           23.873297844520607,
           23.2886647051892,
           22.704031565857754,
           22.119398426526317,
           21.534765287194876,
           20.950132147863464,
           20.365499008532023,
           19.780865869200582,
           19.19623272986914,
           18.6115995905377,
           18.23358503859499,
           18.062189074040976,
           17.890793109486925,
           17.719397144932927,
           17.54800118037891,
           17.376605215824913,
           17.20948760683434,
           17.049087767605986,
           16.888687928377628,
           16.72828808914929,
           16.56788824992089,
           16.407488410692537,
           16.247088571464193,
           16.086688732235842,
           15.92628889300744,
           15.765889053779139,
           15.605981479883372,
           15.4556238908868,
           15.305266301890201,
           15.154908712893684,
           15.004551123897073,
           14.854193534900507,
           14.703835945903958,
           14.553478356907386,
           14.40312076791082,
           14.25276317891422,
           14.1074598300237,
           13.966263048659256,
           13.825066267294858,
           13.68386948593046,
           13.542672704566053,
           13.401475923201605,
           13.260279141837255,
           13.119082360472811,
           12.977885579108403,
           12.843374852314282,
           12.710554561822905,
           12.57773427133155,
           12.444913980840207,
           12.312093690348863,
           12.179273399857511,
           12.046453109366134,
           11.91363281887479,
           11.786321881817866,
           11.661323514066824,
           11.536325146315797,
           11.411326778564755,
           11.286328410813713,
           11.161330043062645,
           11.036331675311612,
           10.91314081104575,
           10.79725632694789,
           10.68137184285,
           10.565487358752131,
           10.449602874654264,
           10.333718390556411,
           10.217833906458543,
           10.104109822529795,
           9.998120502760218,
           9.892131182990642,
           9.786141863221058,
           9.680152543451479,
           9.574163223681904,
           9.46817390391232,
           9.367162830556989,
           9.268175879941735,
           9.169188929326472,
           9.070201978711212,
           8.971215028095964,
           8.872228077480678,
           8.7764938446572,
           8.682672211082878,
           8.588850577508579,
           8.495028943934274,
           8.401207310359975,
           8.307385676785675,
           8.219705556076724,
           8.132458387553886,
           8.04521121903105,
           7.957964050508208,
           7.8707168819853655,
           7.787552185824722,
           7.707240301957978,
           7.626928418091248,
           7.546616534224487,
           7.466304650357745,
           7.389450102289826,
           7.315290866055507,
           7.241131629821193,
           7.166972393586856,
           7.092813157352534,
           7.0231536903479155,
           6.95444026600347,
           6.885726841659008,
           6.817013417314582,
           6.743395100046249,
           6.66094797551489,
           6.578500850983533,
           6.496053726452183,
           6.413606601920828,
           6.3311594773894715,
           6.248712352858121,
           6.166265228326763,
           6.0838181037954016,
           6.001370979264051,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           65.72830464920686,
           65.75951590428264,
           65.7907271593584,
           65.82193841443417,
           65.85314966950995,
           65.8843609245857,
           65.91557217966148,
           65.94678343473726,
           65.97799468981302,
           66.0092059448888,
           66.04041719996457,
           66.07162845504033,
           66.1028397101161,
           66.13405096519188,
           66.16526222026765,
           66.19647347534342,
           66.22768473041918,
           66.25889598549496,
           66.29010724057073,
           66.3213184956465,
           66.35252975072227,
           66.38374100579804,
           66.4149522608738,
           66.44616351594956,
           66.47737477102535,
           66.50858602610111,
           66.53979728117689,
           66.57100853625266,
           66.60221979132844,
           66.6334310464042,
           66.66464230147997,
           66.69585355655575,
           66.72706481163151,
           66.75827606670728,
           66.78948732178306,
           66.82069857685883,
           66.85190983193459,
           66.88312108701037,
           66.91433234208614,
           66.9455435971619,
           66.97675485223768,
           67.00796610731345,
           67.03917736238921,
           67.070388617465,
           67.10159987254076,
           67.13281112761652,
           67.1640223826923,
           67.19523363776807,
           67.22644489284384,
           67.2576561479196,
           67.28886740299538,
           67.32007865807115,
           67.35128991314693,
           67.3825011682227,
           67.41371242329846,
           67.44492367837424,
           67.47613493345,
           67.50734618852579,
           67.53855744360153,
           67.56976869867732,
           67.60097995375308,
           67.63219120882886,
           67.66340246390462,
           67.69461371898039,
           67.72582497405617,
           67.75703622913193,
           67.7882474842077,
           67.82081678284544,
           67.85365769283305,
           67.88649860282067,
           67.91933951280826,
           67.95218042279588,
           67.98502133278349,
           68.0178622427711,
           68.0507031527587,
           68.08354406274631,
           68.11638497273393,
           68.14922588272154,
           68.18206679270915,
           68.21490770269676,
           68.24774861268438,
           68.28058952267197,
           68.31343043265959,
           68.3462713426472,
           68.34360315664509,
           68.33383315144505,
           68.324063146245,
           68.31429314104494,
           68.3045231358449,
           68.29475313064485,
           68.2849831254448,
           68.27521312024474,
           68.2654431150447,
           68.25567310984465,
           68.24590310464461,
           68.23613309944456,
           68.2263630942445,
           68.21659308904447,
           68.20682308384443,
           68.19705307864437,
           68.18728307344432,
           68.16665132739902,
           68.14384725427946,
           68.12104318115989,
           68.09823910804032,
           68.07543503492076,
           68.05263096180119,
           68.02982688868164,
           68.00702281556207,
           67.98421874244251,
           67.96141466932293,
           67.93861059620338,
           67.9158065230838,
           67.89300244996424,
           67.87019837684468,
           67.84739430372511,
           67.82459023060555,
           67.80178615748598,
           67.7789820843664,
           67.75617801124685,
           67.73337393812727,
           67.71056986500773,
           67.68776579188815,
           67.6649617187686,
           67.64215764564902,
           67.61935357252946,
           67.59654949940989,
           67.57374542629034,
           67.55094135317076,
           67.5281372800512,
           67.50533320693164,
           67.48252913381206,
           67.4597250606925,
           67.43692098757293,
           67.41411691445337,
           67.3913128413338,
           67.36850876821424,
           67.34570469509467,
           67.32290062197511,
           67.30009654885554,
           67.27729247573598,
           67.2544884026164,
           67.23168432949684,
           67.20888025637728,
           67.18607618325771,
           67.16327211013815,
           67.1404680370186,
           67.11766396389902,
           67.09485989077946,
           67.07205581765989,
           67.04925174454033,
           67.02644767142075,
           67.00364359830118,
           66.98083952518162,
           66.95803545206206,
           66.93523137894249,
           66.91242730582293,
           66.88962323270336,
           66.8668191595838,
           66.84401508646422,
           66.82121101334467,
           66.7984069402251,
           66.77560286710553,
           66.75279879398597,
           66.7299947208664,
           66.70719064774684,
           66.68438657462727,
           66.28575513131346,
           65.69921000290257,
           65.11266487449167,
           64.52611974608075,
           63.93957461766987,
           63.35302948925893,
           62.76648436084805,
           62.179939232437135,
           61.593394104026224,
           61.00684897561534,
           60.42030384720441,
           59.83375871879352,
           59.24721359038261,
           58.6606684619717,
           58.07412333356081,
           57.4875782051499,
           56.90103307673899,
           56.31448794832808,
           55.72794281991716,
           55.14139769150627,
           54.554852563095366,
           53.96830743468446,
           53.38356807703251,
           52.79893493770104,
           52.214301798369625,
           51.62966865903818,
           51.045035519706744,
           50.46040238037533,
           49.87576924104387,
           49.29113610171245,
           48.706502962381016,
           48.12186982304957,
           47.537236683718156,
           46.95260354438672,
           46.36797040505527,
           45.78333726572383,
           45.19870412639239,
           44.614070987060984,
           44.02943784772954,
           43.444804708398095,
           42.86017156906669,
           42.27553842973524,
           41.690905290403805,
           41.10627215107236,
           40.52163901174092,
           39.937005872409486,
           39.35237273307807,
           38.767739593746626,
           38.18310645441519,
           37.59847331508375,
           37.01384017575231,
           36.42920703642089,
           35.844573897089454,
           35.25994075775801,
           34.67530761842657,
           34.090674479095156,
           33.50604133976372,
           32.92140820043228,
           32.33677506110084,
           31.7521419217694,
           31.167508782437984,
           30.582875643106547,
           29.998242503775103,
           29.413609364443662,
           28.82897622511225,
           28.24434308578081,
           27.659709946449368,
           27.07507680711793,
           26.490443667786487,
           25.905810528455074,
           25.321177389123633,
           24.736544249792196,
           24.151911110460752,
           23.567277971129315,
           22.9826448317979,
           22.398011692466458,
           21.813378553135017,
           21.228745413803576,
           20.644112274472164,
           20.059479135140723,
           19.474845995809282,
           18.890212856477845,
           18.3055797171464,
           17.92756516520369,
           17.756169200649683,
           17.58477323609563,
           17.41337727154163,
           17.252752255316278,
           17.092352416087888,
           16.93195257685954,
           16.771552737631186,
           16.61115289840283,
           16.450753059174488,
           16.29035321994609,
           16.129953380717733,
           15.96955354148939,
           15.80915370226104,
           15.654070346594327,
           15.503712757597768,
           15.353355168601214,
           15.202997579604641,
           15.052639990608045,
           14.902282401611526,
           14.751924812614917,
           14.601567223618348,
           14.4512096346218,
           14.300852045625227,
           14.159023485851547,
           14.017826704487149,
           13.876629923122751,
           13.735433141758309,
           13.594236360393909,
           13.453039579029511,
           13.311842797665102,
           13.170646016300656,
           13.030155686083258,
           12.897335395591906,
           12.76451510510052,
           12.631694814609208,
           12.49887452411783,
           12.366054233626478,
           12.233233943135133,
           12.100413652643791,
           11.967593362152439,
           11.841846809634605,
           11.716848441883537,
           11.591850074132493,
           11.466851706381453,
           11.341853338630425,
           11.216854970879382,
           11.09185660312834,
           10.969760423226974,
           10.853875939129113,
           10.737991455031246,
           10.622106970933386,
           10.506222486835496,
           10.390338002737625,
           10.274453518639758,
           10.16118285194879,
           10.055193532179207,
           9.949204212409594,
           9.843214892640018,
           9.737225572870441,
           9.631236253100857,
           9.52524693333128,
           9.42407174194457,
           9.32508479132931,
           9.226097840714054,
           9.1271108900988,
           9.028123939483537,
           8.929136988868278,
           8.832947375441297,
           8.739125741866992,
           8.645304108292665,
           8.551482474718345,
           8.457660841144044,
           8.36383920756974,
           8.275180934747539,
           8.1879337662247,
           8.10068659770186,
           8.013439429179023,
           7.926192260656185,
           7.841601158429769,
           7.761289274563021,
           7.68097739069626,
           7.600665506829516,
           7.520353622962787,
           7.441904466671806,
           7.367745230437489,
           7.293585994203169,
           7.2194267579688525,
           7.145267521734537,
           7.073922157511975,
           7.005208733167514,
           6.936495308823076,
           6.867781884478632,
           6.79906846013417,
           6.716621335602838,
           6.634174211071488,
           6.55172708654013,
           6.469279962008773,
           6.386832837477423,
           6.304385712946068,
           6.2219385884147105,
           6.139491463883361,
           6.057044339352003,
           5.9745972148206405,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           65.62392510145715,
           65.65513635653292,
           65.68634761160868,
           65.71755886668446,
           65.74877012176023,
           65.77998137683599,
           65.81119263191177,
           65.84240388698754,
           65.87361514206331,
           65.90482639713908,
           65.93603765221485,
           65.96724890729061,
           65.99846016236638,
           66.02967141744216,
           66.06088267251793,
           66.09209392759371,
           66.12330518266947,
           66.15451643774524,
           66.18572769282102,
           66.21693894789678,
           66.24815020297255,
           66.27936145804833,
           66.31057271312409,
           66.34178396819986,
           66.37299522327562,
           66.4042064783514,
           66.43541773342719,
           66.46662898850295,
           66.49784024357872,
           66.52905149865448,
           66.56026275373026,
           66.59147400880603,
           66.62268526388179,
           66.65389651895757,
           66.68510777403334,
           66.71631902910912,
           66.74753028418488,
           66.77874153926065,
           66.80995279433643,
           66.84116404941219,
           66.87237530448796,
           66.90358655956373,
           66.9347978146395,
           66.96600906971528,
           66.99722032479104,
           67.0284315798668,
           67.05964283494258,
           67.09085409001835,
           67.12206534509413,
           67.1532766001699,
           67.18448785524566,
           67.21569911032144,
           67.24691036539721,
           67.27812162047297,
           67.30933287554875,
           67.34054413062452,
           67.37175538570028,
           67.40296664077606,
           67.43417789585183,
           67.46538915092759,
           67.49660040600337,
           67.52781166107914,
           67.5590229161549,
           67.59023417123068,
           67.62144542630645,
           67.65265668138223,
           67.683867936458,
           67.71507919153376,
           67.74629044660954,
           67.77750170168531,
           67.80871295676107,
           67.83992421183684,
           67.87113546691262,
           67.90234672198838,
           67.93355797706415,
           67.96476923213993,
           67.99598048721569,
           68.02719174229146,
           68.05840299736724,
           68.08961425244301,
           68.12082550751877,
           68.15203676259455,
           68.18324801767032,
           68.21500248858324,
           68.20798959354502,
           68.18518552042545,
           68.16238144730589,
           68.13957737418632,
           68.11677330106676,
           68.0939692279472,
           68.07116515482763,
           68.04836108170807,
           68.02555700858849,
           68.00275293546893,
           67.97994886234936,
           67.9571447892298,
           67.93434071611023,
           67.91153664299067,
           67.8887325698711,
           67.86592849675154,
           67.84312442363198,
           67.82032035051242,
           67.79751627739284,
           67.77471220427327,
           67.75190813115371,
           67.72910405803415,
           67.70629998491458,
           67.68349591179502,
           67.66069183867545,
           67.63788776555589,
           67.61508369243633,
           67.59227961931676,
           67.5694755461972,
           67.54667147307762,
           67.52386739995806,
           67.5010633268385,
           67.47825925371893,
           67.45545518059936,
           67.4326511074798,
           67.40984703436024,
           67.38704296124067,
           67.3642388881211,
           67.34143481500155,
           67.31863074188198,
           67.2958266687624,
           67.27302259564286,
           67.25021852252328,
           67.22741444940371,
           67.20461037628414,
           67.18180630316458,
           67.15900223004502,
           67.13619815692545,
           67.11339408380589,
           67.09059001068631,
           67.06778593756675,
           67.04498186444718,
           67.02217779132762,
           66.99937371820805,
           66.97656964508849,
           66.95376557196892,
           66.93096149884936,
           66.90815742572978,
           66.88535335261022,
           66.86254927949065,
           66.83974520637109,
           66.81694113325153,
           66.79413706013196,
           66.7713329870124,
           66.74852891389284,
           66.72572484077327,
           66.70292076765371,
           66.68011669453415,
           66.65731262141458,
           66.634508548295,
           66.61170447517544,
           66.58890040205587,
           66.56609632893631,
           66.54329225581674,
           66.52048818269718,
           66.49768410957762,
           66.47488003645805,
           66.45207596333849,
           66.42927189021891,
           66.40646781709935,
           66.38366374397978,
           66.36085967086022,
           66.33805559774066,
           65.93947726893272,
           65.35484412960129,
           64.77021099026986,
           64.18557785093842,
           63.600944711607006,
           63.016311572275534,
           62.431678432944125,
           61.84704529361268,
           61.262412154281236,
           60.67777901494983,
           60.09314587561836,
           59.508512736286946,
           58.9238795969555,
           58.339246457624064,
           57.75461331829265,
           57.16998017896121,
           56.58534703962977,
           56.00071390029834,
           55.41608076096689,
           54.831447621635476,
           54.24681448230404,
           53.662181342972595,
           53.077548203641186,
           52.49291506430971,
           51.9082819249783,
           51.32364878564687,
           50.73901564631542,
           50.15438250698401,
           49.56974936765254,
           48.98511622832113,
           48.40048308898969,
           47.81584994965825,
           47.231216810326835,
           46.6465836709954,
           46.06195053166395,
           45.47731739233251,
           44.89268425300107,
           44.308051113669656,
           43.72341797433822,
           43.138784835006774,
           42.55415169567536,
           41.96951855634393,
           41.384885417012484,
           40.80025227768105,
           40.2156191383496,
           39.63098599901816,
           39.04635285968675,
           38.46171972035531,
           37.87708658102387,
           37.29245344169243,
           36.707820302360986,
           36.12318716302957,
           35.53855402369813,
           34.95392088436669,
           34.36928774503525,
           33.784654605703835,
           33.2000214663724,
           32.61538832704096,
           32.03075518770952,
           31.44612204837808,
           30.861488909046663,
           30.276855769715223,
           29.69222263038378,
           29.10758949105234,
           28.52295635172093,
           27.938323212389488,
           27.353690073058047,
           26.769056933726606,
           26.184423794395165,
           25.599790655063753,
           25.015157515732312,
           24.43052437640087,
           23.84589123706943,
           23.261258097737993,
           22.676624958406578,
           22.091991819075137,
           21.507358679743696,
           20.922725540412255,
           20.338092401080843,
           19.753459261749402,
           19.16882612241796,
           18.58419298308652,
           17.99955984375508,
           17.621545291812367,
           17.4564167430265,
           17.29601690379815,
           17.135617064569807,
           16.975217225341453,
           16.814817386113063,
           16.654417546884716,
           16.494017707656358,
           16.333617868428004,
           16.173218029199663,
           16.012818189971263,
           15.852516802301878,
           15.702159213305276,
           15.55180162430876,
           15.401444035312151,
           15.25108644631559,
           15.100728857319035,
           14.950371268322465,
           14.800013679325865,
           14.649656090329348,
           14.499298501332738,
           14.351783923043781,
           14.21058714167943,
           14.069390360314985,
           13.928193578950577,
           13.786996797586179,
           13.645800016221783,
           13.504603234857337,
           13.363406453492939,
           13.22220967212854,
           13.084116229360859,
           12.951295938869507,
           12.81847564837817,
           12.68565535788682,
           12.552835067395431,
           12.42001477690412,
           12.28719448641274,
           12.154374195921392,
           12.022370105202327,
           11.897371737451294,
           11.772373369700253,
           11.647375001949218,
           11.522376634198151,
           11.397378266447108,
           11.272379898696066,
           11.14738153094504,
           11.026380035408215,
           10.910495551310344,
           10.794611067212454,
           10.678726583114592,
           10.562842099016727,
           10.446957614918865,
           10.331073130820975,
           10.21825588136773,
           10.112266561598148,
           10.006277241828576,
           9.900287922058993,
           9.79429860228938,
           9.688309282519803,
           9.582319962750228,
           9.480980653332155,
           9.381993702716901,
           9.283006752101622,
           9.184019801486361,
           9.085032850871109,
           8.986045900255855,
           8.889400906225353,
           8.795579272651047,
           8.701757639076753,
           8.607936005502449,
           8.51411437192812,
           8.420292738353801,
           8.330656313418341,
           8.2434091448955,
           8.156161976372664,
           8.068914807849826,
           7.981667639326984,
           7.895650131034807,
           7.8153382471680635,
           7.735026363301297,
           7.65471447943455,
           7.57440259556779,
           7.494358831053795,
           7.420199594819475,
           7.346040358585143,
           7.271881122350826,
           7.197721886116505,
           7.124690624676017,
           7.055977200331575,
           6.987263775987129,
           6.918550351642667,
           6.849836927298231,
           6.772294695690785,
           6.689847571159427,
           6.60740044662807,
           6.524953322096719,
           6.442506197565361,
           6.360059073034005,
           6.2776119485026545,
           6.1951648239713,
           6.112717699439942,
           6.030270574908592,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           65.51288603785714,
           65.54409729293292,
           65.57530854800868,
           65.60651980308445,
           65.63773105816023,
           65.668942313236,
           65.70015356831178,
           65.73136482338754,
           65.76257607846331,
           65.79378733353907,
           65.82499858861485,
           65.85620984369062,
           65.88742109876638,
           65.91863235384216,
           65.94984360891793,
           65.9810548639937,
           66.01226611906947,
           66.04347737414524,
           66.07468862922101,
           66.10589988429679,
           66.13711113937255,
           66.16832239444832,
           66.19953364952408,
           66.23074490459986,
           66.26195615967563,
           66.29316741475141,
           66.32437866982718,
           66.35558992490294,
           66.38680117997872,
           66.4180124350545,
           66.44922369013025,
           66.48043494520603,
           66.5116462002818,
           66.54285745535756,
           66.57406871043334,
           66.60527996550911,
           66.63649122058487,
           66.66770247566063,
           66.69891373073642,
           66.73012498581218,
           66.76133624088796,
           66.79254749596373,
           66.8237587510395,
           66.85497000611528,
           66.88618126119104,
           66.91739251626682,
           66.94860377134258,
           66.97981502641835,
           67.01102628149413,
           67.0422375365699,
           67.07344879164566,
           67.10466004672143,
           67.13587130179721,
           67.16708255687298,
           67.19829381194874,
           67.22950506702452,
           67.2607163221003,
           67.29192757717607,
           67.32313883225183,
           67.3543500873276,
           67.38556134240336,
           67.41677259747914,
           67.44798385255491,
           67.47919510763067,
           67.51040636270645,
           67.54161761778222,
           67.572828872858,
           67.60404012793376,
           67.63363154613066,
           67.66289899926103,
           67.6921664523914,
           67.72143390552176,
           67.75070135865214,
           67.77996881178251,
           67.80923626491287,
           67.83850371804323,
           67.8677711711736,
           67.89703862430397,
           67.92630607743435,
           67.9555735305647,
           67.98484098369508,
           68.01410843682544,
           68.04337588995581,
           68.07264334308617,
           68.04266503480154,
           68.0008375742339,
           67.95901011366628,
           67.91718265309864,
           67.87535519253102,
           67.83352773196339,
           67.79170027139575,
           67.74987281082812,
           67.70804535026049,
           67.66621788969285,
           67.62439042912523,
           67.5825629685576,
           67.54073550798995,
           67.49890804742232,
           67.4570805868547,
           67.41525312628707,
           67.38927846975967,
           67.3664743966401,
           67.34367032352054,
           67.32086625040097,
           67.29806217728141,
           67.27525810416184,
           67.25245403104228,
           67.22964995792272,
           67.20684588480314,
           67.18404181168358,
           67.16123773856401,
           67.13843366544445,
           67.11562959232488,
           67.09282551920532,
           67.07002144608575,
           67.04721737296619,
           67.02441329984661,
           67.00160922672706,
           66.97880515360748,
           66.95600108048792,
           66.93319700736835,
           66.91039293424879,
           66.88758886112923,
           66.86478478800966,
           66.8419807148901,
           66.81917664177054,
           66.79637256865097,
           66.7735684955314,
           66.75076442241183,
           66.72796034929227,
           66.7051562761727,
           66.68235220305314,
           66.65954812993357,
           66.63674405681401,
           66.61393998369444,
           66.59113591057488,
           66.56833183745532,
           66.54552776433574,
           66.52272369121619,
           66.49991961809661,
           66.47711554497705,
           66.45431147185748,
           66.43150739873792,
           66.40870332561835,
           66.38589925249879,
           66.36309517937921,
           66.34029110625967,
           66.3174870331401,
           66.29468296002054,
           66.27187888690096,
           66.2490748137814,
           66.22627074066185,
           66.20346666754227,
           66.1806625944227,
           66.15785852130314,
           66.13505444818357,
           66.11225037506401,
           66.08944630194443,
           66.06664222882488,
           66.0438381557053,
           66.02103408258574,
           65.99823000946617,
           65.97542593634661,
           65.95262186322705,
           65.92981779010748,
           65.90701371698792,
           65.88420964386835,
           65.49340597148382,
           64.91860249946686,
           64.34379902744986,
           63.76899555543288,
           63.19419208341591,
           62.619388611398904,
           62.04458513938193,
           61.469781667364956,
           60.89497819534797,
           60.32017472333099,
           59.74537125131398,
           59.17056777929702,
           58.595764307280035,
           58.02096083526305,
           57.44615736324607,
           56.8713538912291,
           56.2965504192121,
           55.72032663502337,
           55.135580907341996,
           54.55083517966066,
           53.96608945197929,
           53.38134372429792,
           52.79659799661658,
           52.21185226893519,
           51.627106541253845,
           51.04236081357248,
           50.45761508589111,
           49.87286935820977,
           49.288123630528375,
           48.70337790284704,
           48.118632175165665,
           47.533886447484306,
           46.94914071980296,
           46.364394992121596,
           45.779649264440216,
           45.19490353675886,
           44.610157809077485,
           44.02541208139614,
           43.440666353714775,
           42.8559206260334,
           42.271174898352065,
           41.6864291706707,
           41.101683442989334,
           40.51693771530796,
           39.932191987626595,
           39.34744625994522,
           38.762700532263885,
           38.17795480458252,
           37.593209076901154,
           37.00846334921978,
           36.423717621538415,
           35.83897189385707,
           35.254226166175705,
           34.66948043849434,
           34.084734710812974,
           33.49998898313163,
           32.915243255450264,
           32.3304975277689,
           31.745751800087525,
           31.16100607240616,
           30.576260344724815,
           29.991514617043453,
           29.406768889362084,
           28.822023161680715,
           28.237277433999374,
           27.652531706318005,
           27.067785978636635,
           26.48304025095527,
           25.898294523273904,
           25.31354879559256,
           24.728803067911194,
           24.144057340229825,
           23.559311612548456,
           22.97456588486709,
           22.38982015718575,
           21.80507442950438,
           21.220328701823014,
           20.635582974141645,
           20.050837246460304,
           19.466091518778935,
           18.881345791097566,
           18.2966000634162,
           17.71185433573483,
           17.33928155228008,
           17.178881713051684,
           17.01848187382333,
           16.858082034594986,
           16.69768219536663,
           16.537282356138242,
           16.376882516909895,
           16.216482677681537,
           16.056082838453182,
           15.900605669012839,
           15.750248080016268,
           15.599890491019698,
           15.4495329020231,
           15.299175313026582,
           15.148817724029973,
           14.998460135033412,
           14.848102546036857,
           14.697744957040285,
           14.547387368043687,
           14.403347578871667,
           14.262150797507259,
           14.120954016142814,
           13.979757234778463,
           13.838560453414019,
           13.697363672049608,
           13.55616689068521,
           13.414970109320814,
           13.27377332795637,
           13.1380767726385,
           13.005256482147121,
           12.87243619165577,
           12.739615901164418,
           12.606795610673082,
           12.47397532018173,
           12.341155029690341,
           12.208334739199032,
           12.077895033019056,
           11.952896665268012,
           11.827898297516946,
           11.702899929765913,
           11.577901562014867,
           11.452903194263834,
           11.327904826512768,
           11.202906458761722,
           11.082999647589414,
           10.967115163491563,
           10.851230679393694,
           10.735346195295826,
           10.619461711197935,
           10.503577227100074,
           10.387692743002207,
           10.275328910786682,
           10.169339591017103,
           10.063350271247518,
           9.957360951477936,
           9.851371631708366,
           9.74538231193878,
           9.63939299216917,
           9.53788956471975,
           9.438902614104473,
           9.339915663489212,
           9.240928712873956,
           9.141941762258677,
           9.042954811643417,
           8.945854437009414,
           8.852032803435115,
           8.75821116986081,
           8.664389536286503,
           8.57056790271221,
           8.476746269137903,
           8.38613169208916,
           8.298884523566324,
           8.211637355043468,
           8.124390186520627,
           8.03714301799779,
           7.949895849474953,
           7.86938721977308,
           7.789075335906338,
           7.708763452039594,
           7.628451568172828,
           7.548139684306081,
           7.472653959201449,
           7.398494722967131,
           7.324335486732811,
           7.2501762504984795,
           7.176017014264162,
           7.106745667495628,
           7.0380322431511715,
           6.969318818806729,
           6.900605394462285,
           6.827968055778721,
           6.745520931247375,
           6.663073806716013,
           6.580626682184655,
           6.498179557653298,
           6.415732433121947,
           6.33328530859059,
           6.250838184059233,
           6.168391059527883,
           6.085943934996527,
           6.003496810465171,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           65.40163886503869,
           65.43285012011447,
           65.46406137519023,
           65.495272630266,
           65.52648388534178,
           65.55769514041754,
           65.58890639549331,
           65.62011765056909,
           65.65132890564485,
           65.68254016072062,
           65.7137514157964,
           65.74496267087216,
           65.77617392594794,
           65.8073851810237,
           65.83859643609948,
           65.86980769117525,
           65.90101894625101,
           65.93223020132679,
           65.96344145640256,
           65.99465271147832,
           66.02586396655411,
           66.05707522162987,
           66.08828647670565,
           66.11949773178141,
           66.15070898685718,
           66.18192024193294,
           66.21313149700872,
           66.2443427520845,
           66.27555400716025,
           66.30676526223604,
           66.3379765173118,
           66.36918777238758,
           66.40039902746335,
           66.43161028253911,
           66.46282153761489,
           66.49403279269066,
           66.52524404776642,
           66.5564553028422,
           66.58766655791796,
           66.61887781299374,
           66.65008906806952,
           66.68130032314528,
           66.71251157822105,
           66.74372283329683,
           66.77493408837259,
           66.80614534344835,
           66.83735659852414,
           66.8685678535999,
           66.89977910867567,
           66.93099036375145,
           66.96220161882721,
           66.99276493905661,
           67.02203239218699,
           67.05129984531735,
           67.08056729844772,
           67.10983475157808,
           67.13910220470845,
           67.16836965783882,
           67.19763711096918,
           67.22690456409956,
           67.25617201722991,
           67.28543947036029,
           67.31470692349066,
           67.34397437662102,
           67.3732418297514,
           67.40250928288175,
           67.43177673601213,
           67.46104418914248,
           67.49031164227286,
           67.51957909540323,
           67.54884654853359,
           67.57811400166396,
           67.60738145479432,
           67.6366489079247,
           67.66591636105507,
           67.69518381418543,
           67.7244512673158,
           67.75371872044616,
           67.78298617357653,
           67.81225362670689,
           67.84152107983726,
           67.87078853296764,
           67.900055986098,
           67.92932343922837,
           67.89934513094373,
           67.8575176703761,
           67.81569020980847,
           67.77386274924083,
           67.73203528867322,
           67.69020782810557,
           67.64838036753794,
           67.60655290697031,
           67.56472544640268,
           67.52289798583504,
           67.48107052526741,
           67.43924306469978,
           67.39741560413215,
           67.35558814356452,
           67.31376068299689,
           67.27193322242925,
           67.23010576186162,
           67.18827830129399,
           67.14645084072636,
           67.10462338015873,
           67.0627959195911,
           67.02096845902346,
           66.97914099845583,
           66.9373135378882,
           66.89548607732057,
           66.85365861675294,
           66.8118311561853,
           66.77000369561767,
           66.72817623505003,
           66.68634877448241,
           66.64452131391478,
           66.60269385334715,
           66.56720751346761,
           66.54440344034805,
           66.52159936722848,
           66.4987952941089,
           66.47599122098934,
           66.45318714786978,
           66.43038307475021,
           66.40757900163065,
           66.38477492851109,
           66.36197085539153,
           66.33916678227196,
           66.3163627091524,
           66.29355863603283,
           66.27075456291327,
           66.2479504897937,
           66.22514641667414,
           66.20234234355456,
           66.179538270435,
           66.15673419731543,
           66.13393012419587,
           66.1111260510763,
           66.08832197795674,
           66.06551790483718,
           66.0427138317176,
           66.01990975859803,
           65.99710568547847,
           65.97430161235891,
           65.95149753923934,
           65.92869346611978,
           65.90588939300022,
           65.88308531988065,
           65.86028124676108,
           65.83747717364153,
           65.81467310052196,
           65.79186902740238,
           65.76906495428283,
           65.74626088116325,
           65.7234568080437,
           65.70065273492412,
           65.67784866180456,
           65.65504458868499,
           65.63224051556543,
           65.60943644244585,
           65.5866323693263,
           65.56382829620674,
           65.54102422308716,
           65.5182201499676,
           65.49541607684804,
           65.47261200372847,
           65.4498079306089,
           65.42700385748934,
           65.03620018510482,
           64.46139671308785,
           63.886593241070855,
           63.311789769053874,
           62.73698629703691,
           62.1621828250199,
           61.58737935300292,
           61.01257588098595,
           60.437772408968954,
           59.86296893695199,
           59.28816546493498,
           58.71336199291801,
           58.13855852090103,
           57.56375504888403,
           56.988951576867066,
           56.414148104850085,
           55.83934463283309,
           55.26454116081611,
           54.68973768879911,
           54.11493421678215,
           53.540130744765165,
           52.965327272748176,
           52.39052380073121,
           51.81572032871419,
           51.24091685669724,
           50.666113384680244,
           50.091309912663256,
           49.51650644064629,
           48.94170296862928,
           48.36689949661232,
           47.792096024595324,
           47.217292552578336,
           46.642489080561376,
           46.06768560854439,
           45.4928821365274,
           44.91736850678405,
           44.332622779102685,
           43.74787705142134,
           43.163131323739975,
           42.5783855960586,
           41.993639868377265,
           41.40889414069589,
           40.824148413014534,
           40.23940268533316,
           39.654656957651795,
           39.06991122997043,
           38.485165502289085,
           37.90041977460772,
           37.31567404692635,
           36.73092831924498,
           36.14618259156361,
           35.56143686388227,
           34.9766911362009,
           34.39194540851953,
           33.80719968083817,
           33.22245395315683,
           32.63770822547546,
           32.05296249779409,
           31.468216770112726,
           30.883471042431356,
           30.298725314750016,
           29.71397958706865,
           29.129233859387277,
           28.544488131705915,
           27.95974240402457,
           27.374996676343205,
           26.790250948661836,
           26.20550522098047,
           25.6207594932991,
           25.03601376561776,
           24.45126803793639,
           23.86652231025502,
           23.281776582573656,
           22.697030854892287,
           22.112285127210946,
           21.527539399529577,
           20.94279367184821,
           20.35804794416684,
           19.7733022164855,
           19.18855648880413,
           18.603810761122766,
           18.019065033441397,
           17.434319305760027,
           17.061746522305278,
           16.901346683076877,
           16.740946843848526,
           16.580547004620183,
           16.42014716539183,
           16.259747326163435,
           16.099347486935088,
           15.948694535723837,
           15.798336946727227,
           15.647979357730678,
           15.497621768734112,
           15.347264179737541,
           15.19690659074094,
           15.046549001744422,
           14.896191412747813,
           14.745833823751253,
           14.59610801606392,
           14.45491123469951,
           14.313714453335113,
           14.172517671970715,
           14.031320890606306,
           13.89012410924186,
           13.74892732787751,
           13.607730546513066,
           13.466533765148657,
           13.32533698378426,
           13.192037315916123,
           13.059217025424768,
           12.926396734933425,
           12.793576444442046,
           12.660756153950693,
           12.52793586345934,
           12.395115572968004,
           12.262295282476654,
           12.13341996083575,
           12.00842159308472,
           11.883423225333683,
           11.75842485758264,
           11.633426489831574,
           11.508428122080542,
           11.383429754329496,
           11.258431386578462,
           11.139619259770674,
           11.023734775672775,
           10.907850291574906,
           10.791965807477055,
           10.676081323379186,
           10.560196839281316,
           10.444312355183426,
           10.332401940205663,
           10.226412620436054,
           10.120423300666479,
           10.0144339808969,
           9.908444661127316,
           9.802455341357733,
           9.696466021588163,
           9.594798476107306,
           9.495811525492067,
           9.396824574876813,
           9.297837624261536,
           9.198850673646273,
           9.099863723031019,
           9.002307967793485,
           8.908486334219178,
           8.81466470064488,
           8.720843067070579,
           8.627021433496274,
           8.533199799921968,
           8.44160707076,
           8.354359902237135,
           8.267112733714294,
           8.17986556519146,
           8.092618396668602,
           8.00537122814576,
           7.923436192378108,
           7.843124308511365,
           7.7628124246446175,
           7.682500540777875,
           7.602188656911132,
           7.525108323583445,
           7.450949087349107,
           7.3767898511147925,
           7.302630614880475,
           7.228471378646154,
           7.157514134659676,
           7.08880071031522,
           7.020087285970788,
           6.951373861626333,
           6.88266043728189,
           6.801194291335315,
           6.71874716680396,
           6.636300042272614,
           6.553852917741253,
           6.471405793209895,
           6.388958668678538,
           6.306511544147187,
           6.2240644196158295,
           6.1416172950844725,
           6.059170170553122,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           65.29039169222023,
           65.32160294729601,
           65.35281420237177,
           65.38402545744754,
           65.41523671252332,
           65.44644796759908,
           65.47765922267484,
           65.50887047775062,
           65.5400817328264,
           65.57129298790217,
           65.60250424297794,
           65.6337154980537,
           65.66492675312948,
           65.69613800820525,
           65.72734926328103,
           65.7585605183568,
           65.78977177343256,
           65.82098302850834,
           65.85219428358411,
           65.88340553865987,
           65.91461679373563,
           65.94582804881142,
           65.97703930388718,
           66.00825055896294,
           66.03946181403872,
           66.07067306911449,
           66.10188432419025,
           66.13309557926604,
           66.1643068343418,
           66.19551808941758,
           66.22672934449335,
           66.25794059956911,
           66.28915185464489,
           66.32036310972066,
           66.35157436479643,
           66.38116578511293,
           66.41043323824329,
           66.43970069137366,
           66.46896814450402,
           66.49823559763439,
           66.52750305076475,
           66.55677050389511,
           66.5860379570255,
           66.61530541015586,
           66.64457286328623,
           66.67384031641659,
           66.70310776954696,
           66.73237522267732,
           66.76164267580769,
           66.79091012893807,
           66.82017758206842,
           66.84944503519878,
           66.87871248832916,
           66.90797994145953,
           66.9372473945899,
           66.96651484772026,
           66.99578230085064,
           67.025049753981,
           67.05431720711137,
           67.08358466024173,
           67.1128521133721,
           67.14211956650247,
           67.17138701963283,
           67.2006544727632,
           67.22992192589356,
           67.25918937902394,
           67.2884568321543,
           67.31772428528467,
           67.34699173841503,
           67.37625919154542,
           67.40552664467577,
           67.43479409780613,
           67.4640615509365,
           67.49332900406688,
           67.52259645719724,
           67.55186391032761,
           67.58113136345797,
           67.61039881658834,
           67.63966626971872,
           67.66893372284908,
           67.69820117597945,
           67.72746862910981,
           67.75673608224018,
           67.78600353537054,
           67.75602522708591,
           67.71419776651828,
           67.67237030595065,
           67.63054284538302,
           67.58871538481537,
           67.54688792424776,
           67.50506046368012,
           67.46323300311249,
           67.42140554254486,
           67.37957808197723,
           67.33775062140958,
           67.29592316084197,
           67.25409570027432,
           67.2122682397067,
           67.17044077913906,
           67.12861331857142,
           67.08678585800381,
           67.04495839743618,
           67.00313093686853,
           66.96130347630091,
           66.91947601573328,
           66.87764855516564,
           66.83582109459802,
           66.79399363403039,
           66.75216617346274,
           66.71033871289512,
           66.66851125232748,
           66.62668379175986,
           66.58485633119223,
           66.5430288706246,
           66.50120141005695,
           66.45937394948932,
           66.41754648892169,
           66.37571902835407,
           66.33389156778642,
           66.2920641072188,
           66.25023664665116,
           66.20840918608354,
           66.1665817255159,
           66.12475426494827,
           66.08292680438063,
           66.04109934381302,
           65.99927188324537,
           65.95744442267775,
           65.91561696211011,
           65.87378950154248,
           65.83196204097484,
           65.79013458040723,
           65.74830711983958,
           65.72233248405595,
           65.69952841093638,
           65.67672433781682,
           65.65392026469726,
           65.63111619157769,
           65.60831211845813,
           65.58550804533856,
           65.562703972219,
           65.53989989909942,
           65.51709582597987,
           65.4942917528603,
           65.47148767974073,
           65.44868360662116,
           65.42587953350161,
           65.40307546038204,
           65.38027138726248,
           65.35746731414291,
           65.33466324102335,
           65.31185916790378,
           65.2890550947842,
           65.26625102166464,
           65.24344694854508,
           65.22064287542551,
           65.19783880230595,
           65.1750347291864,
           65.15223065606682,
           65.12942658294726,
           65.10662250982769,
           65.08381843670813,
           65.06101436358855,
           65.038210290469,
           65.01540621734942,
           64.99260214422986,
           64.96979807111029,
           64.57899439872577,
           64.0041909267088,
           63.42938745469181,
           62.854583982674825,
           62.27978051065786,
           61.70497703864085,
           61.13017356662389,
           60.5553700946069,
           59.980566622589905,
           59.40576315057294,
           58.83095967855593,
           58.25615620653896,
           57.68135273452198,
           57.106549262504984,
           56.53174579048803,
           55.956942318471036,
           55.382138846454055,
           54.80733537443705,
           54.23253190242007,
           53.65772843040311,
           53.082924958386116,
           52.50812148636913,
           51.93331801435216,
           51.35851454233515,
           50.78371107031818,
           50.208907598301195,
           49.634104126284214,
           49.05930065426725,
           48.48449718225023,
           47.90969371023327,
           47.334890238216275,
           46.760086766199294,
           46.18528329418233,
           45.61047982216534,
           45.03567635014835,
           44.46087287813136,
           43.88606940611437,
           43.31126593409741,
           42.73646246208042,
           42.16165899006343,
           41.58685551804647,
           41.012052046029474,
           40.43724857401249,
           39.8624451019955,
           39.287641629978516,
           38.712838157961514,
           38.13803468594456,
           37.56323121392757,
           36.98842774191058,
           36.41362426989359,
           35.8388207978766,
           35.26401732585964,
           34.68921385384265,
           34.114410378544704,
           33.529664650863346,
           32.944918923182,
           32.360173195500636,
           31.775427467819267,
           31.190681740137904,
           30.60593601245653,
           30.021190284775194,
           29.43644455709382,
           28.851698829412452,
           28.26695310173109,
           27.682207374049746,
           27.09746164636838,
           26.512715918687007,
           25.92797019100564,
           25.343224463324276,
           24.758478735642935,
           24.173733007961566,
           23.588987280280197,
           23.00424155259883,
           22.419495824917462,
           21.83475009723612,
           21.250004369554752,
           20.665258641873386,
           20.080512914192017,
           19.495767186510676,
           18.911021458829307,
           18.32627573114794,
           17.741530003466572,
           17.156784275785206,
           16.78421149233045,
           16.623811653102052,
           16.4634118138737,
           16.303011974645358,
           16.14714099143138,
           15.996783402434781,
           15.846425813438222,
           15.696068224441657,
           15.545710635445046,
           15.395353046448497,
           15.24499545745193,
           15.09463786845536,
           14.94428027945876,
           14.793922690462242,
           14.647671671891743,
           14.506474890527347,
           14.365278109162949,
           14.224081327798539,
           14.082884546434142,
           13.941687765069743,
           13.800490983705334,
           13.659294202340892,
           13.51809742097654,
           13.378818149685104,
           13.245997859193753,
           13.113177568702376,
           12.980357278211033,
           12.84753698771968,
           12.714716697228335,
           12.581896406736956,
           12.449076116245605,
           12.316255825754252,
           12.188944888652454,
           12.06394652090141,
           11.938948153150367,
           11.813949785399334,
           11.6889514176483,
           11.563953049897258,
           11.43895468214619,
           11.313956314395156,
           11.196238871951849,
           11.080354387854014,
           10.964469903756154,
           10.848585419658257,
           10.732700935560388,
           10.616816451462535,
           10.500931967364668,
           10.38947496962463,
           10.283485649855052,
           10.177496330085448,
           10.071507010315841,
           9.965517690546264,
           9.859528370776687,
           9.753539051007103,
           9.651707387494893,
           9.552720436879644,
           9.45373348626436,
           9.35474653564912,
           9.255759585033868,
           9.156772634418589,
           9.058761498577537,
           8.964939865003236,
           8.87111823142894,
           8.777296597854631,
           8.683474964280332,
           8.589653330706033,
           8.497082449430778,
           8.409835280907934,
           8.322588112385123,
           8.235340943862262,
           8.148093775339419,
           8.060846606816582,
           7.977485164983147,
           7.897173281116379,
           7.816861397249637,
           7.736549513382894,
           7.656237629516147,
           7.577562687965417,
           7.503403451731101,
           7.429244215496779,
           7.355084979262442,
           7.280925743028127,
           7.208282601823717,
           7.139569177479256,
           7.070855753134829,
           7.002142328790374,
           6.933428904445942,
           6.856867651423261,
           6.7744205268919115,
           6.691973402360546,
           6.609526277829191,
           6.527079153297846,
           6.444632028766484,
           6.362184904235125,
           6.279737779703769,
           6.197290655172418,
           6.1148435306410605,
           6.032396406109703,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           65.17914451940177,
           65.21035577447755,
           65.24156702955331,
           65.27277828462908,
           65.30398953970486,
           65.33520079478063,
           65.3664120498564,
           65.39762330493217,
           65.42883456000794,
           65.46004581508372,
           65.49125707015949,
           65.52246832523525,
           65.55367958031101,
           65.5848908353868,
           65.61610209046256,
           65.64731334553834,
           65.6785246006141,
           65.70973585568987,
           65.74029917803887,
           65.76956663116923,
           65.79883408429961,
           65.82810153742996,
           65.85736899056033,
           65.8866364436907,
           65.91590389682106,
           65.94517134995144,
           65.9744388030818,
           66.00370625621217,
           66.03297370934254,
           66.0622411624729,
           66.09150861560327,
           66.12077606873363,
           66.150043521864,
           66.17931097499437,
           66.20857842812472,
           66.23784588125511,
           66.26711333438547,
           66.29638078751584,
           66.32564824064622,
           66.35491569377658,
           66.38418314690695,
           66.4134506000373,
           66.44271805316768,
           66.47198550629804,
           66.50125295942841,
           66.53052041255877,
           66.55978786568915,
           66.58905531881952,
           66.61832277194988,
           66.64759022508025,
           66.67685767821061,
           66.70612513134098,
           66.73539258447136,
           66.76466003760171,
           66.79392749073209,
           66.82319494386246,
           66.85246239699282,
           66.88172985012318,
           66.91099730325355,
           66.94026475638393,
           66.96953220951428,
           66.99879966264466,
           67.02806711577503,
           67.05733456890539,
           67.08660202203576,
           67.11586947516612,
           67.1451369282965,
           67.17440438142685,
           67.20367183455723,
           67.2329392876876,
           67.26220674081796,
           67.29147419394833,
           67.32074164707869,
           67.35000910020906,
           67.37927655333942,
           67.4085440064698,
           67.43781145960017,
           67.46707891273053,
           67.4963463658609,
           67.52561381899127,
           67.55488127212165,
           67.584148725252,
           67.61341617838237,
           67.64268363151274,
           67.6127053232281,
           67.57087786266047,
           67.52905040209284,
           67.4872229415252,
           67.44539548095757,
           67.40356802038994,
           67.36174055982232,
           67.31991309925468,
           67.27808563868705,
           67.23625817811941,
           67.19443071755178,
           67.15260325698415,
           67.11077579641652,
           67.06894833584889,
           67.02712087528126,
           66.98529341471362,
           66.94346595414599,
           66.90163849357836,
           66.85981103301073,
           66.8179835724431,
           66.77615611187545,
           66.73432865130783,
           66.6925011907402,
           66.65067373017257,
           66.60884626960494,
           66.56701880903731,
           66.52519134846968,
           66.48336388790204,
           66.4415364273344,
           66.39970896676677,
           66.35788150619913,
           66.31605404563152,
           66.27422658506389,
           66.23239912449625,
           66.19057166392862,
           66.14874420336098,
           66.10691674279336,
           66.06508928222571,
           66.02326182165808,
           65.98143436109046,
           65.93960690052282,
           65.8977794399552,
           65.85595197938756,
           65.81412451881994,
           65.77229705825229,
           65.73046959768467,
           65.68864213711704,
           65.64681467654941,
           65.60498721598177,
           65.56315975541413,
           65.52133229484652,
           65.47950483427888,
           65.43767737371124,
           65.39584991314362,
           65.35402245257598,
           65.31219499200836,
           65.27036753144073,
           65.2285400708731,
           65.18671261030546,
           65.14488514973783,
           65.1030576891702,
           65.06123022860257,
           65.01940276803492,
           64.97757530746729,
           64.93574784689966,
           64.9002615277639,
           64.87745745464434,
           64.85465338152477,
           64.8318493084052,
           64.80904523528564,
           64.78624116216606,
           64.7634370890465,
           64.74063301592693,
           64.71782894280737,
           64.69502486968781,
           64.67222079656824,
           64.64941672344867,
           64.62661265032911,
           64.60380857720955,
           64.58100450408999,
           64.55820043097042,
           64.53539635785086,
           64.51259228473128,
           64.12178861234676,
           63.54698514032979,
           62.97218166831281,
           62.397378196295804,
           61.82257472427885,
           61.247771252261835,
           60.672967780244875,
           60.09816430822789,
           59.5233608362109,
           58.94855736419393,
           58.373753892176914,
           57.79895042015996,
           57.22414694814297,
           56.64934347612598,
           56.07454000410901,
           55.49973653209203,
           54.924933060075034,
           54.35012958805805,
           53.77532611604106,
           53.20052264402409,
           52.6257191720071,
           52.050915699990114,
           51.47611222797316,
           50.90130875595614,
           50.326505283939184,
           49.75170181192219,
           49.17689833990521,
           48.602094867888226,
           48.027291395871224,
           47.45248792385425,
           46.87768445183727,
           46.30288097982027,
           45.72807750780332,
           45.153274035786325,
           44.57847056376934,
           44.00366709175235,
           43.42886361973536,
           42.8540601477184,
           42.27925667570141,
           41.70445320368442,
           41.129649731667456,
           40.554846259650475,
           39.98004278763347,
           39.4052393156165,
           38.830435843599496,
           38.255632371582514,
           37.680828899565554,
           37.10602542754856,
           36.53122195553157,
           35.95641848351458,
           35.38161501149759,
           34.806811539480634,
           34.232008067463646,
           33.65720459544666,
           33.08240112342966,
           32.5075976514127,
           31.932794179395714,
           31.35799070737872,
           30.78318723536174,
           30.20838376334474,
           29.63358029132778,
           29.058776819310797,
           28.483973347293805,
           27.909169875276817,
           27.334366403259857,
           26.759562931242865,
           26.18475945922588,
           25.609955987208885,
           25.0351525151919,
           24.46034904317494,
           23.885545571157945,
           23.31074209914096,
           22.726706522624024,
           22.14196079494266,
           21.557215067261318,
           20.97246933957995,
           20.387723611898586,
           19.802977884217214,
           19.218232156535873,
           18.633486428854507,
           18.048740701173134,
           17.463994973491772,
           16.879249245810403,
           16.50667646235565,
           16.346276623127252,
           16.19522985814235,
           16.044872269145753,
           15.894514680149221,
           15.744157091152623,
           15.593799502156063,
           15.443441913159496,
           15.293084324162887,
           15.142726735166338,
           14.99236914616977,
           14.8420115571732,
           14.699235327719636,
           14.55803854635524,
           14.416841764990796,
           14.275644983626398,
           14.134448202261998,
           13.99325142089759,
           13.852054639533193,
           13.710857858168794,
           13.569661076804385,
           13.43277869296272,
           13.299958402471388,
           13.16713811198003,
           13.034317821488681,
           12.901497530997302,
           12.76867724050596,
           12.635856950014608,
           12.503036659523262,
           12.370216369031883,
           12.244469816469186,
           12.11947144871814,
           11.994473080967083,
           11.869474713216041,
           11.744476345464996,
           11.619477977713963,
           11.494479609962928,
           11.369481242211885,
           11.252858484133101,
           11.136974000035211,
           11.021089515937343,
           10.90520503183951,
           10.789320547741648,
           10.67343606364375,
           10.557551579545882,
           10.446547999043599,
           10.340558679274015,
           10.23456935950443,
           10.128580039734853,
           10.022590719965248,
           9.91660140019564,
           9.810612080426065,
           9.708616298882504,
           9.609629348267218,
           9.510642397651958,
           9.411655447036711,
           9.312668496421425,
           9.213681545806187,
           9.11521502936165,
           9.02139339578733,
           8.927571762213002,
           8.833750128638702,
           8.739928495064405,
           8.646106861490097,
           8.552557828101632,
           8.465310659578774,
           8.378063491055912,
           8.29081632253307,
           8.20356915401026,
           8.116321985487396,
           8.03153413758817,
           7.951222253721427,
           7.870910369854684,
           7.790598485987918,
           7.710286602121176,
           7.630017052347414,
           7.555857816113075,
           7.481698579878762,
           7.407539343644444,
           7.3333801074101235,
           7.259220871175786,
           7.1903376446433205,
           7.121624220298878,
           7.052910795954418,
           6.984197371609991,
           6.91254101151122,
           6.830093886979858,
           6.747646762448508,
           6.665199637917158,
           6.582752513385793,
           6.5003053888544375,
           6.417858264323092,
           6.335411139791731,
           6.252964015260373,
           6.170516890729015,
           6.088069766197666,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           65.06789734658331,
           65.09910860165908,
           65.12870002409517,
           65.15796747722554,
           65.18723493035591,
           65.21650238348627,
           65.24576983661665,
           65.275037289747,
           65.30430474287738,
           65.33357219600774,
           65.36283964913811,
           65.39210710226848,
           65.42137455539884,
           65.45064200852921,
           65.47990946165957,
           65.50917691478995,
           65.5384443679203,
           65.56771182105068,
           65.59697927418105,
           65.62624672731141,
           65.65551418044178,
           65.68478163357216,
           65.71404908670252,
           65.74331653983289,
           65.77258399296325,
           65.80185144609362,
           65.83111889922398,
           65.86038635235435,
           65.88965380548473,
           65.91892125861509,
           65.94818871174546,
           65.97745616487582,
           66.00672361800619,
           66.03599107113655,
           66.06525852426694,
           66.0945259773973,
           66.12379343052766,
           66.15306088365803,
           66.1823283367884,
           66.21159578991876,
           66.24086324304912,
           66.27013069617948,
           66.29939814930987,
           66.32866560244022,
           66.3579330555706,
           66.38720050870096,
           66.41646796183133,
           66.44573541496169,
           66.47500286809206,
           66.50427032122244,
           66.5335377743528,
           66.56280522748317,
           66.59207268061354,
           66.6213401337439,
           66.65060758687426,
           66.67987504000463,
           66.709142493135,
           66.73840994626536,
           66.76767739939574,
           66.7969448525261,
           66.82621230565647,
           66.85547975878683,
           66.8847472119172,
           66.91401466504757,
           66.94328211817793,
           66.9725495713083,
           67.00181702443868,
           67.03108447756904,
           67.0603519306994,
           67.08961938382977,
           67.11888683696014,
           67.1481542900905,
           67.17742174322088,
           67.20668919635125,
           67.23595664948161,
           67.26522410261198,
           67.29449155574234,
           67.32375900887271,
           67.35302646200309,
           67.38229391513345,
           67.4115613682638,
           67.44082882139418,
           67.47009627452455,
           67.49936372765491,
           67.46938541937027,
           67.42755795880264,
           67.385730498235,
           67.34390303766737,
           67.30207557709976,
           67.26024811653213,
           67.2184206559645,
           67.17659319539686,
           67.13476573482923,
           67.0929382742616,
           67.05111081369397,
           67.00928335312634,
           66.96745589255869,
           66.92562843199107,
           66.88380097142344,
           66.84197351085581,
           66.80014605028818,
           66.75831858972055,
           66.71649112915291,
           66.67466366858527,
           66.63283620801765,
           66.59100874745002,
           66.54918128688237,
           66.50735382631476,
           66.46552636574712,
           66.42369890517949,
           66.38187144461185,
           66.34004398404421,
           66.29821652347658,
           66.25638906290897,
           66.21456160234132,
           66.17273414177369,
           66.13090668120606,
           66.08907922063844,
           66.0472517600708,
           66.00542429950318,
           65.96359683893553,
           65.9217693783679,
           65.87994191780027,
           65.83811445723265,
           65.796286996665,
           65.75445953609739,
           65.71263207552974,
           65.67080461496212,
           65.62897715439448,
           65.58714969382685,
           65.54532223325921,
           65.5034947726916,
           65.46166731212395,
           65.41983985155632,
           65.37801239098869,
           65.33618493042107,
           65.29435746985342,
           65.25253000928579,
           65.21070254871816,
           65.16887508815053,
           65.1270476275829,
           65.08522016701527,
           65.04339270644763,
           65.00156524588,
           64.95973778531237,
           64.91791032474474,
           64.8760828641771,
           64.83425540360948,
           64.79242794304184,
           64.75060048247421,
           64.70877302190658,
           64.66694556133895,
           64.62511810077132,
           64.58329064020369,
           64.54146317963605,
           64.49963571906842,
           64.45780825850079,
           64.41598079793316,
           64.37415333736553,
           64.33232587679788,
           64.29049841623026,
           64.24867095566263,
           64.206843495095,
           64.16501603452737,
           64.12318857395974,
           64.0813611133921,
           64.05538649835225,
           63.664582825967706,
           63.08977935395075,
           62.51497588193376,
           61.94017240991677,
           61.36536893789981,
           60.79056546588279,
           60.21576199386583,
           59.640958521848844,
           59.06615504983185,
           58.49135157781489,
           57.91654810579788,
           57.341744633780905,
           56.766941161763924,
           56.192407212531656,
           55.618681893205334,
           55.044956573879,
           54.47123125455267,
           53.897505935226334,
           53.32378061589999,
           52.75005529657367,
           52.17632997724735,
           51.602604657921,
           51.028879338594685,
           50.45515401926833,
           49.88142869994202,
           49.30770338061567,
           48.73397806128934,
           48.16025274196302,
           47.586527422636664,
           47.01280210331035,
           46.43907678398402,
           45.86535146465768,
           45.291626145331364,
           44.71790082600503,
           44.14417550667869,
           43.57045018735235,
           42.99672486802601,
           42.42299954869971,
           41.849274229373364,
           41.27554891004702,
           40.70182359072072,
           40.12809827139438,
           39.554372952068036,
           38.9806476327417,
           38.406922313415365,
           37.83319699408902,
           37.259471674762715,
           36.68574635543637,
           36.112021036110036,
           35.5382957167837,
           34.964570397457365,
           34.39084507813105,
           33.817119758804715,
           33.24339443947838,
           32.66966912015204,
           32.09594380082572,
           31.522218481499387,
           30.94849316217305,
           30.374767842846715,
           29.801042523520373,
           29.227317204194062,
           28.653591884867723,
           28.079866565541387,
           27.50614124621505,
           26.932415926888737,
           26.3586906075624,
           25.784965288236066,
           25.211239968909723,
           24.637514649583384,
           24.063789330257077,
           23.490064010930737,
           22.916338691604395,
           22.34261337227806,
           21.768888052951723,
           21.19516273362541,
           20.621437414299074,
           20.047712094972734,
           19.4739867756464,
           18.900261456320084,
           18.32653613699375,
           17.75281081766741,
           17.179085498341074,
           16.605360179014735,
           16.243318724853296,
           16.09296113585673,
           15.942603546860171,
           15.792245957863573,
           15.641888368867043,
           15.491530779870445,
           15.341173190873883,
           15.19081560187732,
           15.040458012880707,
           14.891995764911918,
           14.750798983547474,
           14.609602202183066,
           14.468405420818668,
           14.32720863945427,
           14.186011858089824,
           14.044815076725428,
           13.90361829536103,
           13.762421513996621,
           13.621224732632223,
           13.486739236240371,
           13.35391894574902,
           13.221098655257633,
           13.0882783647663,
           12.955458074274942,
           12.822637783783591,
           12.689817493292212,
           12.55699720280087,
           12.424993112036908,
           12.299994744285874,
           12.17499637653484,
           12.049998008783797,
           11.924999641032755,
           11.800001273281698,
           11.675002905530654,
           11.55000453777961,
           11.425362580412173,
           11.309478096314312,
           11.193593612216443,
           11.077709128118583,
           10.961824644020693,
           10.845940159922824,
           10.73005567582499,
           10.614171191727129,
           10.503621028462538,
           10.397631708692954,
           10.291642388923385,
           10.185653069153801,
           10.079663749384215,
           9.97367442961464,
           9.867685109845034,
           9.765525210270065,
           9.66653825965481,
           9.567551309039555,
           9.46856435842427,
           9.369577407809011,
           9.270590457193764,
           9.171668560145712,
           9.077846926571405,
           8.984025292997107,
           8.890203659422786,
           8.796382025848459,
           8.702560392274158,
           8.60873875869986,
           8.520786038249572,
           8.433538869726755,
           8.3462917012039,
           8.259044532681038,
           8.171797364158195,
           8.085583110193197,
           8.005271226326446,
           7.924959342459699,
           7.8446474585929575,
           7.764335574726214,
           7.684023690859447,
           7.608312180495051,
           7.53415294426075,
           7.459993708026413,
           7.385834471792098,
           7.3116752355577805,
           7.241106111807376,
           7.172392687462915,
           7.103679263118474,
           7.034965838774033,
           6.966252414429571,
           6.885767247067801,
           6.8033201225364515,
           6.72087299800509,
           6.638425873473739,
           6.5559787489423895,
           6.473531624411024,
           6.391084499879669,
           6.308637375348324,
           6.226190250816962,
           6.143743126285604,
           6.061296001754247,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           64.94830923236229,
           64.97543081336667,
           65.00255239437105,
           65.02967397537543,
           65.05679555637983,
           65.0839171373842,
           65.11103871838857,
           65.13816029939295,
           65.16528188039734,
           65.19240346140172,
           65.2195250424061,
           65.24664662341048,
           65.27376820441486,
           65.30088978541926,
           65.32801136642364,
           65.35513294742802,
           65.38368511215887,
           65.41295256528922,
           65.4422200184196,
           65.47148747154996,
           65.50075492468034,
           65.53002237781071,
           65.55928983094105,
           65.58855728407144,
           65.6178247372018,
           65.64709219033217,
           65.67635964346255,
           65.7056270965929,
           65.73489454972326,
           65.76416200285364,
           65.79342945598401,
           65.82269690911437,
           65.85196436224473,
           65.88123181537512,
           65.91049926850548,
           65.93976672163583,
           65.96903417476621,
           65.99830162789658,
           66.02756908102694,
           66.05683653415731,
           66.08610398728769,
           66.11537144041804,
           66.1446388935484,
           66.17390634667879,
           66.20317379980915,
           66.23244125293951,
           66.26170870606988,
           66.29097615920024,
           66.32024361233061,
           66.34951106546099,
           66.37877851859135,
           66.40804597172172,
           66.43731342485208,
           66.46658087798244,
           66.49584833111282,
           66.52511578424318,
           66.55438323737356,
           66.58365069050393,
           66.61291814363429,
           66.64218559676465,
           66.67145304989502,
           66.7007205030254,
           66.72998795615575,
           66.75925540928613,
           66.78852286241649,
           66.81779031554686,
           66.84705776867722,
           66.87632522180759,
           66.90559267493796,
           66.93486012806832,
           66.9641275811987,
           66.99339503432905,
           67.02266248745943,
           67.05192994058979,
           67.08119739372016,
           67.11046484685053,
           67.13973229998089,
           67.16899975311127,
           67.19826720624162,
           67.227534659372,
           67.25680211250237,
           67.28606956563273,
           67.31533701876309,
           67.34460447189348,
           67.31462616360885,
           67.27279870304122,
           67.23097124247356,
           67.18914378190594,
           67.14731632133831,
           67.10548886077068,
           67.06366140020305,
           67.02183393963541,
           66.98000647906778,
           66.93817901850015,
           66.89635155793252,
           66.85452409736489,
           66.81269663679726,
           66.77086917622962,
           66.72904171566199,
           66.68721425509436,
           66.64538679452673,
           66.6035593339591,
           66.56173187339147,
           66.51990441282383,
           66.4780769522562,
           66.43624949168857,
           66.39442203112094,
           66.35259457055331,
           66.31076710998568,
           66.26893964941803,
           66.22711218885041,
           66.18528472828277,
           66.14345726771515,
           66.10162980714752,
           66.05980234657989,
           66.01797488601225,
           65.97614742544461,
           65.93431996487699,
           65.89249250430936,
           65.85066504374173,
           65.80883758317408,
           65.76701012260645,
           65.72518266203883,
           65.6833552014712,
           65.64152774090356,
           65.59970028033592,
           65.5578728197683,
           65.51604535920066,
           65.47421789863304,
           65.4323904380654,
           65.39056297749778,
           65.34873551693013,
           65.3069080563625,
           65.26508059579487,
           65.22325313522725,
           65.18142567465962,
           65.13959821409198,
           65.09777075352434,
           65.05594329295671,
           65.01411583238908,
           64.97228837182146,
           64.93046091125382,
           64.88863345068619,
           64.84680599011855,
           64.80497852955094,
           64.7631510689833,
           64.72132360841566,
           64.67949614784803,
           64.6376686872804,
           64.59584122671276,
           64.55401376614513,
           64.5121863055775,
           64.4459387919978,
           64.37969125213999,
           64.31344371228217,
           64.24719617242435,
           64.18094863256654,
           64.11470109270871,
           64.04845355285089,
           63.982206012993075,
           63.915958473135255,
           63.849710933277436,
           63.783463393419616,
           63.7172158535618,
           63.65096831370398,
           63.58472077384616,
           63.518473233988345,
           63.12331227953881,
           62.563694617793466,
           62.0040769560481,
           61.44445929430274,
           60.884841632557404,
           60.32522397081201,
           59.76560630906667,
           59.20598864732131,
           58.646370985575935,
           58.0867533238306,
           57.527135662085215,
           56.96751800033987,
           56.40790033859451,
           55.848282676849145,
           55.2886650151038,
           54.72904735335844,
           54.16942969161307,
           53.60981202986771,
           53.05019436812235,
           52.490576706377006,
           51.92370366596516,
           51.34997834663882,
           50.776253027312514,
           50.20252770798616,
           49.628802388659835,
           49.05507706933349,
           48.481351750007164,
           47.90762643068085,
           47.33390111135448,
           46.76017579202818,
           46.186450472701836,
           45.61272515337551,
           45.038999834049186,
           44.46527451472285,
           43.8915491953965,
           43.31782387607017,
           42.74409855674382,
           42.17037323741752,
           41.596647918091186,
           41.02292259876485,
           40.449197279438536,
           39.8754719601122,
           39.30174664078586,
           38.72802132145952,
           38.15429600213318,
           37.580570682806844,
           37.00684536348054,
           36.433120044154194,
           35.85939472482786,
           35.285669405501515,
           34.71194408617518,
           34.13821876684887,
           33.56449344752253,
           32.990768128196194,
           32.41704280886986,
           31.843317489543544,
           31.269592170217205,
           30.69586685089087,
           30.122141531564534,
           29.548416212238195,
           28.974690892911884,
           28.400965573585545,
           27.82724025425921,
           27.253514934932873,
           26.67978961560656,
           26.106064296280223,
           25.532338976953884,
           24.95861365762754,
           24.384888338301202,
           23.811163018974895,
           23.23743769964856,
           22.663712380322217,
           22.08998706099588,
           21.516261741669542,
           20.942536422343228,
           20.36881110301689,
           19.795085783690553,
           19.221360464364217,
           18.647635145037903,
           18.073909825711567,
           17.50018450638523,
           16.926459187058892,
           16.352733867732557,
           15.990692413571123,
           15.840334824574551,
           15.689977235577995,
           15.539619646581395,
           15.389262057584865,
           15.238904468588267,
           15.088546879591707,
           14.943559420739748,
           14.802362639375303,
           14.661165858010952,
           14.519969076646507,
           14.378772295282097,
           14.2375755139177,
           14.096378732553303,
           13.955181951188855,
           13.813985169824461,
           13.673520070009323,
           13.540699779517972,
           13.407879489026627,
           13.275059198535283,
           13.14223890804393,
           13.009418617552543,
           12.87659832706121,
           12.743778036569854,
           12.610957746078503,
           12.480518039853635,
           12.355519672102602,
           12.230521304351527,
           12.10552293660049,
           11.980524568849455,
           11.855526201098415,
           11.73052783334737,
           11.605529465596314,
           11.481982192593412,
           11.366097708495513,
           11.250213224397653,
           11.134328740299793,
           11.018444256201924,
           10.902559772104063,
           10.786675288006174,
           10.670790803908304,
           10.560694057881488,
           10.454704738111912,
           10.348715418342326,
           10.242726098572742,
           10.136736778803174,
           10.030747459033588,
           9.924758139264004,
           9.822434121657638,
           9.72344717104238,
           9.624460220427121,
           9.525473269811867,
           9.426486319196611,
           9.327499368581327,
           9.228512417966066,
           9.134300457355472,
           9.040478823781168,
           8.946657190206862,
           8.852835556632561,
           8.759013923058241,
           8.665192289483914,
           8.576261416920397,
           8.489014248397561,
           8.401767079874698,
           8.314519911351882,
           8.227272742829026,
           8.140025574306165,
           8.059320198931482,
           7.979008315064727,
           7.898696431197978,
           7.81838454733123,
           7.738072663464488,
           7.660766544877024,
           7.586607308642718,
           7.512448072408387,
           7.438288836174086,
           7.36412959993975,
           7.291874578971419,
           7.223161154626977,
           7.154447730282532,
           7.085734305938071,
           7.017020881593629,
           6.941440607155748,
           6.858993482624383,
           6.776546358093032,
           6.6940992335616825,
           6.61165210903032,
           6.529204984498971,
           6.4467578599676205,
           6.364310735436256,
           6.281863610904901,
           6.199416486373556,
           6.116969361842193,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           64.82808648057576,
           64.85520806158014,
           64.88232964258451,
           64.90945122358889,
           64.93657280459328,
           64.96369438559766,
           64.99081596660204,
           65.01793754760642,
           65.04505912861082,
           65.0721807096152,
           65.09930229061958,
           65.12642387162396,
           65.15354545262832,
           65.18066703363272,
           65.20778861463711,
           65.23491019564148,
           65.26203177664586,
           65.28915335765025,
           65.31627493865463,
           65.34339651965901,
           65.37051810066339,
           65.39763968166778,
           65.42476126267215,
           65.45188284367654,
           65.47900442468091,
           65.5061260056853,
           65.53324758668968,
           65.56036916769406,
           65.58749074869846,
           65.61461232970282,
           65.64173391070722,
           65.6688554917116,
           65.69633472002538,
           65.72560217315575,
           65.75486962628612,
           65.78413707941648,
           65.81340453254685,
           65.84267198567721,
           65.87193943880759,
           65.90120689193795,
           65.93047434506832,
           65.95974179819869,
           65.98900925132904,
           66.01827670445942,
           66.0475441575898,
           66.07681161072016,
           66.10607906385053,
           66.13534651698089,
           66.16461397011125,
           66.19388142324163,
           66.223148876372,
           66.25241632950235,
           66.28168378263273,
           66.3109512357631,
           66.34021868889346,
           66.36948614202382,
           66.3987535951542,
           66.42802104828456,
           66.45728850141492,
           66.4865559545453,
           66.51582340767567,
           66.54509086080603,
           66.57435831393639,
           66.60362576706676,
           66.63289322019713,
           66.66216067332749,
           66.69142812645786,
           66.72069557958824,
           66.7499630327186,
           66.77923048584897,
           66.80849793897933,
           66.83776539210969,
           66.86703284524008,
           66.89630029837043,
           66.92556775150081,
           66.95483520463117,
           66.98410265776154,
           67.01337011089191,
           67.04263756402227,
           67.07190501715264,
           67.101172470283,
           67.13043992341338,
           67.15970737654374,
           67.18897482967411,
           67.15899652138948,
           67.11716906082185,
           67.0753416002542,
           67.03351413968657,
           66.99168667911896,
           66.94985921855132,
           66.9080317579837,
           66.86620429741606,
           66.82437683684843,
           66.7825493762808,
           66.74072191571315,
           66.69889445514552,
           66.6570669945779,
           66.61523953401027,
           66.57341207344263,
           66.531584612875,
           66.48975715230738,
           66.44792969173974,
           66.4061022311721,
           66.36427477060447,
           66.32244731003684,
           66.28061984946922,
           66.23879238890157,
           66.19696492833395,
           66.15513746776631,
           66.11331000719868,
           66.07148254663106,
           66.02965508606341,
           65.98782762549578,
           65.94600016492815,
           65.90417270436052,
           65.86234524379289,
           65.82051778322526,
           65.77869032265762,
           65.73686286208999,
           65.69503540152236,
           65.65320794095473,
           65.6113804803871,
           65.56955301981947,
           65.52772555925183,
           65.4858980986842,
           65.44407063811657,
           65.40224317754894,
           65.36041571698131,
           65.31858825641368,
           65.27676079584604,
           65.23493333527841,
           65.19310587471078,
           65.15127841414315,
           65.10945095357552,
           65.06762349300789,
           65.013586015044,
           64.94733847518619,
           64.88109093532836,
           64.81484339547055,
           64.74859585561272,
           64.68234831575491,
           64.61610077589708,
           64.54985323603927,
           64.48360569618144,
           64.41735815632362,
           64.3511106164658,
           64.28486307660799,
           64.21861553675016,
           64.15236799689235,
           64.08612045703453,
           64.01987291717671,
           63.9536253773189,
           63.88737783746107,
           63.82113029760325,
           63.75488275774543,
           63.68863521788761,
           63.622387678029796,
           63.55614013817197,
           63.48989259831416,
           63.42364505845633,
           63.35739751859852,
           63.2911499787407,
           63.22490243888288,
           63.15865489902505,
           63.09240735916724,
           63.02615981930942,
           62.9599122794516,
           62.564751325002064,
           62.00513366325673,
           61.445516001511365,
           60.885898339766,
           60.326280678020666,
           59.76666301627527,
           59.20704535452993,
           58.64742769278456,
           58.0878100310392,
           57.52819236929386,
           56.96857470754847,
           56.408957045803135,
           55.84933938405777,
           55.2897217223124,
           54.73010406056706,
           54.170486398821694,
           53.61086873707633,
           53.05125107533097,
           52.4916334135856,
           51.93201575184027,
           51.3723980900949,
           50.812780428349534,
           50.25316276660419,
           49.693545104858806,
           49.13392744311347,
           48.5743097813681,
           48.01469211962274,
           47.4550744578774,
           46.895456796132,
           46.33583913438667,
           45.77622147264131,
           45.21660381089594,
           44.656986149150605,
           44.097368487405234,
           43.53775082565987,
           42.97813316391451,
           42.418515502169136,
           41.8588978404238,
           41.29928017867844,
           40.73966251693307,
           40.18004485518774,
           39.62042719344237,
           39.0491203295037,
           38.47539501017736,
           37.90166969085103,
           37.32794437152469,
           36.75421905219837,
           36.18049373287203,
           35.606768413545694,
           35.03304309421936,
           34.45931777489302,
           33.88559245556671,
           33.31186713624037,
           32.73814181691404,
           32.164416497587695,
           31.590691178261384,
           31.016965858935045,
           30.443240539608713,
           29.869515220282377,
           29.295789900956038,
           28.722064581629724,
           28.148339262303388,
           27.574613942977052,
           27.00088862365071,
           26.427163304324395,
           25.85343798499806,
           25.279712665671727,
           24.70598734634538,
           24.132262027019046,
           23.55853670769274,
           22.984811388366403,
           22.41108606904006,
           21.83736074971372,
           21.26363543038738,
           20.689910111061067,
           20.11618479173473,
           19.542459472408396,
           18.968734153082057,
           18.395008833755746,
           17.82128351442941,
           17.24755819510307,
           16.673832875776732,
           16.100107556450396,
           15.738066102288963,
           15.587708513292394,
           15.437350924295835,
           15.286993335299236,
           15.136635746302707,
           14.995123076567598,
           14.853926295203204,
           14.712729513838795,
           14.571532732474349,
           14.430335951109997,
           14.289139169745555,
           14.147942388381145,
           14.006745607016747,
           13.865548825652349,
           13.727480613286934,
           13.594660322795592,
           13.461840032304249,
           13.329019741812894,
           13.19619945132155,
           13.063379160830207,
           12.930558870338855,
           12.797738579847467,
           12.664918289356132,
           12.53604296767034,
           12.411044599919297,
           12.286046232168262,
           12.16104786441723,
           12.036049496666154,
           11.911051128915119,
           11.786052761164084,
           11.661054393413043,
           11.538601804774624,
           11.422717320676771,
           11.306832836578902,
           11.190948352481005,
           11.075063868383145,
           10.959179384285283,
           10.843294900187416,
           10.727410416089556,
           10.617767087300473,
           10.511777767530862,
           10.405788447761285,
           10.29979912799171,
           10.193809808222124,
           10.08782048845254,
           9.981831168682971,
           9.879343033045217,
           9.780356082429956,
           9.6813691318147,
           9.582382181199446,
           9.483395230584184,
           9.38440827996893,
           9.285421329353676,
           9.190753988139537,
           9.096932354565231,
           9.003110720990938,
           8.909289087416632,
           8.815467453842327,
           8.721645820268028,
           8.63173679559121,
           8.54448962706837,
           8.457242458545531,
           8.369995290022695,
           8.282748121499832,
           8.195500952977016,
           8.113369171536515,
           8.033057287669767,
           7.952745403803019,
           7.872433519936264,
           7.792121636069515,
           7.713220909259016,
           7.6390616730247,
           7.564902436790368,
           7.490743200556063,
           7.416583964321731,
           7.342643046135468,
           7.273929621791007,
           7.20521619744658,
           7.136502773102137,
           7.067789348757692,
           6.997113967243685,
           6.914666842712335,
           6.832219718180985,
           6.749772593649619,
           6.6673254691182695,
           6.584878344586919,
           6.502431220055557,
           6.419984095524207,
           6.337536970992858,
           6.255089846461492,
           6.172642721930137,
           6.090195597398791,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           64.70786372878922,
           64.7349853097936,
           64.76210689079798,
           64.78922847180236,
           64.81635005280674,
           64.84347163381112,
           64.8705932148155,
           64.89771479581988,
           64.92483637682427,
           64.95195795782865,
           64.97907953883303,
           65.00620111983741,
           65.0333227008418,
           65.06044428184617,
           65.08756586285057,
           65.11468744385495,
           65.14180902485933,
           65.16893060586371,
           65.19605218686809,
           65.22317376787247,
           65.25029534887685,
           65.27741692988124,
           65.3045385108856,
           65.33166009189,
           65.35878167289437,
           65.38590325389876,
           65.41302483490315,
           65.44014641590752,
           65.46726799691191,
           65.4943895779163,
           65.52151115892067,
           65.54863273992505,
           65.57575432092943,
           65.60287590193383,
           65.6299974829382,
           65.65711906394257,
           65.68424064494697,
           65.71136222595135,
           65.73848380695573,
           65.76560538796011,
           65.79272696896449,
           65.81984854996888,
           65.84697013097326,
           65.87409171197764,
           65.90121329298202,
           65.9283348739864,
           65.95545645499078,
           65.98257803599516,
           66.00969961699954,
           66.03825178102227,
           66.06751923415263,
           66.09678668728299,
           66.12605414041336,
           66.15532159354373,
           66.18458904667409,
           66.21385649980446,
           66.24312395293484,
           66.2723914060652,
           66.30165885919556,
           66.33092631232593,
           66.3601937654563,
           66.38946121858666,
           66.41872867171703,
           66.4479961248474,
           66.47726357797777,
           66.50653103110812,
           66.5357984842385,
           66.56506593736887,
           66.59433339049923,
           66.6236008436296,
           66.65286829675996,
           66.68213574989034,
           66.71140320302071,
           66.74067065615107,
           66.76993810928144,
           66.7992055624118,
           66.82847301554217,
           66.85774046867253,
           66.8870079218029,
           66.91627537493328,
           66.94554282806365,
           66.97481028119401,
           67.00407773432437,
           67.03334518745474,
           67.0033668791701,
           66.96153941860247,
           66.91971195803485,
           66.8778844974672,
           66.83605703689959,
           66.79422957633196,
           66.75240211576433,
           66.71057465519668,
           66.66874719462906,
           66.62691973406142,
           66.5850922734938,
           66.54326481292615,
           66.50143735235852,
           66.45960989179089,
           66.41778243122326,
           66.37595497065564,
           66.334127510088,
           66.29230004952036,
           66.25047258895273,
           66.2086451283851,
           66.16681766781747,
           66.12499020724984,
           66.0831627466822,
           66.04133528611457,
           65.99950782554694,
           65.95768036497931,
           65.91585290441168,
           65.87402544384405,
           65.83219798327642,
           65.79037052270878,
           65.74854306214115,
           65.70671560157352,
           65.66488814100589,
           65.62306068043826,
           65.58123321987063,
           65.51498569823231,
           65.4487381583745,
           65.38249061851668,
           65.31624307865887,
           65.24999553880104,
           65.18374799894322,
           65.1175004590854,
           65.05125291922758,
           64.98500537936977,
           64.91875783951195,
           64.85251029965413,
           64.78626275979632,
           64.72001521993849,
           64.65376768008068,
           64.58752014022285,
           64.52127260036504,
           64.45502506050721,
           64.3887775206494,
           64.32252998079157,
           64.25628244093376,
           64.19003490107593,
           64.12378736121812,
           64.0575398213603,
           63.99129228150248,
           63.925044741644655,
           63.858797201786835,
           63.792549661929016,
           63.7263021220712,
           63.660054582213384,
           63.593807042355564,
           63.52755950249774,
           63.461311962639925,
           63.395064422782106,
           63.328816882924286,
           63.26256934306647,
           63.19632180320864,
           63.13007426335082,
           63.06382672349301,
           62.99757918363518,
           62.93133164377737,
           62.86508410391956,
           62.79883656406173,
           62.732589024203904,
           62.66634148434609,
           62.60009394448827,
           62.53384640463045,
           62.46759886477264,
           62.40135132491481,
           62.006190370465276,
           61.44657270871994,
           60.88695504697458,
           60.32733738522922,
           59.76771972348388,
           59.20810206173849,
           58.64848439999315,
           58.08886673824777,
           57.52924907650241,
           56.969631414757075,
           56.41001375301168,
           55.85039609126635,
           55.290778429520984,
           54.73116076777562,
           54.17154310603027,
           53.611925444284914,
           53.05230778253955,
           52.49269012079418,
           51.933072459048816,
           51.37345479730348,
           50.81383713555812,
           50.25421947381275,
           49.69460181206742,
           49.134984150322026,
           48.57536648857668,
           48.01574882683131,
           47.45613116508595,
           46.896513503340614,
           46.33689584159522,
           45.77727817984989,
           45.21766051810452,
           44.65804285635915,
           44.09842519461382,
           43.538807532868454,
           42.97918987112308,
           42.41957220937772,
           41.859954547632356,
           41.30033688588702,
           40.74071922414165,
           40.18110156239629,
           39.62148390065095,
           39.06186623890558,
           38.502248577160216,
           37.94263091541485,
           37.38301325366949,
           36.823395591924125,
           36.26377793017879,
           35.70416026843342,
           35.14454260668806,
           34.58492494494269,
           34.02530728319733,
           33.465689621451986,
           32.90607195970662,
           32.34645429796126,
           31.786836636215895,
           31.227218974470553,
           30.66760131272519,
           30.10798365097983,
           29.54836598923446,
           28.9887483274891,
           28.429130665743756,
           27.869513003998392,
           27.30989534225303,
           26.74826231236853,
           26.174536993042217,
           25.600811673715885,
           25.027086354389546,
           24.453361035063203,
           23.879635715736867,
           23.305910396410553,
           22.73218507708422,
           22.158459757757882,
           21.584734438431543,
           21.011009119105204,
           20.43728379977889,
           19.863558480452554,
           19.289833161126218,
           18.71610784179988,
           18.14238252247356,
           17.56865720314723,
           16.994931883820893,
           16.421206564494554,
           15.847481245168217,
           15.485439791006781,
           15.335082202010211,
           15.187883513759871,
           15.046686732395472,
           14.905489951031027,
           14.76429316966663,
           14.623096388302232,
           14.481899606937823,
           14.34070282557338,
           14.199506044209029,
           14.058309262844585,
           13.917112481480176,
           13.781441156564542,
           13.648620866073234,
           13.515800575581846,
           13.382980285090502,
           13.250159994599159,
           13.117339704107804,
           12.984519413616463,
           12.851699123125117,
           12.718878832633767,
           12.59156789548706,
           12.466569527735999,
           12.341571159984957,
           12.216572792233915,
           12.091574424482879,
           11.966576056731846,
           11.84157768898077,
           11.716579321229736,
           11.595221416955871,
           11.479336932857972,
           11.363452448760105,
           11.247567964662252,
           11.131683480564384,
           11.015798996466486,
           10.899914512368625,
           10.784030028270765,
           10.674840116719412,
           10.568850796949837,
           10.462861477180258,
           10.356872157410649,
           10.25088283764107,
           10.144893517871495,
           10.03890419810191,
           9.9362519444328,
           9.837264993817556,
           9.738278043202268,
           9.639291092587008,
           9.540304141971754,
           9.441317191356497,
           9.342330240741237,
           9.247207518923597,
           9.153385885349296,
           9.059564251774992,
           8.965742618200684,
           8.87192098462639,
           8.778099351052084,
           8.687212174262028,
           8.599965005739191,
           8.512717837216336,
           8.425470668693492,
           8.338223500170656,
           8.25097633164782,
           8.167418144141548,
           8.087106260274787,
           8.006794376408045,
           7.926482492541297,
           7.846170608674548,
           7.765858724807794,
           7.6915160374066724,
           7.617356801172351,
           7.543197564938034,
           7.469038328703703,
           7.394879092469398,
           7.324698088955078,
           7.255984664610621,
           7.18727124026616,
           7.118557815921734,
           7.049844391577292,
           6.970340202800282,
           6.887893078268916,
           6.805445953737566,
           6.722998829206216,
           6.64055170467485,
           6.5581045801435,
           6.47565745561215,
           6.393210331080788,
           6.310763206549439,
           6.228316082018089,
           6.145868957486723,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           64.58764097700268,
           64.61476255800706,
           64.64188413901144,
           64.66900572001582,
           64.6961273010202,
           64.72324888202458,
           64.75037046302896,
           64.77749204403334,
           64.80461362503773,
           64.83173520604211,
           64.85885678704649,
           64.88597836805087,
           64.91309994905525,
           64.94022153005963,
           64.96734311106403,
           64.9944646920684,
           65.02158627307278,
           65.04870785407716,
           65.07582943508156,
           65.10295101608594,
           65.13007259709032,
           65.1571941780947,
           65.18431575909908,
           65.21143734010346,
           65.23855892110782,
           65.26568050211222,
           65.29280208311661,
           65.31992366412098,
           65.34704524512537,
           65.37416682612975,
           65.40128840713413,
           65.42840998813851,
           65.45553156914289,
           65.48265315014729,
           65.50977473115167,
           65.53689631215605,
           65.56401789316043,
           65.5911394741648,
           65.61826105516919,
           65.64538263617357,
           65.67250421717794,
           65.69962579818234,
           65.72674737918672,
           65.7538689601911,
           65.78099054119548,
           65.80811212219986,
           65.83523370320424,
           65.86235528420862,
           65.889476865213,
           65.91659844621738,
           65.94372002722177,
           65.97084160822615,
           65.99796318923053,
           66.02508477023491,
           66.05220635123929,
           66.07932793224367,
           66.10644951324805,
           66.13357109425243,
           66.16069267525681,
           66.1878142562612,
           66.21493583726559,
           66.24205741826997,
           66.26917899927435,
           66.29630058027874,
           66.32342216128312,
           66.35090138888876,
           66.38016884201913,
           66.4094362951495,
           66.43870374827986,
           66.46797120141024,
           66.4972386545406,
           66.52650610767097,
           66.55577356080133,
           66.5850410139317,
           66.61430846706207,
           66.64357592019243,
           66.6728433733228,
           66.70211082645316,
           66.73137827958354,
           66.7606457327139,
           66.78991318584428,
           66.81918063897464,
           66.848448092105,
           66.87771554523538,
           66.84773723695073,
           66.8059097763831,
           66.76408231581549,
           66.72225485524784,
           66.68042739468021,
           66.63859993411259,
           66.59677247354495,
           66.55494501297731,
           66.51311755240968,
           66.47129009184205,
           66.42946263127442,
           66.38763517070679,
           66.34580771013916,
           66.30398024957152,
           66.26215278900389,
           66.22032532843626,
           66.17849786786863,
           66.136670407301,
           66.08263292127846,
           66.01638538142065,
           65.95013784156284,
           65.88389030170501,
           65.81764276184718,
           65.75139522198937,
           65.68514768213154,
           65.61890014227373,
           65.55265260241592,
           65.48640506255809,
           65.42015752270026,
           65.35390998284245,
           65.28766244298464,
           65.22141490312681,
           65.15516736326899,
           65.08891982341117,
           65.02267228355336,
           64.95642474369554,
           64.89017720383771,
           64.8239296639799,
           64.75768212412208,
           64.69143458426426,
           64.62518704440643,
           64.55893950454862,
           64.4926919646908,
           64.42644442483298,
           64.36019688497515,
           64.29394934511734,
           64.22770180525953,
           64.1614542654017,
           64.09520672554389,
           64.02895918568606,
           63.96271164582825,
           63.89646410597042,
           63.83021656611261,
           63.76396902625479,
           63.69772148639697,
           63.631473946539145,
           63.56522640668133,
           63.498978866823514,
           63.432731326965694,
           63.366483787107875,
           63.300236247250055,
           63.233988707392236,
           63.167741167534416,
           63.101493627676604,
           63.03524608781878,
           62.96899854796096,
           62.90275100810314,
           62.836503468245326,
           62.7702559283875,
           62.70400838852967,
           62.63776084867185,
           62.57151330881404,
           62.50526576895622,
           62.439018229098394,
           62.37277068924058,
           62.30652314938277,
           62.24027560952494,
           62.17402806966712,
           62.107780529809304,
           62.04153298995149,
           61.975285450093665,
           61.909037910235845,
           61.84279037037803,
           61.447629415928496,
           60.88801175418316,
           60.32839409243779,
           59.76877643069243,
           59.2091587689471,
           58.6495411072017,
           58.08992344545636,
           57.530305783711,
           56.97068812196563,
           56.411070460220294,
           55.8514527984749,
           55.29183513672956,
           54.7322174749842,
           54.172599813238826,
           53.6129821514935,
           53.053364489748134,
           52.49374682800276,
           51.9341291662574,
           51.37451150451204,
           50.8148938427667,
           50.25527618102134,
           49.695658519275966,
           49.13604085753063,
           48.576423195785246,
           48.01680553403989,
           47.457187872294526,
           46.89757021054916,
           46.33795254880383,
           45.778334887058435,
           45.2187172253131,
           44.659099563567736,
           44.09948190182237,
           43.53986424007703,
           42.980246578331666,
           42.420628916586296,
           41.86101125484094,
           41.30139359309557,
           40.74177593135023,
           40.18215826960487,
           39.622540607859506,
           39.06292294611416,
           38.50330528436879,
           37.94368762262343,
           37.384069960878065,
           36.8244522991327,
           36.26483463738734,
           35.705216975642,
           35.14559931389664,
           34.585981652151276,
           34.0263639904059,
           33.46674632866055,
           32.9071286669152,
           32.347511005169835,
           31.78789334342447,
           31.22827568167911,
           30.668658019933773,
           30.10904035818841,
           29.549422696443045,
           28.989805034697675,
           28.430187372952314,
           27.870569711206972,
           27.31095204946161,
           26.75133438771624,
           26.191716725970878,
           25.632099064225542,
           25.07248140248017,
           24.512863740734815,
           23.953246078989444,
           23.393628417244088,
           22.834010755498742,
           22.27439309375338,
           21.71477543200801,
           21.15515777026265,
           20.595540108517287,
           20.03592244677194,
           19.476304785026585,
           18.916687144512487,
           18.361819208475154,
           17.806951272437843,
           17.252083336400517,
           16.697215400363184,
           16.142347464325855,
           15.58747952828852,
           15.23944716958771,
           15.098250388223303,
           14.957053606858903,
           14.815856825494505,
           14.67466004413006,
           14.533463262765663,
           14.392266481401267,
           14.251069700036858,
           14.109872918672414,
           13.968676137308062,
           13.835401699842185,
           13.702581409350833,
           13.569761118859454,
           13.436940828368144,
           13.304120537876758,
           13.171300247385414,
           13.03847995689407,
           12.905659666402716,
           12.772839375911374,
           12.647092823303758,
           12.522094455552715,
           12.397096087801671,
           12.272097720050613,
           12.147099352299572,
           12.022100984548528,
           11.897102616797492,
           11.772104249046459,
           11.651841029137072,
           11.535956545039213,
           11.420072060941353,
           11.304187576843454,
           11.188303092745585,
           11.072418608647732,
           10.956534124549865,
           10.840649640451968,
           10.731913146138362,
           10.625923826368785,
           10.519934506599203,
           10.413945186829624,
           10.307955867060048,
           10.201966547290436,
           10.095977227520859,
           9.993160855820403,
           9.894173905205117,
           9.795186954589857,
           9.696200003974608,
           9.597213053359322,
           9.498226102744063,
           9.399239152128809,
           9.30366104970768,
           9.20983941613335,
           9.11601778255905,
           9.02219614898475,
           8.928374515410447,
           8.83455288183614,
           8.74268755293284,
           8.655440384409996,
           8.568193215887153,
           8.480946047364318,
           8.393698878841462,
           8.306451710318619,
           8.22146711674655,
           8.14115523287981,
           8.060843349013078,
           7.980531465146319,
           7.900219581279576,
           7.819907697412827,
           7.743970401788641,
           7.6698111655543295,
           7.595651929320009,
           7.521492693085689,
           7.447333456851371,
           7.375466556119121,
           7.306753131774659,
           7.238039707430233,
           7.169326283085777,
           7.100612858741316,
           7.026013562888218,
           6.943566438356867,
           6.861119313825513,
           6.778672189294147,
           6.696225064762797,
           6.613777940231447,
           6.531330815700082,
           6.448883691168732,
           6.3664365666373826,
           6.28398944210602,
           6.20154231757467,
           6.11909519304332,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           64.46741822521615,
           64.49453980622053,
           64.52166138722491,
           64.54878296822929,
           64.57590454923367,
           64.60302613023805,
           64.63014771124243,
           64.65726929224681,
           64.6843908732512,
           64.71151245425558,
           64.73863403525996,
           64.76575561626434,
           64.79287719726872,
           64.81999877827312,
           64.8471203592775,
           64.87424194028188,
           64.90136352128626,
           64.92848510229064,
           64.95560668329502,
           64.98272826429941,
           65.00984984530378,
           65.03697142630817,
           65.06409300731254,
           65.09121458831693,
           65.11833616932131,
           65.14545775032569,
           65.17257933133007,
           65.19970091233445,
           65.22682249333884,
           65.25394407434321,
           65.2810656553476,
           65.30818723635198,
           65.33530881735636,
           65.36243039836074,
           65.38955197936512,
           65.41667356036952,
           65.4437951413739,
           65.47091672237826,
           65.49803830338266,
           65.52515988438704,
           65.55228146539142,
           65.57940304639581,
           65.60652462740018,
           65.63364620840457,
           65.66076778940894,
           65.68788937041333,
           65.71501095141771,
           65.74213253242209,
           65.76925411342647,
           65.79637569443085,
           65.82349727543524,
           65.85061885643961,
           65.877740437444,
           65.90486201844838,
           65.93198359945276,
           65.95910518045714,
           65.98622676146152,
           66.0133483424659,
           66.04046992347028,
           66.06759150447468,
           66.09471308547906,
           66.12183466648344,
           66.14895624748782,
           66.1760778284922,
           66.20319940949658,
           66.23032099050096,
           66.25744257150535,
           66.28456415250972,
           66.31168573351411,
           66.33880731451849,
           66.36592889552287,
           66.39305047652725,
           66.42017205753164,
           66.44729363853602,
           66.4744152195404,
           66.50153680054478,
           66.52865838154916,
           66.55577996255354,
           66.58290154355792,
           66.6100231245623,
           66.6371447055667,
           66.66426628657106,
           66.69281844988564,
           66.72208590301602,
           66.69210759473138,
           66.65028013416375,
           66.58403260446684,
           66.51778506460901,
           66.45153752475119,
           66.38528998489338,
           66.31904244503555,
           66.25279490517774,
           66.18654736531991,
           66.1202998254621,
           66.05405228560427,
           65.98780474574646,
           65.92155720588863,
           65.85530966603082,
           65.789062126173,
           65.72281458631518,
           65.65656704645735,
           65.59031950659954,
           65.52407196674172,
           65.4578244268839,
           65.39157688702608,
           65.32532934716826,
           65.25908180731044,
           65.19283426745262,
           65.1265867275948,
           65.06033918773699,
           64.99409164787917,
           64.92784410802135,
           64.86159656816353,
           64.79534902830571,
           64.7291014884479,
           64.66285394859007,
           64.59660640873224,
           64.53035886887443,
           64.46411132901662,
           64.39786378915879,
           64.33161624930096,
           64.26536870944315,
           64.19912116958534,
           64.13287362972753,
           64.0666260898697,
           64.00037855001189,
           63.93413101015406,
           63.86788347029624,
           63.80163593043842,
           63.73538839058061,
           63.66914085072278,
           63.602893310864964,
           63.536645771007144,
           63.47039823114932,
           63.404150691291505,
           63.337903151433686,
           63.271655611575866,
           63.205408071718054,
           63.13916053186023,
           63.07291299200241,
           63.00666545214459,
           62.940417912286776,
           62.87417037242895,
           62.80792283257113,
           62.74167529271331,
           62.6754277528555,
           62.60918021299767,
           62.54293267313986,
           62.47668513328205,
           62.41043759342422,
           62.3441900535664,
           62.27794251370858,
           62.211694973850754,
           62.14544743399294,
           62.079199894135115,
           62.012952354277296,
           61.94670481441948,
           61.880457274561664,
           61.81420973470384,
           61.74796219484602,
           61.681714654988205,
           61.615467115130386,
           61.54921957527256,
           61.48297203541475,
           61.41672449555693,
           61.35047695569911,
           61.28422941584129,
           60.88906846139176,
           60.329450799646416,
           59.76983313790105,
           59.21021547615569,
           58.65059781441035,
           58.090980152664955,
           57.53136249091962,
           56.97174482917425,
           56.41687688814969,
           55.86200895211239,
           55.30714101607503,
           54.752273080037725,
           54.197405144000385,
           53.64253720796306,
           53.08766927192576,
           52.53280133588842,
           51.97793339985109,
           51.42306546381376,
           50.868197527776424,
           50.31332959173912,
           49.75846165570179,
           49.20359371966446,
           48.64872578362716,
           48.093857847589796,
           47.538989911552484,
           46.98412197551516,
           46.42925403947783,
           45.87438610344052,
           45.31951816740316,
           44.764650231365856,
           44.20978229532852,
           43.65491435929119,
           43.100046423253886,
           42.54517848721656,
           41.99031055117923,
           41.43544261514189,
           40.88057467910456,
           40.32570674306726,
           39.770838807029925,
           39.21597087099259,
           38.66110293495529,
           38.106234998917955,
           37.55136706288062,
           36.9964991268433,
           36.441631190805964,
           35.886763254768624,
           35.33189531873132,
           34.777027382693994,
           34.22215944665666,
           33.667291510619336,
           33.112423574581996,
           32.55755563854469,
           32.00268770250736,
           31.44781976647003,
           30.8929518304327,
           30.338083894395393,
           29.783215958358063,
           29.22834802232073,
           28.673480086283398,
           28.11861215024607,
           27.563744214208764,
           27.008876278171435,
           26.454008342134102,
           25.89914040609677,
           25.34427247005946,
           24.789404534022133,
           24.2345365979848,
           23.67966866194747,
           23.124800725910134,
           22.56993278987283,
           22.015064853835504,
           21.460196917798168,
           20.90532898176084,
           20.350461045723506,
           19.7955931096862,
           19.240725173648865,
           18.685857237611536,
           18.130989301574203,
           17.576121365536896,
           17.021253429499566,
           16.466385493462237,
           15.911517557424904,
           15.356649621387572,
           15.008617262686757,
           14.867420481322348,
           14.72622369995795,
           14.585026918593552,
           14.443830137229108,
           14.302633355864709,
           14.161436574500312,
           14.02218253361119,
           13.8893622431198,
           13.756541952628499,
           13.623721662137113,
           13.49090137164576,
           13.358081081154381,
           13.225260790663071,
           13.092440500171685,
           12.95962020968034,
           12.827616118871497,
           12.702617751120453,
           12.57761938336942,
           12.452621015618385,
           12.327622647867344,
           12.2026242801163,
           12.077625912365242,
           11.9526275446142,
           11.827629176863157,
           11.708460641318297,
           11.592576157220437,
           11.476691673122566,
           11.360807189024706,
           11.244922704926847,
           11.12903822082895,
           11.013153736731079,
           10.897269252633226,
           10.788986175557346,
           10.682996855787762,
           10.577007536018161,
           10.471018216248583,
           10.365028896479,
           10.259039576709423,
           10.153050256939846,
           10.050069767207974,
           9.95108281659272,
           9.852095865977466,
           9.75310891536218,
           9.654121964746919,
           9.555135014131674,
           9.456148063516387,
           9.360114580491764,
           9.266292946917442,
           9.172471313343145,
           9.078649679768816,
           8.984828046194517,
           8.891006412620216,
           8.798162931603645,
           8.710915763080804,
           8.623668594557971,
           8.53642142603513,
           8.449174257512286,
           8.36192708898945,
           8.275516089351598,
           8.195204205484831,
           8.114892321618088,
           8.034580437751346,
           7.954268553884615,
           7.873956670017856,
           7.7964247661706425,
           7.722265529936322,
           7.648106293701985,
           7.573947057467673,
           7.499787821233352,
           7.426235023283164,
           7.357521598938707,
           7.288808174594282,
           7.220094750249819,
           7.151381325905393,
           7.081686922976172,
           6.9992397984448145,
           6.916792673913457,
           6.834345549382107,
           6.7518984248507525,
           6.669451300319388,
           6.587004175788037,
           6.504557051256687,
           6.422109926725322,
           6.339662802193971,
           6.2572156776626215,
           6.17476855313126,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           64.33355066132931,
           64.36067224233369,
           64.38779382333809,
           64.41491540434245,
           64.44203698534685,
           64.46915856635123,
           64.4962801473556,
           64.52340172835999,
           64.55052330936437,
           64.57764489036875,
           64.60476647137314,
           64.6318880523775,
           64.6590096333819,
           64.68613121438628,
           64.71325279539067,
           64.74037437639505,
           64.76749595739943,
           64.79461753840381,
           64.82173911940819,
           64.84886070041257,
           64.87598228141695,
           64.90310386242133,
           64.93022544342571,
           64.9573470244301,
           64.98446860543447,
           65.01159018643887,
           65.03871176744323,
           65.06583334844763,
           65.09295492945199,
           65.12007651045639,
           65.14719809146077,
           65.17431967246515,
           65.20144125346954,
           65.2285628344739,
           65.2556844154783,
           65.28280599648268,
           65.30992757748706,
           65.33704915849145,
           65.36417073949582,
           65.39129232050021,
           65.4184139015046,
           65.44553548250897,
           65.47265706351335,
           65.49977864451773,
           65.52690022552211,
           65.55402180652649,
           65.58114338753089,
           65.60826496853527,
           65.63538654953965,
           65.66250813054403,
           65.6896297115484,
           65.71675129255279,
           65.74387287355717,
           65.77099445456155,
           65.79811603556593,
           65.82523761657032,
           65.8523591975747,
           65.87948077857908,
           65.90660235958346,
           65.93372394058785,
           65.96084552159223,
           65.98796710259661,
           66.015088683601,
           66.04221026460537,
           66.06933184560975,
           66.09645342661413,
           66.12357500761851,
           66.15069658862289,
           66.17781816962729,
           66.20391332350883,
           66.22898204923662,
           66.25405077496443,
           66.27911950069223,
           66.30418822642004,
           66.32925695214784,
           66.35432567787564,
           66.37939440360344,
           66.40446312933125,
           66.42953185505905,
           66.45460058078686,
           66.47966930651467,
           66.50473803224246,
           66.52980675797026,
           66.55487548369808,
           66.4803124946238,
           66.38582316258913,
           66.29133383055445,
           66.19684449851977,
           66.10235516648508,
           66.0078658344504,
           65.91337650241573,
           65.81888717038105,
           65.72439783834636,
           65.62990850631168,
           65.535419174277,
           65.44092984224233,
           65.34644051020764,
           65.25195117817296,
           65.16216881859224,
           65.09592127873442,
           65.02967373887661,
           64.9634261990188,
           64.89717865916097,
           64.83093111930314,
           64.76468357944533,
           64.69843603958752,
           64.6321884997297,
           64.56594095987187,
           64.49969342001405,
           64.43344588015624,
           64.36719834029842,
           64.30095080044059,
           64.23470326058278,
           64.16845572072495,
           64.10220818086714,
           64.03596064100931,
           63.9697131011515,
           63.90346556129368,
           63.83721802143586,
           63.77097048157804,
           63.70472294172022,
           63.6384754018624,
           63.57222786200458,
           63.50598032214677,
           63.43973278228894,
           63.37348524243113,
           63.3072377025733,
           63.24099016271549,
           63.174742622857664,
           63.108495082999845,
           63.04224754314203,
           62.976000003284206,
           62.909752463426386,
           62.84350492356857,
           62.77725738371075,
           62.711009843852935,
           62.644762303995115,
           62.578514764137296,
           62.51226722427947,
           62.44601968442166,
           62.37977214456383,
           62.31352460470602,
           62.2472770648482,
           62.18102952499038,
           62.11478198513255,
           62.04853444527474,
           61.98228690541693,
           61.9160393655591,
           61.84979182570128,
           61.78354428584346,
           61.71729674598565,
           61.65104920612782,
           61.584801666269996,
           61.518554126412184,
           61.452306586554364,
           61.386059046696545,
           61.31981150683872,
           61.2535639669809,
           61.187316427123086,
           61.12106888726527,
           61.05482134740745,
           60.98857380754963,
           60.92232626769181,
           60.85607872783399,
           60.78983118797617,
           60.72358364811836,
           60.65733610826054,
           60.27529239598243,
           59.73535059749423,
           59.195408799006,
           58.655467000517774,
           58.11552520202959,
           57.57558340354134,
           57.03564160505313,
           56.495699806564915,
           55.95575800807669,
           55.41581620958849,
           54.875874411100234,
           54.33593261261204,
           53.79599081412382,
           53.25604901563559,
           52.71610721714739,
           52.176165418659174,
           51.636223620170945,
           51.09628182168272,
           50.556340023194494,
           50.01639822470629,
           49.476456426218064,
           48.93651462772985,
           48.39657282924165,
           47.856631030753405,
           47.308160004651526,
           46.753292068614186,
           46.19842413257686,
           45.643556196539556,
           45.08868826050219,
           44.5338203244649,
           43.97895238842756,
           43.42408445239022,
           42.86921651635292,
           42.31434858031559,
           41.759480644278256,
           41.20461270824092,
           40.64974477220359,
           40.09487683616629,
           39.54000890012896,
           38.98514096409162,
           38.430273028054316,
           37.87540509201699,
           37.32053715597966,
           36.765669219942325,
           36.21080128390499,
           35.655933347867666,
           35.10106541183036,
           34.54619747579302,
           33.99132953975569,
           33.436461603718364,
           32.88159366768103,
           32.32672573164372,
           31.771857795606394,
           31.21698985956906,
           30.66212192353173,
           30.107253987494424,
           29.552386051457095,
           28.99751811541976,
           28.442650179382433,
           27.8877822433451,
           27.332914307307796,
           26.778046371270463,
           26.22317843523313,
           25.668310499195798,
           25.113442563158493,
           24.55857462712116,
           24.003706691083828,
           23.448838755046502,
           22.89397081900917,
           22.33910288297186,
           21.784234946934532,
           21.2293670108972,
           20.674499074859867,
           20.119631138822534,
           19.56476320278523,
           19.009895266747893,
           18.455027330710568,
           17.90015939467323,
           17.345291458635927,
           16.790423522598598,
           16.23555558656126,
           15.680687650523936,
           15.1258197144866,
           14.77778735578579,
           14.636590574421382,
           14.495393793056984,
           14.354197011692584,
           14.213000230328142,
           14.076143076888792,
           13.94332278639745,
           13.810502495906098,
           13.677682205414712,
           13.54486191492341,
           13.412041624432023,
           13.279221333940672,
           13.146401043449293,
           13.013580752957983,
           12.883141046688216,
           12.758142678937181,
           12.633144311186115,
           12.508145943435071,
           12.383147575684038,
           12.258149207933002,
           12.133150840181958,
           12.008152472430917,
           11.88315410467986,
           11.765080253499535,
           11.649195769401668,
           11.533311285303778,
           11.417426801205917,
           11.301542317108048,
           11.185657833010188,
           11.069773348912328,
           10.953888864814429,
           10.846059204976287,
           10.740069885206719,
           10.634080565437134,
           10.528091245667552,
           10.42210192589795,
           10.316112606128371,
           10.210123286358787,
           10.106978678595548,
           10.007991727980269,
           9.909004777365029,
           9.810017826749776,
           9.711030876134522,
           9.612043925519236,
           9.513056974903975,
           9.416568111275831,
           9.322746477701525,
           9.22892484412722,
           9.135103210552899,
           9.0412815769786,
           8.947459943404272,
           8.853638310274452,
           8.766391141751615,
           8.679143973228772,
           8.59189680470593,
           8.504649636183098,
           8.417402467660256,
           8.330155299137415,
           8.249253178089871,
           8.168941294223128,
           8.088629410356363,
           8.00831752648962,
           7.928005642622877,
           7.848879130552611,
           7.774719894318311,
           7.70056065808398,
           7.626401421849659,
           7.552242185615321,
           7.47808294938101,
           7.40829006610278,
           7.339576641758319,
           7.270863217413861,
           7.202149793069436,
           7.1334363687249756,
           7.054913158532753,
           6.972466034001403,
           6.8900189094700455,
           6.807571784938688,
           6.725124660407339,
           6.6426775358759835,
           6.560230411344619,
           6.477783286813268,
           6.395336162281918,
           6.312889037750553,
           6.230441913219202,
           6.1479947886878525,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           64.19797749551365,
           64.22509907651803,
           64.25222065752241,
           64.2793422385268,
           64.30646381953119,
           64.33358540053555,
           64.36070698153995,
           64.38782856254433,
           64.41495014354871,
           64.44207172455309,
           64.46919330555747,
           64.49631488656185,
           64.52343646756623,
           64.55055804857062,
           64.577679629575,
           64.60480121057938,
           64.63192279158376,
           64.65904437258814,
           64.68616595359254,
           64.7132875345969,
           64.7404091156013,
           64.76753069660568,
           64.79465227761006,
           64.82177385861443,
           64.84889543961881,
           64.87601702062321,
           64.90313860162759,
           64.93026018263195,
           64.95738176363635,
           64.98450334464073,
           65.01162492564511,
           65.03874650664949,
           65.06586808765387,
           65.09298966865826,
           65.12011124966264,
           65.14723283066701,
           65.1743544116714,
           65.20147599267578,
           65.22859757368016,
           65.25571915468454,
           65.28284073568892,
           65.30996231669332,
           65.3370838976977,
           65.36420547870208,
           65.39132705970646,
           65.41844864071084,
           65.44557022171523,
           65.4726918027196,
           65.49981338372399,
           65.52693496472835,
           65.55405654573275,
           65.58117812673713,
           65.60829970774151,
           65.63336843364604,
           65.65843715937385,
           65.68350588510165,
           65.70857461082944,
           65.73364333655725,
           65.75871206228506,
           65.78378078801286,
           65.80884951374065,
           65.83391823946846,
           65.85898696519627,
           65.88405569092407,
           65.90912441665188,
           65.93419314237968,
           65.95926186810749,
           65.9843305938353,
           66.00939931956309,
           66.0344680452909,
           66.0595367710187,
           66.08460549674649,
           66.10967422247431,
           66.1347429482021,
           66.15981167392991,
           66.18488039965771,
           66.20994912538552,
           66.23501785111333,
           66.26008657684113,
           66.28515530256892,
           66.31022402829674,
           66.33529275402454,
           66.36036147975234,
           66.38543020548015,
           66.31086721640587,
           66.2163778843712,
           66.12188855233651,
           66.02739922030183,
           65.93290988826716,
           65.83842055623248,
           65.7439312241978,
           65.64944189216311,
           65.55495256012844,
           65.46046322809374,
           65.36597389605907,
           65.27148456402439,
           65.17699523198972,
           65.08250589995504,
           64.98801656792035,
           64.89352723588567,
           64.799037903851,
           64.70454857181632,
           64.61005923978163,
           64.51556990774695,
           64.42108057571227,
           64.3265912436776,
           64.23210191164291,
           64.13761257960823,
           64.04312324757355,
           63.94863391553888,
           63.854144583504194,
           63.75965525146951,
           63.665165919434834,
           63.57067658740015,
           63.476187255365474,
           63.40052578721328,
           63.33427824735546,
           63.268030707497644,
           63.20178316763983,
           63.135535627782005,
           63.069288087924186,
           63.003040548066366,
           62.936793008208554,
           62.870545468350734,
           62.80429792849291,
           62.738050388635095,
           62.67180284877727,
           62.60555530891945,
           62.53930776906164,
           62.47306022920381,
           62.406812689346,
           62.34056514948817,
           62.27431760963036,
           62.20807006977253,
           62.14182252991472,
           62.0755749900569,
           62.00932745019908,
           61.94307991034127,
           61.87683237048344,
           61.81058483062562,
           61.7443372907678,
           61.67808975090999,
           61.61184221105216,
           61.545594671194344,
           61.47934713133652,
           61.41309959147871,
           61.346852051620886,
           61.280604511763066,
           61.21435697190525,
           61.148109432047434,
           61.081861892189615,
           61.015614352331795,
           60.94936681247397,
           60.88311927261615,
           60.81687173275833,
           60.75062419290052,
           60.68437665304269,
           60.618129113184864,
           60.55188157332705,
           60.48563403346923,
           60.41938649361141,
           60.3531389537536,
           60.28689141389577,
           60.22064387403796,
           60.154396334180134,
           60.08814879432232,
           60.0219012544645,
           59.63985754218639,
           59.09991574369819,
           58.55997394520997,
           58.02003214672174,
           57.48009034823355,
           56.9401485497453,
           56.400206751257095,
           55.86026495276887,
           55.32032315428065,
           54.78038135579245,
           54.2404395573042,
           53.700497758816,
           53.160555960327784,
           52.620614161839555,
           52.080672363351354,
           51.54073056486313,
           51.0007887663749,
           50.46084696788668,
           49.92090516939845,
           49.38096337091026,
           48.84102157242202,
           48.30107977393381,
           47.76113797544561,
           47.22119617695736,
           46.68125437846916,
           46.141312579980934,
           45.60137078149271,
           45.06142898300452,
           44.52148718451626,
           43.981545386028074,
           43.44160358753983,
           42.901661789051616,
           42.361719990563415,
           41.821778192075186,
           41.28183639358697,
           40.74189459509874,
           40.20195279661053,
           39.66201099812233,
           39.1220691996341,
           38.58212740114587,
           38.04218560265767,
           37.502243804169446,
           36.962302005681224,
           36.422360207192995,
           35.88241840870477,
           35.34247661021655,
           34.80253481172835,
           34.26259301324013,
           33.7226512147519,
           33.18270941626368,
           32.64276761777545,
           32.09589582474275,
           31.541027888705425,
           30.98615995266809,
           30.431292016630763,
           29.876424080593452,
           29.321556144556126,
           28.76668820851879,
           28.211820272481454,
           27.65695233644413,
           27.102084400406824,
           26.547216464369495,
           25.992348528332162,
           25.437480592294825,
           24.882612656257518,
           24.327744720220192,
           23.77287678418286,
           23.21800884814553,
           22.663140912108194,
           22.108272976070886,
           21.55340504003356,
           20.998537103996227,
           20.443669167958898,
           19.888801231921562,
           19.333933295884258,
           18.779065359846925,
           18.2241974238096,
           17.66932948777226,
           17.114461551734955,
           16.559593615697626,
           16.004725679660293,
           15.449857743622967,
           14.894989807585631,
           14.54695744888482,
           14.405760667520413,
           14.264563886156013,
           14.130103620166398,
           13.997283329675048,
           13.8644630391837,
           13.731642748692359,
           13.598822458201008,
           13.46600216770962,
           13.333181877218319,
           13.20036158672693,
           13.06754129623558,
           12.938665974504906,
           12.813667606753873,
           12.688669239002827,
           12.563670871251793,
           12.438672503500728,
           12.313674135749682,
           12.188675767998651,
           12.063677400247615,
           11.938679032496573,
           11.821699865680735,
           11.705815381582884,
           11.589930897485013,
           11.474046413387146,
           11.358161929289256,
           11.242277445191394,
           11.126392961093526,
           11.010508476995666,
           10.90313223439527,
           10.797142914625686,
           10.691153594856074,
           10.585164275086504,
           10.479174955316921,
           10.373185635547337,
           10.267196315777735,
           10.163887589983114,
           10.064900639367853,
           9.9659136887526,
           9.866926738137321,
           9.767939787522081,
           9.66895283690683,
           9.569965886291575,
           9.473021642059882,
           9.379200008485578,
           9.285378374911284,
           9.191556741336978,
           9.097735107762674,
           9.003913474188352,
           8.910091840614054,
           8.821866520422432,
           8.734619351899577,
           8.64737218337674,
           8.560125014853897,
           8.472877846331055,
           8.385630677808223,
           8.30330215069491,
           8.222990266828143,
           8.142678382961401,
           8.062366499094658,
           7.9820546152278915,
           7.901742731361148,
           7.827174258700268,
           7.753015022465946,
           7.678855786231647,
           7.604696549997314,
           7.530537313762994,
           7.459058533266816,
           7.3903451089223795,
           7.321631684577934,
           7.252918260233473,
           7.184204835889016,
           7.110586518620697,
           7.028139394089342,
           6.945692269557986,
           6.863245145026635,
           6.780798020495277,
           6.69835089596392,
           6.61590377143257,
           6.5334566469012145,
           6.45100952236985,
           6.3685623978385,
           6.28611527330715,
           6.203668148775785,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           64.062404329698,
           64.08952591070239,
           64.11664749170676,
           64.14376907271114,
           64.17089065371553,
           64.1980122347199,
           64.22513381572429,
           64.25225539672867,
           64.27937697773305,
           64.30649855873745,
           64.33362013974183,
           64.3607417207462,
           64.38786330175058,
           64.41498488275496,
           64.44210646375934,
           64.46922804476372,
           64.4963496257681,
           64.5234712067725,
           64.55059278777688,
           64.57771436878126,
           64.60483594978564,
           64.63195753079003,
           64.6590791117944,
           64.68620069279878,
           64.71332227380316,
           64.74044385480755,
           64.76756543581192,
           64.79468701681631,
           64.82180859782069,
           64.84893017882507,
           64.87605175982945,
           64.90317334083383,
           64.93029492183823,
           64.95741650284259,
           64.98453808384699,
           65.01165966485136,
           65.03775481805546,
           65.06282354378327,
           65.08789226951107,
           65.11296099523888,
           65.13802972096667,
           65.16309844669448,
           65.18816717242228,
           65.21323589815009,
           65.2383046238779,
           65.2633733496057,
           65.2884420753335,
           65.3135108010613,
           65.3385795267891,
           65.36364825251691,
           65.38871697824472,
           65.41378570397252,
           65.43885442970031,
           65.46392315542812,
           65.48899188115593,
           65.51406060688373,
           65.53912933261154,
           65.56419805833934,
           65.58926678406715,
           65.61433550979496,
           65.63940423552275,
           65.66447296125057,
           65.68954168697836,
           65.71461041270615,
           65.73967913843397,
           65.76474786416178,
           65.78981658988958,
           65.81488531561737,
           65.83995404134518,
           65.86502276707299,
           65.89009149280079,
           65.91516021852858,
           65.9402289442564,
           65.9652976699842,
           65.990366395712,
           66.01543512143981,
           66.04050384716761,
           66.06557257289542,
           66.09064129862323,
           66.11571002435102,
           66.14077875007882,
           66.16584747580664,
           66.19091620153444,
           66.21598492726223,
           66.14142193818797,
           66.04693260615328,
           65.95244327411861,
           65.85795394208394,
           65.76346461004924,
           65.66897527801457,
           65.57448594597989,
           65.4799966139452,
           65.38550728191053,
           65.29101794987584,
           65.19652861784117,
           65.1020392858065,
           65.0075499537718,
           64.91306062173713,
           64.81857128970245,
           64.72408195766778,
           64.6295926256331,
           64.53510329359841,
           64.44061396156371,
           64.34612462952906,
           64.25163529749437,
           64.15714596545969,
           64.06265663342501,
           63.96816730139033,
           63.87367796935565,
           63.77918863732097,
           63.68469930528628,
           63.59020997325162,
           63.495720641216934,
           63.40123130918225,
           63.30674197714757,
           63.21225264511288,
           63.11776331307821,
           63.02327398104353,
           62.92878464900885,
           62.83429531697417,
           62.73980598493948,
           62.64531665290481,
           62.55082732087013,
           62.45633798883544,
           62.36184865680076,
           62.26735932476609,
           62.17286999273141,
           62.07838066069672,
           61.98389132866204,
           61.88940199662736,
           61.79491266459269,
           61.70513029569218,
           61.638882755834366,
           61.57263521597655,
           61.50638767611873,
           61.44014013626091,
           61.37389259640308,
           61.30764505654526,
           61.24139751668745,
           61.17514997682963,
           61.1089024369718,
           61.04265489711399,
           60.97640735725617,
           60.91015981739835,
           60.84391227754053,
           60.77766473768271,
           60.711417197824886,
           60.645169657967074,
           60.578922118109254,
           60.512674578251435,
           60.44642703839362,
           60.380179498535796,
           60.313931958677976,
           60.24768441882016,
           60.18143687896234,
           60.11518933910452,
           60.0489417992467,
           59.98269425938888,
           59.916446719531066,
           59.85019917967324,
           59.78395163981543,
           59.7177040999576,
           59.65145656009978,
           59.58520902024196,
           59.51896148038415,
           59.45271394052632,
           59.38646640066851,
           59.004422688390406,
           58.46448088990221,
           57.92453909141398,
           57.38459729292576,
           56.84465549443756,
           56.30471369594931,
           55.7647718974611,
           55.22483009897289,
           54.68488830048466,
           54.14494650199646,
           53.605004703508214,
           53.065062905020014,
           52.525121106531785,
           51.98517930804356,
           51.44523750955537,
           50.90529571106714,
           50.36535391257891,
           49.82541211409069,
           49.28547031560247,
           48.745528517114266,
           48.20558671862604,
           47.66564492013782,
           47.12570312164962,
           46.58576132316138,
           46.04581952467318,
           45.50587772618494,
           44.96593592769672,
           44.425994129208526,
           43.886052330720275,
           43.346110532232075,
           42.806168733743846,
           42.26622693525563,
           41.72628513676743,
           41.1863433382792,
           40.646401539790986,
           40.10645974130275,
           39.566517942814535,
           39.026576144326334,
           38.4866343458381,
           37.946692547349876,
           37.40675074886168,
           36.86680895037345,
           36.32686715188523,
           35.78692535339701,
           35.24698355490878,
           34.70704175642056,
           34.16709995793236,
           33.627158159444136,
           33.087216360955914,
           32.54727456246769,
           32.00733276397946,
           31.467390965491266,
           30.92744916700304,
           30.387507368514814,
           29.84756557002659,
           29.307623771538392,
           28.767681973050166,
           28.227740174561944,
           27.687798376073715,
           27.147856577585497,
           26.607914779097293,
           26.06797298060907,
           25.52803118212085,
           24.988089383632623,
           24.448147585144426,
           23.9082057866562,
           23.36826398816798,
           22.828322189679753,
           22.288380391191527,
           21.74843859270333,
           21.208496794215105,
           20.66855499572688,
           20.128613197238657,
           19.58867139875043,
           19.048729600262234,
           18.50878780177401,
           17.968846003285783,
           17.42890420479756,
           16.883631644834004,
           16.328763708796675,
           15.77389577275934,
           15.219027836722015,
           14.664159900684679,
           14.316884453935403,
           14.184064163444015,
           14.051243872952705,
           13.918423582461324,
           13.785603291969974,
           13.652783001478628,
           13.519962710987285,
           13.387142420495936,
           13.254322130004546,
           13.121501839513245,
           12.994190902321646,
           12.869192534570573,
           12.744194166819536,
           12.619195799068503,
           12.49419743131746,
           12.369199063566425,
           12.244200695815358,
           12.119202328064315,
           11.994203961959855,
           11.878319477861996,
           11.762434993764128,
           11.64655050966623,
           11.530666025568376,
           11.414781541470509,
           11.29889705737264,
           11.18301257327475,
           11.06712808917689,
           10.960205263814222,
           10.854215944044645,
           10.748226624275068,
           10.642237304505484,
           10.536247984735873,
           10.430258664966301,
           10.324269345196718,
           10.220796501370712,
           10.121809550755456,
           10.022822600140177,
           9.923835649524918,
           9.824848698909664,
           9.725861748294385,
           9.626874797679147,
           9.529475172843954,
           9.435653539269655,
           9.341831905695349,
           9.248010272121045,
           9.15418863854675,
           9.060367004972443,
           8.966545371398139,
           8.877341899093244,
           8.790094730570408,
           8.702847562047566,
           8.61560039352471,
           8.528353225001872,
           8.44110605647903,
           8.357351123299932,
           8.277039239433194,
           8.196727355566447,
           8.11641547169968,
           8.036103587832939,
           7.955791703966195,
           7.879628623082259,
           7.805469386847943,
           7.731310150613611,
           7.657150914379289,
           7.582991678144991,
           7.509827000430869,
           7.441113576086408,
           7.372400151741976,
           7.303686727397539,
           7.234973303053095,
           7.166259878708633,
           7.083812754177297,
           7.001365629645941,
           6.918918505114585,
           6.8364713805832285,
           6.754024256051878,
           6.67157713152052,
           6.589130006989162,
           6.506682882457813,
           6.424235757926459,
           6.341788633395093,
           6.259341508863743,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           63.92683116388234,
           63.95395274488672,
           63.98107432589111,
           64.00819590689548,
           64.03531748789987,
           64.06243906890425,
           64.08956064990863,
           64.11668223091301,
           64.1438038119174,
           64.17092539292177,
           64.19804697392615,
           64.22516855493055,
           64.25229013593493,
           64.27941171693931,
           64.30653329794369,
           64.33365487894807,
           64.36077645995245,
           64.38789804095683,
           64.41501962196122,
           64.44214120246488,
           64.46720992819269,
           64.49227865392048,
           64.51734737964829,
           64.54241610537609,
           64.5674848311039,
           64.5925535568317,
           64.61762228255951,
           64.6426910082873,
           64.66775973401512,
           64.69282845974291,
           64.71789718547072,
           64.74296591119852,
           64.76803463692633,
           64.79310336265414,
           64.81817208838194,
           64.84324081410975,
           64.86830953983754,
           64.89337826556535,
           64.91844699129315,
           64.94351571702094,
           64.96858444274875,
           64.99365316847656,
           65.01872189420436,
           65.04379061993217,
           65.06885934565997,
           65.09392807138778,
           65.11899679711559,
           65.14406552284339,
           65.16913424857118,
           65.19420297429899,
           65.2192717000268,
           65.2443404257546,
           65.2694091514824,
           65.2944778772102,
           65.319546602938,
           65.34461532866581,
           65.36968405439362,
           65.39475278012142,
           65.41982150584923,
           65.44489023157703,
           65.46995895730484,
           65.49502768303263,
           65.52009640876045,
           65.54516513448824,
           65.57023386021605,
           65.59530258594386,
           65.62037131167165,
           65.64544003739947,
           65.67050876312726,
           65.69557748885506,
           65.72064621458287,
           65.74571494031068,
           65.77078366603848,
           65.79585239176627,
           65.82092111749408,
           65.84598984322189,
           65.87105856894969,
           65.8961272946775,
           65.9211960204053,
           65.94626474613311,
           65.97133347186092,
           65.99640219758871,
           66.02147092331651,
           66.04653964904432,
           65.97197665997004,
           65.87748732793537,
           65.78299799590069,
           65.688508663866,
           65.59401933183133,
           65.49952999979665,
           65.40504066776197,
           65.31055133572728,
           65.21606200369261,
           65.12157267165793,
           65.02708333962326,
           64.93259400758856,
           64.8381046755539,
           64.74361534351921,
           64.64912601148453,
           64.55463667944984,
           64.46014734741516,
           64.36565801538049,
           64.2711686833458,
           64.17667935131112,
           64.08219001927645,
           63.98770068724177,
           63.893211355207086,
           63.7987220231724,
           63.70423269113772,
           63.60974335910305,
           63.51525402706836,
           63.42076469503368,
           63.326275362999006,
           63.23178603096432,
           63.137296698929646,
           63.04280736689496,
           62.94831803486028,
           62.85382870282561,
           62.759339370790926,
           62.66485003875624,
           62.57036070672156,
           62.47587137468688,
           62.381382042652206,
           62.28689271061752,
           62.19240337858284,
           62.09791404654817,
           62.003424714513486,
           61.9089353824788,
           61.81444605044412,
           61.71995671840944,
           61.625467386374766,
           61.53097805434008,
           61.436488722305405,
           61.341999390270715,
           61.24751005823604,
           61.15302072620136,
           61.05853139416668,
           60.964042062132,
           60.86955273009732,
           60.77506339806264,
           60.68057406602796,
           60.586084733993275,
           60.4915954019586,
           60.39710606992392,
           60.30261673788924,
           60.208127405854555,
           60.11363807381988,
           60.0191487417852,
           59.94348726431322,
           59.8772397244554,
           59.81099218459759,
           59.744744644739754,
           59.67849710488194,
           59.61224956502412,
           59.5460020251663,
           59.47975448530849,
           59.41350694545066,
           59.347259405592844,
           59.281011865735024,
           59.21476432587721,
           59.148516786019385,
           59.082269246161566,
           59.016021706303746,
           58.94977416644593,
           58.88352662658811,
           58.817279086730295,
           58.751031546872476,
           58.368987834594364,
           57.82904603610617,
           57.28910423761794,
           56.74916243912972,
           56.20922064064152,
           55.66927884215327,
           55.12933704366507,
           54.589395245176846,
           54.049453446688624,
           53.50951164820042,
           52.969569849712165,
           52.42962805122397,
           51.88968625273575,
           51.34974445424752,
           50.80980265575933,
           50.2698608572711,
           49.729919058782876,
           49.189977260294654,
           48.650035461806425,
           48.11009366331823,
           47.57015186483,
           47.03021006634178,
           46.49026826785358,
           45.950326469365336,
           45.410384670877136,
           44.8704428723889,
           44.33050107390069,
           43.79055927541249,
           43.25061747692423,
           42.71067567843603,
           42.17073387994781,
           41.63079208145959,
           41.09085028297139,
           40.55090848448316,
           40.010966685994944,
           39.47102488750671,
           38.93108308901849,
           38.39114129053029,
           37.85119949204206,
           37.31125769355384,
           36.77131589506564,
           36.23137409657742,
           35.69143229808919,
           35.15149049960097,
           34.611548701112746,
           34.07160690262452,
           33.53166510413632,
           32.991723305648094,
           32.452898126894034,
           31.92300584963554,
           31.393113572377036,
           30.863221295118564,
           30.333329017860063,
           29.803436740601562,
           29.273544463343065,
           28.74365218608459,
           28.213759908826084,
           27.683867631567587,
           27.15397535430909,
           26.624083077050592,
           26.094190799792116,
           25.564298522533612,
           25.034406245275115,
           24.504513968016617,
           23.974621690758138,
           23.44472941349964,
           22.91483713624114,
           22.38494485898264,
           21.85505258172414,
           21.32516030446567,
           20.795268027207168,
           20.265375749948664,
           19.735483472690166,
           19.205591195431666,
           18.67569891817319,
           18.145806640914692,
           17.61591436365619,
           17.086022086397694,
           16.556129809139218,
           16.026237531880717,
           15.496345254622218,
           14.96645297736372,
           14.436560700105218,
           14.105204416230313,
           13.972384125738925,
           13.839563835247617,
           13.706743544756236,
           13.573923254264885,
           13.44110296377354,
           13.308282673282196,
           13.175462382790846,
           13.049715830138327,
           12.924717462387305,
           12.799719094636261,
           12.674720726885184,
           12.54972235913415,
           12.424723991383116,
           12.299725623632074,
           12.174727255881038,
           12.050823574141067,
           11.934939090043198,
           11.819054605945336,
           11.703170121847478,
           11.587285637749607,
           11.47140115365171,
           11.355516669553857,
           11.239632185455989,
           11.123747701358122,
           11.017278293233172,
           10.911288973463595,
           10.805299653694009,
           10.699310333924434,
           10.593321014154856,
           10.48733169438527,
           10.381342374615661,
           10.277705412758314,
           10.178718462143028,
           10.079731511527767,
           9.980744560912512,
           9.881757610297234,
           9.782770659681972,
           9.683783709066718,
           9.585928703628039,
           9.49210707005371,
           9.39828543647941,
           9.30446380290511,
           9.210642169330804,
           9.1168205357565,
           9.022998902182206,
           8.932817277764048,
           8.845570109241208,
           8.75832294071837,
           8.671075772195532,
           8.583828603672693,
           8.496581435149837,
           8.411400095904977,
           8.33108821203821,
           8.250776328171463,
           8.170464444304725,
           8.090152560437978,
           8.00984067657121,
           7.932082987464233,
           7.857923751229916,
           7.783764514995596,
           7.709605278761279,
           7.635446042526947,
           7.561286806292626,
           7.491882043250465,
           7.423168618906024,
           7.354455194561563,
           7.2857417702171325,
           7.217028345872695,
           7.139486114265237,
           7.057038989733879,
           6.9745918652025285,
           6.8921447406711716,
           6.809697616139817,
           6.72725049160846,
           6.64480336707711,
           6.562356242545752,
           6.479909118014395,
           6.397461993483045,
           6.31501486895169,
           6.232567744420324,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           63.79125799806668,
           63.81837957907106,
           63.84550116007544,
           63.871596312602094,
           63.8966650383299,
           63.921733764057706,
           63.94680248978551,
           63.97187121551331,
           63.996939941241116,
           64.02200866696892,
           64.04707739269672,
           64.07214611842453,
           64.09721484415232,
           64.12228356988014,
           64.14735229560793,
           64.17242102133575,
           64.19748974706354,
           64.22255847279135,
           64.24762719851915,
           64.27269592424696,
           64.29776464997477,
           64.32283337570256,
           64.34790210143036,
           64.37297082715816,
           64.39803955288598,
           64.42310827861378,
           64.44817700434157,
           64.47324573006938,
           64.49831445579719,
           64.52338318152499,
           64.5484519072528,
           64.5735206329806,
           64.59858935870841,
           64.62365808443622,
           64.648726810164,
           64.67379553589183,
           64.69886426161962,
           64.72393298734742,
           64.74900171307522,
           64.77407043880302,
           64.79913916453083,
           64.82420789025863,
           64.84927661598644,
           64.87434534171425,
           64.89941406744205,
           64.92448279316986,
           64.94955151889765,
           64.97462024462547,
           64.99968897035326,
           65.02475769608107,
           65.04982642180887,
           65.07489514753667,
           65.09996387326449,
           65.12503259899228,
           65.15010132472008,
           65.17517005044789,
           65.2002387761757,
           65.2253075019035,
           65.2503762276313,
           65.2754449533591,
           65.30051367908692,
           65.32558240481471,
           65.35065113054252,
           65.37571985627032,
           65.40078858199813,
           65.42585730772593,
           65.45092603345373,
           65.47599475918153,
           65.50106348490934,
           65.52613221063714,
           65.55120093636495,
           65.57626966209276,
           65.60133838782055,
           65.62640711354835,
           65.65147583927616,
           65.67654456500397,
           65.70161329073177,
           65.72668201645958,
           65.75175074218738,
           65.77681946791517,
           65.80188819364298,
           65.82695691937079,
           65.85202564509858,
           65.8770943708264,
           65.80253138175213,
           65.70804204971745,
           65.61355271768277,
           65.5190633856481,
           65.4245740536134,
           65.33008472157873,
           65.23559538954405,
           65.14110605750938,
           65.04661672547468,
           64.95212739344001,
           64.85763806140532,
           64.76314872937064,
           64.66865939733597,
           64.57417006530127,
           64.4796807332666,
           64.38519140123192,
           64.29070206919725,
           64.19621273716257,
           64.10172340512788,
           64.0072340730932,
           63.91274474105853,
           63.81825540902384,
           63.723766076989165,
           63.62927674495449,
           63.534787412919805,
           63.44029808088512,
           63.345808748850445,
           63.25131941681576,
           63.15683008478109,
           63.062340752746394,
           62.967851420711725,
           62.87336208867704,
           62.778872756642365,
           62.68438342460769,
           62.589894092573005,
           62.49540476053832,
           62.40091542850364,
           62.30642609646897,
           62.211936764434284,
           62.11744743239961,
           62.02295810036492,
           61.92846876833025,
           61.83397943629555,
           61.73949010426088,
           61.6450007722262,
           61.550511440191514,
           61.45602210815684,
           61.36153277612215,
           61.26704344408748,
           61.172554112052794,
           61.07806478001811,
           60.98357544798344,
           60.88908611594875,
           60.79459678391408,
           60.70010745187939,
           60.60561811984472,
           60.51112878781004,
           60.41663945577535,
           60.32215012374067,
           60.227660791706,
           60.13317145967131,
           60.03868212763663,
           59.94419279560195,
           59.84970346356728,
           59.7552141315326,
           59.66072479949791,
           59.56623546746324,
           59.47174613542855,
           59.37725680339387,
           59.28276747135919,
           59.1882781393245,
           59.09378880728983,
           58.99929947525515,
           58.90481014322047,
           58.8103208111858,
           58.715831479151106,
           58.62134214711643,
           58.52685281508175,
           58.43236348304707,
           58.33787415101239,
           58.24809177279207,
           58.18184423293425,
           58.115596693076434,
           57.73355298079833,
           57.193611182310136,
           56.65366938382191,
           56.11372758533368,
           55.57378578684548,
           55.03384398835723,
           54.496693734045714,
           53.966801456787216,
           53.43690917952872,
           52.907016902270236,
           52.37712462501172,
           51.84723234775324,
           51.317340070494744,
           50.78744779323624,
           50.257555515977764,
           49.72766323871926,
           49.19777096146077,
           48.667878684202265,
           48.13798640694376,
           47.60809412968529,
           47.078201852426794,
           46.54830957516829,
           46.018417297909814,
           45.48852502065129,
           44.95863274339282,
           44.42874046613432,
           43.898848188875824,
           43.36895591161735,
           42.839063634358816,
           42.30917135710034,
           41.77927907984185,
           41.249386802583345,
           40.71949452532487,
           40.189602248066365,
           39.659709970807874,
           39.12981769354937,
           38.59992541629087,
           38.07003313903239,
           37.54014086177389,
           37.010248584515395,
           36.480356307256926,
           35.95046402999842,
           35.420571752739924,
           34.89067947548142,
           34.36078719822292,
           33.83089492096442,
           33.30100264370594,
           32.771110366447445,
           32.24121808918895,
           31.71132581193045,
           31.181433534671946,
           30.65154125741347,
           30.121648980154973,
           29.591756702896475,
           29.061864425637975,
           28.531972148379502,
           28.002079871120998,
           27.4721875938625,
           26.942295316604,
           26.4124030393455,
           25.882510762087026,
           25.352618484828525,
           24.822726207570025,
           24.292833930311524,
           23.762941653053048,
           23.23304937579455,
           22.703157098536053,
           22.17326482127755,
           21.64337254401905,
           21.113480266760575,
           20.583587989502078,
           20.053695712243577,
           19.523803434985076,
           18.99391115772658,
           18.464018880468103,
           17.934126603209602,
           17.4042343259511,
           16.8743420486926,
           16.344449771434128,
           15.814557494175627,
           15.284665216917126,
           14.75477293965863,
           14.224880662400128,
           13.893524378525223,
           13.760704088033837,
           13.627883797542527,
           13.495063507051148,
           13.362243216559797,
           13.230239125706095,
           13.105240757955029,
           12.980242390203985,
           12.855244022452942,
           12.730245654701916,
           12.605247286950874,
           12.480248919199799,
           12.355250551448764,
           12.230252183697731,
           12.107443186322271,
           11.991558702224438,
           11.875674218126548,
           11.759789734028677,
           11.643905249930818,
           11.52802076583296,
           11.412136281735089,
           11.296251797637192,
           11.180367313539339,
           11.074351322652118,
           10.968362002882534,
           10.862372683112957,
           10.75638336334338,
           10.650394043573796,
           10.544404723804218,
           10.438415404034643,
           10.334614324145852,
           10.235627373530612,
           10.136640422915365,
           10.03765347230008,
           9.93866652168482,
           9.839679571069563,
           9.740692620454286,
           9.642382234412112,
           9.548560600837792,
           9.454738967263495,
           9.360917333689164,
           9.267095700114865,
           9.173274066540566,
           9.07945243296626,
           8.988292656434867,
           8.901045487912038,
           8.813798319389175,
           8.726551150866332,
           8.639303982343495,
           8.552056813820657,
           8.465449068509992,
           8.385137184643249,
           8.304825300776505,
           8.22451341690974,
           8.144201533042992,
           8.063889649176254,
           7.984537351846223,
           7.910378115611885,
           7.83621887937757,
           7.762059643143252,
           7.687900406908932,
           7.613741170674615,
           7.542650510414522,
           7.473937086070062,
           7.4052236617256195,
           7.336510237381178,
           7.267796813036717,
           7.195159474353176,
           7.112712349821834,
           7.030265225290468,
           6.94781810075911,
           6.86537097622776,
           6.782923851696403,
           6.700476727165048,
           6.618029602633691,
           6.5355824781023415,
           6.453135353570982,
           6.370688229039626,
           6.288241104508276,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           63.6380262142797,
           63.663094940007504,
           63.6881636657353,
           63.71323239146311,
           63.738301117190915,
           63.76336984291871,
           63.78843856864653,
           63.81350729437432,
           63.83857602010213,
           63.86364474582993,
           63.88871347155774,
           63.913782197285535,
           63.93885092301334,
           63.96391964874115,
           63.98898837446895,
           64.01405710019675,
           64.03912582592456,
           64.06419455165236,
           64.08926327738016,
           64.11433200310798,
           64.13940072883577,
           64.16446945456357,
           64.18953818029138,
           64.21460690601918,
           64.23967563174699,
           64.2647443574748,
           64.2898130832026,
           64.3148818089304,
           64.33995053465821,
           64.365019260386,
           64.3900879861138,
           64.41515671184162,
           64.44022543756941,
           64.46529416329723,
           64.49036288902502,
           64.51543161475283,
           64.54050034048063,
           64.56556906620844,
           64.59063779193625,
           64.61570651766404,
           64.64077524339186,
           64.66584396911966,
           64.69091269484746,
           64.71598142057525,
           64.74105014630305,
           64.76611887203086,
           64.79118759775866,
           64.81625632348647,
           64.84132504921428,
           64.86639377494208,
           64.89146250066989,
           64.9165312263977,
           64.9415999521255,
           64.9666686778533,
           64.99173740358111,
           65.0168061293089,
           65.0418748550367,
           65.06694358076452,
           65.09201230649231,
           65.11708103222011,
           65.14214975794792,
           65.16721848367573,
           65.19228720940353,
           65.21735593513134,
           65.24242466085914,
           65.26749338658695,
           65.29256211231476,
           65.31763083804255,
           65.34269956377035,
           65.36776828949814,
           65.39142152501316,
           65.41479166365541,
           65.43816180229766,
           65.4615319409399,
           65.48490207958216,
           65.5082722182244,
           65.53164235686666,
           65.5550124955089,
           65.57838263415115,
           65.6017527727934,
           65.62512291143565,
           65.6484930500779,
           65.67186318872015,
           65.6952333273624,
           65.59497318431292,
           65.4699869849251,
           65.34500078553727,
           65.22001458614943,
           65.09502838676161,
           64.97004218737379,
           64.84505598798597,
           64.72006978859814,
           64.59508358921032,
           64.47009738982248,
           64.34511119043466,
           64.22012499104683,
           64.09513879165901,
           63.97015259227118,
           63.87058043150844,
           63.77609109947376,
           63.68160176743907,
           63.58711243540439,
           63.492623103369716,
           63.398133771335026,
           63.30364443930035,
           63.20915510726567,
           63.114665775230996,
           63.02017644319632,
           62.92568711116163,
           62.83119777912695,
           62.73670844709227,
           62.64221911505759,
           62.547729783022916,
           62.453240450988226,
           62.35875111895355,
           62.26426178691887,
           62.16977245488419,
           62.07528312284951,
           61.98079379081483,
           61.88630445878015,
           61.791815126745476,
           61.697325794710785,
           61.60283646267611,
           61.50834713064143,
           61.413857798606756,
           61.31936846657207,
           61.22487913453739,
           61.13038980250271,
           61.03590047046802,
           60.94141113843335,
           60.84692180639867,
           60.752432474363985,
           60.65794314232931,
           60.56345381029463,
           60.46896447825995,
           60.374475146225265,
           60.279985814190596,
           60.18549648215591,
           60.09100715012123,
           59.996517818086545,
           59.90202848605187,
           59.80753915401719,
           59.71304982198251,
           59.618560489947825,
           59.52407115791315,
           59.42958182587847,
           59.33509249384379,
           59.240603161809105,
           59.14611382977443,
           59.051624497739745,
           58.95713516570507,
           58.86264583367039,
           58.768156501635694,
           58.673667169601025,
           58.57917783756634,
           58.484688505531665,
           58.39019917349698,
           58.2957098414623,
           58.20122050942762,
           58.106731177392945,
           58.01224184535826,
           57.917752513323585,
           57.8232631812889,
           57.728773849254225,
           57.63428451721954,
           57.539795185184865,
           57.44530585315019,
           57.06932657512732,
           56.552602324110424,
           56.03587807309351,
           55.51915382207658,
           55.00242957105969,
           54.48570532004275,
           53.96898106902585,
           53.452256818008934,
           52.935532566992016,
           52.41880831597511,
           51.902084064958174,
           51.38535981394128,
           50.86863556292436,
           50.351911311907436,
           49.83518706089055,
           49.31846280987362,
           48.8017385588567,
           48.28501430783977,
           47.768290056822856,
           47.25156580580597,
           46.73484155478904,
           46.218117303772125,
           45.70139305275522,
           45.18466880173829,
           44.66794455072139,
           44.15122029970447,
           43.634496048687545,
           43.11777179767065,
           42.60104754665371,
           42.084323295636814,
           41.56759904213678,
           41.037706764878266,
           40.5078144876198,
           39.97792221036129,
           39.4480299331028,
           38.9181376558443,
           38.3882453785858,
           37.858353101327324,
           37.32846082406883,
           36.79856854681032,
           36.26867626955185,
           35.73878399229335,
           35.208891715034845,
           34.67899943777635,
           34.14910716051785,
           33.619214883259346,
           33.08932260600087,
           32.55943032874237,
           32.029538051483875,
           31.499645774225378,
           30.969753496966874,
           30.439861219708398,
           29.9099689424499,
           29.3800766651914,
           28.850184387932902,
           28.32029211067443,
           27.790399833415925,
           27.260507556157425,
           26.730615278898924,
           26.200723001640426,
           25.670830724381954,
           25.140938447123453,
           24.611046169864952,
           24.08115389260645,
           23.551261615347975,
           23.021369338089478,
           22.491477060830977,
           21.961584783572476,
           21.43169250631398,
           20.901800229055503,
           20.371907951797002,
           19.8420156745385,
           19.312123397280004,
           18.782231120021503,
           18.25233884276303,
           17.72244656550453,
           17.19255428824603,
           16.662662010987532,
           16.132769733729056,
           15.602877456470555,
           15.072985179212054,
           14.543092901953557,
           14.013200624695056,
           13.681844340820147,
           13.549024050328761,
           13.416203759837451,
           13.285764053522804,
           13.16076568577176,
           13.035767318020726,
           12.91076895026966,
           12.785770582518616,
           12.660772214767572,
           12.535773847016548,
           12.410775479265505,
           12.28577711151443,
           12.16406279850349,
           12.048178314405657,
           11.932293830307763,
           11.81640934620993,
           11.70052486211204,
           11.58464037801417,
           11.46875589391631,
           11.35287140981845,
           11.237413671840708,
           11.131424352071098,
           11.02543503230153,
           10.919445712531918,
           10.813456392762333,
           10.707467072992758,
           10.601477753223179,
           10.495488433453595,
           10.391523235533457,
           10.292536284918178,
           10.193549334302917,
           10.094562383687677,
           9.995575433072432,
           9.896588482457146,
           9.797601531841885,
           9.698835765196183,
           9.605014131621884,
           9.511192498047578,
           9.417370864473257,
           9.323549230898958,
           9.22972759732463,
           9.13590596375033,
           9.04376803510569,
           8.956520866582864,
           8.86927369806,
           8.782026529537173,
           8.694779361014309,
           8.607532192491467,
           8.520285023968631,
           8.439186157248278,
           8.35887427338153,
           8.278562389514788,
           8.198250505648044,
           8.11793862178128,
           8.03762673791453,
           7.962832479993887,
           7.888673243759566,
           7.814514007525228,
           7.740354771290913,
           7.6661955350565965,
           7.593418977578566,
           7.52470555323411,
           7.455992128889684,
           7.387278704545222,
           7.318565280200781,
           7.24985185585634,
           7.168385709909773,
           7.085938585378416,
           7.003491460847074,
           6.921044336315707,
           6.83859721178435,
           6.756150087252999,
           6.673702962721643,
           6.591255838190288,
           6.508808713658931,
           6.4263615891275805,
           6.343914464596223,
           6.261467340064865,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           63.48164110650001,
           63.50670983222781,
           63.53177855795561,
           63.55684728368342,
           63.581916009411216,
           63.60698473513902,
           63.63205346086683,
           63.657122186594634,
           63.68219091232244,
           63.707259638050246,
           63.73232836377805,
           63.757397089505844,
           63.78246581523365,
           63.807534540961456,
           63.83260326668926,
           63.85767199241707,
           63.88274071814486,
           63.907809443872665,
           63.93287816960047,
           63.95794689532828,
           63.98301562105608,
           64.00808434678389,
           64.03315307251168,
           64.0582217982395,
           64.08329052396729,
           64.1083592496951,
           64.1334279754229,
           64.15849670115071,
           64.18356542687852,
           64.20863415260632,
           64.23370287833411,
           64.25877160406193,
           64.28384032978971,
           64.30890905551753,
           64.33397778124534,
           64.35904650697314,
           64.38411523270094,
           64.40918395842874,
           64.43425268415655,
           64.45932140988435,
           64.48439013561216,
           64.50945886133997,
           64.53452758706777,
           64.55959631279556,
           64.58466503852337,
           64.60973376425117,
           64.63480248997898,
           64.65987121570679,
           64.68493994143458,
           64.7100086671624,
           64.73507739289019,
           64.760146118618,
           64.7852148443458,
           64.8097173731233,
           64.83308751176556,
           64.8564576504078,
           64.87982778905005,
           64.9031979276923,
           64.92656806633455,
           64.9499382049768,
           64.97330834361905,
           64.9966784822613,
           65.02004862090355,
           65.0434187595458,
           65.06678889818805,
           65.0901590368303,
           65.11352917547255,
           65.1368993141148,
           65.16026945275705,
           65.1836395913993,
           65.20700973004155,
           65.2303798686838,
           65.25375000732605,
           65.2771201459683,
           65.30049028461055,
           65.3238604232528,
           65.34723056189505,
           65.3706007005373,
           65.39397083917954,
           65.4173409778218,
           65.44071111646404,
           65.4640812551063,
           65.48745139374854,
           65.51082153239079,
           65.41056138934132,
           65.28557518995348,
           65.16058899056566,
           65.03560279117784,
           64.91061659179,
           64.78563039240218,
           64.66064419301435,
           64.53565799362653,
           64.41067179423871,
           64.28568559485088,
           64.16069939546306,
           64.03571319607522,
           63.910726996687394,
           63.78574079729957,
           63.66075459791175,
           63.53576839852392,
           63.410782199136094,
           63.28579599974827,
           63.16080980036045,
           63.03582360097261,
           62.91083740158479,
           62.785851202196966,
           62.66086500280913,
           62.53587880342131,
           62.41089260403348,
           62.28590640464566,
           62.16092020525783,
           62.035934005870004,
           61.910947806482184,
           61.78596160709435,
           61.67114100762305,
           61.576651675588366,
           61.48216234355368,
           61.387673011519006,
           61.29318367948433,
           61.198694347449646,
           61.10420501541497,
           61.00971568338028,
           60.9152263513456,
           60.820737019310926,
           60.72624768727625,
           60.63175835524157,
           60.53726902320689,
           60.442779691172206,
           60.34829035913752,
           60.25380102710285,
           60.15931169506817,
           60.064822363033485,
           59.9703330309988,
           59.87584369896412,
           59.78135436692944,
           59.686865034894765,
           59.59237570286009,
           59.497886370825405,
           59.40339703879072,
           59.30890770675604,
           59.21441837472137,
           59.119929042686685,
           59.025439710652,
           58.93095037861732,
           58.83646104658264,
           58.741971714547965,
           58.64748238251328,
           58.5529930504786,
           58.45850371844393,
           58.36401438640924,
           58.26952505437456,
           58.175035722339885,
           58.08054639030519,
           57.98605705827052,
           57.891567726235834,
           57.79707839420115,
           57.702589062166474,
           57.6080997301318,
           57.51361039809712,
           57.41912106606244,
           57.32463173402776,
           57.23014240199308,
           57.135653069958394,
           57.04116373792372,
           56.94667440588904,
           56.85218507385436,
           56.75769574181968,
           56.38171646379682,
           55.864992212779924,
           55.34826796176301,
           54.83154371074608,
           54.31481945972918,
           53.79809520871225,
           53.281370957695344,
           52.76464670667842,
           52.24792245566151,
           51.731198204644606,
           51.21447395362767,
           50.697749702610764,
           50.18102545159385,
           49.664301200576936,
           49.14757694956003,
           48.63085269854311,
           48.1141284475262,
           47.597404196509274,
           47.08067994549235,
           46.56395569447546,
           46.04723144345854,
           45.53050719244162,
           45.01378294142472,
           44.49705869040778,
           43.98033443939088,
           43.46361018837396,
           42.946885937357045,
           42.43016168634015,
           41.9134374353232,
           41.39671318430631,
           40.87998893328939,
           40.36326468227247,
           39.846540431255576,
           39.32981618023866,
           38.813091929221734,
           38.29636767820482,
           37.7796434271879,
           37.262919176170996,
           36.74619492515408,
           36.229470674137154,
           35.71274642312026,
           35.19602217210334,
           34.679297921086416,
           34.1625736700695,
           33.64584941905258,
           33.129125168035664,
           32.61240091701876,
           32.09567666600184,
           31.578952414984922,
           31.062228163968005,
           30.545503912951084,
           30.028779661934188,
           29.51205541091727,
           28.99533115990035,
           28.478606908883428,
           27.961882657866532,
           27.445158406849615,
           26.92843415583269,
           26.411709904815773,
           25.894985653798855,
           25.37826140278196,
           24.861537151765035,
           24.344812900748117,
           23.8280886497312,
           23.3113643987143,
           22.79464014769738,
           22.27791589668046,
           21.74990474586739,
           21.22001246860889,
           20.690120191350413,
           20.160227914091912,
           19.630335636833415,
           19.100443359574914,
           18.570551082316413,
           18.04065880505794,
           17.51076652779944,
           16.98087425054094,
           16.45098197328244,
           15.921089696023962,
           15.391197418765465,
           14.861305141506964,
           14.331412864248467,
           13.801520586989966,
           13.470164303115059,
           13.341288981339487,
           13.21629061358845,
           13.091292245837415,
           12.966293878086375,
           12.84129551033534,
           12.716297142584272,
           12.59129877483323,
           12.466300407082187,
           12.341302039331161,
           12.22068241068473,
           12.104797926586864,
           11.988913442488972,
           11.873028958391139,
           11.757144474293243,
           11.641259990195412,
           11.52537550609752,
           11.409491021999651,
           11.294486701259654,
           11.188497381490079,
           11.082508061720494,
           10.976518741950885,
           10.870529422181313,
           10.764540102411704,
           10.65855078264212,
           10.552561462872545,
           10.448432146921023,
           10.349445196305764,
           10.25045824569051,
           10.151471295075229,
           10.05248434445997,
           9.953497393844732,
           9.854510443229485,
           9.7555234926142,
           9.661467662405938,
           9.56764602883164,
           9.473824395257338,
           9.380002761683034,
           9.286181128108712,
           9.192359494534415,
           9.099243413776504,
           9.011996245253668,
           8.924749076730814,
           8.837501908207988,
           8.750254739685127,
           8.663007571162296,
           8.575760402639435,
           8.493235129853293,
           8.412923245986551,
           8.332611362119808,
           8.25229947825306,
           8.171987594386316,
           8.091675710519574,
           8.015286844375854,
           7.941127608141534,
           7.866968371907223,
           7.792809135672902,
           7.718649899438565,
           7.64449066320425,
           7.575474020398166,
           7.50676059605372,
           7.438047171709265,
           7.369333747364837,
           7.300620323020376,
           7.224059069997717,
           7.141611945466367,
           7.059164820935004,
           6.976717696403647,
           6.894270571872305,
           6.81182344734094,
           6.729376322809581,
           6.646929198278231,
           6.564482073746874,
           6.48203494921552,
           6.399587824684162,
           6.317140700152812,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           63.32525599872034,
           63.350324724448136,
           63.375393450175935,
           63.40046217590374,
           63.42553090163155,
           63.45059962735935,
           63.47566835308716,
           63.50073707881495,
           63.52580580454276,
           63.55087453027057,
           63.57594325599837,
           63.60101198172617,
           63.62608070745397,
           63.65114943318178,
           63.676218158909585,
           63.70128688463739,
           63.72635561036519,
           63.751424336092995,
           63.7764930618208,
           63.8015617875486,
           63.826630513276406,
           63.85169923900421,
           63.876767964732004,
           63.901836690459824,
           63.92690541618761,
           63.95197414191543,
           63.977042867643235,
           64.00211159337103,
           64.02718031909885,
           64.05224904482664,
           64.07731777055444,
           64.10238649628226,
           64.12745522201004,
           64.15252394773786,
           64.17759267346565,
           64.20266139919346,
           64.22773012492127,
           64.25138335987573,
           64.27475349851798,
           64.29812363716022,
           64.32149377580248,
           64.34486391444473,
           64.36823405308698,
           64.39160419172923,
           64.41497433037148,
           64.43834446901373,
           64.46171460765598,
           64.48508474629823,
           64.50845488494048,
           64.53182502358273,
           64.55519516222498,
           64.57856530086723,
           64.60193543950948,
           64.62530557815172,
           64.64867571679397,
           64.67204585543622,
           64.69541599407847,
           64.71878613272072,
           64.74215627136297,
           64.76552641000522,
           64.78889654864747,
           64.81226668728972,
           64.83563682593197,
           64.85900696457422,
           64.88237710321647,
           64.90574724185872,
           64.92911738050097,
           64.95248751914322,
           64.97585765778547,
           64.99922779642772,
           65.02259793506997,
           65.04596807371222,
           65.06933821235447,
           65.09270835099672,
           65.11607848963897,
           65.13944862828122,
           65.16281876692346,
           65.18618890556571,
           65.20955904420796,
           65.23292918285021,
           65.25629932149245,
           65.27966946013471,
           65.30303959877695,
           65.32640973741921,
           65.22614959436973,
           65.1011633949819,
           64.97617719559408,
           64.85119099620624,
           64.72620479681842,
           64.60121859743059,
           64.47623239804277,
           64.35124619865495,
           64.22625999926711,
           64.10127379987928,
           63.97628760049147,
           63.85130140110363,
           63.72631520171581,
           63.60132900232799,
           63.47634280294016,
           63.35135660355234,
           63.22637040416451,
           63.10138420477668,
           62.97639800538886,
           62.851411806001025,
           62.726425606613205,
           62.60143940722538,
           62.47645320783755,
           62.35146700844973,
           62.2264808090619,
           62.10149460967408,
           61.97650841028625,
           61.85152221089842,
           61.7265360115106,
           61.60154981212277,
           61.47656361273495,
           61.351577413347115,
           61.226591213959296,
           61.10160501457147,
           60.97661881518364,
           60.851632615795815,
           60.72664641640799,
           60.60166021702016,
           60.47667401763234,
           60.351687818244514,
           60.22670161885669,
           60.10171541946886,
           59.976729220081026,
           59.851743020693206,
           59.726756821305386,
           59.60177062191755,
           59.47678442252973,
           59.377212251703035,
           59.28272291966836,
           59.18823358763366,
           59.093744255598985,
           58.99925492356431,
           58.90476559152963,
           58.81027625949495,
           58.71578692746027,
           58.62129759542559,
           58.52680826339091,
           58.43231893135623,
           58.33782959932155,
           58.24334026728687,
           58.148850935252185,
           58.05436160321751,
           57.959872271182824,
           57.86538293914815,
           57.770893607113464,
           57.67640427507878,
           57.581914943044104,
           57.487425611009435,
           57.392936278974744,
           57.29844694694006,
           57.20395761490538,
           57.10946828287071,
           57.014978950836024,
           56.92048961880134,
           56.82600028676666,
           56.73151095473199,
           56.637021622697304,
           56.54253229066262,
           56.44804295862794,
           56.35355362659327,
           56.259064294558584,
           56.1645749625239,
           56.07008563048923,
           55.69410635246636,
           55.177382101449474,
           54.66065785043256,
           54.143933599415625,
           53.627209348398736,
           53.1104850973818,
           52.5937608463649,
           52.07703659534798,
           51.56031234433106,
           51.04358809331416,
           50.52686384229722,
           50.01013959128032,
           49.493415340263404,
           48.97669108924648,
           48.45996683822958,
           47.94324258721266,
           47.426518336195755,
           46.909794085178824,
           46.3930698341619,
           45.876345583145,
           45.359621332128086,
           44.84289708111116,
           44.32617283009427,
           43.809448579077326,
           43.29272432806043,
           42.77600007704351,
           42.259275826026595,
           41.7425515750097,
           41.22582732399275,
           40.70910307297586,
           40.19237882195894,
           39.675654570942015,
           39.158930319925126,
           38.6422060689082,
           38.12548181789128,
           37.60875756687436,
           37.09203331585744,
           36.57530906484054,
           36.05858481382363,
           35.541860562806704,
           35.02513631178981,
           34.50841206077289,
           33.99168780975597,
           33.47496355873905,
           32.958239307722124,
           32.44151505670521,
           31.92479080568831,
           31.408066554671397,
           30.89134230365447,
           30.37461805263755,
           29.857893801620634,
           29.341169550603738,
           28.824445299586817,
           28.307721048569896,
           27.790996797552975,
           27.274272546536082,
           26.75754829551916,
           26.24082404450224,
           25.72409979348532,
           25.207375542468398,
           24.690651291451502,
           24.173927040434585,
           23.657202789417664,
           23.140478538400746,
           22.623754287383846,
           22.10703003636693,
           21.59225493271982,
           21.09177370802653,
           20.591292483333245,
           20.09081125863998,
           19.590330033946692,
           19.089848809253404,
           18.589367584560115,
           18.088886359866823,
           17.58840513517356,
           17.08792391048027,
           16.587442685786982,
           16.086961461093694,
           15.58648023640043,
           15.085999011707141,
           14.585517787013853,
           14.085036562320564,
           13.584555337627275,
           13.271815541405159,
           13.146817173654117,
           13.021818805903083,
           12.896820438152048,
           12.771822070401006,
           12.646823702649971,
           12.521825334898905,
           12.396826967147861,
           12.277302022865948,
           12.161417538768093,
           12.045533054670225,
           11.929648570572358,
           11.813764086474466,
           11.697879602376632,
           11.581995118278737,
           11.466110634180904,
           11.351559730678613,
           11.24557041090903,
           11.139581091139451,
           11.033591771369876,
           10.927602451600292,
           10.821613131830683,
           10.715623812061112,
           10.609634492291502,
           10.505341058308622,
           10.406354107693367,
           10.307367157078087,
           10.208380206462826,
           10.109393255847573,
           10.010406305232294,
           9.911419354617035,
           9.812432404001793,
           9.717921193190014,
           9.624099559615708,
           9.5302779260414,
           9.436456292467103,
           9.342634658892802,
           9.248813025318496,
           9.154991391744176,
           9.067471623924481,
           8.980224455401638,
           8.892977286878804,
           8.805730118355948,
           8.718482949833122,
           8.63123578131026,
           8.547284102458327,
           8.466972218591597,
           8.38666033472483,
           8.306348450858088,
           8.226036566991345,
           8.145724683124598,
           8.067741208757836,
           7.993581972523535,
           7.919422736289198,
           7.845263500054877,
           7.771104263820566,
           7.696945027586245,
           7.626242487562225,
           7.5575290632177685,
           7.488815638873326,
           7.420102214528881,
           7.351388790184425,
           7.279732430085672,
           7.197285305554306,
           7.114838181022956,
           7.032391056491606,
           6.949943931960245,
           6.867496807428887,
           6.785049682897544,
           6.702602558366179,
           6.620155433834822,
           6.537708309303471,
           6.455261184772114,
           6.372814060240759,
           6.290366935709402,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           63.16887089094064,
           63.193939616668445,
           63.219008342396236,
           63.24407706812404,
           63.269145793851855,
           63.294214519579654,
           63.31928324530746,
           63.34435197103525,
           63.369420696763065,
           63.39448942249087,
           63.41955814821868,
           63.444626873946476,
           63.469695599674274,
           63.49476432540209,
           63.51983305112989,
           63.54490177685769,
           63.5699705025855,
           63.5950392283133,
           63.6201079540411,
           63.64517667976891,
           63.66967920798589,
           63.693049346628136,
           63.716419485270386,
           63.73978962391264,
           63.763159762554885,
           63.786529901197135,
           63.809900039839384,
           63.83327017848164,
           63.85664031712389,
           63.88001045576613,
           63.90338059440838,
           63.92675073305064,
           63.95012087169288,
           63.97349101033514,
           63.99686114897738,
           64.02023128761964,
           64.04360142626189,
           64.06697156490414,
           64.09034170354639,
           64.11371184218862,
           64.13708198083089,
           64.16045211947313,
           64.18382225811538,
           64.20719239675763,
           64.23056253539988,
           64.25393267404213,
           64.27730281268438,
           64.30067295132663,
           64.32404308996887,
           64.34741322861112,
           64.37078336725338,
           64.39415350589562,
           64.41752364453787,
           64.44089378318012,
           64.46426392182236,
           64.48763406046461,
           64.51100419910688,
           64.53437433774911,
           64.55774447639138,
           64.58111461503361,
           64.60448475367586,
           64.62785489231813,
           64.65122503096038,
           64.67459516960263,
           64.69796530824487,
           64.72133544688711,
           64.74470558552937,
           64.76807572417161,
           64.79144586281386,
           64.81481600145612,
           64.83818614009837,
           64.86155627874062,
           64.88492641738287,
           64.9082965560251,
           64.93166669466736,
           64.95503683330962,
           64.97840697195186,
           65.00177711059412,
           65.02514724923635,
           65.04851738787862,
           65.07188752652085,
           65.09525766516312,
           65.11862780380535,
           65.1419979424476,
           65.04173779939813,
           64.9167516000103,
           64.79176540062247,
           64.66677920123465,
           64.54179300184683,
           64.41680680245899,
           64.29182060307117,
           64.16683440368334,
           64.0418482042955,
           63.916862004907685,
           63.791875805519865,
           63.66688960613204,
           63.54190340674421,
           63.41691720735638,
           63.29193100796856,
           63.16694480858073,
           63.0419586091929,
           62.91697240980508,
           62.79198621041725,
           62.66700001102943,
           62.5420138116416,
           62.41702761225378,
           62.29204141286595,
           62.167055213478136,
           62.0420690140903,
           61.91708281470247,
           61.79209661531465,
           61.66711041592683,
           61.542124216538994,
           61.41713801715116,
           61.29215181776334,
           61.16716561837551,
           61.042179418987686,
           60.917193219599866,
           60.79220702021205,
           60.66722082082422,
           60.54223462143639,
           60.41724842204856,
           60.29226222266074,
           60.167276023272905,
           60.042289823885085,
           59.91730362449726,
           59.79231742510943,
           59.66733122572161,
           59.54234502633378,
           59.41735882694596,
           59.29237262755814,
           59.167386428170296,
           59.042400228782476,
           58.91741402939465,
           58.792427830006815,
           58.667441630619,
           58.54245543123117,
           58.41746923184335,
           58.292483032455515,
           58.167496833067695,
           58.04251063367987,
           57.91752443429204,
           57.792538234904214,
           57.667552035516394,
           57.54256583612856,
           57.41757963674074,
           57.29259343735292,
           57.17777282781764,
           57.083283495782965,
           56.98879416374828,
           56.894304831713605,
           56.79981549967892,
           56.70532616764423,
           56.61083683560956,
           56.51634750357487,
           56.421858171540194,
           56.32736883950551,
           56.232879507470834,
           56.13839017543616,
           56.043900843401474,
           55.94941151136679,
           55.854922179332114,
           55.76043284729743,
           55.665943515262754,
           55.57145418322808,
           55.4769648511934,
           55.382475519158724,
           55.006496241135864,
           54.48977199011896,
           53.97304773910205,
           53.456323488085125,
           52.93959923706823,
           52.42287498605129,
           51.90615073503439,
           51.38942648401748,
           50.87270223300056,
           50.355977981983656,
           49.83925373096671,
           49.32252947994982,
           48.8058052289329,
           48.28908097791598,
           47.77235672689908,
           47.25563247588216,
           46.73890822486524,
           46.22218397384832,
           45.7054597228314,
           45.188735471814496,
           44.67201122079758,
           44.15528696978066,
           43.638562718763765,
           43.12183846774683,
           42.60511421672993,
           42.088389965713006,
           41.57166571469609,
           41.0549414636792,
           40.538217212662246,
           40.02149296164535,
           39.50476871062844,
           38.98804445961151,
           38.47132020859462,
           37.9545959575777,
           37.43787170656078,
           36.92114745554385,
           36.41221986583293,
           35.911738641139664,
           35.411257416446375,
           34.91077619175309,
           34.41029496705982,
           33.90981374236653,
           33.40933251767324,
           32.90885129297995,
           32.408370068286665,
           31.907888843593376,
           31.407407618900113,
           30.906926394206824,
           30.406445169513535,
           29.905963944820247,
           29.40548272012696,
           28.905001495433694,
           28.404520270740406,
           27.904039046047117,
           27.40355782135383,
           26.903076596660565,
           26.40259537196727,
           25.902114147273988,
           25.401632922580696,
           24.90115169788741,
           24.400670473194147,
           23.900189248500855,
           23.39970802380757,
           22.899226799114277,
           22.398745574421014,
           21.898264349727725,
           21.397783125034437,
           20.897301900341148,
           20.39682067564786,
           19.896339450954596,
           19.395858226261304,
           18.89537700156802,
           18.39489577687473,
           17.894414552181438,
           17.393933327488174,
           16.89345210279489,
           16.392970878101597,
           15.89248965340831,
           15.392008428715044,
           14.891527204021756,
           14.391045979328467,
           13.890564754635179,
           13.39008352994189,
           13.077343733719772,
           12.952345365968732,
           12.827346998217696,
           12.70234863046666,
           12.577350262715619,
           12.452351894964584,
           12.333921635047192,
           12.218037150949295,
           12.10215266685143,
           11.986268182753573,
           11.870383698655706,
           11.754499214557837,
           11.638614730459947,
           11.522730246362114,
           11.408632760097557,
           11.302643440327978,
           11.196654120558401,
           11.090664800788817,
           10.984675481019242,
           10.878686161249664,
           10.77269684148008,
           10.666707521710471,
           10.5622499696962,
           10.463263019080935,
           10.364276068465676,
           10.265289117850422,
           10.166302167235143,
           10.067315216619882,
           9.968328266004628,
           9.869341315389349,
           9.774374723974066,
           9.680553090399762,
           9.586731456825468,
           9.492909823251162,
           9.399088189676856,
           9.30526655610256,
           9.211444922528257,
           9.122947002595282,
           9.035699834072444,
           8.948452665549608,
           8.861205497026765,
           8.773958328503928,
           8.686711159981073,
           8.601333075063362,
           8.521021191196613,
           8.440709307329858,
           8.360397423463127,
           8.28008553959636,
           8.199773655729619,
           8.120195573139824,
           8.046036336905503,
           7.971877100671171,
           7.8977178644368715,
           7.823558628202534,
           7.749399391968213,
           7.677010954726272,
           7.608297530381812,
           7.539584106037379,
           7.470870681692923,
           7.402157257348481,
           7.3334438330040355,
           7.25295866564225,
           7.1705115411108995,
           7.088064416579535,
           7.005617292048185,
           6.923170167516834,
           6.840723042985473,
           6.758275918454114,
           6.675828793922773,
           6.593381669391407,
           6.510934544860049,
           6.4284874203286995,
           6.3460402957973425,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           63.01248578316094,
           63.037554508888746,
           63.06262323461655,
           63.08769196034436,
           63.11134519473829,
           63.13471533338054,
           63.15808547202279,
           63.18145561066504,
           63.20482574930729,
           63.22819588794953,
           63.25156602659179,
           63.27493616523404,
           63.29830630387629,
           63.32167644251853,
           63.34504658116079,
           63.36841671980304,
           63.391786858445286,
           63.41515699708753,
           63.43852713572979,
           63.46189727437203,
           63.485267413014284,
           63.50863755165653,
           63.53200769029878,
           63.55537782894103,
           63.578747967583276,
           63.60211810622553,
           63.625488244867775,
           63.64885838351003,
           63.672228522152274,
           63.69559866079452,
           63.71896879943678,
           63.74233893807903,
           63.76570907672127,
           63.78907921536353,
           63.81244935400577,
           63.83581949264803,
           63.85918963129027,
           63.88255976993253,
           63.90592990857477,
           63.92930004721702,
           63.952670185859276,
           63.976040324501525,
           63.999410463143775,
           64.02278060178602,
           64.04615074042827,
           64.06952087907052,
           64.09289101771277,
           64.11626115635502,
           64.13963129499727,
           64.16300143363952,
           64.18637157228177,
           64.20974171092402,
           64.23311184956627,
           64.25648198820852,
           64.27985212685077,
           64.30322226549302,
           64.32659240413527,
           64.34996254277752,
           64.37333268141977,
           64.39670282006202,
           64.42007295870427,
           64.44344309734652,
           64.46681323598877,
           64.49018337463102,
           64.51355351327327,
           64.53692365191552,
           64.56029379055776,
           64.58366392920001,
           64.60703406784226,
           64.63040420648451,
           64.65377434512676,
           64.67714448376901,
           64.70051462241125,
           64.72388476105351,
           64.74725489969575,
           64.77062503833801,
           64.79399517698025,
           64.81736531562251,
           64.84073545426475,
           64.86410559290701,
           64.88747573154924,
           64.91084587019151,
           64.93421600883374,
           64.957586147476,
           64.85732600442653,
           64.73233980503869,
           64.60735360565087,
           64.48236740626304,
           64.35738120687522,
           64.23239500748738,
           64.10740880809956,
           63.98242260871174,
           63.85743640932391,
           63.73245020993608,
           63.60746401054826,
           63.482477811160436,
           63.35749161177261,
           63.23250541238478,
           63.107519212996955,
           62.98253301360913,
           62.85754681422131,
           62.732560614833474,
           62.607574415445654,
           62.48258821605782,
           62.35760201667001,
           62.23261581728217,
           62.10762961789435,
           61.98264341850653,
           61.85765721911869,
           61.73267101973087,
           61.60768482034304,
           61.48269862095522,
           61.35771242156739,
           61.232726222179565,
           61.10774002279174,
           60.98275382340391,
           60.857767624016084,
           60.73278142462827,
           60.60779522524044,
           60.48280902585262,
           60.35782282646478,
           60.232836627076956,
           60.107850427689144,
           59.9828642283013,
           59.857878028913476,
           59.732891829525656,
           59.60790563013782,
           59.48291943075,
           59.357933231362175,
           59.23294703197435,
           59.10796083258653,
           58.982974633198694,
           58.857988433810874,
           58.73300223442304,
           58.60801603503521,
           58.48302983564739,
           58.358043636259566,
           58.23305743687174,
           58.10807123748391,
           57.983085038096085,
           57.85809883870826,
           57.73311263932044,
           57.608126439932605,
           57.483140240544785,
           57.35815404115695,
           57.23316784176913,
           57.10818164238131,
           56.98319544299348,
           56.85820924360565,
           56.73322304421782,
           56.608236844829996,
           56.483250645442176,
           56.35826444605435,
           56.23327824666653,
           56.108292047278695,
           55.983305847890875,
           55.85831964850304,
           55.733333449115214,
           55.6083472497274,
           55.48336105033957,
           55.35837485095175,
           55.233388651563914,
           55.108402452176094,
           54.98341625278827,
           54.88384407189757,
           54.78935473986289,
           54.69486540782821,
           54.31888612980536,
           53.80216187878845,
           53.285437627771536,
           52.76871337675462,
           52.25198912573772,
           51.73526487472078,
           51.23218479894606,
           50.73170357425276,
           50.23122234955948,
           49.73074112486621,
           49.230259900172896,
           48.72977867547964,
           48.22929745078635,
           47.728816226093066,
           47.2283350013998,
           46.72785377670651,
           46.22737255201322,
           45.72689132731993,
           45.226410102626645,
           44.72592887793338,
           44.22544765324009,
           43.72496642854679,
           43.22448520385353,
           42.72400397916022,
           42.223522754466956,
           41.72304152977367,
           41.22256030508038,
           40.72207908038711,
           40.22159785569381,
           39.72111663100054,
           39.22063540630725,
           38.720154181613964,
           38.2196729569207,
           37.71919173222741,
           37.21871050753412,
           36.71822928284084,
           36.21774805814754,
           35.717266833454275,
           35.21678560876099,
           34.716304384067705,
           34.21582315937444,
           33.71534193468115,
           33.21486070998786,
           32.71437948529457,
           32.213898260601276,
           31.71341703590799,
           31.212935811214727,
           30.71245458652144,
           30.21197336182815,
           29.71149213713486,
           29.21101091244157,
           28.710529687748313,
           28.21004846305502,
           27.709567238361736,
           27.209086013668443,
           26.708604788975176,
           26.20812356428189,
           25.7076423395886,
           25.20716111489531,
           24.706679890202025,
           24.20619866550876,
           23.70571744081547,
           23.205236216122184,
           22.704754991428896,
           22.20427376673563,
           21.70379254204234,
           21.20331131734905,
           20.702830092655763,
           20.202348867962474,
           19.701867643269207,
           19.20138641857592,
           18.700905193882633,
           18.200423969189345,
           17.699942744496056,
           17.19946151980279,
           16.6989802951095,
           16.19849907041621,
           15.698017845722925,
           15.19753662102966,
           14.69705539633637,
           14.196574171643082,
           13.696092946949793,
           13.195611722256505,
           12.882871926034385,
           12.757873558283343,
           12.63287519053231,
           12.507876822781276,
           12.390541247228397,
           12.274656763130535,
           12.158772279032673,
           12.042887794934776,
           11.92700331083691,
           11.811118826739055,
           11.695234342641188,
           11.57934985854332,
           11.46570578951653,
           11.359716469746951,
           11.253727149977342,
           11.147737830207763,
           11.04174851043819,
           10.935759190668604,
           10.829769870899026,
           10.72378055112945,
           10.61915888108376,
           10.5201719304685,
           10.421184979853251,
           10.322198029237988,
           10.22321107862273,
           10.124224128007475,
           10.025237177392196,
           9.926250226776936,
           9.830828254758151,
           9.73700662118385,
           9.643184987609523,
           9.549363354035217,
           9.455541720460925,
           9.361720086886619,
           9.267898453312311,
           9.178422381266103,
           9.091175212743249,
           9.003928044220405,
           8.91668087569757,
           8.829433707174733,
           8.74218653865189,
           8.65538204766838,
           8.575070163801639,
           8.49475827993489,
           8.414446396068142,
           8.334134512201388,
           8.253822628334657,
           8.17351074446789,
           8.098490701287478,
           8.02433146505316,
           7.950172228818839,
           7.876012992584507,
           7.801853756350208,
           7.727779421890309,
           7.659065997545864,
           7.590352573201427,
           7.5216391488569645,
           7.452925724512533,
           7.384212300168078,
           7.308632025730196,
           7.226184901198835,
           7.143737776667484,
           7.061290652136135,
           6.978843527604768,
           6.896396403073419,
           6.813949278542069,
           6.731502154010707,
           6.649055029479349,
           6.566607904948007,
           6.484160780416642,
           6.401713655885284,
           6.319266531353934,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           62.843745654679736,
           62.865518744908535,
           62.88729183513733,
           62.90906492536613,
           62.93083801559493,
           62.95261110582373,
           62.974384196052526,
           62.99615728628133,
           63.01793037651012,
           63.03970346673893,
           63.061476556967726,
           63.083249647196524,
           63.10502273742532,
           63.12679582765412,
           63.14963361550766,
           63.1730037541499,
           63.19637389279215,
           63.2197440314344,
           63.24311417007666,
           63.2664843087189,
           63.28985444736115,
           63.3132245860034,
           63.33659472464564,
           63.35996486328791,
           63.38333500193014,
           63.4067051405724,
           63.43007527921465,
           63.4534454178569,
           63.47681555649915,
           63.5001856951414,
           63.52355583378365,
           63.5469259724259,
           63.57029611106814,
           63.5936662497104,
           63.617036388352645,
           63.640406526994894,
           63.663776665637144,
           63.687146804279394,
           63.71051694292164,
           63.733887081563886,
           63.75725722020614,
           63.78062735884839,
           63.80399749749064,
           63.82736763613289,
           63.85073777477514,
           63.87410791341739,
           63.89747805205964,
           63.92084819070189,
           63.94421832934414,
           63.96758846798639,
           63.99095860662864,
           64.01432874527089,
           64.03769888391314,
           64.06106902255539,
           64.08443916119764,
           64.10780929983989,
           64.13117943848214,
           64.15454957712438,
           64.17791971576663,
           64.20128985440888,
           64.22465999305113,
           64.24803013169338,
           64.27140027033563,
           64.29477040897788,
           64.31814054762013,
           64.34151068626238,
           64.36488082490463,
           64.38825096354688,
           64.41162110218913,
           64.43499124083138,
           64.45836137947363,
           64.48173151811588,
           64.50510165675811,
           64.52847179540038,
           64.55184193404263,
           64.57521207268488,
           64.59858221132713,
           64.62195234996938,
           64.64532248861163,
           64.66869262725388,
           64.69206276589613,
           64.71543290453837,
           64.73880304318062,
           64.76217318182287,
           64.66191303877339,
           64.53692683938556,
           64.41194063999774,
           64.28695444060992,
           64.16196824122208,
           64.03698204183426,
           63.91199584244643,
           63.78700964305861,
           63.66202344367078,
           63.53703724428295,
           63.412051044895136,
           63.287064845507295,
           63.162078646119475,
           63.03709244673165,
           62.91210624734383,
           62.787120047956,
           62.662133848568175,
           62.53714764918034,
           62.41216144979253,
           62.28717525040469,
           62.162189051016874,
           62.03720285162904,
           61.91221665224121,
           61.78723045285339,
           61.66224425346557,
           61.53725805407774,
           61.41227185468992,
           61.287285655302085,
           61.162299455914265,
           61.03731325652643,
           60.91232705713861,
           60.78734085775078,
           60.66235465836296,
           60.53736845897513,
           60.412382259587304,
           60.28739606019948,
           60.16240986081165,
           60.03742366142382,
           59.912437462036,
           59.787451262648176,
           59.66246506326035,
           59.53747886387253,
           59.412492664484695,
           59.287506465096875,
           59.16252026570904,
           59.03753406632122,
           58.912547866933394,
           58.78756166754557,
           58.66257546815774,
           58.537589268769906,
           58.41260306938209,
           58.28761686999427,
           58.16263067060643,
           58.03764447121861,
           57.91265827183078,
           57.78767207244296,
           57.66268587305514,
           57.537699673667305,
           57.412713474279485,
           57.28772727489166,
           57.16274107550383,
           57.037754876116004,
           56.91276867672818,
           56.78778247734035,
           56.66279627795252,
           56.537810078564696,
           56.41282387917687,
           56.28783767978905,
           56.162851480401216,
           56.03786525495172,
           55.88128911376208,
           55.724712972572455,
           55.568136831382816,
           55.411560690193184,
           55.25498454900356,
           55.098408407813935,
           54.9418322666243,
           54.78525612543467,
           54.62867998424504,
           54.472103843055415,
           54.31552770186578,
           54.15895156067615,
           54.00237541948653,
           53.62298247807581,
           53.13218113655461,
           52.64137979503338,
           52.15057845351215,
           51.65977711199094,
           51.16897577046969,
           50.67817442894848,
           50.18737308742726,
           49.69657174590603,
           49.20577040438482,
           48.714969062863574,
           48.22416772134236,
           47.73336637982113,
           47.2425650382999,
           46.751763696778696,
           46.26096235525746,
           45.770161013736235,
           45.27935967221501,
           44.78855833069378,
           44.29775698917257,
           43.80695564765134,
           43.316154306130116,
           42.82535296460891,
           42.334551623087656,
           41.84375028156645,
           41.35294894004522,
           40.86214759852399,
           40.371346257002784,
           39.880544915481536,
           39.38974357396033,
           38.8989422324391,
           38.40814089091787,
           37.917339549396665,
           37.42653820787543,
           36.935736866354205,
           36.44493552483298,
           35.954134183311744,
           35.46333284179054,
           34.97253150026931,
           34.48173015874808,
           33.990928817226866,
           33.50012747570564,
           33.00932613418441,
           32.51852479266318,
           32.01942645291591,
           31.518945228222623,
           31.018464003529356,
           30.517982778836068,
           30.01750155414278,
           29.51702032944949,
           29.016539104756202,
           28.516057880062938,
           28.015576655369653,
           27.51509543067636,
           27.014614205983072,
           26.51413298128981,
           26.01365175659652,
           25.513170531903228,
           25.01268930720994,
           24.512208082516654,
           24.011726857823387,
           23.511245633130102,
           23.010764408436813,
           22.51028318374352,
           22.009801959050257,
           21.50932073435697,
           21.008839509663677,
           20.50835828497039,
           20.007877060277103,
           19.50739583558384,
           19.006914610890547,
           18.506433386197262,
           18.005952161503973,
           17.50547093681068,
           17.004989712117418,
           16.504508487424133,
           16.00402726273084,
           15.503546038037552,
           15.003064813344288,
           14.502583588651001,
           14.002102363957711,
           13.50162113926442,
           13.001139914571134,
           12.688400118349017,
           12.563401750597976,
           12.447160859409646,
           12.331276375311754,
           12.215391891213889,
           12.099507407116025,
           11.983622923018165,
           11.867738438920268,
           11.7518539548224,
           11.635969470724548,
           11.52277881893549,
           11.416789499165908,
           11.31080017939633,
           11.204810859626752,
           11.098821539857141,
           10.992832220087564,
           10.886842900317989,
           10.780853580548403,
           10.676067792471367,
           10.577080841856112,
           10.478093891240828,
           10.379106940625567,
           10.280119990010316,
           10.181133039395055,
           10.082146088779794,
           9.98315913816454,
           9.887281785542221,
           9.793460151967917,
           9.699638518393616,
           9.605816884819317,
           9.511995251244988,
           9.418173617670682,
           9.32435198409639,
           9.23389775993692,
           9.146650591414076,
           9.059403422891238,
           8.972156254368382,
           8.884909085845543,
           8.797661917322705,
           8.710414748799868,
           8.629119136406663,
           8.548807252539921,
           8.468495368673178,
           8.38818348480643,
           8.30787160093968,
           8.227559717072927,
           8.150945065669474,
           8.076785829435153,
           8.002626593200821,
           7.928467356966505,
           7.854308120732183,
           7.7801488844978515,
           7.709834464709916,
           7.641121040365469,
           7.5724076160210245,
           7.503694191676589,
           7.434980767332126,
           7.364305385818136,
           7.281858261286786,
           7.199411136755436,
           7.1169640122240745,
           7.034516887692725,
           6.952069763161375,
           6.869622638630009,
           6.787175514098659,
           6.704728389567308,
           6.622281265035948,
           6.53983414050459,
           6.4573870159732465,
           6.374939891441882,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           62.67207121023313,
           62.69384430046192,
           62.71561739069072,
           62.737390480919515,
           62.75916357114832,
           62.78093666137712,
           62.80270975160591,
           62.82448284183471,
           62.846255932063514,
           62.86802902229232,
           62.88980211252111,
           62.911575202749916,
           62.933348292978714,
           62.95512138320751,
           62.97689447343631,
           62.99866756366511,
           63.02044065389391,
           63.042213744122705,
           63.06398683435151,
           63.08575992458031,
           63.10753301480911,
           63.129306105037905,
           63.151079195266696,
           63.17285228549551,
           63.19462537572429,
           63.2163984659531,
           63.23817155618191,
           63.25994464641069,
           63.28171773663951,
           63.3034908268683,
           63.32553009138584,
           63.34890023002809,
           63.37227036867034,
           63.39564050731259,
           63.41901064595484,
           63.44238078459709,
           63.46575092323934,
           63.4891210618816,
           63.51249120052384,
           63.53586133916609,
           63.55923147780834,
           63.58260161645059,
           63.60597175509284,
           63.62934189373509,
           63.65271203237734,
           63.67608217101959,
           63.69945230966184,
           63.722822448304086,
           63.746192586946336,
           63.769562725588585,
           63.792932864230835,
           63.816303002873084,
           63.839673141515334,
           63.86304328015758,
           63.88641341879983,
           63.90978355744208,
           63.93315369608433,
           63.95652383472658,
           63.97989397336883,
           64.00326411201108,
           64.02663425065333,
           64.05000438929558,
           64.07337452793783,
           64.09674466658008,
           64.12011480522233,
           64.14348494386458,
           64.16685508250683,
           64.19022522114908,
           64.21359535979133,
           64.23696549843358,
           64.26033563707583,
           64.28370577571808,
           64.30707591436033,
           64.33044605300258,
           64.35381619164482,
           64.37718633028707,
           64.40055646892932,
           64.42392660757157,
           64.44729674621382,
           64.47066688485607,
           64.49403702349832,
           64.51740716214057,
           64.54077730078282,
           64.56414743942506,
           64.46388729637557,
           64.33890109698775,
           64.21391489759993,
           64.08892869821211,
           63.963942498824274,
           63.83895629943646,
           63.71397010004862,
           63.5889839006608,
           63.46399770127297,
           63.33901150188514,
           63.214025302497326,
           63.089039103109485,
           62.964052903721665,
           62.839066704333845,
           62.71408050494602,
           62.58909430555819,
           62.46410810617037,
           62.33912190678254,
           62.21413570739472,
           62.089149508006884,
           61.964163308619064,
           61.83917710923124,
           61.71419090984341,
           61.58920471045559,
           61.464218511067756,
           61.339232311679936,
           61.21424611229211,
           61.08925991290427,
           60.96427371351646,
           60.83928751412863,
           60.7143013147408,
           60.589315115352974,
           60.46432891596515,
           60.33934271657733,
           60.2143565171895,
           60.08937031780167,
           59.96438411841385,
           59.83939791902602,
           59.71441171963819,
           59.58942552025037,
           59.46443932086254,
           59.33945312147472,
           59.214466922086885,
           59.089480722699065,
           58.964494523311245,
           58.83950832392341,
           58.714522124535584,
           58.58953592514776,
           58.46454972575994,
           58.3395635263721,
           58.21457732698428,
           58.089591127596464,
           57.96460492820863,
           57.823823749081605,
           57.66724760789197,
           57.510671466702334,
           57.35409532551271,
           57.197519184323085,
           57.04094304313345,
           56.88436690194382,
           56.72779076075419,
           56.57121461956456,
           56.41463847837493,
           56.2580623371853,
           56.101486195995676,
           55.94491005480604,
           55.78833391361641,
           55.63175777242679,
           55.47518163123715,
           55.318605490047524,
           55.162029348857885,
           55.00545320766825,
           54.84887706647862,
           54.69230092528899,
           54.53572478409937,
           54.37914864290974,
           54.22257250172011,
           54.06599636053048,
           53.909420219340845,
           53.75284407815122,
           53.59626793696159,
           53.43969179577196,
           53.28311565458234,
           52.90372271317162,
           52.41292137165041,
           51.92212003012919,
           51.43131868860796,
           50.940517347086754,
           50.44971600556549,
           49.958914664044286,
           49.46811332252307,
           48.97731198100183,
           48.48651063948063,
           47.99570929795938,
           47.504907956438174,
           47.01410661491694,
           46.52330527339571,
           46.0325039318745,
           45.54170259035328,
           45.05090124883205,
           44.560099907310814,
           44.06929856578959,
           43.57849722426838,
           43.087695882747155,
           42.59689454122592,
           42.106093199704716,
           41.61529185818346,
           41.12449051666226,
           40.63368917514103,
           40.142887833619795,
           39.65208649209859,
           39.16128515057734,
           38.67048380905613,
           38.1796824675349,
           37.688881126013676,
           37.19807978449247,
           36.70727844297124,
           36.21647710145002,
           35.725675759928784,
           35.23487441840756,
           34.744073076886345,
           34.25327173536512,
           33.762470393843884,
           33.27166905232267,
           32.780867710801445,
           32.29006636928022,
           31.799265027758988,
           31.30846368623776,
           30.81766234471653,
           30.326861003195326,
           29.8360596616741,
           29.345258320152872,
           28.85445697863164,
           28.363655637110412,
           27.872854295589207,
           27.382052954067973,
           26.891251612546746,
           26.400450271025516,
           25.909648929504307,
           25.418847587983077,
           24.92804624646185,
           24.43724490494062,
           23.94644356341939,
           23.455642221898188,
           22.96484088037696,
           22.47403953885573,
           21.9832381973345,
           21.492436855813292,
           21.001635514292065,
           20.510834172770835,
           20.02003283124961,
           19.529231489728375,
           19.03843014820717,
           18.547628806685942,
           18.056827465164712,
           17.566026123643482,
           17.075224782122255,
           16.58442344060105,
           16.093622099079816,
           15.60282079990455,
           15.134959555863814,
           14.667098311823095,
           14.199237067782358,
           13.731375823741615,
           13.263514579700882,
           12.795653335660143,
           12.503780471590856,
           12.387895987492985,
           12.272011503395127,
           12.156127019297235,
           12.040242535199368,
           11.924358051101507,
           11.808473567003647,
           11.69258908290575,
           11.579851848354432,
           11.473862528584862,
           11.367873208815277,
           11.261883889045693,
           11.155894569276116,
           11.049905249506539,
           10.943915929736928,
           10.83792660996735,
           10.732976703858935,
           10.633989753243673,
           10.53500280262842,
           10.436015852013165,
           10.337028901397879,
           10.23804195078262,
           10.139055000167371,
           10.040068049552108,
           9.943735316326297,
           9.849913682751996,
           9.756092049177676,
           9.662270415603372,
           9.568448782029073,
           9.474627148454772,
           9.380805514880445,
           9.289373138607717,
           9.202125970084884,
           9.114878801562043,
           9.027631633039201,
           8.940384464516363,
           8.853137295993507,
           8.765890127470666,
           8.683168109011701,
           8.602856225144958,
           8.522544341278191,
           8.44223245741145,
           8.361920573544706,
           8.28160868967796,
           8.203399430051427,
           8.129240193817116,
           8.05508095758281,
           7.980921721348489,
           7.906762485114157,
           7.832603248879841,
           7.760602931873968,
           7.6918895075295115,
           7.62317608318507,
           7.554462658840624,
           7.485749234496178,
           7.417035810151742,
           7.337531621374733,
           7.255084496843368,
           7.1726373723120185,
           7.090190247780669,
           7.007743123249306,
           6.925295998717956,
           6.842848874186606,
           6.760401749655241,
           6.67795462512389,
           6.595507500592541,
           6.513060376061179,
           6.43061325152982,
           6.348166126998479,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           62.50039676578652,
           62.522169856015324,
           62.543942946244115,
           62.56571603647291,
           62.58748912670171,
           62.60926221693052,
           62.63103530715931,
           62.652808397388114,
           62.674581487616905,
           62.69635457784571,
           62.718127668074516,
           62.73990075830331,
           62.7616738485321,
           62.7834469387609,
           62.80522002898971,
           62.8269931192185,
           62.848766209447305,
           62.87053929967611,
           62.8923123899049,
           62.91408548013371,
           62.9358585703625,
           62.957631660591304,
           62.979404750820095,
           63.0011778410489,
           63.02295093127769,
           63.0447240215065,
           63.066497111735295,
           63.08827020196409,
           63.1100432921929,
           63.13181638242169,
           63.153589472650495,
           63.17536256287929,
           63.197135653108084,
           63.21890874333689,
           63.24068183356569,
           63.26245492379448,
           63.284228014023284,
           63.30600110425208,
           63.32777419448089,
           63.34954728470968,
           63.37132037493848,
           63.39309346516728,
           63.414866555396074,
           63.43663964562488,
           63.458412735853685,
           63.480185826082476,
           63.50195891631128,
           63.52479670590628,
           63.54816684454853,
           63.57153698319078,
           63.59490712183303,
           63.61827726047528,
           63.64164739911753,
           63.66501753775978,
           63.68838767640203,
           63.71175781504428,
           63.73512795368653,
           63.75849809232878,
           63.78186823097103,
           63.80523836961328,
           63.82860850825553,
           63.85197864689778,
           63.87534878554003,
           63.898718924182276,
           63.92208906282452,
           63.945459201466775,
           63.96882934010902,
           63.992199478751274,
           64.01556961739352,
           64.03893975603577,
           64.06230989467802,
           64.08568003332027,
           64.10905017196251,
           64.13242031060477,
           64.15579044924702,
           64.17916058788927,
           64.20253072653152,
           64.22590086517377,
           64.24927100381602,
           64.27264114245827,
           64.29601128110052,
           64.31938141974277,
           64.34275155838502,
           64.36612169702727,
           64.26586155397779,
           64.14087535458995,
           64.01588915520213,
           63.890902955814305,
           63.76591675642648,
           63.64093055703866,
           63.515944357650824,
           63.390958158263,
           63.26597195887517,
           63.14098575948735,
           63.01599956009952,
           62.89101336071169,
           62.76602716132387,
           62.64104096193604,
           62.516054762548215,
           62.391068563160395,
           62.26608236377257,
           62.141096164384734,
           62.016109964996915,
           61.89112376560908,
           61.76613756622126,
           61.641151366833434,
           61.51616516744561,
           61.39117896805779,
           61.26619276866995,
           61.14120656928213,
           61.016220369894306,
           60.89123417050648,
           60.76624797111866,
           60.641261771730825,
           60.516275572343005,
           60.39128937295517,
           60.26630317356735,
           60.141316974179524,
           60.0163307747917,
           59.89134457540387,
           59.76635837601604,
           59.609782243211484,
           59.45320610202186,
           59.296629960832234,
           59.1400538196426,
           58.98347767845297,
           58.82690153726334,
           58.67032539607371,
           58.51374925488407,
           58.357173113694444,
           58.200596972504826,
           58.04402083131519,
           57.88744469012556,
           57.73086854893592,
           57.57429240774629,
           57.417716266556674,
           57.26114012536704,
           57.10456398417741,
           56.94798784298778,
           56.79141170179815,
           56.63483556060852,
           56.47825941941889,
           56.32168327822926,
           56.16510713703963,
           56.008530995849995,
           55.85195485466036,
           55.69537871347074,
           55.53880257228111,
           55.38222643109148,
           55.22565028990184,
           55.06907414871222,
           54.91249800752259,
           54.755921866332955,
           54.59934572514333,
           54.44276958395369,
           54.286193442764066,
           54.12961730157443,
           53.9730411603848,
           53.81646501919518,
           53.659888878005546,
           53.503312736815914,
           53.34673659562628,
           53.19016045443665,
           53.033584313247026,
           52.8770081720574,
           52.72043203086776,
           52.56385588967814,
           52.18446294826743,
           51.69366160674622,
           51.202860265225,
           50.712058923703765,
           50.22125758218255,
           49.730456240661304,
           49.2396548991401,
           48.74885355761887,
           48.25805221609764,
           47.76725087457643,
           47.276449533055185,
           46.78564819153398,
           46.294846850012746,
           45.80404550849152,
           45.31324416697031,
           44.82244282544909,
           44.331641483927854,
           43.84084014240663,
           43.3500388008854,
           42.85923745936418,
           42.36843611784296,
           41.87763477632173,
           41.38683343480052,
           40.896032093279274,
           40.40523075175807,
           39.914429410236835,
           39.4236280687156,
           38.932826727194396,
           38.44202538567315,
           37.95122404415194,
           37.46042270263071,
           36.96962136110949,
           36.47882001958827,
           35.98801867806704,
           35.497217336545816,
           35.00641599502459,
           34.51561465350336,
           34.02481331198216,
           33.534011970460924,
           33.04321062893969,
           32.552409287418484,
           32.06160794589726,
           31.570806604376028,
           31.080005262854797,
           30.589203921333567,
           30.098402579812344,
           29.60760123829113,
           29.116799896769898,
           28.625998555248675,
           28.135197213727444,
           27.644395872206218,
           27.153594530685012,
           26.662793189163786,
           26.188480056826904,
           25.72061881278617,
           25.252757568745444,
           24.784896324704707,
           24.317035080663974,
           23.849173836623237,
           23.381312592582496,
           22.913451348541777,
           22.44559010450104,
           21.977728860460306,
           21.509867616419562,
           21.042006372378847,
           20.57414512833811,
           20.10628388429737,
           19.638422640256632,
           19.170561396215895,
           18.702700152175176,
           18.23483890813444,
           17.7669776640937,
           17.299116420052965,
           16.831255176012224,
           16.36339393197151,
           15.895532687930768,
           15.427671443890034,
           14.959810199849294,
           14.491948955808576,
           14.024087711767837,
           13.556226467727098,
           13.08836522368636,
           12.620503979645623,
           12.328631115576338,
           12.212746631478467,
           12.096862147380609,
           11.980977663282717,
           11.865093179184848,
           11.749208695086988,
           11.636924877773385,
           11.5309355580038,
           11.424946238234217,
           11.318956918464647,
           11.212967598695062,
           11.10697827892548,
           11.000988959155901,
           10.894999639386324,
           10.789885615246519,
           10.690898664631266,
           10.591911714015987,
           10.492924763400726,
           10.39393781278547,
           10.294950862170218,
           10.195963911554934,
           10.09697696093967,
           10.000188847110362,
           9.906367213536056,
           9.81254557996175,
           9.718723946387449,
           9.62490231281313,
           9.531080679238826,
           9.437259045664526,
           9.344848517278525,
           9.257601348755683,
           9.170354180232842,
           9.083107011710009,
           8.99585984318717,
           8.908612674664324,
           8.821365506141488,
           8.737217081616722,
           8.656905197749973,
           8.57659331388323,
           8.496281430016488,
           8.41596954614972,
           8.335657662282978,
           8.25585379443342,
           8.1816945581991,
           8.107535321964763,
           8.03337608573045,
           7.959216849496146,
           7.885057613261824,
           7.811371399038009,
           7.742657974693567,
           7.673944550349122,
           7.605231126004665,
           7.536517701660224,
           7.4678042773157784,
           7.393204981462665,
           7.310757856931323,
           7.228310732399965,
           7.145863607868599,
           7.0634164833372495,
           6.9809693588059,
           6.898522234274537,
           6.816075109743188,
           6.733627985211838,
           6.651180860680473,
           6.568733736149122,
           6.486286611617771,
           6.40383948708641,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           62.328722321339924,
           62.35049541156873,
           62.37226850179752,
           62.39404159202631,
           62.41581468225512,
           62.43758777248392,
           62.459360862712714,
           62.48113395294152,
           62.50290704317031,
           62.524680133399116,
           62.54645322362792,
           62.56822631385671,
           62.5899994040855,
           62.61177249431431,
           62.633545584543114,
           62.65531867477192,
           62.67709176500071,
           62.698864855229516,
           62.72063794545831,
           62.7424110356871,
           62.764184125915904,
           62.78595721614471,
           62.8077303063735,
           62.829503396602306,
           62.8512764868311,
           62.8730495770599,
           62.8948226672887,
           62.9165957575175,
           62.938368847746304,
           62.960141937975095,
           62.981915028203886,
           63.0036881184327,
           63.02546120866149,
           63.047234298890295,
           63.06900738911909,
           63.090780479347885,
           63.1125535695767,
           63.13432665980548,
           63.15609975003429,
           63.177872840263085,
           63.19964593049188,
           63.22141902072069,
           63.24319211094948,
           63.264965201178285,
           63.286738291407076,
           63.30851138163588,
           63.33028447186469,
           63.35205756209348,
           63.37383065232227,
           63.395603742551074,
           63.41737683277988,
           63.43914992300867,
           63.460923013237476,
           63.48269610346627,
           63.50446919369507,
           63.52624228392388,
           63.54801537415267,
           63.569788464381475,
           63.591561554610266,
           63.61333464483907,
           63.63510773506786,
           63.65688082529667,
           63.67865391552546,
           63.700693181784494,
           63.724063320426744,
           63.74743345906899,
           63.77080359771124,
           63.79417373635349,
           63.81754387499574,
           63.84091401363799,
           63.86428415228024,
           63.887654290922484,
           63.91102442956474,
           63.93439456820698,
           63.95776470684924,
           63.98113484549148,
           64.00450498413375,
           64.02787512277598,
           64.05124526141823,
           64.0746154000605,
           64.09798553870273,
           64.121355677345,
           64.14472581598723,
           64.16809595462948,
           64.06783581158,
           63.94284961219217,
           63.81786341280435,
           63.69287721341652,
           63.567891014028696,
           63.442904814640876,
           63.31791861525304,
           63.19293241586522,
           63.06794621647739,
           62.94296001708957,
           62.81797381770174,
           62.692987618313914,
           62.56800141892609,
           62.44301521953826,
           62.31802902015043,
           62.193042820762614,
           62.06805662137478,
           61.94307042198696,
           61.81808422259913,
           61.693098023211306,
           61.55231687853106,
           61.39574073734143,
           61.239164596151795,
           61.08258845496218,
           60.92601231377253,
           60.769436172582914,
           60.61286003139328,
           60.45628389020365,
           60.29970774901403,
           60.14313160782439,
           59.98655546663476,
           59.82997932544513,
           59.6734031842555,
           59.51682704306587,
           59.360250901876235,
           59.2036747606866,
           59.04709861949697,
           58.89052247830734,
           58.73394633711772,
           58.57737019592809,
           58.42079405473846,
           58.26421791354884,
           58.1076417723592,
           57.95106563116958,
           57.79448948997994,
           57.637913348790306,
           57.48133720760069,
           57.32476106641104,
           57.168184925221425,
           57.01160878403179,
           56.85503264284216,
           56.69845650165253,
           56.54188036046291,
           56.38530421927328,
           56.22872807808364,
           56.07215193689401,
           55.91557579570438,
           55.75899965451475,
           55.60242351332512,
           55.445847372135496,
           55.28927123094586,
           55.132695089756226,
           54.9761189485666,
           54.81954280737697,
           54.662966666187344,
           54.50639052499771,
           54.34981438380808,
           54.19323824261845,
           54.03666210142882,
           53.88008596023919,
           53.72350981904955,
           53.56693367785993,
           53.4103575366703,
           53.253781395480665,
           53.09720525429104,
           52.94062911310141,
           52.78405297191178,
           52.627476830722145,
           52.47090068953251,
           52.314324548342896,
           52.157748407153264,
           52.00117226596363,
           51.84459612477401,
           51.465203183363286,
           50.97440184184208,
           50.48360050032085,
           49.99279915879963,
           49.50199781727842,
           49.01119647575717,
           48.520395134235955,
           48.02959379271473,
           47.5387924511935,
           47.047991109672296,
           46.55718976815104,
           46.066388426629835,
           45.57558708510861,
           45.084785743587375,
           44.59398440206617,
           44.10318306054494,
           43.612381719023716,
           43.12158037750249,
           42.630779035981256,
           42.13997769446005,
           41.64917635293881,
           41.15837501141759,
           40.667573669896385,
           40.17677232837513,
           39.685970986853924,
           39.1951696453327,
           38.704368303811464,
           38.21356696229026,
           37.722765620769,
           37.24200055779001,
           36.77413931374927,
           36.306278069708526,
           35.83841682566782,
           35.37055558162708,
           34.90269433758634,
           34.4348330935456,
           33.96697184950487,
           33.499110605464146,
           33.03124936142341,
           32.56338811738267,
           32.095526873341946,
           31.627665629301212,
           31.15980438526048,
           30.69194314121974,
           30.224081897179005,
           29.75622065313826,
           29.288359409097545,
           28.820498165056808,
           28.35263692101607,
           27.884775676975327,
           27.41691443293459,
           26.949053188893878,
           26.481191944853137,
           26.013330700812396,
           25.54546945677166,
           25.077608212730944,
           24.609746968690203,
           24.141885724649466,
           23.67402448060873,
           23.20616323656799,
           22.738301992527276,
           22.27044074848653,
           21.802579504445795,
           21.334718260405058,
           20.866857016364342,
           20.3989957723236,
           19.93113452828286,
           19.463273284242128,
           18.99541204020139,
           18.527550796160668,
           18.059689552119927,
           17.591828308079194,
           17.12396706403846,
           16.65610581999772,
           16.188244575957,
           15.72038333191626,
           15.252522087875526,
           14.784660843834788,
           14.316799599794074,
           13.84893835575333,
           13.381077111712589,
           12.913215867671859,
           12.445354623631115,
           12.15348175956183,
           12.037597275463963,
           11.921712791366103,
           11.80582830726821,
           11.69399790719239,
           11.588008587422813,
           11.482019267653184,
           11.3760299478836,
           11.270040628114018,
           11.164051308344447,
           11.058061988574861,
           10.95207266880528,
           10.846794526634078,
           10.747807576018825,
           10.648820625403584,
           10.549833674788331,
           10.450846724173052,
           10.351859773557793,
           10.252872822942537,
           10.153885872327283,
           10.056642377894425,
           9.96282074432012,
           9.868999110745825,
           9.775177477171521,
           9.681355843597215,
           9.587534210022914,
           9.493712576448596,
           9.400323895949352,
           9.313076727426518,
           9.225829558903662,
           9.138582390380819,
           9.051335221857977,
           8.964088053335145,
           8.876840884812303,
           8.791266054221746,
           8.710954170355,
           8.63064228648826,
           8.550330402621512,
           8.470018518754769,
           8.389706634888025,
           8.309394751021259,
           8.234148922581095,
           8.159989686346764,
           8.085830450112443,
           8.011671213878106,
           7.937511977643794,
           7.86335274140949,
           7.793426441857626,
           7.724713017513171,
           7.65599959316873,
           7.587286168824282,
           7.518572744479828,
           7.4488783415506274,
           7.36643121701927,
           7.283984092487905,
           7.201536967956563,
           7.119089843425204,
           7.036642718893839,
           6.9541955943624885,
           6.8717484698311395,
           6.789301345299777,
           6.706854220768427,
           6.624407096237078,
           6.541959971705712,
           6.459512847174362,
           6.377065722643011,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           62.157047876893316,
           62.17882096712212,
           62.20059405735091,
           62.22236714757971,
           62.244140237808516,
           62.265913328037314,
           62.28768641826611,
           62.30945950849491,
           62.33123259872371,
           62.35300568895251,
           62.374778779181305,
           62.39655186941011,
           62.4183249596389,
           62.44009804986771,
           62.461871140096505,
           62.48364423032531,
           62.5054173205541,
           62.52719041078291,
           62.548963501011706,
           62.5707365912405,
           62.5925096814693,
           62.6142827716981,
           62.6360558619269,
           62.657828952155704,
           62.67960204238449,
           62.7013751326133,
           62.7231482228421,
           62.74492131307089,
           62.766694403299695,
           62.78846749352849,
           62.81024058375729,
           62.83201367398609,
           62.85378676421488,
           62.875559854443686,
           62.897332944672485,
           62.91910603490128,
           62.94087912513009,
           62.96265221535888,
           62.984425305587685,
           63.006198395816476,
           63.02797148604528,
           63.04974457627408,
           63.07151766650288,
           63.09329075673168,
           63.115063846960474,
           63.13683693718928,
           63.15861002741808,
           63.180383117646876,
           63.20215620787567,
           63.22392929810447,
           63.24570238833327,
           63.26747547856207,
           63.289248568790875,
           63.311021659019666,
           63.33279474924847,
           63.35456783947727,
           63.37634092970607,
           63.39811401993487,
           63.419887110163664,
           63.44166020039246,
           63.46343329062126,
           63.48520638085006,
           63.50697947107886,
           63.52875256130766,
           63.55052565153646,
           63.57229874176526,
           63.59407183199406,
           63.615844922222855,
           63.63761801245166,
           63.65939110268045,
           63.68116419290925,
           63.70293728313805,
           63.72471037336685,
           63.74648346359565,
           63.76825655382445,
           63.79002964405325,
           63.81180273428205,
           63.833575824510845,
           63.85534891473965,
           63.87712200496845,
           63.899959796304934,
           63.923329934947176,
           63.94670007358943,
           63.97007021223168,
           63.8698100691822,
           63.74482386979437,
           63.61983767040655,
           63.49485147101872,
           63.338275372660945,
           63.18169923147132,
           63.02512309028169,
           62.86854694909206,
           62.711970807902425,
           62.55539466671279,
           62.39881852552317,
           62.24224238433354,
           62.085666243143905,
           61.92909010195427,
           61.77251396076464,
           61.61593781957502,
           61.459361678385385,
           61.30278553719576,
           61.14620939600613,
           60.989633254816496,
           60.83305711362687,
           60.67648097243724,
           60.5199048312476,
           60.36332869005798,
           60.20675254886834,
           60.05017640767872,
           59.89360026648908,
           59.73702412529945,
           59.58044798410983,
           59.42387184292019,
           59.26729570173057,
           59.110719560540936,
           58.954143419351304,
           58.79756727816168,
           58.64099113697205,
           58.484414995782416,
           58.327838854592784,
           58.17126271340315,
           58.01468657221352,
           57.8581104310239,
           57.70153428983427,
           57.54495814864464,
           57.38838200745501,
           57.231805866265375,
           57.075229725075744,
           56.91865358388612,
           56.762077442696494,
           56.60550130150686,
           56.44892516031723,
           56.2923490191276,
           56.13577287793797,
           55.97919673674834,
           55.82262059555871,
           55.66604445436908,
           55.50946831317945,
           55.352892171989815,
           55.19631603080019,
           55.03973988961056,
           54.88316374842093,
           54.72658760723131,
           54.57001146604166,
           54.413435324852045,
           54.256859183662414,
           54.100283042472775,
           53.94370690128315,
           53.78713076009351,
           53.630554618903886,
           53.47397847771426,
           53.31740233652462,
           53.160826195335,
           53.00425005414536,
           52.847673912955734,
           52.69109777176611,
           52.53452163057648,
           52.377945489386846,
           52.22136934819722,
           52.06479320700759,
           51.90821706581796,
           51.751640924628326,
           51.5950647834387,
           51.43848864224906,
           51.28191250105944,
           51.12533635986981,
           50.7459434184591,
           50.25514207693789,
           49.76434073541666,
           49.273539393895426,
           48.78273805237423,
           48.29552105875308,
           47.82765981471236,
           47.35979857067163,
           46.891937326630895,
           46.424076082590176,
           45.956214838549414,
           45.488353594508695,
           45.02049235046796,
           44.55263110642722,
           44.0847698623865,
           43.61690861834577,
           43.14904737430503,
           42.68118613026428,
           42.213324886223546,
           41.745463642182834,
           41.27760239814209,
           40.80974115410135,
           40.34187991006065,
           39.874018666019886,
           39.40615742197917,
           38.93829617793842,
           38.470434933897685,
           38.002573689856966,
           37.53471244581621,
           37.06685120177549,
           36.59898995773475,
           36.13112871369401,
           35.6632674696533,
           35.19540622561256,
           34.72754498157182,
           34.259683737531084,
           33.79182249349034,
           33.323961249449624,
           32.85610000540889,
           32.38823876136814,
           31.920377517327434,
           31.45251627328669,
           30.984655029245953,
           30.51679378520522,
           30.04893254116448,
           29.581071297123746,
           29.113210053083023,
           28.645348809042286,
           28.17748756500155,
           27.709626320960812,
           27.241765076920068,
           26.773903832879352,
           26.306042588838615,
           25.83818134479788,
           25.370320100757137,
           24.90245885671642,
           24.43459761267568,
           23.966736368634947,
           23.498875124594207,
           23.031013880553466,
           22.563152636512754,
           22.095291392472014,
           21.627430148431273,
           21.15956890439054,
           20.69170766034982,
           20.22384641630908,
           19.75598517226834,
           19.288123928227606,
           18.820262684186865,
           18.35240144014615,
           17.88454019610541,
           17.41667895206467,
           16.948817708023935,
           16.480956463983198,
           16.013095219942475,
           15.545233975901743,
           15.077372731861004,
           14.609511487820267,
           14.14165024377955,
           13.673788999738813,
           13.205927755698067,
           12.738066511657335,
           12.270205267616596,
           11.978332403547311,
           11.862447919449442,
           11.751070936611338,
           11.645081616841761,
           11.539092297072175,
           11.433102977302598,
           11.327113657532971,
           11.221124337763387,
           11.115135017993804,
           11.009145698224232,
           10.903703438021669,
           10.80471648740641,
           10.70572953679113,
           10.606742586175876,
           10.507755635560638,
           10.408768684945384,
           10.309781734330105,
           10.210794783714844,
           10.11309590867851,
           10.019274275104209,
           9.925452641529882,
           9.831631007955576,
           9.737809374381282,
           9.643987740806976,
           9.55016610723267,
           9.456344473658369,
           9.36855210609732,
           9.281304937574477,
           9.194057769051643,
           9.106810600528785,
           9.019563432005945,
           8.9323162634831,
           8.845315026826789,
           8.76500314296004,
           8.684691259093274,
           8.60437937522653,
           8.524067491359789,
           8.44375560749304,
           8.363443723626299,
           8.28660328696307,
           8.212444050728733,
           8.138284814494433,
           8.064125578260102,
           7.98996634202578,
           7.915807105791442,
           7.844194909021674,
           7.775481484677212,
           7.706768060332781,
           7.638054635988325,
           7.569341211643883,
           7.500627787299437,
           7.422104577107216,
           7.339657452575859,
           7.257210328044501,
           7.174763203513136,
           7.092316078981794,
           7.009868954450436,
           6.927421829919071,
           6.84497470538772,
           6.76252758085637,
           6.680080456325009,
           6.597633331793658,
           6.515186207262309,
           6.432739082730944,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           61.98718604918173,
           62.008959139410535,
           62.03073222963933,
           62.052505319868125,
           62.07427841009692,
           62.09605150032573,
           62.11782459055453,
           62.139597680783325,
           62.161370771012116,
           62.18314386124092,
           62.20491695146972,
           62.226690041698525,
           62.248463131927316,
           62.270236222156115,
           62.29200931238491,
           62.31378240261372,
           62.335555492842516,
           62.357328583071315,
           62.37910167330011,
           62.40087476352892,
           62.42264785375771,
           62.444420943986515,
           62.46619403421531,
           62.48796712444411,
           62.50974021467291,
           62.53151330490171,
           62.553286395130506,
           62.575059485359304,
           62.59683257558811,
           62.6186056658169,
           62.640378756045706,
           62.6621518462745,
           62.6839249365033,
           62.705698026732094,
           62.7274711169609,
           62.74924420718969,
           62.771017297418496,
           62.7927903876473,
           62.81456347787609,
           62.8363365681049,
           62.85810965833369,
           62.879882748562494,
           62.901655838791285,
           62.92342892902009,
           62.94520201924888,
           62.96697510947769,
           62.98874819970649,
           63.010521289935284,
           63.032294380164075,
           63.05406747039288,
           63.075840560621685,
           63.09761365085048,
           63.11938674107928,
           63.14115983130807,
           63.16293292153688,
           63.184706011765684,
           63.206479101994475,
           63.22825219222328,
           63.25002528245207,
           63.27179837268088,
           63.29357146290967,
           63.31534455313847,
           63.33711764336728,
           63.35889073359607,
           63.380663823824875,
           63.402436914053666,
           63.42421000428247,
           63.44598309451126,
           63.46775618474007,
           63.48952927496886,
           63.511302365197665,
           63.53189597630306,
           63.55131010188814,
           63.57072422747323,
           63.59013835305832,
           63.60955247864341,
           63.628966604228495,
           63.64838072981359,
           63.66779485539867,
           63.68720898098376,
           63.70662310656885,
           63.726037232153935,
           63.74545135773903,
           63.764865483324115,
           63.61105172074152,
           63.42259238052538,
           63.23413304030926,
           63.045673700093126,
           62.857214359877,
           62.66875501966088,
           62.48029567944475,
           62.29183633922862,
           62.10337699901249,
           61.914917658796355,
           61.726458318580235,
           61.53799897836411,
           61.35485354788186,
           61.19827740669222,
           61.04170126550259,
           60.885125124312964,
           60.72854898312333,
           60.57197284193371,
           60.415396700744076,
           60.258820559554444,
           60.10224441836482,
           59.94566827717519,
           59.789092135985555,
           59.63251599479593,
           59.47593985360629,
           59.31936371241667,
           59.162787571227035,
           59.0062114300374,
           58.849635288847786,
           58.69305914765815,
           58.536483006468515,
           58.37990686527888,
           58.22333072408925,
           58.06675458289963,
           57.910178441709995,
           57.75360230052036,
           57.59702615933073,
           57.4404500181411,
           57.283873876951475,
           57.12729773576185,
           56.97072159457222,
           56.814145453382594,
           56.65756931219296,
           56.50099317100333,
           56.3444170298137,
           56.187840888624066,
           56.03126474743444,
           55.8746886062448,
           55.71811246505518,
           55.561536323865546,
           55.40496018267592,
           55.24838404148629,
           55.09180790029666,
           54.935231759107026,
           54.778655617917394,
           54.62207947672776,
           54.46550333553814,
           54.30892719434851,
           54.15235105315888,
           53.99577491196926,
           53.83919877077962,
           53.682622629589986,
           53.526046488400354,
           53.36947034721072,
           53.212894206021105,
           53.05631806483146,
           52.89974192364184,
           52.74316578245221,
           52.58658964126257,
           52.430013500072945,
           52.27343735888331,
           52.11686121769368,
           51.96028507650405,
           51.80370893531442,
           51.6471327941248,
           51.49055665293517,
           51.33398051174554,
           51.177404370555905,
           51.02082822936627,
           50.864252088176656,
           50.707675946987024,
           50.551099805797385,
           50.39452366460776,
           50.03386208090714,
           49.571157775951065,
           49.10845347099497,
           48.64574916603887,
           48.18304486108279,
           47.720340556126665,
           47.257636251170595,
           46.7949319462145,
           46.332227641258406,
           45.869523336302336,
           45.40681903134622,
           44.94411472639014,
           44.481410421434035,
           44.018706116477944,
           43.55600181152187,
           43.09329750656576,
           42.63059320160967,
           42.16788889665357,
           41.705184591697474,
           41.242480286741404,
           40.7797759817853,
           40.31707167682921,
           39.85436737187313,
           39.39166306691701,
           38.928958761960935,
           38.46625445700484,
           38.003550152048746,
           37.54084584709267,
           37.07814154213655,
           36.61543723718047,
           36.152732932224374,
           35.690028627268276,
           35.22732432231221,
           34.7646200173561,
           34.3019157124,
           33.839211407443905,
           33.376507102487814,
           32.91380279753174,
           32.45109849257564,
           31.98839418761954,
           31.525689882663464,
           31.06298557770737,
           30.600281272751275,
           30.137576967795177,
           29.67487266283908,
           29.21216835788298,
           28.749464052926903,
           28.286759747970805,
           27.82405544301471,
           27.361351138058613,
           26.898646833102518,
           26.43594252814644,
           25.973238223190343,
           25.510533918234245,
           25.047829613278147,
           24.585125308322077,
           24.12242100336598,
           23.65971669840988,
           23.197012393453782,
           22.734308088497684,
           22.271603783541607,
           21.808899478585513,
           21.346195173629415,
           20.88349086867332,
           20.420786563717243,
           19.958082258761145,
           19.495377953805047,
           19.03267364884895,
           18.569969343892854,
           18.10726503893678,
           17.644560733980683,
           17.181856429024585,
           16.719152124068486,
           16.256447819112392,
           15.793743514156317,
           15.331039209200219,
           14.868334904244122,
           14.405630599288024,
           13.942926294331944,
           13.480221989375847,
           13.01751768441975,
           12.554813379463653,
           12.092109074507558,
           11.808143966030284,
           11.702154646260702,
           11.596165326491125,
           11.490176006721546,
           11.384186686951963,
           11.278197367182385,
           11.172208047412756,
           11.066218727643173,
           10.960612349409256,
           10.861625398794008,
           10.762638448178723,
           10.663651497563464,
           10.564664546948183,
           10.465677596332931,
           10.36669064571769,
           10.267703695102437,
           10.16954943946257,
           10.075727805888263,
           9.981906172313966,
           9.888084538739665,
           9.794262905165338,
           9.700441271591032,
           9.606619638016738,
           9.512798004442432,
           9.424027484768118,
           9.336780316245283,
           9.249533147722445,
           9.162285979199602,
           9.075038810676768,
           8.987791642153912,
           8.900544473631069,
           8.819052115565054,
           8.738740231698317,
           8.658428347831569,
           8.578116463964804,
           8.497804580098059,
           8.417492696231317,
           8.339057651345037,
           8.264898415110721,
           8.190739178876406,
           8.116579942642069,
           8.04242070640777,
           7.968261470173437,
           7.89496337618571,
           7.826249951841264,
           7.7575365274968275,
           7.688823103152367,
           7.6201096788079346,
           7.551396254463478,
           7.47777793719515,
           7.395330812663797,
           7.312883688132448,
           7.23043656360109,
           7.1479894390697325,
           7.065542314538368,
           6.983095190007026,
           6.900648065475667,
           6.818200940944301,
           6.735753816412952,
           6.653306691881602,
           6.57085956735024,
           6.488412442818889,
           6.4059653182875405,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           61.81787277681106,
           61.83964586703986,
           61.861418957268654,
           61.88319204749745,
           61.90496513772625,
           61.926738227955056,
           61.948511318183854,
           61.97028440841265,
           61.992057498641444,
           62.01383058887025,
           62.035603679099054,
           62.057376769327846,
           62.07914985955664,
           62.10092294978544,
           62.12269604001425,
           62.14446913024305,
           62.166242220471844,
           62.18801531070065,
           62.20978840092944,
           62.231561491158246,
           62.25333458138704,
           62.27510767161584,
           62.29688076184464,
           62.31865385207344,
           62.34042694230224,
           62.362200032531035,
           62.383973122759826,
           62.40574621298864,
           62.42751930321743,
           62.44929239344623,
           62.471065483675034,
           62.492838573903825,
           62.51461166413264,
           62.53638475436142,
           62.55815784459023,
           62.57993093481902,
           62.60170402504782,
           62.62347711527663,
           62.64525020550542,
           62.667023295734225,
           62.688796385963016,
           62.71056947619182,
           62.73234256642061,
           62.75411565664942,
           62.77588874687822,
           62.797661837107015,
           62.81943492733582,
           62.84120801756461,
           62.862981107793416,
           62.88475419802221,
           62.90652728825101,
           62.928300378479804,
           62.95007346870861,
           62.971846558937415,
           62.993619649166206,
           63.013033777560516,
           63.03244790314561,
           63.051862028730696,
           63.071276154315775,
           63.09069027990087,
           63.110104405485956,
           63.12951853107104,
           63.148932656656136,
           63.168346782241215,
           63.1877609078263,
           63.207175033411396,
           63.22658915899648,
           63.24600328458157,
           63.26541741016666,
           63.28483153575174,
           63.304245661336836,
           63.32365978692192,
           63.34307391250701,
           63.362488038092096,
           63.38190216367719,
           63.40131628926227,
           63.42073041484736,
           63.440144540432456,
           63.459558666017536,
           63.47897279160263,
           63.498386917187716,
           63.517801042772795,
           63.53721516835789,
           63.556629293942976,
           63.40281553136038,
           63.21435619114425,
           63.02589685092813,
           62.83743751071199,
           62.648978170495866,
           62.46051883027974,
           62.27205949006361,
           62.08360014984748,
           61.89514080963136,
           61.70668146941522,
           61.5182221291991,
           61.32976278898297,
           61.14130344876684,
           60.95284410855071,
           60.76438476833458,
           60.57592542811846,
           60.38746608790233,
           60.1990067476862,
           60.01054740747007,
           59.822088067253944,
           59.633628727037824,
           59.44516938682169,
           59.25671004660556,
           59.06825070638944,
           58.8797913661733,
           58.69133202595718,
           58.50287268574105,
           58.314413345524926,
           58.1259540053088,
           57.95875016907909,
           57.80217402788947,
           57.64559788669984,
           57.4890217455102,
           57.33244560432057,
           57.17586946313094,
           57.019293321941305,
           56.86271718075167,
           56.70614103956204,
           56.549564898372424,
           56.39298875718279,
           56.23641261599316,
           56.07983647480354,
           55.9232603336139,
           55.76668419242427,
           55.61010805123464,
           55.45353191004501,
           55.29695576885538,
           55.140379627665745,
           54.98380348647613,
           54.827227345286495,
           54.670651204096856,
           54.51407506290724,
           54.35749892171761,
           54.200922780527975,
           54.04434663933834,
           53.88777049814871,
           53.73119435695908,
           53.574618215769455,
           53.41804207457982,
           53.2614659333902,
           53.10488979220056,
           52.948313651010935,
           52.7917375098213,
           52.63516136863167,
           52.47858522744205,
           52.32200908625241,
           52.16543294506279,
           52.00885680387315,
           51.85228066268352,
           51.695704521493894,
           51.539128380304255,
           51.38255223911463,
           51.225976097925,
           51.06939995673537,
           50.91282381554574,
           50.75624767435611,
           50.599671533166486,
           50.443095391976854,
           50.28651925078722,
           50.12994310959759,
           49.97336696840796,
           49.816790827218334,
           49.66021468602871,
           49.299553102328076,
           48.83684879737201,
           48.37414449241591,
           47.91144018745982,
           47.44873588250374,
           46.986031577547614,
           46.523327272591544,
           46.060622967635446,
           45.59791866267935,
           45.13521435772327,
           44.67251005276715,
           44.20980574781108,
           43.747101442854984,
           43.284397137898885,
           42.82169283294281,
           42.35898852798671,
           41.89628422303062,
           41.433579918074514,
           40.97087561311842,
           40.508171308162346,
           40.04546700320624,
           39.58276269825015,
           39.12005839329407,
           38.65735408833796,
           38.19464978338188,
           37.731945478425786,
           37.26924117346969,
           36.80653686851362,
           36.3438325635575,
           35.88112825860142,
           35.418423953645316,
           34.955719648689225,
           34.49301534373315,
           34.03031103877704,
           33.56760673382095,
           33.10490242886485,
           32.642198123908756,
           32.179493818952686,
           31.71678951399658,
           31.254085209040486,
           30.791380904084413,
           30.328676599128315,
           29.865972294172217,
           29.40326798921612,
           28.940563684260024,
           28.477859379303926,
           28.015155074347845,
           27.552450769391754,
           27.089746464435652,
           26.627042159479558,
           26.16433785452346,
           25.701633549567383,
           25.238929244611285,
           24.77622493965519,
           24.313520634699096,
           23.85081632974302,
           23.38811202478692,
           22.925407719830826,
           22.462703414874724,
           21.999999109918633,
           21.537294804962556,
           21.074590500006455,
           20.61188619505036,
           20.149181890094262,
           19.715485929189494,
           19.28255333927627,
           18.84962074936304,
           18.416688159449812,
           17.983755569536587,
           17.550822979623383,
           17.117890389710155,
           16.68495779979693,
           16.2520252098837,
           15.819092619970474,
           15.386160030057269,
           14.953227440144042,
           14.520294850230814,
           14.087362260317589,
           13.65442967040438,
           13.221497080491151,
           12.788564490577924,
           12.355631900664697,
           11.922699310751472,
           11.653238355910085,
           11.5472490361405,
           11.441259716370926,
           11.335270396601347,
           11.229281076831763,
           11.123291757062184,
           11.017521260796842,
           10.918534310181585,
           10.819547359566322,
           10.720560408951073,
           10.621573458335789,
           10.52258650772053,
           10.423599557105248,
           10.324612606489996,
           10.226002970246656,
           10.132181336672335,
           10.038359703098035,
           9.944538069523729,
           9.85071643594943,
           9.75689480237513,
           9.663073168800802,
           9.569251535226496,
           9.47950286343896,
           9.392255694916116,
           9.305008526393253,
           9.217761357870417,
           9.130514189347581,
           9.043267020824738,
           8.956019852301901,
           8.873101088170108,
           8.79278920430336,
           8.712477320436593,
           8.632165436569856,
           8.551853552703108,
           8.471541668836341,
           8.391512015727034,
           8.317352779492703,
           8.243193543258382,
           8.169034307024065,
           8.09487507078975,
           8.020715834555412,
           7.946556598321113,
           7.877018419005317,
           7.808304994660872,
           7.739591570316426,
           7.670878145971989,
           7.6021647216275285,
           7.533451297283096,
           7.4510041727517455,
           7.3685570482203895,
           7.286109923689038,
           7.203662799157687,
           7.121215674626329,
           7.0387685500949715,
           6.956321425563607,
           6.873874301032265,
           6.791427176500907,
           6.708980051969541,
           6.626532927438191,
           6.544085802906841,
           6.461638678375479,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           61.64855950444037,
           61.67033259466916,
           61.69210568489797,
           61.713878775126766,
           61.735651865355564,
           61.75742495558437,
           61.77919804581316,
           61.800971136041966,
           61.82274422627077,
           61.844517316499555,
           61.86629040672836,
           61.88806349695716,
           61.90983658718596,
           61.931609677414755,
           61.95338276764356,
           61.97515585787236,
           61.99692894810115,
           62.018702038329955,
           62.040475128558754,
           62.06224821878756,
           62.08402130901635,
           62.10579439924515,
           62.127567489473954,
           62.14934057970275,
           62.17111366993155,
           62.19288676016035,
           62.21465985038915,
           62.236432940617945,
           62.25820603084675,
           62.27997912107554,
           62.30175221130435,
           62.323525301533145,
           62.34529839176194,
           62.36707148199074,
           62.38884457221954,
           62.41061766244834,
           62.43239075267714,
           62.45416384290594,
           62.474757453232876,
           62.49417157881797,
           62.51358570440305,
           62.53299982998814,
           62.55241395557323,
           62.571828081158316,
           62.5912422067434,
           62.61065633232849,
           62.630070457913575,
           62.64948458349867,
           62.668898709083756,
           62.688312834668835,
           62.70772696025393,
           62.72714108583902,
           62.74655521142411,
           62.765969337009196,
           62.78538346259428,
           62.80479758817937,
           62.824211713764456,
           62.84362583934954,
           62.86303996493463,
           62.88245409051972,
           62.901868216104816,
           62.921282341689896,
           62.94069646727498,
           62.960110592860076,
           62.97952471844516,
           62.99893884403025,
           63.018352969615336,
           63.03776709520043,
           63.057181220785516,
           63.07659534637061,
           63.09600947195569,
           63.115423597540776,
           63.13483772312587,
           63.154251848710956,
           63.17366597429604,
           63.193080099881136,
           63.212494225466216,
           63.2319083510513,
           63.251322476636396,
           63.270736602221476,
           63.29015072780657,
           63.309564853391656,
           63.32897897897675,
           63.348393104561836,
           63.194579341979235,
           63.006120001763094,
           62.817660661546974,
           62.62920132133085,
           62.44074198111472,
           62.2522826408986,
           62.06382330068246,
           61.875363960466345,
           61.6869046202502,
           61.498445280034076,
           61.309985939817956,
           61.12152659960182,
           60.933067259385695,
           60.74460791916957,
           60.55614857895344,
           60.36768923873731,
           60.179229898521186,
           59.99077055830506,
           59.802311218088924,
           59.61385187787279,
           59.42539253765668,
           59.23693319744055,
           59.04847385722441,
           58.86001451700829,
           58.671555176792154,
           58.48309583657603,
           58.294636496359914,
           58.10617715614377,
           57.91771781592765,
           57.72925847571151,
           57.54079913549539,
           57.35233979527926,
           57.163880455063136,
           56.97542111484701,
           56.78696177463088,
           56.59850243441475,
           56.41004309419863,
           56.221583753982486,
           56.033124413766366,
           55.844665073550246,
           55.656205733334104,
           55.46774639311799,
           55.27928705290185,
           55.09082771268573,
           54.902368372469596,
           54.71922293146589,
           54.562646790276276,
           54.40607064908664,
           54.24949450789701,
           54.09291836670738,
           53.93634222551775,
           53.77976608432813,
           53.6231899431385,
           53.46661380194886,
           53.31003766075923,
           53.153461519569596,
           52.99688537837997,
           52.84030923719035,
           52.683733096000715,
           52.52715695481108,
           52.37058081362145,
           52.21400467243182,
           52.057428531242195,
           51.90085239005256,
           51.74427624886293,
           51.58770010767329,
           51.43112396648367,
           51.27454782529404,
           51.11797168410441,
           50.96139554291479,
           50.80481940172515,
           50.64824326053552,
           50.49166711934589,
           50.33509097815626,
           50.17851483696664,
           50.021938695777,
           49.86536255458737,
           49.70878641339774,
           49.55221027220811,
           49.39563413101848,
           49.23905798982885,
           49.08248184863922,
           48.925905707449594,
           48.56524412374897,
           48.10253981879289,
           47.6398355138368,
           47.1771312088807,
           46.71442690392462,
           46.251722598968506,
           45.789018294012436,
           45.32631398905633,
           44.86360968410024,
           44.40090537914416,
           43.93820107418804,
           43.47549676923197,
           43.012792464275876,
           42.55008815931977,
           42.087383854363694,
           41.6246795494076,
           41.161975244451504,
           40.699270939495406,
           40.236566634539315,
           39.77386232958324,
           39.31115802462713,
           38.84845371967104,
           38.385749414714965,
           37.923045109758846,
           37.46034080480277,
           36.997636499846664,
           36.53493219489057,
           36.0722278899345,
           35.60952358497838,
           35.14681928002231,
           34.6841149750662,
           34.22141067011011,
           33.75870636515403,
           33.296002060197935,
           32.833297755241844,
           32.37059345028574,
           31.907889145329648,
           31.445184840373575,
           30.98248053541747,
           30.51977623046137,
           30.057071925505298,
           29.5943676205492,
           29.131663315593105,
           28.668959010637007,
           28.21923211733371,
           27.786299527420486,
           27.353366937507282,
           26.920434347594053,
           26.487501757680825,
           26.0545691677676,
           25.62163657785437,
           25.188703987941167,
           24.75577139802794,
           24.322838808114714,
           23.88990621820149,
           23.45697362828828,
           23.024041038375053,
           22.591108448461824,
           22.158175858548603,
           21.725243268635374,
           21.292310678722167,
           20.85937808880894,
           20.426445498895713,
           19.99351290898249,
           19.56058031906928,
           19.127647729156052,
           18.694715139242827,
           18.261782549329602,
           17.828849959416374,
           17.395917369503167,
           16.96298477958994,
           16.530052189676717,
           16.097119599763488,
           15.664187009850263,
           15.231254419937057,
           14.798321830023829,
           14.365389240110602,
           13.932456650197377,
           13.499524060284166,
           13.06659147037094,
           12.633658880457713,
           12.200726290544488,
           11.76779370063126,
           11.498332745789872,
           11.392343426020286,
           11.286354106250709,
           11.180364786481134,
           11.074430172184407,
           10.975443221569153,
           10.876456270953897,
           10.777469320338636,
           10.678482369723376,
           10.579495419108126,
           10.480508468492841,
           10.381521517877582,
           10.282534567262303,
           10.188634867456415,
           10.094813233882109,
           10.000991600307788,
           9.90716996673349,
           9.813348333159182,
           9.719526699584884,
           9.625705066010584,
           9.534978242109776,
           9.447731073586914,
           9.360483905064083,
           9.273236736541241,
           9.185989568018378,
           9.098742399495544,
           9.011495230972706,
           8.927150060775123,
           8.84683817690838,
           8.766526293041636,
           8.68621440917489,
           8.605902525308123,
           8.525590641441385,
           8.445278757574638,
           8.369807143874686,
           8.295647907640369,
           8.221488671406037,
           8.147329435171716,
           8.0731701989374,
           7.999010962703085,
           7.927786886169369,
           7.859073461824914,
           7.790360037480472,
           7.721646613136025,
           7.652933188791581,
           7.584219764447144,
           7.506677532839686,
           7.424230408308328,
           7.341783283776977,
           7.25933615924562,
           7.176889034714268,
           7.094441910182919,
           7.011994785651561,
           6.929547661120203,
           6.847100536588838,
           6.764653412057497,
           6.682206287526138,
           6.599759162994773,
           6.517312038463422,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           61.479246232069684,
           61.50101932229849,
           61.52279241252728,
           61.54456550275608,
           61.566338592984884,
           61.588111683213675,
           61.609884773442474,
           61.63165786367128,
           61.65343095390007,
           61.67520404412888,
           61.69697713435768,
           61.71875022458647,
           61.74052331481527,
           61.762296405044076,
           61.784069495272874,
           61.80584258550167,
           61.82761567573047,
           61.849388765959276,
           61.87116185618807,
           61.89293494641687,
           61.91470803664566,
           61.93648112687447,
           61.955895254490315,
           61.9753093800754,
           61.99472350566049,
           62.01413763124558,
           62.03355175683066,
           62.05296588241575,
           62.07238000800084,
           62.09179413358592,
           62.111208259171015,
           62.13062238475611,
           62.15003651034119,
           62.16945063592628,
           62.18886476151136,
           62.208278887096455,
           62.22769301268154,
           62.24710713826663,
           62.266521263851715,
           62.28593538943681,
           62.305349515021895,
           62.324763640606974,
           62.34417776619207,
           62.36359189177716,
           62.38300601736224,
           62.40242014294733,
           62.42183426853242,
           62.44124839411751,
           62.460662519702595,
           62.48007664528768,
           62.49949077087277,
           62.518904896457855,
           62.53831902204294,
           62.557733147628035,
           62.57714727321313,
           62.596561398798215,
           62.615975524383295,
           62.63538964996839,
           62.654803775553475,
           62.67421790113856,
           62.69363202672365,
           62.71304615230874,
           62.73246027789382,
           62.751874403478915,
           62.771288529064,
           62.790702654649095,
           62.81011678023418,
           62.82953090581926,
           62.848945031404355,
           62.86835915698944,
           62.88777328257453,
           62.907187408159615,
           62.92660153374471,
           62.94601565932979,
           62.96542978491488,
           62.98484391049997,
           63.004258036085055,
           63.02367216167015,
           63.043086287255235,
           63.06250041284032,
           63.08191453842541,
           63.101328664010495,
           63.12074278959559,
           63.140156915180675,
           62.98634315259809,
           62.79788381238195,
           62.60942447216582,
           62.4209651319497,
           62.232505791733566,
           62.044046451517445,
           61.85558711130131,
           61.667127771085184,
           61.47866843086905,
           61.29020909065293,
           61.10174975043681,
           60.913290410220675,
           60.72483107000454,
           60.536371729788414,
           60.34791238957228,
           60.15945304935616,
           59.97099370914003,
           59.782534368923905,
           59.59407502870778,
           59.40561568849164,
           59.21715634827552,
           59.02869700805939,
           58.84023766784326,
           58.65177832762714,
           58.463318987411,
           58.27485964719489,
           58.08640030697875,
           57.897940966762626,
           57.709481626546506,
           57.521022286330364,
           57.33256294611425,
           57.14410360589811,
           56.95564426568198,
           56.76718492546586,
           56.57872558524973,
           56.3902662450336,
           56.201806904817474,
           56.01334756460135,
           55.82488822438522,
           55.63642888416909,
           55.447969543952965,
           55.25951020373684,
           55.0710508635207,
           54.88259152330458,
           54.69413218308844,
           54.505672842872315,
           54.3172135026562,
           54.12875416244006,
           53.94029482222394,
           53.751835482007806,
           53.56337614179168,
           53.37491680157555,
           53.186457461359424,
           52.99799812114329,
           52.80953878092717,
           52.62107944071103,
           52.432620100494916,
           52.24416076027879,
           52.055701420062654,
           51.86724207984653,
           51.67878273963039,
           51.490323399414265,
           51.32311955266308,
           51.16654341147345,
           51.00996727028382,
           50.85339112909418,
           50.69681498790455,
           50.54023884671493,
           50.383662705525296,
           50.22708656433567,
           50.07051042314603,
           49.91393428195641,
           49.757358140766776,
           49.600781999577144,
           49.44420585838753,
           49.28762971719789,
           49.131053576008256,
           48.974477434818624,
           48.81790129362899,
           48.66132515243937,
           48.504749011249736,
           48.348172870060104,
           48.191596728870486,
           47.83093514516986,
           47.368230840213776,
           46.90552653525768,
           46.44282223030159,
           45.98011792534551,
           45.51741362038939,
           45.054709315433314,
           44.59200501047722,
           44.12930070552113,
           43.666596400565055,
           43.203892095608936,
           42.74118779065285,
           42.27848348569675,
           41.815779180740655,
           41.35307487578458,
           40.89037057082849,
           40.427666265872396,
           39.9649619609163,
           39.5022576559602,
           39.03955335100412,
           38.57684904604802,
           38.11414474109193,
           37.65144043613585,
           37.18873613117973,
           36.726031826223654,
           36.290045715564716,
           35.8571131256515,
           35.424180535738294,
           34.991247945825044,
           34.55831535591184,
           34.12538276599861,
           33.69245017608539,
           33.25951758617218,
           32.82658499625895,
           32.39365240634572,
           31.960719816432494,
           31.527787226519276,
           31.09485463660607,
           30.661922046692837,
           30.228989456779612,
           29.7960568668664,
           29.363124276953176,
           28.93019168703995,
           28.497259097126726,
           28.064326507213497,
           27.631393917300272,
           27.198461327387065,
           26.76552873747384,
           26.33259614756061,
           25.899663557647386,
           25.466730967734158,
           25.033798377820954,
           24.60086578790773,
           24.1679331979945,
           23.735000608081272,
           23.302068018168065,
           22.86913542825484,
           22.436202838341615,
           22.003270248428386,
           21.57033765851516,
           21.137405068601954,
           20.70447247868873,
           20.2715398887755,
           19.838607298862275,
           19.405674708949068,
           18.972742119035843,
           18.539809529122614,
           18.10687693920939,
           17.673944349296164,
           17.241011759382957,
           16.80807916946973,
           16.375146579556503,
           15.942213989643275,
           15.50928139973005,
           15.076348809816844,
           14.643416219903617,
           14.210483629990389,
           13.777551040077164,
           13.344618450163953,
           12.911685860250726,
           12.4787532703375,
           12.045820680424274,
           11.612888090511047,
           11.343427135669659,
           11.237437815900075,
           11.131448496130497,
           11.032352132956722,
           10.933365182341463,
           10.834378231726207,
           10.735391281110951,
           10.636404330495692,
           10.537417379880429,
           10.438430429265182,
           10.339443478649896,
           10.245088398240469,
           10.151266764666168,
           10.05744513109187,
           9.963623497517563,
           9.869801863943245,
           9.775980230368944,
           9.682158596794638,
           9.59045362078058,
           9.503206452257745,
           9.415959283734903,
           9.32871211521204,
           9.24146494668921,
           9.154217778166368,
           9.066970609643505,
           8.981199033380161,
           8.90088714951342,
           8.820575265646655,
           8.740263381779911,
           8.659951497913168,
           8.579639614046421,
           8.499327730179653,
           8.422261508256664,
           8.348102272022343,
           8.273943035788022,
           8.199783799553705,
           8.125624563319374,
           8.051465327085054,
           7.978555353333413,
           7.90984192898897,
           7.841128504644525,
           7.772415080300069,
           7.703701655955627,
           7.634988231611182,
           7.562350892927625,
           7.479903768396282,
           7.397456643864917,
           7.315009519333559,
           7.232562394802208,
           7.150115270270852,
           7.067668145739501,
           6.985221021208151,
           6.902773896676793,
           6.820326772145435,
           6.737879647614069,
           6.655432523082728,
           6.57298539855137,
           6.490538274020005,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           61.30993295969901,
           61.33170604992781,
           61.35347914015661,
           61.37525223038541,
           61.397025320614205,
           61.41761893016269,
           61.43703305574777,
           61.456447181332855,
           61.47586130691795,
           61.495275432503036,
           61.51468955808813,
           61.534103683673216,
           61.553517809258295,
           61.57293193484339,
           61.592346060428476,
           61.61176018601357,
           61.631174311598656,
           61.650588437183735,
           61.67000256276883,
           61.689416688353916,
           61.708830813939,
           61.72824493952409,
           61.74765906510918,
           61.76707319069426,
           61.78648731627935,
           61.80590144186445,
           61.825315567449536,
           61.84472969303461,
           61.86414381861971,
           61.883557944204796,
           61.90297206978988,
           61.922386195374976,
           61.941800320960056,
           61.961214446545156,
           61.980628572130236,
           62.00004269771532,
           62.01945682330041,
           62.038870948885496,
           62.05828507447059,
           62.077699200055676,
           62.09711332564076,
           62.11652745122585,
           62.135941576810936,
           62.15535570239603,
           62.174769827981116,
           62.194183953566196,
           62.21359807915129,
           62.23301220473638,
           62.25242633032147,
           62.271840455906556,
           62.29125458149164,
           62.310668707076736,
           62.33008283266182,
           62.3494969582469,
           62.368911083831996,
           62.38832520941708,
           62.40773933500218,
           62.42715346058726,
           62.44656758617235,
           62.465981711757436,
           62.48539583734252,
           62.50480996292761,
           62.5242240885127,
           62.54363821409779,
           62.563052339682876,
           62.58246646526796,
           62.60188059085305,
           62.621294716438136,
           62.64070884202323,
           62.66012296760832,
           62.6795370931934,
           62.69895121877849,
           62.718365344363576,
           62.73777946994866,
           62.75719359553376,
           62.77660772111884,
           62.79602184670393,
           62.81543597228902,
           62.8348500978741,
           62.8542642234592,
           62.87367834904428,
           62.89309247462937,
           62.91250660021446,
           62.93192072579954,
           62.77810696321695,
           62.589647623000815,
           62.40118828278469,
           62.21272894256855,
           62.024269602352426,
           61.83581026213631,
           61.64735092192018,
           61.45889158170405,
           61.27043224148792,
           61.08197290127178,
           60.89351356105567,
           60.70505422083954,
           60.51659488062341,
           60.328135540407274,
           60.13967620019115,
           59.951216859975034,
           59.7627575197589,
           59.574298179542765,
           59.385838839326645,
           59.19737949911051,
           59.008920158894384,
           58.82046081867826,
           58.63200147846212,
           58.44354213824601,
           58.255082798029875,
           58.06662345781375,
           57.87816411759761,
           57.68970477738148,
           57.501245437165366,
           57.312786096949225,
           57.124326756733105,
           56.93586741651697,
           56.74740807630084,
           56.55894873608473,
           56.370489395868596,
           56.18203005565246,
           55.993570715436334,
           55.80511137522021,
           55.61665203500409,
           55.42819269478795,
           55.239733354571825,
           55.05127401435571,
           54.86281467413957,
           54.674355333923444,
           54.48589599370732,
           54.29743665349119,
           54.10897731327506,
           53.92051797305893,
           53.73205863284281,
           53.543599292626666,
           53.355139952410546,
           53.166680612194426,
           52.97822127197829,
           52.789761931762165,
           52.60130259154603,
           52.4128432513299,
           52.22438391111379,
           52.03592457089765,
           51.84746523068152,
           51.6590058904654,
           51.47054655024926,
           51.28208721003314,
           51.09362786981701,
           50.90516852960088,
           50.71670918938476,
           50.52824984916862,
           50.339790508952504,
           50.15133116873637,
           49.96287182852024,
           49.774412488304115,
           49.58595314808798,
           49.397493807871854,
           49.209034467655734,
           49.0205751274396,
           48.83211578722348,
           48.643656447007345,
           48.45519710679122,
           48.26673776657509,
           48.083592315049934,
           47.92701617386031,
           47.77044003267068,
           47.613863891481046,
           47.45728775029143,
           47.0966261665908,
           46.633921861634725,
           46.17121755667863,
           45.708513251722536,
           45.24580894676646,
           44.79379190370895,
           44.36085931379575,
           43.92792672388252,
           43.4949941339693,
           43.062061544056085,
           42.62912895414284,
           42.196196364229635,
           41.763263774316414,
           41.33033118440318,
           40.89739859448998,
           40.46446600457675,
           40.03153341466353,
           39.59860082475029,
           39.16566823483707,
           38.732735644923864,
           38.299803055010635,
           37.866870465097406,
           37.4339378751842,
           37.001005285270956,
           36.568072695357756,
           36.13514010544452,
           35.7022075155313,
           35.26927492561809,
           34.83634233570485,
           34.403409745791635,
           33.970477155878406,
           33.53754456596519,
           33.10461197605198,
           32.67167938613875,
           32.23874679622553,
           31.805814206312295,
           31.372881616399077,
           30.939949026485866,
           30.507016436572634,
           30.07408384665941,
           29.641151256746202,
           29.208218666832973,
           28.775286076919752,
           28.342353487006523,
           27.909420897093298,
           27.47648830718007,
           27.043555717266866,
           26.610623127353637,
           26.177690537440412,
           25.744757947527184,
           25.31182535761396,
           24.878892767700755,
           24.445960177787526,
           24.013027587874298,
           23.580094997961073,
           23.147162408047866,
           22.71422981813464,
           22.281297228221412,
           21.848364638308187,
           21.415432048394962,
           20.982499458481755,
           20.549566868568526,
           20.116634278655297,
           19.683701688742076,
           19.25076909882887,
           18.81783650891564,
           18.38490391900241,
           17.95197132908919,
           17.51903873917596,
           17.086106149262754,
           16.653173559349526,
           16.2202409694363,
           15.787308379523076,
           15.354375789609849,
           14.921443199696643,
           14.488510609783415,
           14.055578019870188,
           13.622645429956963,
           13.189712840043752,
           12.756780250130525,
           12.323847660217298,
           11.890915070304072,
           11.457982480390847,
           11.188521525549458,
           11.089261044344317,
           10.990274093729067,
           10.891287143113784,
           10.792300192498525,
           10.69331324188327,
           10.594326291268015,
           10.495339340652754,
           10.396352390037494,
           10.301541929024568,
           10.20772029545024,
           10.113898661875934,
           10.020077028301634,
           9.926255394727336,
           9.83243376115303,
           9.738612127578708,
           9.645928999451394,
           9.558681830928553,
           9.471434662405715,
           9.38418749388288,
           9.296940325360035,
           9.209693156837174,
           9.122445988314343,
           9.03524800598517,
           8.954936122118442,
           8.874624238251698,
           8.794312354384957,
           8.71400047051819,
           8.633688586651447,
           8.553376702784703,
           8.474715872638658,
           8.40055663640432,
           8.326397400170007,
           8.252238163935688,
           8.178078927701367,
           8.10391969146705,
           8.029760455232719,
           7.960610396153029,
           7.891896971808572,
           7.823183547464131,
           7.7544701231196855,
           7.685756698775229,
           7.617043274430787,
           7.5355771284842294,
           7.453130003952872,
           7.370682879421529,
           7.288235754890163,
           7.205788630358806,
           7.123341505827455,
           7.0408943812960985,
           6.958447256764748,
           6.876000132233397,
           6.79355300770204,
           6.711105883170682,
           6.628658758639316,
           6.546211634107975,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           61.13098767278659,
           61.15040179837169,
           61.16981592395676,
           61.189230049541855,
           61.208644175126956,
           61.228058300712036,
           61.24747242629712,
           61.26688655188221,
           61.286300677467295,
           61.30571480305239,
           61.325128928637476,
           61.34454305422256,
           61.36395717980765,
           61.38337130539274,
           61.40278543097783,
           61.422199556562916,
           61.441613682148,
           61.461027807733096,
           61.480441933318176,
           61.499856058903276,
           61.51927018448835,
           61.53868431007345,
           61.55809843565852,
           61.577512561243616,
           61.5969266868287,
           61.61634081241379,
           61.63575493799888,
           61.65516906358396,
           61.674583189169056,
           61.69399731475416,
           61.71341144033923,
           61.73282556592433,
           61.75223969150941,
           61.7716538170945,
           61.79106794267959,
           61.810482068264676,
           61.82989619384976,
           61.84931031943485,
           61.86872444501994,
           61.88813857060502,
           61.907552696190116,
           61.9269668217752,
           61.94638094736028,
           61.965795072945376,
           61.98520919853046,
           62.004623324115556,
           62.024037449700636,
           62.04345157528573,
           62.062865700870816,
           62.0822798264559,
           62.10169395204099,
           62.12110807762608,
           62.14052220321116,
           62.15993632879625,
           62.17935045438134,
           62.19876457996643,
           62.21817870555152,
           62.23759283113661,
           62.257006956721696,
           62.27642108230678,
           62.29583520789187,
           62.315249333476956,
           62.33466345906205,
           62.354077584647136,
           62.37349171023222,
           62.3929058358173,
           62.412319961402396,
           62.43173408698748,
           62.451148212572576,
           62.47056233815766,
           62.48997646374275,
           62.50939058932783,
           62.52668846589874,
           62.54356309104902,
           62.5604377161993,
           62.57731234134959,
           62.594186966499876,
           62.611061591650156,
           62.62793621680044,
           62.64481084195073,
           62.661685467101016,
           62.678560092251296,
           62.695434717401575,
           62.71230934255186,
           62.53269470763647,
           62.31378222070795,
           62.09486973377944,
           61.87595724685092,
           61.65704475992241,
           61.4381322729939,
           61.21921978606537,
           61.00030729913686,
           60.78139481220833,
           60.56248232527982,
           60.34356983835131,
           60.12465735142279,
           59.93112250292124,
           59.74266316270511,
           59.55420382248897,
           59.36574448227285,
           59.177285142056725,
           58.98882580184059,
           58.80036646162447,
           58.611907121408336,
           58.423447781192216,
           58.23498844097608,
           58.046529100759955,
           57.85806976054383,
           57.6696104203277,
           57.48115108011157,
           57.292691739895446,
           57.10423239967931,
           56.91577305946319,
           56.72731371924705,
           56.53885437903094,
           56.3503950388148,
           56.161935698598676,
           55.973476358382555,
           55.78501701816642,
           55.59655767795029,
           55.40809833773417,
           55.21963899751803,
           55.03117965730191,
           54.84272031708578,
           54.65426097686965,
           54.46580163665353,
           54.277342296437396,
           54.08888295622127,
           53.90042361600514,
           53.711964275789015,
           53.52350493557289,
           53.33504559535675,
           53.14658625514063,
           52.9581269149245,
           52.76966757470837,
           52.58120823449225,
           52.39274889427612,
           52.20428955406,
           52.01583021384386,
           51.82737087362773,
           51.638911533411616,
           51.450452193195474,
           51.26199285297935,
           51.07353351276323,
           50.88507417254709,
           50.69661483233097,
           50.50815549211484,
           50.31969615189871,
           50.13123681168259,
           49.94277747146646,
           49.75431813125033,
           49.5658587910342,
           49.37739945081806,
           49.18894011060195,
           49.000480770385806,
           48.812021430169686,
           48.62356208995355,
           48.435102749737425,
           48.24664340952131,
           48.05818406930518,
           47.86972472908905,
           47.681265388872916,
           47.49280604865679,
           47.30434670844066,
           47.11588736822454,
           46.92742802800841,
           46.73896868779229,
           46.40759654328045,
           46.00476799662079,
           45.601939449961115,
           45.19911090330145,
           44.79628235664179,
           44.39345380998209,
           43.99062526332245,
           43.587796716662766,
           43.184968170003096,
           42.78213962334344,
           42.37931107668374,
           41.97648253002409,
           41.573653983364416,
           41.17082543670474,
           40.75255888947999,
           40.319626299566764,
           39.88669370965354,
           39.45376111974031,
           39.020828529827085,
           38.58789593991388,
           38.154963350000656,
           37.72203076008742,
           37.28909817017421,
           36.85616558026097,
           36.42323299034777,
           35.990300400434535,
           35.55736781052131,
           35.124435220608106,
           34.69150263069486,
           34.258570040781656,
           33.82563745086843,
           33.392704860955206,
           32.95977227104199,
           32.52683968112876,
           32.09390709121554,
           31.660974501302313,
           31.22804191138909,
           30.79510932147588,
           30.362176731562656,
           29.929244141649427,
           29.496311551736216,
           29.06337896182299,
           28.630446371909766,
           28.19751378199654,
           27.764581192083313,
           27.331648602170084,
           26.89871601225688,
           26.465783422343655,
           26.032850832430427,
           25.599918242517198,
           25.166985652603973,
           24.73405306269077,
           24.30112047277754,
           23.868187882864312,
           23.435255292951087,
           23.00232270303788,
           22.569390113124655,
           22.136457523211426,
           21.7035249332982,
           21.270592343384976,
           20.83765975347177,
           20.40472716355854,
           19.97179457364531,
           19.538861983732087,
           19.10592939381888,
           18.672996803905654,
           18.240064213992426,
           17.8071316240792,
           17.374199034165976,
           16.94126644425277,
           16.50833385433954,
           16.075401264426315,
           15.642468674513088,
           15.209536084599861,
           14.776603494686654,
           14.343670904773429,
           13.910738314860202,
           13.477805724946975,
           13.044873135033765,
           12.611940545120538,
           12.179007955207311,
           11.746075365294086,
           11.313142775380859,
           11.047183005116633,
           10.948196054501372,
           10.849209103886118,
           10.750222153270839,
           10.65123520265558,
           10.552248252040325,
           10.453261301425067,
           10.357995459808622,
           10.264173826234295,
           10.170352192660024,
           10.076530559085697,
           9.98270892551139,
           9.88888729193709,
           9.795065658362791,
           9.701404378122211,
           9.614157209599355,
           9.526910041076519,
           9.439662872553678,
           9.35241570403084,
           9.265168535508003,
           9.177921366985162,
           9.090674198462297,
           9.008985094723467,
           8.9286732108567,
           8.84836132698997,
           8.768049443123228,
           8.687737559256487,
           8.60742567538972,
           8.527170237020613,
           8.453011000786315,
           8.378851764551992,
           8.304692528317656,
           8.230533292083344,
           8.156374055849025,
           8.082214819614702,
           8.01137886331707,
           7.942665438972614,
           7.873952014628183,
           7.805238590283727,
           7.736525165939285,
           7.667811741594839,
           7.591250488572176,
           7.508803364040825,
           7.42635623950946,
           7.343909114978103,
           7.261461990446761,
           7.179014865915395,
           7.096567741384036,
           7.014120616852686,
           6.93167349232133,
           6.849226367789979,
           6.766779243258628,
           6.684332118727271,
           6.601884994195912,
           6.519437869664548,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           60.9484303797027,
           60.967844505287786,
           60.98725863087287,
           61.00667275645796,
           61.02608688204305,
           61.04550100762814,
           61.064915133213226,
           61.084329258798306,
           61.10374338438341,
           61.12315750996849,
           61.14257163555357,
           61.161985761138666,
           61.181399886723746,
           61.20081401230884,
           61.22022813789393,
           61.23964226347901,
           61.259056389064106,
           61.27847051464919,
           61.29788464023429,
           61.31729876581937,
           61.33671289140446,
           61.35612701698955,
           61.375541142574626,
           61.39495526815972,
           61.414369393744806,
           61.4337835193299,
           61.453197644914994,
           61.472611770500066,
           61.49202589608516,
           61.51144002167025,
           61.53085414725534,
           61.55026827284043,
           61.56968239842551,
           61.5890965240106,
           61.60851064959569,
           61.62792477518077,
           61.64733890076587,
           61.666753026350946,
           61.68616715193605,
           61.70558127752112,
           61.72499540310621,
           61.74440952869131,
           61.76382365427639,
           61.78323777986148,
           61.80265190544657,
           61.82206603103165,
           61.84148015661674,
           61.86089428220183,
           61.88030840778691,
           61.899722533372,
           61.91913665895709,
           61.93855078454218,
           61.957964910127274,
           61.97737903571235,
           61.99679316129744,
           62.01536078766673,
           62.03223541281702,
           62.049110037967296,
           62.065984663117575,
           62.08285928826787,
           62.09973391341815,
           62.11660853856844,
           62.133483163718715,
           62.150357788868995,
           62.16723241401928,
           62.184107039169575,
           62.200981664319855,
           62.21785628947014,
           62.23473091462043,
           62.25160553977071,
           62.268480164920994,
           62.285354790071274,
           62.30222941522156,
           62.319104040371855,
           62.335978665522134,
           62.352853290672414,
           62.3697279158227,
           62.38660254097299,
           62.40347716612327,
           62.420351791273546,
           62.43722641642384,
           62.45410104157412,
           62.4709756667244,
           62.48785029187469,
           62.3082356569593,
           62.08932317003078,
           61.870410683102264,
           61.65149819617375,
           61.43258570924523,
           61.213673222316714,
           60.9947607353882,
           60.77584824845968,
           60.556935761531165,
           60.33802327460264,
           60.11911078767413,
           59.900198300745615,
           59.6812858138171,
           59.46237332688858,
           59.24346083996006,
           59.02454835303155,
           58.80563586610303,
           58.586723379174515,
           58.367810892246,
           58.14889840531747,
           57.929985918388965,
           57.71107343146044,
           57.492160944531925,
           57.273248457603415,
           57.05433597067489,
           56.835423483746375,
           56.61651099681786,
           56.39759850988934,
           56.18883708300686,
           56.00037774279072,
           55.811918402574605,
           55.62345906235847,
           55.434999722142344,
           55.24654038192622,
           55.05808104171009,
           54.869621701493955,
           54.681162361277835,
           54.4927030210617,
           54.30424368084558,
           54.115784340629446,
           53.92732500041332,
           53.7388656601972,
           53.55040631998106,
           53.36194697976494,
           53.17348763954881,
           52.985028299332676,
           52.79656895911656,
           52.60810961890042,
           52.4196502786843,
           52.23119093846817,
           52.04273159825204,
           51.85427225803592,
           51.665812917819785,
           51.47735357760366,
           51.288894237387524,
           51.1004348971714,
           50.911975556955284,
           50.72351621673914,
           50.535056876523015,
           50.346597536306895,
           50.15813819609076,
           49.96967885587463,
           49.781219515658506,
           49.59276017544238,
           49.40430083522625,
           49.21584149501012,
           49.027382154794,
           48.83892281457787,
           48.650463474361736,
           48.462004134145616,
           48.273544793929474,
           48.085085453713354,
           47.89662611349722,
           47.70816677328109,
           47.519707433064966,
           47.33124809284884,
           47.14278875263271,
           46.954329412416584,
           46.76587007220046,
           46.57741073198433,
           46.3889513917682,
           46.200492051552075,
           46.01203271133595,
           45.680660566824116,
           45.27783202016445,
           44.87500347350478,
           44.47217492684511,
           44.06934638018546,
           43.666517833525766,
           43.26368928686611,
           42.860860740206434,
           42.45803219354676,
           42.05520364688711,
           41.65237510022742,
           41.24954655356776,
           40.846718006908084,
           40.443889460248414,
           40.04106091358875,
           39.63823236692908,
           39.23540382026941,
           38.832575273609734,
           38.429746726950064,
           38.02691818029041,
           37.624089633630724,
           37.221261086971055,
           36.818432540311406,
           36.415603993651715,
           36.01277544699205,
           35.609946900332375,
           35.207118353672705,
           34.804289807013056,
           34.40146126035336,
           33.99863271369371,
           33.595804167034025,
           33.192975620374355,
           32.79014707371471,
           32.38577469128583,
           31.952842101372603,
           31.519909511459375,
           31.086976921546153,
           30.654044331632946,
           30.221111741719717,
           29.78817915180649,
           29.35524656189328,
           28.922313971980053,
           28.48938138206683,
           28.056448792153603,
           27.623516202240374,
           27.19058361232715,
           26.757651022413945,
           26.324718432500717,
           25.891785842587492,
           25.458853252674263,
           25.025920662761038,
           24.59298807284783,
           24.160055482934606,
           23.727122893021377,
           23.294190303108152,
           22.861257713194945,
           22.428325123281716,
           21.99539253336849,
           21.562459943455266,
           21.129527353542038,
           20.69659476362883,
           20.263662173715606,
           19.83072958380238,
           19.397796993889152,
           18.964864403975945,
           18.53193181406272,
           18.098999224149495,
           17.666066634236266,
           17.23313404432304,
           16.800201454409834,
           16.36726886449661,
           15.93433627458338,
           15.501403684670155,
           15.068471094756926,
           14.635538504843721,
           14.202605914930494,
           13.769673325017267,
           13.33674073510404,
           12.90380814519083,
           12.470875555277605,
           12.037942965364376,
           11.605010375451151,
           11.172077785537924,
           10.906118015273698,
           10.807131064658439,
           10.708144114043185,
           10.609157163427906,
           10.510170212812644,
           10.414448990592692,
           10.320627357018394,
           10.226805723444087,
           10.13298408986976,
           10.03916245629549,
           9.945340822721162,
           9.851519189146856,
           9.757697555572555,
           9.66963258827019,
           9.582385419747347,
           9.49513825122449,
           9.407891082701656,
           9.320643914178811,
           9.233396745655975,
           9.146149577133139,
           9.063034067328493,
           8.982722183461743,
           8.902410299595008,
           8.82209841572824,
           8.74178653186151,
           8.661474647994767,
           8.581162764128026,
           8.50546536516829,
           8.431306128933958,
           8.357146892699658,
           8.282987656465338,
           8.208828420230999,
           8.134669183996689,
           8.06214733048112,
           7.993433906136659,
           7.9247204817922325,
           7.856007057447776,
           7.787293633103344,
           7.718580208758889,
           7.646923848660131,
           7.564476724128765,
           7.482029599597415,
           7.399582475066064,
           7.3171353505347,
           7.234688226003342,
           7.152241101472,
           7.069793976940634,
           6.987346852409277,
           6.904899727877927,
           6.822452603346569,
           6.740005478815218,
           6.657558354283867,
           6.575111229752511,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           60.76587308661878,
           60.78528721220387,
           60.804701337788956,
           60.82411546337404,
           60.84352958895913,
           60.86294371454422,
           60.882357840129316,
           60.901771965714396,
           60.92118609129949,
           60.940600216884576,
           60.96001434246967,
           60.97942846805475,
           60.998842593639836,
           61.01825671922493,
           61.037670844810016,
           61.05708497039511,
           61.07649909598019,
           61.095913221565276,
           61.11532734715037,
           61.134741472735456,
           61.15415559832054,
           61.173569723905636,
           61.192983849490716,
           61.2123979750758,
           61.23181210066089,
           61.25122622624598,
           61.27064035183108,
           61.290054477416156,
           61.30946860300125,
           61.32888272858633,
           61.34829685417142,
           61.36771097975652,
           61.387125105341596,
           61.40653923092669,
           61.42595335651177,
           61.445367482096856,
           61.46478160768196,
           61.484195733267036,
           61.50360985885214,
           61.52090773458499,
           61.53778235973527,
           61.55465698488556,
           61.57153161003584,
           61.58840623518612,
           61.60528086033641,
           61.62215548548669,
           61.63903011063699,
           61.65590473578726,
           61.67277936093754,
           61.689653986087826,
           61.70652861123811,
           61.72340323638841,
           61.74027786153868,
           61.757152486688966,
           61.77402711183925,
           61.790901736989525,
           61.807776362139826,
           61.824650987290106,
           61.841525612440385,
           61.85840023759067,
           61.87527486274095,
           61.892149487891245,
           61.909024113041525,
           61.925898738191805,
           61.9427733633421,
           61.95964798849238,
           61.976522613642665,
           61.993397238792944,
           62.01027186394323,
           62.02714648909351,
           62.044021114243805,
           62.060895739394084,
           62.077770364544364,
           62.09464498969466,
           62.11151961484494,
           62.128394239995224,
           62.1452688651455,
           62.16214349029579,
           62.17901811544607,
           62.195892740596356,
           62.21276736574664,
           62.22964199089692,
           62.24651661604722,
           62.263391241197496,
           62.083776606282115,
           61.864864119353584,
           61.645951632425074,
           61.42703914549656,
           61.208126658568034,
           60.98921417163953,
           60.77030168471101,
           60.551389197782484,
           60.332476710853975,
           60.11356422392545,
           59.89465173699695,
           59.675739250068425,
           59.45682676313991,
           59.23791427621139,
           59.01900178928287,
           58.800089302354365,
           58.581176815425835,
           58.36226432849732,
           58.1433518415688,
           57.924439354640285,
           57.70552686771177,
           57.48661438078325,
           57.267701893854735,
           57.048789406926225,
           56.829876919997695,
           56.61096443306919,
           56.39205194614067,
           56.173139459212145,
           55.95422697228364,
           55.73531448535511,
           55.5164019984266,
           55.297489511498085,
           55.07857702456956,
           54.85966453764105,
           54.640752050712535,
           54.42183956378402,
           54.202927076855495,
           53.984014589926986,
           53.76510210299847,
           53.54618961606995,
           53.32727712914143,
           53.108364642212926,
           52.889452155284395,
           52.670539668355886,
           52.45162718142737,
           52.25809232287629,
           52.069632982660174,
           51.88117364244403,
           51.69271430222791,
           51.50425496201178,
           51.31579562179565,
           51.12733628157953,
           50.9388769413634,
           50.75041760114727,
           50.561958260931135,
           50.37349892071501,
           50.18503958049889,
           49.99658024028276,
           49.808120900066626,
           49.619661559850506,
           49.431202219634365,
           49.24274287941825,
           49.05428353920212,
           48.86582419898599,
           48.67736485876986,
           48.48890551855372,
           48.30044617833761,
           48.111986838121474,
           47.92352749790535,
           47.73506815768923,
           47.546608817473086,
           47.358149477256966,
           47.16969013704084,
           46.981230796824704,
           46.792771456608584,
           46.60431211639245,
           46.41585277617632,
           46.227393435960195,
           46.03893409574407,
           45.85047475552794,
           45.662015415311814,
           45.473556075095686,
           45.28509673487956,
           44.95372459036773,
           44.55089604370807,
           44.148067497048395,
           43.745238950388725,
           43.34241040372906,
           42.93958185706937,
           42.53675331040972,
           42.133924763750045,
           41.73109621709037,
           41.32826767043072,
           40.92543912377103,
           40.522610577111365,
           40.119782030451695,
           39.71695348379202,
           39.31412493713236,
           38.91129639047269,
           38.50846784381302,
           38.105639297153346,
           37.70281075049367,
           37.29998220383402,
           36.897153657174336,
           36.494325110514666,
           36.09149656385502,
           35.688668017195326,
           35.28583947053566,
           34.883010923875986,
           34.48018237721632,
           34.07735383055666,
           33.67452528389697,
           33.27169673723732,
           32.868868190577636,
           32.466039643917966,
           32.06321109725832,
           31.660382550598634,
           31.257554003938964,
           30.854725457279287,
           30.45189691061962,
           30.04906836395996,
           29.646239817300284,
           29.24341127064061,
           28.84058272398096,
           28.43775417732128,
           28.034925630661608,
           27.632097084001934,
           27.22926853734226,
           26.826439990682587,
           26.42361144402293,
           26.020782897363258,
           25.617954350703585,
           25.215125804043907,
           24.812297257384238,
           24.409468710724582,
           24.00664016406491,
           23.586057903178432,
           23.153125313265207,
           22.720192723352,
           22.28726013343877,
           21.854327543525542,
           21.42139495361232,
           20.988462363699092,
           20.555529773785885,
           20.122597183872657,
           19.68966459395943,
           19.256732004046206,
           18.823799414133,
           18.39086682421977,
           17.957934234306546,
           17.52500164439332,
           17.092069054480092,
           16.659136464566885,
           16.22620387465366,
           15.793271284740435,
           15.360338694827206,
           14.927406104913981,
           14.494473515000774,
           14.061540925087547,
           13.62860833517432,
           13.195675745261095,
           12.762743155347884,
           12.329810565434657,
           11.89687797552143,
           11.463945385608206,
           11.031012795694979,
           10.76505302543075,
           10.66606607481549,
           10.567079124200237,
           10.470902521376772,
           10.377080887802467,
           10.283259254228147,
           10.189437620653846,
           10.09561598707954,
           10.001794353505213,
           9.907972719930944,
           9.814151086356615,
           9.725107966940987,
           9.637860798418151,
           9.550613629895313,
           9.46336646137247,
           9.376119292849616,
           9.28887212432678,
           9.201624955803936,
           9.117083039933531,
           9.036771156066788,
           8.956459272200021,
           8.876147388333273,
           8.795835504466535,
           8.71552362059977,
           8.635211736733039,
           8.557919729550262,
           8.483760493315945,
           8.409601257081624,
           8.335442020847292,
           8.261282784612993,
           8.187123548378672,
           8.112964312144335,
           8.044202373300719,
           7.975488948956273,
           7.906775524611812,
           7.838062100267385,
           7.76934867592293,
           7.700635251578499,
           7.620150084216712,
           7.537702959685362,
           7.455255835153997,
           7.372808710622646,
           7.290361586091297,
           7.207914461559932,
           7.125467337028574,
           7.043020212497232,
           6.960573087965867,
           6.878125963434508,
           6.795678838903158,
           6.713231714371801,
           6.630784589840449,
           6.5483374653091,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           60.58331579353488,
           60.602729919119966,
           60.62214404470505,
           60.64155817029014,
           60.660972295875226,
           60.68038642146031,
           60.699800547045406,
           60.719214672630486,
           60.738628798215586,
           60.75804292380067,
           60.77745704938576,
           60.796871174970846,
           60.81628530055593,
           60.83569942614102,
           60.85511355172611,
           60.8745276773112,
           60.89394180289628,
           60.91335592848137,
           60.93277005406646,
           60.952184179651546,
           60.97159830523664,
           60.991012430821726,
           61.009580056352966,
           61.026454681503246,
           61.04332930665353,
           61.06020393180381,
           61.0770785569541,
           61.093953182104386,
           61.110827807254665,
           61.12770243240496,
           61.14457705755523,
           61.16145168270552,
           61.17832630785581,
           61.1952009330061,
           61.21207555815637,
           61.22895018330666,
           61.245824808456945,
           61.262699433607224,
           61.27957405875752,
           61.29644868390779,
           61.31332330905808,
           61.33019793420836,
           61.34707255935865,
           61.36394718450894,
           61.38082180965922,
           61.397696434809504,
           61.41457105995978,
           61.43144568511006,
           61.44832031026035,
           61.46519493541064,
           61.482069560560916,
           61.49894418571121,
           61.51581881086149,
           61.53269343601177,
           61.54956806116206,
           61.56644268631234,
           61.583317311462636,
           61.60019193661291,
           61.61706656176319,
           61.63394118691349,
           61.65081581206377,
           61.66769043721405,
           61.684565062364335,
           61.70143968751462,
           61.7183143126649,
           61.735188937815195,
           61.752063562965475,
           61.768938188115754,
           61.78581281326604,
           61.80268743841632,
           61.819562063566615,
           61.836436688716894,
           61.85331131386718,
           61.87018593901746,
           61.887060564167754,
           61.903935189318034,
           61.92080981446831,
           61.9376844396186,
           61.95455906476888,
           61.97143368991917,
           61.98830831506945,
           62.00518294021974,
           62.02205756537002,
           62.0389321905203,
           61.85931755560492,
           61.64040506867639,
           61.421492581747884,
           61.20258009481937,
           60.983667607890844,
           60.764755120962334,
           60.54584263403382,
           60.326930147105294,
           60.10801766017678,
           59.889105173248254,
           59.670192686319744,
           59.451280199391235,
           59.232367712462704,
           59.0134552255342,
           58.79454273860567,
           58.57563025167716,
           58.356717764748645,
           58.13780527782013,
           57.918892790891604,
           57.69998030396309,
           57.48106781703458,
           57.26215533010606,
           57.043242843177545,
           56.824330356249035,
           56.605417869320505,
           56.386505382391995,
           56.16759289546347,
           55.948680408534955,
           55.72976792160645,
           55.51085543467792,
           55.291942947749405,
           55.07303046082089,
           54.85411797389237,
           54.63520548696386,
           54.41629300003534,
           54.19738051310682,
           53.978468026178305,
           53.75955553924978,
           53.54064305232128,
           53.321730565392755,
           53.10281807846424,
           52.88390559153572,
           52.66499310460719,
           52.44608061767869,
           52.22716813075017,
           52.008255643821656,
           51.78934315689314,
           51.57043066996462,
           51.351518183036106,
           51.13260569610759,
           50.913693209179065,
           50.694780722250556,
           50.47586823532203,
           50.25695574839352,
           50.038043261465,
           49.81913077453648,
           49.600218287607966,
           49.381305800679456,
           49.16239331375093,
           48.94348082682243,
           48.7245683398939,
           48.515806902961856,
           48.32734756274573,
           48.1388882225296,
           47.950428882313474,
           47.76196954209735,
           47.57351020188121,
           47.38505086166509,
           47.19659152144896,
           47.00813218123284,
           46.819672841016704,
           46.631213500800584,
           46.44275416058445,
           46.254294820368315,
           46.065835480152195,
           45.877376139936075,
           45.68891679971994,
           45.50045745950381,
           45.31199811928768,
           45.12353877907155,
           44.93507943885543,
           44.7466200986393,
           44.55816075842318,
           44.22678861391133,
           43.82396006725168,
           43.421131520592006,
           43.018302973932336,
           42.61547442727267,
           42.21264588061298,
           41.80981733395333,
           41.406988787293656,
           41.00416024063398,
           40.60133169397432,
           40.19850314731464,
           39.795674600654976,
           39.39284605399531,
           38.99001750733563,
           38.587188960675974,
           38.1843604140163,
           37.781531867356634,
           37.37870332069696,
           36.97587477403728,
           36.573046227377624,
           36.17021768071795,
           35.76738913405828,
           35.36456058739863,
           34.96173204073893,
           34.558903494079274,
           34.1560749474196,
           33.75324640075993,
           33.35041785410027,
           32.94758930744058,
           32.544760760780925,
           32.14193221412125,
           31.739103667461578,
           31.336275120801922,
           30.933446574142245,
           30.530618027482575,
           30.127789480822898,
           29.724960934163228,
           29.322132387503572,
           28.919303840843895,
           28.516475294184218,
           28.113646747524566,
           27.710818200864892,
           27.30798965420522,
           26.905161107545545,
           26.50233256088587,
           26.0995040142262,
           25.696675467566543,
           25.293846920906866,
           24.891018374247192,
           24.48818982758752,
           24.085361280927845,
           23.682532734268193,
           23.27970418760852,
           22.876875640948843,
           22.47404709428917,
           22.071218547629513,
           21.668390000969843,
           21.265561454310166,
           20.862732907650496,
           20.45990436099082,
           20.057075814331164,
           19.654247267671494,
           19.251418721011817,
           18.848590174352147,
           18.445761627692487,
           18.042933081032814,
           17.640104534373144,
           17.23727598771347,
           16.834447441053793,
           16.43161889439414,
           16.028790347734464,
           15.62596180107479,
           15.21927370498426,
           14.786341115071036,
           14.353408525157828,
           13.920475935244601,
           13.487543345331375,
           13.05461075541815,
           12.621678165504939,
           12.188745575591712,
           11.755812985678485,
           11.32288039576526,
           10.889947805852033,
           10.623988035587807,
           10.527356052160828,
           10.433534418586527,
           10.339712785012228,
           10.245891151437924,
           10.152069517863602,
           10.058247884289303,
           9.964426250714997,
           9.87060461714067,
           9.780583345611799,
           9.693336177088955,
           9.606089008566114,
           9.518841840043278,
           9.43159467152044,
           9.344347502997596,
           9.257100334474742,
           9.171132012538552,
           9.090820128671803,
           9.010508244805061,
           8.93019636093832,
           8.849884477071553,
           8.769572593204803,
           8.689260709338065,
           8.61037409393225,
           8.53621485769793,
           8.462055621463598,
           8.387896385229281,
           8.31373714899496,
           8.23957791276063,
           8.165418676526329,
           8.094970840464773,
           8.026257416120313,
           7.957543991775874,
           7.888830567431429,
           7.820117143086968,
           7.751403718742542,
           7.675823444304651,
           7.593376319773293,
           7.5109291952419435,
           7.428482070710594,
           7.346034946179228,
           7.263587821647878,
           7.181140697116529,
           7.098693572585163,
           7.0162464480538045,
           6.933799323522463,
           6.851352198991097,
           6.768905074459739,
           6.686457949928389,
           6.604010825397031,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           60.400758500450976,
           60.42017262603607,
           60.43958675162115,
           60.459000877206236,
           60.47841500279133,
           60.49782912837642,
           60.515127003271246,
           60.532001628421526,
           60.54887625357182,
           60.5657508787221,
           60.582625503872386,
           60.599500129022665,
           60.616374754172945,
           60.63324937932324,
           60.65012400447352,
           60.666998629623805,
           60.683873254774085,
           60.700747879924364,
           60.71762250507466,
           60.73449713022494,
           60.751371755375224,
           60.76824638052551,
           60.7851210056758,
           60.80199563082608,
           60.818870255976364,
           60.835744881126644,
           60.85261950627692,
           60.86949413142722,
           60.8863687565775,
           60.90324338172778,
           60.92011800687807,
           60.93699263202835,
           60.953867257178636,
           60.97074188232892,
           60.9876165074792,
           61.0044911326295,
           61.021365757779776,
           61.038240382930056,
           61.05511500808034,
           61.07198963323063,
           61.08886425838091,
           61.10573888353119,
           61.122613508681475,
           61.13948813383176,
           61.15636275898204,
           61.17323738413233,
           61.19011200928262,
           61.206986634432894,
           61.22386125958318,
           61.24073588473347,
           61.25761050988375,
           61.27448513503404,
           61.29135976018432,
           61.3082343853346,
           61.325109010484894,
           61.341983635635174,
           61.35885826078547,
           61.37573288593574,
           61.39260751108602,
           61.40948213623632,
           61.42635676138659,
           61.44323138653688,
           61.46010601168716,
           61.476980636837446,
           61.49385526198773,
           61.51072988713802,
           61.5276045122883,
           61.544479137438586,
           61.56135376258887,
           61.57822838773916,
           61.59510301288944,
           61.61197763803972,
           61.628852263190005,
           61.64572688834029,
           61.66260151349058,
           61.67947613864086,
           61.696350763791145,
           61.71322538894143,
           61.73010001409172,
           61.746974639242,
           61.76384926439228,
           61.780723889542564,
           61.79759851469285,
           61.81447313984314,
           61.63485850492775,
           61.41594601799922,
           61.19703353107071,
           60.97812104414219,
           60.75920855721367,
           60.540296070285166,
           60.32138358335665,
           60.10247109642812,
           59.8835586094996,
           59.664646122571085,
           59.445733635642576,
           59.22682114871406,
           59.007908661785535,
           58.788996174857026,
           58.5700836879285,
           58.35117120099999,
           58.13225871407147,
           57.91334622714295,
           57.694433740214436,
           57.47552125328592,
           57.2566087663574,
           57.037696279428886,
           56.81878379250037,
           56.59987130557187,
           56.380958818643336,
           56.16204633171482,
           55.9431338447863,
           55.724221357857786,
           55.50530887092928,
           55.28639638400075,
           55.067483897072236,
           54.84857141014372,
           54.6296589232152,
           54.4107464362867,
           54.19183394935817,
           53.97292146242965,
           53.75400897550114,
           53.53509648857262,
           53.3161840016441,
           53.09727151471559,
           52.87835902778707,
           52.65944654085856,
           52.44053405393003,
           52.22162156700152,
           52.002709080073004,
           51.78379659314449,
           51.56488410621597,
           51.34597161928745,
           51.12705913235894,
           50.90814664543041,
           50.6892341585019,
           50.47032167157339,
           50.25140918464487,
           50.032496697716354,
           49.81358421078783,
           49.59467172385931,
           49.375759236930804,
           49.15684675000229,
           48.93793426307376,
           48.719021776145254,
           48.500109289216724,
           48.28119680228822,
           48.062284315359705,
           47.843371828431174,
           47.62445934150267,
           47.40554685457414,
           47.18663436764564,
           46.967721880717114,
           46.74880939378859,
           46.52989690686009,
           46.31098441993156,
           46.09207193300304,
           45.873159446074524,
           45.65424695914601,
           45.435334472217505,
           45.21642198528898,
           44.99750949836046,
           44.77859701143194,
           44.58506214283134,
           44.39660280261521,
           44.20814346239909,
           44.01968412218296,
           43.83122478196684,
           43.499852637455,
           43.097024090795344,
           42.694195544135674,
           42.291366997476,
           41.88853845081634,
           41.48570990415665,
           41.082881357496994,
           40.68005281083732,
           40.27722426417765,
           39.87439571751799,
           39.47156717085829,
           39.068738624198645,
           38.66591007753897,
           38.26308153087929,
           37.86025298421964,
           37.45742443755997,
           37.054595890900295,
           36.65176734424062,
           36.24893879758094,
           35.8461102509213,
           35.443281704261615,
           35.040453157601945,
           34.63762461094229,
           34.2347960642826,
           33.83196751762294,
           33.429138970963265,
           33.026310424303595,
           32.62348187764393,
           32.22065333098425,
           31.817824784324593,
           31.414996237664912,
           31.012167691005242,
           30.609339144345586,
           30.206510597685913,
           29.80760657574741,
           29.410272394106386,
           29.01293821246535,
           28.615604030824343,
           28.218269849183315,
           27.820935667542287,
           27.423601485901276,
           27.02626730426025,
           26.62893312261922,
           26.23159894097819,
           25.834264759337163,
           25.43693057769613,
           25.039596396055124,
           24.642262214414096,
           24.244928032773068,
           23.84759385113204,
           23.450259669491007,
           23.052925487849997,
           22.655591306208972,
           22.258257124567944,
           21.860922942926916,
           21.463588761285905,
           21.066254579644877,
           20.66892039800385,
           20.27158621636282,
           19.874252034721792,
           19.47691785308078,
           19.07958367143975,
           18.682249489798725,
           18.284915308157693,
           17.887581126516686,
           17.490246944875658,
           17.09291276323463,
           16.695578581593598,
           16.298244399952573,
           15.900910218311562,
           15.503576036670534,
           15.106241855029504,
           14.708907673388476,
           14.311573491747449,
           13.914239310106439,
           13.51690512846541,
           13.11957094682438,
           12.722236765183352,
           12.324902583542343,
           11.927568401901313,
           11.530234220260287,
           11.132900038619256,
           10.735565856978228,
           10.4899879493706,
           10.396166315796293,
           10.302344682221994,
           10.208523048647692,
           10.114701415073387,
           10.020879781499067,
           9.92705814792477,
           9.836058724282625,
           9.748811555759783,
           9.661564387236933,
           9.57431721871409,
           9.487070050191248,
           9.39982288166841,
           9.312575713145574,
           9.22532854462273,
           9.144869101276832,
           9.064557217410089,
           8.98424533354334,
           8.903933449676598,
           8.823621565809855,
           8.74330968194309,
           8.662997798076338,
           8.588669222079917,
           8.514509985845594,
           8.440350749611275,
           8.366191513376942,
           8.292032277142626,
           8.217873040908305,
           8.145739307628821,
           8.077025883284378,
           8.008312458939933,
           7.939599034595472,
           7.870885610251036,
           7.802172185906589,
           7.731496804392585,
           7.6490496798612355,
           7.566602555329885,
           7.484155430798527,
           7.401708306267177,
           7.319261181735826,
           7.2368140572044615,
           7.154366932673112,
           7.071919808141761,
           6.989472683610396,
           6.907025559079038,
           6.824578434547695,
           6.7421313100163305,
           6.659684185484973,
           6.577237060953622,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           60.204290264933306,
           60.21872548175937,
           60.23316069858543,
           60.24759591541149,
           60.26203113223755,
           60.27646634906361,
           60.29090156588967,
           60.30533678271573,
           60.31977199954179,
           60.33420721636785,
           60.34864243319391,
           60.363077650019974,
           60.37913913834468,
           60.39601376349496,
           60.41288838864525,
           60.42976301379554,
           60.446637638945816,
           60.463512264096096,
           60.48038688924639,
           60.49726151439667,
           60.514136139546956,
           60.531010764697236,
           60.54788538984752,
           60.5647600149978,
           60.581634640148096,
           60.598509265298375,
           60.615383890448655,
           60.63225851559895,
           60.64913314074923,
           60.666007765899515,
           60.682882391049795,
           60.69975701620008,
           60.71663164135036,
           60.733506266500655,
           60.750380891650934,
           60.76725551680122,
           60.78413014195151,
           60.80100476710179,
           60.81787939225207,
           60.834754017402354,
           60.85162864255264,
           60.86850326770292,
           60.885377892853214,
           60.90225251800349,
           60.91912714315378,
           60.93600176830406,
           60.952876393454346,
           60.96975101860463,
           60.98662564375492,
           61.0035002689052,
           61.02037489405548,
           61.037249519205766,
           61.05412414435605,
           61.07099876950633,
           61.087873394656626,
           61.1047480198069,
           61.1216226449572,
           61.13849727010747,
           61.15537189525775,
           61.17224652040804,
           61.189121145558325,
           61.20599577070861,
           61.22287039585889,
           61.23974502100917,
           61.256619646159464,
           61.27349427130975,
           61.29036889646003,
           61.30724352161032,
           61.3241181467606,
           61.340992771910884,
           61.35786739706117,
           61.37474202221145,
           61.39161664736174,
           61.40849127251202,
           61.42536589766231,
           61.4422405228126,
           61.459115147962876,
           61.475989773113156,
           61.49286439826344,
           61.50973902341373,
           61.52661364856401,
           61.543488273714296,
           61.560362898864575,
           61.57723752401486,
           61.397622889099466,
           61.178710402170935,
           60.95979791524243,
           60.74088542831392,
           60.5219729413854,
           60.30306045445688,
           60.084147967528374,
           59.86523548059985,
           59.64632299367133,
           59.42741050674281,
           59.208498019814314,
           58.98958553288578,
           58.770673045957274,
           58.55176055902875,
           58.33284807210024,
           58.113935585171724,
           57.8950230982432,
           57.67611061131469,
           57.45719812438617,
           57.23828563745765,
           57.019373150529134,
           56.80046066360061,
           56.5815481766721,
           56.362635689743584,
           56.14372320281506,
           55.92481071588655,
           55.70589822895803,
           55.48698574202952,
           55.268073255101,
           55.04916076817248,
           54.83024828124397,
           54.611335794315444,
           54.39242330738692,
           54.17351082045842,
           53.9545983335299,
           53.73568584660137,
           53.51677335967287,
           53.29786087274434,
           53.078948385815835,
           52.86003589888732,
           52.64112341195879,
           52.422210925030285,
           52.203298438101754,
           51.984385951173245,
           51.76547346424473,
           51.54656097731622,
           51.327648490387695,
           51.10873600345917,
           50.889823516530655,
           50.67091102960214,
           50.45199854267362,
           50.23308605574512,
           50.014173568816595,
           49.79526108188807,
           49.576348594959555,
           49.35743610803103,
           49.13852362110253,
           48.91961113417401,
           48.70069864724549,
           48.48178616031698,
           48.262873673388455,
           48.043961186459946,
           47.82504869953143,
           47.6061362126029,
           47.387223725674396,
           47.168311238745865,
           46.94939875181736,
           46.73048626488884,
           46.511573777960315,
           46.29266129103181,
           46.07374880410328,
           45.854836308968125,
           45.60802239428474,
           45.36120847960136,
           45.11439456491799,
           44.8675806502346,
           44.620766735551214,
           44.373952820867835,
           44.12713890618445,
           43.88032499150108,
           43.6335110768177,
           43.38669716213431,
           43.13988324745094,
           42.8088066422712,
           42.43559869184336,
           42.062390741415484,
           41.689182790987616,
           41.31597484055977,
           40.94276689013188,
           40.56955893970404,
           40.19635098927616,
           39.82314303884829,
           39.449935088420446,
           39.076727137992556,
           38.7035191875647,
           38.33031123713684,
           37.95710328670897,
           37.58389533628112,
           37.21068738585325,
           36.8284321089213,
           36.43109792728028,
           36.03376374563925,
           35.636429563998234,
           35.239095382357206,
           34.841761200716185,
           34.44442701907517,
           34.04709283743412,
           33.649758655793114,
           33.252424474152086,
           32.85509029251106,
           32.457756110870044,
           32.060421929229,
           31.663087747587987,
           31.26575356594696,
           30.868419384305934,
           30.471085202664923,
           30.073751021023895,
           29.676416839382867,
           29.279082657741835,
           28.881748476100807,
           28.4844142944598,
           28.08708011281877,
           27.68974593117774,
           27.292411749536733,
           26.895077567895704,
           26.497743386254676,
           26.100409204613648,
           25.703075022972616,
           25.305740841331584,
           24.90840665969058,
           24.511072478049552,
           24.11373829640852,
           23.716404114767496,
           23.319069933126464,
           22.921735751485453,
           22.524401569844425,
           22.1270673882034,
           21.729733206562372,
           21.332399024921358,
           20.93506484328033,
           20.5377306616393,
           20.140396479998273,
           19.74306229835725,
           19.345728116716238,
           18.948393935075206,
           18.55105975343418,
           18.15372557179315,
           17.756391390152142,
           17.35905720851111,
           16.961723026870082,
           16.564388845229054,
           16.167054663588026,
           15.769720481947017,
           15.372386300305989,
           14.97505211866496,
           14.57771793702393,
           14.180383755382902,
           13.783049573741891,
           13.385715392100863,
           12.988381210459837,
           12.591047028818807,
           12.193712847177798,
           11.796378665536768,
           11.399044483895741,
           11.001710302254711,
           10.604376120613683,
           10.358798213006054,
           10.26497657943175,
           10.171154945857449,
           10.077333312283148,
           9.983511678708844,
           9.891534102953429,
           9.804286934430571,
           9.71703976590775,
           9.629792597384906,
           9.542545428862056,
           9.455298260339214,
           9.368051091816373,
           9.280803923293535,
           9.19891807388187,
           9.118606190015102,
           9.03829430614836,
           8.957982422281617,
           8.877670538414868,
           8.797358654548129,
           8.717046770681383,
           8.641123586461902,
           8.566964350227563,
           8.492805113993253,
           8.418645877758932,
           8.344486641524611,
           8.27032740529028,
           8.196507774792861,
           8.127794350448415,
           8.059080926103976,
           7.990367501759533,
           7.921654077415086,
           7.852940653070625,
           7.7842272287261896,
           7.704723039949182,
           7.622275915417816,
           7.539828790886466,
           7.457381666355117,
           7.374934541823759,
           7.292487417292408,
           7.210040292761057,
           7.1275931682296925,
           7.045146043698342,
           6.962698919166993,
           6.880251794635627,
           6.797804670104269,
           6.715357545572927,
           6.6329104210415615,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           60.001480276570405,
           60.01591549339646,
           60.03035071022252,
           60.044785927048586,
           60.059221143874645,
           60.0736563607007,
           60.08809157752676,
           60.10252679435282,
           60.11696201117888,
           60.13139722800494,
           60.145832444831,
           60.16026766165706,
           60.174702878483124,
           60.18913809530918,
           60.20357331213524,
           60.2180085289613,
           60.232443745787364,
           60.24687896261342,
           60.26131417943948,
           60.275749396265546,
           60.290184613091604,
           60.30461982991766,
           60.31905504674371,
           60.333490263569786,
           60.347925480395844,
           60.3623606972219,
           60.37679591404796,
           60.39123113087402,
           60.4060729146341,
           60.422947539784396,
           60.439822164934675,
           60.45669679008496,
           60.47357141523525,
           60.490446040385535,
           60.507320665535815,
           60.5241952906861,
           60.54106991583638,
           60.55794454098667,
           60.574819166136955,
           60.59169379128723,
           60.60856841643752,
           60.6254430415878,
           60.64231766673809,
           60.659192291888374,
           60.67606691703866,
           60.69294154218895,
           60.70981616733923,
           60.726690792489514,
           60.74356541763979,
           60.76044004279008,
           60.77731466794036,
           60.79418929309064,
           60.81106391824093,
           60.82793854339121,
           60.844813168541506,
           60.861687793691786,
           60.878562418842066,
           60.89543704399235,
           60.91231166914263,
           60.92918629429292,
           60.94606091944321,
           60.96293554459349,
           60.97981016974378,
           60.996684794894065,
           61.013559420044345,
           61.03043404519463,
           61.04730867034492,
           61.0641832954952,
           61.081057920645485,
           61.097932545795764,
           61.11480717094605,
           61.13168179609634,
           61.148556421246624,
           61.165431046396904,
           61.182305671547184,
           61.19918029669747,
           61.21605492184776,
           61.232929546998044,
           61.24980417214832,
           61.26667879729861,
           61.28355342244889,
           61.30042804759918,
           61.31730267274946,
           61.33417729789974,
           61.15456266298436,
           60.93565017605583,
           60.71673768912733,
           60.49782520219881,
           60.27891271527028,
           60.06000022834178,
           59.84108774141326,
           59.62217525448474,
           59.403262767556214,
           59.1843502806277,
           58.965437793699195,
           58.74652530677067,
           58.527612819842155,
           58.30870033291363,
           58.089787845985114,
           57.87087535905661,
           57.65196287212808,
           57.433050385199564,
           57.21413789827105,
           56.99522541134253,
           56.77631292441402,
           56.5574004374855,
           56.33848795055698,
           56.11957546362847,
           55.90066297669994,
           55.68175048977143,
           55.462838002842915,
           55.2439255159144,
           55.02501302898589,
           54.80610054205736,
           54.58718805512885,
           54.36827556820033,
           54.149363081271815,
           53.9304505943433,
           53.71153810741479,
           53.49262562048625,
           53.27371313355775,
           53.05480064662922,
           52.835888159700716,
           52.6169756727722,
           52.39806318584368,
           52.179150698915166,
           51.960238211986635,
           51.74132572505813,
           51.522413238129616,
           51.30350075120109,
           51.08458826427258,
           50.86567577734406,
           50.64676329041555,
           50.42785080348703,
           50.2089383165585,
           49.99002582963,
           49.771113342701476,
           49.552200855772966,
           49.333288368844435,
           49.100425155228095,
           48.853611240544716,
           48.606797325861336,
           48.35998341117795,
           48.11316949649458,
           47.866355581811185,
           47.61954166712781,
           47.37272775244443,
           47.12591383776105,
           46.879099923077675,
           46.632286008394274,
           46.38547209371091,
           46.13865817902752,
           45.891844264344144,
           45.645030349660765,
           45.39821643497737,
           45.151402520294,
           44.90458860561061,
           44.65777469092723,
           44.41096077624386,
           44.164146861560475,
           43.917332946877096,
           43.67051903219371,
           43.42370511751032,
           43.17689120282695,
           42.93007728814357,
           42.683263373460186,
           42.43644945877681,
           42.10537285359708,
           41.73216490316924,
           41.358956952741366,
           40.9857490023135,
           40.61254105188565,
           40.23933310145776,
           39.86612515102991,
           39.492917200602044,
           39.119709250174175,
           38.74650129974633,
           38.37329334931843,
           38.000085398890576,
           37.626877448462714,
           37.253669498034846,
           36.880461547607,
           36.50725359717912,
           36.134045646751254,
           35.760837696323385,
           35.38762974589552,
           35.01442179546767,
           34.64121384503979,
           34.26800589461193,
           33.89479794418407,
           33.52158999375619,
           33.14838204332834,
           32.77517409290047,
           32.401966142472595,
           32.02875819204475,
           31.65555024161686,
           31.28234229118901,
           30.909134340761145,
           30.535926390333273,
           30.162718439905422,
           29.789510489477554,
           29.41630253904968,
           29.043094588621813,
           28.669886638193944,
           28.29667868776609,
           27.92347073733822,
           27.550262786910356,
           27.161222013172186,
           26.763887831531157,
           26.36655364989013,
           25.9692194682491,
           25.571885286608072,
           25.17455110496704,
           24.777216923326037,
           24.37988274168501,
           23.982548560043973,
           23.585214378402952,
           23.18788019676192,
           22.79054601512091,
           22.393211833479885,
           21.995877651838853,
           21.598543470197825,
           21.201209288556814,
           20.803875106915786,
           20.406540925274758,
           20.00920674363373,
           19.611872561992705,
           19.21453838035169,
           18.817204198710662,
           18.419870017069638,
           18.022535835428606,
           17.625201653787595,
           17.227867472146567,
           16.83053329050554,
           16.43319910886451,
           16.035864927223482,
           15.638530745582472,
           15.241196563941443,
           14.843862382300415,
           14.446528200659387,
           14.049194019018357,
           13.651859837377348,
           13.25452565573632,
           12.857191474095291,
           12.459857292454263,
           12.062523110813252,
           11.665188929172224,
           11.267854747531196,
           10.870520565890168,
           10.47318638424914,
           10.227608476641507,
           10.133786843067202,
           10.039965209492903,
           9.947009481624255,
           9.859762313101392,
           9.772515144578556,
           9.685267976055698,
           9.598020807532874,
           9.510773639010033,
           9.423526470487182,
           9.336279301964339,
           9.252967046486887,
           9.172655162620142,
           9.0923432787534,
           9.012031394886634,
           8.931719511019892,
           8.851407627153149,
           8.7710957432864,
           8.693577950843872,
           8.619418714609559,
           8.545259478375236,
           8.471100242140897,
           8.396941005906587,
           8.322781769672266,
           8.248622533437945,
           8.178562817612473,
           8.109849393268018,
           8.041135968923571,
           7.972422544579129,
           7.903709120234689,
           7.834995695890242,
           7.76039640003712,
           7.677949275505771,
           7.595502150974413,
           7.513055026443048,
           7.430607901911698,
           7.348160777380348,
           7.265713652848989,
           7.18326652831764,
           7.100819403786289,
           7.0183722792549235,
           6.9359251547235745,
           6.853478030192224,
           6.771030905660858,
           6.6885837811295,
           6.606136656598158,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           59.798670288207504,
           59.81310550503356,
           59.82754072185962,
           59.841975938685685,
           59.85641115551174,
           59.8708463723378,
           59.88528158916386,
           59.899716805989925,
           59.91415202281598,
           59.92858723964204,
           59.94302245646811,
           59.957457673294165,
           59.97189289012022,
           59.98632810694628,
           60.00076332377235,
           60.015198540598405,
           60.02963375742446,
           60.04406897425052,
           60.05850419107659,
           60.072939407902645,
           60.0873746247287,
           60.10180984155476,
           60.11624505838083,
           60.130680275206885,
           60.14511549203294,
           60.159550708859,
           60.17398592568506,
           60.18842114251112,
           60.202856359337176,
           60.217291576163234,
           60.231726792989306,
           60.246162009815365,
           60.26059722664142,
           60.27503244346748,
           60.28946766029354,
           60.3039028771196,
           60.318338093945655,
           60.33277331077173,
           60.347208527597786,
           60.361643744423844,
           60.3760789612499,
           60.39051417807596,
           60.40494939490202,
           60.419384611728084,
           60.433819828554135,
           60.44988131607385,
           60.46675594122413,
           60.483630566374416,
           60.500505191524695,
           60.51737981667498,
           60.53425444182527,
           60.55112906697555,
           60.56800369212583,
           60.58487831727612,
           60.6017529424264,
           60.61862756757669,
           60.635502192726975,
           60.652376817877254,
           60.66925144302754,
           60.68612606817782,
           60.70300069332811,
           60.7198753184784,
           60.73674994362868,
           60.75362456877896,
           60.77049919392924,
           60.787373819079534,
           60.80424844422981,
           60.82112306938011,
           60.83799769453039,
           60.85487231968067,
           60.87174694483095,
           60.88862156998124,
           60.90549619513152,
           60.92237082028181,
           60.93924544543209,
           60.95612007058237,
           60.972994695732666,
           60.989869320882946,
           61.006743946033225,
           61.02361857118351,
           61.0404931963338,
           61.05736782148408,
           61.07424244663436,
           61.09111707178465,
           60.91150243686926,
           60.69258994994074,
           60.47367746301222,
           60.254764976083706,
           60.03585248915519,
           59.81694000222667,
           59.598027515298156,
           59.37911502836964,
           59.160202541441116,
           58.9412900545126,
           58.72237756758409,
           58.50346508065557,
           58.28455259372706,
           58.06564010679853,
           57.84672761987002,
           57.62781513294151,
           57.40890264601299,
           57.18999015908447,
           56.97107767215596,
           56.75216518522743,
           56.533252698298924,
           56.3143402113704,
           56.09542772444188,
           55.876515237513374,
           55.65760275058485,
           55.43869026365634,
           55.21977777672782,
           55.0008652897993,
           54.78195280287079,
           54.56304031594227,
           54.34412782901375,
           54.125215342085234,
           53.90630285515671,
           53.68739036822821,
           53.468477881299684,
           53.24956539437116,
           53.03065290744265,
           52.81174042051413,
           52.592827916171515,
           52.34601400148813,
           52.09920008680474,
           51.85238617212138,
           51.605572257437984,
           51.35875834275461,
           51.11194442807121,
           50.86513051338784,
           50.61831659870447,
           50.371502684021074,
           50.1246887693377,
           49.877874854654316,
           49.63106093997093,
           49.38424702528756,
           49.13743311060417,
           48.89061919592079,
           48.64380528123741,
           48.39699136655402,
           48.15017745187065,
           47.903363537187275,
           47.65654962250388,
           47.40973570782051,
           47.162921793137116,
           46.916107878453744,
           46.669293963770365,
           46.422480049086985,
           46.1756661344036,
           45.92885221972021,
           45.68203830503683,
           45.435224390353454,
           45.18841047567007,
           44.941596560986696,
           44.6947826463033,
           44.44796873161993,
           44.201154816936544,
           43.954340902253165,
           43.70752698756979,
           43.460713072886406,
           43.21389915820302,
           42.96708524351964,
           42.72027132883626,
           42.47345741415289,
           42.2266434994695,
           41.97982958478612,
           41.733015670102745,
           41.40193906492302,
           41.028731114495166,
           40.6555231640673,
           40.28231521363943,
           39.90910726321158,
           39.53589931278369,
           39.162691362355844,
           38.789483411927975,
           38.4162754615001,
           38.04306751107225,
           37.66985956064436,
           37.296651610216514,
           36.923443659788646,
           36.55023570936078,
           36.17702775893292,
           35.80381980850506,
           35.430611858077185,
           35.05740390764932,
           34.68419595722145,
           34.3109880067936,
           33.937780056365725,
           33.56457210593786,
           33.19136415551,
           32.81815620508212,
           32.44494825465427,
           32.0717403042264,
           31.698532353798527,
           31.32532440337068,
           30.952116452942793,
           30.578908502514942,
           30.205700552087073,
           29.832492601659204,
           29.45928465123135,
           29.08607670080348,
           28.712868750375613,
           28.339660799947744,
           27.966452849519875,
           27.59324489909202,
           27.220036948664152,
           26.846828998236283,
           26.473621047808436,
           26.100413097380564,
           25.7272051469527,
           25.353997196524826,
           24.980789246096958,
           24.607581295669085,
           24.234373345241238,
           23.86116539481337,
           23.4879574443855,
           23.114749493957632,
           22.74154154352976,
           22.36833359310191,
           21.995125642674044,
           21.62191769224617,
           21.248709741818303,
           20.87550179139045,
           20.502293840962583,
           20.129085890534714,
           19.755877940106842,
           19.382669989678977,
           19.009462039251122,
           18.636254088823254,
           18.263046138395385,
           17.88983818796752,
           17.49401191742306,
           17.096677735782034,
           16.699343554141002,
           16.302009372499974,
           15.904675190858946,
           15.507341009217937,
           15.11000682757691,
           14.71267264593588,
           14.315338464294854,
           13.918004282653822,
           13.520670101012811,
           13.123335919371783,
           12.726001737730755,
           12.328667556089728,
           11.931333374448718,
           11.53399919280769,
           11.13666501116666,
           10.739330829525631,
           10.341996647884605,
           10.096418740276972,
           10.002597106702668,
           9.915237691772203,
           9.827990523249388,
           9.740743354726526,
           9.653496186203688,
           9.566249017680832,
           9.47900184915801,
           9.391754680635167,
           9.307016019091918,
           9.226704135225189,
           9.146392251358424,
           9.066080367491681,
           8.98576848362494,
           8.905456599758171,
           8.82514471589143,
           8.746032315225854,
           8.671873078991517,
           8.597713842757218,
           8.523554606522902,
           8.44939537028858,
           8.375236134054242,
           8.301076897819932,
           8.22933128477652,
           8.160617860432076,
           8.091904436087633,
           8.023191011743178,
           7.954477587398731,
           7.88576416305429,
           7.816069760125076,
           7.733622635593718,
           7.65117551106236,
           7.568728386531012,
           7.486281261999653,
           7.403834137468288,
           7.321387012936938,
           7.2389398884055876,
           7.156492763874229,
           7.074045639342879,
           6.991598514811529,
           6.909151390280163,
           6.826704265748814,
           6.744257141217464,
           6.661810016686099,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           59.59586029984459,
           59.61029551667065,
           59.62473073349671,
           59.63916595032277,
           59.65360116714883,
           59.668036383974886,
           59.68247160080095,
           59.69690681762701,
           59.71134203445307,
           59.725777251279126,
           59.74021246810519,
           59.75464768493125,
           59.76908290175731,
           59.783518118583366,
           59.79795333540943,
           59.81238855223549,
           59.826823769061555,
           59.841258985887606,
           59.85569420271367,
           59.87012941953973,
           59.884564636365795,
           59.898999853191846,
           59.91343507001791,
           59.92787028684397,
           59.94230550367003,
           59.956740720496086,
           59.971175937322144,
           59.985611154148216,
           60.00004637097426,
           60.01448158780033,
           60.02891680462639,
           60.04335202145245,
           60.05778723827851,
           60.072222455104566,
           60.086657671930624,
           60.10109288875668,
           60.11552810558274,
           60.12996332240881,
           60.14439853923487,
           60.15883375606093,
           60.17326897288699,
           60.187704189713045,
           60.20213940653911,
           60.216574623365176,
           60.23100984019123,
           60.245445057017285,
           60.25988027384335,
           60.2743154906694,
           60.28875070749546,
           60.30318592432153,
           60.31762114114758,
           60.332056357973656,
           60.34649157479971,
           60.360926791625765,
           60.37536200845183,
           60.38979722527789,
           60.404232442103954,
           60.418667658930005,
           60.43310287575606,
           60.447538092582136,
           60.46197330940819,
           60.476815092363275,
           60.49368971751356,
           60.51056434266385,
           60.527438967814135,
           60.544313592964414,
           60.5611882181147,
           60.57806284326499,
           60.59493746841527,
           60.611812093565554,
           60.628686718715834,
           60.64556134386613,
           60.66243596901641,
           60.679310594166694,
           60.69618521931697,
           60.71305984446727,
           60.72993446961755,
           60.746809094767826,
           60.76368371991811,
           60.7805583450684,
           60.797432970218686,
           60.814307595368966,
           60.831182220519246,
           60.84805684566953,
           60.668442210754144,
           60.44952972382562,
           60.23061723689711,
           60.011704749968594,
           59.79279226304008,
           59.57387977611156,
           59.354967289183044,
           59.13605480225453,
           58.917142315326004,
           58.69822982839749,
           58.479317341468985,
           58.260404854540454,
           58.041492367611944,
           57.82257988068342,
           57.603667393754904,
           57.384754906826394,
           57.16584241989788,
           56.94692993296936,
           56.72801744604084,
           56.509104959112314,
           56.290192472183804,
           56.07127998525529,
           55.83841676243148,
           55.591602847748106,
           55.34478893306472,
           55.09797501838134,
           54.851161103697955,
           54.604347189014575,
           54.3575332743312,
           54.11071935964781,
           53.86390544496443,
           53.61709153028105,
           53.37027761559767,
           53.12346370091429,
           52.876649786230914,
           52.62983587154753,
           52.38302195686415,
           52.13620804218076,
           51.88939412749739,
           51.642580212813996,
           51.39576629813062,
           51.14895238344725,
           50.90213846876385,
           50.65532455408048,
           50.40851063939709,
           50.161696724713714,
           49.91488281003034,
           49.66806889534695,
           49.421254980663576,
           49.17444106598019,
           48.92762715129681,
           48.68081323661343,
           48.433999321930045,
           48.18718540724666,
           47.94037149256329,
           47.6935575778799,
           47.44674366319653,
           47.19992974851314,
           46.95311583382976,
           46.706301919146384,
           46.459488004463,
           46.21267408977962,
           45.96586017509624,
           45.71904626041285,
           45.47223234572948,
           45.22541843104609,
           44.978604516362715,
           44.731790601679336,
           44.48497668699594,
           44.23816277231257,
           43.99134885762918,
           43.744534942945805,
           43.49772102826242,
           43.25090711357904,
           43.00409319889566,
           42.75727928421229,
           42.5104653695289,
           42.263651454845515,
           42.01683754016213,
           41.77002362547876,
           41.52320971079538,
           41.27639579611199,
           41.02958188142862,
           40.69850527624889,
           40.32529732582105,
           39.95208937539318,
           39.57888142496531,
           39.205673474537456,
           38.83246552410957,
           38.45925757368172,
           38.08604962325384,
           37.71284167282598,
           37.33963372239813,
           36.96642577197024,
           36.593217821542396,
           36.22000987111453,
           35.84680192068665,
           35.473593970258804,
           35.100386019830935,
           34.72717806940307,
           34.3539701189752,
           33.98076216854733,
           33.607554218119475,
           33.234346267691606,
           32.86113831726374,
           32.48793036683588,
           32.114722416408,
           31.741514465980146,
           31.368306515552277,
           30.995098565124408,
           30.621890614696557,
           30.24868266426867,
           29.875474713840816,
           29.502266763412948,
           29.12905881298508,
           28.755850862557224,
           28.382642912129356,
           28.009434961701494,
           27.63622701127362,
           27.26301906084575,
           26.889811110417895,
           26.51660315999003,
           26.143395209562158,
           25.77018725913431,
           25.396979308706438,
           25.023771358278573,
           24.650563407850704,
           24.277355457422836,
           23.904147506994963,
           23.530939556567116,
           23.157731606139244,
           22.784523655711375,
           22.411315705283506,
           22.038107754855638,
           21.664899804427787,
           21.291691853999918,
           20.91848390357205,
           20.54527595314418,
           20.17206800271633,
           19.798860052288457,
           19.42565210186059,
           19.05244415143272,
           18.67923620100485,
           18.306028250577,
           17.93282030014913,
           17.559612349721263,
           17.186404399293394,
           16.81319644886554,
           16.439988498437675,
           16.066780548009802,
           15.693572597581936,
           15.320364647154065,
           14.947156696726214,
           14.573948746298345,
           14.200740795870477,
           13.827532845442606,
           13.457404842988485,
           13.09497661264281,
           12.732548382297118,
           12.370120151951424,
           12.007691921605732,
           11.645263691260055,
           11.282835460914361,
           10.920407230568667,
           10.557979000222975,
           10.195550769877283,
           9.97071307044303,
           9.883465901920188,
           9.79621873339733,
           9.708971564874515,
           9.621724396351652,
           9.534477227828814,
           9.447230059305959,
           9.36106499169697,
           9.280753107830206,
           9.200441223963448,
           9.12012934009672,
           9.039817456229954,
           8.959505572363211,
           8.87919368849647,
           8.798881804629701,
           8.724327443373523,
           8.650168207139192,
           8.576008970904855,
           8.501849734670554,
           8.427690498436238,
           8.353531262201916,
           8.280099751940575,
           8.211386327596124,
           8.142672903251675,
           8.07395947890723,
           8.00524605456279,
           7.936532630218332,
           7.867819205873886,
           7.789295995681671,
           7.7068488711503145,
           7.624401746618956,
           7.541954622087599,
           7.45950749755625,
           7.377060373024892,
           7.294613248493526,
           7.2121661239621755,
           7.129718999430826,
           7.047271874899467,
           6.964824750368117,
           6.882377625836767,
           6.799930501305402,
           6.717483376774052,
           6.635036252242703,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           59.39305031148168,
           59.40748552830774,
           59.4219207451338,
           59.43635596195986,
           59.45079117878592,
           59.46522639561198,
           59.479661612438036,
           59.494096829264095,
           59.50853204609015,
           59.52296726291621,
           59.537402479742276,
           59.55183769656834,
           59.56627291339439,
           59.58070813022045,
           59.595143347046516,
           59.609578563872574,
           59.62401378069863,
           59.63844899752469,
           59.652884214350756,
           59.667319431176814,
           59.68175464800287,
           59.69618986482893,
           59.710625081654996,
           59.725060298481054,
           59.73949551530711,
           59.75393073213317,
           59.768365948959236,
           59.782801165785294,
           59.79723638261135,
           59.81167159943741,
           59.826106816263476,
           59.840542033089534,
           59.85497724991559,
           59.86941246674166,
           59.883847683567716,
           59.89828290039378,
           59.91271811721984,
           59.9271533340459,
           59.94158855087196,
           59.956023767698014,
           59.97045898452407,
           59.984894201350144,
           59.999329418176195,
           60.01376463500226,
           60.02819985182832,
           60.04263506865438,
           60.057070285480435,
           60.07150550230649,
           60.08594071913255,
           60.10037593595862,
           60.11481115278468,
           60.12924636961074,
           60.1436815864368,
           60.15811680326286,
           60.172552020088915,
           60.18698723691498,
           60.20142245374104,
           60.215857670567104,
           60.23029288739316,
           60.24472810421922,
           60.25916332104528,
           60.27359853787134,
           60.2880337546974,
           60.30246897152346,
           60.31690418834952,
           60.331339405175584,
           60.34577462200164,
           60.3602098388277,
           60.37464505565376,
           60.389080272479816,
           60.40351548930588,
           60.41795070613194,
           60.432385922958,
           60.44682113978406,
           60.46125635661012,
           60.47569157343618,
           60.49012679026224,
           60.504562007088296,
           60.520623493803,
           60.53749811895328,
           60.55437274410357,
           60.571247369253854,
           60.58812199440413,
           60.60499661955442,
           60.42538198463903,
           60.20646949771051,
           59.987557010782,
           59.768644523853474,
           59.54973203692496,
           59.33081952337484,
           59.08400560869146,
           58.83719169400807,
           58.59037777932469,
           58.343563864641304,
           58.09674994995793,
           57.84993603527455,
           57.603122120591166,
           57.35630820590779,
           57.109494291224394,
           56.86268037654102,
           56.61586646185765,
           56.369052547174256,
           56.12223863249087,
           55.8754247178075,
           55.628610803124126,
           55.38179688844073,
           55.13498297375736,
           54.88816905907399,
           54.64135514439059,
           54.394541229707215,
           54.14772731502383,
           53.90091340034045,
           53.65409948565708,
           53.407285570973684,
           53.16047165629031,
           52.91365774160693,
           52.66684382692354,
           52.42002991224017,
           52.173215997556795,
           51.9264020828734,
           51.67958816819002,
           51.432774253506636,
           51.185960338823264,
           50.93914642413988,
           50.69233250945649,
           50.44551859477312,
           50.19870468008973,
           49.95189076540636,
           49.70507685072297,
           49.45826293603959,
           49.211449021356216,
           48.96463510667283,
           48.71782119198945,
           48.47100727730607,
           48.224193362622685,
           47.97737944793931,
           47.73056553325593,
           47.48375161857254,
           47.23693770388916,
           46.99012378920578,
           46.7433098745224,
           46.496495959839024,
           46.24968204515564,
           46.002868130472265,
           45.75605421578887,
           45.50924030110549,
           45.26242638642212,
           45.015612471738734,
           44.76879855705536,
           44.52198464237196,
           44.27517072768859,
           44.02835681300521,
           43.781542898321824,
           43.53472898363845,
           43.28791506895506,
           43.041101154271686,
           42.7942872395883,
           42.547473324904914,
           42.30065941022154,
           42.05384549553816,
           41.807031580854776,
           41.56021766617139,
           41.31340375148801,
           41.06658983680464,
           40.81977592212125,
           40.572962007437866,
           40.326148092754494,
           39.99507148757477,
           39.621863537146915,
           39.24865558671905,
           38.87544763629118,
           38.50223968586334,
           38.12903173543545,
           37.75582378500759,
           37.382615834579724,
           37.009407884151855,
           36.636199933724,
           36.26299198329611,
           35.88978403286827,
           35.516576082440395,
           35.14336813201253,
           34.77016018158467,
           34.39695223115681,
           34.02374428072894,
           33.65053633030107,
           33.2773283798732,
           32.90951032328086,
           32.54708209293517,
           32.18465386258948,
           31.8222256322438,
           31.45979740189809,
           31.097369171552412,
           30.734940941206723,
           30.372512710861027,
           30.010084480515353,
           29.647656250169643,
           29.28522801982397,
           28.922799789478272,
           28.560371559132577,
           28.1979433287869,
           27.835515098441206,
           27.473086868095514,
           27.11065863774982,
           26.74823040740413,
           26.38580217705845,
           26.023373946712763,
           25.660945716367063,
           25.29851748602139,
           24.936089255675697,
           24.573661025330004,
           24.211232794984312,
           23.848804564638616,
           23.48637633429292,
           23.123948103947246,
           22.76151987360155,
           22.39909164325586,
           22.036663412910166,
           21.67423518256447,
           21.3118069522188,
           20.949378721873103,
           20.58695049152741,
           20.22452226118172,
           19.86209403083604,
           19.499665800490348,
           19.137237570144652,
           18.774809339798963,
           18.412381109453268,
           18.049952879107593,
           17.6875246487619,
           17.325096418416205,
           16.96266818807051,
           16.600239957724835,
           16.23781172737914,
           15.875383497033448,
           15.512955266687754,
           15.150527036342062,
           14.788098805996384,
           14.425670575650692,
           14.063242345305,
           13.700814114959305,
           13.338385884613611,
           12.975957654267937,
           12.613529423922245,
           12.251101193576549,
           11.888672963230857,
           11.526244732885178,
           11.163816502539486,
           10.801388272193794,
           10.4389600418481,
           10.076531811502406,
           9.851694112068154,
           9.764446943545313,
           9.677199775022455,
           9.589952606499638,
           9.502705437976777,
           9.41545826945394,
           9.334802080435232,
           9.254490196568499,
           9.174178312701734,
           9.093866428834977,
           9.01355454496825,
           8.933242661101483,
           8.852930777234741,
           8.77678180775548,
           8.702622571521175,
           8.62846333528686,
           8.554304099052528,
           8.48014486281819,
           8.40598562658389,
           8.331826390349574,
           8.262154794760175,
           8.193441370415728,
           8.124727946071276,
           8.05601452172683,
           7.987301097382384,
           7.918587673037943,
           7.844969355769612,
           7.762522231238253,
           7.680075106706903,
           7.597627982175546,
           7.5151808576441885,
           7.43273373311283,
           7.350286608581481,
           7.267839484050122,
           7.185392359518757,
           7.102945234987407,
           7.020498110456058,
           6.938050985924699,
           6.855603861393349,
           6.773156736861999,
           6.690709612330633,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           59.18982442553618,
           59.20425964236224,
           59.2186948591883,
           59.23313007601436,
           59.24756529284042,
           59.26200050966648,
           59.276435726492544,
           59.290870943318595,
           59.30530616014465,
           59.31974137697071,
           59.334176593796776,
           59.348611810622835,
           59.36304702744889,
           59.37748224427495,
           59.391917461101016,
           59.406352677927075,
           59.42078789475313,
           59.43522311157919,
           59.449658328405256,
           59.464093545231314,
           59.47852876205737,
           59.49296397888344,
           59.507399195709496,
           59.521834412535554,
           59.53626962936161,
           59.55070484618767,
           59.56514006301373,
           59.57957527983979,
           59.59401049666586,
           59.60844571349192,
           59.622880930317976,
           59.637316147144034,
           59.65175136397009,
           59.66618658079616,
           59.680621797622216,
           59.695057014448274,
           59.70949223127433,
           59.7239274481004,
           59.738362664926456,
           59.752797881752514,
           59.76723309857857,
           59.78166831540463,
           59.7961035322307,
           59.81053874905675,
           59.82497396588281,
           59.83940918270887,
           59.853844399534935,
           59.868279616360994,
           59.88271483318705,
           59.89715005001311,
           59.91158526683917,
           59.92602048366523,
           59.9404557004913,
           59.95489091731736,
           59.969326134143415,
           59.98376135096947,
           59.99819656779553,
           60.01263178462159,
           60.02706700144765,
           60.04150221827371,
           60.05593743509978,
           60.07037265192584,
           60.084807868751895,
           60.09924308557795,
           60.11367830240401,
           60.12811351923007,
           60.14254873605613,
           60.15698395288219,
           60.17141916970826,
           60.18585438653432,
           60.200289603360375,
           60.21472482018643,
           60.2291600370125,
           60.242040982261216,
           60.25336766003585,
           60.26469433781048,
           60.27602101558512,
           60.287347693359756,
           60.29867437113439,
           60.31000104890903,
           60.321327726683656,
           60.33265440445829,
           60.34398108223293,
           60.35530776000756,
           60.15151727740052,
           59.90470336271712,
           59.65788944803375,
           59.41107553335037,
           59.164261618666984,
           58.91744770398361,
           58.67063378930023,
           58.42381987461684,
           58.17700595993346,
           57.930192045250074,
           57.6833781305667,
           57.43656421588332,
           57.189750301199936,
           56.94293638651655,
           56.696122471833164,
           56.4493085571498,
           56.20249464246641,
           55.955680727783026,
           55.70886681309965,
           55.46205289841626,
           55.215238983732895,
           54.9684250690495,
           54.72161115436612,
           54.47479723968276,
           54.22798332499936,
           53.981169410315985,
           53.7343554956326,
           53.48754158094921,
           53.24072766626585,
           52.99391375158245,
           52.747099836899075,
           52.500285922215696,
           52.25347200753231,
           52.00665809284894,
           51.75984417816555,
           51.51303026348217,
           51.26621634879879,
           51.01940243411539,
           50.77258851943203,
           50.52577460474865,
           50.27896069006526,
           50.03214677538189,
           49.78533286069849,
           49.538518946015124,
           49.29170503133174,
           49.04489111664836,
           48.798077201964986,
           48.551263287281586,
           48.304449372598214,
           48.05763545791483,
           47.81082154323144,
           47.564007628548076,
           47.3171937138647,
           47.07037979918131,
           46.823565884497924,
           46.57675196981454,
           46.329938055131166,
           46.08312414044779,
           45.83631022576439,
           45.58949631108103,
           45.342682396397635,
           45.09586848171426,
           44.849054567030876,
           44.60224065234749,
           44.35542673766412,
           44.108612822980724,
           43.86179890829735,
           43.61498499361397,
           43.368171078930594,
           43.12135716424722,
           42.87454324956382,
           42.62772933488045,
           42.372381704291655,
           42.099966692582164,
           41.82755168087268,
           41.55513666916318,
           41.28272165745369,
           41.010306645744194,
           40.737891634034696,
           40.46547662232521,
           40.193061610615715,
           39.920646598906224,
           39.64823158719674,
           39.32806387565966,
           38.98401981420882,
           38.63997575275798,
           38.29593169130713,
           37.951887629856294,
           37.60784356840543,
           37.2637995069546,
           36.919755445503746,
           36.5757113840529,
           36.23166732260207,
           35.8876232611512,
           35.54357919970037,
           35.19953513824952,
           34.85549107679867,
           34.51144701534784,
           34.16740295389699,
           33.82335889244614,
           33.47931483099529,
           33.13527076954444,
           32.790491364905996,
           32.428063134560304,
           32.06563490421461,
           31.703206673868934,
           31.340778443523227,
           30.978350213177546,
           30.615921982831857,
           30.25349375248616,
           29.891065522140483,
           29.528637291794777,
           29.1662090614491,
           28.803780831103403,
           28.44135260075771,
           28.078924370412036,
           27.71649614006634,
           27.35406790972065,
           26.991639679374952,
           26.629211449029263,
           26.266783218683585,
           25.904354988337897,
           25.5419267579922,
           25.179498527646523,
           24.81707029730083,
           24.454642066955138,
           24.092213836609442,
           23.72978560626375,
           23.367357375918054,
           23.004929145572383,
           22.642500915226687,
           22.28007268488099,
           21.9176444545353,
           21.555216224189607,
           21.192787993843933,
           20.830359763498237,
           20.467931533152544,
           20.105503302806852,
           19.743075072461174,
           19.380646842115482,
           19.01821861176979,
           18.655790381424094,
           18.2933621510784,
           17.930933920732727,
           17.56850569038703,
           17.206077460041342,
           16.843649229695647,
           16.48122099934997,
           16.118792769004276,
           15.756364538658584,
           15.393936308312892,
           15.031508077967196,
           14.66907984762152,
           14.306651617275827,
           13.944223386930133,
           13.58179515658444,
           13.219366926238747,
           12.85693869589307,
           12.494510465547378,
           12.132082235201684,
           11.76965400485599,
           11.407225774510312,
           11.04479754416462,
           10.682369313818928,
           10.319941083473234,
           9.957512853127541,
           9.732675153693288,
           9.645427985170446,
           9.558180816647589,
           9.470933648124772,
           9.388851053040252,
           9.308539169173509,
           9.228227285306767,
           9.147915401440036,
           9.067603517573271,
           8.987291633706514,
           8.906979749839786,
           8.829236172137474,
           8.755076935903155,
           8.680917699668823,
           8.60675846343452,
           8.532599227200205,
           8.458439990965871,
           8.384280754731535,
           8.312923261924206,
           8.244209837579781,
           8.175496413235335,
           8.106782988890888,
           8.038069564546436,
           7.969356140201991,
           7.900642715857544,
           7.818195591326209,
           7.735748466794851,
           7.653301342263493,
           7.570854217732143,
           7.488407093200785,
           7.405959968669428,
           7.323512844138071,
           7.24106571960672,
           7.158618595075362,
           7.076171470543998,
           6.993724346012647,
           6.9112772214812965,
           6.828830096949938,
           6.746382972418588,
           6.663935847887238,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           58.986371095661234,
           59.0008063124873,
           59.01524152931336,
           59.029676746139415,
           59.044111962965474,
           59.05854717979154,
           59.0729823966176,
           59.087417613443655,
           59.10185283026971,
           59.11628804709578,
           59.13072326392184,
           59.145158480747895,
           59.15959369757396,
           59.17402891440001,
           59.18846413122608,
           59.20289934805214,
           59.2173345648782,
           59.23176978170425,
           59.24620499853032,
           59.26064021535638,
           59.27507543218244,
           59.2895106490085,
           59.30394586583456,
           59.31838108266062,
           59.33281629948668,
           59.34725151631274,
           59.3616867331388,
           59.376121949964855,
           59.39055716679091,
           59.40499238361697,
           59.41942760044303,
           59.4338628172691,
           59.44829803409516,
           59.46273325092122,
           59.477168467747276,
           59.491603684573334,
           59.50603890139939,
           59.52047411822545,
           59.534909335051516,
           59.54934455187758,
           59.56377976870364,
           59.5782149855297,
           59.592650202355756,
           59.607085419181814,
           59.62152063600788,
           59.63595585283394,
           59.65039106965999,
           59.66482628648606,
           59.67926150331212,
           59.69369672013817,
           59.708131936964236,
           59.722567153790294,
           59.73700237061636,
           59.75143758744241,
           59.76587280426848,
           59.780308021094534,
           59.79474323756379,
           59.806069915338426,
           59.81739659311306,
           59.8287232708877,
           59.840049948662326,
           59.85137662643697,
           59.8627033042116,
           59.87402998198623,
           59.88535665976087,
           59.89668333753551,
           59.90801001531015,
           59.91933669308478,
           59.93066337085941,
           59.941990048634054,
           59.95331672640869,
           59.96464340418332,
           59.97597008195795,
           59.98729675973259,
           59.99862343750723,
           60.00995011528186,
           60.0212767930565,
           60.032603470831134,
           60.04393014860577,
           60.0552568263804,
           60.066583504155034,
           60.07791018192967,
           60.08923685970431,
           60.10056353747894,
           59.89677305487189,
           59.64995914018849,
           59.40314522550513,
           59.15633131082174,
           58.909517396138355,
           58.66270348145498,
           58.415889566771604,
           58.16907565208822,
           57.92226173740483,
           57.67544782272145,
           57.42863390803808,
           57.181819993354694,
           56.93500607867131,
           56.68819216398792,
           56.44137824930454,
           56.19456433462117,
           55.94775041993778,
           55.700936505254404,
           55.45412259057102,
           55.20730867588763,
           54.96049476120427,
           54.71368084652088,
           54.466866931837494,
           54.22005301715413,
           53.97323910247073,
           53.726425187787356,
           53.47961127310397,
           53.232797358420584,
           52.98598344373722,
           52.73916952905382,
           52.492355614370446,
           52.24554169968707,
           51.99872778500368,
           51.75191387032031,
           51.50509995563692,
           51.258286040953536,
           51.01147212627016,
           50.76465821158678,
           50.517844296903405,
           50.27103038222002,
           50.02421646753663,
           49.77740255285326,
           49.53058863816987,
           49.283774723486495,
           49.036960808803116,
           48.79014689411973,
           48.54333297943636,
           48.29651906475296,
           48.049705150069585,
           47.80289123538621,
           47.556077320702826,
           47.309263406019454,
           47.06244949133607,
           46.81563557665268,
           46.5688216619693,
           46.322007747285916,
           46.05385958214224,
           45.78144457043274,
           45.50902955872324,
           45.23661454701376,
           44.964199535304246,
           44.69178452359476,
           44.41936951188527,
           44.146954500175774,
           43.8745394884663,
           43.602124476756785,
           43.3297094650473,
           43.05729445333781,
           42.784879441628306,
           42.51246442991882,
           42.24004941820931,
           41.967634406499826,
           41.69521939479034,
           41.422804383080845,
           41.15038937137136,
           40.87797435966186,
           40.605559347952365,
           40.33314433624287,
           40.060729324533376,
           39.78831431282389,
           39.515899301114395,
           39.243484289404904,
           38.97106927769542,
           38.65090156615834,
           38.30685750470751,
           37.96281344325666,
           37.61876938180581,
           37.274725320354975,
           36.930681258904116,
           36.58663719745328,
           36.24259313600243,
           35.89854907455158,
           35.55450501310075,
           35.210460951649885,
           34.86641689019905,
           34.5223728287482,
           34.17832876729735,
           33.83428470584652,
           33.49024064439567,
           33.146196582944825,
           32.802152521493966,
           32.45810846004313,
           32.11406439859229,
           31.77002033714144,
           31.425976275690594,
           31.081932214239764,
           30.737888152788898,
           30.39384409133806,
           30.04980002988721,
           29.705755968436364,
           29.361711906985533,
           29.017667845534667,
           28.673623784083837,
           28.329579722632985,
           27.98553566118214,
           27.641491599731307,
           27.29744753828045,
           26.953403476829607,
           26.609359415378755,
           26.26531535392791,
           25.92127129247708,
           25.577227231026225,
           25.233183169575376,
           24.889139108124542,
           24.545095046673694,
           24.201050985222846,
           23.857006923771998,
           23.512962862321146,
           23.1689188008703,
           22.824874739419467,
           22.480830677968616,
           22.136786616517767,
           21.79274255506692,
           21.436197265814734,
           21.07376903546906,
           20.711340805123363,
           20.348912574777668,
           19.98648434443198,
           19.6240561140863,
           19.261627883740605,
           18.899199653394913,
           18.53677142304922,
           18.174343192703528,
           17.81191496235785,
           17.449486732012158,
           17.087058501666466,
           16.72463027132077,
           16.362202040975095,
           15.999773810629401,
           15.637345580283707,
           15.274917349938013,
           14.912489119592323,
           14.550060889246645,
           14.187632658900952,
           13.825204428555258,
           13.462776198209566,
           13.100347967863872,
           12.737919737518196,
           12.375491507172503,
           12.01306327682681,
           11.650635046481115,
           11.288206816135439,
           10.925778585789747,
           10.563350355444053,
           10.200922125098359,
           9.838493894752666,
           9.613656195318413,
           9.52640902679557,
           9.442900025645292,
           9.36258814177853,
           9.282276257911782,
           9.201964374045039,
           9.121652490178297,
           9.041340606311566,
           8.9610287224448,
           8.881690536519448,
           8.807531300285111,
           8.733372064050808,
           8.659212827816491,
           8.58505359158216,
           8.510894355347855,
           8.43673511911354,
           8.363691729088265,
           8.294978304743832,
           8.226264880399361,
           8.157551456054936,
           8.08883803171049,
           8.020124607366043,
           7.95141118302159,
           7.873868951414141,
           7.79142182688279,
           7.70897470235144,
           7.626527577820082,
           7.544080453288724,
           7.461633328757373,
           7.379186204226016,
           7.2967390796946585,
           7.214291955163301,
           7.131844830631953,
           7.049397706100594,
           6.966950581569228,
           6.884503457037878,
           6.802056332506528,
           6.71960920797517,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           58.7829177657863,
           58.79735298261236,
           58.81178819943842,
           58.82622341626448,
           58.84065863309054,
           58.8550938499166,
           58.86952906674266,
           58.88396428356872,
           58.898399500394774,
           58.91283471722084,
           58.927269934046905,
           58.94170515087296,
           58.95614036769902,
           58.97057558452508,
           58.985010801351144,
           58.999446018177196,
           59.01388123500326,
           59.02831645182932,
           59.042751668655384,
           59.05718688548144,
           59.0716221023075,
           59.08605731913356,
           59.100492535959624,
           59.114927752785675,
           59.12936296961173,
           59.14379818643779,
           59.15823340326385,
           59.17266862008992,
           59.18710383691598,
           59.20153905374204,
           59.2159742705681,
           59.230409487394155,
           59.24484470422021,
           59.25927992104627,
           59.273715137872344,
           59.2881503546984,
           59.30258557152446,
           59.31702078835052,
           59.33145600517658,
           59.345891222002635,
           59.35877217064101,
           59.37009884841565,
           59.381425526190284,
           59.39275220396492,
           59.40407888173955,
           59.415405559514184,
           59.42673223728882,
           59.43805891506345,
           59.449385592838084,
           59.46071227061272,
           59.472038948387365,
           59.483365626162,
           59.49469230393663,
           59.506018981711264,
           59.5173456594859,
           59.52867233726053,
           59.539999015035164,
           59.55132569280981,
           59.562652370584445,
           59.57397904835907,
           59.58530572613371,
           59.596632403908345,
           59.60795908168298,
           59.61928575945761,
           59.63061243723225,
           59.64193911500689,
           59.653265792781525,
           59.66459247055616,
           59.67591914833079,
           59.687245826105425,
           59.69857250388006,
           59.70989918165469,
           59.72122585942934,
           59.73255253720397,
           59.743879214978605,
           59.75520589275324,
           59.76653257052787,
           59.777859248302505,
           59.78918592607714,
           59.80051260385178,
           59.81183928162641,
           59.82316595940105,
           59.834492637175686,
           59.84581931495032,
           59.64202883234327,
           59.39521491765987,
           59.148401002976506,
           58.90158708829312,
           58.65477317360973,
           58.40795925892636,
           58.16114534424298,
           57.914331429559596,
           57.66751751487621,
           57.42070360019282,
           57.17388968550946,
           56.92707577082607,
           56.680261856142685,
           56.433447941459306,
           56.18663402677592,
           55.93982011209255,
           55.69300619740916,
           55.446192282725775,
           55.199378368042396,
           54.95256445335902,
           54.705750538675645,
           54.45893662399226,
           54.21212270930888,
           53.9653087946255,
           53.718494879942114,
           53.47168096525874,
           53.224867050575355,
           52.97805313589197,
           52.7312392212086,
           52.4844253065252,
           52.23761139184183,
           51.990797477158445,
           51.743983562475066,
           51.497169647791694,
           51.25035573310831,
           51.00354181842492,
           50.756727903741535,
           50.509913989058155,
           50.26310007437478,
           50.00775247170229,
           49.73533745999279,
           49.46292244828331,
           49.190507436573796,
           48.91809242486431,
           48.64567741315483,
           48.37326240144533,
           48.10084738973585,
           47.828432378026335,
           47.55601736631685,
           47.28360235460736,
           47.01118734289787,
           46.738772331188386,
           46.46635731947889,
           46.19394230776939,
           45.92152729605989,
           45.649112284350394,
           45.37669727264092,
           45.10428226093142,
           44.83186724922192,
           44.55945223751244,
           44.28703722580293,
           44.01462221409345,
           43.74220720238395,
           43.469792190674454,
           43.19737717896498,
           42.924962167255465,
           42.65254715554598,
           42.380132143836484,
           42.10771713212699,
           41.83530212041751,
           41.562887108708,
           41.29047209699851,
           41.018057085289016,
           40.745642073579525,
           40.47322706187004,
           40.20081205016054,
           39.92839703845105,
           39.655982026741555,
           39.38356701503206,
           39.11115200332257,
           38.838736991613075,
           38.566321979903584,
           38.29390696819411,
           37.973739256657026,
           37.62969519520619,
           37.28565113375534,
           36.94160707230449,
           36.59756301085366,
           36.25351894940279,
           35.90947488795196,
           35.565430826501114,
           35.22138676505026,
           34.877342703599425,
           34.533298642148566,
           34.189254580697735,
           33.84521051924688,
           33.50116645779603,
           33.1571223963452,
           32.81307833489436,
           32.469034273443505,
           32.12499021199265,
           31.780946150541805,
           31.43690208909097,
           31.09285802764012,
           30.748813966189275,
           30.404769904738444,
           30.060725843287578,
           29.716681781836744,
           29.372637720385892,
           29.028593658935048,
           28.684549597484214,
           28.340505536033348,
           27.996461474582517,
           27.652417413131666,
           27.30837335168082,
           26.964329290229987,
           26.62028522877913,
           26.276241167328287,
           25.932197105877435,
           25.58815304442659,
           25.24410898297576,
           24.900064921524905,
           24.556020860074057,
           24.211976798623223,
           23.867932737172374,
           23.52388867572153,
           23.179844614270678,
           22.835800552819826,
           22.49175649136898,
           22.147712429918144,
           21.8036683684673,
           21.459624307016448,
           21.115580245565603,
           20.77153618411475,
           20.42749212266392,
           20.08344806121307,
           19.73940399976222,
           19.395359938311373,
           19.05131587686054,
           18.70727181540969,
           18.363227753958842,
           18.019183692507994,
           17.675139631057146,
           17.331095569606312,
           16.98705150815546,
           16.643007446704615,
           16.298963385253764,
           15.954919323802933,
           15.610875262352083,
           15.266831200901233,
           14.922787139450385,
           14.578743077999537,
           14.234699016548703,
           13.890654955097853,
           13.546610893647006,
           13.202566832196158,
           12.85852277074531,
           12.514478709294476,
           12.170434647843628,
           11.826390586392778,
           11.482346524941928,
           11.138302463491094,
           10.794258402040242,
           10.444331397069178,
           10.081903166723485,
           9.719474936377791,
           9.496948998250316,
           9.416637114383548,
           9.336325230516822,
           9.256013346650063,
           9.175701462783314,
           9.09538957891657,
           9.015077695049829,
           8.9347658111831,
           8.859985664667112,
           8.785826428432788,
           8.71166719219845,
           8.637507955964146,
           8.563348719729829,
           8.489189483495498,
           8.415030247261193,
           8.345746771907846,
           8.277033347563421,
           8.208319923218989,
           8.139606498874517,
           8.07089307453009,
           8.002179650185644,
           7.929542311502081,
           7.847095186970737,
           7.764648062439372,
           7.6822009379080205,
           7.599753813376671,
           7.517306688845315,
           7.434859564313957,
           7.352412439782606,
           7.269965315251248,
           7.18751819071989,
           7.105071066188532,
           7.022623941657183,
           6.940176817125825,
           6.857729692594461,
           6.77528256806311,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           58.57946443591137,
           58.593899652737434,
           58.60833486956349,
           58.62277008638955,
           58.637205303215616,
           58.651640520041674,
           58.66607573686773,
           58.68051095369379,
           58.694946170519856,
           58.709381387345914,
           58.72381660417197,
           58.73825182099804,
           58.752687037824096,
           58.767122254650154,
           58.78155747147621,
           58.79599268830228,
           58.810427905128336,
           58.824863121954394,
           58.83929833878046,
           58.85373355560652,
           58.868168772432576,
           58.882603989258634,
           58.8970392060847,
           58.91147442291076,
           58.92280110371824,
           58.934127781492876,
           58.94545445926752,
           58.95678113704216,
           58.96810781481679,
           58.97943449259142,
           58.990761170366056,
           59.00208784814069,
           59.01341452591532,
           59.02474120368997,
           59.03606788146459,
           59.04739455923924,
           59.05872123701387,
           59.0700479147885,
           59.08137459256314,
           59.09270127033777,
           59.1040279481124,
           59.115354625887036,
           59.12668130366167,
           59.13800798143632,
           59.14933465921095,
           59.160661336985584,
           59.17198801476022,
           59.18331469253486,
           59.19464137030949,
           59.20596804808412,
           59.21729472585876,
           59.22862140363339,
           59.23994808140803,
           59.25127475918267,
           59.2626014369573,
           59.27392811473194,
           59.285254792506564,
           59.296581470281204,
           59.30790814805584,
           59.31923482583046,
           59.33056150360511,
           59.34188818137974,
           59.353214859154384,
           59.36454153692902,
           59.375868214703644,
           59.38719489247828,
           59.39852157025291,
           59.409848248027544,
           59.42117492580219,
           59.432501603576824,
           59.44382828135146,
           59.45515495912609,
           59.466481636900724,
           59.47780831467537,
           59.489134992450005,
           59.50046167022464,
           59.51178834799927,
           59.523115025773905,
           59.53444170354854,
           59.54576838132317,
           59.557095059097804,
           59.56842173687244,
           59.57974841464707,
           59.59107509242172,
           59.38728460981467,
           59.14047069513127,
           58.893656780447905,
           58.64684286576452,
           58.40002895108113,
           58.15321503639776,
           57.906401121714374,
           57.659587207030995,
           57.41277329234761,
           57.16595937766422,
           56.91914546298086,
           56.67233154829747,
           56.425517633614085,
           56.178703718930706,
           55.93188980424732,
           55.68507588956395,
           55.43826197488056,
           55.191448060197175,
           54.944634145513795,
           54.697820230830416,
           54.451006316147044,
           54.20419240146366,
           53.95737848678027,
           53.689230349552915,
           53.41681533784342,
           53.144400326133926,
           52.871985314424435,
           52.59957030271493,
           52.327155291005454,
           52.05474027929594,
           51.78232526758646,
           51.50991025587697,
           51.23749524416747,
           50.965080232457986,
           50.69266522074849,
           50.420250209039,
           50.1478351973295,
           49.87542018562,
           49.60300517391052,
           49.33059016220103,
           49.05817515049153,
           48.785760138782045,
           48.51334512707254,
           48.24093011536306,
           47.96851510365356,
           47.69610009194406,
           47.42368508023458,
           47.15127006852507,
           46.87885505681559,
           46.6064400451061,
           46.3340250333966,
           46.061610021687116,
           45.78919500997762,
           45.51677999826812,
           45.24436498655862,
           44.97194997484913,
           44.69953496313965,
           44.42711995143015,
           44.15470493972066,
           43.882289928011176,
           43.60987491630166,
           43.33745990459218,
           43.06504489288269,
           42.79262988117319,
           42.52021486946371,
           42.2477998577542,
           41.97538484604472,
           41.70296983433522,
           41.43055482262572,
           41.15813981091624,
           40.88572479920673,
           40.61330978749725,
           40.34089477578775,
           40.068479764078255,
           39.79606475236877,
           39.52364974065928,
           39.25123472894978,
           38.978819717240285,
           38.70640470553079,
           38.43398969382131,
           38.16157468211181,
           37.88915967040232,
           37.61674465869284,
           37.296576947155756,
           36.952532885704926,
           36.60848882425407,
           36.26444476280322,
           35.92040070135239,
           35.576356639901526,
           35.23231257845069,
           34.888268516999844,
           34.544224455549,
           34.20018039409816,
           33.8561363326473,
           33.512092271196465,
           33.16804820974562,
           32.82400414829477,
           32.47996008684394,
           32.13591602539309,
           31.791871963942235,
           31.44782790249139,
           31.10378384104054,
           30.759739779589705,
           30.415695718138853,
           30.07165165668801,
           29.727607595237178,
           29.383563533786315,
           29.039519472335478,
           28.695475410884626,
           28.35143134943378,
           28.00738728798295,
           27.66334322653208,
           27.31929916508125,
           26.9752551036304,
           26.63121104217955,
           26.28716698072872,
           25.94312291927787,
           25.599078857827024,
           25.25503479637617,
           24.910990734925324,
           24.566946673474494,
           24.22290261202364,
           23.87885855057279,
           23.534814489121956,
           23.190770427671108,
           22.846726366220263,
           22.50268230476941,
           22.158638243318563,
           21.814594181867715,
           21.47055012041688,
           21.126506058966033,
           20.782461997515185,
           20.438417936064333,
           20.098884417538564,
           19.770627363000624,
           19.442370308462674,
           19.11411325392472,
           18.785856199386767,
           18.457599144848828,
           18.129342090310875,
           17.80108503577292,
           17.472827981234968,
           17.144570926697018,
           16.81631387215908,
           16.488056817621125,
           16.15979976308317,
           15.831542708545221,
           15.503285654007282,
           15.175028599469327,
           14.846771544931375,
           14.518514490393422,
           14.190257435855468,
           13.86200038131753,
           13.533743326779579,
           13.205486272241625,
           12.877229217703672,
           12.548972163165718,
           12.220715108627779,
           11.892458054089825,
           11.564200999551874,
           11.235943945013922,
           10.907686890475983,
           10.57942983593803,
           10.251172781400076,
           9.922915726862122,
           9.594658672324169,
           9.390374203121851,
           9.310062319255083,
           9.22975043538836,
           9.1494385515216,
           9.06912666765485,
           8.988814783788106,
           8.912440029049097,
           8.838280792814794,
           8.764121556580456,
           8.68996232034613,
           8.615803084111793,
           8.54164384787749,
           8.467484611643172,
           8.396515239071922,
           8.327801814727492,
           8.259088390383006,
           8.19037496603858,
           8.121661541694147,
           8.052948117349676,
           7.9842346930052495,
           7.9027685470586775,
           7.82032142252732,
           7.737874297995977,
           7.655427173464612,
           7.57298004893326,
           7.490532924401911,
           7.408085799870554,
           7.325638675339196,
           7.243191550807845,
           7.160744426276488,
           7.07829730174513,
           6.9958501772137724,
           6.9134030526824235,
           6.830955928151065,
           6.7485088036197,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           58.37601110603644,
           58.390446322862495,
           58.40488153968856,
           58.41931675651462,
           58.43375197334068,
           58.448187190166735,
           58.4626224069928,
           58.47550335902083,
           58.48683003679546,
           58.498156714570094,
           58.50948339234473,
           58.52081007011937,
           58.532136747894,
           58.543463425668634,
           58.554790103443274,
           58.56611678121791,
           58.57744345899254,
           58.58877013676718,
           58.600096814541814,
           58.61142349231645,
           58.62275017009108,
           58.634076847865714,
           58.64540352564035,
           58.65673020341498,
           58.66805688118962,
           58.679383558964254,
           58.690710236738894,
           58.70203691451353,
           58.71336359228816,
           58.724690270062794,
           58.736016947837435,
           58.747343625612075,
           58.75867030338671,
           58.76999698116134,
           58.78132365893597,
           58.79265033671061,
           58.80397701448524,
           58.815303692259874,
           58.826630370034515,
           58.83795704780914,
           58.84928372558378,
           58.86061040335842,
           58.871937081133055,
           58.88326375890769,
           58.89459043668232,
           58.905917114456955,
           58.917243792231595,
           58.92857047000622,
           58.93989714778086,
           58.951223825555495,
           58.962550503330135,
           58.973877181104776,
           58.98520385887941,
           58.996530536654035,
           59.007857214428675,
           59.019183892203316,
           59.03051056997794,
           59.04183724775258,
           59.053163925527215,
           59.06449060330185,
           59.07581728107648,
           59.08714395885112,
           59.098470636625756,
           59.10979731440039,
           59.12112399217503,
           59.13245066994966,
           59.143777347724296,
           59.15510402549893,
           59.16643070327356,
           59.177757381048195,
           59.189084058822836,
           59.20041073659747,
           59.2117374143721,
           59.22306409214674,
           59.234390769921376,
           59.24571744769601,
           59.25704412547064,
           59.268370803245276,
           59.27969748101991,
           59.29102415879454,
           59.30235083656918,
           59.313677514343816,
           59.325004192118456,
           59.33633086989309,
           59.13254038728604,
           58.88572647260264,
           58.63891255791928,
           58.39209864323589,
           58.145284728552504,
           57.89847081386913,
           57.643123239112974,
           57.37070822740348,
           57.098293215693985,
           56.82587820398449,
           56.553463192275004,
           56.28104818056551,
           56.00863316885601,
           55.73621815714652,
           55.46380314543702,
           55.191388133727536,
           54.918973122018045,
           54.64655811030855,
           54.37414309859905,
           54.10172808688956,
           53.829313075180075,
           53.55689806347058,
           53.28448305176108,
           53.012068040051595,
           52.7396530283421,
           52.467238016632606,
           52.194823004923116,
           51.92240799321361,
           51.649992981504134,
           51.37757796979462,
           51.10516295808514,
           50.83274794637564,
           50.56033293466615,
           50.28791792295666,
           50.01550291124717,
           49.74308789953768,
           49.47067288782818,
           49.19825787611868,
           48.9258428644092,
           48.6534278526997,
           48.3810128409902,
           48.10859782928073,
           47.83618281757122,
           47.563767805861744,
           47.29135279415224,
           47.01893778244275,
           46.746522770733264,
           46.47410775902375,
           46.20169274731427,
           45.92927773560478,
           45.65686272389528,
           45.384447712185796,
           45.1120327004763,
           44.8396176887668,
           44.5672026770573,
           44.294787665347805,
           44.02237265363833,
           43.74995764192883,
           43.47754263021934,
           43.20512761850985,
           42.932712606800344,
           42.66029759509086,
           42.38788258338136,
           42.115467571671864,
           41.84305255996239,
           41.57063754825288,
           41.2982225365434,
           41.02580752483391,
           40.7533925131244,
           40.48097750141492,
           40.208562489705415,
           39.936147477995924,
           39.66373246628643,
           39.39131745457694,
           39.11890244286746,
           38.84648743115797,
           38.57407241944847,
           38.30165740773897,
           38.029242396029474,
           37.75682738431999,
           37.48441237261049,
           37.211997360900995,
           36.93958234919151,
           36.61941463765443,
           36.275370576203606,
           35.931326514752755,
           35.58728245330191,
           35.24323839185107,
           34.89919433040021,
           34.555150268949376,
           34.21110620749853,
           33.86706214604768,
           33.52301808459684,
           33.178974023145976,
           32.834929961695146,
           32.4908859002443,
           32.14684183879345,
           31.8095635857763,
           31.481306531238346,
           31.153049476700392,
           30.82479242216244,
           30.49653536762449,
           30.168278313086546,
           29.840021258548596,
           29.511764204010642,
           29.183507149472703,
           28.855250094934735,
           28.5269930403968,
           28.198735985858846,
           27.870478931320893,
           27.542221876782953,
           27.213964822244986,
           26.885707767707046,
           26.557450713169096,
           26.22919365863114,
           25.900936604093204,
           25.572679549555254,
           25.2444224950173,
           24.916165440479347,
           24.587908385941397,
           24.259651331403454,
           23.9313942768655,
           23.603137222327547,
           23.27488016778961,
           22.946623113251658,
           22.618366058713704,
           22.29010900417575,
           21.961851949637797,
           21.633594895099844,
           21.305337840561904,
           20.977080786023954,
           20.648823731486,
           20.320566676948044,
           19.992309622410094,
           19.664052567872158,
           19.3357955133342,
           19.007538458796247,
           18.679281404258298,
           18.35102434972036,
           18.022767295182405,
           17.69451024064445,
           17.3662531861065,
           17.037996131568548,
           16.70973907703061,
           16.381482022492655,
           16.0532249679547,
           15.72496791341675,
           15.39671085887881,
           15.068453804340855,
           14.740196749802903,
           14.411939695264952,
           14.083682640726998,
           13.755425586189059,
           13.427168531651109,
           13.098911477113155,
           12.770654422575202,
           12.442397368037248,
           12.114140313499309,
           11.785883258961356,
           11.457626204423404,
           11.129369149885449,
           10.801112095347513,
           10.47285504080956,
           10.144597986271606,
           9.816340931733652,
           9.4880838771957,
           9.283799407993381,
           9.203487524126617,
           9.123175640259891,
           9.042863756393132,
           8.964894393431068,
           8.890735157196735,
           8.816575920962434,
           8.742416684728129,
           8.668257448493792,
           8.594098212259466,
           8.519938976025129,
           8.447283706235932,
           8.378570281891506,
           8.30985685754708,
           8.241143433202648,
           8.172430008858163,
           8.103716584513736,
           8.035003160169303,
           7.958441907146624,
           7.875994782615274,
           7.793547658083909,
           7.711100533552551,
           7.62865340902121,
           7.546206284489843,
           7.463759159958492,
           7.3813120354271415,
           7.298864910895785,
           7.216417786364427,
           7.133970661833077,
           7.051523537301719,
           6.969076412770361,
           6.886629288239003,
           6.8041821637076545,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           58.165114279987094,
           58.17324087817611,
           58.18136747636513,
           58.189494074554155,
           58.19762067274318,
           58.20574727093219,
           58.213873869121215,
           58.22200046731023,
           58.23012706549926,
           58.238253663688276,
           58.24638026711152,
           58.25770694488616,
           58.26903362266079,
           58.280360300435426,
           58.29168697821006,
           58.3030136559847,
           58.31434033375933,
           58.325667011533966,
           58.336993689308606,
           58.34832036708324,
           58.359647044857866,
           58.370973722632506,
           58.38230040040714,
           58.39362707818177,
           58.40495375595641,
           58.416280433731046,
           58.42760711150568,
           58.43893378928032,
           58.45026046705495,
           58.46158714482959,
           58.47291382260423,
           58.48424050037886,
           58.49556717815349,
           58.506893855928126,
           58.51822053370276,
           58.5295472114774,
           58.540873889252026,
           58.55220056702667,
           58.5635272448013,
           58.57485392257594,
           58.58618060035057,
           58.59750727812521,
           58.60883395589984,
           58.62016063367447,
           58.631487311449106,
           58.64281398922375,
           58.65414066699838,
           58.66546734477302,
           58.67679402254765,
           58.68812070032229,
           58.69944737809692,
           58.71077405587155,
           58.72210073364619,
           58.73342741142082,
           58.74475408919547,
           58.75608076697009,
           58.767407444744734,
           58.77873412251936,
           58.790060800294,
           58.801387478068634,
           58.81271415584327,
           58.8240408336179,
           58.83536751139253,
           58.84669418916717,
           58.85802086694181,
           58.86934754471645,
           58.88067422249108,
           58.892000900265714,
           58.90332757804035,
           58.91465425581499,
           58.92598093358962,
           58.93730761136426,
           58.948634289138894,
           58.95996096691353,
           58.97128764468816,
           58.982614322462794,
           58.99394100023743,
           59.00526767801207,
           59.0165943557867,
           59.027921033561334,
           59.03924771133597,
           59.05057438911061,
           59.06190106688524,
           59.073227744659874,
           58.84810301453107,
           58.575688002821565,
           58.303272991112074,
           58.03085797940258,
           57.758442967693085,
           57.4860279559836,
           57.21361294427411,
           56.94119793256461,
           56.66878292085512,
           56.39636790914562,
           56.12395289743614,
           55.85153788572664,
           55.579122874017145,
           55.30670786230765,
           55.034292850598156,
           54.76187783888867,
           54.489462827179175,
           54.217047815469684,
           53.944632803760186,
           53.67221779205069,
           53.39980278034121,
           53.127387768631706,
           52.854972756922216,
           52.58255774521274,
           52.31014273350323,
           52.03772772179374,
           51.765312710084245,
           51.492897698374755,
           51.220482686665264,
           50.94806767495576,
           50.67565266324627,
           50.40323765153678,
           50.13082263982729,
           49.858407628117796,
           49.585992616408305,
           49.31357760469881,
           49.04116259298931,
           48.76874758127981,
           48.49633256957033,
           48.22391755786083,
           47.95150254615134,
           47.679087534441855,
           47.40667252273235,
           47.13425751102287,
           46.86184249931337,
           46.58942748760387,
           46.31701247589439,
           46.04459746418488,
           45.7721824524754,
           45.4997674407659,
           45.22735242905641,
           44.954937417346926,
           44.68252240563743,
           44.41010739392793,
           44.13769238221844,
           43.86527737050894,
           43.59286235879946,
           43.32044734708997,
           43.04803233538047,
           42.775617323670986,
           42.50320231196147,
           42.23078730025199,
           41.9583722885425,
           41.685957276833,
           41.41354226512352,
           41.14112725341401,
           40.86871224170453,
           40.59629722999503,
           40.32388221828553,
           40.05146720657605,
           39.779052194866544,
           39.50663718315706,
           39.23422217144756,
           38.945731713089884,
           38.6492034722468,
           38.35267523140371,
           38.05614699056062,
           37.759618749717525,
           37.46309050887443,
           37.166562268031356,
           36.87003402718826,
           36.57350578634517,
           36.27697754550209,
           35.968147827782175,
           35.653167371623866,
           35.33818691546555,
           35.02320645930723,
           34.70822600314893,
           34.3932455469906,
           34.078265090832296,
           33.76328463467398,
           33.44830417851566,
           33.13332372235736,
           32.81834326619903,
           32.50336281004073,
           32.18838235388241,
           31.873401897724097,
           31.55842144156579,
           31.243440985407478,
           30.928460529249158,
           30.61348007309084,
           30.298499616932524,
           29.98351916077422,
           29.668538704615905,
           29.35355824845759,
           29.03857779229929,
           28.723597336140955,
           28.408616879982652,
           28.092161190730387,
           27.76390413619243,
           27.43564708165449,
           27.107390027116523,
           26.779132972578584,
           26.45087591804063,
           26.12261886350268,
           25.79436180896474,
           25.466104754426787,
           25.13784769988884,
           24.809590645350884,
           24.48133359081293,
           24.15307653627499,
           23.824819481737038,
           23.496562427199084,
           23.168305372661152,
           22.840048318123195,
           22.51179126358524,
           22.18353420904729,
           21.855277154509334,
           21.52702009997138,
           21.19876304543344,
           20.870505990895488,
           20.542248936357534,
           20.213991881819585,
           19.88573482728163,
           19.55747777274369,
           19.229220718205738,
           18.90096366366779,
           18.572706609129835,
           18.244449554591895,
           17.916192500053942,
           17.587935445515992,
           17.25967839097804,
           16.931421336440085,
           16.603164281902146,
           16.274907227364192,
           15.94665017282624,
           15.618393118288289,
           15.290136063750348,
           14.961879009212394,
           14.633621954674442,
           14.305364900136489,
           13.977107845598535,
           13.648850791060598,
           13.320593736522646,
           12.992336681984693,
           12.664079627446739,
           12.335822572908786,
           12.007565518370846,
           11.679308463832895,
           11.351051409294941,
           11.02279435475699,
           10.69453730021905,
           10.366280245681097,
           10.038023191143143,
           9.70976613660519,
           9.381509082067238,
           9.177224612864919,
           9.096912728998152,
           9.01734875781308,
           8.943189521578748,
           8.869030285344412,
           8.79487104911008,
           8.720711812875777,
           8.646552576641472,
           8.572393340407135,
           8.49823410417281,
           8.429338749055583,
           8.360625324711092,
           8.291911900366664,
           8.223198476022239,
           8.154485051677808,
           8.085771627333322,
           8.01411526723458,
           7.93166814270322,
           7.849221018171864,
           7.766773893640513,
           7.684326769109148,
           7.6018796445777905,
           7.519432520046449,
           7.436985395515083,
           7.354538270983733,
           7.272091146452381,
           7.1896440219210245,
           7.107196897389667,
           7.024749772858316,
           6.942302648326959,
           6.8598555237956,
           6.777408399264243,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           57.94937917929266,
           57.957505777481686,
           57.96563237567071,
           57.97375897385973,
           57.98188557204875,
           57.99001217023777,
           57.998138768426784,
           58.006265366615814,
           58.01439196480483,
           58.02251856299385,
           58.03064516118287,
           58.03877175937189,
           58.04689835756091,
           58.055024955749936,
           58.06315155393895,
           58.07127815212798,
           58.079404750316996,
           58.08753134850602,
           58.09565794669504,
           58.10378454488406,
           58.11191114307309,
           58.1200377412621,
           58.128164339451125,
           58.13629093764014,
           58.144417535829156,
           58.152544134018186,
           58.1606707322072,
           58.17039737489523,
           58.18172405266987,
           58.193050730444504,
           58.20437740821914,
           58.21570408599378,
           58.22703076376841,
           58.238357441543045,
           58.24968411931768,
           58.26101079709232,
           58.272337474866944,
           58.28366415264158,
           58.294990830416225,
           58.30631750819085,
           58.31764418596549,
           58.328970863740125,
           58.34029754151476,
           58.35162421928939,
           58.362950897064025,
           58.37427757483866,
           58.3856042526133,
           58.39693093038793,
           58.408257608162565,
           58.4195842859372,
           58.43091096371184,
           58.44223764148647,
           58.453564319261105,
           58.46489099703575,
           58.476217674810385,
           58.48754435258502,
           58.49887103035965,
           58.510197708134285,
           58.52152438590892,
           58.53285106368355,
           58.544177741458185,
           58.55550441923282,
           58.56683109700746,
           58.5781577747821,
           58.58948445255673,
           58.600811130331365,
           58.612137808106,
           58.62346448588063,
           58.634791163655265,
           58.6461178414299,
           58.65744451920454,
           58.66877119697918,
           58.68009787475381,
           58.691424552528446,
           58.70275123030308,
           58.71407790807772,
           58.725404585852345,
           58.73673126362698,
           58.748057941401626,
           58.75938461917626,
           58.77071129695089,
           58.782037974725526,
           58.79336465250016,
           58.80469133027479,
           58.579566600145995,
           58.30715158843648,
           58.034736576727,
           57.7623215650175,
           57.48990655330801,
           57.21749154159852,
           56.94507652988903,
           56.67266151817953,
           56.40024650647003,
           56.12783149476054,
           55.85541648305105,
           55.583001471341554,
           55.31058645963206,
           55.038171447922565,
           54.76575643621307,
           54.49334142450358,
           54.22092641279409,
           53.948511401084595,
           53.676096389375104,
           53.403681377665606,
           53.13126636595612,
           52.858851354246625,
           52.586436342537134,
           52.31402133082764,
           52.041606319118145,
           51.76919130740866,
           51.49677629569916,
           51.224361283989666,
           50.95194627228018,
           50.67953126057067,
           50.40711624886119,
           50.1347012371517,
           49.8622862254422,
           49.58987121373272,
           49.31745620202322,
           49.045041190313725,
           48.77262617860423,
           48.50021116689473,
           48.227796155185246,
           47.955381143475755,
           47.68296613176626,
           47.41055112005677,
           47.13813610834727,
           46.865721096637785,
           46.59330608492829,
           46.32089107321879,
           46.048476061509305,
           45.77606104979981,
           45.50364603809032,
           45.231231026380826,
           44.95881601467133,
           44.686401002961844,
           44.413985991252346,
           44.14157097954285,
           43.869155967833365,
           43.59674095612386,
           43.32030710835431,
           43.023778867511204,
           42.727250626668116,
           42.430722385825035,
           42.134194144981926,
           41.83766590413885,
           41.54113766329576,
           41.24460942245267,
           40.94808118160959,
           40.65155294076648,
           40.355024699923405,
           40.05849645908032,
           39.761968218237215,
           39.465439977394134,
           39.16891173655104,
           38.87238349570796,
           38.57585525486486,
           38.279327014021774,
           37.98279877317869,
           37.6862705323356,
           37.38974229149251,
           37.093214050649415,
           36.79668580980632,
           36.500157568963246,
           36.20362932812015,
           35.907101087277056,
           35.61057284643398,
           35.30174312871406,
           34.986762672555756,
           34.67178221639744,
           34.35680176023912,
           34.04182130408083,
           33.72684084792249,
           33.411860391764186,
           33.09687993560587,
           32.78189947944755,
           32.46691902328925,
           32.15193856713092,
           31.836958110972617,
           31.521977654814304,
           31.206997198655987,
           30.89201674249768,
           30.577036286339368,
           30.262055830181048,
           29.94707537402273,
           29.632094917864414,
           29.31711446170611,
           29.002134005547795,
           28.68715354938948,
           28.372173093231176,
           28.057192637072845,
           27.742212180914542,
           27.427231724756226,
           27.11225126859791,
           26.797270812439606,
           26.482290356281275,
           26.167309900122973,
           25.852329443964656,
           25.53734898780634,
           25.22236853164804,
           24.90738807548972,
           24.592407619331404,
           24.27742716317309,
           23.962446707014767,
           23.647466250856468,
           23.33248579469815,
           23.017505338539834,
           22.70252488238153,
           22.387544426223215,
           22.0725639700649,
           21.757583513906585,
           21.442603057748265,
           21.12762260158995,
           20.812642145431646,
           20.49766168927333,
           20.18268123311501,
           19.867700776956696,
           19.55272032079838,
           19.237739864640076,
           18.92275940848176,
           18.607778952323446,
           18.292798496165126,
           17.977818040006824,
           17.662837583848507,
           17.34785712769019,
           17.032876671531874,
           16.717896215373557,
           16.402915759215254,
           16.08793530305694,
           15.772954846898624,
           15.457974390740304,
           15.142993934582002,
           14.82801347842369,
           14.51303302226537,
           14.198052566107053,
           13.870533050470064,
           13.542275995932128,
           13.214018941394174,
           12.885761886856223,
           12.55750483231827,
           12.229247777780314,
           11.900990723242378,
           11.572733668704425,
           11.244476614166471,
           10.916219559628518,
           10.58796250509058,
           10.259705450552625,
           9.931448396014675,
           9.60319134147672,
           9.274934286938768,
           9.070649817736447,
           8.995643885960682,
           8.921484649726416,
           8.847325413492085,
           8.773166177257746,
           8.699006941023415,
           8.624847704789111,
           8.550688468554808,
           8.480107216219588,
           8.411393791875168,
           8.342680367530736,
           8.273966943186245,
           8.205253518841818,
           8.136540094497393,
           8.06782667015296,
           7.987341502791154,
           7.904894378259804,
           7.822447253728446,
           7.740000129197088,
           7.657553004665739,
           7.575105880134373,
           7.492658755603014,
           7.4102116310716735,
           7.3277645065403085,
           7.245317382008957,
           7.162870257477606,
           7.080423132946249,
           6.9979760084148905,
           6.915528883883541,
           6.833081759352185,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           57.733644078598246,
           57.74177067678727,
           57.749897274976284,
           57.7580238731653,
           57.76615047135432,
           57.774277069543345,
           57.78240366773237,
           57.79053026592139,
           57.79865686411041,
           57.80678346229943,
           57.81491006048845,
           57.82303665867747,
           57.83116325686649,
           57.83928985505551,
           57.847416453244534,
           57.85554305143356,
           57.86366964962257,
           57.871796247811595,
           57.87992284600061,
           57.88804944418964,
           57.896176042378656,
           57.90430264056768,
           57.912429238756694,
           57.92055583694572,
           57.92868243513474,
           57.93680903332376,
           57.94493563151278,
           57.95306222970181,
           57.961188827890815,
           57.969315426079845,
           57.97744202426887,
           57.98556862245788,
           57.99369522064691,
           58.00182181883592,
           58.00994841702495,
           58.01807501521397,
           58.02620161340299,
           58.03432821159201,
           58.04245480978103,
           58.05058140797005,
           58.05870800615907,
           58.06683460434809,
           58.07496120253711,
           58.08308780490432,
           58.09441448267896,
           58.10574116045359,
           58.11706783822822,
           58.128394516002864,
           58.1397211937775,
           58.15104787155214,
           58.16237454932677,
           58.173701227101404,
           58.18502790487604,
           58.19635458265067,
           58.2076812604253,
           58.21900793819994,
           58.23033461597457,
           58.24166129374921,
           58.25298797152385,
           58.264314649298484,
           58.27564132707312,
           58.28696800484775,
           58.298294682622384,
           58.309621360397024,
           58.320948038171665,
           58.3322747159463,
           58.34360139372093,
           58.354928071495564,
           58.3662547492702,
           58.37758142704483,
           58.388908104819464,
           58.400234782594104,
           58.411561460368745,
           58.42288813814338,
           58.43421481591801,
           58.445541493692645,
           58.45686817146728,
           58.46819484924191,
           58.479521527016544,
           58.49084820479118,
           58.50217488256581,
           58.51350156034046,
           58.52482823811509,
           58.536154915889725,
           58.31103018576091,
           58.03861517405141,
           57.76620016234192,
           57.49378515063243,
           57.22137013892293,
           56.948955127213445,
           56.676540115503954,
           56.404125103794456,
           56.131710092084965,
           55.85929508037547,
           55.586880068665984,
           55.314465056956486,
           55.042050045246995,
           54.7696350335375,
           54.497220021828,
           54.22480501011852,
           53.95238999840902,
           53.67997498669953,
           53.407559974990036,
           53.13514496328054,
           52.862729951571055,
           52.59031493986156,
           52.31789992815206,
           52.045484916442575,
           51.77306990473307,
           51.50065489302359,
           51.22823988131409,
           50.9558248696046,
           50.683409857895114,
           50.4109948461856,
           50.13857983447612,
           49.86616482276662,
           49.59374981105712,
           49.32133479934764,
           49.04891978763815,
           48.77650477592865,
           48.50408976421916,
           48.23167475250966,
           47.95925974080018,
           47.68684472909068,
           47.39835426277561,
           47.10182602193254,
           46.80529778108943,
           46.50876954024635,
           46.21224129940325,
           45.915713058560165,
           45.619184817717084,
           45.32265657687398,
           45.0261283360309,
           44.729600095187806,
           44.43307185434472,
           44.13654361350164,
           43.84001537265855,
           43.543487131815446,
           43.24695889097236,
           42.95043065012927,
           42.65390240928619,
           42.3573741684431,
           42.0608459276,
           41.764317686756925,
           41.46778944591382,
           41.17126120507074,
           40.87473296422765,
           40.57820472338456,
           40.28167648254148,
           39.98514824169837,
           39.688620000855295,
           39.3920917600122,
           39.095563519169104,
           38.79903527832603,
           38.50250703748292,
           38.20597879663984,
           37.90945055579675,
           37.61292231495366,
           37.316394074110576,
           37.01986583326749,
           36.72333759242439,
           36.4268093515813,
           36.13028111073821,
           35.83375286989513,
           35.53722462905204,
           35.240696388208946,
           34.94416814736587,
           34.63533842964594,
           34.320357973487646,
           34.005377517329336,
           33.69039706117101,
           33.37541660501272,
           33.06043614885438,
           32.745455692696076,
           32.43047523653776,
           32.11549478037944,
           31.80051432422114,
           31.48553386806281,
           31.170553411904507,
           30.85557295574619,
           30.540592499587877,
           30.22561204342957,
           29.910631587271254,
           29.595651131112938,
           29.280670674954628,
           28.965690218796304,
           28.650709762638,
           28.335729306479685,
           28.02074885032137,
           27.705768394163066,
           27.390787938004735,
           27.075807481846432,
           26.760827025688116,
           26.4458465695298,
           26.130866113371496,
           25.815885657213165,
           25.500905201054863,
           25.185924744896546,
           24.87094428873823,
           24.55596383257993,
           24.240983376421614,
           23.926002920263294,
           23.611022464104977,
           23.29604200794666,
           22.98106155178836,
           22.66608109563004,
           22.351100639471724,
           22.03612018331342,
           21.72113972715511,
           21.40615927099679,
           21.09117881483847,
           20.776198358680155,
           20.461217902521838,
           20.146237446363536,
           19.83125699020522,
           19.516276534046902,
           19.201296077888586,
           18.88631562173027,
           18.571335165571966,
           18.25635470941365,
           17.941374253255333,
           17.62639379709702,
           17.311413340938714,
           16.996432884780397,
           16.68145242862208,
           16.366471972463767,
           16.051491516305447,
           15.736511060147144,
           15.421530603988828,
           15.106550147830514,
           14.791569691672194,
           14.476589235513893,
           14.161608779355577,
           13.860910585191428,
           13.566977739557128,
           13.273044893922826,
           12.97911204828854,
           12.685179202654243,
           12.391246357019943,
           12.097313511385645,
           11.803380665751341,
           11.509447820117057,
           11.215514974482756,
           10.921582128848456,
           10.627649283214156,
           10.33371643757987,
           10.03978359194557,
           9.74585074631127,
           9.451917900676971,
           9.157985055042673,
           8.973939014108359,
           8.89977977787402,
           8.825620541639752,
           8.751461305405423,
           8.677302069171084,
           8.603142832936753,
           8.530875683383668,
           8.462162259039237,
           8.393448834694746,
           8.324735410350325,
           8.256021986005893,
           8.187308561661402,
           8.118595137316975,
           8.043014862879106,
           7.960567738347749,
           7.878120613816392,
           7.795673489285043,
           7.713226364753684,
           7.630779240222326,
           7.548332115690977,
           7.465884991159612,
           7.383437866628253,
           7.300990742096912,
           7.218543617565546,
           7.136096493034195,
           7.053649368502845,
           6.971202243971487,
           6.8887551194401295,
           6.806307994908779,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           57.51790897790383,
           57.52603557609285,
           57.534162174281875,
           57.54228877247089,
           57.55041537065992,
           57.558541968848935,
           57.56666856703795,
           57.57479516522697,
           57.582921763415996,
           57.59104836160502,
           57.59917495979404,
           57.607301557983064,
           57.61542815617208,
           57.62355475436111,
           57.631681352550125,
           57.63980795073914,
           57.64793454892816,
           57.656061147117185,
           57.66418774530621,
           57.67231434349523,
           57.680440941684246,
           57.68856753987327,
           57.696694138062284,
           57.70482073625131,
           57.71294733444033,
           57.72107393262935,
           57.72920053081837,
           57.7373271290074,
           57.745453727196406,
           57.75358032538543,
           57.76170692357446,
           57.76983352176347,
           57.777960119952496,
           57.78608671814152,
           57.794213316330534,
           57.802339914519564,
           57.81046651270857,
           57.818593110897595,
           57.82671970908662,
           57.83484630727563,
           57.84297290546466,
           57.85109950365368,
           57.8592261018427,
           57.867352700031724,
           57.87547929822074,
           57.88360589640976,
           57.891732494598784,
           57.8998590927878,
           57.90798569097682,
           57.91611228916585,
           57.92423888735487,
           57.93236548554388,
           57.94049208373291,
           57.94861868192193,
           57.95674528011095,
           57.964871878299974,
           57.97299847648899,
           57.98112507467802,
           57.98925167286703,
           57.99737827105606,
           58.00710491268806,
           58.0184315904627,
           58.02975826823733,
           58.04108494601196,
           58.052411623786604,
           58.06373830156124,
           58.07506497933587,
           58.086391657110504,
           58.09771833488514,
           58.10904501265977,
           58.12037169043441,
           58.131698368209044,
           58.14302504598368,
           58.15435172375832,
           58.16567840153295,
           58.17700507930759,
           58.18833175708222,
           58.19965843485685,
           58.21098511263149,
           58.222311790406124,
           58.23363846818076,
           58.2449651459554,
           58.25629182373003,
           58.267618501504664,
           58.04249377137585,
           57.770078759666355,
           57.497663747956864,
           57.22524873624737,
           56.952833724537875,
           56.68041871282839,
           56.4080037011189,
           56.1355886894094,
           55.863173677699905,
           55.59075866599041,
           55.31834365428093,
           55.045928642571425,
           54.773513630861935,
           54.501098619152444,
           54.22868360744294,
           53.95626859573346,
           53.683853584023964,
           53.41143857231447,
           53.139023560604976,
           52.86660854889548,
           52.594193537185994,
           52.3217785254765,
           52.049363513767005,
           51.772929658040084,
           51.47640141719698,
           51.1798731763539,
           50.883344935510806,
           50.58681669466772,
           50.29028845382464,
           49.993760212981535,
           49.697231972138454,
           49.40070373129536,
           49.10417549045227,
           48.80764724960919,
           48.5111190087661,
           48.214590767923006,
           47.91806252707991,
           47.621534286236816,
           47.32500604539374,
           47.02847780455065,
           46.73194956370756,
           46.435421322864485,
           46.138893082021376,
           45.842364841178295,
           45.5458366003352,
           45.249308359492105,
           44.95278011864903,
           44.65625187780593,
           44.35972363696285,
           44.06319539611975,
           43.766667155276664,
           43.47013891443358,
           43.17361067359049,
           42.87708243274739,
           42.580554191904305,
           42.28402595106121,
           41.987497710218136,
           41.69096946937505,
           41.394441228531946,
           41.097912987688865,
           40.80138474684576,
           40.50485650600268,
           40.208328265159594,
           39.911800024316506,
           39.61527178347342,
           39.318743542630315,
           39.022215301787234,
           38.72568706094415,
           38.42915882010105,
           38.13263057925798,
           37.83610233841487,
           37.53957409757179,
           37.24304585672869,
           36.946517615885604,
           36.64998937504252,
           36.35346113419943,
           36.05693289335635,
           35.760404652513245,
           35.46387641167016,
           35.16734817082708,
           34.87081992998398,
           34.57429168914089,
           34.27776344829782,
           33.96893373057789,
           33.653953274419585,
           33.33897281826127,
           33.02399236210295,
           32.70901190594466,
           32.394031449786326,
           32.079050993628016,
           31.764070537469703,
           31.44909008131139,
           31.13410962515308,
           30.81912916899475,
           30.504148712836447,
           30.189168256678137,
           29.87418780051982,
           29.559207344361514,
           29.244226888203197,
           28.92924643204488,
           28.614265975886568,
           28.299285519728247,
           27.984305063569945,
           27.66932460741163,
           27.354344151253315,
           27.039363695095005,
           26.724383238936674,
           26.409402782778372,
           26.094422326620055,
           25.77944187046174,
           25.464461414303436,
           25.149480958145112,
           24.83450050198681,
           24.519520045828486,
           24.20453958967017,
           23.889559133511867,
           23.57457867735355,
           23.259598221195237,
           22.94461776503692,
           22.629637308878607,
           22.314656852720304,
           21.99967639656198,
           21.701233309230783,
           21.4073004635965,
           21.113367617962197,
           20.8194347723279,
           20.5255019266936,
           20.2315690810593,
           19.937636235424996,
           19.643703389790712,
           19.349770544156417,
           19.055837698522115,
           18.761904852887813,
           18.467972007253515,
           18.174039161619227,
           17.88010631598493,
           17.586173470350627,
           17.292240624716328,
           16.998307779082044,
           16.704374933447742,
           16.410442087813443,
           16.116509242179145,
           15.822576396544845,
           15.528643550910559,
           15.234710705276258,
           14.940777859641958,
           14.646845014007656,
           14.352912168373372,
           14.058979322739072,
           13.765046477104772,
           13.471113631470471,
           13.177180785836171,
           12.883247940201885,
           12.589315094567587,
           12.295382248933285,
           12.001449403298986,
           11.707516557664686,
           11.4135837120304,
           11.119650866396102,
           10.825718020761801,
           10.5317851751275,
           10.237852329493213,
           9.943919483858915,
           9.649986638224615,
           9.356053792590314,
           9.062120946956014,
           8.878074906021704,
           8.803915669787363,
           8.729756433553097,
           8.655597197318766,
           8.58164415054774,
           8.512930726203255,
           8.444217301858826,
           8.375503877514396,
           8.306790453169905,
           8.238077028825483,
           8.169363604481052,
           8.098688222967056,
           8.016241098435698,
           7.933793973904347,
           7.851346849372989,
           7.768899724841633,
           7.6864526003102815,
           7.604005475778924,
           7.521558351247567,
           7.439111226716216,
           7.356664102184851,
           7.274216977653494,
           7.1917698531221514,
           7.109322728590786,
           7.026875604059435,
           6.944428479528084,
           6.861981354996727,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           57.3021738772094,
           57.31030047539843,
           57.31842707358744,
           57.32655367177646,
           57.33468026996548,
           57.34280686815451,
           57.35093346634352,
           57.35906006453254,
           57.36718666272157,
           57.37531326091059,
           57.38343985909961,
           57.39156645728863,
           57.39969305547765,
           57.40781965366667,
           57.415946251855694,
           57.424072850044716,
           57.43219944823373,
           57.440326046422754,
           57.44845264461178,
           57.45657924280079,
           57.464705840989815,
           57.47283243917884,
           57.48095903736786,
           57.48908563555687,
           57.497212233745906,
           57.50533883193492,
           57.51346543012394,
           57.521592028312966,
           57.529718626501975,
           57.537845224691,
           57.54597182288002,
           57.55409842106904,
           57.562225019258065,
           57.57035161744707,
           57.5784782156361,
           57.58660481382513,
           57.59473141201415,
           57.602858010203164,
           57.61098460839219,
           57.61911120658121,
           57.62723780477023,
           57.63536440295925,
           57.64349100114828,
           57.65161759933729,
           57.659744197526315,
           57.66787079571533,
           57.67599739390435,
           57.68412399209337,
           57.69225059028239,
           57.70037718847142,
           57.70850378666044,
           57.71663038484945,
           57.724756983038475,
           57.7328835812275,
           57.74101017941652,
           57.74913677760554,
           57.75726337579456,
           57.76538997398358,
           57.773516572172596,
           57.781643170361626,
           57.78976976855064,
           57.797896366739664,
           57.80602296492869,
           57.8141495631177,
           57.822276161306725,
           57.83040275949575,
           57.83852935768477,
           57.846655955873786,
           57.85478255406281,
           57.86290915225183,
           57.871035750440846,
           57.87916234862987,
           57.88728894681889,
           57.895415545007914,
           57.90354214319693,
           57.91166874138595,
           57.91979534269714,
           57.931122020471776,
           57.94244869824641,
           57.95377537602104,
           57.96510205379568,
           57.976428731570316,
           57.987755409344956,
           57.99908208711959,
           57.77395735699078,
           57.50154234528127,
           57.22912733357179,
           56.95671232186229,
           56.68429731015279,
           56.41188229844332,
           56.13946728673382,
           55.8509768124614,
           55.5544485716183,
           55.25792033077521,
           54.96139208993213,
           54.66486384908904,
           54.36833560824594,
           54.071807367402855,
           53.77527912655976,
           53.478750885716686,
           53.18222264487359,
           52.885694404030495,
           52.5891661631874,
           52.29263792234431,
           51.99610968150123,
           51.69958144065814,
           51.403053199815055,
           51.106524958971974,
           50.809996718128865,
           50.513468477285784,
           50.216940236442696,
           49.92041199559961,
           49.62388375475652,
           49.32735551391342,
           49.03082727307034,
           48.73429903222725,
           48.43777079138415,
           48.14124255054108,
           47.844714309697984,
           47.54818606885489,
           47.2516578280118,
           46.955129587168706,
           46.658601346325625,
           46.36207310548254,
           46.06554486463944,
           45.76901662379637,
           45.47248838295326,
           45.175960142110185,
           44.87943190126709,
           44.582903660423995,
           44.28637541958092,
           43.98984717873782,
           43.69331893789473,
           43.39679069705164,
           43.100262456208554,
           42.803734215365466,
           42.50720597452238,
           42.21067773367929,
           41.91414949283619,
           41.6176212519931,
           41.321093011150026,
           41.02456477030693,
           40.728036529463836,
           40.43150828862076,
           40.134980047777645,
           39.83845180693457,
           39.541923566091484,
           39.24539532524839,
           38.94886708440531,
           38.652338843562205,
           38.355810602719124,
           38.059282361876036,
           37.76275412103294,
           37.46622588018986,
           37.16969763934675,
           36.87316939850368,
           36.57664115766059,
           36.280112916817494,
           35.98358467597441,
           35.687056435131325,
           35.39052819428823,
           35.093999953445135,
           34.79747171260205,
           34.500943471758966,
           34.20441523091587,
           33.90788699007278,
           33.6113587492297,
           33.30252903150978,
           32.987548575351475,
           32.67256811919316,
           32.35758766303485,
           32.042607206876546,
           31.727626750718212,
           31.41264629455991,
           31.097665838401596,
           30.782685382243276,
           30.467704926084973,
           30.152724469926643,
           29.837744013768344,
           29.541556033270133,
           29.247623187635835,
           28.953690342001547,
           28.65975749636725,
           28.365824650732947,
           28.07189180509865,
           27.777958959464346,
           27.484026113830062,
           27.190093268195763,
           26.896160422561465,
           26.602227576927177,
           26.308294731292868,
           26.014361885658577,
           25.72042904002428,
           25.42649619438998,
           25.132563348755692,
           24.83863050312138,
           24.544697657487095,
           24.25076481185279,
           23.956831966218495,
           23.662899120584207,
           23.36896627494991,
           23.075033429315607,
           22.781100583681308,
           22.487167738047006,
           22.193234892412722,
           21.89930204677842,
           21.605369201144125,
           21.311436355509837,
           21.01750350987553,
           20.723570664241237,
           20.429637818606935,
           20.135704972972636,
           19.841772127338338,
           19.547839281704046,
           19.25390643606975,
           18.95997359043545,
           18.66604074480115,
           18.37210789916685,
           18.07817505353256,
           17.784242207898263,
           17.49030936226396,
           17.196376516629662,
           16.90244367099538,
           16.60851082536108,
           16.314577979726778,
           16.02064513409248,
           15.72671228845818,
           15.432779442823893,
           15.138846597189593,
           14.844913751555293,
           14.550980905920992,
           14.257048060286706,
           13.963115214652408,
           13.669182369018106,
           13.375249523383808,
           13.08131667774951,
           12.787383832115221,
           12.493450986480921,
           12.199518140846621,
           11.905585295212322,
           11.611652449578022,
           11.317719603943736,
           11.023786758309438,
           10.729853912675136,
           10.435921067040837,
           10.14198822140655,
           9.848055375772251,
           9.55412253013795,
           9.26018968450365,
           8.96625683886935,
           8.782210797935038,
           8.708051561700698,
           8.633892325466434,
           8.563699193367325,
           8.494985769022893,
           8.426272344678408,
           8.35755892033398,
           8.288845495989548,
           8.220132071645057,
           8.151418647300638,
           8.071914458523638,
           7.989467333992286,
           7.907020209460928,
           7.824573084929578,
           7.74212596039822,
           7.659678835866863,
           7.577231711335513,
           7.494784586804156,
           7.412337462272798,
           7.329890337741448,
           7.247443213210083,
           7.164996088678725,
           7.082548964147382,
           7.0001018396160175,
           6.917654715084666,
           6.835207590553315,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           57.0750564927796,
           57.083183090968625,
           57.09130968915764,
           57.09943628734666,
           57.107562885535685,
           57.11568948372471,
           57.12381608191372,
           57.13194268010274,
           57.14006927829176,
           57.148195876480784,
           57.15632247466981,
           57.16444907285883,
           57.17257567104785,
           57.180702269236875,
           57.18882886742588,
           57.19695546561491,
           57.20508206380393,
           57.21320866199295,
           57.221335260181974,
           57.229461858370996,
           57.23758845656001,
           57.24571505474904,
           57.25384165293805,
           57.26196825112707,
           57.270094849316095,
           57.27822144750512,
           57.28634804569414,
           57.29447464388316,
           57.302601242072186,
           57.310727840261194,
           57.31885443845022,
           57.32698103663924,
           57.33510763482826,
           57.343234233017284,
           57.3513608312063,
           57.35948742939532,
           57.367614027584345,
           57.37574062577337,
           57.38386722396239,
           57.391993822151406,
           57.40012042034043,
           57.40824701852945,
           57.416373616718474,
           57.42450021490749,
           57.432626813096505,
           57.440753411285534,
           57.44888000947455,
           57.45700660766357,
           57.465133205852595,
           57.47325980404162,
           57.48138640223064,
           57.489513000419656,
           57.497639598608686,
           57.505766196797694,
           57.513892794986724,
           57.52201939317574,
           57.53014599136476,
           57.538272589553785,
           57.5463991877428,
           57.55452578593183,
           57.562652384120845,
           57.57077898230987,
           57.57890558049889,
           57.587032178687906,
           57.59515877687693,
           57.60328537506595,
           57.611411973254974,
           57.61953857144399,
           57.62766516963301,
           57.635791767822035,
           57.64391836601105,
           57.65204496420007,
           57.660171562389095,
           57.66829816057812,
           57.675889211703144,
           57.680802511878966,
           57.68571581205479,
           57.69062911223062,
           57.69554241240644,
           57.70045571258227,
           57.7053690127581,
           57.71028231293392,
           57.71519561310974,
           57.72010891328557,
           57.45690612416486,
           57.14008011718484,
           56.823254110204836,
           56.50642810322483,
           56.18960209624481,
           55.87277608926482,
           55.5559500822848,
           55.239124075304794,
           54.92229806832478,
           54.61562096086765,
           54.31909272002458,
           54.02256447918148,
           53.726036238338395,
           53.4295079974953,
           53.132979756652205,
           52.83645151580913,
           52.539923274966036,
           52.24339503412295,
           51.94686679327985,
           51.650338552436764,
           51.35381031159368,
           51.05728207075059,
           50.7607538299075,
           50.46422558906442,
           50.16769734822131,
           49.871169107378236,
           49.57464086653514,
           49.27811262569205,
           48.98158438484897,
           48.68505614400586,
           48.38852790316278,
           48.091999662319694,
           47.795471421476606,
           47.498943180633525,
           47.20241493979043,
           46.905886698947334,
           46.609358458104246,
           46.31283021726115,
           46.01630197641808,
           45.719773735574975,
           45.42324549473189,
           45.12671725388881,
           44.830189013045704,
           44.53366077220262,
           44.237132531359535,
           43.94060429051644,
           43.64407604967336,
           43.34754780883026,
           43.051019567987176,
           42.75449132714409,
           42.45796308630099,
           42.16143484545792,
           41.86490660461482,
           41.56837836377173,
           41.27185012292864,
           40.97532188208555,
           40.678793641242464,
           40.382265400399376,
           40.085737159556274,
           39.7892089187132,
           39.4926806778701,
           39.19615243702702,
           38.89962419618393,
           38.603095955340834,
           38.30656771449775,
           38.01003947365465,
           37.71351123281157,
           37.41698299196848,
           37.120454751125386,
           36.823926510282305,
           36.5273982694392,
           36.23087002859612,
           35.93434178775303,
           35.63781354690994,
           35.34128530606686,
           35.04475706522376,
           34.748228824380675,
           34.45170058353758,
           34.15517234269449,
           33.85864410185141,
           33.562115861008316,
           33.26558762016522,
           32.96905937932215,
           32.67936213389093,
           32.39308038616569,
           32.10679863844043,
           31.820516890715172,
           31.53423514298993,
           31.24795339526466,
           30.961671647539415,
           30.67538989981416,
           30.3891081520889,
           30.10282640436366,
           29.816544656638392,
           29.53026290891314,
           29.24398116118789,
           28.95769941346263,
           28.671417665737387,
           28.385135918012132,
           28.098854170286877,
           27.81257242256162,
           27.526290674836364,
           27.240008927111116,
           26.953727179385858,
           26.667445431660603,
           26.381163683935362,
           26.094881936210086,
           25.80860018848485,
           25.522318440759594,
           25.23603669303433,
           24.94975494530909,
           24.66347319758382,
           24.37719144985857,
           24.090909702133317,
           23.804627954408062,
           23.518346206682818,
           23.23206445895756,
           22.9457827112323,
           22.659500963507043,
           22.373219215781788,
           22.086937468056547,
           21.80065572033129,
           21.509505093057456,
           21.21557224742317,
           20.921639401788873,
           20.62770655615457,
           20.333773710520273,
           20.039840864885974,
           19.745908019251672,
           19.451975173617384,
           19.158042327983086,
           18.864109482348784,
           18.570176636714486,
           18.276243791080184,
           17.982310945445903,
           17.6883780998116,
           17.3944452541773,
           17.100512408543,
           16.806579562908716,
           16.512646717274414,
           16.218713871640112,
           15.924781026005814,
           15.630848180371515,
           15.336915334737231,
           15.04298248910293,
           14.74904964346863,
           14.455116797834329,
           14.161183952200043,
           13.867251106565742,
           13.573318260931444,
           13.279385415297144,
           12.985452569662844,
           12.691519724028558,
           12.397586878394259,
           12.103654032759959,
           11.809721187125659,
           11.515788341491358,
           11.221855495857072,
           10.927922650222772,
           10.633989804588472,
           10.340056958954172,
           10.046124113319888,
           9.752191267685587,
           9.458258422051287,
           9.164325576416987,
           8.870392730782687,
           8.686346689848373,
           8.614467660531334,
           8.545754236186907,
           8.477040811842482,
           8.408327387498051,
           8.339613963153564,
           8.270900538809137,
           8.202187114464706,
           8.127587818611575,
           8.045140694080226,
           7.962693569548868,
           7.880246445017518,
           7.797799320486161,
           7.71535219595481,
           7.632905071423452,
           7.550457946892094,
           7.468010822360744,
           7.385563697829387,
           7.30311657329803,
           7.22066944876668,
           7.138222324235314,
           7.055775199703956,
           6.973328075172613,
           6.8908809506412485,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           56.839199138532635,
           56.84732573672164,
           56.855452334910666,
           56.86357893309969,
           56.87170553128871,
           56.879832129477734,
           56.88795872766675,
           56.89608532585578,
           56.9042119240448,
           56.91233852223381,
           56.92046512042285,
           56.928591718611855,
           56.93671831680088,
           56.9448449149899,
           56.952971513178916,
           56.961098111367946,
           56.969224709556954,
           56.977351307745984,
           56.985477905935,
           56.99360450412402,
           57.001731102313045,
           57.00985770050207,
           57.01798429869108,
           57.02611089688011,
           57.03423749506912,
           57.04236409325815,
           57.050490691447166,
           57.05861728963619,
           57.06674388782521,
           57.07487048601423,
           57.08299708420326,
           57.091123682392265,
           57.09925028058129,
           57.10737687877031,
           57.11550347695933,
           57.123630075148355,
           57.13175667333737,
           57.139883271526394,
           57.148009869715416,
           57.15613646790443,
           57.164263066093454,
           57.17238966428248,
           57.1805162624715,
           57.18864286066052,
           57.19676945884954,
           57.20489605703856,
           57.21302265522758,
           57.2211492534166,
           57.22927585160562,
           57.237402449794644,
           57.245529047983666,
           57.25365564617268,
           57.26178224436171,
           57.26990884255073,
           57.27803544073975,
           57.286162038928765,
           57.29428863711779,
           57.30241523530681,
           57.30839963689504,
           57.31331293707087,
           57.31822623724669,
           57.32313953742252,
           57.32805283759834,
           57.332966137774164,
           57.33787943795,
           57.34279273812582,
           57.347706038301645,
           57.352619338477474,
           57.357532638653296,
           57.362445938829126,
           57.367359239004955,
           57.37227253918078,
           57.3771858393566,
           57.38209913953243,
           57.38701243970826,
           57.39192573988408,
           57.3968390400599,
           57.40175234023573,
           57.40666564041155,
           57.41157894058738,
           57.416492240763205,
           57.421405540939034,
           57.426318841114856,
           57.43123214129068,
           57.168029352169974,
           56.85120334518995,
           56.53437733820995,
           56.217551331229934,
           55.900725324249926,
           55.58389931726993,
           55.267073310289916,
           54.9502473033099,
           54.63342129632989,
           54.316595289349884,
           53.99976928236988,
           53.682943275389874,
           53.36611726840985,
           53.04929126142984,
           52.732465254449835,
           52.415639247469834,
           52.09881324048982,
           51.78198723350981,
           51.4651612265298,
           51.14833521954979,
           50.831509212569784,
           50.514683205589776,
           50.19785719860976,
           49.881031191629766,
           49.56420518464974,
           49.247379190775064,
           48.95085094993197,
           48.65432270908889,
           48.3577944682458,
           48.06126622740269,
           47.764737986559616,
           47.46820974571652,
           47.17168150487343,
           46.875153264030345,
           46.578625023187264,
           46.28209678234417,
           45.985568541501074,
           45.68904030065798,
           45.3925120598149,
           45.09598381897181,
           44.79945557812872,
           44.50292733728565,
           44.20639909644254,
           43.90987085559945,
           43.61334261475637,
           43.31681437391327,
           43.02028613307019,
           42.72375789222709,
           42.427229651384,
           42.13070141054092,
           41.83417316969782,
           41.537644928854746,
           41.24111668801165,
           40.944588447168556,
           40.64806020632547,
           40.35153196548238,
           40.05500372463929,
           39.758475483796204,
           39.461947242953116,
           39.16541900211003,
           38.868890761266925,
           38.572362520423845,
           38.27583427958076,
           37.97930603873766,
           37.68277779789458,
           37.38624955705148,
           37.0897213162084,
           36.79319307536531,
           36.49666483452221,
           36.20013659367913,
           35.90360835283603,
           35.60708011199295,
           35.31055187114986,
           35.01402363030677,
           34.717495389463686,
           34.4209671486206,
           34.1244389077775,
           33.82791066693441,
           33.53138242609132,
           33.23485418524824,
           32.93832594440515,
           32.641797703562055,
           32.345269462718974,
           32.05557221728776,
           31.769290469562517,
           31.48300872183726,
           31.196726974112003,
           30.91044522638676,
           30.624163478661487,
           30.337881730936246,
           30.051599983210984,
           29.76531823548573,
           29.479036487760492,
           29.19275474003522,
           28.906472992309975,
           28.62019124458472,
           28.333909496859462,
           28.04762774913421,
           27.76134600140896,
           27.4750642536837,
           27.188782505958446,
           26.90250075823319,
           26.61621901050794,
           26.32993726278269,
           26.04365551505743,
           25.757373767332183,
           25.471092019606914,
           25.184810271881673,
           24.89852852415642,
           24.612246776431157,
           24.325965028705912,
           24.039683280980647,
           23.7534015332554,
           23.467119785530144,
           23.180838037804886,
           22.894556290079645,
           22.608274542354387,
           22.32199279462913,
           22.03571104690387,
           21.749429299178615,
           21.46314755145337,
           21.176865803728116,
           20.890584056002858,
           20.604302308277617,
           20.318020560552355,
           20.031738812827104,
           19.745457065101842,
           19.459175317376587,
           19.17289356965133,
           18.88661182192609,
           18.60033007420083,
           18.31404832647557,
           18.027766578750317,
           17.74148483102506,
           17.455203083299814,
           17.16892133557456,
           16.8826395878493,
           16.596357840124043,
           16.310076092398802,
           16.023794344673544,
           15.737512596948287,
           15.45123084922303,
           15.164949101497774,
           14.878667353772528,
           14.592385606047273,
           14.306103858322015,
           14.01982211059676,
           13.733540362871514,
           13.447258615146257,
           13.160976867421002,
           12.874695119695744,
           12.588413371970486,
           12.302131624245245,
           12.015849876519987,
           11.72956812879473,
           11.443286381069472,
           11.157004633344215,
           10.870722885618973,
           10.592225684811341,
           10.33071284890625,
           10.069200013001161,
           9.807687177096085,
           9.546174341190994,
           9.284661505285905,
           9.023148669380815,
           8.761635833475728,
           8.596522703350983,
           8.527809279006492,
           8.459095854662067,
           8.39038243031764,
           8.32166900597321,
           8.252955581628724,
           8.183261178699532,
           8.100814054168174,
           8.018366929636816,
           7.935919805105467,
           7.853472680574108,
           7.771025556042757,
           7.6885784315114005,
           7.606131306980051,
           7.523684182448692,
           7.441237057917335,
           7.358789933385984,
           7.2763428088546265,
           7.193895684323269,
           7.111448559791919,
           7.029001435260554,
           6.946554310729196,
           6.864107186197854,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           56.60334178428565,
           56.61146838247467,
           56.61959498066368,
           56.6277215788527,
           56.63584817704172,
           56.643974775230745,
           56.65210137341977,
           56.66022797160878,
           56.668354569797806,
           56.67648116798682,
           56.68460776617585,
           56.69273436436487,
           56.70086096255389,
           56.70898756074291,
           56.717114158931935,
           56.72524075712096,
           56.73336735530997,
           56.741493953498995,
           56.74962055168801,
           56.75774714987704,
           56.765873748066056,
           56.77400034625508,
           56.782126944444094,
           56.79025354263312,
           56.79838014082213,
           56.80650673901116,
           56.814633337200185,
           56.8227599353892,
           56.83088653357822,
           56.839013131767246,
           56.84713972995626,
           56.855266328145284,
           56.863392926334306,
           56.87151952452332,
           56.879646122712344,
           56.88777272090137,
           56.89589931909039,
           56.90402591727941,
           56.91215251546843,
           56.92027911365744,
           56.92840571184647,
           56.935996761911106,
           56.940910062086935,
           56.94582336226276,
           56.95073666243858,
           56.95564996261441,
           56.96056326279024,
           56.96547656296606,
           56.97038986314188,
           56.97530316331772,
           56.980216463493534,
           56.98512976366937,
           56.99004306384519,
           56.994956364021014,
           56.999869664196844,
           57.004782964372666,
           57.009696264548495,
           57.01460956472432,
           57.01952286490014,
           57.02443616507597,
           57.02934946525179,
           57.03426276542763,
           57.03917606560344,
           57.04408936577927,
           57.0490026659551,
           57.05391596613093,
           57.058829266306745,
           57.063742566482574,
           57.0686558666584,
           57.073569166834226,
           57.078482467010055,
           57.08339576718588,
           57.088309067361706,
           57.09322236753753,
           57.09813566771335,
           57.10304896788918,
           57.10796226806501,
           57.11287556824083,
           57.11778886841665,
           57.12270216859248,
           57.127615468768305,
           57.13252876894413,
           57.137442069119956,
           57.142355369295785,
           56.879152580175074,
           56.56232657319505,
           56.24550056621505,
           55.92867455923505,
           55.611848552255026,
           55.29502254527503,
           54.978196538295016,
           54.66137053131501,
           54.34454452433499,
           54.02771851735498,
           53.71089251037498,
           53.394066503394974,
           53.07724049641495,
           52.76041448943494,
           52.44358848245493,
           52.12676247547493,
           51.80993646849492,
           51.49311046151491,
           51.176284454534894,
           50.85945844755489,
           50.54263244057489,
           50.225806433594876,
           49.90898042661486,
           49.592154419634866,
           49.275328412654844,
           48.95850240567484,
           48.64167639869483,
           48.32485039171482,
           48.008024384734824,
           47.691198377754795,
           47.37437237077479,
           47.05754636379478,
           46.740720356814776,
           46.42389434983477,
           46.10706834285476,
           45.790242335874744,
           45.473416328894736,
           45.15659032191472,
           44.839764314934726,
           44.52293830795471,
           44.2061123009747,
           43.88928629399471,
           43.58260917983931,
           43.28608093899623,
           42.98955269815314,
           42.693024457310045,
           42.396496216466964,
           42.09996797562386,
           41.80343973478078,
           41.50691149393769,
           41.210383253094605,
           40.913855012251524,
           40.61732677140843,
           40.320798530565334,
           40.024270289722246,
           39.72774204887915,
           39.43121380803608,
           39.13468556719298,
           38.83815732634989,
           38.541629085506806,
           38.2451008446637,
           37.94857260382062,
           37.652044362977534,
           37.35551612213444,
           37.05898788129136,
           36.762459640448256,
           36.465931399605175,
           36.16940315876209,
           35.87287491791899,
           35.57634667707592,
           35.27981843623281,
           34.98329019538973,
           34.68676195454664,
           34.390233713703545,
           34.093705472860464,
           33.79717723201737,
           33.50064899117428,
           33.204120750331185,
           32.9075925094881,
           32.611064268645016,
           32.31453602780192,
           32.01800778695883,
           31.721479546115752,
           31.43178230068454,
           31.145500552959295,
           30.859218805234036,
           30.57293705750878,
           30.286655309783537,
           30.000373562058268,
           29.714091814333024,
           29.427810066607766,
           29.141528318882507,
           28.855246571157267,
           28.568964823431998,
           28.282683075706753,
           27.9964013279815,
           27.71011958025624,
           27.42383783253099,
           27.137556084805734,
           26.85127433708048,
           26.564992589355224,
           26.27871084162997,
           25.992429093904725,
           25.706147346179467,
           25.41986559845421,
           25.13358385072896,
           24.847302103003692,
           24.561020355278455,
           24.274738607553196,
           23.988456859827934,
           23.702175112102694,
           23.415893364377425,
           23.12961161665218,
           22.843329868926922,
           22.557048121201664,
           22.270766373476423,
           21.984484625751165,
           21.69820287802591,
           21.411921130300648,
           21.125639382575397,
           20.839357634850153,
           20.553075887124894,
           20.26679413939964,
           19.98051239167439,
           19.694230643949137,
           19.40794889622388,
           19.12166714849862,
           18.83538540077337,
           18.54910365304811,
           18.262821905322866,
           17.976540157597608,
           17.69025840987235,
           17.403976662147095,
           17.11769491442184,
           16.831413166696592,
           16.545131418971337,
           16.258849693198403,
           15.997336857293313,
           15.735824021388236,
           15.474311185483145,
           15.212798349578057,
           14.951285513672966,
           14.689772677767877,
           14.4282598418628,
           14.166747005957712,
           13.905234170052623,
           13.643721334147532,
           13.382208498242456,
           13.120695662337363,
           12.859182826432274,
           12.597669990527187,
           12.336157154622096,
           12.07464431871702,
           11.813131482811931,
           11.551618646906842,
           11.290105811001752,
           11.028592975096661,
           10.767080139191584,
           10.505567303286494,
           10.244054467381407,
           9.982541631476316,
           9.72102879557124,
           9.459515959666149,
           9.19800312376106,
           8.936490287855971,
           8.67497745195088,
           8.50986432182614,
           8.44115089748165,
           8.372437473137223,
           8.303724048792796,
           8.235010624448366,
           8.156487414256121,
           8.074040289724763,
           7.991593165193405,
           7.909146040662047,
           7.826698916130698,
           7.744251791599339,
           7.6618046670679885,
           7.5793575425366315,
           7.496910418005281,
           7.414463293473922,
           7.332016168942565,
           7.249569044411216,
           7.167121919879858,
           7.0846747953485,
           7.002227670817151,
           6.919780546285786,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           56.36748443003865,
           56.37561102822767,
           56.38373762641669,
           56.39186422460571,
           56.399990822794734,
           56.40811742098376,
           56.41624401917277,
           56.42437061736179,
           56.432497215550825,
           56.44062381373984,
           56.448750411928856,
           56.45687701011788,
           56.4650036083069,
           56.473130206495924,
           56.481256804684946,
           56.48938340287396,
           56.497510001062984,
           56.505636599252,
           56.51376319744103,
           56.521889795630045,
           56.53001639381906,
           56.53814299200809,
           56.546269590197106,
           56.55439618838613,
           56.56252278657515,
           56.56850718710299,
           56.57342048727882,
           56.578333787454646,
           56.58324708763047,
           56.58816038780629,
           56.59307368798212,
           56.59798698815794,
           56.60290028833377,
           56.6078135885096,
           56.612726888685415,
           56.617640188861245,
           56.622553489037074,
           56.6274667892129,
           56.63238008938872,
           56.63729338956455,
           56.64220668974038,
           56.6471199899162,
           56.65203329009203,
           56.65694659026785,
           56.66185989044368,
           56.666773190619494,
           56.671686490795324,
           56.676599790971146,
           56.68151309114697,
           56.686426391322804,
           56.69133969149863,
           56.696252991674456,
           56.70116629185027,
           56.70607959202611,
           56.71099289220193,
           56.71590619237775,
           56.72081949255359,
           56.7257327927294,
           56.73064609290523,
           56.73555939308106,
           56.74047269325689,
           56.74538599343272,
           56.750299293608535,
           56.755212593784364,
           56.76012589396019,
           56.765039194136016,
           56.76995249431184,
           56.77486579448767,
           56.779779094663496,
           56.784692394839325,
           56.78960569501514,
           56.79451899519097,
           56.7994322953668,
           56.80434559554262,
           56.80925889571844,
           56.81417219589427,
           56.819085496070095,
           56.823998796245924,
           56.82891209642175,
           56.833825396597575,
           56.838738696773405,
           56.84365199694923,
           56.84856529712505,
           56.85347859730088,
           56.59027580818017,
           56.273449801200144,
           55.95662379422014,
           55.639797787240134,
           55.32297178026012,
           55.006145773280124,
           54.68931976630011,
           54.3724937593201,
           54.055667752340085,
           53.73884174536008,
           53.42201573838008,
           53.10518973140006,
           52.78836372442005,
           52.47153771744004,
           52.154711710460035,
           51.837885703480026,
           51.52105969650001,
           51.20423368952,
           50.887407682539994,
           50.570581675559986,
           50.253755668579984,
           49.93692966159997,
           49.62010365461995,
           49.303277647639966,
           48.986451640659936,
           48.669625633679935,
           48.35279962669992,
           48.03597361971991,
           47.71914761273992,
           47.40232160575989,
           47.085495598779886,
           46.76866959179988,
           46.45184358481986,
           46.13501757783986,
           45.81819157085985,
           45.501365563879844,
           45.18453955689983,
           44.86771354991981,
           44.55088754293982,
           44.23406153595981,
           43.91723552897979,
           43.6004095219998,
           43.28358351501977,
           42.96675750803977,
           42.649931501059754,
           42.333105494079746,
           42.01627948709975,
           41.69945348011972,
           41.38262747313972,
           41.06580146615971,
           40.7489754591797,
           40.4321494521997,
           40.11532344521969,
           39.79849743823968,
           39.48167143125967,
           39.16484542427965,
           38.84801941729965,
           38.531193410319645,
           38.214367409746664,
           37.91783916890358,
           37.62131092806048,
           37.3247826872174,
           37.02825444637431,
           36.73172620553122,
           36.435197964688136,
           36.13866972384504,
           35.84214148300196,
           35.545613242158865,
           35.24908500131577,
           34.95255676047269,
           34.65602851962959,
           34.359500278786506,
           34.06297203794342,
           33.76644379710032,
           33.46991555625724,
           33.17338731541415,
           32.87685907457106,
           32.58033083372797,
           32.283802592884875,
           31.987274352041798,
           31.690746111198706,
           31.39421787035561,
           31.097689629512534,
           30.807992384081317,
           30.521710636356076,
           30.23542888863082,
           29.94914714090556,
           29.662865393180315,
           29.376583645455042,
           29.090301897729802,
           28.804020150004543,
           28.517738402279285,
           28.231456654554048,
           27.945174906828775,
           27.65889315910353,
           27.372611411378273,
           27.086329663653018,
           26.800047915927774,
           26.513766168202512,
           26.227484420477257,
           25.941202672752002,
           25.65492092502675,
           25.368639177301503,
           25.08235742957624,
           24.796075681850986,
           24.509793934125742,
           24.223512186400473,
           23.93723043867523,
           23.650948690949974,
           23.364666943224716,
           23.07838519549947,
           22.792103447774206,
           22.505821700048955,
           22.219539952323704,
           21.933258204598445,
           21.663960865680384,
           21.402448029775297,
           21.140935193870206,
           20.879422357965115,
           20.617909522060028,
           20.35639668615495,
           20.09488385024986,
           19.83337101434477,
           19.571858178439697,
           19.310345342534607,
           19.048832506629516,
           18.787319670724425,
           18.525806834819335,
           18.264293998914248,
           18.00278116300917,
           17.74126832710408,
           17.47975549119899,
           17.218242655293903,
           16.956729819388812,
           16.695216983483732,
           16.433704147578645,
           16.172191311673554,
           15.910678475768467,
           15.649165639863389,
           15.387652803958298,
           15.126139968053211,
           14.864627132148122,
           14.603114296243032,
           14.341601460337955,
           14.080088624432864,
           13.818575788527776,
           13.557062952622687,
           13.295550116717608,
           13.034037280812518,
           12.772524444907429,
           12.511011609002342,
           12.249498773097251,
           11.987985937192175,
           11.726473101287086,
           11.464960265381995,
           11.203447429476906,
           10.941934593571816,
           10.680421757666739,
           10.418908921761648,
           10.157396085856561,
           9.89588324995147,
           9.634370414046394,
           9.372857578141303,
           9.111344742236213,
           8.849831906331124,
           8.588319070426035,
           8.423205940301294,
           8.354492515956803,
           8.285779091612376,
           8.212160774344067,
           8.129713649812702,
           8.047266525281351,
           7.964819400749994,
           7.882372276218637,
           7.799925151687278,
           7.71747802715593,
           7.635030902624571,
           7.5525837780932195,
           7.4701366535618625,
           7.387689529030513,
           7.305242404499155,
           7.222795279967797,
           7.140348155436447,
           7.0579010309050885,
           6.975453906373732,
           6.893006781842383,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           56.131627075791684,
           56.1397536739807,
           56.147880272169715,
           56.156006870358745,
           56.16413346854777,
           56.17226006673678,
           56.180386664925805,
           56.18851326311483,
           56.196104312119076,
           56.2010176122949,
           56.20593091247073,
           56.210844212646556,
           56.21575751282238,
           56.2206708129982,
           56.22558411317403,
           56.23049741334985,
           56.23541071352568,
           56.24032401370151,
           56.245237313877325,
           56.250150614053155,
           56.255063914228984,
           56.25997721440481,
           56.264890514580635,
           56.269803814756465,
           56.27471711493228,
           56.27963041510811,
           56.28454371528394,
           56.28945701545976,
           56.29437031563559,
           56.29928361581141,
           56.30419691598724,
           56.30911021616306,
           56.31402351633889,
           56.31893681651472,
           56.32385011669054,
           56.328763416866366,
           56.333676717042195,
           56.338590017218024,
           56.34350331739384,
           56.34841661756967,
           56.3533299177455,
           56.35824321792132,
           56.36315651809715,
           56.36806981827297,
           56.3729831184488,
           56.377896418624616,
           56.38280971880045,
           56.387723018976274,
           56.392636319152096,
           56.397549619327926,
           56.40246291950375,
           56.40737621967958,
           56.4122895198554,
           56.41720282003122,
           56.42211612020705,
           56.42702942038288,
           56.43194272055871,
           56.436856020734524,
           56.44176932091035,
           56.44668262108618,
           56.451595921262,
           56.45650922143784,
           56.461422521613656,
           56.46633582178948,
           56.471249121965315,
           56.47616242214113,
           56.481075722316966,
           56.48598902249279,
           56.49090232266862,
           56.49581562284443,
           56.50072892302026,
           56.50564222319609,
           56.51055552337192,
           56.515468823547735,
           56.520382123723564,
           56.525295423899394,
           56.530208724075216,
           56.535122024251045,
           56.54003532442687,
           56.544948624602696,
           56.549861924778526,
           56.55477522495435,
           56.55968852513017,
           56.564601825306,
           56.30139903618529,
           55.984573029205265,
           55.667747022225264,
           55.350921015245255,
           55.03409500826524,
           54.717269001285246,
           54.40044299430523,
           54.08361698732522,
           53.766790980345206,
           53.4499649733652,
           53.1331389663852,
           52.81631295940518,
           52.49948695242517,
           52.182660945445164,
           51.86583493846514,
           51.54900893148515,
           51.23218292450513,
           50.91535691752512,
           50.598530910545115,
           50.28170490356511,
           49.964878896585105,
           49.64805288960509,
           49.331226882625074,
           49.01440087564508,
           48.69757486866505,
           48.380748861685056,
           48.06392285470505,
           47.74709684772503,
           47.43027084074504,
           47.11344483376501,
           46.79661882678501,
           46.47979281980499,
           46.162966812824976,
           45.84614080584498,
           45.529314798864974,
           45.21248879188496,
           44.89566278490495,
           44.578836777924934,
           44.26201077094494,
           43.945184763964924,
           43.62835875698491,
           43.31153275000492,
           42.99470674302489,
           42.67788073604489,
           42.361054729064875,
           42.04422872208487,
           41.72740271510487,
           41.41057670812484,
           41.09375070114484,
           40.77692469416483,
           40.46009868718482,
           40.143272680204824,
           39.82644667322481,
           39.5096206662448,
           39.192794659264784,
           38.87596865228477,
           38.559142645304775,
           38.242316638324766,
           37.92549063134475,
           37.60866462436475,
           37.29183861738473,
           36.975012610404725,
           36.65818660342472,
           36.3413605964447,
           36.02453458946471,
           35.70770858248468,
           35.390882575504676,
           35.07405656852467,
           34.75723056154465,
           34.44040455456465,
           34.12357854758463,
           33.80675254060463,
           33.48992653362462,
           33.1731005266446,
           32.85627451966461,
           32.549597398810974,
           32.253069157967886,
           31.956540917124798,
           31.660012676281703,
           31.363484435438625,
           31.066956194595534,
           30.77042795375244,
           30.47389971290936,
           30.184202467478144,
           29.8979207197529,
           29.61163897202764,
           29.325357224302383,
           29.039075476577143,
           28.752793728851874,
           28.46651198112663,
           28.180230233401375,
           27.893948485676116,
           27.607666737950872,
           27.330584874067437,
           27.069072038162364,
           26.807559202257274,
           26.546046366352183,
           26.284533530447106,
           26.02302069454202,
           25.76150785863693,
           25.499995022731838,
           25.23848218682675,
           24.976969350921674,
           24.715456515016584,
           24.453943679111493,
           24.19243084320642,
           23.930918007301315,
           23.66940517139624,
           23.407892335491148,
           23.14637949958606,
           22.88486666368098,
           22.62335382777588,
           22.361840991870803,
           22.100328155965713,
           21.838815320060625,
           21.577302484155545,
           21.31578964825046,
           21.054276812345364,
           20.792763976440277,
           20.53125114053519,
           20.269738304630113,
           20.008225468725023,
           19.746712632819932,
           19.48519979691486,
           19.223686961009765,
           18.962174125104678,
           18.700661289199587,
           18.439148453294496,
           18.177635617389406,
           17.91612278148433,
           17.654609945579242,
           17.39309710967415,
           17.13158427376906,
           16.870071437863974,
           16.608558601958894,
           16.347045766053807,
           16.085532930148716,
           15.824020094243629,
           15.56250725833855,
           15.30099442243346,
           15.039481586528371,
           14.77796875062328,
           14.516455914718193,
           14.254943078813117,
           13.993430242908026,
           13.731917407002937,
           13.470404571097845,
           13.20889173519277,
           12.94737889928768,
           12.68586606338259,
           12.4243532274775,
           12.162840391572413,
           11.901327555667335,
           11.639814719762246,
           11.378301883857157,
           11.116789047952068,
           10.855276212046977,
           10.5937633761419,
           10.33225054023681,
           10.07073770433172,
           9.809224868426632,
           9.547712032521552,
           9.286199196616465,
           9.024686360711375,
           8.763173524806286,
           8.501660688901195,
           8.336547558776452,
           8.267834134431961,
           8.185387009900657,
           8.102939885369306,
           8.020492760837941,
           7.938045636306591,
           7.855598511775234,
           7.773151387243876,
           7.690704262712518,
           7.608257138181169,
           7.52581001364981,
           7.443362889118459,
           7.3609157645871015,
           7.278468640055753,
           7.196021515524394,
           7.113574390993037,
           7.031127266461687,
           6.948680141930328,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           55.88646115024781,
           55.89137445042364,
           55.89628775059946,
           55.90120105077529,
           55.906114350951114,
           55.911027651126936,
           55.915940951302765,
           55.920854251478595,
           55.92576755165442,
           55.930680851830246,
           55.935594152006075,
           55.94050745218189,
           55.94542075235772,
           55.95033405253355,
           55.95524735270938,
           55.9601606528852,
           55.96507395306102,
           55.96998725323685,
           55.974900553412674,
           55.9798138535885,
           55.984727153764325,
           55.98964045394015,
           55.99455375411598,
           55.999467054291806,
           56.00438035446763,
           56.00929365464345,
           56.01420695481928,
           56.0191202549951,
           56.02403355517093,
           56.02894685534676,
           56.03386015552259,
           56.038773455698404,
           56.04368675587423,
           56.04860005605006,
           56.053513356225885,
           56.058426656401714,
           56.063339956577536,
           56.068253256753366,
           56.073166556929195,
           56.07807985710502,
           56.08299315728084,
           56.08790645745667,
           56.09281975763249,
           56.09773305780831,
           56.10264635798414,
           56.10755965815997,
           56.1124729583358,
           56.117386258511615,
           56.122299558687445,
           56.127212858863274,
           56.13212615903909,
           56.13703945921493,
           56.14195275939074,
           56.14686605956658,
           56.151779359742406,
           56.15669265991822,
           56.16160596009405,
           56.16651926026988,
           56.1714325604457,
           56.17634586062153,
           56.18125916079735,
           56.18617246097318,
           56.191085761149,
           56.19599906132483,
           56.20091236150066,
           56.205825661676485,
           56.21073896185231,
           56.21565226202814,
           56.220565562203966,
           56.22547886237979,
           56.23039216255562,
           56.23530546273144,
           56.24021876290726,
           56.24513206308309,
           56.25004536325892,
           56.253114828062735,
           56.25434045760038,
           56.25556608713802,
           56.256791716675664,
           56.25801734621331,
           56.259242975750944,
           56.26046860528859,
           56.26169423482623,
           56.26291986436387,
           55.99910246347014,
           55.682276456490115,
           55.365450449510114,
           55.048624442530105,
           54.73179843555009,
           54.414972428570096,
           54.09814642159008,
           53.78132041461007,
           53.464494407630056,
           53.14766840065005,
           52.830842393670046,
           52.51401638669003,
           52.19719037971002,
           51.880364372730014,
           51.56353836574999,
           51.24671235877,
           50.92988635178999,
           50.61306034480997,
           50.296234337829965,
           49.97940833084996,
           49.662582323869955,
           49.34575631688994,
           49.028930309909924,
           48.71210430292993,
           48.3952782959499,
           48.078452288969906,
           47.7616262819899,
           47.44480027500988,
           47.12797426802989,
           46.81114826104986,
           46.49432225406986,
           46.17749624708984,
           45.860670240109826,
           45.54384423312983,
           45.22701822614982,
           44.91019221916981,
           44.5933662121898,
           44.276540205209784,
           43.95971419822979,
           43.64288819124977,
           43.32606218426976,
           43.009236177289765,
           42.69241017030974,
           42.37558416332974,
           42.058758156349725,
           41.74193214936972,
           41.42510614238972,
           41.10828013540969,
           40.79145412842969,
           40.474628121449676,
           40.15780211446967,
           39.84097610748967,
           39.52415010050966,
           39.20732409352965,
           38.890498086549634,
           38.57367207956962,
           38.256846072589624,
           37.94002006560961,
           37.62319405862959,
           37.3063680516496,
           36.98954204466958,
           36.672716037689575,
           36.35589003070957,
           36.03906402372955,
           35.72223801674956,
           35.40541200976953,
           35.088586002789526,
           34.77175999580952,
           34.4549339888295,
           34.1381079818495,
           33.82128197486948,
           33.50445596788948,
           33.18762996090947,
           32.87080395392945,
           32.549105998668615,
           32.21766414747516,
           31.88622229628171,
           31.55478044508826,
           31.22333859389481,
           30.89189674270137,
           30.56045489150792,
           30.229013040314467,
           29.89757118912103,
           29.61439621436105,
           29.35535467781784,
           29.096313141274617,
           28.837271604731388,
           28.578230068188176,
           28.319188531644944,
           28.06014699510173,
           27.80110545855851,
           27.542063922015277,
           27.28302238547207,
           27.023980848928833,
           26.764939312385618,
           26.5058977758424,
           26.24685623929917,
           25.987814702755962,
           25.72877316621274,
           25.46973162966951,
           25.210690093126285,
           24.951648556583066,
           24.69260702003985,
           24.433565483496626,
           24.174523946953403,
           23.91548241041019,
           23.656440873866956,
           23.39739933732374,
           23.13835780078052,
           22.879316264237296,
           22.620274727694085,
           22.36123319115085,
           22.102191654607633,
           21.843150118064408,
           21.584108581521185,
           21.325067044977974,
           21.06602550843475,
           20.806983971891523,
           20.5479424353483,
           20.288900898805075,
           20.029859362261863,
           19.770817825718638,
           19.511776289175415,
           19.2527347526322,
           18.993693216088978,
           18.734651679545753,
           18.475610143002527,
           18.216568606459305,
           17.957527069916082,
           17.698485533372867,
           17.439443996829645,
           17.18040246028642,
           16.921360923743194,
           16.66231938719997,
           16.40327785065676,
           16.144236314113535,
           15.88519477757031,
           15.626153241027088,
           15.367111704483875,
           15.10807016794065,
           14.849028631397427,
           14.589987094854202,
           14.330945558310978,
           14.071904021767766,
           13.812862485224542,
           13.553820948681317,
           13.294779412138094,
           13.035737875594881,
           12.776696339051657,
           12.517654802508433,
           12.25861326596521,
           11.999571729421984,
           11.740530192878772,
           11.48148865633555,
           11.222447119792324,
           10.9634055832491,
           10.704364046705876,
           10.445322510162665,
           10.18628097361944,
           9.927239437076217,
           9.668197900532991,
           9.40915636398978,
           9.150114827446554,
           8.89107329090333,
           8.632097933627477,
           8.3749444617637,
           8.241060369988611,
           8.158613245457246,
           8.076166120925896,
           7.993718996394545,
           7.91127187186318,
           7.828824747331829,
           7.746377622800472,
           7.6639304982691145,
           7.581483373737757,
           7.499036249206408,
           7.416589124675049,
           7.334142000143697,
           7.2516948756123405,
           7.169247751080991,
           7.086800626549632,
           7.004353502018276,
           6.921906377486925,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           55.63288170819159,
           55.63779500836742,
           55.64270830854324,
           55.64762160871907,
           55.65253490889489,
           55.657448209070715,
           55.662361509246544,
           55.66727480942237,
           55.672188109598196,
           55.677101409774025,
           55.682014709949854,
           55.68692801012567,
           55.6918413103015,
           55.69675461047733,
           55.70166791065314,
           55.70658121082897,
           55.7114945110048,
           55.71640781118063,
           55.72132111135645,
           55.72623441153228,
           55.731147711708104,
           55.736061011883926,
           55.740974312059755,
           55.745887612235585,
           55.75080091241141,
           55.75571421258723,
           55.76062751276306,
           55.76554081293888,
           55.77045411311471,
           55.77536741329053,
           55.780280713466354,
           55.78519401364218,
           55.79010731381801,
           55.79502061399384,
           55.79993391416966,
           55.804847214345486,
           55.809760514521315,
           55.814673814697144,
           55.81958711487296,
           55.82450041504879,
           55.82941371522462,
           55.83432701540044,
           55.83924031557626,
           55.84415361575209,
           55.84906691592792,
           55.853980216103736,
           55.858893516279565,
           55.86380681645539,
           55.86872011663121,
           55.87363341680705,
           55.87854671698287,
           55.8834600171587,
           55.88837331733451,
           55.89328661751034,
           55.89819991768617,
           55.903113217862,
           55.90802651803783,
           55.912939818213644,
           55.9178531177281,
           55.91907874726574,
           55.92030437680339,
           55.92153000634102,
           55.922755635878666,
           55.92398126541631,
           55.92520689495395,
           55.92643252449159,
           55.92765815402923,
           55.928883783566874,
           55.93010941310452,
           55.93133504264216,
           55.932560672179804,
           55.93378630171745,
           55.93501193125509,
           55.93623756079273,
           55.93746319033037,
           55.93868881986801,
           55.939914449405656,
           55.9411400789433,
           55.942365708480935,
           55.94359133801858,
           55.94481696755622,
           55.946042597093864,
           55.94726822663151,
           55.94849385616915,
           55.68467645527541,
           55.367850448295385,
           55.05102444131539,
           54.734198434335376,
           54.41737242735536,
           54.10054642037537,
           53.78372041339536,
           53.46689440641534,
           53.15006839943533,
           52.833242392455325,
           52.516416385475324,
           52.1995903784953,
           51.88276437151529,
           51.565938364535285,
           51.249112357555276,
           50.93228635057527,
           50.61546034359526,
           50.29863433661525,
           49.98180832963524,
           49.66498232265523,
           49.348156315675226,
           49.03133030869521,
           48.7145043017152,
           48.39767829473521,
           48.08085228775518,
           47.76402628077518,
           47.44720027379517,
           47.13037426681516,
           46.81354825983516,
           46.49672225285513,
           46.179896245875135,
           45.86307023889512,
           45.546244231915104,
           45.22941822493511,
           44.9125922179551,
           44.595766210975086,
           44.27894020399507,
           43.96211419701506,
           43.64528819003506,
           43.32846218305505,
           43.01163617607504,
           42.69481016909504,
           42.37798416211501,
           42.06115815513502,
           41.744332148154996,
           41.42750614117499,
           41.11068013419499,
           40.79385412721497,
           40.47702812023497,
           40.160202113254954,
           39.843376106274945,
           39.52655009929495,
           39.209724092314936,
           38.89289808533492,
           38.57607207835491,
           38.259246071374896,
           37.942420064394895,
           37.62559405741489,
           37.296588177635684,
           36.96514632644225,
           36.633704475248784,
           36.302262624055345,
           35.9708207728619,
           35.639378921668445,
           35.307937070475006,
           34.97649521928154,
           34.6450533680881,
           34.31361151689465,
           33.9821696657012,
           33.65072781450776,
           33.3192859633143,
           32.98784411212086,
           32.65640226092741,
           32.32496040973396,
           31.993518558540522,
           31.66207670734707,
           31.330634856153615,
           30.999193004960166,
           30.667751153766712,
           30.336309302573277,
           30.004867451379823,
           29.673425600186373,
           29.341983748992938,
           29.058808774232958,
           28.799767237689743,
           28.540725701146517,
           28.281684164603295,
           28.022642628060083,
           27.76360109151685,
           27.504559554973635,
           27.245518018430413,
           26.98647648188719,
           26.727434945343976,
           26.468393408800736,
           26.20935187225753,
           25.9503103357143,
           25.69126879917108,
           25.43222726262787,
           25.17318572608464,
           24.914144189541418,
           24.655102652998192,
           24.39606111645497,
           24.137019579911755,
           23.877978043368532,
           23.61893650682531,
           23.359894970282095,
           23.10085343373886,
           22.841811897195647,
           22.58277036065242,
           22.3237288241092,
           22.064687287565988,
           21.80564575102275,
           21.54660421447954,
           21.287562677936315,
           21.028521141393092,
           20.769479604849877,
           20.510438068306655,
           20.25139653176343,
           19.992354995220207,
           19.73331345867698,
           19.47427192213377,
           19.215230385590548,
           18.956188849047322,
           18.69714731250411,
           18.438105775960885,
           18.17906423941766,
           17.920022702874437,
           17.66098116633121,
           17.40193962978799,
           17.142898093244778,
           16.883856556701552,
           16.624815020158326,
           16.3657734836151,
           16.10673194707188,
           15.847690410528667,
           15.588648873985441,
           15.32960733744222,
           15.070565800898995,
           14.811524264355782,
           14.552482727812558,
           14.293441191269334,
           14.034399654726109,
           13.775358118182886,
           13.516316581639675,
           13.25727504509645,
           12.998233508553225,
           12.739324330697615,
           12.48120930369374,
           12.223094276689853,
           11.964979249685966,
           11.706864222682078,
           11.448749195678191,
           11.190634168674315,
           10.93251914167043,
           10.67440411466654,
           10.416289087662653,
           10.158174060658766,
           9.903424476904904,
           9.649155670346081,
           9.394886863787258,
           9.146780739116629,
           8.902534573251973,
           8.667535802461021,
           8.455891277087147,
           8.297927313304628,
           8.214286605545192,
           8.131839481013841,
           8.049392356482477,
           7.966945231951126,
           7.884498107419776,
           7.802050982888412,
           7.719603858357061,
           7.637156733825703,
           7.5547096092943455,
           7.472262484762987,
           7.389815360231639,
           7.307368235700281,
           7.224921111168929,
           7.142473986637572,
           7.060026862106222,
           6.977579737574864,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           55.37930226613538,
           55.38421556631121,
           55.389128866487034,
           55.394042166662864,
           55.398955466838686,
           55.40386876701451,
           55.40878206719034,
           55.41369536736617,
           55.41860866754199,
           55.42352196771781,
           55.42843526789364,
           55.43334856806946,
           55.43826186824529,
           55.443175168421114,
           55.448088468596936,
           55.453001768772765,
           55.457915068948594,
           55.46282836912442,
           55.46774166930024,
           55.47265496947607,
           55.4775682696519,
           55.48248156982772,
           55.48739487000355,
           55.49230817017937,
           55.49722147035519,
           55.50213477053102,
           55.50704807070685,
           55.51196137088267,
           55.516874671058495,
           55.521787971234325,
           55.52670127141015,
           55.531614571585976,
           55.536527871761805,
           55.54144117193762,
           55.54635447211345,
           55.55126777228928,
           55.5561810724651,
           55.56109437264093,
           55.56600767281675,
           55.57092097299258,
           55.575834273168404,
           55.580747573344226,
           55.58381703693112,
           55.585042666468766,
           55.58626829600641,
           55.58749392554405,
           55.588719555081695,
           55.58994518461934,
           55.59117081415698,
           55.59239644369461,
           55.59362207323227,
           55.5948477027699,
           55.596073332307554,
           55.59729896184519,
           55.59852459138283,
           55.59975022092047,
           55.60097585045811,
           55.602201479995756,
           55.6034271095334,
           55.60465273907104,
           55.605878368608685,
           55.60710399814632,
           55.60832962768397,
           55.609555257221615,
           55.61078088675925,
           55.612006516296894,
           55.61323214583454,
           55.61445777537218,
           55.61568340490982,
           55.61690903444746,
           55.6181346639851,
           55.619360293522746,
           55.62058592306039,
           55.62181155259803,
           55.623037182135675,
           55.62426281167332,
           55.625488441210955,
           55.6267140707486,
           55.62793970028624,
           55.62916532982388,
           55.63039095936152,
           55.63161658889916,
           55.63284221843681,
           55.63406784797445,
           55.370250447080714,
           55.05342444010069,
           54.73659843312069,
           54.419772426140675,
           54.102946419160666,
           53.78612041218067,
           53.46929440520066,
           53.15246839822064,
           52.83564239124063,
           52.518816384260624,
           52.20199037728062,
           51.8851643703006,
           51.56833836332059,
           51.251512356340584,
           50.934686349360575,
           50.617860342380574,
           50.301034335400566,
           49.98420832842055,
           49.66738232144054,
           49.35055631446053,
           49.033730307480525,
           48.71690430050052,
           48.4000782935205,
           48.08325228654051,
           47.76642627956048,
           47.44960027258048,
           47.132774265600474,
           46.81594825862046,
           46.49912225164046,
           46.182296244660435,
           45.865470237680434,
           45.54864423070042,
           45.2318182237204,
           44.91499221674041,
           44.5981662097604,
           44.281340202780385,
           43.964514195800376,
           43.64768818882036,
           43.33086218184036,
           43.01403617486035,
           42.69721016788034,
           42.37551220779627,
           42.0440703566028,
           41.71262850540936,
           41.38118665421592,
           41.04974480302246,
           40.718302951829024,
           40.38686110063556,
           40.055419249442124,
           39.72397739824867,
           39.39253554705522,
           39.061093695861786,
           38.72965184466833,
           38.39820999347488,
           38.066768142281425,
           37.73532629108797,
           37.40388443989454,
           37.07244258870109,
           36.74100073750763,
           36.4095588863142,
           36.078117035120734,
           35.746675183927294,
           35.41523333273385,
           35.083791481540395,
           34.752349630346956,
           34.42090777915349,
           34.089465927960056,
           33.7580240767666,
           33.42658222557315,
           33.09514037437972,
           32.76369852318625,
           32.43225667199281,
           32.10081482079936,
           31.76937296960591,
           31.43793111841247,
           31.10648926721902,
           30.775047416025565,
           30.44360556483211,
           30.112163713638665,
           29.780721862445226,
           29.449280011251773,
           29.117838160058326,
           28.786396308864887,
           28.503221334104907,
           28.244179797561692,
           27.98513826101847,
           27.726096724475244,
           27.467055187932033,
           27.2080136513888,
           26.948972114845585,
           26.689930578302363,
           26.430889041759137,
           26.171847505215926,
           25.912805968672686,
           25.653764432129478,
           25.394722895586252,
           25.135681359043026,
           24.87663982249982,
           24.617598285956593,
           24.358556749413367,
           24.09951521287014,
           23.84047367632692,
           23.58143213978371,
           23.322390603240482,
           23.06334906669726,
           22.804307530154045,
           22.545265993610812,
           22.286224457067597,
           22.027182920524375,
           21.76814138398115,
           21.509099847437938,
           21.2500583108947,
           20.991016774351486,
           20.731975237808268,
           20.472933701265042,
           20.21389216472183,
           19.954850628178608,
           19.69580909163538,
           19.436767555092157,
           19.17772601854893,
           18.91868448200572,
           18.659642945462494,
           18.40060140891927,
           18.141559872376057,
           17.882518335832835,
           17.62347679928961,
           17.364435262746387,
           17.10539372620316,
           16.846550727767795,
           16.588435700763917,
           16.33032067376003,
           16.072205646756146,
           15.814090619752257,
           15.55597559274837,
           15.297860565744497,
           15.039745538740606,
           14.78163051173672,
           14.523515484732833,
           14.265400457728955,
           14.00728543072507,
           13.749170403721182,
           13.491055376717295,
           13.232940349713408,
           12.974825322709533,
           12.716710295705646,
           12.458595268701757,
           12.200480241697871,
           11.942365214693996,
           11.68617329860496,
           11.431904492046137,
           11.177635685487312,
           10.923366878928487,
           10.669098072369676,
           10.414829265810852,
           10.16357176932515,
           9.918687046970808,
           9.673802324616465,
           9.431216405683955,
           9.193994361627118,
           8.964292212342446,
           8.747779742177547,
           8.548902034223028,
           8.380048056843771,
           8.26995996563314,
           8.187512841101789,
           8.105065716570431,
           8.02261859203908,
           7.940171467507716,
           7.857724342976367,
           7.775277218445016,
           7.692830093913651,
           7.6103829693823,
           7.527935844850943,
           7.445488720319585,
           7.363041595788228,
           7.2805944712568795,
           7.19814734672552,
           7.115700222194169,
           7.033253097662811,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           55.12572282407915,
           55.13063612425498,
           55.1355494244308,
           55.14046272460663,
           55.14537602478245,
           55.15028932495827,
           55.1552026251341,
           55.16011592530993,
           55.16502922548575,
           55.16994252566158,
           55.17485582583741,
           55.17976912601323,
           55.184682426189056,
           55.189595726364885,
           55.194509026540715,
           55.19942232671654,
           55.20433562689236,
           55.20924892706819,
           55.21416222724401,
           55.21907552741984,
           55.22398882759566,
           55.228902127771484,
           55.23381542794731,
           55.23872872812314,
           55.243642028298964,
           55.24855532659649,
           55.249780956134124,
           55.25100658567177,
           55.25223221520941,
           55.253457844747054,
           55.2546834742847,
           55.25590910382234,
           55.25713473335998,
           55.258360362897626,
           55.25958599243526,
           55.260811621972906,
           55.26203725151055,
           55.26326288104819,
           55.26448851058583,
           55.26571414012348,
           55.266939769661114,
           55.26816539919876,
           55.2693910287364,
           55.270616658274044,
           55.27184228781169,
           55.27306791734932,
           55.27429354688698,
           55.27551917642461,
           55.27674480596225,
           55.277970435499896,
           55.27919606503754,
           55.28042169457518,
           55.281647324112825,
           55.282872953650454,
           55.28409858318811,
           55.28532421272574,
           55.2865498422634,
           55.28777547180103,
           55.28900110133867,
           55.29022673087633,
           55.291452360413956,
           55.2926779899516,
           55.29390361948924,
           55.295129249026886,
           55.29635487856453,
           55.29758050810217,
           55.29880613763981,
           55.30003176717745,
           55.301257396715094,
           55.30248302625274,
           55.30370865579038,
           55.304934285328024,
           55.30615991486567,
           55.3073855444033,
           55.308611173940946,
           55.30983680347859,
           55.31106243301623,
           55.312288062553876,
           55.31351369209152,
           55.31473932162916,
           55.315964951166805,
           55.31719058070444,
           55.318416210242084,
           55.31964183977973,
           55.05582443888599,
           54.73899843190597,
           54.42217242492597,
           54.10534641794595,
           53.788520410965944,
           53.47169440398594,
           53.154868397005934,
           52.838042390025926,
           52.52121638304591,
           52.204390376065895,
           51.8875643690859,
           51.570738362105885,
           51.25391235512588,
           50.937086348145854,
           50.620260341165846,
           50.30343433418585,
           49.986608327205836,
           49.66978232022583,
           49.35295631324582,
           49.036130306265804,
           48.7193042992858,
           48.402478292305794,
           48.08565228532578,
           47.768826278345784,
           47.452000271365755,
           47.122994386763345,
           46.79155253556989,
           46.46011068437644,
           46.128668833183,
           45.79722698198953,
           45.4657851307961,
           45.134343279602646,
           44.80290142840919,
           44.47145957721576,
           44.14001772602231,
           43.808575874828854,
           43.4771340236354,
           43.14569217244195,
           42.814250321248515,
           42.48280847005506,
           42.15136661886161,
           41.81992476766818,
           41.48848291647471,
           41.15704106528127,
           40.82559921408782,
           40.49415736289437,
           40.16271551170093,
           39.83127366050747,
           39.49983180931403,
           39.16838995812058,
           38.836948106927125,
           38.50550625573369,
           38.17406440454024,
           37.842622553346786,
           37.51118070215333,
           37.17973885095988,
           36.84829699976645,
           36.51685514857299,
           36.18541329737954,
           35.85397144618611,
           35.52252959499264,
           35.1910877437992,
           34.859645892605755,
           34.5282040414123,
           34.19676219021886,
           33.865320339025395,
           33.53387848783196,
           33.20243663663851,
           32.870994785445056,
           32.539552934251624,
           32.20811108305816,
           31.876669231864717,
           31.545227380671264,
           31.213785529477818,
           30.88234367828438,
           30.550901827090925,
           30.219459975897475,
           29.888018124704022,
           29.556576273510572,
           29.225134422317137,
           28.893692571123683,
           28.56225071993023,
           28.230808868736794,
           27.94763389397681,
           27.688592357433606,
           27.429550820890377,
           27.17050928434715,
           26.91146774780394,
           26.652426211260703,
           26.393384674717492,
           26.13434313817427,
           25.875301601631044,
           25.616260065087832,
           25.357218528544593,
           25.098176992001378,
           24.83913545545816,
           24.580093918914933,
           24.32105238237172,
           24.0620108458285,
           23.802969309285274,
           23.543927772742048,
           23.284886236198826,
           23.025844699655615,
           22.76680316311239,
           22.507761626569167,
           22.24872009002595,
           21.989678553482715,
           21.730637016939504,
           21.47159548039628,
           21.212553943853056,
           20.953777124837945,
           20.69566209783404,
           20.43754707083017,
           20.179432043826285,
           19.921317016822393,
           19.66320198981852,
           19.405086962814632,
           19.146971935810747,
           18.888856908806858,
           18.63074188180297,
           18.372626854799094,
           18.11451182779521,
           17.85639680079132,
           17.598281773787445,
           17.34016674678356,
           17.08205171977967,
           16.82393669277578,
           16.565821665771896,
           16.30770663876801,
           16.049591611764132,
           15.791476584760245,
           15.533361557756358,
           15.27524653075247,
           15.017131503748583,
           14.759016476744709,
           14.50090144974082,
           14.242786422736934,
           13.984671395733047,
           13.72655636872917,
           13.468922120304974,
           13.21465331374615,
           12.960384507187324,
           12.706115700628501,
           12.451846894069691,
           12.197578087510866,
           11.943309280952043,
           11.689040474393218,
           11.434771667834408,
           11.180502861275585,
           10.935478077179294,
           10.690593354824951,
           10.445708632470609,
           10.200823910116277,
           9.959898238115905,
           9.72267619405907,
           9.48545415000223,
           9.261048622223841,
           9.040694257716343,
           8.836583692254845,
           8.641912791358877,
           8.471217338985007,
           8.335851906887664,
           8.243186201189722,
           8.16073907665837,
           8.078291952127021,
           7.995844827595663,
           7.913397703064313,
           7.830950578532947,
           7.748503454001597,
           7.666056329470247,
           7.583609204938883,
           7.501162080407533,
           7.418714955876175,
           7.336267831344817,
           7.2538207068134595,
           7.17137358228211,
           7.088926457750752,
           7.006479333219399,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           54.87214338202294,
           54.87705668219877,
           54.88196998237459,
           54.88688328255042,
           54.89179658272624,
           54.896709882902066,
           54.901623183077895,
           54.906536483253724,
           54.911449783429546,
           54.91451924579952,
           54.915744875337154,
           54.9169705048748,
           54.91819613441245,
           54.91942176395008,
           54.92064739348772,
           54.92187302302536,
           54.923098652563006,
           54.924324282100656,
           54.92554991163829,
           54.926775541175935,
           54.92800117071358,
           54.92922680025122,
           54.930452429788865,
           54.9316780593265,
           54.932903688864144,
           54.934129318401794,
           54.93535494793942,
           54.936580577477066,
           54.93780620701471,
           54.93903183655235,
           54.940257466089996,
           54.94148309562764,
           54.94270872516528,
           54.943934354702925,
           54.94515998424056,
           54.94638561377821,
           54.947611243315855,
           54.94883687285349,
           54.950062502391134,
           54.95128813192878,
           54.95251376146642,
           54.953739391004056,
           54.9549650205417,
           54.95619065007934,
           54.957416279616986,
           54.95864190915462,
           54.95986753869227,
           54.96109316822991,
           54.96231879776755,
           54.963544427305195,
           54.96477005684284,
           54.96599568638048,
           54.967221315918124,
           54.96844694545576,
           54.9696725749934,
           54.970898204531046,
           54.97212383406869,
           54.973349463606326,
           54.97457509314397,
           54.97580072268162,
           54.977026352219255,
           54.978251981756905,
           54.97947761129454,
           54.980703240832185,
           54.98192887036983,
           54.983154499907464,
           54.98438012944511,
           54.98560575898275,
           54.98683138852039,
           54.988057018058036,
           54.98928264759567,
           54.990508277133316,
           54.99173390667096,
           54.9929595362086,
           54.994185165746245,
           54.99541079528389,
           54.99663642482153,
           54.997862054359175,
           54.99908768389682,
           55.00031331343446,
           55.001538942972104,
           55.00276457250975,
           55.00399020204738,
           55.005215831585026,
           54.74139843069129,
           54.42457242371127,
           54.10774641673127,
           53.79092040975125,
           53.47409440277124,
           53.15726839579124,
           52.84044238881123,
           52.52361638183122,
           52.2019184169239,
           51.870476565730456,
           51.53903471453701,
           51.207592863343564,
           50.87615101215012,
           50.54470916095667,
           50.21326730976321,
           49.88182545856978,
           49.55038360737633,
           49.21894175618287,
           48.887499904989426,
           48.556058053795965,
           48.22461620260253,
           47.89317435140909,
           47.561732500215626,
           47.230290649022194,
           46.89884879782872,
           46.56740694663529,
           46.23596509544184,
           45.90452324424838,
           45.57308139305495,
           45.24163954186149,
           44.91019769066804,
           44.578755839474596,
           44.24731398828115,
           43.9158721370877,
           43.58443028589426,
           43.25298843470081,
           42.92154658350735,
           42.590104732313904,
           42.25866288112046,
           41.92722102992701,
           41.595779178733565,
           41.264337327540126,
           40.93289547634666,
           40.60145362515322,
           40.270011773959766,
           39.93856992276632,
           39.60712807157288,
           39.27568622037942,
           38.94424436918598,
           38.61280251799252,
           38.281360666799074,
           37.94991881560564,
           37.61847696441218,
           37.287035113218735,
           36.95559326202529,
           36.62415141083183,
           36.292709559638396,
           35.961267708444936,
           35.62982585725149,
           35.29838400605806,
           34.96694215486459,
           34.63550030367115,
           34.3040584524777,
           33.97261660128425,
           33.64117475009081,
           33.309732898897344,
           32.978291047703905,
           32.64684919651046,
           32.315407345317006,
           31.98396549412357,
           31.652523642930102,
           31.321081791736667,
           30.989639940543213,
           30.65819808934976,
           30.326756238156324,
           29.99531438696287,
           29.66387253576942,
           29.33243068457597,
           29.00098883338252,
           28.669546982189082,
           28.338105130995633,
           28.00666327980218,
           27.675221428608744,
           27.39204645384876,
           27.133004917305552,
           26.873963380762326,
           26.6149218442191,
           26.355880307675893,
           26.096838771132656,
           25.83779723458944,
           25.57875569804622,
           25.319714161502997,
           25.061003521908123,
           24.802888494904224,
           24.54477346790035,
           24.28665844089646,
           24.028543413892574,
           23.7704283868887,
           23.51231335988481,
           23.254198332880925,
           22.996083305877036,
           22.73796827887315,
           22.479853251869272,
           22.221738224865387,
           21.9636231978615,
           21.705508170857623,
           21.447393143853724,
           21.189278116849852,
           20.931163089845963,
           20.673048062842074,
           20.4149330358382,
           20.1568180088343,
           19.898702981830425,
           19.640587954826536,
           19.38247292782265,
           19.124357900818776,
           18.866242873814887,
           18.608127846811,
           18.350012819807112,
           18.091897792803227,
           17.833782765799352,
           17.575667738795463,
           17.317552711791574,
           17.0594376847877,
           16.801322657783814,
           16.543207630779925,
           16.285092603776036,
           16.02697757677215,
           15.768862549768265,
           15.51074752276439,
           15.252632495760501,
           14.997402135446201,
           14.743133328887378,
           14.488864522328555,
           14.234595715769744,
           13.98032690921092,
           13.726058102652097,
           13.471789296093274,
           13.217520489534463,
           12.963251682975638,
           12.708982876416815,
           12.45471406985799,
           12.200445263299168,
           11.952269107387814,
           11.70738438503347,
           11.462499662679129,
           11.217614940324786,
           10.972730217970454,
           10.727845495616114,
           10.488580070547888,
           10.251358026491049,
           10.014135982434212,
           9.780248848427263,
           9.557805032105275,
           9.33536121578329,
           9.12949820779365,
           8.928157978469493,
           8.735335917036103,
           8.562386621126265,
           8.417090355195402,
           8.301843519347917,
           8.216412436746312,
           8.133965312214956,
           8.051518187683605,
           7.969071063152254,
           7.886623938620896,
           7.804176814089546,
           7.72172968955818,
           7.63928256502683,
           7.556835440495481,
           7.474388315964116,
           7.391941191432765,
           7.309494066901408,
           7.227046942370049,
           7.144599817838692,
           7.062152693307343,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           54.613554840406486,
           54.61027744741177,
           54.60700005441706,
           54.60372266142234,
           54.60044526842762,
           54.59716787543291,
           54.59389048243819,
           54.59061308944347,
           54.587335696448754,
           54.58856132220679,
           54.589786951744436,
           54.59101258128207,
           54.59223821081972,
           54.59346384035736,
           54.594689469895,
           54.595915099432645,
           54.59714072897029,
           54.59836635850793,
           54.599591988045574,
           54.60081761758322,
           54.602043247120854,
           54.6032688766585,
           54.60449450619614,
           54.60572013573378,
           54.606945765271426,
           54.60817139480907,
           54.609397024346706,
           54.61062265388435,
           54.61184828342199,
           54.613073912959635,
           54.61429954249728,
           54.61552517203492,
           54.616750801572564,
           54.61797643111021,
           54.619202060647844,
           54.620427690185494,
           54.62165331972313,
           54.62287894926077,
           54.62410457879841,
           54.62533020833606,
           54.626555837873696,
           54.62778146741134,
           54.62900709694898,
           54.630232726486625,
           54.63145835602427,
           54.63268398556191,
           54.63390961509956,
           54.6351352446372,
           54.636360874174834,
           54.637586503712484,
           54.63881213325012,
           54.64003776278777,
           54.6412633923254,
           54.64248902186304,
           54.643714651400686,
           54.64494028093833,
           54.64616591047597,
           54.64739154001361,
           54.64861716955126,
           54.6498427990889,
           54.65106842862653,
           54.65229405816419,
           54.65351968770182,
           54.65474531723947,
           54.65597094677711,
           54.65719657631475,
           54.658422205852396,
           54.65964783539004,
           54.660873464927676,
           54.66209909446532,
           54.66332472400296,
           54.664550353540605,
           54.66577598307824,
           54.667001612615884,
           54.66822724215353,
           54.66945287169117,
           54.670678501228814,
           54.67190413076646,
           54.6731297603041,
           54.67435538984174,
           54.675581019379386,
           54.67680664891702,
           54.678032278454666,
           54.67925790799231,
           54.393127631590005,
           54.049526173999695,
           53.70592471640941,
           53.36232325881912,
           53.01872180122882,
           52.67512034363853,
           52.33151888604824,
           51.98791742845793,
           51.65444896599221,
           51.323007114798756,
           50.99156526360532,
           50.66012341241186,
           50.32868156121842,
           49.997239710024964,
           49.66579785883151,
           49.33435600763807,
           49.002914156444625,
           48.67147230525117,
           48.340030454057725,
           48.00858860286427,
           47.67714675167083,
           47.345704900477386,
           47.01426304928393,
           46.682821198090494,
           46.351379346897026,
           46.019937495703594,
           45.68849564451014,
           45.35705379331669,
           45.02561194212325,
           44.69417009092978,
           44.36272823973635,
           44.031286388542895,
           43.69984453734944,
           43.36840268615601,
           43.03696083496256,
           42.7055189837691,
           42.37407713257566,
           42.042635281382196,
           41.711193430188764,
           41.37975157899532,
           41.04830972780186,
           40.716867876608426,
           40.38542602541496,
           40.05398417422152,
           39.722542323028065,
           39.39110047183462,
           39.05965862064118,
           38.72821676944772,
           38.39677491825428,
           38.06533306706083,
           37.733891215867374,
           37.40244936467394,
           37.07100751348049,
           36.73956566228704,
           36.40812381109358,
           36.076681959900135,
           35.745240108706696,
           35.41379825751324,
           35.082356406319796,
           34.75091455512636,
           34.41947270393289,
           34.08803085273945,
           33.756589001546004,
           33.42514715035255,
           33.09370529915911,
           32.76226344796565,
           32.43082159677221,
           32.09937974557876,
           31.7679378943853,
           31.43649604319187,
           31.1050541919984,
           30.773612340804963,
           30.442170489611513,
           30.11072863841806,
           29.779286787224624,
           29.44784493603117,
           29.11640308483772,
           28.784961233644268,
           28.453519382450818,
           28.122077531257382,
           27.79063568006393,
           27.459193828870475,
           27.12775197767704,
           26.845194675943283,
           26.58707964893941,
           26.328964621935523,
           26.070849594931637,
           25.812734567927762,
           25.554619540923866,
           25.296504513919988,
           25.0383894869161,
           24.780274459912214,
           24.52215943290834,
           24.264044405904443,
           24.00592937890056,
           23.747814351896675,
           23.48969932489279,
           23.231584297888915,
           22.973469270885026,
           22.715354243881137,
           22.457239216877255,
           22.199124189873366,
           21.941009162869488,
           21.6828941358656,
           21.424779108861713,
           21.16666408185784,
           20.908549054853943,
           20.650434027850064,
           20.39231900084618,
           20.13420397384229,
           19.876088946838415,
           19.617973919834515,
           19.359858892830637,
           19.10174386582675,
           18.843628838822866,
           18.58551381181899,
           18.327398784815102,
           18.069283757811213,
           17.811168730807328,
           17.553053703803442,
           17.294938676799568,
           17.03682364979568,
           16.780150957146216,
           16.525882150587407,
           16.27161334402858,
           16.017344537469757,
           15.763075730910934,
           15.508806924352111,
           15.254538117793288,
           15.000269311234476,
           14.746000504675653,
           14.49173169811683,
           14.237462891558005,
           13.98319408499918,
           13.72892527844037,
           13.474656471881545,
           13.220387665322724,
           12.969060137596287,
           12.724175415241955,
           12.479290692887613,
           12.234405970533272,
           11.989521248178928,
           11.744636525824589,
           11.499751803470257,
           11.254867081115913,
           11.01726190297984,
           10.780039858923,
           10.542817814866176,
           10.305595770809337,
           10.07700525830866,
           9.854561441986672,
           9.632117625664685,
           9.422412723332446,
           9.218302157870948,
           9.02116873560535,
           8.829944602779973,
           8.655472947832289,
           8.50220155132101,
           8.373880175201837,
           8.272085796834244,
           8.189638672302902,
           8.107191547771544,
           8.024744423240186,
           7.942297298708835,
           7.859850174177485,
           7.777403049646127,
           7.694955925114778,
           7.612508800583412,
           7.530061676052062,
           7.4476145515207115,
           7.365167426989347,
           7.282720302457997,
           7.20027317792664,
           7.117826053395282,
           7.035378928863923,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           54.34964413148792,
           54.3463667384932,
           54.343089345498484,
           54.33981195250377,
           54.336534559509055,
           54.33325716651434,
           54.329979773519625,
           54.32670238052491,
           54.32342498753019,
           54.32014759453547,
           54.31687020154075,
           54.31359280854603,
           54.31031541555133,
           54.30703802255661,
           54.30376062956189,
           54.300483236567175,
           54.297205843572456,
           54.29392845057774,
           54.29065105758302,
           54.28737366458831,
           54.28409627159359,
           54.28081887859887,
           54.27754148560416,
           54.27426409260944,
           54.270986699614724,
           54.26996081336358,
           54.271186442901225,
           54.27241207243887,
           54.27363770197651,
           54.274863331514155,
           54.2760889610518,
           54.27731459058944,
           54.278540220127084,
           54.27976584966473,
           54.280991479202356,
           54.282217108740014,
           54.28344273827764,
           54.284668367815286,
           54.28589399735293,
           54.28711962689057,
           54.288345256428215,
           54.28957088596586,
           54.2907965155035,
           54.292022145041145,
           54.29324777457879,
           54.294473404116424,
           54.295699033654074,
           54.29692466319171,
           54.298150292729346,
           54.299375922267,
           54.30060155180464,
           54.30182718134229,
           54.30305281087992,
           54.304278440417555,
           54.305504069955205,
           54.30672969949284,
           54.30795532903049,
           54.30918095856813,
           54.31040658810577,
           54.31163221764342,
           54.31285784718106,
           54.31408347671871,
           54.31530910625634,
           54.31653473579398,
           54.31776036533162,
           54.318985994869266,
           54.32021162440691,
           54.32143725394455,
           54.322662883482195,
           54.32388851301984,
           54.32511414255748,
           54.326339772095125,
           54.32756540163277,
           54.32879103117041,
           54.33001666070804,
           54.33124229024568,
           54.33246791978334,
           54.333693549320984,
           54.33491917885861,
           54.336144808396256,
           54.3373704379339,
           54.33859606747154,
           54.339821697009185,
           54.34104732654683,
           54.05491705014452,
           53.71131559255421,
           53.367714134963926,
           53.02411267737363,
           52.680511219783334,
           52.33690976219305,
           51.99330830460275,
           51.64970684701245,
           51.30610538942215,
           50.962503931831854,
           50.61890247424157,
           50.27530101665128,
           49.93169955906098,
           49.58809810147068,
           49.24449664388038,
           48.90089518629009,
           48.5572937286998,
           48.2136922711095,
           47.87009081351921,
           47.52648935592891,
           47.18288789833863,
           46.83928644074833,
           46.49568498315803,
           46.15208352556775,
           45.81253525789724,
           45.481093406703806,
           45.14965155551035,
           44.8182097043169,
           44.48676785312346,
           44.15532600193,
           43.82388415073656,
           43.492442299543114,
           43.16100044834966,
           42.82955859715622,
           42.49811674596277,
           42.16667489476932,
           41.83523304357587,
           41.503791192382415,
           41.172349341188976,
           40.84090748999553,
           40.50946563880208,
           40.17802378760864,
           39.84658193641517,
           39.51514008522173,
           39.183698234028284,
           38.85225638283483,
           38.52081453164139,
           38.18937268044793,
           37.85793082925449,
           37.52648897806104,
           37.195047126867586,
           36.86360527567415,
           36.5321634244807,
           36.20072157328725,
           35.8692797220938,
           35.53783787090035,
           35.20639601970691,
           34.87495416851346,
           34.54351231732001,
           34.21207046612657,
           33.8806286149331,
           33.54918676373966,
           33.217744912546216,
           32.88630306135276,
           32.55486121015932,
           32.22341935896586,
           31.891977507772424,
           31.56053565657897,
           31.22909380538552,
           30.89765195419208,
           30.566210102998614,
           30.23476825180518,
           29.90332640061173,
           29.571884549418275,
           29.24044269822484,
           28.909000847031386,
           28.577558995837936,
           28.246117144644483,
           27.914675293451037,
           27.583233442257598,
           27.251791591064148,
           26.920349739870694,
           26.588907888677255,
           26.306350586943502,
           26.048235559939627,
           25.790120532935738,
           25.532005505931853,
           25.273890478927974,
           25.01577545192408,
           24.757660424920203,
           24.499545397916314,
           24.241430370912425,
           23.983315343908554,
           23.725200316904655,
           23.46708528990078,
           23.20897026289689,
           22.950855235893002,
           22.692740208889127,
           22.434625181885238,
           22.176510154881356,
           21.918395127877467,
           21.660280100873578,
           21.402165073869703,
           21.144050046865814,
           20.885935019861932,
           20.627819992858054,
           20.369704965854154,
           20.11158993885028,
           19.85347491184639,
           19.5953598848425,
           19.337244857838627,
           19.07912983083473,
           18.821014803830856,
           18.56289977884623,
           18.30863097228741,
           18.054362165728598,
           17.80009335916977,
           17.545824552610952,
           17.291555746052126,
           17.037286939493306,
           16.783018132934494,
           16.528749326375667,
           16.274480519816844,
           16.020211713258032,
           15.765942906699209,
           15.511674100140384,
           15.25740529358156,
           15.003136487022736,
           14.748867680463915,
           14.494598873905101,
           14.240330067346278,
           13.986061260787455,
           13.740966445450429,
           13.49608172309609,
           13.251197000741755,
           13.006312278387414,
           12.76142755603307,
           12.51654283367873,
           12.271658111324399,
           12.026773388970057,
           11.783165779468625,
           11.54594373541179,
           11.30872169135495,
           11.071499647298126,
           10.83427760324129,
           10.597055559184449,
           10.373761668190053,
           10.151317851868077,
           9.928874035546091,
           9.71532723887123,
           9.511216673409729,
           9.307413922715941,
           9.114179492741208,
           8.924553288523851,
           8.750081633576167,
           8.593370833462245,
           8.454659443528259,
           8.336830661603184,
           8.24531203239084,
           8.162864907859483,
           8.080417783328132,
           7.997970658796775,
           7.915523534265418,
           7.833076409734068,
           7.7506292852027165,
           7.668182160671359,
           7.585735036140008,
           7.503287911608643,
           7.420840787077293,
           7.338393662545943,
           7.2559465380145785,
           7.173499413483228,
           7.091052288951872,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           54.085733422569376,
           54.08245602957466,
           54.079178636579954,
           54.075901243585236,
           54.07262385059052,
           54.0693464575958,
           54.06606906460108,
           54.06279167160636,
           54.059514278611644,
           54.05623688561693,
           54.05295949262222,
           54.049682099627496,
           54.04640470663278,
           54.04312731363807,
           54.03984992064335,
           54.03657252764863,
           54.03329513465391,
           54.0300177416592,
           54.02674034866448,
           54.023462955669764,
           54.020185562675046,
           54.01690816968033,
           54.01363077668561,
           54.0103533836909,
           54.00707599069618,
           54.00379859770147,
           54.00052120470675,
           53.99724381171203,
           53.993966418717314,
           53.990689025722595,
           53.987411632727884,
           53.984134239733166,
           53.98085684673845,
           53.977579453743736,
           53.97430206074902,
           53.9710246677543,
           53.96774727475958,
           53.96446988176486,
           53.961192488770145,
           53.957915095775434,
           53.954637702780715,
           53.951360309786,
           53.95258593405804,
           53.953811563595686,
           53.95503719313333,
           53.956262822670965,
           53.957488452208615,
           53.95871408174625,
           53.959939711283894,
           53.96116534082154,
           53.96239097035918,
           53.963616599896824,
           53.96484222943447,
           53.9660678589721,
           53.96729348850975,
           53.96851911804738,
           53.96974474758504,
           53.97097037712267,
           53.97219600666031,
           53.97342163619796,
           53.9746472657356,
           53.97587289527324,
           53.977098524810884,
           53.97832415434853,
           53.97954978388617,
           53.980775413423814,
           53.98200104296146,
           53.9832266724991,
           53.98445230203674,
           53.98567793157438,
           53.98690356111202,
           53.988129190649666,
           53.98935482018731,
           53.990580449724945,
           53.99180607926259,
           53.99303170880023,
           53.994257338337874,
           53.99548296787552,
           53.99670859741316,
           53.997934226950804,
           53.99915985648844,
           54.00038548602609,
           54.001611115563726,
           54.00283674510137,
           53.71670646869906,
           53.37310501110875,
           53.02950355351847,
           52.68590209592817,
           52.342300638337875,
           51.998699180747586,
           51.6550977231573,
           51.31149626556699,
           50.96789480797669,
           50.624293350386395,
           50.28069189279611,
           49.93709043520582,
           49.59348897761552,
           49.249887520025226,
           48.906286062434916,
           48.56268460484464,
           48.21908314725434,
           47.87548168966404,
           47.531880232073746,
           47.18827877448345,
           46.84467731689317,
           46.50107585930287,
           46.15747440171257,
           45.813872944122295,
           45.47027148653198,
           45.12667002894169,
           44.78306857135139,
           44.4394671137611,
           44.095865656170815,
           43.7522641985805,
           43.40866274099022,
           43.06506128339992,
           42.72145982580962,
           42.377858368219336,
           42.03425691062904,
           41.690655453038744,
           41.34705399544845,
           41.00345253785815,
           40.65985108026786,
           40.31624962267757,
           39.97264816508727,
           39.6391796986089,
           39.307737847415424,
           38.97629599622199,
           38.64485414502854,
           38.313412293835086,
           37.981970442641654,
           37.650528591448186,
           37.319086740254754,
           36.98764488906129,
           36.65620303786784,
           36.32476118667441,
           35.993319335480955,
           35.6618774842875,
           35.330435633094055,
           34.998993781900595,
           34.66755193070716,
           34.336110079513716,
           34.004668228320256,
           33.673226377126824,
           33.34178452593336,
           33.01034267473992,
           32.67890082354647,
           32.347458972353024,
           32.01601712115958,
           31.684575269966114,
           31.353133418772682,
           31.021691567579232,
           30.69024971638577,
           30.35880786519234,
           30.027366013998872,
           29.695924162805433,
           29.364482311611987,
           29.033040460418533,
           28.701598609225094,
           28.370156758031644,
           28.03871490683819,
           27.70727305564474,
           27.375831204451288,
           27.044389353257852,
           26.712947502064402,
           26.38150565087095,
           26.050063799677513,
           25.767506497943756,
           25.50939147093988,
           25.251276443935993,
           24.993161416932107,
           24.73504638992823,
           24.476931362924333,
           24.218816335920458,
           23.96070130891657,
           23.702586281912687,
           23.44447125490881,
           23.18635622790491,
           22.928241200901034,
           22.670126173897145,
           22.412011146893256,
           22.15389611988938,
           21.895781092885493,
           21.63766606588161,
           21.37955103887772,
           21.121436011873836,
           20.86332098486996,
           20.60520595786607,
           20.347090930862187,
           20.091379793987475,
           19.83711098742864,
           19.58284218086983,
           19.328573374311002,
           19.07430456775218,
           18.820035761193367,
           18.565766954634533,
           18.31149814807572,
           18.057229341516894,
           17.802960534958075,
           17.548691728399263,
           17.294422921840436,
           17.040154115281616,
           16.78588530872279,
           16.53161650216397,
           16.277347695605158,
           16.02307888904633,
           15.768810082487509,
           15.514541275928698,
           15.260272469369871,
           15.006003662811048,
           14.75775747565895,
           14.512872753304606,
           14.267988030950265,
           14.023103308595934,
           13.778218586241593,
           13.533333863887247,
           13.288449141532908,
           13.043564419178566,
           12.798679696824234,
           12.553794974469891,
           12.31184761190061,
           12.074625567843771,
           11.837403523786945,
           11.600181479730109,
           11.362959435673268,
           11.125737391616433,
           10.892961894393466,
           10.670518078071488,
           10.4480742617495,
           10.225630445427516,
           10.008241754410037,
           9.80413118894855,
           9.60002062348705,
           9.40042467985182,
           9.20719024987708,
           9.01916197426774,
           8.844690319320065,
           8.684540115603504,
           8.53911215228598,
           8.411908443516008,
           8.3057597253912,
           8.218538267947439,
           8.13609114341608,
           8.053644018884723,
           7.971196894353373,
           7.888749769822015,
           7.806302645290657,
           7.723855520759306,
           7.641408396227956,
           7.558961271696599,
           7.476514147165249,
           7.394067022633884,
           7.311619898102533,
           7.229172773571182,
           7.146725649039817,
           7.064278524508467,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           53.82182271365082,
           53.8185453206561,
           53.81526792766138,
           53.81199053466666,
           53.80871314167195,
           53.80543574867723,
           53.80215835568251,
           53.79888096268779,
           53.795603569693085,
           53.79232617669837,
           53.78904878370365,
           53.78577139070893,
           53.78249399771421,
           53.779216604719494,
           53.775939211724776,
           53.77266181873007,
           53.769384425735346,
           53.766107032740635,
           53.76282963974592,
           53.7595522467512,
           53.75627485375648,
           53.75299746076176,
           53.74972006776705,
           53.74644267477233,
           53.74316528177762,
           53.7398878887829,
           53.736610495788184,
           53.733333102793466,
           53.73005570979875,
           53.72677831680403,
           53.72350092380931,
           53.72022353081461,
           53.716946137819875,
           53.71366874482517,
           53.71039135183045,
           53.707113958835734,
           53.703836565841016,
           53.7005591728463,
           53.697281779851586,
           53.69400438685687,
           53.69072699386215,
           53.68744960086743,
           53.68417220787271,
           53.680894814878,
           53.677617421883284,
           53.67434002888857,
           53.67106263589385,
           53.667785242899136,
           53.66450784990442,
           53.6612304569097,
           53.65795306391498,
           53.65467567092026,
           53.65139827792555,
           53.64812088493083,
           53.64484349193612,
           53.6415660989414,
           53.638288705946685,
           53.63501131295196,
           53.633985425214824,
           53.63521105475248,
           53.63643668429011,
           53.63766231382776,
           53.63888794336539,
           53.64011357290303,
           53.64133920244068,
           53.642564831978326,
           53.64379046151597,
           53.64501609105361,
           53.64624172059125,
           53.64746735012889,
           53.648692979666535,
           53.64991860920418,
           53.65114423874182,
           53.652369868279465,
           53.65359549781711,
           53.65482112735475,
           53.656046756892394,
           53.65727238643004,
           53.65849801596767,
           53.659723645505316,
           53.66094927504296,
           53.662174904580596,
           53.66340053411824,
           53.66462616365588,
           53.37849588725358,
           53.03489442966326,
           52.69129297207298,
           52.34769151448268,
           52.00409005689239,
           51.660488599302106,
           51.31688714171181,
           50.97328568412151,
           50.62968422653121,
           50.286082768940915,
           49.942481311350626,
           49.59887985376034,
           49.255278396170034,
           48.91167693857973,
           48.568075480989435,
           48.224474023399154,
           47.88087256580886,
           47.537271108218555,
           47.193669650628266,
           46.85006819303797,
           46.50646673544768,
           46.162865277857385,
           45.81926382026709,
           45.47566236267681,
           45.1320609050865,
           44.78845944749621,
           44.44485798990591,
           44.10125653231561,
           43.757655074725335,
           43.41405361713502,
           43.070452159544736,
           42.72685070195444,
           42.38324924436414,
           42.039647786773855,
           41.69604632918356,
           41.35244487159326,
           41.00884341400296,
           40.665241956412665,
           40.32164049882238,
           39.97803904123209,
           39.634437583641784,
           39.2908361260515,
           38.94723466846119,
           38.60363321087091,
           38.260031753280614,
           37.91643029569032,
           37.57282883810003,
           37.22922738050971,
           36.88562592291943,
           36.542024465329135,
           36.19842300773884,
           35.85482155014856,
           35.51122009255826,
           35.16761863496796,
           34.82401717737766,
           34.480415719787366,
           34.136814262197085,
           33.79726599051393,
           33.465824139320475,
           33.13438228812704,
           32.80294043693357,
           32.471498585740136,
           32.14005673454668,
           31.808614883353233,
           31.477173032159797,
           31.14573118096633,
           30.81428932977289,
           30.482847478579444,
           30.151405627385984,
           29.81996377619255,
           29.48852192499908,
           29.157080073805645,
           28.825638222612195,
           28.494196371418745,
           28.162754520225306,
           27.83131266903186,
           27.499870817838406,
           27.168428966644953,
           26.836987115451503,
           26.505545264258068,
           26.174103413064614,
           25.84266156187116,
           25.51121971067773,
           25.22866240894397,
           24.970547381940097,
           24.712432354936208,
           24.45431732793232,
           24.196202300928444,
           23.93808727392455,
           23.679972246920673,
           23.421857219916784,
           23.1637421929129,
           22.905627165909024,
           22.64751213890512,
           22.38939711190125,
           22.13128208489736,
           21.874128615687475,
           21.619859809128666,
           21.365591002569843,
           21.11132219601102,
           20.857053389452194,
           20.60278458289337,
           20.348515776334562,
           20.094246969775735,
           19.839978163216916,
           19.585709356658104,
           19.331440550099266,
           19.077171743540454,
           18.822902936981627,
           18.568634130422808,
           18.314365323863996,
           18.060096517305162,
           17.80582771074635,
           17.551558904187523,
           17.297290097628704,
           17.04302129106989,
           16.788752484511065,
           16.53448367795224,
           16.28021487139342,
           16.025946064834596,
           15.774548505867434,
           15.52966378351309,
           15.284779061158751,
           15.03989433880442,
           14.795009616450074,
           14.550124894095735,
           14.305240171741394,
           14.06035544938705,
           13.815470727032709,
           13.570586004678376,
           13.325701282324037,
           13.08081655996969,
           12.84052944433256,
           12.603307400275723,
           12.366085356218896,
           12.128863312162057,
           11.891641268105221,
           11.654419224048382,
           11.417197179991556,
           11.189718304274871,
           10.967274487952885,
           10.744830671630897,
           10.522386855308913,
           10.30115626994883,
           10.097045704487332,
           9.892935139025834,
           9.688824573564334,
           9.49343543698768,
           9.300201007012937,
           9.113770660011621,
           8.939299005063935,
           8.77570939774474,
           8.624355045798247,
           8.492228531861137,
           8.374858929917357,
           8.276002002877524,
           8.191764503504027,
           8.10931737897267,
           8.026870254441311,
           7.9444231299099535,
           7.8619760053786045,
           7.779528880847247,
           7.697081756315889,
           7.614634631784538,
           7.5321875072531865,
           7.44974038272183,
           7.367293258190481,
           7.284846133659114,
           7.202399009127764,
           7.119951884596414,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           53.55791200473225,
           53.554634611737534,
           53.551357218742815,
           53.548079825748104,
           53.544802432753386,
           53.541525039758675,
           53.53824764676395,
           53.53497025376923,
           53.53169286077452,
           53.5284154677798,
           53.52513807478509,
           53.52186068179037,
           53.518583288795654,
           53.51530589580094,
           53.512028502806224,
           53.508751109811506,
           53.50547371681678,
           53.50219632382207,
           53.49891893082735,
           53.49564153783264,
           53.49236414483792,
           53.4890867518432,
           53.48580935884849,
           53.48253196585377,
           53.479254572859055,
           53.47597717986433,
           53.47269978686962,
           53.46942239387491,
           53.46614500088018,
           53.46286760788547,
           53.45959021489075,
           53.456312821896034,
           53.45303542890132,
           53.449758035906605,
           53.44648064291189,
           53.44320324991717,
           53.43992585692246,
           53.43664846392774,
           53.43337107093302,
           53.4300936779383,
           53.426816284943584,
           53.423538891948866,
           53.420261498954154,
           53.416984105959436,
           53.413706712964725,
           53.41042931997001,
           53.40715192697529,
           53.40387453398057,
           53.40059714098585,
           53.39731974799114,
           53.394042354996415,
           53.390764962001704,
           53.387487569006986,
           53.384210176012274,
           53.380932783017556,
           53.37765539002284,
           53.37437799702812,
           53.3711006040334,
           53.36782321103868,
           53.36454581804397,
           53.36126842504925,
           53.35799103205454,
           53.354713639059824,
           53.351436246065106,
           53.34815885307039,
           53.34488146007567,
           53.34160406708095,
           53.33832667408624,
           53.33504928109152,
           53.3317718880968,
           53.32849449510209,
           53.32521710210737,
           53.321939709112655,
           53.31866231611794,
           53.31538492312322,
           53.31661054590926,
           53.31783617544691,
           53.31906180498455,
           53.32028743452219,
           53.321513064059836,
           53.32273869359747,
           53.323964323135115,
           53.32518995267276,
           53.3264155822104,
           53.0402853058081,
           52.69668384821779,
           52.353082390627506,
           52.0094809330372,
           51.66587947544691,
           51.322278017856625,
           50.97867656026632,
           50.635075102676026,
           50.29147364508573,
           49.947872187495435,
           49.60427072990515,
           49.26066927231485,
           48.91706781472455,
           48.57346635713425,
           48.229864899543955,
           47.88626344195367,
           47.54266198436338,
           47.19906052677308,
           46.85545906918278,
           46.51185761159248,
           46.1682561540022,
           45.824654696411905,
           45.48105323882161,
           45.13745178123133,
           44.79385032364101,
           44.45024886605072,
           44.106647408460425,
           43.76304595087013,
           43.41944449327985,
           43.07584303568954,
           42.732241578099256,
           42.38864012050895,
           42.04503866291866,
           41.701437205328375,
           41.35783574773807,
           41.014234290147776,
           40.67063283255747,
           40.32703137496718,
           39.983429917376895,
           39.6398284597866,
           39.296227002196304,
           38.95262554460602,
           38.609024087015705,
           38.26542262942542,
           37.92182117183513,
           37.57821971424483,
           37.23461825665455,
           36.89101679906423,
           36.54741534147395,
           36.203813883883655,
           35.86021242629336,
           35.51661096870308,
           35.17300951111278,
           34.82940805352248,
           34.48580659593218,
           34.14220513834188,
           33.7986036807516,
           33.4550022231613,
           33.111400765571005,
           32.767799307980724,
           32.42419785039041,
           32.080596392800125,
           31.73699493520983,
           31.39339347761953,
           31.049792020029248,
           30.706190562438934,
           30.362589104848652,
           30.018987647258356,
           29.67538618966806,
           29.33178473207777,
           28.98818327448746,
           28.64458181689718,
           28.300980359306884,
           27.95737890171658,
           27.62391043122552,
           27.29246858003207,
           26.96102672883862,
           26.629584877645165,
           26.298143026451715,
           25.96670117525828,
           25.635259324064826,
           25.303817472871376,
           24.97237562167794,
           24.689818319944184,
           24.43170329294031,
           24.173588265936424,
           23.915473238932538,
           23.65735821192866,
           23.402608630828666,
           23.148339824269854,
           22.894071017711035,
           22.63980221115221,
           22.3855334045934,
           22.131264598034562,
           21.87699579147575,
           21.62272698491693,
           21.368458178358104,
           21.11418937179929,
           20.85992056524047,
           20.605651758681645,
           20.351382952122822,
           20.097114145564,
           19.842845339005187,
           19.58857653244636,
           19.33430772588754,
           19.08003891932873,
           18.825770112769895,
           18.57150130621108,
           18.317232499652256,
           18.062963693093433,
           17.808694886534624,
           17.554426079975787,
           17.300157273416975,
           17.045888466858152,
           16.79161966029933,
           16.546454813721578,
           16.301570091367232,
           16.056685369012897,
           15.81180064665855,
           15.566915924304208,
           15.322031201949878,
           15.077146479595534,
           14.832261757241195,
           14.587377034886863,
           14.342492312532517,
           14.097607590178178,
           13.852722867823838,
           13.607838145469493,
           13.36921127676451,
           13.131989232707685,
           12.894767188650846,
           12.657545144594005,
           12.42032310053717,
           12.183101056480334,
           11.945879012423507,
           11.708918530478254,
           11.486474714156268,
           11.264030897834278,
           11.041587081512304,
           10.819143265190316,
           10.596699448868332,
           10.389960220026115,
           10.185849654564617,
           9.98173908910313,
           9.77968062409827,
           9.586446194123528,
           9.393211764148786,
           9.208379345755498,
           9.033907690807814,
           8.866878679885982,
           8.715524327939482,
           8.57668124061884,
           8.449936711830176,
           8.339433653948149,
           8.247437863591973,
           8.164990739060617,
           8.082543614529266,
           8.000096489997908,
           7.917649365466549,
           7.8352022409351925,
           7.752755116403843,
           7.670307991872486,
           7.587860867341127,
           7.505413742809777,
           7.4229666182784255,
           7.340519493747069,
           7.258072369215719,
           7.175625244684353,
           7.093178120153002,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           53.29073004408654,
           53.28745265109182,
           53.2841752580971,
           53.28089786510238,
           53.27762047210767,
           53.27434307911295,
           53.271065686118234,
           53.267788293123516,
           53.264510900128805,
           53.26123350713409,
           53.25795611413937,
           53.25467872114465,
           53.25140132814994,
           53.24812393515522,
           53.2448465421605,
           53.24156914916579,
           53.23829175617107,
           53.235014363176354,
           53.231736970181636,
           53.22845957718692,
           53.22518218419221,
           53.22190479119749,
           53.21862739820277,
           53.21535000520806,
           53.21207261221333,
           53.20879521921862,
           53.205517826223904,
           53.20224043322918,
           53.198963040234474,
           53.19568564723975,
           53.19240825424504,
           53.18913086125033,
           53.1858534682556,
           53.18257607526089,
           53.17929868226617,
           53.17602128927146,
           53.17274389627674,
           53.16946650328202,
           53.16618911028731,
           53.16291171729259,
           53.15963432429787,
           53.15635693130315,
           53.15307953830843,
           53.14980214531373,
           53.14652475231901,
           53.14324735932429,
           53.13996996632957,
           53.136692573334855,
           53.13341518034014,
           53.13013778734542,
           53.12686039435071,
           53.123583001355996,
           53.12030560836128,
           53.11702821536656,
           53.11375082237184,
           53.11047342937712,
           53.107196036382405,
           53.103918643387686,
           53.100641250392975,
           53.097363857398264,
           53.094086464403546,
           53.09080907140883,
           53.08753167841411,
           53.08425428541939,
           53.08097689242467,
           53.077699499429954,
           53.07442210643524,
           53.07114471344053,
           53.067867320445814,
           53.064589927451095,
           53.06131253445638,
           53.05803514146166,
           53.05475774846694,
           53.05148035547222,
           53.048202962477504,
           53.0449255694828,
           53.0407413399399,
           53.03202297168541,
           53.02330460343092,
           53.01458623517643,
           53.00586786692194,
           52.997149498667454,
           52.988431130412955,
           52.97971276215847,
           52.68462094422613,
           52.3322544363582,
           51.9798879284903,
           51.62752142062239,
           51.27515491275447,
           50.922788404886575,
           50.57042189701866,
           50.22243790246818,
           49.878836444877884,
           49.53523498728758,
           49.1916335296973,
           48.848032072106996,
           48.5044306145167,
           48.160829156926404,
           47.81722769933611,
           47.473626241745826,
           47.13002478415553,
           46.78642332656523,
           46.44282186897493,
           46.099220411384636,
           45.755618953794354,
           45.41201749620406,
           45.068416038613755,
           44.72481458102347,
           44.38121312343316,
           44.03761166584288,
           43.69401020825258,
           43.35040875066228,
           43.006807293072,
           42.66320583548168,
           42.3196043778914,
           41.976002920301106,
           41.63240146271081,
           41.28880000512052,
           40.945198547530225,
           40.60159708993993,
           40.25799563234963,
           39.91439417475933,
           39.57079271716905,
           39.22719125957875,
           38.88358980198846,
           38.539988344398175,
           38.19638688680786,
           37.852785429217576,
           37.50918397162728,
           37.165582514036984,
           36.8219810564467,
           36.478379598856385,
           36.1347781412661,
           35.79117668367581,
           35.447575226085505,
           35.10397376849522,
           34.76037231090493,
           34.41677085331463,
           34.073169395724335,
           33.72956793813404,
           33.38596648054375,
           33.042365022953454,
           32.69876356536315,
           32.35516210777287,
           32.01156065018256,
           31.667959192592274,
           31.32435773500198,
           30.980756277411682,
           30.6371548198214,
           30.293553362231087,
           29.949951904640805,
           29.606350447050502,
           29.262748989460206,
           28.919147531869925,
           28.575546074279615,
           28.231944616689333,
           27.88834315909903,
           27.544741701508734,
           27.201140243918452,
           26.857538786328153,
           26.513937328737853,
           26.170335871147557,
           25.82673441355726,
           25.48313295596698,
           25.139531498376677,
           24.79593004078638,
           24.4523285831961,
           24.16828222629344,
           23.91401341973463,
           23.659744613175803,
           23.40547580661698,
           23.151207000058168,
           22.896938193499334,
           22.642669386940522,
           22.3884005803817,
           22.134131773822876,
           21.87986296726406,
           21.625594160705226,
           21.371325354146414,
           21.117056547587595,
           20.862787741028768,
           20.608518934469956,
           20.354250127911136,
           20.09998132135231,
           19.84571251479349,
           19.591443708234664,
           19.33717490167585,
           19.082906095117025,
           18.828637288558205,
           18.574368481999393,
           18.320099675440556,
           18.065830868881747,
           17.81156206232292,
           17.563245843930083,
           17.318361121575755,
           17.0734763992214,
           16.828591676867074,
           16.583706954512728,
           16.338822232158385,
           16.093937509804054,
           15.849052787449711,
           15.604168065095372,
           15.35928334274103,
           15.114398620386687,
           14.869513898032357,
           14.624629175678013,
           14.379744453323674,
           14.135115153253341,
           13.897893109196506,
           13.660671065139667,
           13.423449021082828,
           13.186226977025989,
           12.949004932969153,
           12.711782888912328,
           12.474560844855487,
           12.23733880079865,
           12.005674940359675,
           11.783231124037691,
           11.560787307715714,
           11.33834349139373,
           11.115899675071743,
           10.893455858749753,
           10.682874735564933,
           10.478764170103435,
           10.274653604641935,
           10.070543039180437,
           9.87269138123414,
           9.679456951259407,
           9.486222521284667,
           9.302988031499389,
           9.128516376551703,
           8.95804796202724,
           8.806693610080742,
           8.66113394937656,
           8.529797620194008,
           8.412887198231529,
           8.309675931434484,
           8.220664099148571,
           8.138216974617213,
           8.055769850085856,
           7.973322725554504,
           7.890875601023147,
           7.80842847649179,
           7.725981351960432,
           7.6435342274290825,
           7.561087102897725,
           7.478639978366367,
           7.396192853835017,
           7.313745729303665,
           7.231298604772308,
           7.148851480240957,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           53.01945902037871,
           53.016181627384,
           53.01290423438928,
           53.009626841394564,
           53.00634944839985,
           53.003072055405134,
           52.999794662410416,
           52.9965172694157,
           52.99323987642098,
           52.98996248342627,
           52.98668509043155,
           52.98340769743683,
           52.98013030444211,
           52.9768529114474,
           52.973575518452684,
           52.970298125457965,
           52.96702073246325,
           52.963743339468536,
           52.96046594647382,
           52.9571885534791,
           52.95391116048438,
           52.95063376748966,
           52.947356374494944,
           52.94407898150023,
           52.940801588505515,
           52.937524195510804,
           52.934246802516085,
           52.93096940952137,
           52.92769201652665,
           52.92441462353193,
           52.92113723053721,
           52.9178598375425,
           52.914582444547776,
           52.91130505155307,
           52.90802765855835,
           52.904750265563635,
           52.901472872568924,
           52.8981954795742,
           52.89491808657949,
           52.89164069358477,
           52.88836330059006,
           52.88508590759534,
           52.88180851460062,
           52.8785311216059,
           52.875253728611185,
           52.871976335616466,
           52.86869894262175,
           52.86542154962704,
           52.86214415663232,
           52.85886676363761,
           52.85558937064289,
           52.85231197764817,
           52.84903458465345,
           52.845757191658734,
           52.842479798664016,
           52.8392024056693,
           52.83592501267458,
           52.83264761967986,
           52.82937022668515,
           52.82609283369044,
           52.81918811948416,
           52.81046975122968,
           52.80175138297518,
           52.7930330147207,
           52.78431464646621,
           52.775596278211715,
           52.76687790995723,
           52.75815954170274,
           52.749441173448254,
           52.74072280519376,
           52.73200443693927,
           52.723286068684786,
           52.714567700430294,
           52.7058493321758,
           52.69713096392131,
           52.68841259566682,
           52.679694227412334,
           52.67097585915784,
           52.66225749090336,
           52.653539122648866,
           52.644820754394374,
           52.63610238613988,
           52.62738401788539,
           52.61866564963091,
           52.32357383169857,
           51.97120732383063,
           51.618840815962734,
           51.26647430809482,
           50.91410780022691,
           50.56174129235901,
           50.2093747844911,
           49.857008276623176,
           49.50464176875526,
           49.15227526088736,
           48.79990875301946,
           48.447542245151546,
           48.095175737283625,
           47.74280922941571,
           47.3904427215478,
           47.0380762136799,
           46.68570970581199,
           46.333343197944075,
           45.98097669007616,
           45.62861018220825,
           45.27624367434036,
           44.92387716647244,
           44.571510658604524,
           44.219144150736625,
           43.875542686103785,
           43.53194122851351,
           43.18833977092321,
           42.844738313332904,
           42.50113685574263,
           42.157535398152305,
           41.81393394056203,
           41.47033248297173,
           41.12673102538144,
           40.78312956779115,
           40.439528110200854,
           40.09592665261056,
           39.75232519502026,
           39.40872373742996,
           39.06512227983967,
           38.72152082224938,
           38.37791936465908,
           38.034317907068804,
           37.69071644947849,
           37.347114991888205,
           37.00351353429791,
           36.659912076707606,
           36.316310619117324,
           35.972709161527014,
           35.62910770393673,
           35.28550624634643,
           34.94190478875613,
           34.59830333116585,
           34.254701873575556,
           33.91110041598526,
           33.56749895839496,
           33.22389750080466,
           32.88029604321438,
           32.536694585624076,
           32.19309312803378,
           31.8494916704435,
           31.50589021285319,
           31.162288755262907,
           30.81868729767261,
           30.47508584008231,
           30.13148438249203,
           29.787882924901716,
           29.444281467311434,
           29.10068000972113,
           28.757078552130835,
           28.413477094540553,
           28.06987563695024,
           27.726274179359958,
           27.38267272176966,
           27.039071264179363,
           26.69546980658908,
           26.351868348998778,
           26.008266891408482,
           25.664665433818186,
           25.321063976227887,
           24.977462518637605,
           24.63386106104731,
           24.29025960345701,
           23.946658145866728,
           23.662611788964064,
           23.408342982405255,
           23.154074175846432,
           22.899805369287606,
           22.645536562728793,
           22.39126775616996,
           22.136998949611147,
           21.882730143052324,
           21.6284613364935,
           21.37419252993469,
           21.119923723375855,
           20.865654916817043,
           20.61138611025822,
           20.357117303699397,
           20.102848497140585,
           19.84857969058176,
           19.59431088402294,
           19.340042077464112,
           19.08577327090529,
           18.83150446434648,
           18.58003687413857,
           18.335152151784225,
           18.090267429429893,
           17.84538270707554,
           17.600497984721216,
           17.35561326236687,
           17.11072854001253,
           16.8658438176582,
           16.62095909530384,
           16.376074372949518,
           16.13118965059517,
           15.886304928240829,
           15.641420205886497,
           15.396535483532155,
           15.151650761177816,
           14.906766038823474,
           14.663796985685282,
           14.426574941628456,
           14.18935289757162,
           13.952130853514777,
           13.714908809457953,
           13.477686765401113,
           13.240464721344278,
           13.003242677287439,
           12.7660206332306,
           12.528798589173764,
           12.302431350241083,
           12.079987533919098,
           11.857543717597114,
           11.635099901275122,
           11.412656084953138,
           11.19021226863116,
           10.975789251103716,
           10.771678685642218,
           10.567568120180722,
           10.363457554719233,
           10.159346989257735,
           9.96570213837,
           9.772467708395258,
           9.579233278420514,
           9.397596717243268,
           9.223125062295583,
           9.049217244168478,
           8.897862892221978,
           8.746508540275485,
           8.614250328951716,
           8.48796498014435,
           8.375837684632875,
           8.279918208920805,
           8.19389033470516,
           8.111443210173801,
           8.028996085642444,
           7.9465489611110876,
           7.864101836579736,
           7.78165471204838,
           7.699207587517021,
           7.616760462985664,
           7.5343133384543135,
           7.451866213922956,
           7.369419089391599,
           7.286971964860247,
           7.204524840328897,
           7.1220777157975395,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           52.74818799667089,
           52.744910603676175,
           52.74163321068146,
           52.73835581768674,
           52.735078424692034,
           52.731801031697316,
           52.72852363870259,
           52.72524624570788,
           52.72196885271316,
           52.71869145971844,
           52.71541406672373,
           52.712136673729006,
           52.708859280734295,
           52.705581887739584,
           52.702304494744865,
           52.69902710175015,
           52.69574970875543,
           52.69247231576072,
           52.689194922766,
           52.68591752977128,
           52.68264013677656,
           52.679362743781844,
           52.67608535078713,
           52.672807957792415,
           52.6695305647977,
           52.66625317180298,
           52.66297577880827,
           52.65969838581354,
           52.65642099281883,
           52.65314359982411,
           52.649866206829394,
           52.64658881383469,
           52.64331142083996,
           52.64003402784525,
           52.63675663485053,
           52.63347924185582,
           52.6302018488611,
           52.62692445586637,
           52.62364706287167,
           52.62036966987694,
           52.61709227688223,
           52.613814883887514,
           52.610537490892796,
           52.60635326728293,
           52.597634899028435,
           52.58891653077394,
           52.58019816251945,
           52.57147979426496,
           52.562761426010475,
           52.55404305775599,
           52.54532468950149,
           52.536606321247014,
           52.527887952992515,
           52.51916958473803,
           52.510451216483546,
           52.50173284822905,
           52.49301447997456,
           52.48429611172007,
           52.47557774346558,
           52.466859375211094,
           52.458141006956595,
           52.44942263870212,
           52.44070427044762,
           52.431985902193134,
           52.42326753393864,
           52.41454916568415,
           52.40583079742967,
           52.39711242917517,
           52.38839406092069,
           52.3796756926662,
           52.370957324411705,
           52.36223895615722,
           52.35352058790273,
           52.344802219648244,
           52.33608385139375,
           52.32736548313926,
           52.31864711488477,
           52.30992874663028,
           52.301210378375785,
           52.2924920101213,
           52.283773641866816,
           52.275055273612324,
           52.26633690535783,
           52.25761853710334,
           51.962526719171,
           51.61016021130307,
           51.257793703435176,
           50.90542719556726,
           50.55306068769935,
           50.20069417983145,
           49.84832767196354,
           49.49596116409562,
           49.143594656227705,
           48.79122814835979,
           48.43886164049189,
           48.08649513262398,
           47.73412862475606,
           47.38176211688815,
           47.029395609020234,
           46.677029101152335,
           46.32466259328443,
           45.97229608541651,
           45.619929577548604,
           45.26756306968069,
           44.91519656181279,
           44.56283005394487,
           44.21046354607696,
           43.85809703820906,
           43.50573053034113,
           43.153364022473234,
           42.800997514605314,
           42.44863100673741,
           42.09626449886951,
           41.74389799100158,
           41.391531483133676,
           41.03916497526576,
           40.68679846739785,
           40.33443195952995,
           39.98206545166204,
           39.629698943794125,
           39.27733243592621,
           38.9249659280583,
           38.5725994201904,
           38.22023291232249,
           37.872248927329714,
           37.52864746973943,
           37.185046012149115,
           36.84144455455883,
           36.49784309696854,
           36.154241639378235,
           35.81064018178795,
           35.46703872419764,
           35.12343726660736,
           34.77983580901706,
           34.43623435142676,
           34.09263289383648,
           33.749031436246185,
           33.40542997865588,
           33.061828521065586,
           32.71822706347529,
           32.37462560588501,
           32.031024148294705,
           31.68742269070441,
           31.343821233114127,
           31.000219775523814,
           30.656618317933532,
           30.313016860343236,
           29.969415402752936,
           29.625813945162655,
           29.28221248757234,
           28.93861102998206,
           28.59500957239176,
           28.25140811480146,
           27.907806657211175,
           27.564205199620865,
           27.220603742030583,
           26.877002284440287,
           26.53340082684999,
           26.18979936925971,
           25.846197911669407,
           25.50259645407911,
           25.15899499648881,
           24.815393538898512,
           24.47179208130823,
           24.128190623717934,
           23.78458916612764,
           23.440987708537357,
           23.156941351634693,
           22.90267254507588,
           22.648403738517057,
           22.394134931958234,
           22.139866125399422,
           21.885597318840585,
           21.631328512281776,
           21.37705970572295,
           21.12279089916413,
           20.868522092605318,
           20.614253286046484,
           20.359984479487668,
           20.105715672928845,
           19.851446866370022,
           19.59717805981121,
           19.351943181992716,
           19.107058459638374,
           18.862173737284028,
           18.617289014929685,
           18.372404292575357,
           18.127519570221015,
           17.88263484786667,
           17.637750125512337,
           17.392865403157984,
           17.147980680803656,
           16.903095958449313,
           16.65821123609497,
           16.413326513740643,
           16.168441791386282,
           15.923557069031961,
           15.678672346677615,
           15.433787624323273,
           15.192478818117243,
           14.955256774060405,
           14.718034730003568,
           14.480812685946727,
           14.243590641889895,
           14.006368597833065,
           13.769146553776231,
           13.531924509719389,
           13.294702465662564,
           13.057480421605725,
           12.821631576444464,
           12.599187760122481,
           12.376743943800493,
           12.154300127478507,
           11.931856311156528,
           11.709412494834545,
           11.48696867851256,
           11.2687037666425,
           11.064593201181001,
           10.860482635719512,
           10.656372070258014,
           10.452261504796517,
           10.25194732548059,
           10.058712895505858,
           9.865478465531115,
           9.672244035556373,
           9.492205402987139,
           9.317733748039453,
           9.143262093091776,
           8.98903217436322,
           8.83767782241672,
           8.698703037709416,
           8.567366708526874,
           8.450915466545696,
           8.34334985999143,
           8.250160486407129,
           8.16711657026174,
           8.084669445730391,
           8.002222321199033,
           7.919775196667676,
           7.837328072136318,
           7.754880947604967,
           7.67243382307361,
           7.589986698542252,
           7.507539574010895,
           7.4250924494795445,
           7.342645324948188,
           7.26019820041683,
           7.17775107588548,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           52.476916972963096,
           52.47363957996838,
           52.47036218697365,
           52.467084793978934,
           52.46380740098422,
           52.46053000798951,
           52.45725261499479,
           52.453975222000075,
           52.450697829005364,
           52.447420436010646,
           52.44414304301593,
           52.4408656500212,
           52.43758825702649,
           52.43431086403178,
           52.43103347103706,
           52.42775607804234,
           52.424478685047625,
           52.42120129205291,
           52.417923899058195,
           52.414646506063484,
           52.41136911306876,
           52.40809172007404,
           52.40481432707932,
           52.40153693408461,
           52.398259541089885,
           52.394982148095174,
           52.39170475510047,
           52.384800046827216,
           52.37608167857274,
           52.36736331031825,
           52.358644942063755,
           52.34992657380926,
           52.34120820555477,
           52.332489837300294,
           52.3237714690458,
           52.31505310079131,
           52.30633473253681,
           52.29761636428233,
           52.28889799602784,
           52.28017962777335,
           52.27146125951886,
           52.26274289126437,
           52.25402452300988,
           52.2453061547554,
           52.236587786500905,
           52.227869418246414,
           52.21915104999192,
           52.21043268173742,
           52.20171431348294,
           52.19299594522846,
           52.18427757697396,
           52.17555920871948,
           52.16684084046498,
           52.15812247221049,
           52.149404103956016,
           52.14068573570151,
           52.131967367447025,
           52.123248999192526,
           52.11453063093804,
           52.10581226268356,
           52.097093894429065,
           52.08837552617458,
           52.07965715792009,
           52.07093878966559,
           52.06222042141111,
           52.05350205315662,
           52.04478368490213,
           52.036065316647644,
           52.027346948393145,
           52.01862858013867,
           52.009910211884176,
           52.001191843629684,
           51.9924734753752,
           51.9837551071207,
           51.97503673886622,
           51.966318370611724,
           51.95760000235723,
           51.94888163410275,
           51.940163265848255,
           51.931444897593764,
           51.92272652933927,
           51.91400816108478,
           51.9052897928303,
           51.896571424575804,
           51.601479606643466,
           51.24911309877553,
           50.89674659090764,
           50.544380083039734,
           50.192013575171806,
           49.83964706730391,
           49.487280559436,
           49.134914051568074,
           48.782547543700176,
           48.430181035832256,
           48.07781452796436,
           47.725448020096444,
           47.37308151222853,
           47.02071500436062,
           46.668348496492705,
           46.315981988624806,
           45.963615480756886,
           45.61124897288898,
           45.25888246502107,
           44.90651595715315,
           44.55414944928525,
           44.20178294141735,
           43.84941643354943,
           43.49704992568153,
           43.144683417813596,
           42.7923169099457,
           42.439950402077784,
           42.08758389420987,
           41.73521738634197,
           41.38285087847404,
           41.030484370606146,
           40.67811786273823,
           40.32575135487032,
           39.97338484700242,
           39.62101833913451,
           39.268651831266595,
           38.91628532339868,
           38.56391881553076,
           38.21155230766286,
           37.85918579979495,
           37.50681929192703,
           37.154452784059146,
           36.80208627619121,
           36.44971976832331,
           36.09735326045539,
           35.74498675258749,
           35.39262024471959,
           35.04025373685165,
           34.68788722898376,
           34.33552072111584,
           33.983154213247936,
           33.63078770538004,
           33.27842119751212,
           32.92605468964421,
           32.57368818177629,
           32.22132167390838,
           31.868955168555672,
           31.52535371096537,
           31.18175225337507,
           30.838150795784788,
           30.494549338194478,
           30.150947880604196,
           29.807346423013897,
           29.4637449654236,
           29.12014350783332,
           28.776542050243005,
           28.432940592652724,
           28.089339135062424,
           27.745737677472125,
           27.402136219881843,
           27.05853476229153,
           26.714933304701248,
           26.371331847110948,
           26.027730389520652,
           25.68412893193037,
           25.34052747434007,
           24.996926016749775,
           24.65332455915948,
           24.309723101569176,
           23.966121643978894,
           23.6225201863886,
           23.2789187287983,
           22.935317271208017,
           22.651270914305357,
           22.397002107746548,
           22.142733301187718,
           21.8884644946289,
           21.63419568807009,
           21.379926881511253,
           21.12565807495244,
           20.871389268393617,
           20.61712046183479,
           20.36873421220123,
           20.123849489846883,
           19.878964767492548,
           19.634080045138205,
           19.389195322783863,
           19.144310600429534,
           18.8994258780752,
           18.65454115572085,
           18.409656433366507,
           18.164771711012165,
           17.919886988657836,
           17.675002266303494,
           17.430117543949148,
           17.185232821594816,
           16.940348099240463,
           16.695463376886135,
           16.450578654531792,
           16.205693932177454,
           15.960809209823122,
           15.72116065054922,
           15.483938606492384,
           15.246716562435552,
           15.009494518378713,
           14.772272474321888,
           14.535050430265049,
           14.297828386208211,
           14.060606342151372,
           13.823384298094538,
           13.58616225403771,
           13.348940209980874,
           13.118387986325892,
           12.895944170003915,
           12.673500353681927,
           12.45105653735994,
           12.228612721037956,
           12.006168904715969,
           11.783725088393982,
           11.56161828218132,
           11.357507716719821,
           11.153397151258321,
           10.949286585796822,
           10.745176020335325,
           10.541065454873834,
           10.344958082616472,
           10.15172365264173,
           9.958489222666987,
           9.765254792692255,
           9.586814088731037,
           9.412342433783351,
           9.237870778835667,
           9.080201456504472,
           8.928847104557981,
           8.783155746467138,
           8.651819417284589,
           8.525993248458523,
           8.413865952947054,
           8.313592137477764,
           8.22278993034969,
           8.140342805818332,
           8.05789568128698,
           7.975448556755631,
           7.893001432224273,
           7.810554307692915,
           7.7281071831615575,
           7.645660058630208,
           7.56321293409885,
           7.480765809567492,
           7.398318685036135,
           7.3158715605047835,
           7.233424435973427,
           7.15097731144207,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           52.20564594925528,
           52.20236855626056,
           52.199091163265834,
           52.19581377027112,
           52.192536377276404,
           52.18925898428169,
           52.185981591286975,
           52.18270419829226,
           52.179426805297545,
           52.17614941230283,
           52.17196519462598,
           52.16324682637149,
           52.15452845811701,
           52.145810089862515,
           52.13709172160802,
           52.12837335335353,
           52.11965498509905,
           52.110936616844555,
           52.10221824859007,
           52.09349988033558,
           52.084781512081086,
           52.076063143826595,
           52.06734477557211,
           52.05862640731762,
           52.049908039063126,
           52.04118967080864,
           52.03247130255415,
           52.02375293429966,
           52.01503456604517,
           52.00631619779068,
           51.99759782953619,
           51.9888794612817,
           51.980161093027206,
           51.97144272477273,
           51.96272435651824,
           51.954005988263745,
           51.94528762000925,
           51.93656925175476,
           51.92785088350028,
           51.919132515245785,
           51.9104141469913,
           51.90169577873681,
           51.89297741048232,
           51.884259042227825,
           51.87554067397334,
           51.86682230571884,
           51.858103937464364,
           51.849385569209865,
           51.84066720095538,
           51.83194883270089,
           51.8232304644464,
           51.81451209619192,
           51.80579372793741,
           51.79707535968293,
           51.788356991428444,
           51.77963862317395,
           51.77092025491947,
           51.76220188666497,
           51.753483518410484,
           51.744765150156,
           51.7360467819015,
           51.727328413647015,
           51.71861004539252,
           51.70989167713803,
           51.70117330888355,
           51.692454940629055,
           51.68373657237457,
           51.67501820412008,
           51.66629983586559,
           51.6575814676111,
           51.64886309935662,
           51.64014473110212,
           51.63142636284763,
           51.62270799459314,
           51.61398962633865,
           51.60527125808416,
           51.596552889829674,
           51.58783452157518,
           51.5791161533207,
           51.570397785066206,
           51.561679416811714,
           51.55296104855722,
           51.54424268030273,
           51.53552431204824,
           51.24043249411591,
           50.88806598624797,
           50.535699478380074,
           50.18333297051216,
           49.83096646264425,
           49.47859995477635,
           49.12623344690844,
           48.773866939040516,
           48.4215004311726,
           48.0691339233047,
           47.7167674154368,
           47.364400907568886,
           47.012034399700966,
           46.65966789183305,
           46.30730138396514,
           45.95493487609724,
           45.60256836822933,
           45.25020186036141,
           44.8978353524935,
           44.54546884462559,
           44.19310233675769,
           43.84073582888977,
           43.48836932102186,
           43.13600281315396,
           42.78363630528604,
           42.43126979741814,
           42.07890328955022,
           41.726536781682306,
           41.37417027381441,
           41.02180376594649,
           40.66943725807859,
           40.31707075021067,
           39.96470424234275,
           39.612337734474856,
           39.25997122660694,
           38.90760471873903,
           38.55523821087111,
           38.2028717030032,
           37.8505051951353,
           37.498138687267385,
           37.14577217939947,
           36.79340567153158,
           36.441039163663646,
           36.08867265579575,
           35.736306147927834,
           35.38393964005992,
           35.03157313219202,
           34.679206624324095,
           34.3268401164562,
           33.97447360858828,
           33.62210710072036,
           33.269740592852465,
           32.91737408498456,
           32.56500757711664,
           32.212641069248726,
           31.860274561380812,
           31.507908053512917,
           31.155541545645,
           30.803175037777088,
           30.45080852990919,
           30.098442022041258,
           29.746075514173363,
           29.393709006305446,
           29.041342498437533,
           28.688975990569634,
           28.336609482701704,
           27.98424297483381,
           27.631876466965892,
           27.27950995909798,
           26.927143451230084,
           26.574776943362153,
           26.222410435494254,
           25.87004392762634,
           25.52205995219128,
           25.178458494601,
           24.834857037010703,
           24.4912555794204,
           24.147654121830104,
           23.80405266423981,
           23.460451206649523,
           23.116849749059227,
           22.773248291468928,
           22.42964683387865,
           22.145600476975982,
           21.891331670417173,
           21.637062863858347,
           21.385525242409702,
           21.140640520055374,
           20.89575579770102,
           20.650871075346693,
           20.405986352992347,
           20.161101630638008,
           19.916216908283673,
           19.671332185929327,
           19.42644746357499,
           19.18156274122065,
           18.936678018866306,
           18.691793296511978,
           18.44690857415764,
           18.202023851803297,
           17.95713912944895,
           17.71225440709461,
           17.46736968474028,
           17.222484962385938,
           16.977600240031595,
           16.73271551767726,
           16.487830795322907,
           16.249842482981173,
           16.012620438924337,
           15.775398394867503,
           15.538176350810673,
           15.30095430675383,
           15.063732262696995,
           14.826510218640163,
           14.589288174583324,
           14.352066130526499,
           14.114844086469661,
           13.877622042412822,
           13.640399998355983,
           13.415144396207287,
           13.192700579885312,
           12.970256763563325,
           12.74781294724134,
           12.525369130919362,
           12.302925314597374,
           12.080481498275388,
           11.858037681953403,
           11.650422232258604,
           11.446311666797104,
           11.242201101335617,
           11.038090535874117,
           10.83397997041262,
           10.631203269727061,
           10.43796883975232,
           10.244734409777587,
           10.051499979802845,
           9.858265549828102,
           9.681422774474907,
           9.50695111952723,
           9.332479464579546,
           9.171370738645715,
           9.020016386699215,
           8.868662034752717,
           8.736272126042294,
           8.604935796859746,
           8.48894373485987,
           8.377023788548385,
           8.28383441496409,
           8.196016165906277,
           8.113569041374921,
           8.031121916843562,
           7.948674792312212,
           7.866227667780862,
           7.783780543249505,
           7.701333418718146,
           7.6188862941867885,
           7.536439169655439,
           7.453992045124082,
           7.371544920592724,
           7.289097796061366,
           7.206650671530015,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           51.93020650706048,
           51.91493653912366,
           51.89966657118683,
           51.884396603249996,
           51.86912663531317,
           51.85385666737635,
           51.83858669943952,
           51.825500605207566,
           51.816782236953074,
           51.80806386869858,
           51.79934550044409,
           51.7906271321896,
           51.78190876393512,
           51.77319039568063,
           51.76447202742614,
           51.755753659171646,
           51.747035290917154,
           51.73831692266266,
           51.729598554408184,
           51.72088018615369,
           51.7121618178992,
           51.70344344964471,
           51.69472508139022,
           51.686006713135725,
           51.677288344881234,
           51.668569976626756,
           51.659851608372264,
           51.65113324011777,
           51.64241487186328,
           51.63369650360879,
           51.6249781353543,
           51.61625976709982,
           51.60754139884533,
           51.598823030590836,
           51.590104662336344,
           51.58138629408185,
           51.57266792582736,
           51.56394955757287,
           51.55523118931839,
           51.5465128210639,
           51.53779445280941,
           51.529076084554916,
           51.520357716300424,
           51.51163934804593,
           51.502920979791455,
           51.49420261153696,
           51.48548424328247,
           51.47676587502798,
           51.46804750677349,
           51.459329138519,
           51.45061077026451,
           51.441892402010026,
           51.433174033755535,
           51.42445566550104,
           51.41573729724656,
           51.40701892899206,
           51.398300560737574,
           51.38958219248308,
           51.3808638242286,
           51.372145455974106,
           51.363427087719614,
           51.35470871946513,
           51.34599035121063,
           51.337271982956146,
           51.32855361470166,
           51.31983524644717,
           51.31111687819268,
           51.302398509938186,
           51.293680141683694,
           51.28496177342922,
           51.276243405174725,
           51.26752503692023,
           51.25880666866574,
           51.25008830041125,
           51.24136993215676,
           51.232651563902266,
           51.22393319564779,
           51.2152148273933,
           51.206496459138805,
           51.19777809088431,
           51.18905972262982,
           51.180341354375344,
           51.17162298612085,
           51.16290461786636,
           50.86463966628775,
           50.50846539804431,
           50.1522911298009,
           49.79611686155747,
           49.439942593314036,
           49.08376832507063,
           48.72822868770856,
           48.375862179840645,
           48.02349567197274,
           47.671129164104826,
           47.31876265623693,
           46.96639614836901,
           46.614029640501094,
           46.26166313263318,
           45.90929662476527,
           45.55693011689737,
           45.20456360902945,
           44.852197101161536,
           44.49983059329363,
           44.14746408542571,
           43.79509757755782,
           43.442731069689906,
           43.09036456182199,
           42.737998053954094,
           42.38563154608616,
           42.03326503821826,
           41.68089853035035,
           41.328532022482435,
           40.976165514614536,
           40.6237990067466,
           40.27143249887871,
           39.9190659910108,
           39.566699483142884,
           39.214332975274985,
           38.86196646740707,
           38.50959995953916,
           38.157233451671246,
           37.80486694380333,
           37.452500435935434,
           37.10013392806752,
           36.74776742019961,
           36.39540091233171,
           36.043034404463775,
           35.690667896595876,
           35.33830138872797,
           34.98593488086005,
           34.63356837299215,
           34.281201865124224,
           33.928835357256325,
           33.57646884938841,
           33.2241023415205,
           32.8717358336526,
           32.51936932578469,
           32.167002817916774,
           31.814636310048858,
           31.46226980218095,
           31.10990329431305,
           30.757536786445133,
           30.405170278577216,
           30.052803770709318,
           29.70043726284139,
           29.34807075497349,
           28.99570424710558,
           28.643337739237666,
           28.290971231369767,
           27.93860472350184,
           27.58623821563394,
           27.233871707766024,
           26.88150519989811,
           26.529138692030216,
           26.17677218416228,
           25.824405676294386,
           25.47203916842647,
           25.119672660558557,
           24.767306152690658,
           24.414939644822745,
           24.062573136954832,
           23.710206629086915,
           23.357840121219002,
           23.005473613351107,
           22.65310710548319,
           22.300740597615277,
           21.94837408974738,
           21.667662105555166,
           21.42277738320083,
           21.17789266084649,
           20.933007938492146,
           20.688123216137818,
           20.443238493783465,
           20.198353771429137,
           19.953469049074794,
           19.70858432672045,
           19.463699604366116,
           19.21881488201177,
           18.97393015965744,
           18.729045437303093,
           18.48416071494875,
           18.239275992594422,
           17.99439127024008,
           17.749506547885737,
           17.504621825531395,
           17.259737103177052,
           17.01574635946996,
           16.778524315413126,
           16.541302271356287,
           16.304080227299462,
           16.066858183242616,
           15.829636139185787,
           15.592414095128948,
           15.355192051072112,
           15.117970007015284,
           14.880747962958441,
           14.643525918901606,
           14.406303874844774,
           14.169081830787935,
           13.934344622410679,
           13.711900806088694,
           13.489456989766708,
           13.267013173444719,
           13.044569357122732,
           12.822125540800759,
           12.59968172447877,
           12.377237908156786,
           12.154794091834809,
           11.943336747797396,
           11.739226182335896,
           11.5351156168744,
           11.3310050514129,
           11.126894485951402,
           10.922783920489913,
           10.72421402686292,
           10.530979596888178,
           10.337745166913436,
           10.144510736938694,
           9.95127630696396,
           9.776031460218785,
           9.601559805271101,
           9.427088150323415,
           9.26254002078696,
           9.11118566884046,
           8.95983131689396,
           8.820724834799996,
           8.689388505617446,
           8.56402151677269,
           8.451894221261217,
           8.347266066034711,
           8.254076692450411,
           8.169242401462867,
           8.08679527693151,
           8.004348152400151,
           7.9219010278687945,
           7.839453903337443,
           7.757006778806093,
           7.674559654274735,
           7.592112529743378,
           7.50966540521202,
           7.427218280680669,
           7.344771156149313,
           7.262324031617955,
           7.179876907086597,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           51.6486186458068,
           51.633348677869975,
           51.61807870993315,
           51.60280874199631,
           51.58753877405949,
           51.572268806122665,
           51.55699883818584,
           51.54172887024902,
           51.526458902312186,
           51.51118893437536,
           51.49591896643852,
           51.4806489985017,
           51.465379030564876,
           51.45010906262805,
           51.43483909469121,
           51.41956912675439,
           51.404299158817565,
           51.38902919088074,
           51.37375922294391,
           51.358489255007086,
           51.34321928707026,
           51.32794931913343,
           51.3126793511966,
           51.297409383259776,
           51.28759908778798,
           51.27888071953349,
           51.270162351279,
           51.261443983024506,
           51.25272561477003,
           51.24400724651554,
           51.235288878261045,
           51.22657051000655,
           51.21785214175206,
           51.20913377349757,
           51.20041540524309,
           51.191697036988586,
           51.18297866873411,
           51.17426030047962,
           51.165541932225125,
           51.15682356397063,
           51.14810519571614,
           51.139386827461664,
           51.13066845920717,
           51.12195009095268,
           51.11323172269819,
           51.1045133544437,
           51.09579498618921,
           51.08707661793471,
           51.07835824968023,
           51.06963988142574,
           51.060921513171245,
           51.05220314491677,
           51.04348477666226,
           51.034766408407776,
           51.0260480401533,
           51.0173296718988,
           51.008611303644315,
           50.999892935389816,
           50.99117456713533,
           50.98245619888085,
           50.973737830626355,
           50.96501946237187,
           50.95630109411737,
           50.94758272586288,
           50.938864357608395,
           50.9301459893539,
           50.92142762109941,
           50.912709252844934,
           50.90399088459044,
           50.89527251633595,
           50.88655414808146,
           50.87783577982697,
           50.869117411572475,
           50.860399043318,
           50.851680675063506,
           50.842962306809014,
           50.83424393855452,
           50.82552557030003,
           50.81680720204555,
           50.80808883379105,
           50.799370465536555,
           50.79065209728208,
           50.781933729027585,
           50.773215360773094,
           50.47495040919449,
           50.11877614095104,
           49.76260187270764,
           49.40642760446421,
           49.05025333622078,
           48.69407906797737,
           48.337904799733934,
           47.98173053149051,
           47.625556263247084,
           47.269381995003656,
           46.91320772676025,
           46.55703345851682,
           46.20085919027339,
           45.84468492202996,
           45.488510653786534,
           45.13233638554313,
           44.7761621172997,
           44.41998784905626,
           44.063813580812834,
           43.70763931256941,
           43.351465044326,
           42.99529077608257,
           42.63911650783914,
           42.28548075003658,
           41.93311424216864,
           41.58074773430074,
           41.22838122643283,
           40.87601471856492,
           40.52364821069702,
           40.171281702829084,
           39.81891519496119,
           39.46654868709327,
           39.11418217922536,
           38.76181567135747,
           38.409449163489555,
           38.05708265562164,
           37.70471614775372,
           37.35234963988581,
           36.99998313201791,
           36.64761662415,
           36.29525011628208,
           35.942883608414185,
           35.59051710054626,
           35.23815059267836,
           34.885784084810446,
           34.533417576942526,
           34.18105106907463,
           33.8286845612067,
           33.4763180533388,
           33.123951545470895,
           32.771585037602975,
           32.419218529735076,
           32.06685202186716,
           31.71448551399925,
           31.362119006131334,
           31.009752498263424,
           30.657385990395525,
           30.305019482527612,
           29.9526529746597,
           29.6002864667918,
           29.247919958923866,
           28.895553451055967,
           28.543186943188058,
           28.19082043532014,
           27.83845392745225,
           27.486087419584315,
           27.133720911716416,
           26.781354403848503,
           26.42898789598059,
           26.07662138811269,
           25.724254880244764,
           25.371888372376866,
           25.01952186450895,
           24.667155356641036,
           24.314788848773137,
           23.96242234090522,
           23.610055833037308,
           23.257689325169395,
           22.90532281730148,
           22.552956309433583,
           22.20058980156567,
           21.848223293697757,
           21.495856785829858,
           21.215144801637646,
           20.970260079283314,
           20.725375356928968,
           20.480490634574625,
           20.235605912220297,
           19.990721189865944,
           19.745836467511616,
           19.500951745157273,
           19.25606702280293,
           19.011182300448596,
           18.76629757809425,
           18.521412855739914,
           18.276528133385572,
           18.03164341103123,
           17.7867586886769,
           17.544428191901943,
           17.307206147845108,
           17.069984103788272,
           16.832762059731436,
           16.595540015674604,
           16.35831797161777,
           16.12109592756093,
           15.883873883504107,
           15.646651839447259,
           15.40942979539043,
           15.172207751333591,
           14.934985707276757,
           14.697763663219927,
           14.460541619163084,
           14.23110103229211,
           14.008657215970118,
           13.786213399648133,
           13.563769583326154,
           13.34132576700417,
           13.118881950682184,
           12.896438134360196,
           12.673994318038208,
           12.451550501716234,
           12.236251263336205,
           12.032140697874706,
           11.828030132413218,
           11.623919566951718,
           11.41980900149022,
           11.215698436028722,
           11.011587870567222,
           10.817224783998793,
           10.623990354024059,
           10.430755924049317,
           10.237521494074574,
           10.045111800910359,
           9.870640145962675,
           9.696168491014998,
           9.521696836067314,
           9.353709302928209,
           9.20235495098171,
           9.05100059903522,
           8.905177543557716,
           8.773841214375166,
           8.642504885192617,
           8.526972003174043,
           8.414844707662574,
           8.317508343521045,
           8.224915761550808,
           8.14246863701945,
           8.0600215124881,
           7.977574387956743,
           7.895127263425386,
           7.812680138894027,
           7.7302330143626765,
           7.647785889831327,
           7.565338765299969,
           7.482891640768612,
           7.400444516237254,
           7.317997391705903,
           7.235550267174546,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           51.367030784553094,
           51.35176081661627,
           51.33649084867944,
           51.321220880742615,
           51.305950912805784,
           51.29068094486896,
           51.275410976932136,
           51.260141008995305,
           51.244871041058474,
           51.22960107312166,
           51.214331105184826,
           51.199061137247995,
           51.183791169311164,
           51.16852120137435,
           51.153251233437516,
           51.13798126550069,
           51.12271129756386,
           51.10744132962704,
           51.09217136169021,
           51.076901393753374,
           51.06163142581655,
           51.046361457879726,
           51.031091489942895,
           51.01582152200607,
           51.00055155406924,
           50.985281586132416,
           50.970011618195585,
           50.95474165025876,
           50.93947168232194,
           50.92420171438511,
           50.90893174644829,
           50.89366177851145,
           50.87839181057463,
           50.8631218426378,
           50.847851874700964,
           50.83258190676414,
           50.81731193882732,
           50.80204197089049,
           50.78677200295367,
           50.77150203501684,
           50.75841593862285,
           50.74969757036837,
           50.74097920211388,
           50.732260833859385,
           50.72354246560489,
           50.7148240973504,
           50.70610572909592,
           50.69738736084142,
           50.68866899258693,
           50.67995062433245,
           50.67123225607796,
           50.66251388782347,
           50.65379551956897,
           50.64507715131448,
           50.636358783060004,
           50.62764041480551,
           50.61892204655102,
           50.61020367829653,
           50.60148531004204,
           50.59276694178755,
           50.58404857353306,
           50.575330205278576,
           50.566611837024084,
           50.55789346876959,
           50.54917510051511,
           50.540456732260616,
           50.531738364006124,
           50.52301999575164,
           50.51430162749715,
           50.505583259242655,
           50.49686489098817,
           50.48814652273368,
           50.47942815447919,
           50.4707097862247,
           50.46199141797021,
           50.45327304971572,
           50.44455468146123,
           50.435836313206735,
           50.42711794495225,
           50.418399576697766,
           50.409681208443274,
           50.40096284018878,
           50.39224447193429,
           50.3835261036798,
           50.0852611521012,
           49.729086883857754,
           49.37291261561434,
           49.01673834737092,
           48.66056407912748,
           48.304389810884075,
           47.948215542640646,
           47.59204127439722,
           47.23586700615379,
           46.87969273791036,
           46.52351846966695,
           46.16734420142352,
           45.811169933180096,
           45.45499566493666,
           45.09882139669324,
           44.742647128449825,
           44.386472860206396,
           44.030298591962975,
           43.674124323719546,
           43.31795005547611,
           42.9617757872327,
           42.605601518989275,
           42.24942725074585,
           41.89325298250243,
           41.53707871425899,
           41.180904446015575,
           40.824730177772146,
           40.46855590952872,
           40.11238164128531,
           39.75620737304187,
           39.40003310479845,
           39.043858836555025,
           38.6876845683116,
           38.33151030006819,
           37.97533603182476,
           37.61916176358133,
           37.2629874953379,
           36.906813227094474,
           36.55063895885106,
           36.195099320232444,
           35.842732812364524,
           35.490366304496625,
           35.1379997966287,
           34.7856332887608,
           34.43326678089289,
           34.08090027302497,
           33.728533765157074,
           33.37616725728915,
           33.02380074942125,
           32.671434241553335,
           32.31906773368542,
           31.966701225817523,
           31.61433471794961,
           31.261968210081694,
           30.90960170221378,
           30.557235194345868,
           30.204868686477973,
           29.852502178610056,
           29.50013567074214,
           29.147769162874248,
           28.795402655006313,
           28.443036147138415,
           28.0906696392705,
           27.73830313140259,
           27.38593662353469,
           27.033570115666762,
           26.681203607798864,
           26.32883709993095,
           25.976470592063034,
           25.624104084195135,
           25.271737576327205,
           24.919371068459306,
           24.567004560591393,
           24.21463805272348,
           23.86227154485558,
           23.509905036987668,
           23.157538529119755,
           22.805172021251842,
           22.45280551338393,
           22.10043900551603,
           21.748072497648117,
           21.395705989780204,
           21.043339481912305,
           20.76262749772009,
           20.517742775365754,
           20.27285805301141,
           20.02797333065707,
           19.78308860830274,
           19.538203885948388,
           19.29331916359406,
           19.048434441239717,
           18.803549718885375,
           18.55866499653104,
           18.31378027417669,
           18.0731100243339,
           17.835887980277057,
           17.598665936220222,
           17.361443892163397,
           17.124221848106554,
           16.88699980404972,
           16.649777759992883,
           16.412555715936048,
           16.175333671879216,
           15.93811162782238,
           15.700889583765541,
           15.463667539708718,
           15.226445495651868,
           14.98922345159504,
           14.752001407538202,
           14.527857442173502,
           14.305413625851525,
           14.08296980952953,
           13.860525993207553,
           13.638082176885561,
           13.41563836056358,
           13.193194544241601,
           12.970750727919617,
           12.74830691159763,
           12.52916577887499,
           12.32505521341349,
           12.120944647952003,
           11.916834082490503,
           11.712723517029005,
           11.508612951567516,
           11.304502386106018,
           11.10346997110939,
           10.91023554113465,
           10.717001111159908,
           10.523766681185165,
           10.330532251210434,
           10.139720486654237,
           9.965248831706553,
           9.79077717675887,
           9.616305521811185,
           9.444878585069453,
           9.293524233122954,
           9.142169881176454,
           8.990815529229955,
           8.858293923132873,
           8.726957593950324,
           8.602049785086862,
           8.48992248957539,
           8.380939994591667,
           8.28775062100737,
           8.198141997107397,
           8.11569487257604,
           8.033247748044683,
           7.950800623513333,
           7.868353498981974,
           7.785906374450617,
           7.703459249919259,
           7.621012125387908,
           7.538565000856558,
           7.456117876325201,
           7.373670751793842,
           7.291223627262484,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           51.08544292329941,
           51.07017295536258,
           51.05490298742575,
           51.039633019488925,
           51.0243630515521,
           51.00909308361527,
           50.99382311567844,
           50.978553147741614,
           50.96328317980479,
           50.94801321186796,
           50.93274324393114,
           50.91747327599431,
           50.90220330805748,
           50.886933340120656,
           50.87166337218383,
           50.856393404247,
           50.84112343631017,
           50.825853468373346,
           50.81058350043652,
           50.79531353249969,
           50.78004356456286,
           50.76477359662604,
           50.74950362868921,
           50.73423366075239,
           50.71896369281556,
           50.70369372487873,
           50.6884237569419,
           50.67315378900508,
           50.65788382106825,
           50.64261385313142,
           50.6273438851946,
           50.61207391725777,
           50.59680394932094,
           50.58153398138411,
           50.56626401344728,
           50.55099404551046,
           50.53572407757363,
           50.5204541096368,
           50.50518414169998,
           50.48991417376315,
           50.47464420582632,
           50.4593742378895,
           50.444104269952675,
           50.428834302015844,
           50.41356433407901,
           50.39829436614219,
           50.383024398205364,
           50.367754430268526,
           50.3524844623317,
           50.33721449439488,
           50.321944526458054,
           50.30667455852122,
           50.2914045905844,
           50.276134622647575,
           50.260864654710744,
           50.24559468677392,
           50.23032471883708,
           50.22051442120326,
           50.21179605294878,
           50.20307768469429,
           50.1943593164398,
           50.185640948185316,
           50.17692257993082,
           50.168204211676326,
           50.15948584342185,
           50.150767475167356,
           50.142049106912864,
           50.13333073865837,
           50.12461237040389,
           50.115894002149396,
           50.10717563389491,
           50.09845726564042,
           50.08973889738593,
           50.081020529131436,
           50.072302160876944,
           50.06358379262245,
           50.05486542436796,
           50.046147056113476,
           50.037428687858984,
           50.0287103196045,
           50.01999195135001,
           50.011273583095516,
           50.002555214841024,
           49.99383684658653,
           49.69557189500793,
           49.33939762676449,
           48.98322335852107,
           48.62704909027765,
           48.270874822034216,
           47.91470055379081,
           47.55852628554738,
           47.20235201730395,
           46.84617774906052,
           46.490003480817094,
           46.13382921257369,
           45.77765494433025,
           45.42148067608683,
           45.065306407843394,
           44.70913213959997,
           44.352957871356566,
           43.99678360311313,
           43.64060933486971,
           43.28443506662628,
           42.92826079838285,
           42.572086530139444,
           42.21591226189601,
           41.85973799365258,
           41.50356372540917,
           41.14738945716572,
           40.79121518892231,
           40.43504092067889,
           40.07886665243545,
           39.722692384192044,
           39.3665181159486,
           39.01034384770519,
           38.65416957946176,
           38.29799531121833,
           37.94182104297492,
           37.585646774731494,
           37.229472506488065,
           36.87329823824464,
           36.51712397000121,
           36.1609497017578,
           35.80477543351437,
           35.448601165270944,
           35.09242689702753,
           34.73625262878409,
           34.38007836054067,
           34.02390409229724,
           33.66772982405382,
           33.31155555581041,
           32.955381287566965,
           32.59920701932355,
           32.24303275108012,
           31.886858482836693,
           31.530684214593286,
           31.174509946349854,
           30.818335678106425,
           30.462161409862997,
           30.10598714161957,
           29.75235138256045,
           29.399984874692535,
           29.047618366824622,
           28.695251858956723,
           28.34288535108879,
           27.990518843220894,
           27.63815233535298,
           27.285785827485064,
           26.933419319617173,
           26.581052811749238,
           26.22868630388134,
           25.876319796013426,
           25.52395328814551,
           25.17158678027761,
           24.819220272409684,
           24.466853764541785,
           24.114487256673875,
           23.76212074880596,
           23.40975424093806,
           23.057387733070147,
           22.70502122520223,
           22.352654717334318,
           22.000288209466405,
           21.647921701598506,
           21.295555193730593,
           20.94318868586268,
           20.59082217799478,
           20.310110193802565,
           20.065225471448233,
           19.82034074909389,
           19.575456026739545,
           19.33057130438522,
           19.085686582030867,
           18.84080185967654,
           18.60179185676588,
           18.36456981270904,
           18.127347768652214,
           17.890125724595368,
           17.652903680538543,
           17.4156816364817,
           17.178459592424865,
           16.94123754836804,
           16.7040155043112,
           16.46679346025436,
           16.229571416197523,
           15.992349372140692,
           15.755127328083857,
           15.517905284027023,
           15.280683239970184,
           15.047057668376919,
           14.824613852054926,
           14.60217003573295,
           14.379726219410962,
           14.157282403088978,
           13.934838586767,
           13.712394770445004,
           13.489950954123028,
           13.267507137801037,
           13.045063321479056,
           12.822619505157075,
           12.617969728952309,
           12.413859163490809,
           12.20974859802931,
           12.005638032567813,
           11.801527467106323,
           11.597416901644825,
           11.393306336183326,
           11.196480728245273,
           11.003246298270529,
           10.810011868295788,
           10.616777438321044,
           10.423543008346304,
           10.234329172398125,
           10.059857517450451,
           9.885385862502767,
           9.710914207555081,
           9.536442552607397,
           9.384693515264205,
           9.233339163317712,
           9.081984811371214,
           8.942746631890587,
           8.811410302708037,
           8.680073973525495,
           8.565000271488222,
           8.452872975976748,
           8.351182272077999,
           8.2579928984937,
           8.171368232664003,
           8.088921108132643,
           8.006473983601285,
           7.9240268590699285,
           7.841579734538579,
           7.759132610007221,
           7.676685485475864,
           7.594238360944505,
           7.5117912364131545,
           7.429344111881804,
           7.346896987350448,
           7.264449862819089,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           50.8038550620457,
           50.788585094108875,
           50.77331512617205,
           50.75804515823522,
           50.74277519029839,
           50.72750522236157,
           50.71223525442474,
           50.69696528648791,
           50.681695318551085,
           50.66642535061426,
           50.65115538267743,
           50.6358854147406,
           50.620615446803775,
           50.60534547886695,
           50.59007551093013,
           50.5748055429933,
           50.55953557505647,
           50.54426560711964,
           50.52899563918282,
           50.51372567124599,
           50.49845570330916,
           50.48318573537233,
           50.4679157674355,
           50.45264579949868,
           50.43737583156185,
           50.42210586362502,
           50.406835895688204,
           50.39156592775137,
           50.37629595981454,
           50.36102599187771,
           50.34575602394089,
           50.33048605600406,
           50.31521608806724,
           50.299946120130414,
           50.28467615219358,
           50.26940618425675,
           50.25413621631993,
           50.238866248383104,
           50.22359628044627,
           50.20832631250944,
           50.193056344572625,
           50.17778637663579,
           50.16251640869896,
           50.14724644076213,
           50.131976472825315,
           50.116706504888484,
           50.10143653695166,
           50.08616656901483,
           50.070896601078005,
           50.05562663314117,
           50.04035666520435,
           50.025086697267525,
           50.009816729330694,
           49.99454676139386,
           49.97927679345704,
           49.964006825520215,
           49.948736857583384,
           49.93346688964655,
           49.91819692170973,
           49.902926953772905,
           49.887656985836074,
           49.87238701789924,
           49.85711704996242,
           49.841847082025595,
           49.826577114088764,
           49.81130714615194,
           49.796037178215116,
           49.780767210278285,
           49.76549724234145,
           49.75022727440463,
           49.734957306467805,
           49.71968733853098,
           49.70441737059415,
           49.69133127203814,
           49.68261290378365,
           49.67389453552916,
           49.66517616727467,
           49.65645779902018,
           49.6477394307657,
           49.639021062511205,
           49.63030269425671,
           49.62158432600222,
           49.612865957747736,
           49.604147589493245,
           49.30588263791464,
           48.9497083696712,
           48.59353410142779,
           48.237359833184364,
           47.88118556494093,
           47.52501129669752,
           47.16883702845409,
           46.81266276021066,
           46.456488491967235,
           46.10031422372381,
           45.7441399554804,
           45.387965687236964,
           45.03179141899354,
           44.675617150750114,
           44.31944288250669,
           43.96326861426328,
           43.60709434601985,
           43.250920077776414,
           42.89474580953299,
           42.538571541289556,
           42.18239727304615,
           41.82622300480272,
           41.47004873655929,
           41.113874468315885,
           40.757700200072435,
           40.40152593182903,
           40.0453516635856,
           39.68917739534217,
           39.333003127098756,
           38.97682885885531,
           38.6206545906119,
           38.26448032236847,
           37.90830605412505,
           37.552131785881635,
           37.195957517638206,
           36.83978324939478,
           36.48360898115135,
           36.12743471290792,
           35.771260444664506,
           35.415086176421084,
           35.058911908177656,
           34.70273763993424,
           34.34656337169079,
           33.990389103447384,
           33.63421483520396,
           33.27804056696053,
           32.92186629871712,
           32.56569203047367,
           32.20951776223026,
           31.853343493986834,
           31.497169225743406,
           31.14099495749999,
           30.784820689256563,
           30.428646421013138,
           30.072472152769713,
           29.71629788452628,
           29.36012361628287,
           29.00394934803944,
           28.647775079796013,
           28.291600811552602,
           27.935426543309156,
           27.579252275065745,
           27.223078006822313,
           26.866903738578888,
           26.510729470335477,
           26.154555202092034,
           25.798380933848623,
           25.442206665605195,
           25.086032397361766,
           24.729858129118355,
           24.37368386087491,
           24.017509592631498,
           23.661969952756316,
           23.3096034448884,
           22.957236937020504,
           22.60487042915259,
           22.252503921284674,
           21.90013741341676,
           21.547770905548845,
           21.19540439768095,
           20.843037889813036,
           20.49067138194512,
           20.138304874077225,
           19.857592889885012,
           19.612708167530677,
           19.367823445176334,
           19.130473689197835,
           18.893251645141,
           18.65602960108415,
           18.41880755702733,
           18.181585512970493,
           17.94436346891365,
           17.707141424856825,
           17.46991938079998,
           17.232697336743154,
           16.99547529268631,
           16.758253248629476,
           16.521031204572648,
           16.28380916051581,
           16.046587116458973,
           15.809365072402136,
           15.572143028345304,
           15.343814078258315,
           15.121370261936331,
           14.898926445614343,
           14.676482629292366,
           14.454038812970374,
           14.231594996648395,
           14.009151180326409,
           13.786707364004425,
           13.564263547682447,
           13.34181973136045,
           13.119375915038475,
           12.91088424449109,
           12.706773679029594,
           12.502663113568104,
           12.298552548106606,
           12.094441982645106,
           11.89033141718361,
           11.68622085172211,
           11.482725915355864,
           11.289491485381122,
           11.09625705540638,
           10.903022625431646,
           10.709788195456904,
           10.516553765482161,
           10.328937858142005,
           10.154466203194321,
           9.979994548246635,
           9.80552289329896,
           9.631051238351276,
           9.475862797405448,
           9.32450844545895,
           9.173154093512448,
           9.027199340648295,
           8.895863011465746,
           8.764526682283194,
           8.640078053401036,
           8.527950757889569,
           8.415823462378095,
           8.321424549564327,
           8.228235175980025,
           8.144594468220584,
           8.062147343689233,
           7.979700219157875,
           7.897253094626517,
           7.81480597009516,
           7.73235884556381,
           7.649911721032452,
           7.567464596501094,
           7.485017471969737,
           7.402570347438386,
           7.3201232229070365,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           50.51573913407445,
           50.50046916613762,
           50.48519919820079,
           50.469929230263965,
           50.45465926232714,
           50.43938929439032,
           50.424119326453486,
           50.40884935851666,
           50.39357939057983,
           50.37830942264301,
           50.36303945470618,
           50.34776948676935,
           50.33249951883253,
           50.3172295508957,
           50.30195958295887,
           50.28668961502204,
           50.27141964708522,
           50.25614967914839,
           50.24087971121157,
           50.22560974327473,
           50.210339775337914,
           50.195069807401076,
           50.17979983946425,
           50.16452987152743,
           50.14925990359059,
           50.13398993565377,
           50.11871996771695,
           50.10344999978011,
           50.088180031843294,
           50.07291006390646,
           50.05764009596963,
           50.04237012803281,
           50.027100160095976,
           50.01183019215915,
           49.99656022422232,
           49.981290256285504,
           49.96602028834867,
           49.95075032041184,
           49.935480352475025,
           49.92021038453819,
           49.90494041660136,
           49.88967044866453,
           49.87440048072771,
           49.859130512790884,
           49.84386054485405,
           49.82859057691723,
           49.813320608980405,
           49.798050641043574,
           49.78278067310675,
           49.767510705169926,
           49.752240737233095,
           49.73697076929626,
           49.72170080135944,
           49.706430833422615,
           49.691160865485784,
           49.67589089754896,
           49.66062092961213,
           49.645350961675305,
           49.63008099373848,
           49.61481102580166,
           49.599541057864826,
           49.584271089927995,
           49.56900112199117,
           49.55373115405435,
           49.538461186117516,
           49.52319121818069,
           49.50792125024387,
           49.49265128230703,
           49.477381314370206,
           49.46211134643338,
           49.44684137849656,
           49.43157141055973,
           49.4163014426229,
           49.40103147468607,
           49.38576150674925,
           49.370491538812416,
           49.35522157087559,
           49.33995160293877,
           49.31813212630256,
           49.29500274542308,
           49.271873364543616,
           49.248743983664134,
           49.225614602784674,
           49.2024852219052,
           48.901818434889094,
           48.54564416664565,
           48.18946989840225,
           47.833295630158815,
           47.47712136191539,
           47.12094709367198,
           46.76477282542855,
           46.40859855718512,
           46.052424288941694,
           45.696250020698265,
           45.34007575245485,
           44.98390148421142,
           44.627727215967994,
           44.27155294772457,
           43.915378679481144,
           43.55920441123773,
           43.2030301429943,
           42.846855874750865,
           42.49068160650744,
           42.134507338264015,
           41.7783330700206,
           41.42215880177717,
           41.065984533533744,
           40.70981026529033,
           40.35363599704689,
           39.99746172880348,
           39.64128746056005,
           39.28511319231662,
           38.92893892407321,
           38.572764655829765,
           38.21659038758635,
           37.86041611934292,
           37.5042418510995,
           37.148067582856086,
           36.79189331461266,
           36.435719046369236,
           36.0795447781258,
           35.72337050988238,
           35.367196241638965,
           35.01102197339553,
           34.654847705152115,
           34.29867343690869,
           33.94249916866525,
           33.586324900421836,
           33.230150632178415,
           32.87397636393498,
           32.51780209569157,
           32.16162782744813,
           31.805453559204718,
           31.44927929096129,
           31.09310502271786,
           30.736930754474447,
           30.380756486231018,
           30.024582217987593,
           29.668407949744164,
           29.312233681500736,
           28.956059413257325,
           28.599885145013896,
           28.243710876770468,
           27.887536608527054,
           27.53136234028361,
           27.1751880720402,
           26.81901380379677,
           26.462839535553343,
           26.106665267309932,
           25.75049099906649,
           25.39431673082308,
           25.03814246257965,
           24.68196819433622,
           24.32579392609281,
           23.969619657849364,
           23.613445389605953,
           23.25727112136253,
           22.901096853119096,
           22.544922584875685,
           22.18874831663226,
           21.832574048388828,
           21.47676398269395,
           21.121136018490862,
           20.76550805428779,
           20.4098800900847,
           20.05425212588161,
           19.698624161678538,
           19.421933477572935,
           19.18471143351611,
           18.947489389459278,
           18.710267345402443,
           18.47304530134561,
           18.235823257288764,
           17.99860121323194,
           17.761379169175104,
           17.52415712511826,
           17.286935081061436,
           17.04971303700459,
           16.812490992947765,
           16.575268948890923,
           16.338046904834087,
           16.10082486077726,
           15.86360281672042,
           15.640570488139716,
           15.418126671817728,
           15.195682855495736,
           14.973239039173764,
           14.750795222851778,
           14.52835140652979,
           14.305907590207813,
           14.083463773885821,
           13.861019957563842,
           13.638576141241854,
           13.416132324919873,
           13.203798760029883,
           12.999688194568376,
           12.795577629106887,
           12.59146706364539,
           12.387356498183891,
           12.183245932722402,
           11.979135367260904,
           11.775024801799404,
           11.575736672491711,
           11.38250224251697,
           11.189267812542237,
           10.996033382567495,
           10.802798952592752,
           10.60956452261802,
           10.423546543885884,
           10.2490748889382,
           10.074603233990514,
           9.900131579042828,
           9.725659924095144,
           9.567032079546692,
           9.415677727600192,
           9.264323375653692,
           9.112969023707194,
           8.980315720223448,
           8.848979391040903,
           8.717643061858352,
           8.603028539802382,
           8.490901244290908,
           8.384856200634951,
           8.291666827050651,
           8.20026782830853,
           8.117820703777172,
           8.035373579245814,
           7.952926454714464,
           7.870479330183107,
           7.788032205651749,
           7.705585081120391,
           7.623137956589042,
           7.540690832057684,
           7.458243707526327,
           7.375796582994968,
           7.293349458463617,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           50.2161990883738,
           50.200929120436975,
           50.18565915250014,
           50.17038918456333,
           50.1551192166265,
           50.13984924868967,
           50.12457928075284,
           50.10930931281601,
           50.094039344879185,
           50.07876937694236,
           50.06349940900553,
           50.048229441068706,
           50.03295947313187,
           50.01768950519505,
           50.00241953725823,
           49.987149569321396,
           49.97187960138457,
           49.95660963344774,
           49.94133966551091,
           49.92606969757409,
           49.91079972963726,
           49.89552976170043,
           49.8802597937636,
           49.86498982582678,
           49.84971985788995,
           49.83444988995312,
           49.8191799220163,
           49.80390995407947,
           49.78863998614264,
           49.77337001820581,
           49.758100050268986,
           49.74283008233216,
           49.72756011439533,
           49.712290146458514,
           49.697020178521676,
           49.68175021058485,
           49.66648024264803,
           49.6512102747112,
           49.63594030677437,
           49.62067033883754,
           49.60540037090072,
           49.59013040296389,
           49.57486043502706,
           49.55959046709023,
           49.54432049915341,
           49.52905053121658,
           49.51378056327976,
           49.49851059534292,
           49.4832406274061,
           49.46797065946927,
           49.45270069153245,
           49.437430723595625,
           49.42216075565879,
           49.40689078772196,
           49.39162081978514,
           49.37635085184831,
           49.36108088391148,
           49.34581091597465,
           49.33054094803783,
           49.315270980101,
           49.300001012164174,
           49.28211124070249,
           49.258981859823024,
           49.23585247894354,
           49.21272309806408,
           49.18959371718461,
           49.16646433630514,
           49.14333495542566,
           49.12020557454619,
           49.09707619366672,
           49.07394681278725,
           49.050817431907774,
           49.0276880510283,
           49.00455867014883,
           48.98142928926936,
           48.95829990838988,
           48.93517052751041,
           48.91204114663094,
           48.888911765751466,
           48.86578238487199,
           48.84265300399252,
           48.81952362311305,
           48.79639424223358,
           48.77326486135411,
           48.47259807433801,
           48.116423806094566,
           47.76024953785116,
           47.40407526960773,
           47.047901001364295,
           46.69172673312089,
           46.33555246487746,
           45.97937819663403,
           45.6232039283906,
           45.26702966014717,
           44.91085539190376,
           44.55468112366033,
           44.19850685541691,
           43.84233258717347,
           43.486158318930045,
           43.12998405068664,
           42.77380978244321,
           42.41763551419978,
           42.06146124595636,
           41.70528697771292,
           41.349112709469516,
           40.99293844122609,
           40.63676417298266,
           40.280589904739244,
           39.9244156364958,
           39.56824136825239,
           39.212067100008966,
           38.85589283176553,
           38.49971856352212,
           38.14354429527868,
           37.787370027035266,
           37.43119575879184,
           37.07502149054841,
           36.718847222305,
           36.362672954061566,
           36.006498685818144,
           35.65032441757471,
           35.29415014933129,
           34.93797588108788,
           34.581801612844444,
           34.22562734460102,
           33.86945307635761,
           33.513278808114165,
           33.15710453987075,
           32.80093027162732,
           32.444756003383894,
           32.08858173514049,
           31.732407466897037,
           31.37623319865363,
           31.0200589304102,
           30.663884662166772,
           30.307710393923358,
           29.95153612567993,
           29.5953618574365,
           29.239187589193072,
           28.883013320949644,
           28.526839052706237,
           28.170664784462808,
           27.81449051621938,
           27.458316247975965,
           27.102233030351044,
           26.74660506614797,
           26.390977101944884,
           26.03534913774179,
           25.67972117353872,
           25.324093209335615,
           24.968465245132542,
           24.612837280929455,
           24.257209316726367,
           23.901581352523294,
           23.545953388320186,
           23.190325424117113,
           22.834697459914025,
           22.479069495710938,
           22.123441531507865,
           21.767813567304774,
           21.412185603101687,
           21.056557638898596,
           20.700929674695505,
           20.345301710492432,
           19.989673746289345,
           19.634045782086254,
           19.27841781788318,
           19.001727133777578,
           18.764505089720753,
           18.52728304566392,
           18.29006100160709,
           18.052838957550254,
           17.815616913493407,
           17.578394869436583,
           17.341172825379747,
           17.103950781322904,
           16.86672873726608,
           16.629506693209233,
           16.39228464915241,
           16.159770714343132,
           15.93732689802114,
           15.714883081699162,
           15.492439265377174,
           15.269995449055193,
           15.047551632733205,
           14.825107816411213,
           14.60266400008924,
           14.380220183767253,
           14.157776367445265,
           13.935332551123288,
           13.712888734801295,
           13.496713275568693,
           13.292602710107195,
           13.088492144645695,
           12.884381579184208,
           12.680271013722699,
           12.47616044826121,
           12.272049882799713,
           12.067939317338215,
           11.863828751876724,
           11.668747429627592,
           11.475512999652851,
           11.282278569678107,
           11.089044139703368,
           10.895809709728633,
           10.70257527975389,
           10.518155229629773,
           10.3436835746821,
           10.169211919734414,
           9.994740264786728,
           9.820268609839044,
           9.65820136168794,
           9.506847009741442,
           9.35549265779495,
           9.204138305848453,
           9.064768428981168,
           8.933432099798617,
           8.802095770616068,
           8.678106321715216,
           8.565979026203742,
           8.453851730692268,
           8.355098478121281,
           8.261909104536985,
           8.173494063865128,
           8.09104693933377,
           8.008599814802412,
           7.926152690271054,
           7.843705565739704,
           7.761258441208347,
           7.678811316676988,
           7.596364192145632,
           7.5139170676142815,
           7.431469943082923,
           7.349022818551566,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           49.91665904267313,
           49.90138907473631,
           49.88611910679947,
           49.870849138862646,
           49.85557917092582,
           49.84030920298899,
           49.82503923505217,
           49.80976926711534,
           49.79449929917851,
           49.77922933124169,
           49.76395936330486,
           49.74868939536803,
           49.7334194274312,
           49.718149459494384,
           49.70287949155755,
           49.68760952362072,
           49.67233955568389,
           49.657069587747074,
           49.64179961981024,
           49.62652965187342,
           49.611259683936595,
           49.595989715999764,
           49.58071974806293,
           49.56544978012611,
           49.55017981218928,
           49.534909844252454,
           49.51963987631563,
           49.50436990837879,
           49.489099940441974,
           49.47382997250514,
           49.45856000456832,
           49.443290036631495,
           49.428020068694664,
           49.41275010075785,
           49.39748013282101,
           49.382210164884185,
           49.36694019694736,
           49.35167022901052,
           49.3364002610737,
           49.32113029313687,
           49.305860325200044,
           49.29059035726322,
           49.27532038932639,
           49.260050421389565,
           49.24478045345274,
           49.22296097422293,
           49.19983159334346,
           49.176702212463994,
           49.15357283158451,
           49.13044345070505,
           49.10731406982556,
           49.0841846889461,
           49.06105530806662,
           49.03792592718715,
           49.014796546307686,
           48.99166716542821,
           48.968537784548744,
           48.94540840366926,
           48.922279022789795,
           48.89914964191033,
           48.876020261030845,
           48.85289088015138,
           48.8297614992719,
           48.80663211839243,
           48.78350273751296,
           48.76037335663349,
           48.73724397575402,
           48.714114594874545,
           48.69098521399508,
           48.6678558331156,
           48.64472645223613,
           48.62159707135666,
           48.598467690477186,
           48.57533830959771,
           48.55220892871824,
           48.52907954783876,
           48.505950166959295,
           48.48282078607982,
           48.459691405200346,
           48.43656202432088,
           48.4134326434414,
           48.39030326256193,
           48.36717388168246,
           48.34404450080299,
           48.04337771378688,
           47.687203445543446,
           47.331029177300024,
           46.9748549090566,
           46.618680640813174,
           46.26250637256976,
           45.90633210432634,
           45.5501578360829,
           45.193983567839474,
           44.83780929959606,
           44.48163503135264,
           44.1254607631092,
           43.76928649486579,
           43.413112226622346,
           43.05693795837893,
           42.70076369013552,
           42.34458942189209,
           41.98841515364866,
           41.63224088540523,
           41.2760666171618,
           40.919892348918395,
           40.56371808067496,
           40.20754381243154,
           39.851369544188124,
           39.49519527594468,
           39.13902100770127,
           38.78284673945784,
           38.42667247121441,
           38.070498202970995,
           37.71432393472756,
           37.35814966648414,
           37.00197539824072,
           36.64580112999728,
           36.289626861753874,
           35.93345259351045,
           35.57727832526702,
           35.221104057023595,
           34.86492978878016,
           34.508755520536745,
           34.15258125229333,
           33.796406984049895,
           33.44023271580649,
           33.08405844756304,
           32.72788417931963,
           32.37207411380503,
           32.01644614960194,
           31.660818185398867,
           31.305190221195762,
           30.949562256992692,
           30.5939342927896,
           30.238306328586514,
           29.88267836438344,
           29.52705040018035,
           29.171422435977263,
           28.81579447177417,
           28.46016650757108,
           28.104538543368008,
           27.74891057916492,
           27.393282614961834,
           27.03765465075876,
           26.682026686555652,
           26.32639872235258,
           25.97077075814949,
           25.615142793946404,
           25.25951482974333,
           24.903886865540226,
           24.548258901337153,
           24.192630937134066,
           23.837002972930975,
           23.481375008727902,
           23.125747044524797,
           22.770119080321724,
           22.414491116118636,
           22.058863151915546,
           21.703235187712473,
           21.34760722350938,
           20.991979259306294,
           20.636351295103204,
           20.280723330900116,
           19.925095366697043,
           19.569467402493956,
           19.213839438290865,
           18.858211474087792,
           18.58152078998219,
           18.344298745925368,
           18.107076701868532,
           17.869854657811697,
           17.632632613754865,
           17.39541056969802,
           17.158188525641194,
           16.92096648158436,
           16.683744437527515,
           16.45652712422453,
           16.234083307902534,
           16.011639491580553,
           15.789195675258577,
           15.566751858936586,
           15.344308042614609,
           15.12186422629262,
           14.89942040997064,
           14.676976593648652,
           14.45453277732666,
           14.232088961004685,
           14.009645144682704,
           13.789627791107476,
           13.585517225645987,
           13.38140666018448,
           13.17729609472299,
           12.973185529261492,
           12.769074963799994,
           12.564964398338505,
           12.360853832876998,
           12.156743267415509,
           11.954992616738181,
           11.76175818676344,
           11.568523756788709,
           11.375289326813967,
           11.182054896839226,
           10.988820466864482,
           10.795586036889741,
           10.612763915373652,
           10.43829226042597,
           10.263820605478282,
           10.089348950530608,
           9.914877295582922,
           9.749370643829185,
           9.598016291882686,
           9.446661939936185,
           9.295307587989686,
           9.149221137738873,
           9.017884808556325,
           8.886548479373776,
           8.755212150191225,
           8.641056808116556,
           8.528929512605089,
           8.418530129191907,
           8.325340755607606,
           8.232151382023307,
           8.146720299421709,
           8.064273174890358,
           7.981826050359,
           7.899378925827643,
           7.816931801296286,
           7.734484676764935,
           7.652037552233578,
           7.569590427702219,
           7.487143303170862,
           7.404696178639512,
           7.322249054108155,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           49.61711899697246,
           49.601849029035634,
           49.5865790610988,
           49.57130909316197,
           49.55603912522515,
           49.540769157288324,
           49.52549918935149,
           49.51022922141467,
           49.494959253477845,
           49.47968928554101,
           49.46441931760418,
           49.44914934966736,
           49.433879381730534,
           49.4186094137937,
           49.40333944585687,
           49.38806947792005,
           49.37279950998322,
           49.35752954204639,
           49.34225957410957,
           49.326989606172745,
           49.311719638235914,
           49.29644967029909,
           49.28117970236225,
           49.265909734425435,
           49.250639766488604,
           49.23536979855178,
           49.220099830614956,
           49.20482986267812,
           49.18694008862284,
           49.163810707743366,
           49.14068132686389,
           49.117551945984424,
           49.09442256510495,
           49.071293184225475,
           49.04816380334601,
           49.02503442246653,
           49.00190504158706,
           48.97877566070759,
           48.95564627982811,
           48.93251689894864,
           48.90938751806917,
           48.8862581371897,
           48.863128756310225,
           48.83999937543075,
           48.81686999455128,
           48.79374061367181,
           48.77061123279234,
           48.747481851912866,
           48.72435247103339,
           48.701223090153924,
           48.67809370927445,
           48.654964328394975,
           48.6318349475155,
           48.608705566636026,
           48.585576185756565,
           48.562446804877084,
           48.539317423997616,
           48.51618804311814,
           48.49305866223867,
           48.4699292813592,
           48.446799900479725,
           48.42367051960026,
           48.400541138720776,
           48.3774117578413,
           48.354282376961834,
           48.331152996082366,
           48.3080236152029,
           48.28489423432342,
           48.26176485344395,
           48.238635472564475,
           48.215506091685,
           48.19237671080553,
           48.169247329926066,
           48.146117949046584,
           48.122988568167116,
           48.09985918728764,
           48.07672980640817,
           48.0536004255287,
           48.030471044649225,
           48.00734166376975,
           47.98421228289028,
           47.96108290201081,
           47.937953521131334,
           47.914824140251866,
           47.61415735323577,
           47.25798308499232,
           46.90180881674891,
           46.545634548505475,
           46.189460280262054,
           45.83328601201864,
           45.47711174377521,
           45.12093747553178,
           44.764763207288354,
           44.40858893904493,
           44.052414670801525,
           43.69624040255808,
           43.34006613431467,
           42.98389186607123,
           42.62771759782781,
           42.271543329584404,
           41.91536906134097,
           41.55919479309753,
           41.20302052485411,
           40.846846256610675,
           40.49067198836727,
           40.13449772012384,
           39.77832345188041,
           39.422149183637,
           39.065974915393554,
           38.709800647150146,
           38.35362637890672,
           37.99754316146209,
           37.64191519725902,
           37.286287233055916,
           36.93065926885284,
           36.575031304649755,
           36.21940334044666,
           35.86377537624359,
           35.5081474120405,
           35.152519447837406,
           34.796891483634326,
           34.44126351943123,
           34.08563555522816,
           33.73000759102507,
           33.37437962682198,
           33.01875166261891,
           32.6631236984158,
           32.307495734212736,
           31.951867770009642,
           31.596239805806555,
           31.24061184160348,
           30.884983877400373,
           30.5293559131973,
           30.173727948994213,
           29.818099984791125,
           29.462472020588052,
           29.10684405638496,
           28.751216092181874,
           28.395588127978783,
           28.039960163775696,
           27.684332199572623,
           27.328704235369532,
           26.97307627116644,
           26.617448306963368,
           26.261820342760267,
           25.906192378557193,
           25.550564414354106,
           25.194936450151015,
           24.839308485947942,
           24.483680521744837,
           24.128052557541764,
           23.772424593338677,
           23.41679662913559,
           23.061168664932516,
           22.705540700729408,
           22.349912736526335,
           21.994284772323248,
           21.63865680812016,
           21.283028843917087,
           20.927400879713996,
           20.57177291551091,
           20.216144951307818,
           19.860516987104727,
           19.504889022901654,
           19.149261058698567,
           18.793633094495476,
           18.438005130292403,
           18.161314446186804,
           17.924092402129975,
           17.686870358073143,
           17.44964831401631,
           17.212426269959476,
           16.975727350427906,
           16.75328353410593,
           16.53083971778394,
           16.308395901461953,
           16.085952085139976,
           15.86350826881798,
           15.641064452496003,
           15.418620636174024,
           15.196176819852033,
           14.973733003530056,
           14.751289187208068,
           14.528845370886085,
           14.306401554564097,
           14.083957738242106,
           13.878431741184771,
           13.674321175723271,
           13.470210610261777,
           13.266100044800284,
           13.061989479338777,
           12.857878913877288,
           12.653768348415792,
           12.449657782954292,
           12.245547217492803,
           12.048003373874034,
           11.8547689438993,
           11.661534513924558,
           11.468300083949817,
           11.275065653975084,
           11.08183122400034,
           10.888596794025599,
           10.707372601117527,
           10.532900946169843,
           10.35842929122216,
           10.183957636274478,
           10.009485981326792,
           9.840539925970429,
           9.68918557402393,
           9.537831222077429,
           9.386476870130931,
           9.23512251818443,
           9.102337517314025,
           8.971001188131481,
           8.839664858948932,
           8.716134590029377,
           8.604007294517903,
           8.491879999006429,
           8.388772406678232,
           8.29558303309393,
           8.202393659509632,
           8.11994653497829,
           8.03749941044694,
           7.955052285915588,
           7.872605161384231,
           7.7901580368528744,
           7.707710912321517,
           7.625263787790167,
           7.542816663258809,
           7.460369538727452,
           7.377922414196093,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           49.31757895127181,
           49.30230898333498,
           49.28703901539816,
           49.27176904746132,
           49.2564990795245,
           49.24122911158767,
           49.22595914365085,
           49.210689175714016,
           49.1954192077772,
           49.18014923984036,
           49.16487927190354,
           49.149609303966706,
           49.127789822143306,
           49.104660441263825,
           49.081531060384364,
           49.05840167950488,
           49.035272298625415,
           49.01214291774593,
           48.98901353686647,
           48.965884155987005,
           48.942754775107524,
           48.919625394228056,
           48.89649601334858,
           48.873366632469114,
           48.85023725158963,
           48.827107870710165,
           48.80397848983069,
           48.78084910895122,
           48.75771972807174,
           48.734590347192274,
           48.711460966312806,
           48.68833158543333,
           48.66520220455386,
           48.64207282367438,
           48.618943442794915,
           48.59581406191544,
           48.57268468103597,
           48.54955530015649,
           48.52642591927703,
           48.50329653839755,
           48.48016715751808,
           48.457037776638614,
           48.43390839575913,
           48.410779014879665,
           48.3876496340002,
           48.364520253120716,
           48.34139087224125,
           48.318261491361774,
           48.2951321104823,
           48.27200272960283,
           48.24887334872335,
           48.22574396784388,
           48.20261458696441,
           48.179485206084934,
           48.15635582520547,
           48.133226444326,
           48.11009706344653,
           48.08696768256705,
           48.06383830168758,
           48.040708920808115,
           48.01757953992863,
           47.994450159049165,
           47.971320778169684,
           47.948191397290216,
           47.92506201641075,
           47.901932635531274,
           47.8788032546518,
           47.85567387377233,
           47.83254449289286,
           47.80941511201338,
           47.786285731133916,
           47.76315635025445,
           47.740026969374966,
           47.7168975884955,
           47.69376820761602,
           47.67063882673655,
           47.64750944585708,
           47.62438006497761,
           47.60125068409813,
           47.578121303218666,
           47.55499192233919,
           47.53186254145972,
           47.50873316058025,
           47.485603779700774,
           47.18493699268467,
           46.828762724441226,
           46.47258845619782,
           46.11641418795439,
           45.76023991971096,
           45.40406565146755,
           45.04789138322412,
           44.69171711498069,
           44.33554284673726,
           43.97936857849383,
           43.62319431025043,
           43.2673842449161,
           42.91175628071302,
           42.55612831650993,
           42.20050035230685,
           41.844872388103774,
           41.489244423900686,
           41.13361645969759,
           40.777988495494505,
           40.42236053129141,
           40.066732567088344,
           39.71110460288526,
           39.35547663868216,
           38.99984867447909,
           38.64422071027599,
           38.288592746072915,
           37.93296478186982,
           37.57733681766673,
           37.22170885346366,
           36.86608088926056,
           36.510452925057486,
           36.1548249608544,
           35.799196996651304,
           35.44356903244823,
           35.087941068245144,
           34.73231310404205,
           34.37668513983897,
           34.021057175635875,
           33.6654292114328,
           33.309801247229714,
           32.95417328302662,
           32.598545318823554,
           32.242917354620445,
           31.887289390417376,
           31.531661426214285,
           31.176033462011198,
           30.820405497808125,
           30.464777533605016,
           30.109149569401943,
           29.753521605198856,
           29.39789364099577,
           29.042265676792695,
           28.686637712589604,
           28.331009748386517,
           27.975381784183426,
           27.61975381998034,
           27.264125855777266,
           26.90849789157417,
           26.552869927371084,
           26.19724196316801,
           25.84161399896491,
           25.485986034761837,
           25.13035807055875,
           24.77473010635566,
           24.419102142152585,
           24.06347417794948,
           23.707846213746407,
           23.35221824954332,
           22.99659028534023,
           22.64096232113716,
           22.28533435693405,
           21.929706392730978,
           21.57407842852789,
           21.218450464324803,
           20.86282250012173,
           20.50719453591864,
           20.151566571715552,
           19.795938607512458,
           19.44031064330937,
           19.084682679106297,
           18.72905471490321,
           18.37342675070012,
           18.017798786497046,
           17.741108102391443,
           17.50388605833462,
           17.272483760309342,
           17.05003994398735,
           16.827596127665377,
           16.60515231134338,
           16.382708495021404,
           16.160264678699413,
           15.937820862377428,
           15.715377046055451,
           15.492933229733456,
           15.270489413411477,
           15.0480455970895,
           14.825601780767508,
           14.603157964445531,
           14.380714148123543,
           14.171346256723579,
           13.967235691262081,
           13.763125125800583,
           13.559014560339094,
           13.354903994877596,
           13.150793429416098,
           12.946682863954607,
           12.742572298493101,
           12.53846173303161,
           12.334351167570112,
           12.141014131009914,
           11.94777970103518,
           11.75454527106043,
           11.561310841085696,
           11.368076411110954,
           11.174841981136215,
           10.98160755116148,
           10.801981286861423,
           10.627509631913737,
           10.453037976966055,
           10.27856632201837,
           10.10409466707069,
           9.93170920811168,
           9.780354856165179,
           9.629000504218688,
           9.47764615227219,
           9.326291800325691,
           9.186790226071745,
           9.055453896889194,
           8.924117567706645,
           8.7927812385241,
           8.679085076430734,
           8.56695778091926,
           8.454830485407786,
           8.359014684164562,
           8.265825310580265,
           8.175619895066246,
           8.093172770534888,
           8.01072564600353,
           7.92827852147218,
           7.845831396940829,
           7.763384272409472,
           7.680937147878113,
           7.5984900233467565,
           7.516042898815407,
           7.43359577428405,
           7.351148649752691,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           49.00083455801362,
           48.97025796944809,
           48.939681380882554,
           48.90910479231702,
           48.87852820375148,
           48.84795161518594,
           48.82233982757725,
           48.79921044669778,
           48.7760810658183,
           48.752951684938836,
           48.72982230405936,
           48.70669292317989,
           48.68356354230042,
           48.660434161420945,
           48.63730478054147,
           48.614175399661995,
           48.59104601878253,
           48.56791663790305,
           48.544787257023586,
           48.52165787614411,
           48.49852849526464,
           48.47539911438516,
           48.452269733505695,
           48.42914035262622,
           48.406010971746745,
           48.38288159086727,
           48.3597522099878,
           48.33662282910833,
           48.313493448228854,
           48.29036406734939,
           48.26723468646992,
           48.244105305590445,
           48.22097592471097,
           48.1978465438315,
           48.17471716295203,
           48.15158778207255,
           48.128458401193086,
           48.105329020313604,
           48.08219963943414,
           48.05907025855466,
           48.03594087767519,
           48.01281149679572,
           47.98968211591625,
           47.96655273503677,
           47.943423354157304,
           47.92029397327783,
           47.89716459239836,
           47.87403521151889,
           47.85090583063942,
           47.82777644975994,
           47.80464706888047,
           47.78151768800099,
           47.75838830712152,
           47.735258926242054,
           47.71212954536258,
           47.68900016448311,
           47.66587078360364,
           47.64274140272417,
           47.619612021844695,
           47.59648264096522,
           47.573353260085746,
           47.55022387920627,
           47.527094498326804,
           47.503965117447336,
           47.480835736567855,
           47.45770635568839,
           47.43457697480892,
           47.41144759392944,
           47.38831821304997,
           47.365188832170496,
           47.34205945129103,
           47.318930070411554,
           47.29580068953208,
           47.27267130865261,
           47.24954192777314,
           47.22641254689366,
           47.20328316601419,
           47.18015378513472,
           47.157024404255246,
           47.13389502337577,
           47.110765642496304,
           47.08763626161684,
           47.064506880737355,
           47.04137749985789,
           46.74116596620874,
           46.38553800200563,
           46.02991003780255,
           45.674282073599464,
           45.31865410939638,
           44.96302614519331,
           44.60739818099022,
           44.25177021678712,
           43.896142252584035,
           43.54051428838095,
           43.18488632417788,
           42.82925835997479,
           42.47363039577171,
           42.11800243156861,
           41.76237446736552,
           41.40674650316245,
           41.051118538959365,
           40.69549057475627,
           40.33986261055318,
           39.98423464635009,
           39.62860668214702,
           39.27297871794393,
           38.91735075374084,
           38.56172278953777,
           38.20609482533466,
           37.85046686113159,
           37.4948388969285,
           37.13921093272541,
           36.78358296852234,
           36.42795500431923,
           36.072327040116164,
           35.71669907591307,
           35.361071111709975,
           35.00544314750691,
           34.64981518330383,
           34.294187219100735,
           33.93855925489765,
           33.58293129069455,
           33.22730332649148,
           32.87167536228839,
           32.5160473980853,
           32.16041943388223,
           31.804791469679124,
           31.44916350547605,
           31.093535541272963,
           30.737907577069876,
           30.382279612866803,
           30.026651648663698,
           29.671023684460625,
           29.315395720257534,
           28.959767756054447,
           28.604139791851374,
           28.248511827648283,
           27.892883863445192,
           27.537255899242105,
           27.181627935039018,
           26.825999970835944,
           26.470372006632857,
           26.114744042429766,
           25.759116078226693,
           25.403488114023588,
           25.047860149820515,
           24.692232185617428,
           24.336604221414333,
           23.98097625721126,
           23.62534829300816,
           23.26972032880509,
           22.914092364602,
           22.55846440039891,
           22.202836436195838,
           21.84720847199273,
           21.49158050778966,
           21.13595254358657,
           20.780324579383482,
           20.424696615180405,
           20.069068650977318,
           19.713440686774227,
           19.357812726134373,
           19.008552633374812,
           18.65929254061527,
           18.310032447855708,
           17.960772355096147,
           17.611512262336603,
           17.346796353868747,
           17.12435253754677,
           16.901908721224785,
           16.679464904902794,
           16.457021088580824,
           16.23457727225883,
           16.01213345593685,
           15.78968963961486,
           15.567245823292875,
           15.344802006970898,
           15.122358190648903,
           14.899914374326924,
           14.677470558004947,
           14.464260772262364,
           14.260150206800873,
           14.056039641339376,
           13.851929075877877,
           13.647818510416379,
           13.44370794495488,
           13.239597379493391,
           13.035486814031891,
           12.831376248570395,
           12.627265683108906,
           12.427259318120505,
           12.234024888145772,
           12.040790458171028,
           11.847556028196289,
           11.654321598221555,
           11.461087168246804,
           11.267852738272072,
           11.074618308297326,
           10.896589972605295,
           10.722118317657618,
           10.547646662709933,
           10.373175007762246,
           10.198703352814563,
           10.02423169786688,
           9.871524138306425,
           9.720169786359925,
           9.568815434413425,
           9.417461082466932,
           9.271242934829454,
           9.139906605646903,
           9.008570276464352,
           8.877233947281802,
           8.75416285834355,
           8.642035562832081,
           8.529908267320607,
           8.422446335235188,
           8.329256961650886,
           8.236067588066586,
           8.148846130622836,
           8.066399006091478,
           7.983951881560119,
           7.9015047570287615,
           7.819057632497412,
           7.736610507966061,
           7.654163383434703,
           7.571716258903346,
           7.4892691343719875,
           7.406822009840638,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           48.64806856710901,
           48.61749197854348,
           48.58691538997794,
           48.5563388014124,
           48.525762212846864,
           48.495185624281326,
           48.46460903571579,
           48.43403244715025,
           48.403455858584714,
           48.372879270019176,
           48.34230268145364,
           48.3117260928881,
           48.28114950432257,
           48.25057291575703,
           48.219996327191495,
           48.18941973862596,
           48.15884315006042,
           48.12826656149488,
           48.097689972929345,
           48.06711338436381,
           48.03653679579827,
           48.00596020723273,
           47.976624814552224,
           47.95349543367275,
           47.930366052793275,
           47.9072366719138,
           47.88410729103433,
           47.86097791015486,
           47.837848529275384,
           47.814719148395916,
           47.79158976751644,
           47.768460386636974,
           47.74533100575749,
           47.722201624878025,
           47.69907224399855,
           47.67594286311908,
           47.65281348223961,
           47.629684101360134,
           47.60655472048066,
           47.58342533960119,
           47.56029595872172,
           47.53716657784224,
           47.514037196962775,
           47.4909078160833,
           47.46777843520383,
           47.44464905432436,
           47.42151967344489,
           47.39839029256541,
           47.37526091168595,
           47.352131530806474,
           47.32900214992699,
           47.305872769047525,
           47.28274338816805,
           47.259614007288576,
           47.23648462640911,
           47.21335524552964,
           47.19022586465016,
           47.16709648377069,
           47.14396710289122,
           47.12083772201174,
           47.097708341132275,
           47.0745789602528,
           47.051449579373326,
           47.02832019849386,
           47.00519081761439,
           46.98206143673491,
           46.95893205585544,
           46.935802674975974,
           46.9126732940965,
           46.889543913217025,
           46.86641453233756,
           46.84328515145808,
           46.82015577057861,
           46.797026389699134,
           46.77389700881966,
           46.75076762794019,
           46.72763824706072,
           46.70450886618125,
           46.681379485301775,
           46.65825010442231,
           46.635120723542826,
           46.61199134266336,
           46.58886196178389,
           46.56573258090441,
           46.26552104725526,
           45.909893083052154,
           45.554265118849074,
           45.19863715464599,
           44.8430091904429,
           44.487381226239826,
           44.13175326203674,
           43.776125297833644,
           43.420497333630564,
           43.06486936942747,
           42.709241405224404,
           42.35361344102132,
           41.99798547681823,
           41.642357512615135,
           41.286729548412055,
           40.931101584208974,
           40.57547362000588,
           40.2198456558028,
           39.864217691599706,
           39.50858972739662,
           39.152961763193545,
           38.79733379899045,
           38.44170583478737,
           38.08607787058429,
           37.73044990638118,
           37.374821942178116,
           37.01919397797502,
           36.66356601377194,
           36.30793804956886,
           35.95231008536576,
           35.59668212116269,
           35.24105415695959,
           34.885426192756505,
           34.52979822855343,
           34.17417026435035,
           33.81854230014726,
           33.46291433594417,
           33.107286371741075,
           32.751658407538,
           32.39603044333492,
           32.04040247913183,
           31.684774514928755,
           31.329146550725646,
           30.97351858652258,
           30.617890622319493,
           30.262262658116402,
           29.906634693913325,
           29.55100672971022,
           29.195378765507147,
           28.83975080130406,
           28.48412283710097,
           28.128494872897896,
           27.772866908694805,
           27.417238944491718,
           27.061610980288627,
           26.70598301608554,
           26.350355051882467,
           25.99472708767938,
           25.63909912347629,
           25.283471159273216,
           24.92784319507011,
           24.57539917120274,
           24.226139078443182,
           23.87687898568362,
           23.527618892924078,
           23.1783588001645,
           22.829098707404956,
           22.479838614645395,
           22.130578521885838,
           21.78131842912629,
           21.432058336366715,
           21.082798243607172,
           20.733538150847608,
           20.38427805808805,
           20.035017965328503,
           19.685757872568942,
           19.336497779809385,
           18.98723768704982,
           18.637977594290263,
           18.28871750153072,
           17.939457408771155,
           17.590197316011597,
           17.240937223252054,
           16.976221314784194,
           16.753777498462217,
           16.531333682140232,
           16.308889865818244,
           16.086446049496274,
           15.864002233174276,
           15.641558416852298,
           15.419114600530307,
           15.196670784208322,
           14.974226967886343,
           14.757175287801147,
           14.55306472233966,
           14.348954156878161,
           14.144843591416661,
           13.940733025955172,
           13.736622460493674,
           13.532511895032176,
           13.328401329570678,
           13.124290764109178,
           12.920180198647689,
           12.71606963318619,
           12.520270075256363,
           12.32703564528163,
           12.133801215306878,
           11.940566785332145,
           11.747332355357404,
           11.554097925382662,
           11.36086349540793,
           11.167629065433179,
           10.991198658349171,
           10.816727003401486,
           10.642255348453803,
           10.467783693506126,
           10.293312038558444,
           10.118840383610756,
           9.962693420447659,
           9.811339068501159,
           9.65998471655467,
           9.50863036460817,
           9.357276012661668,
           9.224359314404609,
           9.09302298522206,
           8.961686656039511,
           8.830350326856959,
           8.717113344744897,
           8.604986049233425,
           8.492858753721954,
           8.392688612721512,
           8.299499239137212,
           8.20630986555291,
           8.122072366179417,
           8.039625241648066,
           7.957178117116708,
           7.874730992585351,
           7.792283868053993,
           7.709836743522643,
           7.627389618991291,
           7.544942494459934,
           7.462495369928576,
           7.380048245397219,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           48.29530257620442,
           48.26472598763888,
           48.234149399073345,
           48.20357281050781,
           48.17299622194227,
           48.14241963337674,
           48.1118430448112,
           48.081266456245665,
           48.05068986768013,
           48.02011327911459,
           47.98953669054906,
           47.958960101983514,
           47.92838351341798,
           47.897806924852446,
           47.86723033628691,
           47.83665374772137,
           47.80607715915583,
           47.775500570590296,
           47.74492398202476,
           47.71434739345922,
           47.68377080489368,
           47.653194216328146,
           47.62261762776261,
           47.59204103919707,
           47.56146445063153,
           47.530887862065995,
           47.50031127350046,
           47.46973468493492,
           47.43915809636938,
           47.408581507803845,
           47.37800491923831,
           47.34742833067277,
           47.31685174210724,
           47.2862751535417,
           47.255698564976164,
           47.22512197641063,
           47.19454538784509,
           47.16396879927955,
           47.133392210714014,
           47.10778042064775,
           47.084651039768275,
           47.06152165888881,
           47.03839227800933,
           47.01526289712986,
           46.99213351625039,
           46.96900413537092,
           46.94587475449145,
           46.922745373611974,
           46.8996159927325,
           46.87648661185303,
           46.85335723097356,
           46.83022785009408,
           46.80709846921461,
           46.78396908833514,
           46.76083970745567,
           46.73771032657619,
           46.714580945696724,
           46.69145156481725,
           46.66832218393778,
           46.64519280305831,
           46.62206342217883,
           46.59893404129936,
           46.57580466041989,
           46.552675279540416,
           46.52954589866095,
           46.506416517781474,
           46.483287136902,
           46.460157756022525,
           46.43702837514306,
           46.41389899426358,
           46.39076961338411,
           46.36764023250464,
           46.344510851625174,
           46.32138147074569,
           46.298252089866224,
           46.27512270898675,
           46.251993328107275,
           46.22886394722781,
           46.20573456634833,
           46.18260518546886,
           46.15947580458939,
           46.13634642370992,
           46.11321704283044,
           46.090087661950975,
           45.78987612830181,
           45.43424816409871,
           45.07862019989564,
           44.722992235692544,
           44.367364271489464,
           44.011736307286384,
           43.656108343083304,
           43.30048037888021,
           42.94485241467712,
           42.589224450474035,
           42.23359648627096,
           41.87796852206787,
           41.52234055786478,
           41.16671259366169,
           40.811084629458605,
           40.45545666525554,
           40.099828701052445,
           39.74420073684935,
           39.38857277264626,
           39.032944808443176,
           38.6773168442401,
           38.321688880037016,
           37.96606091583393,
           37.610432951630855,
           37.25480498742775,
           36.899177023224674,
           36.543549059021586,
           36.18792109481849,
           35.832293130615426,
           35.47666516641232,
           35.121037202209244,
           34.76540923800616,
           34.40978127380306,
           34.05415330959999,
           33.69852534539691,
           33.342897381193815,
           32.98726941699073,
           32.63164145278763,
           32.27601348858456,
           31.920385524381476,
           31.564757560178382,
           31.209129595975316,
           30.85350163177221,
           30.497873667569134,
           30.142245709030682,
           29.792985616271118,
           29.443725523511574,
           29.094465430751995,
           28.74520533799246,
           28.395945245232895,
           28.046685152473334,
           27.697425059713787,
           27.34816496695423,
           26.99890487419467,
           26.649644781435107,
           26.300384688675546,
           25.951124595916,
           25.601864503156442,
           25.25260441039688,
           24.903344317637337,
           24.55408422487776,
           24.204824132118215,
           23.855564039358654,
           23.506303946599097,
           23.157043853839554,
           22.807783761079975,
           22.45852366832043,
           22.109263575560874,
           21.76000348280131,
           21.410743390041766,
           21.061483297282187,
           20.712223204522644,
           20.362963111763083,
           20.013703019003522,
           19.66444292624398,
           19.315182833484418,
           18.965922740724857,
           18.6166626479653,
           18.267402555205738,
           17.91814246244619,
           17.568882369686634,
           17.219622276927073,
           16.87036218416753,
           16.605646275699673,
           16.383202459377692,
           16.16075864305571,
           15.93831482673372,
           15.715871010411748,
           15.493427194089753,
           15.270983377767774,
           15.050089803339963,
           14.845979237878467,
           14.641868672416978,
           14.43775810695547,
           14.23364754149398,
           14.029536976032484,
           13.825426410570984,
           13.621315845109494,
           13.417205279647998,
           13.213094714186498,
           13.008984148724998,
           12.806515262366977,
           12.613280832392244,
           12.4200464024175,
           12.22681197244276,
           12.033577542468027,
           11.840343112493276,
           11.647108682518542,
           11.453874252543798,
           11.260639822569058,
           11.08580734409307,
           10.911335689145377,
           10.736864034197701,
           10.562392379250017,
           10.387920724302333,
           10.213449069354656,
           10.05386270258892,
           9.902508350642417,
           9.75115399869592,
           9.599799646749421,
           9.448445294802928,
           9.308812023162323,
           9.177475693979773,
           9.04613936479723,
           8.914803035614682,
           8.792191126657729,
           8.680063831146255,
           8.56793653563478,
           8.456120263792142,
           8.362930890207846,
           8.269741516623546,
           8.177745726267371,
           8.095298601736012,
           8.012851477204656,
           7.930404352673306,
           7.847957228141948,
           7.765510103610591,
           7.683062979079232,
           7.600615854547883,
           7.518168730016531,
           7.435721605485174,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           47.942536585299806,
           47.911959996734275,
           47.88138340816873,
           47.85080681960319,
           47.82023023103766,
           47.789653642472125,
           47.75907705390659,
           47.72850046534105,
           47.69792387677552,
           47.66734728820998,
           47.636770699644444,
           47.6061941110789,
           47.57561752251337,
           47.54504093394783,
           47.514464345382294,
           47.483887756816756,
           47.45331116825122,
           47.42273457968568,
           47.39215799112014,
           47.361581402554606,
           47.33100481398907,
           47.30042822542353,
           47.26985163685799,
           47.239275048292455,
           47.20869845972692,
           47.17812187116138,
           47.14754528259585,
           47.116968694030305,
           47.086392105464775,
           47.05581551689924,
           47.0252389283337,
           46.99466233976816,
           46.96408575120263,
           46.933509162637094,
           46.902932574071556,
           46.87235598550602,
           46.84177939694048,
           46.811202808374944,
           46.7806262198094,
           46.75004963124387,
           46.71947304267833,
           46.68889645411279,
           46.658319865547256,
           46.62774327698172,
           46.59716668841618,
           46.56659009985064,
           46.536013511285105,
           46.50543692271957,
           46.47486033415403,
           46.44428374558849,
           46.41370715702296,
           46.383130568457425,
           46.35255397989189,
           46.32197739132635,
           46.29140080276081,
           46.262065407622714,
           46.23893602674325,
           46.21580664586377,
           46.192677264984304,
           46.16954788410483,
           46.146418503225355,
           46.12328912234588,
           46.10015974146641,
           46.07703036058694,
           46.053900979707464,
           46.030771598828,
           46.00764221794852,
           45.98451283706905,
           45.96138345618958,
           45.938254075310105,
           45.91512469443063,
           45.891995313551156,
           45.86886593267168,
           45.84573655179222,
           45.82260717091274,
           45.79947779003327,
           45.776348409153805,
           45.75321902827433,
           45.730089647394855,
           45.70696026651538,
           45.68383088563591,
           45.66070150475644,
           45.637572123876964,
           45.61444274299749,
           45.31423120934834,
           44.95860324514524,
           44.60297528094217,
           44.247347316739074,
           43.891719352535986,
           43.53609138833291,
           43.180463424129826,
           42.82483545992673,
           42.469207495723644,
           42.11357953152056,
           41.75795156731749,
           41.4023236031144,
           41.04669563891131,
           40.691067674708215,
           40.335439710505135,
           39.979811746302055,
           39.62418378209897,
           39.26855581789588,
           38.91292785369279,
           38.5572998894897,
           38.20167192528663,
           37.84604396108354,
           37.49041599688045,
           37.13478803267738,
           36.77916006847427,
           36.4235321042712,
           36.06790414006811,
           35.712276175865014,
           35.359832154099045,
           35.01057206133947,
           34.66131196857992,
           34.312051875820366,
           33.9627917830608,
           33.61353169030126,
           33.26427159754169,
           32.915011504782136,
           32.56575141202258,
           32.216491319263014,
           31.86723122650347,
           31.517971133743913,
           31.168711040984352,
           30.819450948224805,
           30.470190855465233,
           30.120930762705683,
           29.77167066994613,
           29.422410577186568,
           29.073150484427018,
           28.723890391667446,
           28.374630298907903,
           28.02537020614834,
           27.67611011338878,
           27.326850020629237,
           26.977589927869676,
           26.628329835110115,
           26.279069742350554,
           25.929809649590993,
           25.58054955683145,
           25.23128946407189,
           24.882029371312328,
           24.532769278552784,
           24.183509185793206,
           23.834249093033662,
           23.484989000274105,
           23.135728907514544,
           22.786468814755,
           22.43720872199542,
           22.08794862923588,
           21.738688536476317,
           21.389428443716756,
           21.040168350957213,
           20.690908258197634,
           20.34164816543809,
           19.99238807267853,
           19.64312797991897,
           19.293867887159426,
           18.944607794399865,
           18.595347701640303,
           18.246087608880746,
           17.89682751612118,
           17.547567423361638,
           17.19830733060208,
           16.84904723784252,
           16.499787145082976,
           16.235071236615116,
           16.01262742029314,
           15.790183603971157,
           15.567739787649165,
           15.345295971327197,
           15.13889375341725,
           14.93478318795576,
           14.73067262249426,
           14.526562057032764,
           14.322451491571275,
           14.118340926109767,
           13.91423036064828,
           13.710119795186781,
           13.506009229725281,
           13.301898664263792,
           13.097788098802294,
           12.899526019502835,
           12.706291589528092,
           12.51305715955335,
           12.319822729578618,
           12.126588299603874,
           11.933353869629133,
           11.7401194396544,
           11.546885009679649,
           11.354887684784627,
           11.180416029836941,
           11.005944374889257,
           10.83147271994158,
           10.657001064993887,
           10.48252941004621,
           10.308057755098526,
           10.145031984730156,
           9.993677632783662,
           9.842323280837164,
           9.690968928890664,
           9.539614576944164,
           9.393264731920024,
           9.261928402737482,
           9.130592073554931,
           8.99925574437238,
           8.867919415189839,
           8.755141613059076,
           8.643014317547602,
           8.530887022036127,
           8.426362541278467,
           8.333173167694166,
           8.239983794109872,
           8.150971961823954,
           8.068524837292596,
           7.986077712761238,
           7.903630588229881,
           7.821183463698531,
           7.738736339167173,
           7.656289214635815,
           7.573842090104458,
           7.491394965573107,
           7.408947841041757,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           47.5897705943952,
           47.55919400582966,
           47.52861741726412,
           47.498040828698585,
           47.46746424013305,
           47.43688765156751,
           47.40631106300197,
           47.375734474436435,
           47.345157885870904,
           47.31458129730537,
           47.28400470873983,
           47.25342812017429,
           47.222851531608754,
           47.192274943043216,
           47.16169835447768,
           47.13112176591214,
           47.1005451773466,
           47.069968588781066,
           47.03939200021553,
           47.00881541164999,
           46.97823882308445,
           46.947662234518916,
           46.91708564595338,
           46.88650905738785,
           46.8559324688223,
           46.825355880256765,
           46.794779291691235,
           46.76420270312569,
           46.73362611456017,
           46.70304952599462,
           46.672472937429085,
           46.64189634886355,
           46.61131976029802,
           46.58074317173248,
           46.55016658316694,
           46.519589994601404,
           46.489013406035866,
           46.45843681747033,
           46.427860228904784,
           46.39728364033925,
           46.366707051773716,
           46.33613046320818,
           46.30555387464264,
           46.2749772860771,
           46.244400697511566,
           46.21382410894603,
           46.18324752038049,
           46.15267093181495,
           46.122094343249415,
           46.09151775468388,
           46.06094116611834,
           46.0303645775528,
           45.99978798898727,
           45.96921140042173,
           45.9386348118562,
           45.90805822329066,
           45.87748163472512,
           45.84690504615958,
           45.81632845759405,
           45.78575186902851,
           45.75517528046297,
           45.72459869189744,
           45.6940221033319,
           45.663445514766366,
           45.63286892620083,
           45.60229233763529,
           45.57171574906975,
           45.541139160504216,
           45.51056257193868,
           45.47998598337314,
           45.4494093948076,
           45.418832806242065,
           45.39322101371821,
           45.370091632838744,
           45.34696225195927,
           45.323832871079794,
           45.30070349020033,
           45.27757410932085,
           45.25444472844138,
           45.2313153475619,
           45.208185966682436,
           45.18505658580296,
           45.161927204923494,
           45.13879782404402,
           44.83858629039487,
           44.48295832619176,
           44.12733036198869,
           43.7717023977856,
           43.41607443358251,
           43.06044646937944,
           42.704818505176355,
           42.349190540973254,
           41.99356257677017,
           41.63793461256708,
           41.28230664836401,
           40.92667869192696,
           40.5774185991674,
           40.22815850640784,
           39.87889841364827,
           39.529638320888736,
           39.18037822812917,
           38.831118135369614,
           38.48185804261006,
           38.13259794985049,
           37.78333785709094,
           37.43407776433139,
           37.08481767157183,
           36.73555757881228,
           36.386297486052705,
           36.03703739329316,
           35.6877773005336,
           35.33851720777404,
           34.989257115014496,
           34.63999702225492,
           34.290736929495374,
           33.941476836735816,
           33.59221674397625,
           33.24295665121671,
           32.893696558457144,
           32.544436465697586,
           32.19517637293803,
           31.84591628017846,
           31.496656187418917,
           31.14739609465936,
           30.7981360018998,
           30.448875909140256,
           30.099615816380677,
           29.750355723621134,
           29.401095630861573,
           29.051835538102015,
           28.702575445342468,
           28.35331535258289,
           28.00405525982335,
           27.654795167063785,
           27.305535074304228,
           26.956274981544684,
           26.60701488878512,
           26.257754796025562,
           25.908494703266,
           25.55923461050644,
           25.209974517746897,
           24.860714424987336,
           24.511454332227775,
           24.16219423946823,
           23.812934146708653,
           23.46367405394911,
           23.114413961189552,
           22.765153868429987,
           22.415893775670444,
           22.066633682910865,
           21.717373590151322,
           21.368113497391764,
           21.018853404632203,
           20.669593311872656,
           20.32033321911308,
           19.971073126353534,
           19.621813033593977,
           19.272552940834416,
           18.923292848074873,
           18.57403275531531,
           18.22477266255575,
           17.875512569796193,
           17.526252477036632,
           17.17699238427709,
           16.827732291517528,
           16.478472198757967,
           16.129212105998423,
           15.864496197530567,
           15.642052381208588,
           15.431808268956043,
           15.227697703494545,
           15.023587138033054,
           14.819476572571547,
           14.615366007110058,
           14.41125544164856,
           14.207144876187062,
           14.003034310725573,
           13.798923745264066,
           13.594813179802577,
           13.390702614341077,
           13.186592048879579,
           12.992536776638692,
           12.79930234666395,
           12.60606791668921,
           12.412833486714465,
           12.219599056739725,
           12.026364626764991,
           11.833130196790247,
           11.639895766815508,
           11.449496370528502,
           11.275024715580809,
           11.100553060633136,
           10.92608140568545,
           10.751609750737765,
           10.57713809579009,
           10.402666440842395,
           10.236201266871396,
           10.084846914924897,
           9.9334925629784,
           9.782138211031906,
           9.630783859085408,
           9.479429507138907,
           9.346381111495182,
           9.215044782312631,
           9.08370845313009,
           8.952372123947539,
           8.83021939497189,
           8.71809209946042,
           8.605964803948947,
           8.493837508437474,
           8.396604818764791,
           8.303415445180493,
           8.21022607159619,
           8.124198197380544,
           8.041751072849184,
           7.959303948317826,
           7.876856823786469,
           7.7944096992551115,
           7.711962574723762,
           7.629515450192404,
           7.547068325661046,
           7.464621201129688,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           47.22167044302791,
           47.19109385446238,
           47.160517265896836,
           47.1299406773313,
           47.09936408876577,
           47.06878750020023,
           47.03821091163469,
           47.007634323069155,
           46.97705773450362,
           46.94648114593808,
           46.91590455737254,
           46.885327968807005,
           46.85475138024147,
           46.82417479167594,
           46.7935982031104,
           46.763021614544854,
           46.73244502597932,
           46.701868437413786,
           46.67129184884825,
           46.640715260282704,
           46.61013867171717,
           46.579562083151636,
           46.5489854945861,
           46.51840890602056,
           46.48783231745502,
           46.457255728889486,
           46.426679140323955,
           46.39610255175841,
           46.36552596319288,
           46.33494937462734,
           46.304372786061805,
           46.27379619749627,
           46.24321960893073,
           46.21264302036519,
           46.182066431799655,
           46.15148984323412,
           46.12091325466858,
           46.09033666610304,
           46.059760077537504,
           46.02918348897197,
           45.99860690040643,
           45.96803031184089,
           45.937453723275354,
           45.906877134709816,
           45.876300546144286,
           45.84572395757874,
           45.815147369013204,
           45.78457078044767,
           45.753994191882136,
           45.7234176033166,
           45.69284101475106,
           45.66226442618552,
           45.631687837619985,
           45.60111124905445,
           45.57053466048891,
           45.53995807192338,
           45.50938148335784,
           45.4788048947923,
           45.44822830622677,
           45.41765171766123,
           45.38707512909569,
           45.356498540530154,
           45.32592195196462,
           45.29534536339908,
           45.26476877483354,
           45.234192186268004,
           45.203615597702466,
           45.17303900913693,
           45.14246242057139,
           45.11188583200586,
           45.08130924344032,
           45.050732654874786,
           45.02015606630925,
           44.98957947774371,
           44.95900288917817,
           44.928426300612635,
           44.8978497120471,
           44.86727312348156,
           44.83669653491602,
           44.802640465195054,
           44.76510493079319,
           44.72756939639133,
           44.69003386198948,
           44.65249832758762,
           44.36541397505513,
           44.028419858896484,
           43.69142574273787,
           43.35443162657925,
           43.01539319550631,
           42.66613310274676,
           42.316873009987205,
           41.96761291722765,
           41.61835282446808,
           41.269092731708525,
           40.91983263894898,
           40.57057254618942,
           40.22131245342986,
           39.872052360670295,
           39.52279226791074,
           39.173532175151195,
           38.82427208239163,
           38.47501198963207,
           38.125751896872515,
           37.77649180411295,
           37.42723171135341,
           37.07797161859385,
           36.728711525834285,
           36.37945143307474,
           36.03019134031516,
           35.68093124755562,
           35.331671154796055,
           34.9824110620365,
           34.633150969276954,
           34.283890876517376,
           33.93463078375783,
           33.585370690998275,
           33.23611059823871,
           32.88685050547917,
           32.5375904127196,
           32.188330319960045,
           31.839070227200487,
           31.489810134440926,
           31.14055004168138,
           30.791289948921822,
           30.44202985616226,
           30.092769763402718,
           29.743509670643142,
           29.394249577883595,
           29.044989485124038,
           28.695729392364477,
           28.34646929960493,
           27.99720920684535,
           27.64794911408581,
           27.298689021326247,
           26.94942892856669,
           26.600168835807146,
           26.25090874304758,
           25.901648650288024,
           25.552388557528463,
           25.203128464768902,
           24.85386837200936,
           24.504608279249798,
           24.155348186490237,
           23.806088093730693,
           23.456828000971115,
           23.10756790821157,
           22.758307815452014,
           22.40904772269245,
           22.059787629932906,
           21.71052753717333,
           21.361267444413787,
           21.012007351654226,
           20.66274725889466,
           20.31348716613512,
           19.964227073375543,
           19.614966980616,
           19.26570688785644,
           18.916446795096878,
           18.567186702337334,
           18.217926609577773,
           17.868666516818216,
           17.51940642405865,
           17.170146331299094,
           16.82088623853955,
           16.47162614577999,
           16.12236605302043,
           15.773105960260883,
           15.520612219033353,
           15.316501653571864,
           15.112391088110364,
           14.908280522648866,
           14.704169957187379,
           14.50005939172587,
           14.295948826264382,
           14.091838260802884,
           13.887727695341384,
           13.683617129879895,
           13.479506564418388,
           13.278781963749307,
           13.085547533774562,
           12.892313103799822,
           12.699078673825088,
           12.505844243850348,
           12.312609813875603,
           12.119375383900863,
           11.92614095392612,
           11.732906523951387,
           11.544105056272393,
           11.369633401324709,
           11.195161746377032,
           11.020690091429337,
           10.846218436481664,
           10.671746781533978,
           10.497275126586295,
           10.327370549012656,
           10.176016197066149,
           10.024661845119658,
           9.873307493173158,
           9.72195314122666,
           9.570598789280167,
           9.430833820252904,
           9.299497491070353,
           9.168161161887802,
           9.036824832705253,
           8.90548850352271,
           8.793169881373247,
           8.681042585861775,
           8.568915290350306,
           8.460036469835426,
           8.366847096251126,
           8.273657722666826,
           8.180468349082526,
           8.097424432937132,
           8.014977308405783,
           7.932530183874424,
           7.850083059343067,
           7.767635934811709,
           7.685188810280352,
           7.6027416857490016,
           7.520294561217643,
           7.437847436686286,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           46.81468725745957,
           46.78411066889403,
           46.75353408032849,
           46.722957491762955,
           46.69238090319742,
           46.661804314631894,
           46.63122772606634,
           46.60065113750081,
           46.57007454893528,
           46.53949796036973,
           46.508921371804206,
           46.478344783238654,
           46.44776819467313,
           46.41719160610759,
           46.38661501754205,
           46.35603842897652,
           46.32546184041097,
           46.29488525184544,
           46.264308663279905,
           46.23373207471436,
           46.20315548614883,
           46.17257889758329,
           46.142002309017755,
           46.11142572045222,
           46.08084913188668,
           46.05027254332114,
           46.01969595475561,
           45.98911936619007,
           45.95854277762453,
           45.92796618905899,
           45.897389600493455,
           45.866813011927924,
           45.83623642336238,
           45.80565983479685,
           45.77508324623131,
           45.744506657665774,
           45.713930069100236,
           45.6833534805347,
           45.65277689196916,
           45.622200303403616,
           45.591623714838086,
           45.56104712627254,
           45.53047053770701,
           45.49989394914147,
           45.46931736057594,
           45.4387407720104,
           45.40816418344486,
           45.37758759487932,
           45.34701100631379,
           45.31643441774825,
           45.28585782918271,
           45.25528124061717,
           45.22470465205164,
           45.1941280634861,
           45.16355147492057,
           45.13297488635503,
           45.10239829778949,
           45.071821709223954,
           45.04124512065842,
           45.01066853209288,
           44.98009194352734,
           44.949515354961804,
           44.918938761953136,
           44.88140322755128,
           44.84386769314941,
           44.806332158747566,
           44.768796624345704,
           44.73126108994384,
           44.69372555554198,
           44.65619002114013,
           44.61865448673827,
           44.58111895233641,
           44.54358341793455,
           44.506047883532695,
           44.46851234913083,
           44.43097681472898,
           44.39344128032711,
           44.35590574592526,
           44.3183702115234,
           44.28083467712154,
           44.24329914271968,
           44.205763608317824,
           44.16822807391597,
           44.13069253951411,
           43.84360818698161,
           43.50661407082297,
           43.169619954664356,
           42.832625838505734,
           42.49563172234711,
           42.1586376061885,
           41.82164349002988,
           41.48464937387126,
           41.14765525771262,
           40.810661141554,
           40.473667025395386,
           40.136672909236765,
           39.79967879307814,
           39.46268467691951,
           39.12569056076089,
           38.78869644460228,
           38.45170232844365,
           38.11470821228503,
           37.7777140961264,
           37.44071997996778,
           37.103725863809174,
           36.758554437748145,
           36.40929434498859,
           36.060034252229045,
           35.710774159469466,
           35.361514066709915,
           35.01225397395036,
           34.6629938811908,
           34.31373378843125,
           33.96447369567168,
           33.61521360291213,
           33.26595351015257,
           32.91669341739301,
           32.56743332463346,
           32.218173231873905,
           31.868913139114348,
           31.519653046354783,
           31.170392953595226,
           30.821132860835675,
           30.471872768076118,
           30.12261267531656,
           29.773352582557017,
           29.424092489797438,
           29.074832397037895,
           28.725572304278334,
           28.376312211518776,
           28.02705211875923,
           27.67779202599965,
           27.32853193324011,
           26.979271840480546,
           26.630011747720992,
           26.280751654961442,
           25.931491562201884,
           25.58223146944232,
           25.232971376682762,
           24.883711283923205,
           24.534451191163654,
           24.185191098404097,
           23.835931005644532,
           23.48667091288499,
           23.137410820125417,
           22.788150727365867,
           22.43889063460631,
           22.089630541846752,
           21.74037044908721,
           21.39111035632763,
           21.041850263568087,
           20.692590170808522,
           20.34333007804896,
           19.994069985289418,
           19.644809892529842,
           19.2955497997703,
           18.946289707010735,
           18.597029614251177,
           18.247769521491634,
           17.898509428732073,
           17.54924933597251,
           17.19998924321295,
           16.85072915045339,
           16.501469057693846,
           16.15220896493429,
           15.802948872174726,
           15.453688779415181,
           15.201195038187652,
           14.997084472726163,
           14.792973907264663,
           14.588863341803165,
           14.384752776341676,
           14.180642210880167,
           13.976531645418678,
           13.77242107995718,
           13.568310514495682,
           13.371792720885164,
           13.178558290910413,
           12.98532386093568,
           12.792089430960939,
           12.598855000986195,
           12.405620571011463,
           12.21238614103672,
           12.019151711061978,
           11.825917281087237,
           11.638713742016261,
           11.464242087068587,
           11.289770432120902,
           11.115298777173216,
           10.94082712222554,
           10.766355467277847,
           10.591883812330174,
           10.41853983115389,
           10.267185479207392,
           10.1158311272609,
           9.964476775314393,
           9.8131224233679,
           9.661768071421402,
           9.515286529010602,
           9.38395019982806,
           9.252613870645511,
           9.12127754146296,
           8.98994121228041,
           8.868247663286063,
           8.756120367774594,
           8.64399307226312,
           8.531865776751648,
           8.430278747321752,
           8.337089373737452,
           8.24390000015315,
           8.153097793025093,
           8.070650668493736,
           7.988203543962378,
           7.905756419431027,
           7.82330929489967,
           7.740862170368311,
           7.658415045836954,
           7.575967921305597,
           7.493520796774247,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           46.40770407189126,
           46.37712748332572,
           46.34655089476018,
           46.31597430619465,
           46.28539771762911,
           46.25482112906357,
           46.224244540498034,
           46.1936679519325,
           46.16309136336696,
           46.13251477480142,
           46.101938186235884,
           46.07136159767035,
           46.04078500910481,
           46.01020842053928,
           45.97963183197374,
           45.9490552434082,
           45.918478654842666,
           45.88790206627713,
           45.85732547771159,
           45.82674888914606,
           45.796172300580515,
           45.76559571201498,
           45.73501912344944,
           45.70444253488391,
           45.673865946318365,
           45.643289357752835,
           45.6127127691873,
           45.58213618062175,
           45.55155959205622,
           45.520983003490684,
           45.49040641492515,
           45.45982982635961,
           45.42925323779407,
           45.39867664922854,
           45.368100060663,
           45.33752347209746,
           45.30694688353193,
           45.276370294966384,
           45.245793706400846,
           45.21521711783531,
           45.18464052926978,
           45.15406394070423,
           45.1234873521387,
           45.092910763573165,
           45.062334175007635,
           45.03175758644209,
           44.9977015243094,
           44.96016598990754,
           44.92263045550568,
           44.88509492110383,
           44.84755938670196,
           44.810023852300105,
           44.77248831789825,
           44.73495278349639,
           44.697417249094535,
           44.65988171469267,
           44.62234618029082,
           44.58481064588896,
           44.547275111487096,
           44.50973957708525,
           44.47220404268338,
           44.434668508281526,
           44.397132973879664,
           44.35959743947781,
           44.32206190507594,
           44.284526370674094,
           44.24699083627223,
           44.20945530187037,
           44.17191976746851,
           44.134384233066655,
           44.0968486986648,
           44.05931316426294,
           44.02177762986108,
           43.98424209545922,
           43.94670656105737,
           43.90917102665551,
           43.871635492253645,
           43.834099957851784,
           43.79656442344992,
           43.75902888904807,
           43.72149335464621,
           43.68395782024435,
           43.64642228584249,
           43.608886751440636,
           43.32180239890814,
           42.984808282749505,
           42.64781416659089,
           42.31082005043226,
           41.97382593427364,
           41.63683181811503,
           41.299837701956406,
           40.96284358579778,
           40.62584946963915,
           40.28885535348053,
           39.951861237321914,
           39.61486712116329,
           39.27787300500467,
           38.940878888846036,
           38.603884772687415,
           38.26689065652881,
           37.92989654037018,
           37.59290242421156,
           37.25590830805293,
           36.91891419189431,
           36.5819200757357,
           36.244925959577074,
           35.907931843418446,
           35.57093772725984,
           35.233943611101196,
           34.89694949494259,
           34.55995537878397,
           34.22296126262534,
           33.885967146466726,
           33.54897303030809,
           33.211978914149476,
           32.874984797990855,
           32.53799068183223,
           32.20099656567361,
           31.86400244951499,
           31.527008333356363,
           31.190014217197742,
           30.850975772749543,
           30.50171567999,
           30.152455587230442,
           29.803195494470877,
           29.45393540171134,
           29.104675308951762,
           28.755415216192215,
           28.406155123432654,
           28.056895030673097,
           27.707634937913554,
           27.358374845153975,
           27.00911475239443,
           26.659854659634867,
           26.31059456687531,
           25.961334474115766,
           25.6120743813562,
           25.262814288596644,
           24.91355419583708,
           24.564294103077522,
           24.21503401031798,
           23.86577391755842,
           23.516513824798857,
           23.167253732039313,
           22.817993639279734,
           22.46873354652019,
           22.119473453760634,
           21.77021336100107,
           21.420953268241526,
           21.071693175481947,
           20.722433082722404,
           20.373172989962846,
           20.023912897203285,
           19.67465280444374,
           19.325392711684163,
           18.97613261892462,
           18.62687252616506,
           18.277612433405498,
           17.928352340645954,
           17.579092247886393,
           17.229832155126836,
           16.88057206236727,
           16.531311969607714,
           16.18205187684817,
           15.83279178408861,
           15.483531691329047,
           15.134271598569503,
           14.881777857341973,
           14.677667291880484,
           14.473556726418987,
           14.269446160957488,
           14.065335595495998,
           13.861225030034491,
           13.658037907995777,
           13.464803478021034,
           13.271569048046292,
           13.07833461807156,
           12.88510018809681,
           12.691865758122075,
           12.498631328147333,
           12.305396898172592,
           12.112162468197859,
           11.918928038223118,
           11.733322427760159,
           11.558850772812477,
           11.38437911786479,
           11.209907462917117,
           11.03543580796943,
           10.860964153021747,
           10.686492498074069,
           10.512020843126376,
           10.35835476134865,
           10.207000409402152,
           10.055646057455654,
           9.904291705509161,
           9.752937353562656,
           9.601583001616163,
           9.468402908585775,
           9.337066579403224,
           9.20573025022068,
           9.074393921038132,
           8.943325445198894,
           8.83119814968742,
           8.719070854175948,
           8.60694355866448,
           8.494816263153005,
           8.400521024808082,
           8.307331651223787,
           8.214142277639487,
           8.126324028581667,
           8.043876904050332,
           7.961429779518975,
           7.878982654987618,
           7.796535530456267,
           7.714088405924909,
           7.631641281393551,
           7.549194156862194,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           46.00072088632291,
           45.97014429775738,
           45.939567709191834,
           45.9089911206263,
           45.878414532060766,
           45.84783794349522,
           45.81726135492969,
           45.78668476636415,
           45.75610817779862,
           45.72553158923308,
           45.69495500066754,
           45.66437841210201,
           45.633801823536466,
           45.603225234970935,
           45.57264864640539,
           45.54207205783986,
           45.511495469274315,
           45.480918880708785,
           45.45034229214325,
           45.41976570357771,
           45.38918911501217,
           45.358612526446635,
           45.3280359378811,
           45.29745934931556,
           45.266882760750015,
           45.236306172184484,
           45.205729583618954,
           45.17515299505341,
           45.14457640648787,
           45.113999817922334,
           45.076464286665626,
           45.038928752263764,
           45.0013932178619,
           44.96385768346005,
           44.92632214905819,
           44.888786614656325,
           44.85125108025447,
           44.81371554585262,
           44.776180011450755,
           44.738644477048894,
           44.70110894264704,
           44.663573408245185,
           44.62603787384332,
           44.58850233944146,
           44.5509668050396,
           44.51343127063774,
           44.475895736235884,
           44.43836020183402,
           44.40082466743217,
           44.363289133030314,
           44.325753598628445,
           44.28821806422659,
           44.250682529824736,
           44.213146995422875,
           44.17561146102102,
           44.13807592661916,
           44.100540392217304,
           44.063004857815436,
           44.02546932341358,
           43.98793378901173,
           43.950398254609865,
           43.91286272020801,
           43.87532718580614,
           43.83779165140429,
           43.800256117002434,
           43.76272058260058,
           43.72518504819872,
           43.687649513796856,
           43.650113979395,
           43.61257844499314,
           43.57504291059128,
           43.537507376189424,
           43.49997184178756,
           43.4624363073857,
           43.42490077298385,
           43.387365238581985,
           43.349829704180124,
           43.31229416977827,
           43.274758635376415,
           43.23722310097455,
           43.19968756657269,
           43.16215203217084,
           43.12461649776898,
           43.087080963367114,
           42.799996610834626,
           42.46300249467598,
           42.12600837851737,
           41.78901426235875,
           41.45202014620013,
           41.11502603004151,
           40.77803191388289,
           40.44103779772426,
           40.104043681565635,
           39.767049565407014,
           39.4300554492484,
           39.09306133308978,
           38.75606721693115,
           38.41907310077252,
           38.0820789846139,
           37.745084868455294,
           37.408090752296665,
           37.07109663613804,
           36.734102519979416,
           36.397108403820795,
           36.06011428766219,
           35.72312017150355,
           35.38612605534493,
           35.049131939186324,
           34.71213782302768,
           34.375143706869075,
           34.03814959071045,
           33.70115547455182,
           33.36416135839321,
           33.02716724223457,
           32.69017312607596,
           32.35317900991733,
           32.016184893758705,
           31.6791907776001,
           31.342196661441474,
           31.00520254528285,
           30.668208429124224,
           30.331214312965596,
           29.99422019680699,
           29.657226080648364,
           29.32023196448974,
           28.98323784833113,
           28.64624373217249,
           28.30924961601388,
           27.972255499855255,
           27.63526138369663,
           27.29826726753802,
           26.96127315137938,
           26.624279035220766,
           26.287284919062145,
           25.950290802903517,
           25.61329668674491,
           25.27630257058628,
           24.93930845442766,
           24.594137014991382,
           24.24487692223182,
           23.895616829472274,
           23.546356736712717,
           23.197096643953152,
           22.84783655119361,
           22.498576458434034,
           22.14931636567449,
           21.80005627291493,
           21.45079618015537,
           21.101536087395825,
           20.75227599463625,
           20.403015901876703,
           20.053755809117146,
           19.70449571635758,
           19.355235623598038,
           19.005975530838462,
           18.656715438078916,
           18.307455345319354,
           17.958195252559797,
           17.60893515980025,
           17.259675067040693,
           16.91041497428113,
           16.56115488152157,
           16.21189478876201,
           15.862634696002466,
           15.513374603242905,
           15.164114510483344,
           14.8148544177238,
           14.56236067649627,
           14.358250111034781,
           14.154139545573283,
           13.950028980111785,
           13.751048665131634,
           13.557814235156883,
           13.36457980518215,
           13.171345375207409,
           12.978110945232666,
           12.784876515257933,
           12.591642085283183,
           12.39840765530845,
           12.20517322533371,
           12.011938795358967,
           11.82793111350404,
           11.653459458556354,
           11.47898780360867,
           11.304516148660987,
           11.130044493713301,
           10.955572838765626,
           10.78110118381794,
           10.606629528870258,
           10.449524043489893,
           10.298169691543388,
           10.146815339596895,
           9.995460987650397,
           9.844106635703898,
           9.692752283757406,
           9.552855617343475,
           9.421519288160932,
           9.29018295897838,
           9.158846629795832,
           9.027510300613288,
           8.906275931600241,
           8.794148636088767,
           8.682021340577295,
           8.569894045065821,
           8.463952675878707,
           8.370763302294408,
           8.277573928710106,
           8.184384555125812,
           8.099550264138259,
           8.0171031396069,
           7.934656015075563,
           7.8522088905442065,
           7.769761766012849,
           7.687314641481499,
           7.604867516950141,
           7.522420392418784,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           45.593737700754566,
           45.56316111218903,
           45.53258452362349,
           45.502007935057954,
           45.471431346492416,
           45.440854757926886,
           45.41027816936134,
           45.3797015807958,
           45.34912499223027,
           45.318548403664735,
           45.2879718150992,
           45.25739522653366,
           45.22681863796812,
           45.1927625834237,
           45.15522704902184,
           45.11769151461999,
           45.08015598021813,
           45.04262044581627,
           45.00508491141441,
           44.96754937701255,
           44.9300138426107,
           44.89247830820884,
           44.854942773806975,
           44.81740723940512,
           44.77987170500326,
           44.742336170601405,
           44.70480063619955,
           44.66726510179769,
           44.62972956739583,
           44.592194032993966,
           44.554658498592104,
           44.51712296419025,
           44.479587429788396,
           44.442051895386534,
           44.40451636098468,
           44.36698082658282,
           44.329445292180964,
           44.2919097577791,
           44.25437422337724,
           44.216838688975386,
           44.179303154573525,
           44.14176762017166,
           44.10423208576981,
           44.06669655136795,
           44.02916101696609,
           43.99162548256423,
           43.95408994816238,
           43.91655441376051,
           43.879018879358654,
           43.8414833449568,
           43.80394781055494,
           43.76641227615308,
           43.72887674175122,
           43.69134120734937,
           43.65380567294751,
           43.616270138545644,
           43.57873460414379,
           43.54119906974193,
           43.50366353534007,
           43.46612800093821,
           43.42859246653635,
           43.3910569321345,
           43.353521397732635,
           43.31598586333078,
           43.278450328928926,
           43.24091479452706,
           43.2033792601252,
           43.16584372572335,
           43.12830819132148,
           43.090772656919626,
           43.053237122517764,
           43.0157015881159,
           42.978166053714055,
           42.940630519312194,
           42.90309498491034,
           42.86555945050847,
           42.828023916106616,
           42.79048838170476,
           42.75295284730289,
           42.71541731290104,
           42.67788177849918,
           42.64034624409732,
           42.60281070969547,
           42.5652751752936,
           42.278190822761104,
           41.94119670660247,
           41.604202590443855,
           41.26720847428523,
           40.930214358126605,
           40.59322024196799,
           40.25622612580938,
           39.91923200965075,
           39.58223789349213,
           39.2452437773335,
           38.90824966117489,
           38.571255545016264,
           38.234261428857636,
           37.897267312699014,
           37.560273196540386,
           37.22327908038178,
           36.88628496422315,
           36.54929084806452,
           36.21229673190591,
           35.87530261574728,
           35.538308499588666,
           35.20131438343004,
           34.864320267271424,
           34.52732615111281,
           34.19033203495417,
           33.85333791879556,
           33.51634380263693,
           33.17934968647831,
           32.842355570319704,
           32.505361454161054,
           32.16836733800245,
           31.831373221843826,
           31.494379105685198,
           31.15738498952659,
           30.820390873367963,
           30.483396757209334,
           30.146402641050713,
           29.80940852489209,
           29.472414408733478,
           29.13542029257485,
           28.798426176416225,
           28.461432060257618,
           28.12443794409898,
           27.78744382794037,
           27.450449711781744,
           27.113455595623115,
           26.77646147946451,
           26.439467363305866,
           26.102473247147255,
           25.76547913098863,
           25.42848501483001,
           25.0914908986714,
           24.75449678251277,
           24.417502666354146,
           24.08050855019552,
           23.743514434036896,
           23.406520317878286,
           23.06952620171966,
           22.732532085561036,
           22.395537969402426,
           22.058543853243783,
           21.721549737085176,
           21.384555620926548,
           21.047561504767923,
           20.710567388609313,
           20.37357327245067,
           20.036579156292063,
           19.699585040133442,
           19.362590923974814,
           19.025596807816203,
           18.686558349992758,
           18.337298257233215,
           17.988038164473654,
           17.638778071714093,
           17.28951797895455,
           16.94025788619499,
           16.590997793435427,
           16.24173770067587,
           15.892477607916307,
           15.543217515156764,
           15.193957422397203,
           14.844697329637643,
           14.4954372368781,
           14.24294349565057,
           14.038832930189079,
           13.844059422267485,
           13.65082499229274,
           13.457590562318007,
           13.264356132343257,
           13.071121702368526,
           12.877887272393783,
           12.684652842419041,
           12.49141841244431,
           12.298183982469556,
           12.104949552494825,
           11.922539799247913,
           11.748068144300227,
           11.573596489352548,
           11.399124834404862,
           11.22465317945718,
           11.050181524509496,
           10.87570986956181,
           10.701238214614134,
           10.54069332563113,
           10.38933897368463,
           10.237984621738137,
           10.08663026979163,
           9.93527591784514,
           9.783921565898641,
           9.637308326101182,
           9.505971996918639,
           9.374635667736083,
           9.24329933855354,
           9.111963009370989,
           8.981353713513055,
           8.869226418001588,
           8.757099122490114,
           8.64497182697864,
           8.532844531467166,
           8.43419495336503,
           8.341005579780733,
           8.247816206196433,
           8.155223624226197,
           8.072776499694847,
           7.99032937516349,
           7.907882250632132,
           7.825435126100795,
           7.7429880015694375,
           7.6605408770380805,
           7.57809375250673,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           45.18598134404682,
           45.14844580964497,
           45.11091027524311,
           45.073374740841246,
           45.03583920643939,
           44.99830367203754,
           44.960768137635675,
           44.923232603233814,
           44.88569706883196,
           44.8481615344301,
           44.810626000028236,
           44.77309046562638,
           44.73555493122452,
           44.698019396822666,
           44.660483862420804,
           44.62294832801895,
           44.58541279361709,
           44.547877259215234,
           44.51034172481337,
           44.47280619041151,
           44.43527065600965,
           44.3977351216078,
           44.36019958720594,
           44.32266405280408,
           44.28512851840222,
           44.24759298400036,
           44.2100574495985,
           44.17252191519664,
           44.134986380794786,
           44.09745084639293,
           44.05991531199107,
           44.02237977758921,
           43.984844243187354,
           43.9473087087855,
           43.90977317438363,
           43.872237639981776,
           43.834702105579915,
           43.79716657117806,
           43.7596310367762,
           43.722095502374344,
           43.68455996797248,
           43.64702443357062,
           43.60948889916877,
           43.571953364766905,
           43.534417830365044,
           43.49688229596319,
           43.45934676156133,
           43.42181122715947,
           43.38427569275761,
           43.34674015835576,
           43.3092046239539,
           43.271669089552034,
           43.23413355515018,
           43.196598020748326,
           43.159062486346464,
           43.1215269519446,
           43.08399141754275,
           43.04645588314089,
           43.00892034873903,
           42.97138481433717,
           42.933849279935316,
           42.896313745533455,
           42.85877821113159,
           42.82124267672974,
           42.78370714232788,
           42.746171607926016,
           42.70863607352416,
           42.6711005391223,
           42.633565004720445,
           42.596029470318584,
           42.55849393591672,
           42.52095840151487,
           42.483422867113006,
           42.44588733271115,
           42.40835179830929,
           42.37081626390743,
           42.333280729505574,
           42.29574519510371,
           42.25820966070186,
           42.2206741263,
           42.17543584452152,
           42.12865699806931,
           42.08187815161709,
           42.03509930516487,
           41.74647440062399,
           41.409480284465346,
           41.07248616830674,
           40.73549205214811,
           40.39849793598949,
           40.061503819830875,
           39.724509703672254,
           39.38751558751363,
           39.050521471355,
           38.713527355196376,
           38.37653323903776,
           38.03953912287914,
           37.70254500672052,
           37.365550890561885,
           37.02855677440326,
           36.691562658244656,
           36.35456854208603,
           36.0175744259274,
           35.68058030976878,
           35.34358619361016,
           35.00659207745154,
           34.669597961292915,
           34.332603845134294,
           33.99560972897568,
           33.658615612817044,
           33.32162149665843,
           32.9846273804998,
           32.64763326434118,
           32.310639148182574,
           31.97364503202393,
           31.63665091586532,
           31.299656799706696,
           30.96266268354807,
           30.62566856738946,
           30.288674451230836,
           29.95168033507221,
           29.614686218913587,
           29.27769210275496,
           28.940697986596348,
           28.603703870437727,
           28.2667097542791,
           27.929715638120488,
           27.59272152196185,
           27.25572740580324,
           26.918733289644614,
           26.581739173485985,
           26.24474505732738,
           25.90775094116874,
           25.57075682501013,
           25.2337627088515,
           24.89676859269288,
           24.559774476534272,
           24.222780360375644,
           23.88578624421702,
           23.548792128058395,
           23.211798011899766,
           22.87480389574116,
           22.537809779582535,
           22.20081566342391,
           21.863821547265296,
           21.526827431106657,
           21.189833314948046,
           20.852839198789425,
           20.515845082630797,
           20.17885096647219,
           19.841856850313548,
           19.504862734154937,
           19.167868617996312,
           18.830874501837688,
           18.493880385679077,
           18.156886269520438,
           17.819892153361828,
           17.482898037203203,
           17.145903921044578,
           16.808909804885968,
           16.471915688727343,
           16.134921572568715,
           15.797927456410092,
           15.460933340251465,
           15.134817143654036,
           14.81413994037378,
           14.493462737093523,
           14.17278553381328,
           13.937070179403355,
           13.743835749428623,
           13.55060131945388,
           13.357366889479138,
           13.164132459504405,
           12.970898029529655,
           12.777663599554923,
           12.584429169580178,
           12.391194739605437,
           12.197960309630705,
           12.017148484991802,
           11.842676830044123,
           11.668205175096443,
           11.493733520148757,
           11.31926186520108,
           11.144790210253392,
           10.970318555305708,
           10.795846900358026,
           10.631862607772382,
           10.480508255825889,
           10.32915390387939,
           10.177799551932893,
           10.026445199986398,
           9.875090848039893,
           9.7237364960934,
           9.590424705676353,
           9.459088376493803,
           9.32775204731126,
           9.196415718128703,
           9.06507938894616,
           8.944304199914415,
           8.832176904402939,
           8.720049608891472,
           8.607922313379998,
           8.497626604435663,
           8.404437230851364,
           8.311247857267062,
           8.218058483682766,
           8.128449859782794,
           8.046002735251436,
           7.963555610720086,
           7.8811084861887295,
           7.798661361657372,
           7.716214237126035,
           7.633767112594677,
           7.5513199880633195,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           44.77580882640392,
           44.738273292002056,
           44.7007377576002,
           44.66320222319834,
           44.625666688796485,
           44.588131154394624,
           44.55059561999277,
           44.51306008559091,
           44.47552455118905,
           44.43798901678719,
           44.40045348238533,
           44.362917947983476,
           44.325382413581615,
           44.28784687917976,
           44.2503113447779,
           44.212775810376044,
           44.17524027597418,
           44.13770474157233,
           44.10016920717047,
           44.062633672768605,
           44.025098138366744,
           43.98756260396489,
           43.950027069563035,
           43.91249153516117,
           43.87495600075931,
           43.83742046635746,
           43.799884931955596,
           43.762349397553734,
           43.72481386315187,
           43.68727832875002,
           43.64974279434816,
           43.6122072599463,
           43.57467172554444,
           43.53713619114258,
           43.499600656740725,
           43.46206512233886,
           43.424529587937,
           43.38699405353515,
           43.34945851913329,
           43.311922984731424,
           43.27438745032957,
           43.236851915927716,
           43.19931638152586,
           43.16178084712399,
           43.12424531272214,
           43.08670977832028,
           43.04917424391842,
           43.01163870951656,
           42.974103175114706,
           42.936567640712845,
           42.89903210631098,
           42.86149657190913,
           42.82396103750727,
           42.786425503105406,
           42.74888996870355,
           42.71135443430169,
           42.673818899899835,
           42.636283365497974,
           42.59874783109612,
           42.561212296694265,
           42.523676762292396,
           42.48614122789054,
           42.44860569348868,
           42.40798906621024,
           42.36121021975802,
           42.3144313733058,
           42.26765252685359,
           42.22087368040137,
           42.17409483394915,
           42.12731598749693,
           42.08053714104471,
           42.033758294592495,
           41.986979448140275,
           41.940200601688055,
           41.893421755235835,
           41.84664290878362,
           41.7998640623314,
           41.75308521587918,
           41.70630636942696,
           41.65952752297474,
           41.61274867652252,
           41.5659698300703,
           41.51919098361809,
           41.47241213716587,
           41.18378723262498,
           40.846793116466344,
           40.50979900030773,
           40.17280488414911,
           39.83581076799048,
           39.49881665183187,
           39.161822535673245,
           38.824828419514624,
           38.487834303355996,
           38.150840187197375,
           37.81384607103876,
           37.47685195488013,
           37.13985783872151,
           36.80286372256288,
           36.46586960640426,
           36.128875490245655,
           35.79188137408702,
           35.4548872579284,
           35.11789314176978,
           34.78089902561115,
           34.44390490945254,
           34.10691079329391,
           33.76991667713529,
           33.43292256097668,
           33.095928444818036,
           32.75893432865943,
           32.4219402125008,
           32.08494609634218,
           31.747951980183572,
           31.410957864024926,
           31.073963747866316,
           30.736969631707694,
           30.39997551554907,
           30.06298139939046,
           29.725987283231834,
           29.38899316707321,
           29.05199905091458,
           28.715004934755957,
           28.378010818597346,
           28.041016702438725,
           27.704022586280097,
           27.36702847012149,
           27.030034353962847,
           26.69304023780424,
           26.356046121645612,
           26.019052005486987,
           25.682057889328377,
           25.345063773169738,
           25.008069657011127,
           24.6710755408525,
           24.334081424693878,
           23.99708730853527,
           23.660093192376642,
           23.323099076218018,
           22.986104960059393,
           22.649110843900765,
           22.312116727742158,
           21.97512261158353,
           21.63812849542491,
           21.301134379266294,
           20.964140263107655,
           20.627146146949045,
           20.29287149660471,
           19.972194293324456,
           19.651517090044216,
           19.330839886763943,
           19.0101626834837,
           18.689485480203444,
           18.36880827692319,
           18.048131073642946,
           17.727453870362673,
           17.406776667082433,
           17.086099463802178,
           16.76542226052192,
           16.44474505724168,
           16.12406785396142,
           15.803390650681164,
           15.482713447400908,
           15.162036244120651,
           14.841359040840409,
           14.520681837560153,
           14.200004634279896,
           13.879327430999654,
           13.64361207658973,
           13.450377646614996,
           13.257143216640255,
           13.063908786665511,
           12.870674356690778,
           12.677439926716028,
           12.484205496741295,
           12.290971066766552,
           12.11175717073568,
           11.937285515788004,
           11.76281386084031,
           11.588342205892634,
           11.413870550944951,
           11.239398895997265,
           11.064927241049588,
           10.8904555861019,
           10.723031889913624,
           10.571677537967126,
           10.420323186020626,
           10.268968834074132,
           10.117614482127633,
           9.966260130181135,
           9.814905778234642,
           9.674877414434054,
           9.54354108525151,
           9.41220475606896,
           9.28086842688641,
           9.149532097703867,
           9.01938198182723,
           8.907254686315762,
           8.795127390804288,
           8.683000095292813,
           8.570872799781345,
           8.467868881921987,
           8.374679508337687,
           8.281490134753387,
           8.188300761169089,
           8.101676095339384,
           8.019228970808026,
           7.936781846276668,
           7.854334721745319,
           7.771887597213961,
           7.6894404726826036,
           7.606993348151266,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           44.365636308761005,
           44.32810077435915,
           44.29056523995728,
           44.25302970555543,
           44.21549417115357,
           44.17795863675171,
           44.14042310234986,
           44.102887567947995,
           44.065352033546134,
           44.02781649914427,
           43.99028096474241,
           43.952745430340556,
           43.9152098959387,
           43.87767436153684,
           43.84013882713498,
           43.80260329273312,
           43.76506775833127,
           43.7275322239294,
           43.68999668952755,
           43.65246115512569,
           43.61492562072383,
           43.57739008632197,
           43.53985455192011,
           43.50231901751826,
           43.4647834831164,
           43.42724794871454,
           43.38971241431268,
           43.35217687991082,
           43.31464134550896,
           43.277105811107106,
           43.239570276705244,
           43.20203474230339,
           43.16449920790153,
           43.126963673499674,
           43.08942813909781,
           43.05189260469595,
           43.014357070294096,
           42.976821535892235,
           42.93928600149037,
           42.90175046708852,
           42.864214932686664,
           42.8266793982848,
           42.78914386388294,
           42.75160832948108,
           42.714072795079225,
           42.676537260677364,
           42.63900172627551,
           42.59376344144674,
           42.54698459499452,
           42.5002057485423,
           42.45342690209009,
           42.40664805563786,
           42.359869209185646,
           42.313090362733426,
           42.266311516281206,
           42.21953266982899,
           42.172753823376766,
           42.12597497692455,
           42.07919613047233,
           42.03241728402011,
           41.9856384375679,
           41.93885959111567,
           41.89208074466346,
           41.84530189821124,
           41.79852305175902,
           41.75174420530681,
           41.704965358854594,
           41.65818651240237,
           41.61140766595015,
           41.564628819497926,
           41.51784997304571,
           41.47107112659349,
           41.42429228014127,
           41.37751343368906,
           41.33073458723683,
           41.28395574078462,
           41.23717689433241,
           41.19039804788018,
           41.14361920142797,
           41.09684035497574,
           41.05006150852353,
           41.003282662071314,
           40.95650381561909,
           40.909724969166874,
           40.621100064625985,
           40.28410594846734,
           39.94711183230873,
           39.6101177161501,
           39.27312359999148,
           38.936129483832865,
           38.59913536767424,
           38.262141251515615,
           37.92514713535699,
           37.58815301919837,
           37.25115890303976,
           36.91416478688113,
           36.57717067072251,
           36.24017655456388,
           35.90318243840525,
           35.566188322246646,
           35.22919420608802,
           34.892200089929396,
           34.55520597377077,
           34.21821185761215,
           33.88121774145354,
           33.54422362529491,
           33.20722950913628,
           32.870235392977676,
           32.533241276819034,
           32.19624716066043,
           31.859253044501802,
           31.522258928343177,
           31.185264812184567,
           30.848270696025924,
           30.511276579867314,
           30.17428246370869,
           29.837288347550064,
           29.500294231391457,
           29.16330011523283,
           28.8263059990742,
           28.48931188291558,
           28.152317766756955,
           27.815323650598344,
           27.478329534439716,
           27.141335418281095,
           26.804341302122488,
           26.467347185963842,
           26.13035306980523,
           25.79335895364661,
           25.456364837487982,
           25.13024864627515,
           24.809571442994873,
           24.488894239714632,
           24.168217036434378,
           23.847539833154123,
           23.526862629873882,
           23.206185426593624,
           22.88550822331337,
           22.56483102003311,
           22.244153816752853,
           21.923476613472612,
           21.602799410192354,
           21.2821222069121,
           20.961445003631855,
           20.640767800351586,
           20.320090597071346,
           19.999413393791087,
           19.678736190510833,
           19.35805898723059,
           19.037381783950316,
           18.716704580670076,
           18.39602737738982,
           18.07535017410956,
           17.75467297082932,
           17.43399576754905,
           17.113318564268805,
           16.792641360988547,
           16.471964157708292,
           16.151286954428052,
           15.830609751147795,
           15.509932547867537,
           15.18925534458728,
           14.868578141307024,
           14.547900938026782,
           14.227223734746527,
           13.906546531466269,
           13.585869328186027,
           13.350153973776102,
           13.156919543801369,
           12.963685113826628,
           12.770450683851886,
           12.577216253877154,
           12.383981823902403,
           12.20636585647956,
           12.031894201531872,
           11.85742254658419,
           11.682950891636512,
           11.508479236688821,
           11.334007581741142,
           11.159535926793462,
           10.985064271845774,
           10.814201172054869,
           10.662846820108369,
           10.511492468161867,
           10.360138116215369,
           10.208783764268869,
           10.057429412322376,
           9.906075060375878,
           9.75933012319176,
           9.627993794009216,
           9.49665746482666,
           9.365321135644116,
           9.233984806461567,
           9.102648477279018,
           8.982332468228583,
           8.870205172717103,
           8.758077877205634,
           8.64595058169416,
           8.533823286182688,
           8.438111159408313,
           8.344921785824011,
           8.251732412239713,
           8.158543038655411,
           8.07490233089598,
           7.992455206364615,
           7.910008081833258,
           7.8275609573019,
           7.745113832770549,
           7.662666708239192,
           7.5802195837078346,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           43.95546379111813,
           43.917928256716266,
           43.880392722314404,
           43.84285718791254,
           43.805321653510696,
           43.767786119108834,
           43.73025058470697,
           43.69271505030511,
           43.65517951590326,
           43.617643981501395,
           43.58010844709953,
           43.54257291269768,
           43.505037378295825,
           43.46750184389396,
           43.4299663094921,
           43.39243077509025,
           43.35489524068839,
           43.31735970628653,
           43.27982417188467,
           43.24228863748281,
           43.20475310308096,
           43.1672175686791,
           43.12968203427724,
           43.092146499875376,
           43.054610965473515,
           43.01707543107166,
           42.979539896669806,
           42.942004362267944,
           42.90446882786608,
           42.86693329346423,
           42.8263166631355,
           42.77953781668328,
           42.73275897023106,
           42.68598012377884,
           42.63920127732662,
           42.59242243087441,
           42.54564358442219,
           42.49886473796997,
           42.452085891517754,
           42.40530704506553,
           42.358528198613314,
           42.311749352161094,
           42.264970505708874,
           42.218191659256654,
           42.171412812804434,
           42.12463396635222,
           42.07785511989999,
           42.03107627344779,
           41.98429742699557,
           41.93751858054334,
           41.89073973409113,
           41.84396088763891,
           41.79718204118669,
           41.750403194734474,
           41.70362434828225,
           41.656845501830034,
           41.61006665537781,
           41.563287808925594,
           41.51650896247338,
           41.469730116021154,
           41.42295126956894,
           41.376172423116714,
           41.3293935766645,
           41.28261473021229,
           41.23583588376006,
           41.18905703730785,
           41.14227819085563,
           41.09549934440341,
           41.04872049795119,
           41.00194165149897,
           40.955162805046754,
           40.90838395859454,
           40.861605112142314,
           40.8148262656901,
           40.768047419237874,
           40.72126857278566,
           40.674489726333434,
           40.62771087988122,
           40.58093203342901,
           40.53415318697678,
           40.48737434052457,
           40.44059549407235,
           40.39381664762013,
           40.34703780116791,
           40.058412896627026,
           39.72141878046838,
           39.38442466430977,
           39.04743054815115,
           38.71043643199252,
           38.373442315833906,
           38.036448199675284,
           37.69945408351666,
           37.362459967358035,
           37.025465851199414,
           36.6884717350408,
           36.35147761888217,
           36.01448350272355,
           35.67748938656492,
           35.3404952704063,
           35.003501154247694,
           34.666507038089065,
           34.32951292193044,
           33.992518805771816,
           33.655524689613195,
           33.31853057345458,
           32.98153645729595,
           32.64454234113733,
           32.30754822497872,
           31.97055410882008,
           31.63355999266147,
           31.296565876502843,
           30.959571760344218,
           30.62257764418561,
           30.288302999225834,
           29.967625795945594,
           29.64694859266534,
           29.326271389385084,
           29.005594186104837,
           28.684916982824582,
           28.36423977954432,
           28.043562576264065,
           27.72288537298381,
           27.40220816970357,
           27.081530966423315,
           26.760853763143054,
           26.440176559862813,
           26.11949935658254,
           25.7988221533023,
           25.478144950022045,
           25.157467746741787,
           24.836790543461547,
           24.51611334018127,
           24.19543613690103,
           23.874758933620775,
           23.55408173034052,
           23.23340452706028,
           22.912727323780018,
           22.592050120499763,
           22.27137291721951,
           21.950695713939254,
           21.630018510659006,
           21.30934130737875,
           20.988664104098497,
           20.667986900818253,
           20.34730969753798,
           20.02663249425774,
           19.705955290977485,
           19.38527808769723,
           19.064600884416983,
           18.743923681136714,
           18.423246477856473,
           18.102569274576215,
           17.78189207129596,
           17.461214868015716,
           17.140537664735447,
           16.819860461455203,
           16.49918325817495,
           16.17850605489469,
           15.85782885161445,
           15.537151648334191,
           15.216474445053935,
           14.895797241773677,
           14.575120038493422,
           14.25444283521318,
           13.933765631932923,
           13.613088428652667,
           13.292411225372424,
           13.0566958709625,
           12.863461440987768,
           12.670227011013024,
           12.476992581038282,
           12.300974542223457,
           12.12650288727576,
           11.952031232328089,
           11.777559577380401,
           11.603087922432717,
           11.42861626748504,
           11.254144612537349,
           11.07967295758967,
           10.90537045419612,
           10.75401610224962,
           10.60266175030313,
           10.45130739835663,
           10.29995304641013,
           10.148598694463631,
           9.99724434251713,
           9.845889990570637,
           9.712446502766932,
           9.581110173584381,
           9.449773844401838,
           9.31843751521928,
           9.187101186036738,
           9.057410250141407,
           8.945282954629933,
           8.833155659118466,
           8.721028363606987,
           8.608901068095518,
           8.501542810478945,
           8.408353436894643,
           8.315164063310348,
           8.221974689726046,
           8.13057569098392,
           8.048128566452563,
           7.965681441921219,
           7.883234317389855,
           7.800787192858498,
           7.71834006832714,
           7.635892943795789,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           43.545291273475215,
           43.50775573907335,
           43.4702202046715,
           43.43268467026964,
           43.39514913586778,
           43.35761360146592,
           43.32007806706407,
           43.282542532662205,
           43.24500699826035,
           43.20747146385849,
           43.16993592945663,
           43.13240039505477,
           43.09486486065291,
           43.05732932625106,
           43.01209103837199,
           42.96531219191978,
           42.91853334546756,
           42.87175449901534,
           42.824975652563126,
           42.7781968061109,
           42.731417959658685,
           42.684639113206465,
           42.637860266754245,
           42.591081420302025,
           42.54430257384981,
           42.49752372739759,
           42.45074488094537,
           42.40396603449315,
           42.35718718804093,
           42.31040834158872,
           42.2636294951365,
           42.21685064868428,
           42.17007180223206,
           42.12329295577984,
           42.076514109327626,
           42.0297352628754,
           41.982956416423185,
           41.936177569970965,
           41.889398723518745,
           41.84261987706653,
           41.79584103061431,
           41.74906218416209,
           41.70228333770987,
           41.65550449125765,
           41.60872564480544,
           41.561946798353205,
           41.515167951901,
           41.46838910544878,
           41.42161025899655,
           41.374831412544346,
           41.328052566092126,
           41.281273719639906,
           41.234494873187685,
           41.18771602673546,
           41.14093718028325,
           41.09415833383103,
           41.04737948737881,
           41.00060064092659,
           40.953821794474365,
           40.90704294802215,
           40.86026410156994,
           40.81348525511772,
           40.7667064086655,
           40.719927562213286,
           40.673148715761066,
           40.62636986930884,
           40.579591022856626,
           40.532812176404406,
           40.48603332995219,
           40.43925448349997,
           40.39247563704775,
           40.34569679059553,
           40.29891794414331,
           40.25213909769109,
           40.20536025123887,
           40.15858140478666,
           40.11180255833444,
           40.06502371188222,
           40.01824486543,
           39.97146601897778,
           39.92468717252556,
           39.877908326073346,
           39.831129479621126,
           39.784350633168906,
           39.49572572862802,
           39.15873161246938,
           38.82173749631077,
           38.484743380152146,
           38.14774926399352,
           37.810755147834904,
           37.47376103167628,
           37.13676691551766,
           36.79977279935903,
           36.462778683200405,
           36.12578456704179,
           35.78879045088317,
           35.45179633472455,
           35.125680148896265,
           34.80500294561601,
           34.48432574233577,
           34.16364853905551,
           33.84297133577525,
           33.522294132495,
           33.201616929214744,
           32.8809397259345,
           32.56026252265425,
           32.239585319373994,
           31.91890811609375,
           31.59823091281348,
           31.277553709533237,
           30.95687650625298,
           30.636199302972724,
           30.31552209969248,
           29.99484489641221,
           29.674167693131967,
           29.353490489851712,
           29.032813286571454,
           28.712136083291213,
           28.391458880010955,
           28.070781676730697,
           27.750104473450442,
           27.429427270170184,
           27.108750066889943,
           26.78807286360969,
           26.46739566032943,
           26.146718457049186,
           25.826041253768917,
           25.505364050488676,
           25.184686847208418,
           24.864009643928163,
           24.54333244064792,
           24.222655237367647,
           23.901978034087403,
           23.581300830807148,
           23.260623627526893,
           22.939946424246653,
           22.619269220966395,
           22.29859201768614,
           21.97791481440588,
           21.657237611125627,
           21.336560407845383,
           21.015883204565128,
           20.69520600128487,
           20.374528798004626,
           20.053851594724357,
           19.733174391444113,
           19.412497188163858,
           19.091819984883603,
           18.77114278160336,
           18.450465578323087,
           18.129788375042846,
           17.809111171762588,
           17.488433968482333,
           17.16775676520209,
           16.84707956192182,
           16.52640235864158,
           16.20572515536132,
           15.885047952081063,
           15.56437074880082,
           15.243693545520564,
           14.92301634224031,
           14.602339138960051,
           14.281661935679796,
           13.960984732399552,
           13.640307529119296,
           13.31963032583904,
           12.998953122558799,
           12.763237768148874,
           12.570054882915008,
           12.395583227967329,
           12.221111573019638,
           12.046639918071966,
           11.87216826312427,
           11.697696608176598,
           11.52322495322891,
           11.348753298281228,
           11.17428164333355,
           10.999809988385858,
           10.845185384390863,
           10.693831032444365,
           10.542476680497865,
           10.391122328551374,
           10.239767976604874,
           10.088413624658372,
           9.937059272711874,
           9.796899211524634,
           9.66556288234209,
           9.53422655315954,
           9.402890223976987,
           9.271553894794446,
           9.140217565611888,
           9.020360736542754,
           8.90823344103128,
           8.796106145519806,
           8.683978850008339,
           8.571851554496861,
           8.47178508796527,
           8.378595714380968,
           8.28540634079667,
           8.19221696721237,
           8.103801926540509,
           8.021354802009151,
           7.938907677477794,
           7.856460552946451,
           7.774013428415087,
           7.691566303883729,
           7.60911917935237,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           43.131599685122396,
           43.08482083867018,
           43.03804199221796,
           42.99126314576574,
           42.94448429931352,
           42.8977054528613,
           42.85092660640908,
           42.80414775995687,
           42.75736891350465,
           42.71059006705243,
           42.66381122060021,
           42.61703237414799,
           42.57025352769577,
           42.523474681243556,
           42.47669583479133,
           42.429916988339116,
           42.3831381418869,
           42.336359295434676,
           42.28958044898246,
           42.24280160253024,
           42.19602275607802,
           42.14924390962581,
           42.10246506317359,
           42.05568621672137,
           42.00890737026915,
           41.962128523816936,
           41.91534967736471,
           41.868570830912496,
           41.821791984460276,
           41.775013138008056,
           41.72823429155584,
           41.68145544510362,
           41.634676598651396,
           41.58789775219918,
           41.54111890574697,
           41.49434005929474,
           41.44756121284253,
           41.4007823663903,
           41.35400351993809,
           41.30722467348588,
           41.26044582703365,
           41.213666980581436,
           41.16688813412921,
           41.120109287676996,
           41.07333044122478,
           41.026551594772556,
           40.97977274832034,
           40.932993901868116,
           40.8862150554159,
           40.83943620896368,
           40.79265736251146,
           40.74587851605925,
           40.69909966960702,
           40.65232082315481,
           40.6055419767026,
           40.55876313025037,
           40.51198428379816,
           40.46520543734593,
           40.418426590893716,
           40.3716477444415,
           40.324868897989276,
           40.27809005153706,
           40.231311205084836,
           40.18453235863262,
           40.1377535121804,
           40.09097466572818,
           40.04419581927597,
           39.99741697282375,
           39.95063812637153,
           39.90385927991931,
           39.8570804334671,
           39.81030158701488,
           39.76352274056266,
           39.71674389411044,
           39.669965047658216,
           39.623186201205996,
           39.57640735475378,
           39.529628508301556,
           39.48284966184934,
           39.43607081539712,
           39.387526079786475,
           39.330151863722975,
           39.272777647659474,
           39.21540343159598,
           38.95618990261864,
           38.656608511058515,
           38.35702711949841,
           38.046897810576425,
           37.72622060729616,
           37.40554340401593,
           37.08486620073567,
           36.76418899745541,
           36.44351179417515,
           36.122834590894904,
           35.802157387614656,
           35.481480184334394,
           35.16080298105415,
           34.840125777773885,
           34.51944857449363,
           34.19877137121339,
           33.87809416793313,
           33.55741696465287,
           33.23673976137262,
           32.916062558092364,
           32.59538535481212,
           32.27470815153187,
           31.95403094825161,
           31.633353744971366,
           31.312676541691097,
           30.991999338410853,
           30.671322135130595,
           30.35064493185034,
           30.029967728570096,
           29.709290525289827,
           29.388613322009583,
           29.067936118729328,
           28.747258915449073,
           28.42658171216883,
           28.10590450888857,
           27.785227305608313,
           27.464550102328058,
           27.1438728990478,
           26.82319569576756,
           26.502518492487305,
           26.181841289207046,
           25.861164085926802,
           25.540486882646533,
           25.219809679366293,
           24.899132476086034,
           24.57845527280578,
           24.257778069525536,
           23.937100866245263,
           23.61642366296502,
           23.295746459684764,
           22.97506925640451,
           22.65439205312427,
           22.333714849844014,
           22.013037646563756,
           21.692360443283498,
           21.371683240003243,
           21.051006036723003,
           20.730328833442744,
           20.409651630162486,
           20.088974426882245,
           19.768297223601976,
           19.447620020321732,
           19.126942817041474,
           18.80626561376122,
           18.48558841048098,
           18.164911207200706,
           17.844234003920462,
           17.523556800640208,
           17.202879597359953,
           16.88220239407971,
           16.561525190799436,
           16.240847987519196,
           15.920170784238938,
           15.599493580958681,
           15.278816377678439,
           14.958139174398184,
           14.637461971117926,
           14.31678476783767,
           13.996107564557413,
           13.67543036127717,
           13.354753157996914,
           13.03407595471666,
           12.713398751436417,
           12.490191913711199,
           12.315720258763518,
           12.141248603815836,
           11.966776948868146,
           11.792305293920478,
           11.61783363897278,
           11.443361984025106,
           11.268890329077418,
           11.094418674129738,
           10.936354666532106,
           10.785000314585599,
           10.633645962639108,
           10.48229161069261,
           10.33093725874611,
           10.179582906799618,
           10.028228554853118,
           9.88135192028234,
           9.750015591099789,
           9.618679261917242,
           9.487342932734698,
           9.356006603552146,
           9.224670274369595,
           9.095438518455573,
           8.983311222944096,
           8.871183927432627,
           8.759056631921153,
           8.646929336409679,
           8.535216739035896,
           8.44202736545159,
           8.348837991867294,
           8.255648618282994,
           8.162459244698693,
           8.077028162097099,
           7.99458103756574,
           7.912133913034383,
           7.829686788503024,
           7.747239663971682,
           7.664792539440318,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           42.704007764442075,
           42.65722891798986,
           42.61045007153764,
           42.563671225085415,
           42.5168923786332,
           42.47011353218098,
           42.42333468572876,
           42.37655583927655,
           42.32977699282433,
           42.28299814637211,
           42.23621929991989,
           42.18944045346767,
           42.142661607015455,
           42.095882760563235,
           42.049103914111015,
           42.002325067658795,
           41.95554622120658,
           41.908767374754355,
           41.86198852830214,
           41.81520968184992,
           41.7684308353977,
           41.72165198894548,
           41.67487314249327,
           41.62809429604104,
           41.58131544958883,
           41.53453660313661,
           41.48775775668439,
           41.440978910232175,
           41.39420006377995,
           41.347421217327735,
           41.300642370875515,
           41.253863524423295,
           41.20708467797108,
           41.16030583151886,
           41.11352698506664,
           41.06674813861442,
           41.0199692921622,
           40.97319044570999,
           40.92641159925777,
           40.87963275280555,
           40.83285390635333,
           40.78607505990111,
           40.73929621344889,
           40.692517366996675,
           40.645738520544455,
           40.598959674092235,
           40.552180827640015,
           40.505401981187795,
           40.458623134735575,
           40.41184428828336,
           40.365065441831135,
           40.31828659537892,
           40.2715077489267,
           40.22472890247448,
           40.17795005602227,
           40.13117120957005,
           40.08439236311783,
           40.03761351666561,
           39.99083467021339,
           39.944055823761175,
           39.897276977308955,
           39.850498130856735,
           39.803719284404515,
           39.756940437952295,
           39.70309801578778,
           39.64572379972429,
           39.588349583660786,
           39.530975367597286,
           39.47360115153379,
           39.416226935470284,
           39.35885271940679,
           39.3014785033433,
           39.244104287279804,
           39.186730071216296,
           39.1293558551528,
           39.0719816390893,
           39.0146074230258,
           38.95723320696231,
           38.89985899089881,
           38.842484774835306,
           38.785110558771805,
           38.72773634270831,
           38.67036212664482,
           38.61298791058132,
           38.35377438160398,
           38.05419299004385,
           37.754611598483756,
           37.455030206923645,
           37.155448815363535,
           36.85586742380343,
           36.55628603224333,
           36.25670464068321,
           35.9571232491231,
           35.65754185756299,
           35.35796046600289,
           35.05837907444278,
           34.75879768288267,
           34.45921629132256,
           34.15963489976245,
           33.860053508202355,
           33.560472116642245,
           33.260890725082135,
           32.96130933352202,
           32.661727933940895,
           32.34105073066065,
           32.02037352738039,
           31.699696324100138,
           31.379019120819898,
           31.058341917539625,
           30.737664714259385,
           30.416987510979123,
           30.096310307698868,
           29.775633104418624,
           29.454955901138355,
           29.134278697858115,
           28.813601494577856,
           28.4929242912976,
           28.172247088017357,
           27.8515698847371,
           27.53089268145684,
           27.210215478176586,
           26.88953827489633,
           26.568861071616087,
           26.248183868335833,
           25.927506665055574,
           25.606829461775334,
           25.28615225849506,
           24.96547505521482,
           24.644797851934566,
           24.324120648654308,
           24.003443445374067,
           23.68276624209379,
           23.36208903881355,
           23.041411835533296,
           22.72073463225304,
           22.4000574289728,
           22.079380225692542,
           21.758703022412288,
           21.438025819132026,
           21.11734861585177,
           20.796671412571527,
           20.475994209291272,
           20.155317006011018,
           19.834639802730774,
           19.513962599450505,
           19.19328539617026,
           18.872608192890006,
           18.55193098960975,
           18.231253786329507,
           17.910576583049235,
           17.58989937976899,
           17.269222176488736,
           16.948544973208477,
           16.627867769928237,
           16.307190566647968,
           15.986513363367724,
           15.665836160087467,
           15.34515895680721,
           15.024481753526969,
           14.703804550246712,
           14.383127346966454,
           14.062450143686199,
           13.741772940405943,
           13.4210957371257,
           13.100418533845444,
           12.779741330565187,
           12.459064127284945,
           12.235857289559727,
           12.061385634612046,
           11.886913979664364,
           11.712442324716676,
           11.537970669769006,
           11.363499014821308,
           11.189027359873636,
           11.027523948673355,
           10.876169596726857,
           10.724815244780366,
           10.57346089283386,
           10.422106540887368,
           10.270752188940868,
           10.11939783699437,
           9.96804348504788,
           9.834468299857512,
           9.703131970674962,
           9.571795641492411,
           9.440459312309862,
           9.309122983127319,
           9.177786653944768,
           9.058389004856927,
           8.946261709345457,
           8.834134413833981,
           8.72200711832251,
           8.609879822811038,
           8.505459016522224,
           8.412269642937929,
           8.319080269353623,
           8.225890895769327,
           8.132701522185027,
           8.050254397653681,
           7.967807273122331,
           7.885360148590974,
           7.802913024059616,
           7.720465899528258,
           7.638018774996915,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           42.276415843761725,
           42.229636997309505,
           42.182858150857285,
           42.136079304405065,
           42.089300457952845,
           42.04252161150063,
           41.99574276504841,
           41.94896391859619,
           41.90218507214397,
           41.85540622569175,
           41.80862737923954,
           41.76184853278732,
           41.7150696863351,
           41.66829083988288,
           41.62151199343066,
           41.57473314697844,
           41.527954300526225,
           41.481175454074005,
           41.434396607621785,
           41.387617761169565,
           41.340838914717345,
           41.29406006826513,
           41.24728122181291,
           41.20050237536069,
           41.15372352890847,
           41.10694468245626,
           41.06016583600404,
           41.01338698955182,
           40.9666081430996,
           40.91982929664738,
           40.873050450195166,
           40.826271603742946,
           40.779492757290726,
           40.732713910838505,
           40.685935064386285,
           40.63915621793407,
           40.59237737148185,
           40.54559852502963,
           40.49881967857742,
           40.45204083212519,
           40.40526198567298,
           40.35848313922076,
           40.31170429276854,
           40.264925446316326,
           40.218146599864106,
           40.171367753411886,
           40.12458890695966,
           40.07604416785253,
           40.018669951789036,
           39.96129573572554,
           39.90392151966205,
           39.84654730359855,
           39.78917308753505,
           39.731798871471554,
           39.67442465540805,
           39.61705043934455,
           39.55967622328105,
           39.50230200721755,
           39.44492779115406,
           39.387553575090564,
           39.330179359027056,
           39.27280514296357,
           39.21543092690007,
           39.15805671083656,
           39.100682494773075,
           39.04330827870957,
           38.98593406264607,
           38.92855984658258,
           38.87118563051908,
           38.81381141445558,
           38.75643719839208,
           38.699062982328584,
           38.641688766265084,
           38.58431455020158,
           38.52694033413809,
           38.46956611807459,
           38.412191902011095,
           38.354817685947594,
           38.2974434698841,
           38.24006925382059,
           38.1826950377571,
           38.1253208216936,
           38.067946605630105,
           38.010572389566605,
           37.751358860589264,
           37.45177746902914,
           37.15219607746904,
           36.85261468590893,
           36.55303329434882,
           36.253451902788726,
           35.953870511228615,
           35.654289119668505,
           35.354707728108394,
           35.055126336548284,
           34.75554494498818,
           34.45596355342807,
           34.15638216186796,
           33.85680077030785,
           33.55721937874774,
           33.25763798718764,
           32.95805659562753,
           32.65847520406742,
           32.35889381250731,
           32.0593124209472,
           31.7597310293871,
           31.46014963782699,
           31.16056824626688,
           30.860986854706784,
           30.561405463146656,
           30.26182407158656,
           29.96224268002645,
           29.66266128846634,
           29.36307989690624,
           29.063498505346114,
           28.76391711378602,
           28.464335722225908,
           28.1647543306658,
           27.8651729391057,
           27.56559154754559,
           27.266010155985477,
           26.955880854025096,
           26.63520365074484,
           26.314526447464598,
           25.993849244184343,
           25.673172040904088,
           25.352494837623844,
           25.031817634343575,
           24.71114043106333,
           24.390463227783076,
           24.069786024502818,
           23.749108821222578,
           23.4284316179423,
           23.10775441466206,
           22.787077211381806,
           22.466400008101548,
           22.14572280482131,
           21.82504560154105,
           21.504368398260798,
           21.183691194980536,
           20.86301399170028,
           20.542336788420037,
           20.221659585139783,
           19.900982381859528,
           19.58030517857928,
           19.25962797529901,
           18.93895077201877,
           18.618273568738516,
           18.297596365458258,
           17.976919162178017,
           17.656241958897745,
           17.335564755617504,
           17.014887552337246,
           16.694210349056988,
           16.373533145776747,
           16.05285594249648,
           15.732178739216234,
           15.41150153593598,
           15.090824332655721,
           14.770147129375477,
           14.449469926095222,
           14.128792722814964,
           13.80811551953471,
           13.487438316254451,
           13.16676111297421,
           12.846083909693952,
           12.525406706413698,
           12.204729503133454,
           11.981522665408237,
           11.807051010460556,
           11.632579355512874,
           11.458107700565185,
           11.283636045617513,
           11.118693230814596,
           10.967338878868098,
           10.8159845269216,
           10.664630174975102,
           10.513275823028609,
           10.361921471082104,
           10.21056711913561,
           10.059212767189113,
           9.91892100861521,
           9.787584679432666,
           9.65624835025012,
           9.524912021067568,
           9.393575691885017,
           9.262239362702468,
           9.13346678676975,
           9.021339491258274,
           8.909212195746802,
           8.797084900235332,
           8.684957604723854,
           8.572830309212383,
           8.475701294008548,
           8.38251192042425,
           8.289322546839953,
           8.19613317325565,
           8.10592775774162,
           8.023480633210271,
           7.941033508678912,
           7.8585863841475625,
           7.776139259616206,
           7.693692135084848,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           41.84882392308136,
           41.80204507662915,
           41.75526623017693,
           41.7084873837247,
           41.66170853727249,
           41.614929690820276,
           41.56815084436805,
           41.521371997915836,
           41.474593151463615,
           41.427814305011395,
           41.381035458559175,
           41.33425661210696,
           41.28747776565474,
           41.24069891920252,
           41.1939200727503,
           41.14714122629808,
           41.10036237984587,
           41.05358353339365,
           41.00680468694143,
           40.96002584048921,
           40.91324699403699,
           40.86646814758477,
           40.819689301132556,
           40.77291045468033,
           40.726131608228116,
           40.679352761775895,
           40.63257391532368,
           40.58579506887146,
           40.53901622241924,
           40.49223737596702,
           40.4454585295148,
           40.391616103853806,
           40.33424188779031,
           40.276867671726805,
           40.21949345566331,
           40.16211923959981,
           40.10474502353631,
           40.04737080747282,
           39.989996591409316,
           39.932622375345815,
           39.87524815928232,
           39.81787394321882,
           39.76049972715532,
           39.70312551109183,
           39.645751295028326,
           39.588377078964825,
           39.53100286290133,
           39.47362864683783,
           39.41625443077434,
           39.35888021471084,
           39.301505998647336,
           39.24413178258384,
           39.186757566520335,
           39.12938335045684,
           39.07200913439335,
           39.01463491832985,
           38.95726070226635,
           38.899886486202846,
           38.84251227013935,
           38.78513805407586,
           38.72776383801235,
           38.67038962194886,
           38.613015405885356,
           38.555641189821856,
           38.49826697375836,
           38.44089275769487,
           38.38351854163137,
           38.32614432556787,
           38.26877010950437,
           38.211395893440866,
           38.15402167737737,
           38.09664746131388,
           38.03927324525037,
           37.98189902918688,
           37.924524813123384,
           37.86715059705988,
           37.80977638099639,
           37.75240216493289,
           37.69502794886939,
           37.63765373280589,
           37.580279516742394,
           37.5229053006789,
           37.46553108461539,
           37.4081568685519,
           37.14894333957456,
           36.84936194801443,
           36.54978055645434,
           36.25019916489422,
           35.95061777333411,
           35.65103638177401,
           35.3514549902139,
           35.05187359865379,
           34.75229220709368,
           34.45271081553357,
           34.153129423973475,
           33.853548032413364,
           33.55396664085325,
           33.254385249293136,
           32.954803857733026,
           32.65522246617293,
           32.35564107461283,
           32.05605968305271,
           31.7564782914926,
           31.456896899932488,
           31.157315508372392,
           30.85773411681228,
           30.55815272525217,
           30.258571333692075,
           29.95898994213195,
           29.65940855057185,
           29.359827159011736,
           29.060245767451626,
           28.76066437589153,
           28.461082984331405,
           28.16150159277131,
           27.8619202012112,
           27.562338809651088,
           27.26275741809099,
           26.96317602653088,
           26.66359463497077,
           26.364013243410657,
           26.064431851850546,
           25.76485046029045,
           25.465269068730336,
           25.16568767717023,
           24.86610628561013,
           24.56652489405001,
           24.26694350248991,
           23.9673621109298,
           23.667780719369688,
           23.36819932780959,
           23.068617936249467,
           22.769036544689367,
           22.469455153129257,
           22.169873761569143,
           21.87029237000905,
           21.570710977389563,
           21.250033774109305,
           20.929356570829047,
           20.608679367548792,
           20.288002164268548,
           19.967324960988293,
           19.64664775770803,
           19.325970554427794,
           19.00529335114752,
           18.68461614786728,
           18.363938944587023,
           18.043261741306768,
           17.722584538026524,
           17.40190733474625,
           17.08123013146601,
           16.760552928185753,
           16.439875724905498,
           16.119198521625258,
           15.798521318344985,
           15.477844115064745,
           15.157166911784488,
           14.83648970850423,
           14.515812505223987,
           14.195135301943731,
           13.874458098663474,
           13.553780895383216,
           13.233103692102961,
           12.912426488822717,
           12.591749285542463,
           12.271072082262206,
           11.950394878981964,
           11.727188041256746,
           11.552716386309065,
           11.378244731361384,
           11.209862512955837,
           11.058508161009344,
           10.90715380906284,
           10.755799457116343,
           10.604445105169845,
           10.453090753223346,
           10.301736401276854,
           10.150382049330346,
           10.003373717372918,
           9.872037388190368,
           9.740701059007819,
           9.609364729825272,
           9.478028400642726,
           9.346692071460174,
           9.215355742277623,
           9.09641727317109,
           8.984289977659623,
           8.872162682148147,
           8.760035386636673,
           8.647908091125204,
           8.53913294507917,
           8.445943571494874,
           8.352754197910574,
           8.259564824326274,
           8.16637545074198,
           8.079153993298203,
           7.996706868766852,
           7.914259744235502,
           7.831812619704144,
           7.749365495172794,
           7.666918370641436,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           41.42123200240104,
           41.37445315594882,
           41.3276743094966,
           41.28089546304439,
           41.23411661659216,
           41.18733777013995,
           41.14055892368773,
           41.09378007723551,
           41.04700123078329,
           41.000222384331074,
           40.95344353787885,
           40.906664691426634,
           40.859885844974414,
           40.813106998522194,
           40.764562255918605,
           40.70718803985511,
           40.64981382379162,
           40.592439607728124,
           40.53506539166462,
           40.47769117560112,
           40.42031695953762,
           40.36294274347412,
           40.30556852741063,
           40.248194311347135,
           40.19082009528363,
           40.133445879220126,
           40.07607166315663,
           40.01869744709313,
           39.96132323102964,
           39.90394901496614,
           39.846574798902644,
           39.789200582839136,
           39.73182636677564,
           39.67445215071214,
           39.61707793464865,
           39.55970371858515,
           39.50232950252165,
           39.44495528645815,
           39.38758107039465,
           39.33020685433115,
           39.27283263826766,
           39.21545842220416,
           39.15808420614066,
           39.10070999007716,
           39.04333577401366,
           38.98596155795016,
           38.92858734188667,
           38.87121312582316,
           38.81383890975967,
           38.756464693696174,
           38.69909047763267,
           38.64171626156917,
           38.58434204550568,
           38.526967829442185,
           38.46959361337868,
           38.412219397315184,
           38.35484518125169,
           38.29747096518818,
           38.24009674912469,
           38.182722533061195,
           38.12534831699769,
           38.067974100934194,
           38.01059988487069,
           37.95322566880719,
           37.8958514527437,
           37.8384772366802,
           37.781103020616705,
           37.723728804553204,
           37.66635458848971,
           37.60898037242621,
           37.55160615636271,
           37.494231940299215,
           37.436857724235715,
           37.379483508172214,
           37.32210929210872,
           37.26473507604522,
           37.20736085998172,
           37.149986643918226,
           37.092612427854725,
           37.035238211791224,
           36.97786399572773,
           36.92048977966423,
           36.86311556360073,
           36.80574134753723,
           36.546527818559895,
           36.24694642699977,
           35.947365035439674,
           35.64778364387956,
           35.34820225231945,
           35.04862086075935,
           34.74903946919924,
           34.44945807763913,
           34.14987668607902,
           33.85029529451891,
           33.55071390295881,
           33.2511325113987,
           32.95155111983859,
           32.65196972827847,
           32.35238833671837,
           32.052806945158274,
           31.75322555359816,
           31.453644162038053,
           31.154062770477942,
           30.854481378917825,
           30.554899987357732,
           30.25531859579762,
           29.955737204237508,
           29.65615581267741,
           29.356574421117287,
           29.05699302955719,
           28.757411637997077,
           28.457830246436966,
           28.158248854876874,
           27.858667463316745,
           27.55908607175665,
           27.25950468019654,
           26.95992328863643,
           26.66034189707633,
           26.360760505516218,
           26.061179113956108,
           25.761597722395997,
           25.462016330835887,
           25.16243493927579,
           24.862853547715677,
           24.563272156155563,
           24.26369076459547,
           23.964109373035342,
           23.66452798147525,
           23.364946589915135,
           23.065365198355025,
           22.76578380679493,
           22.466202415234804,
           22.166621023674708,
           21.867039632114597,
           21.567458240554487,
           21.267876848994387,
           20.968295457434273,
           20.668714065874166,
           20.369132674314052,
           20.06955128275394,
           19.769969891193846,
           19.470388499633735,
           19.170807108073625,
           18.871225716513525,
           18.5716443249534,
           18.272062933393304,
           17.972481541833194,
           17.67290015027308,
           17.373318758712983,
           17.073737367152862,
           16.774155975592766,
           16.474574584032652,
           16.174993192472545,
           15.864863897473786,
           15.544186694193515,
           15.223509490913273,
           14.902832287633016,
           14.58215508435276,
           14.261477881072517,
           13.94080067779226,
           13.620123474512004,
           13.299446271231746,
           12.97876906795149,
           12.658091864671247,
           12.33741466139099,
           12.016737458110736,
           11.696060254830494,
           11.472853417105275,
           11.301031795097096,
           11.149677443150596,
           10.998323091204098,
           10.846968739257605,
           10.695614387311101,
           10.544260035364601,
           10.392905683418105,
           10.241551331471607,
           10.090196979525114,
           9.956490096948086,
           9.82515376776554,
           9.69381743858299,
           9.56248110940044,
           9.431144780217895,
           9.299808451035348,
           9.17149505508392,
           9.059367759572448,
           8.947240464060974,
           8.835113168549507,
           8.72298587303803,
           8.610858577526558,
           8.50937522256551,
           8.416185848981204,
           8.322996475396907,
           8.229807101812607,
           8.136617728228307,
           8.052380228854807,
           7.9699331043234425,
           7.887485979792092,
           7.805038855260742,
           7.722591730729383,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           40.98811534063741,
           40.920220214234014,
           40.85232508783062,
           40.78793692859697,
           40.73056271253348,
           40.673188496469976,
           40.615814280406475,
           40.55844006434298,
           40.50106584827948,
           40.44369163221598,
           40.38631741615249,
           40.328943200088986,
           40.271568984025485,
           40.21419476796199,
           40.156820551898484,
           40.09944633583499,
           40.0420721197715,
           39.984697903707996,
           39.927323687644495,
           39.869949471580995,
           39.8125752555175,
           39.755201039454,
           39.6978268233905,
           39.640452607327006,
           39.583078391263506,
           39.525704175200005,
           39.46832995913651,
           39.41095574307301,
           39.35358152700951,
           39.296207310946016,
           39.238833094882516,
           39.181458878819015,
           39.12408466275552,
           39.06671044669202,
           39.00933623062852,
           38.95196201456503,
           38.894587798501526,
           38.837213582438025,
           38.77983936637453,
           38.72246515031103,
           38.66509093424753,
           38.60771671818404,
           38.550342502120536,
           38.492968286057035,
           38.43559406999354,
           38.37821985393004,
           38.32084563786654,
           38.26347142180304,
           38.206097205739546,
           38.14872298967605,
           38.09134877361255,
           38.03397455754906,
           37.97660034148555,
           37.91922612542206,
           37.861851909358556,
           37.804477693295055,
           37.74710347723156,
           37.68972926116806,
           37.63235504510456,
           37.57498082904107,
           37.517606612977566,
           37.46023239691407,
           37.40285818085057,
           37.34548396478707,
           37.28810974872358,
           37.23073553266008,
           37.17336131659658,
           37.11598710053308,
           37.05861288446958,
           37.00123866840609,
           36.94386445234258,
           36.88649023627909,
           36.829116020215594,
           36.77174180415209,
           36.71436758808859,
           36.65699337202509,
           36.5996191559616,
           36.542244939898104,
           36.4848707238346,
           36.4274965077711,
           36.3701222917076,
           36.3127480756441,
           36.25537385958061,
           36.19799964351711,
           35.938786114539774,
           35.63920472297964,
           35.339623331419546,
           35.04004193985944,
           34.740460548299325,
           34.44087915673923,
           34.14129776517912,
           33.84171637361901,
           33.5421349820589,
           33.24255359049879,
           32.94297219893869,
           32.64339080737857,
           32.34380941581847,
           32.04422802425835,
           31.74464663269825,
           31.44506524113815,
           31.14548384957804,
           30.845902458017925,
           30.546321066457818,
           30.246739674897707,
           29.947158283337608,
           29.647576891777497,
           29.347995500217383,
           29.04841410865729,
           28.748832717097166,
           28.449251325537066,
           28.149669933976956,
           27.850088542416845,
           27.550507150856745,
           27.25092575929662,
           26.951344367736525,
           26.651762976176414,
           26.352181584616304,
           26.052600193056204,
           25.753018801496097,
           25.45343740993598,
           25.153856018375876,
           24.85427462681576,
           24.554693235255662,
           24.255111843695556,
           23.95553045213544,
           23.655949060575345,
           23.35636766901522,
           23.056786277455124,
           22.757204885895014,
           22.457623494334904,
           22.158042102774807,
           21.858460711214683,
           21.558879319654583,
           21.259297928094472,
           20.959716536534362,
           20.660135144974262,
           20.360553753414152,
           20.06097236185404,
           19.76139097029393,
           19.46180957873382,
           19.162228187173724,
           18.862646795613614,
           18.5630654040535,
           18.2634840124934,
           17.963902620933276,
           17.66432122937318,
           17.36473983781307,
           17.06515844625296,
           16.765577054692862,
           16.465995663132738,
           16.16641427157264,
           15.866832880012531,
           15.56725148845242,
           15.26767009689232,
           14.968088705332196,
           14.6685073137721,
           14.36892592221199,
           14.069344530651877,
           13.76976313909178,
           13.470181747531669,
           13.170600355971558,
           12.871018964411448,
           12.571437572851336,
           12.27185618129124,
           11.980837056498485,
           11.706942443680347,
           11.43304783086222,
           11.240846725291833,
           11.089492373345339,
           10.93813802139884,
           10.78678366945234,
           10.63542931750585,
           10.484074965559344,
           10.332720613612846,
           10.181366261666348,
           10.040942805705791,
           9.909606476523248,
           9.778270147340692,
           9.646933818158146,
           9.515597488975597,
           9.384261159793045,
           9.252924830610501,
           9.134445541485269,
           9.022318245973793,
           8.91019095046232,
           8.798063654950846,
           8.68593635943938,
           8.573809063927905,
           8.47961750005183,
           8.386428126467534,
           8.29323875288323,
           8.200049379298934,
           8.108053588942745,
           8.02560646441139,
           7.943159339880038,
           7.8607122153486735,
           7.778265090817324,
           7.695817966285972,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           40.52633908774905,
           40.45844396134565,
           40.390548834942265,
           40.322653708538866,
           40.25475858213547,
           40.18686345573208,
           40.118968329328695,
           40.051073202925295,
           39.98317807652191,
           39.91528295011851,
           39.847387823715124,
           39.779492697311724,
           39.71159757090833,
           39.64370244450494,
           39.57580731810155,
           39.50791219169815,
           39.44001706529476,
           39.37212193889137,
           39.30422681248798,
           39.23633168608458,
           39.17720398028493,
           39.11982976422143,
           39.062455548157935,
           39.005081332094434,
           38.94770711603094,
           38.89033289996744,
           38.83295868390394,
           38.77558446784044,
           38.718210251776945,
           38.66083603571345,
           38.603461819649944,
           38.54608760358645,
           38.48871338752295,
           38.431339171459456,
           38.373964955395955,
           38.316590739332455,
           38.25921652326896,
           38.20184230720546,
           38.14446809114196,
           38.087093875078466,
           38.029719659014965,
           37.972345442951465,
           37.914971226887964,
           37.85759701082447,
           37.80022279476097,
           37.742848578697476,
           37.685474362633975,
           37.628100146570475,
           37.57072593050698,
           37.51335171444348,
           37.45597749837998,
           37.398603282316486,
           37.341229066252986,
           37.283854850189485,
           37.22648063412599,
           37.16910641806249,
           37.11173220199899,
           37.054357985935496,
           36.996983769872,
           36.939609553808495,
           36.882235337745,
           36.8248611216815,
           36.767486905618,
           36.71011268955451,
           36.652738473491006,
           36.59536425742751,
           36.53799004136401,
           36.48061582530052,
           36.42324160923702,
           36.36586739317352,
           36.30849317711002,
           36.25111896104652,
           36.19374474498302,
           36.13637052891953,
           36.07899631285602,
           36.02162209679253,
           35.96424788072903,
           35.906873664665525,
           35.84949944860203,
           35.79212523253853,
           35.73475101647503,
           35.67737680041154,
           35.620002584348036,
           35.56262836828454,
           35.3034148393072,
           35.00383344774708,
           34.70425205618698,
           34.40467066462687,
           34.10508927306675,
           33.805507881506664,
           33.505926489946546,
           33.206345098386436,
           32.906763706826325,
           32.607182315266215,
           32.30760092370612,
           32.00801953214601,
           31.708438140585898,
           31.408856749025787,
           31.10927535746568,
           30.80969396590558,
           30.51011257434547,
           30.21053118278536,
           29.91094979122525,
           29.61136839966514,
           29.31178700810504,
           29.01220561654493,
           28.71262422498482,
           28.41304283342472,
           28.113461441864594,
           27.813880050304498,
           27.514298658744387,
           27.214717267184277,
           26.91513587562418,
           26.615554484064052,
           26.31597309250396,
           26.016391700943846,
           25.716810309383735,
           25.417228917823635,
           25.11764752626353,
           24.818066134703415,
           24.518484743143308,
           24.218903351583194,
           23.919321960023094,
           23.619740568462987,
           23.32015917690287,
           23.02057778534278,
           22.720996393782652,
           22.42141500222256,
           22.12183361066245,
           21.822252219102335,
           21.522670827542235,
           21.22308943598211,
           20.923508044422015,
           20.623926652861904,
           20.324345261301794,
           20.024763869741697,
           19.725182478181583,
           19.425601086621477,
           19.126019695061363,
           18.826438303501252,
           18.526856911941156,
           18.227275520381042,
           17.927694128820935,
           17.628112737260835,
           17.32853134570071,
           17.028949954140614,
           16.729368562580504,
           16.42978717102039,
           16.151611439836937,
           15.877716827018789,
           15.603822214200662,
           15.329927601382522,
           15.056032988564382,
           14.782138375746255,
           14.508243762928103,
           14.234349150109978,
           13.960454537291836,
           13.686559924473697,
           13.412665311655571,
           13.138770698837432,
           12.86487608601929,
           12.590981473201152,
           12.317086860383013,
           12.043192247564885,
           11.769297634746746,
           11.495403021928608,
           11.221508409110479,
           11.029307303540092,
           10.8779529515936,
           10.726598599647101,
           10.575244247700603,
           10.42388989575411,
           10.272535543807606,
           10.12539551446351,
           9.99405918528096,
           9.862722856098411,
           9.731386526915868,
           9.600050197733314,
           9.468713868550767,
           9.337377539368216,
           9.209523323398095,
           9.097396027886626,
           8.985268732375152,
           8.87314143686368,
           8.761014141352206,
           8.648886845840732,
           8.543049151122464,
           8.449859777538165,
           8.356670403953864,
           8.263481030369569,
           8.170291656785263,
           8.081279824499344,
           7.998832699967987,
           7.91638557543663,
           7.833938450905278,
           7.751491326373914,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           40.06456283486065,
           39.99666770845725,
           39.92877258205387,
           39.86087745565047,
           39.792982329247074,
           39.72508720284368,
           39.65719207644029,
           39.589296950036896,
           39.52140182363351,
           39.45350669723011,
           39.385611570826725,
           39.317716444423326,
           39.24982131801993,
           39.18192619161654,
           39.11403106521315,
           39.046135938809755,
           38.97824081240636,
           38.91034568600297,
           38.84245055959958,
           38.774555433196184,
           38.70666030679279,
           38.6387651803894,
           38.570870053986006,
           38.50297492758261,
           38.435079801179214,
           38.36718467477583,
           38.299289548372435,
           38.23139442196904,
           38.16349929556564,
           38.09560416916226,
           38.027709042758865,
           37.95981391635547,
           37.89191878995208,
           37.82402366354869,
           37.75612853714529,
           37.6882334107419,
           37.623845248036346,
           37.566471031972846,
           37.509096815909345,
           37.45172259984585,
           37.39434838378235,
           37.33697416771886,
           37.27959995165535,
           37.222225735591856,
           37.16485151952836,
           37.10747730346486,
           37.05010308740136,
           36.99272887133786,
           36.93535465527437,
           36.877980439210866,
           36.820606223147365,
           36.76323200708387,
           36.70585779102037,
           36.64848357495688,
           36.59110935889338,
           36.53373514282988,
           36.476360926766375,
           36.41898671070288,
           36.36161249463939,
           36.30423827857588,
           36.24686406251239,
           36.189489846448886,
           36.132115630385385,
           36.07474141432189,
           36.0173671982584,
           35.9599929821949,
           35.9026187661314,
           35.8452445500679,
           35.7878703340044,
           35.7304961179409,
           35.6731219018774,
           35.61574768581391,
           35.558373469750414,
           35.50099925368691,
           35.44362503762341,
           35.38625082155991,
           35.32887660549642,
           35.27150238943292,
           35.21412817336942,
           35.156753957305924,
           35.09937974124242,
           35.04200552517892,
           34.98463130911543,
           34.92725709305193,
           34.66804356407459,
           34.36846217251446,
           34.068880780954366,
           33.769299389394256,
           33.469717997834145,
           33.17013660627404,
           32.87055521471393,
           32.57097382315382,
           32.27139243159372,
           31.9718110400336,
           31.67222964847351,
           31.372648256913394,
           31.073066865353287,
           30.773485473793173,
           30.473904082233062,
           30.17432269067297,
           29.874741299112856,
           29.575159907552745,
           29.275578515992635,
           28.975997124432524,
           28.676415732872425,
           28.37683434131231,
           28.077252949752207,
           27.777671558192104,
           27.47809016663198,
           27.178508775071883,
           26.878927383511773,
           26.579345991951662,
           26.279764600391566,
           25.98018320883144,
           25.68060181727134,
           25.38102042571123,
           25.081439034151117,
           24.78185764259102,
           24.482276251030918,
           24.1826948594708,
           23.883113467910693,
           23.58353207635058,
           23.28395068479048,
           22.984369293230376,
           22.68478790167026,
           22.385206510110166,
           22.08562511855004,
           21.78604372698994,
           21.48646233542983,
           21.18688094386972,
           20.887299552309624,
           20.59628043599349,
           20.322385823175363,
           20.048491210357223,
           19.774596597539084,
           19.500701984720955,
           19.22680737190282,
           18.95291275908468,
           18.67901814626654,
           18.4051235334484,
           18.13122892063027,
           17.857334307812135,
           17.58343969499399,
           17.309545082175866,
           17.035650469357716,
           16.761755856539587,
           16.487861243721447,
           16.213966630903307,
           15.940072018085182,
           15.666177405267034,
           15.392282792448906,
           15.118388179630767,
           14.844493566812627,
           14.5705989539945,
           14.296704341176348,
           14.022809728358222,
           13.74891511554008,
           13.475020502721941,
           13.201125889903816,
           12.927231277085676,
           12.653336664267535,
           12.379442051449397,
           12.105547438631257,
           11.83165282581313,
           11.55775821299499,
           11.283863600176852,
           11.009968987358723,
           10.817767881788336,
           10.666413529841845,
           10.515059177895345,
           10.363704825948846,
           10.212350474002355,
           10.078511894038666,
           9.947175564856117,
           9.81583923567357,
           9.68450290649102,
           9.553166577308476,
           9.421830248125922,
           9.290493918943376,
           9.172473809799442,
           9.060346514287968,
           8.948219218776499,
           8.836091923265025,
           8.723964627753553,
           8.611837332242079,
           8.513291428608785,
           8.42010205502449,
           8.326912681440188,
           8.23372330785589,
           8.140533934271593,
           8.054506060055926,
           7.972058935524575,
           7.889611810993218,
           7.80716468646186,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           39.60278658197225,
           39.53489145556886,
           39.46699632916547,
           39.399101202762076,
           39.33120607635868,
           39.26331094995529,
           39.1954158235519,
           39.127520697148505,
           39.059625570745105,
           38.99173044434171,
           38.92383531793832,
           38.85594019153493,
           38.788045065131534,
           38.72014993872814,
           38.65225481232475,
           38.584359685921356,
           38.51646455951797,
           38.44856943311457,
           38.38067430671118,
           38.312779180307786,
           38.24488405390439,
           38.176988927501,
           38.109093801097615,
           38.041198674694215,
           37.97330354829082,
           37.90540842188744,
           37.83751329548404,
           37.769618169080644,
           37.701723042677244,
           37.63382791627386,
           37.565932789870466,
           37.49803766346707,
           37.43014253706368,
           37.36224741066029,
           37.294352284256895,
           37.2264571578535,
           37.1585620314501,
           37.09066690504672,
           37.02277177864332,
           36.95487665223993,
           36.88698152583654,
           36.81908639943315,
           36.75119127302975,
           36.683296146626354,
           36.61540102022296,
           36.547505893819576,
           36.47961076741618,
           36.41171564101278,
           36.34382051460939,
           36.275925388206005,
           36.208030261802605,
           36.14013513539921,
           36.07224000899582,
           36.013112299724256,
           35.95573808366076,
           35.898363867597254,
           35.84098965153376,
           35.78361543547027,
           35.72624121940677,
           35.668867003343266,
           35.61149278727977,
           35.554118571216264,
           35.49674435515277,
           35.43937013908928,
           35.38199592302578,
           35.324621706962276,
           35.26724749089878,
           35.20987327483528,
           35.15249905877179,
           35.09512484270829,
           35.03775062664479,
           34.98037641058129,
           34.92300219451779,
           34.86562797845429,
           34.80825376239079,
           34.7508795463273,
           34.6935053302638,
           34.636131114200296,
           34.5787568981368,
           34.5213826820733,
           34.4640084660098,
           34.40663424994631,
           34.349260033882814,
           34.291885817819306,
           34.03267228884197,
           33.73309089728185,
           33.43350950572175,
           33.133928114161634,
           32.83434672260152,
           32.53476533104143,
           32.23518393948132,
           31.935602547921206,
           31.636021156361096,
           31.336439764800986,
           31.03685837324089,
           30.737276981680775,
           30.437695590120672,
           30.138114198560558,
           29.838532807000448,
           29.53895141544035,
           29.239370023880237,
           28.939788632320127,
           28.640207240760017,
           28.340625849199906,
           28.04104445763981,
           27.741463066079696,
           27.441881674519585,
           27.14230028295949,
           26.842718891399365,
           26.54313749983927,
           26.243556108279158,
           25.943974716719044,
           25.644393325158948,
           25.344811933598823,
           25.045230542038727,
           24.76705481933192,
           24.493160206513785,
           24.219265593695656,
           23.94537098087752,
           23.67147636805938,
           23.39758175524124,
           23.1236871424231,
           22.849792529604972,
           22.575897916786836,
           22.302003303968696,
           22.02810869115057,
           21.754214078332417,
           21.48031946551429,
           21.206424852696152,
           20.932530239878012,
           20.658635627059883,
           20.384741014241733,
           20.110846401423608,
           19.836951788605468,
           19.56305717578733,
           19.2891625629692,
           19.015267950151063,
           18.74137333733292,
           18.46747872451478,
           18.193584111696644,
           17.919689498878515,
           17.645794886060376,
           17.371900273242236,
           17.09800566042411,
           16.82411104760596,
           16.550216434787828,
           16.27632182196969,
           16.002427209151552,
           15.728532596333423,
           15.454637983515275,
           15.180743370697147,
           14.90684875787901,
           14.632954145060868,
           14.359059532242743,
           14.08516491942459,
           13.811270306606463,
           13.537375693788324,
           13.263481080970186,
           12.989586468152059,
           12.715691855333917,
           12.44179724251578,
           12.167902629697638,
           11.894008016879502,
           11.620113404061374,
           11.346218791243231,
           11.072324178425097,
           10.798429565606968,
           10.606228460036581,
           10.454874108090088,
           10.303519756143588,
           10.16296460279637,
           10.031628273613826,
           9.900291944431272,
           9.768955615248723,
           9.637619286066176,
           9.506282956883625,
           9.374946627701082,
           9.24755159171226,
           9.135424296200787,
           9.023297000689315,
           8.91116970517784,
           8.799042409666372,
           8.686915114154898,
           8.576723079679411,
           8.48353370609511,
           8.39034433251081,
           8.297154958926514,
           8.203965585342214,
           8.110776211757914,
           8.027732295612536,
           7.945285171081171,
           7.862838046549821,
           7.780390922018463,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           39.14101032908389,
           39.07311520268049,
           39.005220076277105,
           38.937324949873705,
           38.86942982347032,
           38.80153469706693,
           38.733639570663534,
           38.665744444260135,
           38.59784931785675,
           38.52995419145335,
           38.46205906504996,
           38.394163938646564,
           38.32626881224317,
           38.25837368583978,
           38.19047855943639,
           38.12258343303299,
           38.0546883066296,
           37.986793180226215,
           37.91889805382282,
           37.85100292741942,
           37.78310780101603,
           37.71521267461264,
           37.647317548209244,
           37.57942242180585,
           37.51152729540246,
           37.44363216899907,
           37.375737042595674,
           37.30784191619228,
           37.23994678978889,
           37.172051663385496,
           37.1041565369821,
           37.03626141057871,
           36.96836628417532,
           36.900471157771925,
           36.83257603136853,
           36.76468090496514,
           36.69678577856175,
           36.628890652158354,
           36.56099552575496,
           36.49310039935156,
           36.425205272948176,
           36.35731014654478,
           36.28941502014139,
           36.22151989373799,
           36.153624767334605,
           36.085729640931206,
           36.01783451452782,
           35.94993938812442,
           35.882044261721035,
           35.81414913531764,
           35.74625400891425,
           35.67835888251085,
           35.61046375610746,
           35.542568629704064,
           35.47467350330068,
           35.40677837689728,
           35.338883250493886,
           35.27098812409049,
           35.2030929976871,
           35.13519787128371,
           35.067302744880315,
           34.99940761847692,
           34.93151249207352,
           34.86361736567014,
           34.79572223926675,
           34.72782711286335,
           34.65993198645996,
           34.59203686005657,
           34.524141733653174,
           34.45975356747572,
           34.40237935141222,
           34.34500513534872,
           34.28763091928523,
           34.23025670322173,
           34.172882487158226,
           34.11550827109473,
           34.05813405503123,
           34.00075983896773,
           33.94338562290424,
           33.88601140684074,
           33.82863719077724,
           33.77126297471374,
           33.71388875865024,
           33.65651454258675,
           33.39730101360941,
           33.09771962204928,
           32.79813823048919,
           32.498556838929076,
           32.198975447368966,
           31.899394055808862,
           31.599812664248756,
           31.300231272688645,
           31.00064988112853,
           30.70106848956842,
           30.401487098008328,
           30.10190570644821,
           29.802324314888104,
           29.502742923327993,
           29.211723815488504,
           28.937829202670383,
           28.66393458985224,
           28.3900399770341,
           28.11614536421596,
           27.84225075139782,
           27.568356138579695,
           27.294461525761555,
           27.020566912943416,
           26.746672300125287,
           26.472777687307136,
           26.19888307448901,
           25.92498846167087,
           25.65109384885273,
           25.377199236034603,
           25.103304623216452,
           24.829410010398327,
           24.555515397580187,
           24.281620784762048,
           24.00772617194392,
           23.733831559125782,
           23.459936946307643,
           23.186042333489503,
           22.91214772067136,
           22.63825310785323,
           22.3643584950351,
           22.090463882216955,
           21.816569269398833,
           21.54267465658068,
           21.268780043762554,
           20.994885430944414,
           20.720990818126275,
           20.447096205308146,
           20.173201592489995,
           19.89930697967187,
           19.625412366853727,
           19.35151775403559,
           19.07762314121746,
           18.803728528399322,
           18.529833915581182,
           18.255939302763043,
           17.982044689944907,
           17.708150077126778,
           17.434255464308638,
           17.1603608514905,
           16.886466238672373,
           16.61257162585422,
           16.33867701303609,
           16.064782400217954,
           15.790887787399814,
           15.516993174581687,
           15.243098561763539,
           14.96920394894541,
           14.695309336127272,
           14.421414723309132,
           14.147520110491005,
           13.873625497672853,
           13.599730884854726,
           13.325836272036588,
           13.051941659218446,
           12.77804704640032,
           12.504152433582181,
           12.230257820764042,
           11.956363207945902,
           11.682468595127762,
           11.408573982309635,
           11.134679369491495,
           10.860784756673358,
           10.586890143855229,
           10.394689038284842,
           10.247417311554091,
           10.116080982371537,
           9.98474465318899,
           9.853408324006447,
           9.722071994823892,
           9.590735665641343,
           9.459399336458796,
           9.328063007276246,
           9.21050207811362,
           9.098374782602143,
           8.986247487090672,
           8.874120191579198,
           8.761992896067724,
           8.649865600556256,
           8.546965357165744,
           8.453775983581444,
           8.360586609997144,
           8.267397236412844,
           8.174207862828549,
           8.083405655700483,
           8.000958531169125,
           7.9185114066377755,
           7.836064282106411,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           38.67434617143531,
           38.606451045031925,
           38.538555918628525,
           38.47066079222514,
           38.40276566582175,
           38.33487053941835,
           38.266975413014954,
           38.19908028661157,
           38.13118516020817,
           38.06329003380478,
           37.99539490740138,
           37.92749978099799,
           37.8596046545946,
           37.791709528191205,
           37.72381440178781,
           37.65591927538442,
           37.58802414898103,
           37.520129022577635,
           37.45223389617424,
           37.38433876977085,
           37.31644364336746,
           37.248548516964064,
           37.18065339056067,
           37.11275826415728,
           37.044863137753886,
           36.97696801135049,
           36.9090728849471,
           36.84117775854371,
           36.77328263214031,
           36.70538750573692,
           36.63749237933353,
           36.56959725293014,
           36.501702126526745,
           36.43380700012335,
           36.36591187371995,
           36.29801674731657,
           36.230121620913174,
           36.16222649450978,
           36.09433136810638,
           36.026436241702996,
           35.958541115299596,
           35.89064598889621,
           35.82275086249281,
           35.75485573608942,
           35.686960609686025,
           35.61906548328264,
           35.55117035687924,
           35.48327523047585,
           35.415380104072455,
           35.34748497766906,
           35.27958985126567,
           35.21169472486228,
           35.143799598458884,
           35.07590447205549,
           35.0080093456521,
           34.940114219248706,
           34.87221909284531,
           34.80432396644191,
           34.73642884003853,
           34.668533713635135,
           34.60063858723174,
           34.53274346082834,
           34.46484833442495,
           34.396953208021564,
           34.32905808161817,
           34.26116295521477,
           34.193267828811386,
           34.12537270240799,
           34.0574775760046,
           33.9895824496012,
           33.921687323197816,
           33.85379219679442,
           33.78589707039103,
           33.71800194398764,
           33.650106817584245,
           33.58221169118085,
           33.51431656477746,
           33.44642143837407,
           33.378526311970674,
           33.31063118556728,
           33.24273605916389,
           33.17484093276049,
           33.09898504738438,
           33.02153702189152,
           32.80470190803966,
           32.55998937651598,
           32.290958473641254,
           32.017063860823114,
           31.743169248004975,
           31.46927463518685,
           31.19538002236871,
           30.92148540955057,
           30.64759079673243,
           30.37369618391429,
           30.099801571096165,
           29.825906958278026,
           29.552012345459886,
           29.278117732641743,
           29.004223119823603,
           28.73032850700548,
           28.456433894187338,
           28.1825392813692,
           27.90864466855106,
           27.63475005573292,
           27.360855442914794,
           27.086960830096658,
           26.813066217278514,
           26.539171604460385,
           26.265276991642235,
           25.99138237882411,
           25.717487766005974,
           25.44359315318783,
           25.1696985403697,
           24.895803927551547,
           24.621909314733426,
           24.34801470191529,
           24.07412008909715,
           23.80022547627902,
           23.526330863460885,
           23.25243625064274,
           22.978541637824602,
           22.704647025006462,
           22.430752412188333,
           22.156857799370197,
           21.882963186552058,
           21.609068573733932,
           21.335173960915782,
           21.06127934809765,
           20.78738473527951,
           20.51349012246137,
           20.239595509643244,
           19.96570089682509,
           19.691806284006965,
           19.417911671188826,
           19.144017058370686,
           18.87012244555256,
           18.59622783273442,
           18.32233321991628,
           18.04843860709814,
           17.774543994280002,
           17.500649381461873,
           17.226754768643737,
           16.952860155825597,
           16.678965543007468,
           16.405070930189318,
           16.13117631737119,
           15.857281704553051,
           15.58338709173491,
           15.309492478916784,
           15.035597866098636,
           14.761703253280508,
           14.487808640462369,
           14.213914027644229,
           13.940019414826104,
           13.666124802007952,
           13.392230189189824,
           13.118335576371685,
           12.844440963553545,
           12.570546350735418,
           12.29665173791728,
           12.02275712509914,
           11.748862512281,
           11.474967899462861,
           11.201073286644734,
           10.927178673826596,
           10.653284061008454,
           10.379389448190327,
           10.200533691129243,
           10.0691973619467,
           9.937861032764147,
           9.806524703581598,
           9.675188374399054,
           9.5438520452165,
           9.412515716033953,
           9.285579860026436,
           9.173452564514962,
           9.061325269003493,
           8.949197973492016,
           8.837070677980545,
           8.724943382469071,
           8.612816086957597,
           8.51720763465207,
           8.42401826106777,
           8.33082888748347,
           8.23763951389917,
           8.14445014031487,
           8.056631891257073,
           7.974184766725715,
           7.891737642194357,
           7.8092905176630065,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           38.17224472614748,
           38.10434959974409,
           38.0364544733407,
           37.968559346937305,
           37.90066422053392,
           37.83276909413052,
           37.76487396772713,
           37.696978841323734,
           37.62908371492034,
           37.56118858851695,
           37.493293462113556,
           37.42539833571016,
           37.35750320930676,
           37.28960808290338,
           37.221712956499985,
           37.153817830096585,
           37.08592270369319,
           37.01802757728981,
           36.95013245088641,
           36.882237324483015,
           36.81434219807962,
           36.746447071676236,
           36.67855194527284,
           36.610656818869444,
           36.54276169246605,
           36.47486656606266,
           36.406971439659266,
           36.33907631325588,
           36.27118118685248,
           36.20328606044909,
           36.1353909340457,
           36.0674958076423,
           35.99960068123891,
           35.93170555483552,
           35.863810428432124,
           35.79591530202873,
           35.72802017562534,
           35.660125049221946,
           35.59222992281856,
           35.52433479641516,
           35.456439670011775,
           35.388544543608376,
           35.32064941720499,
           35.25275429080159,
           35.184859164398205,
           35.116964037994805,
           35.04906891159142,
           34.98117378518802,
           34.91327865878463,
           34.84538353238124,
           34.77748840597784,
           34.70959327957445,
           34.64169815317105,
           34.57380302676766,
           34.50590790036428,
           34.43801277396088,
           34.370117647557485,
           34.30222252115409,
           34.2343273947507,
           34.16643226834731,
           34.098537141943915,
           34.03064201554052,
           33.96274688913712,
           33.89485176273374,
           33.826956636330344,
           33.75587720570737,
           33.678429180214515,
           33.60098115472165,
           33.52353312922879,
           33.446085103735925,
           33.36863707824307,
           33.29118905275021,
           33.21374102725735,
           33.136293001764486,
           33.05884497627163,
           32.981396950778766,
           32.90394892528591,
           32.82650089979305,
           32.74905287430018,
           32.67160484880733,
           32.594156823314464,
           32.51670879782161,
           32.439260772328744,
           32.36181274683589,
           32.14497763298402,
           31.90026510146035,
           31.65555256993669,
           31.410840038413028,
           31.166127506889364,
           30.921414975365707,
           30.67670244384204,
           30.431989912318375,
           30.187277380794708,
           29.942564849271044,
           29.697852317747387,
           29.453139786223723,
           29.208427254700055,
           28.96371472317639,
           28.719002191652727,
           28.47428966012907,
           28.229577128605406,
           27.98486459708174,
           27.730424718943667,
           27.456530106125527,
           27.1826354933074,
           26.908740880489262,
           26.634846267671122,
           26.360951654852993,
           26.087057042034843,
           25.813162429216717,
           25.539267816398578,
           25.265373203580438,
           24.99147859076231,
           24.717583977944155,
           24.443689365126033,
           24.169794752307894,
           23.895900139489754,
           23.62200552667163,
           23.34811091385349,
           23.07421630103535,
           22.800321688217206,
           22.52642707539907,
           22.25253246258094,
           21.9786378497628,
           21.704743236944665,
           21.430848624126536,
           21.156954011308386,
           20.88305939849026,
           20.609164785672117,
           20.33527017285398,
           20.061375560035852,
           19.787480947217702,
           19.513586334399573,
           19.239691721581433,
           18.965797108763297,
           18.691902495945165,
           18.41800788312703,
           18.14411327030889,
           17.87021865749075,
           17.59632404467261,
           17.32242943185448,
           17.048534819036345,
           16.774640206218205,
           16.500745593400076,
           16.226850980581926,
           15.952956367763798,
           15.679061754945659,
           15.40516714212752,
           15.131272529309394,
           14.857377916491243,
           14.583483303673116,
           14.309588690854977,
           14.035694078036837,
           13.761799465218711,
           13.48790485240056,
           13.214010239582432,
           12.940115626764293,
           12.666221013946153,
           12.392326401128026,
           12.118431788309886,
           11.844537175491748,
           11.570642562673607,
           11.296747949855467,
           11.022853337037342,
           10.748958724219202,
           10.475064111401062,
           10.201169498582935,
           10.022313741521847,
           9.890977412339305,
           9.759641083156753,
           9.628304753974206,
           9.49696842479166,
           9.365632095609108,
           9.248530346427783,
           9.136403050916309,
           9.024275755404837,
           8.912148459893366,
           8.800021164381889,
           8.687893868870418,
           8.580639285722691,
           8.487449912138391,
           8.394260538554095,
           8.301071164969795,
           8.207881791385494,
           8.114692417801194,
           8.029858126813654,
           7.947411002282303,
           7.864963877750946,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           37.6701432808597,
           37.6022481544563,
           37.53435302805291,
           37.46645790164951,
           37.39856277524613,
           37.330667648842734,
           37.26277252243934,
           37.19487739603595,
           37.126982269632556,
           37.05908714322916,
           36.991192016825764,
           36.92329689042237,
           36.855401764018985,
           36.78750663761559,
           36.7196115112122,
           36.65171638480881,
           36.583821258405415,
           36.51592613200202,
           36.44803100559863,
           36.38013587919523,
           36.31224075279184,
           36.244345626388444,
           36.17645049998506,
           36.10855537358166,
           36.040660247178266,
           35.97276512077488,
           35.90486999437149,
           35.83697486796809,
           35.769079741564695,
           35.70118461516131,
           35.63328948875791,
           35.56539436235452,
           35.497499235951125,
           35.42960410954773,
           35.36170898314434,
           35.29381385674095,
           35.225918730337554,
           35.15802360393416,
           35.09012847753077,
           35.022233351127376,
           34.95433822472398,
           34.88644309832059,
           34.8185479719172,
           34.7506528455138,
           34.68275771911041,
           34.61486259270702,
           34.54696746630363,
           34.47907233990023,
           34.41117721349684,
           34.33532133853755,
           34.25787331304468,
           34.18042528755183,
           34.102977262058964,
           34.0255292365661,
           33.948081211073244,
           33.87063318558038,
           33.79318516008752,
           33.715737134594654,
           33.6382891091018,
           33.56084108360894,
           33.48339305811608,
           33.40594503262322,
           33.32849700713036,
           33.2510489816375,
           33.17360095614464,
           33.096152930651776,
           33.01870490515892,
           32.941256879666064,
           32.8638088541732,
           32.78636082868034,
           32.70891280318748,
           32.631464777694625,
           32.55401675220176,
           32.4765687267089,
           32.399120701216034,
           32.32167267572318,
           32.24422465023032,
           32.16677662473746,
           32.089328599244595,
           32.01188057375174,
           31.934432548258876,
           31.85698452276602,
           31.779536497273156,
           31.7020884717803,
           31.485253357928435,
           31.24054082640476,
           30.995828294881104,
           30.75111576335744,
           30.506403231833772,
           30.26169070031012,
           30.01697816878645,
           29.772265637262784,
           29.52755310573912,
           29.282840574215456,
           29.0381280426918,
           28.793415511168135,
           28.548702979644467,
           28.303990448120803,
           28.05927791659714,
           27.814565385073482,
           27.56985285354982,
           27.32514032202615,
           27.080427790502483,
           26.83571525897882,
           26.591002727455162,
           26.3462901959315,
           26.101577664407834,
           25.856865132884177,
           25.612152601360503,
           25.367440069836846,
           25.122727538313182,
           24.878015006789514,
           24.63330247526586,
           24.388589943742183,
           24.143877412218526,
           23.899164880694862,
           23.654452349171198,
           23.40973981764754,
           23.165027286123877,
           22.895996351427968,
           22.62210173860983,
           22.34820712579169,
           22.07431251297356,
           21.800417900155427,
           21.526523287337284,
           21.25262867451916,
           20.978734061701005,
           20.70483944888288,
           20.43094483606474,
           20.1570502232466,
           19.883155610428474,
           19.60926099761032,
           19.335366384792195,
           19.061471771974055,
           18.787577159155916,
           18.51368254633779,
           18.23978793351965,
           17.96589332070151,
           17.69199870788337,
           17.41810409506523,
           17.144209482247103,
           16.870314869428967,
           16.596420256610827,
           16.3225256437927,
           16.048631030974548,
           15.774736418156419,
           15.50084180533828,
           15.226947192520141,
           14.953052579702014,
           14.679157966883864,
           14.405263354065738,
           14.131368741247599,
           13.857474128429459,
           13.583579515611332,
           13.30968490279318,
           13.035790289975054,
           12.761895677156913,
           12.488001064338773,
           12.214106451520648,
           11.940211838702508,
           11.666317225884367,
           11.392422613066229,
           11.118528000248089,
           10.844633387429962,
           10.570738774611822,
           10.296844161793684,
           10.022949548975555,
           9.844093791914469,
           9.712757462731926,
           9.581421133549373,
           9.450084804366824,
           9.323608128340615,
           9.211480832829134,
           9.099353537317667,
           8.987226241806194,
           8.875098946294719,
           8.76297165078325,
           8.650844355271772,
           8.550881563209025,
           8.457692189624725,
           8.364502816040424,
           8.27131344245613,
           8.178124068871828,
           8.085531486901601,
           8.00308436237025,
           7.920637237838894,
           7.838190113307543,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           37.16804183557186,
           37.10014670916848,
           37.03225158276508,
           36.96435645636169,
           36.8964613299583,
           36.8285662035549,
           36.76067107715151,
           36.69277595074812,
           36.62488082434473,
           36.556985697941336,
           36.489090571537936,
           36.42119544513455,
           36.35330031873115,
           36.285405192327765,
           36.217510065924365,
           36.14961493952097,
           36.08171981311758,
           36.01382468671419,
           35.945929560310795,
           35.8780344339074,
           35.81013930750401,
           35.74224418110062,
           35.674349054697224,
           35.60645392829383,
           35.53855880189044,
           35.470663675487046,
           35.40276854908365,
           35.33487342268026,
           35.26697829627687,
           35.199083169873475,
           35.13118804347008,
           35.06329291706669,
           34.99221349686053,
           34.914765471367666,
           34.83731744587481,
           34.759869420381946,
           34.68242139488909,
           34.60497336939623,
           34.52752534390336,
           34.45007731841051,
           34.37262929291765,
           34.29518126742479,
           34.217733241931924,
           34.14028521643907,
           34.06283719094621,
           33.98538916545335,
           33.90794113996049,
           33.83049311446762,
           33.753045088974766,
           33.67559706348191,
           33.598149037989046,
           33.52070101249619,
           33.443252987003326,
           33.36580496151047,
           33.28835693601761,
           33.21090891052474,
           33.13346088503188,
           33.05601285953902,
           32.97856483404616,
           32.901116808553304,
           32.82366878306044,
           32.746220757567585,
           32.66877273207472,
           32.591324706581865,
           32.513876681089,
           32.436428655596146,
           32.35898063010328,
           32.281532604610426,
           32.20408457911756,
           32.1266365536247,
           32.04918852813184,
           31.971740502638987,
           31.894292477146124,
           31.81684445165326,
           31.7393964261604,
           31.66194840066754,
           31.584500375174684,
           31.50705234968182,
           31.429604324188958,
           31.3521562986961,
           31.274708273203238,
           31.197260247710382,
           31.11981222221752,
           31.042364196724662,
           30.825529082872798,
           30.580816551349123,
           30.336104019825466,
           30.091391488301802,
           29.846678956778135,
           29.60196642525448,
           29.357253893730814,
           29.112541362207146,
           28.867828830683482,
           28.62311629915982,
           28.378403767636165,
           28.133691236112497,
           27.88897870458883,
           27.644266173065166,
           27.3995536415415,
           27.154841110017845,
           26.91012857849418,
           26.665416046970513,
           26.420703515446846,
           26.175990983923185,
           25.931278452399525,
           25.686565920875864,
           25.441853389352197,
           25.19714085782854,
           24.95242832630486,
           24.70771579478121,
           24.46300326325754,
           24.21829073173388,
           23.973578200210223,
           23.728865668686545,
           23.48415313716289,
           23.239440605639224,
           22.99472807411556,
           22.750015542591903,
           22.50530301106824,
           22.260590479544575,
           22.015877948020908,
           21.77116541649724,
           21.526452884973587,
           21.281740353449923,
           21.037027821926255,
           20.792315290402605,
           20.547602758878927,
           20.30289022735527,
           20.058177695831606,
           19.81346516430794,
           19.568752632784285,
           19.324040101260607,
           19.079327569736954,
           18.834615038213286,
           18.58990250668962,
           18.335462596730395,
           18.06156798391226,
           17.787673371094115,
           17.513778758275976,
           17.23988414545784,
           16.96598953263971,
           16.69209491982157,
           16.41820030700343,
           16.144305694185306,
           15.870411081367154,
           15.596516468549027,
           15.322621855730887,
           15.048727242912747,
           14.774832630094622,
           14.500938017276471,
           14.227043404458346,
           13.953148791640206,
           13.679254178822065,
           13.40535956600394,
           13.131464953185787,
           12.857570340367658,
           12.58367572754952,
           12.309781114731381,
           12.035886501913254,
           11.761991889095114,
           11.488097276276974,
           11.214202663458837,
           10.940308050640695,
           10.66641343782257,
           10.39251882500443,
           10.118624212186292,
           9.844729599368163,
           9.665873842307077,
           9.534537513124533,
           9.403201183941983,
           9.286558614741955,
           9.174431319230486,
           9.062304023719006,
           8.950176728207541,
           8.838049432696067,
           8.725922137184591,
           8.614313214279651,
           8.521123840695346,
           8.42793446711105,
           8.334745093526749,
           8.24155571994245,
           8.148366346358154,
           8.058757722458184,
           7.976310597926827,
           7.893863473395476,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           36.665940390284035,
           36.59804526388064,
           36.53015013747725,
           36.46225501107386,
           36.39435988467047,
           36.32646475826707,
           36.25856963186368,
           36.19067450546029,
           36.122779379056894,
           36.05488425265351,
           35.98698912625011,
           35.919093999846716,
           35.85119887344332,
           35.78330374703993,
           35.71540862063654,
           35.647513494233145,
           35.57165762969065,
           35.4942096041978,
           35.416761578704936,
           35.33931355321207,
           35.261865527719216,
           35.18441750222635,
           35.1069694767335,
           35.02952145124063,
           34.95207342574777,
           34.874625400254914,
           34.79717737476206,
           34.719729349269194,
           34.64228132377633,
           34.564833298283475,
           34.48738527279061,
           34.409937247297755,
           34.33248922180489,
           34.25504119631203,
           34.17759317081917,
           34.10014514532631,
           34.02269711983345,
           33.94524909434059,
           33.867801068847726,
           33.79035304335487,
           33.71290501786201,
           33.63545699236915,
           33.55800896687629,
           33.48056094138343,
           33.403112915890574,
           33.32566489039771,
           33.248216864904855,
           33.170768839411984,
           33.09332081391913,
           33.01587278842627,
           32.93842476293341,
           32.86097673744055,
           32.78352871194768,
           32.706080686454825,
           32.62863266096197,
           32.551184635469106,
           32.47373660997625,
           32.396288584483386,
           32.31884055899053,
           32.241392533497674,
           32.1639445080048,
           32.08649648251195,
           32.009048457019084,
           31.931600431526228,
           31.854152406033368,
           31.776704380540505,
           31.69925635504765,
           31.62180832955479,
           31.54436030406193,
           31.466912278569065,
           31.389464253076206,
           31.31201622758335,
           31.234568202090486,
           31.157120176597626,
           31.079672151104766,
           31.002224125611903,
           30.924776100119047,
           30.847328074626184,
           30.769880049133327,
           30.692432023640464,
           30.6149839981476,
           30.537535972654744,
           30.46008794716188,
           30.382639921669025,
           30.16580480781716,
           29.921092276293486,
           29.67637974476983,
           29.431667213246165,
           29.186954681722497,
           28.942242150198844,
           28.69752961867518,
           28.45281708715151,
           28.208104555627845,
           27.96339202410418,
           27.718679492580527,
           27.47396696105686,
           27.229254429533196,
           26.984541898009528,
           26.739829366485864,
           26.49511683496221,
           26.250404303438543,
           26.005691771914876,
           25.76097924039121,
           25.516266708867544,
           25.27155417734389,
           25.026841645820223,
           24.78212911429656,
           24.537416582772906,
           24.292704051249228,
           24.04799151972557,
           23.803278988201907,
           23.558566456678243,
           23.31385392515459,
           23.069141393630908,
           22.824428862107254,
           22.579716330583587,
           22.335003799059926,
           22.09029126753627,
           21.845578736012605,
           21.600866204488938,
           21.35615367296527,
           21.111441141441603,
           20.86672860991795,
           20.622016078394285,
           20.377303546870618,
           20.132591015346968,
           19.88787848382329,
           19.643165952299633,
           19.39845342077597,
           19.153740889252305,
           18.909028357728648,
           18.66431582620497,
           18.419603294681316,
           18.17489076315765,
           17.93017823163398,
           17.685465700110328,
           17.44075316858666,
           17.196040637062996,
           16.951328105539332,
           16.706615574015665,
           16.46190304249201,
           16.217190510968344,
           15.97247797944468,
           15.727765447921023,
           15.483052916397344,
           15.238340384873691,
           14.993627853350024,
           14.74891532182636,
           14.504202790302704,
           14.25949025877903,
           14.014777727255376,
           13.770065195731709,
           13.501034229214673,
           13.227139616396546,
           12.953245003578393,
           12.679350390760266,
           12.405455777942128,
           12.131561165123987,
           11.857666552305862,
           11.583771939487722,
           11.309877326669582,
           11.035982713851443,
           10.762088101033303,
           10.488193488215177,
           10.214298875397036,
           9.940404262578898,
           9.666509649760771,
           9.487653892699685,
           9.361636396654776,
           9.249509101143301,
           9.137381805631827,
           9.02525451012036,
           8.913127214608881,
           8.800999919097414,
           8.688872623585938,
           8.584555491765972,
           8.491366118181675,
           8.398176744597372,
           8.304987371013075,
           8.211797997428775,
           8.118608623844475,
           8.031983958014774,
           7.949536833483415,
           7.867089708952058,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           36.15977885053869,
           36.07450354964182,
           35.99444644526263,
           35.91699841976978,
           35.83955039427691,
           35.76210236878406,
           35.6846543432912,
           35.60720631779834,
           35.52975829230547,
           35.45231026681262,
           35.374862241319754,
           35.2974142158269,
           35.219966190334034,
           35.14251816484118,
           35.065070139348315,
           34.98762211385546,
           34.910174088362595,
           34.83272606286974,
           34.755278037376875,
           34.67783001188401,
           34.600381986391156,
           34.52293396089829,
           34.445485935405436,
           34.36803790991257,
           34.29058988441972,
           34.21314185892685,
           34.13569383343399,
           34.058245807941134,
           33.98079778244827,
           33.903349756955414,
           33.82590173146255,
           33.748453705969695,
           33.67100568047683,
           33.59355765498397,
           33.51610962949111,
           33.43866160399825,
           33.36121357850539,
           33.28376555301253,
           33.20631752751967,
           33.12886950202681,
           33.05142147653395,
           32.97397345104109,
           32.89652542554823,
           32.81907740005537,
           32.741629374562514,
           32.66418134906965,
           32.58673332357679,
           32.509285298083924,
           32.43183727259107,
           32.35438924709821,
           32.276941221605355,
           32.199493196112485,
           32.12204517061963,
           32.04459714512677,
           31.96714911963391,
           31.88970109414105,
           31.812253068648182,
           31.734805043155326,
           31.65735701766247,
           31.579908992169607,
           31.50246096667675,
           31.42501294118388,
           31.347564915691027,
           31.270116890198167,
           31.192668864705308,
           31.115220839212444,
           31.037772813719588,
           30.96032478822673,
           30.882876762733865,
           30.805428737241005,
           30.727980711748145,
           30.65053268625529,
           30.573084660762426,
           30.495636635269562,
           30.418188609776703,
           30.340740584283843,
           30.263292558790987,
           30.185844533298123,
           30.108396507805264,
           30.030948482312404,
           29.95350045681954,
           29.876052431326684,
           29.79860440583382,
           29.72115638034096,
           29.53120603456503,
           29.30262431065506,
           29.057911779131402,
           28.813199247607738,
           28.56848671608407,
           28.323774184560417,
           28.079061653036753,
           27.834349121513085,
           27.589636589989425,
           27.344924058465757,
           27.100211526942104,
           26.855498995418436,
           26.61078646389477,
           26.366073932371105,
           26.121361400847437,
           25.876648869323784,
           25.631936337800116,
           25.387223806276452,
           25.14251127475279,
           24.897798743229117,
           24.653086211705467,
           24.408373680181796,
           24.163661148658132,
           23.91894861713448,
           23.6742360856108,
           23.429523554087144,
           23.18481102256348,
           22.940098491039816,
           22.69538595951616,
           22.450673427992484,
           22.205960896468827,
           21.961248364945163,
           21.7165358334215,
           21.471823301897846,
           21.227110770374175,
           20.98239823885051,
           20.737685707326843,
           20.492973175803183,
           20.248260644279526,
           20.00354811275586,
           19.758835581232194,
           19.514123049708537,
           19.269410518184863,
           19.02469798666121,
           18.779985455137542,
           18.535272923613874,
           18.29056039209022,
           18.045847860566543,
           17.80113532904289,
           17.556422797519225,
           17.311710265995558,
           17.066997734471904,
           16.822285202948237,
           16.57757267142457,
           16.332860139900905,
           16.088147608377238,
           15.843435076853584,
           15.598722545329919,
           15.354010013806253,
           15.109297482282598,
           14.864584950758921,
           14.619872419235264,
           14.3751598877116,
           14.130447356187933,
           13.88573482466428,
           13.641022293140605,
           13.396309761616948,
           13.151597230093284,
           12.906884698569616,
           12.662172167045963,
           12.417459635522285,
           12.172747103998631,
           11.928034572474964,
           11.6833220409513,
           11.438609509427645,
           11.193896977903977,
           10.949184446380313,
           10.704471914856645,
           10.45975938333298,
           10.215046851809326,
           9.970334320285659,
           9.725621788761995,
           9.48090925723834,
           9.324586883056128,
           9.212459587544659,
           9.100332292033185,
           8.988204996521713,
           8.876077701010244,
           8.763950405498763,
           8.651823109987296,
           8.554797769252307,
           8.461608395668007,
           8.36841902208371,
           8.275229648499405,
           8.18204027491511,
           8.088850901330808,
           8.005210193571363,
           7.922763069040013,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           35.60743367365956,
           35.52215837276269,
           35.43688307186582,
           35.351607770968954,
           35.266332470072086,
           35.18105716917521,
           35.09578186827835,
           35.010506567381476,
           34.925231266484616,
           34.83995596558775,
           34.75468066469087,
           34.669405363794006,
           34.58413006289714,
           34.49885476200027,
           34.4135794611034,
           34.328304160206535,
           34.24302885930967,
           34.1577535584128,
           34.0737828150401,
           33.99633478954725,
           33.91888676405438,
           33.84143873856152,
           33.763990713068665,
           33.6865426875758,
           33.60909466208294,
           33.53164663659008,
           33.45419861109722,
           33.37675058560436,
           33.2993025601115,
           33.22185453461864,
           33.14440650912578,
           33.066958483632924,
           32.98951045814006,
           32.9120624326472,
           32.83461440715434,
           32.75716638166148,
           32.67971835616862,
           32.60227033067576,
           32.524822305182894,
           32.44737427969004,
           32.36992625419718,
           32.29247822870432,
           32.215030203211455,
           32.1375821777186,
           32.06013415222574,
           31.98268612673288,
           31.90523810124002,
           31.827790075747156,
           31.7503420502543,
           31.67289402476144,
           31.595445999268577,
           31.517997973775714,
           31.440549948282857,
           31.363101922789998,
           31.285653897297138,
           31.208205871804275,
           31.130757846311415,
           31.053309820818555,
           30.975861795325695,
           30.898413769832835,
           30.820965744339976,
           30.74351771884711,
           30.666069693354252,
           30.588621667861396,
           30.511173642368533,
           30.433725616875673,
           30.356277591382817,
           30.278829565889954,
           30.201381540397094,
           30.123933514904234,
           30.04648548941137,
           29.969037463918514,
           29.891589438425655,
           29.814141412932795,
           29.73669338743993,
           29.659245361947068,
           29.581797336454212,
           29.504349310961352,
           29.426901285468492,
           29.34945325997563,
           29.27200523448277,
           29.194557208989913,
           29.11710918349705,
           29.03966115800419,
           28.84971081222826,
           28.637260002395703,
           28.424809192563163,
           28.212358382730613,
           27.999907572898067,
           27.787456763065528,
           27.57500595323298,
           27.362555143400435,
           27.15010433356789,
           26.937653523735342,
           26.725202713902807,
           26.512751904070257,
           26.30030109423771,
           26.08785028440516,
           25.875399474572617,
           25.662948664740078,
           25.450497854907532,
           25.238046997166325,
           24.99333446564266,
           24.748621934118994,
           24.50390940259534,
           24.259196871071673,
           24.014484339548005,
           23.769771808024352,
           23.525059276500674,
           23.280346744977017,
           23.035634213453353,
           22.79092168192969,
           22.546209150406032,
           22.301496618882354,
           22.0567840873587,
           21.812071555835036,
           21.567359024311372,
           21.32264649278772,
           21.07793396126405,
           20.833221429740384,
           20.58850889821672,
           20.343796366693056,
           20.0990838351694,
           19.854371303645735,
           19.609658772122067,
           19.364946240598414,
           19.120233709074736,
           18.87552117755108,
           18.630808646027415,
           18.386096114503747,
           18.141383582980094,
           17.896671051456416,
           17.651958519932762,
           17.407245988409095,
           17.16253345688543,
           16.917820925361774,
           16.67310839383811,
           16.428395862314442,
           16.183683330790778,
           15.93897079926711,
           15.694258267743457,
           15.44954573621979,
           15.204833204696126,
           14.96012067317247,
           14.715408141648794,
           14.470695610125137,
           14.225983078601473,
           13.981270547077806,
           13.736558015554152,
           13.491845484030478,
           13.24713295250682,
           13.002420420983155,
           12.757707889459489,
           12.512995357935836,
           12.268282826412158,
           12.023570294888504,
           11.778857763364838,
           11.534145231841173,
           11.289432700317517,
           11.04472016879385,
           10.800007637270186,
           10.55529510574652,
           10.310582574222853,
           10.0658700426992,
           9.821157511175532,
           9.576444979651868,
           9.331732448128212,
           9.175410073946,
           9.063282778434532,
           8.951155482923058,
           8.839028187411586,
           8.726900891900117,
           8.618229420322928,
           8.525040046738631,
           8.43185067315433,
           8.338661299570031,
           8.245471925985735,
           8.152282552401429,
           8.060883553659309,
           7.978436429127952,
           7.895989304596594,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           35.05508849678043,
           34.96981319588355,
           34.884537894986686,
           34.799262594089825,
           34.71398729319295,
           34.62871199229608,
           34.543436691399215,
           34.45816139050234,
           34.37288608960548,
           34.287610788708605,
           34.20233548781174,
           34.11706018691487,
           34.031784886018,
           33.946509585121134,
           33.86123428422427,
           33.7759589833274,
           33.69068368243053,
           33.605408381533664,
           33.520133080636796,
           33.43485777973993,
           33.349582478843054,
           33.264307177946186,
           33.179031877049326,
           33.09375657615245,
           33.00848127525558,
           32.923205974358716,
           32.83793067346185,
           32.75265537256498,
           32.66738007166811,
           32.582104770771245,
           32.49682946987437,
           32.4115541689775,
           32.326278868080635,
           32.24100356718377,
           32.1557282662869,
           32.075671159324706,
           31.99822313383185,
           31.920775108338987,
           31.843327082846123,
           31.765879057353263,
           31.688431031860404,
           31.610983006367544,
           31.53353498087468,
           31.456086955381824,
           31.378638929888968,
           31.30119090439611,
           31.223742878903245,
           31.14629485341038,
           31.068846827917525,
           30.991398802424662,
           30.913950776931802,
           30.83650275143894,
           30.75905472594608,
           30.681606700453223,
           30.604158674960367,
           30.526710649467503,
           30.44926262397464,
           30.371814598481777,
           30.29436657298892,
           30.216918547496057,
           30.1394705220032,
           30.062022496510338,
           29.98457447101748,
           29.907126445524625,
           29.82967842003176,
           29.7522303945389,
           29.674782369046042,
           29.59733434355318,
           29.51988631806032,
           29.44243829256746,
           29.364990267074596,
           29.28754224158174,
           29.21009421608888,
           29.13264619059602,
           29.055198165103157,
           28.977750139610293,
           28.900302114117437,
           28.822854088624577,
           28.745406063131718,
           28.667958037638854,
           28.590510012145998,
           28.513061986653135,
           28.43561396116028,
           28.358165935667415,
           28.16821558989149,
           27.95576478005893,
           27.743313970226396,
           27.530863160393846,
           27.318412350561296,
           27.105961540728764,
           26.893510730896217,
           26.681059921063667,
           26.46860911123112,
           26.25615830139857,
           26.04370749156604,
           25.831256681733485,
           25.618805871900946,
           25.406355062068393,
           25.19390425223585,
           24.98145344240331,
           24.769002632570764,
           24.556551822738218,
           24.34410101290567,
           24.13165020307312,
           23.919199393240582,
           23.706748583408036,
           23.49429777357549,
           23.28184696374295,
           23.069396153910393,
           22.856945344077857,
           22.644494534245307,
           22.43204372441276,
           22.219592914580222,
           22.007142104747665,
           21.79469129491513,
           21.58224048508258,
           21.369789675250033,
           21.157338865417497,
           20.928757152153924,
           20.684044620630253,
           20.439332089106593,
           20.194619557582925,
           19.949907026059268,
           19.705194494535604,
           19.460481963011937,
           19.215769431488283,
           18.971056899964605,
           18.72634436844095,
           18.481631836917288,
           18.23691930539362,
           17.992206773869967,
           17.74749424234629,
           17.50278171082263,
           17.25806917929897,
           17.0133566477753,
           16.768644116251647,
           16.523931584727983,
           16.279219053204315,
           16.034506521680655,
           15.789793990156982,
           15.545081458633328,
           15.300368927109666,
           15.055656395585995,
           14.810943864062342,
           14.566231332538663,
           14.32151880101501,
           14.076806269491348,
           13.832093737967678,
           13.587381206444023,
           13.34266867492035,
           13.097956143396697,
           12.853243611873028,
           12.608531080349366,
           12.363818548825709,
           12.119106017302034,
           11.874393485778379,
           11.62968095425471,
           11.384968422731047,
           11.140255891207392,
           10.895543359683723,
           10.650830828160059,
           10.406118296636393,
           10.161405765112729,
           9.916693233589072,
           9.671980702065405,
           9.42726817054174,
           9.182555639018087,
           9.026233264835875,
           8.914105969324407,
           8.80197867381293,
           8.689851378301459,
           8.588471697809256,
           8.495282324224952,
           8.402092950640656,
           8.308903577056356,
           8.215714203472055,
           8.122524829887759,
           8.034109789215892,
           7.951662664684542,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           34.502743319901334,
           34.41746801900447,
           34.33219271810759,
           34.246917417210724,
           34.16164211631386,
           34.07636681541699,
           33.99109151452012,
           33.905816213623254,
           33.82054091272638,
           33.73526561182951,
           33.649990310932644,
           33.564715010035776,
           33.47943970913891,
           33.39416440824205,
           33.30888910734517,
           33.223613806448306,
           33.13833850555144,
           33.05306320465457,
           32.9677879037577,
           32.88251260286083,
           32.79723730196396,
           32.7119620010671,
           32.626686700170225,
           32.54141139927336,
           32.45613609837649,
           32.37086079747962,
           32.285585496582755,
           32.20031019568589,
           32.11503489478902,
           32.02975959389215,
           31.944484292995284,
           31.859208992098417,
           31.77393369120154,
           31.68865839030468,
           31.603383089407806,
           31.51810778851094,
           31.43283248761407,
           31.347557186717204,
           31.262281885820336,
           31.17700658492346,
           31.091731284026597,
           31.006455983129733,
           30.921180682232865,
           30.835905381335994,
           30.75063008043913,
           30.665354779542255,
           30.580079478645388,
           30.49480417774852,
           30.409528876851653,
           30.324253575954785,
           30.238978275057914,
           30.155007529102225,
           30.077559503609365,
           30.00011147811651,
           29.922663452623645,
           29.845215427130782,
           29.767767401637922,
           29.69031937614506,
           29.612871350652203,
           29.535423325159343,
           29.457975299666487,
           29.380527274173623,
           29.30307924868076,
           29.225631223187904,
           29.14818319769504,
           29.07073517220218,
           28.99328714670932,
           28.915839121216464,
           28.8383910957236,
           28.760943070230738,
           28.68349504473788,
           28.606047019245025,
           28.528598993752162,
           28.4511509682593,
           28.37370294276644,
           28.29625491727358,
           28.218806891780723,
           28.14135886628786,
           28.063910840794996,
           27.98646281530214,
           27.909014789809277,
           27.83156676431642,
           27.754118738823557,
           27.6766707133307,
           27.486720367554767,
           27.274269557722214,
           27.061818747889674,
           26.849367938057128,
           26.636917128224578,
           26.424466318392042,
           26.212015508559496,
           25.999564698726946,
           25.7871138888944,
           25.57466307906185,
           25.362212269229317,
           25.149761459396768,
           24.937310649564225,
           24.72485983973167,
           24.51240902989913,
           24.299958220066593,
           24.087507410234043,
           23.875056600401493,
           23.662605790568946,
           23.4501549807364,
           23.23770417090386,
           23.025253361071314,
           22.812802551238768,
           22.600351741406232,
           22.38790093157367,
           22.175450121741136,
           21.96299931190859,
           21.750548502076043,
           21.538097692243504,
           21.325646882410947,
           21.113196072578408,
           20.90074526274586,
           20.68829445291331,
           20.475843643080776,
           20.263392833248233,
           20.05094202341568,
           19.83849121358314,
           19.626040403750586,
           19.413589593918047,
           19.201138784085504,
           18.988687974252954,
           18.77623716442042,
           18.56378635458786,
           18.351335544755322,
           18.138884734922776,
           17.92643392509023,
           17.71398311525769,
           17.501532305425137,
           17.289081495592598,
           17.07663068576005,
           16.864179838665187,
           16.619467307141534,
           16.374754775617866,
           16.1300422440942,
           15.885329712570535,
           15.640617181046869,
           15.395904649523214,
           15.151192117999548,
           14.906479586475882,
           14.661767054952229,
           14.41705452342855,
           14.172341991904895,
           13.92762946038123,
           13.682916928857566,
           13.438204397333909,
           13.193491865810234,
           12.94877933428658,
           12.704066802762913,
           12.459354271239247,
           12.214641739715592,
           11.969929208191916,
           11.72521667666826,
           11.480504145144597,
           11.235791613620929,
           10.991079082097276,
           10.74636655057361,
           10.501654019049942,
           10.256941487526277,
           10.01222895600261,
           9.767516424478956,
           9.522803892955292,
           9.278091361431624,
           9.03337882990797,
           8.877056455725759,
           8.764929160214292,
           8.652801864702816,
           8.558713975295587,
           8.46552460171129,
           8.372335228126985,
           8.27914585454269,
           8.185956480958389,
           8.092767107374089,
           8.007336024772496,
           7.924888900241132,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           33.9503981430222,
           33.86512284212533,
           33.779847541228456,
           33.69457224033159,
           33.60929693943472,
           33.52402163853785,
           33.438746337640985,
           33.35347103674412,
           33.26819573584725,
           33.182920434950375,
           33.09764513405351,
           33.01236983315664,
           32.92709453225977,
           32.841819231362905,
           32.756543930466044,
           32.67126862956917,
           32.5859933286723,
           32.500718027775434,
           32.41544272687857,
           32.3301674259817,
           32.24489212508483,
           32.15961682418796,
           32.07434152329109,
           31.98906622239422,
           31.903790921497354,
           31.81851562060049,
           31.733240319703622,
           31.647965018806747,
           31.562689717909883,
           31.477414417013016,
           31.392139116116148,
           31.30686381521928,
           31.221588514322406,
           31.136313213425545,
           31.05103791252867,
           30.965762611631803,
           30.88048731073494,
           30.795212009838068,
           30.7099367089412,
           30.624661408044332,
           30.53938610714746,
           30.454110806250597,
           30.36883550535373,
           30.283560204456858,
           30.198284903559994,
           30.11300960266312,
           30.02773430176625,
           29.942459000869384,
           29.857183699972516,
           29.77190839907565,
           29.68663309817878,
           29.601357797281914,
           29.51608249638504,
           29.430807195488175,
           29.34553189459131,
           29.260256593694436,
           29.174981292797572,
           29.0897059919007,
           29.004430691003833,
           28.91915539010697,
           28.833880089210098,
           28.74860478831323,
           28.66332948741636,
           28.57805418651949,
           28.492778885622624,
           28.407503584725752,
           28.32222828382889,
           28.23695298293202,
           28.15689587338683,
           28.07944784789397,
           28.00199982240111,
           27.924551796908254,
           27.84710377141539,
           27.769655745922528,
           27.692207720429668,
           27.614759694936808,
           27.53731166944395,
           27.45986364395109,
           27.38241561845823,
           27.30496759296537,
           27.227519567472505,
           27.15007154197965,
           27.072623516486786,
           26.99517549099393,
           26.805225145217996,
           26.59277433538544,
           26.3803235255529,
           26.167872715720353,
           25.955421905887807,
           25.74297109605527,
           25.530520286222725,
           25.318069476390175,
           25.10561866655763,
           24.893167856725082,
           24.680717046892546,
           24.468266237059993,
           24.25581542722745,
           24.0433646173949,
           23.830913807562354,
           23.618462997729818,
           23.40601218789727,
           23.193561378064725,
           22.981110568232175,
           22.76865975839963,
           22.55620894856709,
           22.343758138734543,
           22.131307328901997,
           21.918856519069458,
           21.7064057092369,
           21.493954899404365,
           21.281504089571815,
           21.06905327973927,
           20.856602469906733,
           20.644151660074176,
           20.431700850241636,
           20.21925004040909,
           20.00679923057654,
           19.794348420744004,
           19.581897610911458,
           19.36944680107891,
           19.156995991246365,
           18.944545181413815,
           18.732094371581276,
           18.519643561748733,
           18.307192751916183,
           18.094741942083648,
           17.88229113225109,
           17.66984032241855,
           17.457389512586005,
           17.24493870275346,
           17.03248789292092,
           16.820037083088362,
           16.607586273255826,
           16.39513546342328,
           16.18268465359073,
           15.97023384375819,
           15.757783033925644,
           15.545332224093098,
           15.332881414260552,
           15.120430604428005,
           14.907979794595466,
           14.69552898476292,
           14.483078174930373,
           14.270627365097834,
           14.058176555265277,
           13.845725745432738,
           13.633274935600191,
           13.420824125767645,
           13.208373315935107,
           12.995922506102552,
           12.783471696270015,
           12.554889993652786,
           12.31017746212912,
           12.065464930605465,
           11.820752399081789,
           11.576039867558134,
           11.331327336034468,
           11.086614804510802,
           10.841902272987149,
           10.597189741463481,
           10.352477209939815,
           10.10776467841615,
           9.863052146892484,
           9.618339615368829,
           9.373627083845165,
           9.128914552321497,
           8.884202020797844,
           8.727879646615632,
           8.622145626366212,
           8.528956252781912,
           8.435766879197612,
           8.342577505613313,
           8.249388132029011,
           8.156198758444715,
           8.063009384860415,
           7.980562260329077,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           33.39607847813353,
           33.307233066534806,
           33.221957765637946,
           33.13668246474107,
           33.05140716384421,
           32.966131862947336,
           32.88085656205047,
           32.7955812611536,
           32.71030596025673,
           32.625030659359865,
           32.539755358463,
           32.45448005756613,
           32.369204756669255,
           32.283929455772395,
           32.19865415487553,
           32.11337885397865,
           32.028103553081785,
           31.942828252184917,
           31.857552951288046,
           31.772277650391178,
           31.68700234949431,
           31.60172704859744,
           31.516451747700575,
           31.431176446803704,
           31.345901145906833,
           31.26062584500997,
           31.1753505441131,
           31.090075243216234,
           31.004799942319362,
           30.919524641422495,
           30.834249340525627,
           30.74897403962876,
           30.663698738731892,
           30.578423437835024,
           30.493148136938153,
           30.40787283604128,
           30.322597535144418,
           30.237322234247547,
           30.15204693335068,
           30.06677163245381,
           29.981496331556944,
           29.896221030660076,
           29.81094572976321,
           29.725670428866334,
           29.640395127969473,
           29.555119827072605,
           29.469844526175734,
           29.384569225278863,
           29.299293924382003,
           29.21401862348513,
           29.128743322588264,
           29.043468021691396,
           28.958192720794525,
           28.87291741989766,
           28.787642119000793,
           28.70236681810392,
           28.617091517207054,
           28.53181621631018,
           28.44654091541332,
           28.361265614516448,
           28.275990313619577,
           28.19071501272271,
           28.10543971182584,
           28.020164410928974,
           27.934889110032106,
           27.84961380913524,
           27.76433850823837,
           27.6790632073415,
           27.593787906444632,
           27.50851260554776,
           27.423237304650893,
           27.33796200375403,
           27.25268670285716,
           27.16741140196029,
           27.082136101063423,
           26.996860800166555,
           26.911585499269687,
           26.82631019837282,
           26.74103489747595,
           26.655759596579077,
           26.57048429568221,
           26.485208994785346,
           26.399933693888475,
           26.314658392991607,
           26.12340350131501,
           25.910952691482457,
           25.698501881649918,
           25.48605107181737,
           25.273600261984825,
           25.061149452152286,
           24.848698642319743,
           24.636247832487193,
           24.423797022654647,
           24.2113462128221,
           23.99889540298956,
           23.78644459315701,
           23.573993783324465,
           23.361542973491918,
           23.14909216365937,
           22.936641353826833,
           22.724190543994283,
           22.511739734161736,
           22.29928892432919,
           22.08683811449664,
           21.874387304664108,
           21.661936494831558,
           21.44948568499901,
           21.237034875166472,
           21.024584065333915,
           20.812133255501376,
           20.59968244566883,
           20.387231635836283,
           20.174780826003744,
           19.962330016171187,
           19.74987920633865,
           19.5374283965061,
           19.32497758667356,
           19.11252677684102,
           18.900075967008473,
           18.687625157175926,
           18.47517434734338,
           18.26272353751083,
           18.050272727678294,
           17.837821917845744,
           17.625371108013198,
           17.412920298180662,
           17.2004694883481,
           16.988018678515566,
           16.77556786868302,
           16.56311705885047,
           16.350666249017934,
           16.138215439185377,
           15.92576462935284,
           15.713313819520295,
           15.500863009687746,
           15.288412199855207,
           15.07596139002266,
           14.863510580190114,
           14.651059770357564,
           14.438608960525018,
           14.226158150692482,
           14.013707340859934,
           13.801256531027386,
           13.58880572119485,
           13.376354911362293,
           13.163904101529754,
           12.951453291697208,
           12.73900248186466,
           12.526551672032122,
           12.314100862199568,
           12.10165005236703,
           11.889199242534483,
           11.676748432701935,
           11.464297622869397,
           11.25184681303684,
           11.039396003204303,
           10.826945193371754,
           10.614494383539208,
           10.402043573706669,
           10.189592763874122,
           9.977141954041576,
           9.764691144209028,
           9.55224033437648,
           9.339789524543942,
           9.127338714711394,
           8.91488790487885,
           8.713884078117252,
           8.592387903852542,
           8.499198530268245,
           8.406009156683945,
           8.312819783099645,
           8.21963040951535,
           8.126441035931045,
           8.036235620417033,
           7.953788495885675,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           32.79486466205371,
           32.704234188477024,
           32.61360371490034,
           32.52297324132366,
           32.432342767746974,
           32.34171229417029,
           32.25108182059361,
           32.160451347016924,
           32.06982087344025,
           31.979190399863562,
           31.888559926286877,
           31.7979294527102,
           31.707298979133512,
           31.61666850555683,
           31.52603803198015,
           31.435407558403462,
           31.34477708482678,
           31.2541466112501,
           31.16797878510768,
           31.082703484210814,
           30.997428183313946,
           30.912152882417075,
           30.82687758152021,
           30.741602280623344,
           30.65632697972647,
           30.571051678829605,
           30.485776377932737,
           30.40050107703587,
           30.315225776139,
           30.22995047524213,
           30.144675174345263,
           30.059399873448395,
           29.974124572551528,
           29.88884927165466,
           29.80357397075779,
           29.71829866986092,
           29.633023368964054,
           29.547748068067182,
           29.462472767170315,
           29.377197466273447,
           29.29192216537658,
           29.206646864479712,
           29.121371563582844,
           29.036096262685973,
           28.95082096178911,
           28.865545660892238,
           28.78027035999537,
           28.694995059098495,
           28.609719758201635,
           28.524444457304764,
           28.439169156407893,
           28.35389385551103,
           28.268618554614157,
           28.18334325371729,
           28.098067952820426,
           28.012792651923554,
           27.927517351026687,
           27.842242050129812,
           27.75696674923295,
           27.671691448336084,
           27.586416147439213,
           27.501140846542345,
           27.415865545645474,
           27.33059024474861,
           27.245314943851742,
           27.16003964295487,
           27.074764342058007,
           26.98948904116114,
           26.904213740264268,
           26.818938439367397,
           26.73366313847053,
           26.648387837573665,
           26.563112536676798,
           26.477837235779926,
           26.39256193488306,
           26.30728663398619,
           26.222011333089323,
           26.136736032192456,
           26.051460731295588,
           25.966185430398717,
           25.880910129501846,
           25.79563482860498,
           25.71035952770811,
           25.625084226811243,
           25.433829335134646,
           25.22137852530209,
           25.00892771546955,
           24.796476905637004,
           24.584026095804457,
           24.37157528597192,
           24.159124476139375,
           23.946673666306825,
           23.73422285647428,
           23.521772046641733,
           23.309321236809197,
           23.096870426976643,
           22.884419617144097,
           22.67196880731155,
           22.459517997479004,
           22.247067187646465,
           22.03461637781392,
           21.822165567981372,
           21.609714758148826,
           21.39726394831628,
           21.18481313848374,
           20.972362328651194,
           20.759911518818647,
           20.547460708986108,
           20.33500989915355,
           20.122559089321012,
           19.910108279488465,
           19.69765746965592,
           19.48520665982338,
           19.272755849990823,
           19.060305040158287,
           18.847854230325737,
           18.635403420493194,
           18.422952610660655,
           18.210501800828105,
           17.998050990995562,
           17.785600181163012,
           17.573149371330466,
           17.36069856149793,
           17.14824775166538,
           16.935796941832834,
           16.723346132000298,
           16.51089532216774,
           16.2984445123352,
           16.085993702502655,
           15.873542892670105,
           15.66109208283757,
           15.448641273005013,
           15.236190463172473,
           15.023739653339927,
           14.81128884350738,
           14.598838033674841,
           14.386387223842295,
           14.173936414009749,
           13.961485604177199,
           13.749034794344652,
           13.536583984512117,
           13.324133174679567,
           13.11168236484702,
           12.899231555014484,
           12.686780745181926,
           12.474329935349388,
           12.261879125516842,
           12.049428315684292,
           11.836977505851756,
           11.6245266960192,
           11.440693392027413,
           11.262583616401901,
           11.084473840776392,
           10.906364065150889,
           10.728254289525369,
           10.550144513899868,
           10.372034738274357,
           10.193924962648847,
           10.015815187023343,
           9.837705411397833,
           9.659595635772323,
           9.481485860146813,
           9.303376084521302,
           9.125266308895798,
           8.947156533270288,
           8.769046757644778,
           8.590936982019276,
           8.469440807754566,
           8.376251434170271,
           8.283062060585971,
           8.189872687001671,
           8.096683313417374,
           8.009461855973614,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           32.19365084597389,
           32.10302037239721,
           32.01238989882052,
           31.92175942524384,
           31.83112895166716,
           31.74049847809048,
           31.649868004513795,
           31.55923753093711,
           31.46860705736043,
           31.377976583783745,
           31.28734611020706,
           31.19671563663038,
           31.106085163053695,
           31.015454689477014,
           30.92482421590033,
           30.83419374232365,
           30.743563268746964,
           30.652932795170287,
           30.5623023215936,
           30.471671848016914,
           30.381041374440233,
           30.29041090086355,
           30.199780427286868,
           30.109149953710183,
           30.018519480133502,
           29.927889006556818,
           29.837258532980137,
           29.746628059403456,
           29.655997585826768,
           29.565367112250087,
           29.474736638673406,
           29.384106165096725,
           29.293475691520037,
           29.202845217943356,
           29.11399980457742,
           29.028724503680554,
           28.94344920278369,
           28.85817390188682,
           28.77289860098995,
           28.687623300093083,
           28.602347999196212,
           28.517072698299344,
           28.431797397402477,
           28.346522096505606,
           28.261246795608745,
           28.175971494711874,
           28.090696193815003,
           28.00542089291813,
           27.920145592021264,
           27.8348702911244,
           27.74959499022753,
           27.66431968933066,
           27.579044388433793,
           27.493769087536926,
           27.408493786640058,
           27.323218485743183,
           27.23794318484632,
           27.152667883949448,
           27.067392583052587,
           26.982117282155716,
           26.896841981258845,
           26.811566680361977,
           26.72629137946511,
           26.641016078568242,
           26.555740777671375,
           26.470465476774507,
           26.385190175877643,
           26.29991487498077,
           26.214639574083904,
           26.129364273187033,
           26.044088972290165,
           25.958813671393298,
           25.87353837049643,
           25.788263069599562,
           25.70298776870269,
           25.61771246780582,
           25.532437166908956,
           25.447161866012088,
           25.36188656511522,
           25.27661126421835,
           25.19133596332148,
           25.106060662424614,
           25.020785361527746,
           24.935510060630875,
           24.744255168954282,
           24.531804359121722,
           24.319353549289186,
           24.106902739456636,
           23.89445192962409,
           23.682001119791554,
           23.469550309959004,
           23.257099500126458,
           23.04464869029391,
           22.832197880461365,
           22.619747070628826,
           22.40729626079628,
           22.194845450963733,
           21.982394641131187,
           21.769943831298637,
           21.5574930214661,
           21.345042211633555,
           21.132591401801008,
           20.920140591968458,
           20.707689782135915,
           20.495238972303376,
           20.282788162470826,
           20.07033735263828,
           19.85788654280574,
           19.645435732973183,
           19.432984923140648,
           19.220534113308098,
           19.00808330347555,
           18.795632493643016,
           18.58318168381046,
           18.37073087397792,
           18.158280064145373,
           17.945829254312827,
           17.733378444480287,
           17.52092763464774,
           17.308476824815195,
           17.096026014982645,
           16.883575205150102,
           16.671124395317563,
           16.458673585485013,
           16.246222775652466,
           16.03377196581993,
           15.821321155987373,
           15.608870346154836,
           15.396419536322288,
           15.183968726489741,
           14.971517916657204,
           14.759067106824647,
           14.54661629699211,
           14.345612481563084,
           14.167502705937572,
           13.989392930312068,
           13.81128315468656,
           13.633173379061049,
           13.455063603435537,
           13.276953827810027,
           13.098844052184525,
           12.920734276559013,
           12.742624500933504,
           12.564514725308001,
           12.386404949682483,
           12.20829517405698,
           12.03018539843147,
           11.852075622805959,
           11.673965847180458,
           11.49585607155494,
           11.317746295929437,
           11.139636520303927,
           10.961526744678416,
           10.783416969052913,
           10.605307193427395,
           10.427197417801892,
           10.249087642176383,
           10.070977866550871,
           9.892868090925369,
           9.714758315299859,
           9.536648539674347,
           9.358538764048838,
           9.180428988423326,
           9.002319212797824,
           8.824209437172314,
           8.646099661546803,
           8.467989885921302,
           8.346493711656592,
           8.253304338072297,
           8.160114964487995,
           8.066925590903695,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           31.59243702989412,
           31.501806556317433,
           31.41117608274076,
           31.32054560916407,
           31.22991513558739,
           31.139284662010706,
           31.04865418843402,
           30.958023714857337,
           30.86739324128066,
           30.776762767703975,
           30.68613229412729,
           30.59550182055061,
           30.504871346973925,
           30.414240873397244,
           30.323610399820556,
           30.23297992624388,
           30.142349452667197,
           30.051718979090513,
           29.96108850551383,
           29.870458031937144,
           29.77982755836046,
           29.689197084783782,
           29.598566611207097,
           29.507936137630413,
           29.41730566405373,
           29.326675190477047,
           29.236044716900366,
           29.14541424332368,
           29.054783769747,
           28.964153296170316,
           28.873522822593635,
           28.782892349016954,
           28.692261875440266,
           28.601631401863585,
           28.5110009282869,
           28.420370454710216,
           28.329739981133535,
           28.239109507556854,
           28.14847903398017,
           28.057848560403485,
           27.9672180868268,
           27.876587613250123,
           27.785957139673435,
           27.695326666096754,
           27.604696192520077,
           27.514065718943385,
           27.423435245366704,
           27.332804771790023,
           27.242174298213342,
           27.15154382463666,
           27.060913351059973,
           26.97474552315035,
           26.88947022225348,
           26.80419492135661,
           26.718919620459744,
           26.633644319562876,
           26.54836901866601,
           26.463093717769134,
           26.377818416872273,
           26.292543115975405,
           26.20726781507853,
           26.121992514181663,
           26.036717213284795,
           25.951441912387928,
           25.86616661149106,
           25.780891310594193,
           25.69561600969733,
           25.610340708800457,
           25.52506540790359,
           25.439790107006722,
           25.354514806109854,
           25.269239505212987,
           25.18396420431612,
           25.098688903419248,
           25.01341360252238,
           24.92813830162551,
           24.84286300072865,
           24.757587699831774,
           24.672312398934906,
           24.58703709803804,
           24.50176179714117,
           24.416486496244303,
           24.331211195347436,
           24.245935894450568,
           24.054681002773965,
           23.842230192941408,
           23.629779383108872,
           23.41732857327633,
           23.204877763443776,
           22.99242695361124,
           22.77997614377869,
           22.567525333946143,
           22.355074524113597,
           22.14262371428105,
           21.93017290444852,
           21.71772209461597,
           21.50527128478342,
           21.292820474950872,
           21.080369665118326,
           20.86791885528579,
           20.65546804545324,
           20.443017235620694,
           20.230566425788147,
           20.0181156159556,
           19.805664806123062,
           19.593213996290512,
           19.38076318645797,
           19.16831237662543,
           18.955861566792873,
           18.743410756960337,
           18.530959947127783,
           18.31850913729524,
           18.106058327462705,
           17.893607517630144,
           17.68115670779761,
           17.46870589796506,
           17.256255088132516,
           17.07242179547326,
           16.894312019847753,
           16.71620224422224,
           16.53809246859673,
           16.35998269297122,
           16.181872917345714,
           16.003763141720206,
           15.825653366094695,
           15.647543590469194,
           15.469433814843676,
           15.291324039218173,
           15.113214263592662,
           14.935104487967152,
           14.75699471234165,
           14.578884936716129,
           14.400775161090628,
           14.222665385465117,
           14.044555609839609,
           13.866445834214105,
           13.688336058588593,
           13.510226282963085,
           13.332116507337574,
           13.154006731712062,
           12.97589695608656,
           12.79778718046105,
           12.619677404835539,
           12.441567629210036,
           12.26345785358452,
           12.085348077959015,
           11.907238302333505,
           11.729128526707996,
           11.551018751082491,
           11.372908975456975,
           11.194799199831472,
           11.01668942420596,
           10.83857964858045,
           10.660469872954948,
           10.48236009732943,
           10.304250321703927,
           10.126140546078418,
           9.948030770452908,
           9.769920994827405,
           9.591811219201894,
           9.413701443576382,
           9.235591667950873,
           9.057481892325361,
           8.879372116699859,
           8.701262341074349,
           8.523152565448838,
           8.345042789823337,
           8.223546615558625,
           8.13035724197433,
           8.038361451618151,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           30.991223213814305,
           30.90059274023762,
           30.80996226666094,
           30.719331793084255,
           30.628701319507574,
           30.53807084593089,
           30.447440372354208,
           30.356809898777524,
           30.26617942520084,
           30.175548951624158,
           30.084918478047474,
           29.99428800447079,
           29.903657530894108,
           29.813027057317427,
           29.72239658374074,
           29.631766110164058,
           29.541135636587377,
           29.450505163010693,
           29.35987468943401,
           29.269244215857327,
           29.178613742280646,
           29.087983268703965,
           28.99735279512728,
           28.906722321550596,
           28.81609184797391,
           28.72546137439723,
           28.63483090082055,
           28.544200427243865,
           28.453569953667184,
           28.3629394800905,
           28.272309006513815,
           28.181678532937134,
           28.09104805936045,
           28.000417585783765,
           27.909787112207084,
           27.8191566386304,
           27.72852616505372,
           27.637895691477034,
           27.547265217900353,
           27.45663474432367,
           27.366004270746984,
           27.275373797170303,
           27.18474332359362,
           27.094112850016934,
           27.003482376440253,
           26.912851902863572,
           26.822221429286888,
           26.731590955710203,
           26.640960482133526,
           26.55033000855684,
           26.45969953498016,
           26.369069061403472,
           26.27843858782679,
           26.18780811425011,
           26.097177640673426,
           26.00654716709674,
           25.91591669352006,
           25.825286219943372,
           25.734655746366695,
           25.64402527279001,
           25.55339479921333,
           25.46276432563664,
           25.37213385205996,
           25.28150337848328,
           25.190872904906595,
           25.10024243132991,
           25.00961195775323,
           24.920766542620093,
           24.835491241723226,
           24.750215940826354,
           24.664940639929487,
           24.579665339032623,
           24.49439003813575,
           24.40911473723888,
           24.323839436342013,
           24.238564135445145,
           24.153288834548277,
           24.06801353365141,
           23.982738232754542,
           23.89746293185767,
           23.812187630960803,
           23.72691233006394,
           23.641637029167068,
           23.5563617282702,
           23.365106836593604,
           23.152656026761044,
           22.940205216928508,
           22.727754407095958,
           22.515303597263415,
           22.302852787430876,
           22.090401977598326,
           21.877951167765783,
           21.66550035793323,
           21.453049548100683,
           21.240598738268147,
           21.028147928435597,
           20.81569711860305,
           20.603246308770505,
           20.390795498937955,
           20.17834468910542,
           19.977340885008932,
           19.79923110938342,
           19.621121333757912,
           19.4430115581324,
           19.264901782506897,
           19.08679200688139,
           18.908682231255877,
           18.730572455630373,
           18.552462680004854,
           18.374352904379354,
           18.196243128753842,
           18.01813335312833,
           17.840023577502826,
           17.66191380187731,
           17.483804026251807,
           17.305694250626296,
           17.127584475000788,
           16.949474699375287,
           16.771364923749775,
           16.593255148124264,
           16.415145372498756,
           16.237035596873245,
           16.05892582124774,
           15.880816045622232,
           15.702706269996721,
           15.524596494371218,
           15.346486718745698,
           15.168376943120197,
           14.990267167494686,
           14.812157391869174,
           14.634047616243674,
           14.455937840618155,
           14.27782806499265,
           14.099718289367143,
           13.921608513741631,
           13.743498738116127,
           13.56538896249062,
           13.387279186865108,
           13.209169411239596,
           13.031059635614087,
           12.852949859988584,
           12.674840084363073,
           12.496730308737563,
           12.31862053311206,
           12.140510757486542,
           11.962400981861038,
           11.784291206235526,
           11.606181430610015,
           11.428071654984514,
           11.249961879358995,
           11.071852103733494,
           10.893742328107983,
           10.715632552482473,
           10.53752277685697,
           10.359413001231452,
           10.18130322560595,
           10.003193449980438,
           9.825083674354929,
           9.646973898729424,
           9.468864123103916,
           9.290754347478405,
           9.112644571852893,
           8.934534796227384,
           8.756425020601881,
           8.57831524497637,
           8.40020546935086,
           8.222095693725358,
           8.100599519460651,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ],
          [
           30.390009397734485,
           30.2993789241578,
           30.20874845058112,
           30.118117977004434,
           30.027487503427754,
           29.936857029851073,
           29.846226556274388,
           29.755596082697704,
           29.66496560912102,
           29.574335135544338,
           29.483704661967653,
           29.39307418839097,
           29.302443714814288,
           29.211813241237607,
           29.12118276766092,
           29.030552294084238,
           28.939921820507557,
           28.849291346930876,
           28.75866087335419,
           28.668030399777507,
           28.577399926200826,
           28.486769452624145,
           28.39613897904746,
           28.305508505470776,
           28.214878031894095,
           28.12424755831741,
           28.03361708474073,
           27.942986611164045,
           27.852356137587364,
           27.76172566401068,
           27.671095190433995,
           27.580464716857314,
           27.48983424328063,
           27.399203769703945,
           27.308573296127264,
           27.21794282255058,
           27.1273123489739,
           27.036681875397214,
           26.946051401820533,
           26.85542092824385,
           26.764790454667168,
           26.674159981090483,
           26.583529507513802,
           26.492899033937114,
           26.402268560360437,
           26.311638086783752,
           26.22100761320707,
           26.130377139630383,
           26.039746666053702,
           25.94911619247702,
           25.858485718900333,
           25.767855245323656,
           25.67722477174697,
           25.58659429817029,
           25.49596382459361,
           25.40533335101692,
           25.31470287744024,
           25.224072403863552,
           25.13344193028687,
           25.042811456710194,
           24.95218098313351,
           24.861550509556825,
           24.770920035980136,
           24.68028956240346,
           24.589659088826778,
           24.499028615250094,
           24.408398141673413,
           24.317767668096728,
           24.227137194520047,
           24.136506720943363,
           24.045876247366678,
           23.955245773789997,
           23.864615300213316,
           23.77398482663663,
           23.683354353059947,
           23.592723879483263,
           23.50209340590658,
           23.411462932329897,
           23.320832458753216,
           23.23020198517653,
           23.139571511599847,
           23.048941038023166,
           22.958310564446485,
           22.8676800908698,
           22.7041501989191,
           22.52604042329358,
           22.347930647668075,
           22.169820872042568,
           21.991711096417056,
           21.813601320791555,
           21.635491545166044,
           21.457381769540532,
           21.27927199391502,
           21.10116221828951,
           20.923052442664012,
           20.744942667038497,
           20.56683289141299,
           20.388723115787474,
           20.210613340161967,
           20.032503564536466,
           19.854393788910954,
           19.676284013285443,
           19.498174237659935,
           19.320064462034424,
           19.141954686408923,
           18.96384491078341,
           18.7857351351579,
           18.6076253595324,
           18.429515583906877,
           18.251405808281376,
           18.073296032655865,
           17.895186257030357,
           17.717076481404852,
           17.538966705779334,
           17.360856930153833,
           17.18274715452832,
           17.00463737890281,
           16.82652760327731,
           16.6484178276518,
           16.470308052026287,
           16.29219827640078,
           16.114088500775264,
           15.935978725149763,
           15.757868949524257,
           15.579759173898744,
           15.401649398273243,
           15.223539622647724,
           15.04542984702222,
           14.867320071396712,
           14.6892102957712,
           14.511100520145696,
           14.33299074452018,
           14.154880968894677,
           13.976771193269167,
           13.798661417643656,
           13.620551642018153,
           13.442441866392642,
           13.264332090767132,
           13.086222315141622,
           12.908112539516111,
           12.730002763890607,
           12.551892988265099,
           12.373783212639587,
           12.195673437014085,
           12.017563661388566,
           11.839453885763064,
           11.661344110137552,
           11.483234334512042,
           11.30512455888654,
           11.127014783261023,
           10.94890500763552,
           10.770795232010009,
           10.5926854563845,
           10.414575680758997,
           10.236465905133478,
           10.058356129507976,
           9.880246353882466,
           9.702136578256955,
           9.524026802631452,
           9.345917027005942,
           9.167807251380431,
           8.989697475754921,
           8.81158770012941,
           8.633477924503907,
           8.455368148878398,
           8.277258373252886,
           8.099148597627385,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null,
           null
          ]
         ]
        },
        {
         "marker": {
          "color": "darkblue",
          "size": 3
         },
         "type": "scatter3d",
         "x": [
          0.2,
          0.3,
          0.4,
          0.5,
          0.6,
          0.7,
          0.75,
          0.8
         ],
         "y": [
          9.33333333,
          9.1010101,
          8.63636364,
          6.71212121,
          3.06666667,
          0.95959596,
          0.49090909,
          0.17171717
         ],
         "z": [
          68.01934262042212,
          71.67361810162683,
          73.72882962673707,
          72.72681395594431,
          53.5014333402316,
          26.643102863473732,
          15.700600770453711,
          7.795904064860669
         ]
        }
       ],
       "layout": {
        "autosize": true,
        "margin": {
         "b": 5,
         "l": 10,
         "r": 20,
         "t": 50
        },
        "scene": {
         "xaxis": {
          "title": {
           "text": "Mach Number"
          }
         },
         "yaxis": {
          "title": {
           "text": "Alpha [deg]"
          }
         },
         "zaxis": {
          "title": {
           "text": "L/D"
          }
         }
        },
        "template": {
         "data": {
          "bar": [
           {
            "error_x": {
             "color": "rgb(36,36,36)"
            },
            "error_y": {
             "color": "rgb(36,36,36)"
            },
            "marker": {
             "line": {
              "color": "white",
              "width": 0.5
             },
             "pattern": {
              "fillmode": "overlay",
              "size": 10,
              "solidity": 0.2
             }
            },
            "type": "bar"
           }
          ],
          "barpolar": [
           {
            "marker": {
             "line": {
              "color": "white",
              "width": 0.5
             },
             "pattern": {
              "fillmode": "overlay",
              "size": 10,
              "solidity": 0.2
             }
            },
            "type": "barpolar"
           }
          ],
          "carpet": [
           {
            "aaxis": {
             "endlinecolor": "rgb(36,36,36)",
             "gridcolor": "white",
             "linecolor": "white",
             "minorgridcolor": "white",
             "startlinecolor": "rgb(36,36,36)"
            },
            "baxis": {
             "endlinecolor": "rgb(36,36,36)",
             "gridcolor": "white",
             "linecolor": "white",
             "minorgridcolor": "white",
             "startlinecolor": "rgb(36,36,36)"
            },
            "type": "carpet"
           }
          ],
          "choropleth": [
           {
            "colorbar": {
             "outlinewidth": 1,
             "tickcolor": "rgb(36,36,36)",
             "ticks": "outside"
            },
            "type": "choropleth"
           }
          ],
          "contour": [
           {
            "colorbar": {
             "outlinewidth": 1,
             "tickcolor": "rgb(36,36,36)",
             "ticks": "outside"
            },
            "colorscale": [
             [
              0,
              "#440154"
             ],
             [
              0.1111111111111111,
              "#482878"
             ],
             [
              0.2222222222222222,
              "#3e4989"
             ],
             [
              0.3333333333333333,
              "#31688e"
             ],
             [
              0.4444444444444444,
              "#26828e"
             ],
             [
              0.5555555555555556,
              "#1f9e89"
             ],
             [
              0.6666666666666666,
              "#35b779"
             ],
             [
              0.7777777777777778,
              "#6ece58"
             ],
             [
              0.8888888888888888,
              "#b5de2b"
             ],
             [
              1,
              "#fde725"
             ]
            ],
            "type": "contour"
           }
          ],
          "contourcarpet": [
           {
            "colorbar": {
             "outlinewidth": 1,
             "tickcolor": "rgb(36,36,36)",
             "ticks": "outside"
            },
            "type": "contourcarpet"
           }
          ],
          "heatmap": [
           {
            "colorbar": {
             "outlinewidth": 1,
             "tickcolor": "rgb(36,36,36)",
             "ticks": "outside"
            },
            "colorscale": [
             [
              0,
              "#440154"
             ],
             [
              0.1111111111111111,
              "#482878"
             ],
             [
              0.2222222222222222,
              "#3e4989"
             ],
             [
              0.3333333333333333,
              "#31688e"
             ],
             [
              0.4444444444444444,
              "#26828e"
             ],
             [
              0.5555555555555556,
              "#1f9e89"
             ],
             [
              0.6666666666666666,
              "#35b779"
             ],
             [
              0.7777777777777778,
              "#6ece58"
             ],
             [
              0.8888888888888888,
              "#b5de2b"
             ],
             [
              1,
              "#fde725"
             ]
            ],
            "type": "heatmap"
           }
          ],
          "heatmapgl": [
           {
            "colorbar": {
             "outlinewidth": 1,
             "tickcolor": "rgb(36,36,36)",
             "ticks": "outside"
            },
            "colorscale": [
             [
              0,
              "#440154"
             ],
             [
              0.1111111111111111,
              "#482878"
             ],
             [
              0.2222222222222222,
              "#3e4989"
             ],
             [
              0.3333333333333333,
              "#31688e"
             ],
             [
              0.4444444444444444,
              "#26828e"
             ],
             [
              0.5555555555555556,
              "#1f9e89"
             ],
             [
              0.6666666666666666,
              "#35b779"
             ],
             [
              0.7777777777777778,
              "#6ece58"
             ],
             [
              0.8888888888888888,
              "#b5de2b"
             ],
             [
              1,
              "#fde725"
             ]
            ],
            "type": "heatmapgl"
           }
          ],
          "histogram": [
           {
            "marker": {
             "line": {
              "color": "white",
              "width": 0.6
             }
            },
            "type": "histogram"
           }
          ],
          "histogram2d": [
           {
            "colorbar": {
             "outlinewidth": 1,
             "tickcolor": "rgb(36,36,36)",
             "ticks": "outside"
            },
            "colorscale": [
             [
              0,
              "#440154"
             ],
             [
              0.1111111111111111,
              "#482878"
             ],
             [
              0.2222222222222222,
              "#3e4989"
             ],
             [
              0.3333333333333333,
              "#31688e"
             ],
             [
              0.4444444444444444,
              "#26828e"
             ],
             [
              0.5555555555555556,
              "#1f9e89"
             ],
             [
              0.6666666666666666,
              "#35b779"
             ],
             [
              0.7777777777777778,
              "#6ece58"
             ],
             [
              0.8888888888888888,
              "#b5de2b"
             ],
             [
              1,
              "#fde725"
             ]
            ],
            "type": "histogram2d"
           }
          ],
          "histogram2dcontour": [
           {
            "colorbar": {
             "outlinewidth": 1,
             "tickcolor": "rgb(36,36,36)",
             "ticks": "outside"
            },
            "colorscale": [
             [
              0,
              "#440154"
             ],
             [
              0.1111111111111111,
              "#482878"
             ],
             [
              0.2222222222222222,
              "#3e4989"
             ],
             [
              0.3333333333333333,
              "#31688e"
             ],
             [
              0.4444444444444444,
              "#26828e"
             ],
             [
              0.5555555555555556,
              "#1f9e89"
             ],
             [
              0.6666666666666666,
              "#35b779"
             ],
             [
              0.7777777777777778,
              "#6ece58"
             ],
             [
              0.8888888888888888,
              "#b5de2b"
             ],
             [
              1,
              "#fde725"
             ]
            ],
            "type": "histogram2dcontour"
           }
          ],
          "mesh3d": [
           {
            "colorbar": {
             "outlinewidth": 1,
             "tickcolor": "rgb(36,36,36)",
             "ticks": "outside"
            },
            "type": "mesh3d"
           }
          ],
          "parcoords": [
           {
            "line": {
             "colorbar": {
              "outlinewidth": 1,
              "tickcolor": "rgb(36,36,36)",
              "ticks": "outside"
             }
            },
            "type": "parcoords"
           }
          ],
          "pie": [
           {
            "automargin": true,
            "type": "pie"
           }
          ],
          "scatter": [
           {
            "marker": {
             "colorbar": {
              "outlinewidth": 1,
              "tickcolor": "rgb(36,36,36)",
              "ticks": "outside"
             }
            },
            "type": "scatter"
           }
          ],
          "scatter3d": [
           {
            "line": {
             "colorbar": {
              "outlinewidth": 1,
              "tickcolor": "rgb(36,36,36)",
              "ticks": "outside"
             }
            },
            "marker": {
             "colorbar": {
              "outlinewidth": 1,
              "tickcolor": "rgb(36,36,36)",
              "ticks": "outside"
             }
            },
            "type": "scatter3d"
           }
          ],
          "scattercarpet": [
           {
            "marker": {
             "colorbar": {
              "outlinewidth": 1,
              "tickcolor": "rgb(36,36,36)",
              "ticks": "outside"
             }
            },
            "type": "scattercarpet"
           }
          ],
          "scattergeo": [
           {
            "marker": {
             "colorbar": {
              "outlinewidth": 1,
              "tickcolor": "rgb(36,36,36)",
              "ticks": "outside"
             }
            },
            "type": "scattergeo"
           }
          ],
          "scattergl": [
           {
            "marker": {
             "colorbar": {
              "outlinewidth": 1,
              "tickcolor": "rgb(36,36,36)",
              "ticks": "outside"
             }
            },
            "type": "scattergl"
           }
          ],
          "scattermapbox": [
           {
            "marker": {
             "colorbar": {
              "outlinewidth": 1,
              "tickcolor": "rgb(36,36,36)",
              "ticks": "outside"
             }
            },
            "type": "scattermapbox"
           }
          ],
          "scatterpolar": [
           {
            "marker": {
             "colorbar": {
              "outlinewidth": 1,
              "tickcolor": "rgb(36,36,36)",
              "ticks": "outside"
             }
            },
            "type": "scatterpolar"
           }
          ],
          "scatterpolargl": [
           {
            "marker": {
             "colorbar": {
              "outlinewidth": 1,
              "tickcolor": "rgb(36,36,36)",
              "ticks": "outside"
             }
            },
            "type": "scatterpolargl"
           }
          ],
          "scatterternary": [
           {
            "marker": {
             "colorbar": {
              "outlinewidth": 1,
              "tickcolor": "rgb(36,36,36)",
              "ticks": "outside"
             }
            },
            "type": "scatterternary"
           }
          ],
          "surface": [
           {
            "colorbar": {
             "outlinewidth": 1,
             "tickcolor": "rgb(36,36,36)",
             "ticks": "outside"
            },
            "colorscale": [
             [
              0,
              "#440154"
             ],
             [
              0.1111111111111111,
              "#482878"
             ],
             [
              0.2222222222222222,
              "#3e4989"
             ],
             [
              0.3333333333333333,
              "#31688e"
             ],
             [
              0.4444444444444444,
              "#26828e"
             ],
             [
              0.5555555555555556,
              "#1f9e89"
             ],
             [
              0.6666666666666666,
              "#35b779"
             ],
             [
              0.7777777777777778,
              "#6ece58"
             ],
             [
              0.8888888888888888,
              "#b5de2b"
             ],
             [
              1,
              "#fde725"
             ]
            ],
            "type": "surface"
           }
          ],
          "table": [
           {
            "cells": {
             "fill": {
              "color": "rgb(237,237,237)"
             },
             "line": {
              "color": "white"
             }
            },
            "header": {
             "fill": {
              "color": "rgb(217,217,217)"
             },
             "line": {
              "color": "white"
             }
            },
            "type": "table"
           }
          ]
         },
         "layout": {
          "annotationdefaults": {
           "arrowhead": 0,
           "arrowwidth": 1
          },
          "autotypenumbers": "strict",
          "coloraxis": {
           "colorbar": {
            "outlinewidth": 1,
            "tickcolor": "rgb(36,36,36)",
            "ticks": "outside"
           }
          },
          "colorscale": {
           "diverging": [
            [
             0,
             "rgb(103,0,31)"
            ],
            [
             0.1,
             "rgb(178,24,43)"
            ],
            [
             0.2,
             "rgb(214,96,77)"
            ],
            [
             0.3,
             "rgb(244,165,130)"
            ],
            [
             0.4,
             "rgb(253,219,199)"
            ],
            [
             0.5,
             "rgb(247,247,247)"
            ],
            [
             0.6,
             "rgb(209,229,240)"
            ],
            [
             0.7,
             "rgb(146,197,222)"
            ],
            [
             0.8,
             "rgb(67,147,195)"
            ],
            [
             0.9,
             "rgb(33,102,172)"
            ],
            [
             1,
             "rgb(5,48,97)"
            ]
           ],
           "sequential": [
            [
             0,
             "#440154"
            ],
            [
             0.1111111111111111,
             "#482878"
            ],
            [
             0.2222222222222222,
             "#3e4989"
            ],
            [
             0.3333333333333333,
             "#31688e"
            ],
            [
             0.4444444444444444,
             "#26828e"
            ],
            [
             0.5555555555555556,
             "#1f9e89"
            ],
            [
             0.6666666666666666,
             "#35b779"
            ],
            [
             0.7777777777777778,
             "#6ece58"
            ],
            [
             0.8888888888888888,
             "#b5de2b"
            ],
            [
             1,
             "#fde725"
            ]
           ],
           "sequentialminus": [
            [
             0,
             "#440154"
            ],
            [
             0.1111111111111111,
             "#482878"
            ],
            [
             0.2222222222222222,
             "#3e4989"
            ],
            [
             0.3333333333333333,
             "#31688e"
            ],
            [
             0.4444444444444444,
             "#26828e"
            ],
            [
             0.5555555555555556,
             "#1f9e89"
            ],
            [
             0.6666666666666666,
             "#35b779"
            ],
            [
             0.7777777777777778,
             "#6ece58"
            ],
            [
             0.8888888888888888,
             "#b5de2b"
            ],
            [
             1,
             "#fde725"
            ]
           ]
          },
          "colorway": [
           "#1F77B4",
           "#FF7F0E",
           "#2CA02C",
           "#D62728",
           "#9467BD",
           "#8C564B",
           "#E377C2",
           "#7F7F7F",
           "#BCBD22",
           "#17BECF"
          ],
          "font": {
           "color": "rgb(36,36,36)"
          },
          "geo": {
           "bgcolor": "white",
           "lakecolor": "white",
           "landcolor": "white",
           "showlakes": true,
           "showland": true,
           "subunitcolor": "white"
          },
          "hoverlabel": {
           "align": "left"
          },
          "hovermode": "closest",
          "mapbox": {
           "style": "light"
          },
          "paper_bgcolor": "white",
          "plot_bgcolor": "white",
          "polar": {
           "angularaxis": {
            "gridcolor": "rgb(232,232,232)",
            "linecolor": "rgb(36,36,36)",
            "showgrid": false,
            "showline": true,
            "ticks": "outside"
           },
           "bgcolor": "white",
           "radialaxis": {
            "gridcolor": "rgb(232,232,232)",
            "linecolor": "rgb(36,36,36)",
            "showgrid": false,
            "showline": true,
            "ticks": "outside"
           }
          },
          "scene": {
           "xaxis": {
            "backgroundcolor": "white",
            "gridcolor": "rgb(232,232,232)",
            "gridwidth": 2,
            "linecolor": "rgb(36,36,36)",
            "showbackground": true,
            "showgrid": false,
            "showline": true,
            "ticks": "outside",
            "zeroline": false,
            "zerolinecolor": "rgb(36,36,36)"
           },
           "yaxis": {
            "backgroundcolor": "white",
            "gridcolor": "rgb(232,232,232)",
            "gridwidth": 2,
            "linecolor": "rgb(36,36,36)",
            "showbackground": true,
            "showgrid": false,
            "showline": true,
            "ticks": "outside",
            "zeroline": false,
            "zerolinecolor": "rgb(36,36,36)"
           },
           "zaxis": {
            "backgroundcolor": "white",
            "gridcolor": "rgb(232,232,232)",
            "gridwidth": 2,
            "linecolor": "rgb(36,36,36)",
            "showbackground": true,
            "showgrid": false,
            "showline": true,
            "ticks": "outside",
            "zeroline": false,
            "zerolinecolor": "rgb(36,36,36)"
           }
          },
          "shapedefaults": {
           "fillcolor": "black",
           "line": {
            "width": 0
           },
           "opacity": 0.3
          },
          "ternary": {
           "aaxis": {
            "gridcolor": "rgb(232,232,232)",
            "linecolor": "rgb(36,36,36)",
            "showgrid": false,
            "showline": true,
            "ticks": "outside"
           },
           "baxis": {
            "gridcolor": "rgb(232,232,232)",
            "linecolor": "rgb(36,36,36)",
            "showgrid": false,
            "showline": true,
            "ticks": "outside"
           },
           "bgcolor": "white",
           "caxis": {
            "gridcolor": "rgb(232,232,232)",
            "linecolor": "rgb(36,36,36)",
            "showgrid": false,
            "showline": true,
            "ticks": "outside"
           }
          },
          "title": {
           "x": 0.05
          },
          "xaxis": {
           "automargin": true,
           "gridcolor": "rgb(232,232,232)",
           "linecolor": "rgb(36,36,36)",
           "showgrid": false,
           "showline": true,
           "ticks": "outside",
           "title": {
            "standoff": 15
           },
           "zeroline": false,
           "zerolinecolor": "rgb(36,36,36)"
          },
          "yaxis": {
           "automargin": true,
           "gridcolor": "rgb(232,232,232)",
           "linecolor": "rgb(36,36,36)",
           "showgrid": false,
           "showline": true,
           "ticks": "outside",
           "title": {
            "standoff": 15
           },
           "zeroline": false,
           "zerolinecolor": "rgb(36,36,36)"
          }
         }
        },
        "title": {
         "text": "NACA23012"
        },
        "width": 700
       }
      },
      "text/html": [
       "<div>                            <div id=\"c51ae7e6-0857-465a-9c98-1ba2bd53fd0f\" class=\"plotly-graph-div\" style=\"height:525px; width:700px;\"></div>            <script type=\"text/javascript\">                require([\"plotly\"], function(Plotly) {                    window.PLOTLYENV=window.PLOTLYENV || {};                                    if (document.getElementById(\"c51ae7e6-0857-465a-9c98-1ba2bd53fd0f\")) {                    Plotly.newPlot(                        \"c51ae7e6-0857-465a-9c98-1ba2bd53fd0f\",                        [{\"colorscale\":[[0.0,\"#440154\"],[0.1111111111111111,\"#482878\"],[0.2222222222222222,\"#3e4989\"],[0.3333333333333333,\"#31688e\"],[0.4444444444444444,\"#26828e\"],[0.5555555555555556,\"#1f9e89\"],[0.6666666666666666,\"#35b779\"],[0.7777777777777778,\"#6ece58\"],[0.8888888888888888,\"#b5de2b\"],[1.0,\"#fde725\"]],\"opacity\":0.8,\"type\":\"surface\",\"x\":[[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8],[0.2,0.20120240480961926,0.20240480961923848,0.20360721442885774,0.20480961923847696,0.2060120240480962,0.20721442885771543,0.20841683366733468,0.2096192384769539,0.21082164328657316,0.2120240480961924,0.21322645290581163,0.21442885771543088,0.2156312625250501,0.21683366733466936,0.2180360721442886,0.21923847695390783,0.22044088176352705,0.2216432865731463,0.22284569138276555,0.22404809619238478,0.22525050100200403,0.22645290581162325,0.2276553106212425,0.22885771543086175,0.23006012024048098,0.2312625250501002,0.23246492985971945,0.2336673346693387,0.23486973947895792,0.23607214428857717,0.2372745490981964,0.23847695390781565,0.2396793587174349,0.24088176352705412,0.24208416833667337,0.2432865731462926,0.24448897795591185,0.2456913827655311,0.24689378757515032,0.24809619238476954,0.2492985971943888,0.25050100200400804,0.2517034068136273,0.2529058116232465,0.25410821643286574,0.255310621242485,0.25651302605210424,0.25771543086172344,0.2589178356713427,0.26012024048096194,0.2613226452905812,0.26252505010020044,0.26372745490981964,0.2649298597194389,0.26613226452905814,0.2673346693386774,0.26853707414829664,0.26973947895791583,0.2709418837675351,0.27214428857715434,0.2733466933867736,0.27454909819639284,0.27575150300601203,0.2769539078156313,0.27815631262525053,0.27935871743486973,0.280561122244489,0.28176352705410823,0.2829659318637275,0.28416833667334673,0.28537074148296593,0.2865731462925852,0.28777555110220443,0.2889779559118237,0.29018036072144293,0.2913827655310621,0.2925851703406814,0.29378757515030063,0.2949899799599199,0.29619238476953913,0.2973947895791583,0.2985971943887776,0.2997995991983968,0.301002004008016,0.30220440881763533,0.3034068136272545,0.3046092184368738,0.305811623246493,0.3070140280561122,0.30821643286573147,0.3094188376753507,0.31062124248497,0.3118236472945892,0.3130260521042084,0.31422845691382767,0.3154308617234469,0.31663326653306617,0.3178356713426854,0.3190380761523046,0.32024048096192387,0.3214428857715431,0.32264529058116237,0.3238476953907816,0.3250501002004008,0.32625250501002007,0.3274549098196393,0.3286573146292585,0.3298597194388778,0.331062124248497,0.33226452905811626,0.3334669338677355,0.3346693386773547,0.335871743486974,0.3370741482965932,0.33827655310621246,0.3394789579158317,0.3406813627254509,0.34188376753507016,0.3430861723446894,0.34428857715430866,0.3454909819639279,0.3466933867735471,0.34789579158316636,0.3490981963927856,0.3503006012024048,0.3515030060120241,0.3527054108216433,0.35390781563126256,0.3551102204408818,0.356312625250501,0.3575150300601203,0.3587174348697395,0.35991983967935876,0.361122244488978,0.3623246492985972,0.36352705410821645,0.3647294589178357,0.36593186372745495,0.3671342685370742,0.3683366733466934,0.36953907815631265,0.3707414829659319,0.3719438877755511,0.3731462925851704,0.3743486973947896,0.37555110220440885,0.3767535070140281,0.3779559118236473,0.3791583166332666,0.3803607214428858,0.38156312625250505,0.3827655310621243,0.3839679358717435,0.3851703406813628,0.386372745490982,0.38757515030060125,0.3887775551102205,0.3899799599198397,0.39118236472945894,0.3923847695390782,0.39358717434869744,0.3947895791583167,0.3959919839679359,0.39719438877755514,0.3983967935871744,0.3995991983967936,0.4008016032064129,0.4020040080160321,0.40320641282565134,0.4044088176352706,0.4056112224448898,0.4068136272545091,0.4080160320641283,0.40921843687374754,0.4104208416833668,0.411623246492986,0.4128256513026053,0.4140280561122245,0.41523046092184374,0.416432865731463,0.4176352705410822,0.41883767535070143,0.4200400801603207,0.42124248496993993,0.4224448897795592,0.4236472945891784,0.42484969939879763,0.4260521042084169,0.4272545090180361,0.4284569138276554,0.4296593186372746,0.43086172344689383,0.4320641282565131,0.4332665330661323,0.4344689378757516,0.4356713426853708,0.43687374749499003,0.4380761523046093,0.4392785571142285,0.4404809619238477,0.441683366733467,0.4428857715430862,0.4440881763527055,0.4452905811623247,0.4464929859719439,0.4476953907815632,0.44889779559118237,0.4501002004008016,0.45130260521042087,0.4525050100200401,0.4537074148296594,0.4549098196392786,0.4561122244488978,0.45731462925851707,0.4585170340681363,0.45971943887775557,0.4609218436873748,0.462124248496994,0.46332665330661327,0.4645290581162325,0.46573146292585177,0.46693386773547096,0.4681362725450902,0.46933867735470947,0.4705410821643287,0.47174348697394797,0.47294589178356716,0.4741482965931864,0.47535070140280566,0.4765531062124249,0.4777555110220441,0.47895791583166336,0.4801603206412826,0.48136272545090186,0.4825651302605211,0.4837675350701403,0.48496993987975956,0.4861723446893788,0.48737474949899806,0.4885771543086173,0.4897795591182365,0.49098196392785576,0.492184368737475,0.49338677354709426,0.49458917835671345,0.4957915831663327,0.49699398797595196,0.4981963927855712,0.49939879759519046,0.5006012024048097,0.501803607214429,0.5030060120240482,0.5042084168336673,0.5054108216432867,0.5066132264529059,0.507815631262525,0.5090180360721444,0.5102204408817637,0.5114228456913827,0.512625250501002,0.5138276553106214,0.5150300601202406,0.5162324649298597,0.517434869739479,0.5186372745490982,0.5198396793587174,0.5210420841683367,0.522244488977956,0.5234468937875751,0.5246492985971944,0.5258517034068138,0.5270541082164328,0.5282565130260521,0.5294589178356714,0.5306613226452906,0.5318637274549098,0.5330661322645291,0.5342685370741483,0.5354709418837675,0.5366733466933868,0.5378757515030061,0.5390781563126252,0.5402805611222445,0.5414829659318638,0.542685370741483,0.5438877755511022,0.5450901803607215,0.5462925851703407,0.5474949899799599,0.5486973947895792,0.5498997995991984,0.5511022044088176,0.5523046092184369,0.5535070140280562,0.5547094188376753,0.5559118236472946,0.5571142284569139,0.5583166332665331,0.5595190380761523,0.5607214428857716,0.5619238476953908,0.56312625250501,0.5643286573146293,0.5655310621242486,0.5667334669338677,0.567935871743487,0.5691382765531063,0.5703406813627255,0.5715430861723447,0.572745490981964,0.5739478957915832,0.5751503006012024,0.5763527054108217,0.5775551102204409,0.5787575150300601,0.5799599198396794,0.5811623246492987,0.5823647294589178,0.5835671342685371,0.5847695390781564,0.5859719438877756,0.5871743486973948,0.5883767535070141,0.5895791583166333,0.5907815631262525,0.5919839679358718,0.593186372745491,0.5943887775551102,0.5955911823647295,0.5967935871743488,0.597995991983968,0.5991983967935872,0.6004008016032065,0.6016032064128257,0.6028056112224449,0.6040080160320642,0.6052104208416834,0.6064128256513026,0.6076152304609219,0.6088176352705412,0.6100200400801603,0.6112224448897796,0.6124248496993989,0.6136272545090181,0.6148296593186373,0.6160320641282566,0.6172344689378758,0.618436873747495,0.6196392785571143,0.6208416833667335,0.6220440881763527,0.623246492985972,0.6244488977955913,0.6256513026052105,0.6268537074148297,0.628056112224449,0.6292585170340682,0.6304609218436874,0.6316633266533067,0.6328657314629259,0.6340681362725451,0.6352705410821644,0.6364729458917837,0.6376753507014028,0.6388777555110221,0.6400801603206414,0.6412825651302606,0.6424849699398798,0.6436873747494991,0.6448897795591183,0.6460921843687375,0.6472945891783568,0.648496993987976,0.6496993987975952,0.6509018036072145,0.6521042084168338,0.653306613226453,0.6545090180360722,0.6557114228456915,0.6569138276553107,0.6581162324649299,0.6593186372745492,0.6605210420841684,0.6617234468937876,0.6629258517034069,0.6641282565130262,0.6653306613226453,0.6665330661322646,0.6677354709418839,0.6689378757515031,0.6701402805611223,0.6713426853707416,0.6725450901803608,0.67374749498998,0.6749498997995993,0.6761523046092185,0.6773547094188377,0.678557114228457,0.6797595190380763,0.6809619238476954,0.6821643286573147,0.683366733466934,0.6845691382765532,0.6857715430861724,0.6869739478957917,0.6881763527054109,0.6893787575150301,0.6905811623246494,0.6917835671342687,0.6929859719438878,0.6941883767535071,0.6953907815631264,0.6965931863727456,0.6977955911823648,0.6989979959919841,0.7002004008016032,0.7014028056112225,0.7026052104208418,0.7038076152304611,0.7050100200400802,0.7062124248496995,0.7074148296593188,0.7086172344689379,0.7098196392785572,0.7110220440881765,0.7122244488977956,0.7134268537074149,0.7146292585170342,0.7158316633266535,0.7170340681362726,0.7182364729458919,0.7194388777555112,0.7206412825651303,0.7218436873747496,0.7230460921843689,0.724248496993988,0.7254509018036073,0.7266533066132266,0.7278557114228457,0.729058116232465,0.7302605210420843,0.7314629258517036,0.7326653306613227,0.733867735470942,0.7350701402805613,0.7362725450901804,0.7374749498997997,0.738677354709419,0.7398797595190381,0.7410821643286574,0.7422845691382767,0.743486973947896,0.7446893787575151,0.7458917835671344,0.7470941883767537,0.7482965931863728,0.7494989979959921,0.7507014028056114,0.7519038076152305,0.7531062124248498,0.7543086172344691,0.7555110220440882,0.7567134268537075,0.7579158316633268,0.7591182364729461,0.7603206412825652,0.7615230460921845,0.7627254509018038,0.7639278557114229,0.7651302605210422,0.7663326653306615,0.7675350701402806,0.7687374749498999,0.7699398797595192,0.7711422845691385,0.7723446893787576,0.7735470941883769,0.7747494989979962,0.7759519038076153,0.7771543086172346,0.7783567134268539,0.779559118236473,0.7807615230460923,0.7819639278557116,0.7831663326653306,0.78436873747495,0.7855711422845693,0.7867735470941886,0.7879759519038076,0.789178356713427,0.7903807615230463,0.7915831663326653,0.7927855711422847,0.793987975951904,0.795190380761523,0.7963927855711423,0.7975951903807617,0.798797595190381,0.8]],\"y\":[[-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0,-6.0],[-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262,-5.953907815631262],[-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525,-5.907815631262525],[-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787,-5.861723446893787],[-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505,-5.81563126252505],[-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125,-5.7695390781563125],[-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755,-5.7234468937875755],[-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838,-5.677354709418838],[-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501,-5.6312625250501],[-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363,-5.585170340681363],[-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625,-5.539078156312625],[-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888,-5.492985971943888],[-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515,-5.44689378757515],[-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413,-5.400801603206413],[-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675,-5.354709418837675],[-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938,-5.308617234468938],[-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006,-5.2625250501002006],[-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463,-5.216432865731463],[-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726,-5.170340681362726],[-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988,-5.124248496993988],[-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251,-5.078156312625251],[-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513,-5.032064128256513],[-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776,-4.985971943887776],[-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038,-4.939879759519038],[-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503,-4.8937875751503],[-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563,-4.847695390781563],[-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826,-4.801603206412826],[-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088,-4.755511022044088],[-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351,-4.709418837675351],[-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614,-4.663326653306614],[-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876,-4.617234468937876],[-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138,-4.571142284569138],[-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401,-4.525050100200401],[-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663,-4.478957915831663],[-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925,-4.432865731462925],[-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188,-4.386773547094188],[-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515,-4.3406813627254515],[-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714,-4.294589178356714],[-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976,-4.248496993987976],[-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239,-4.202404809619239],[-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501,-4.156312625250501],[-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763,-4.110220440881763],[-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026,-4.064128256513026],[-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289,-4.018036072144289],[-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513,-3.9719438877755513],[-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814,-3.925851703406814],[-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765,-3.8797595190380765],[-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386,-3.8336673346693386],[-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601,-3.787575150300601],[-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864,-3.741482965931864],[-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264,-3.6953907815631264],[-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389,-3.649298597194389],[-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516,-3.6032064128256516],[-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914,-3.557114228456914],[-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763,-3.5110220440881763],[-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439,-3.464929859719439],[-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015,-3.4188376753507015],[-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964,-3.372745490981964],[-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267,-3.3266533066132267],[-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893,-3.2805611222444893],[-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752,-3.234468937875752],[-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014,-3.188376753507014],[-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766,-3.1422845691382766],[-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539,-3.096192384769539],[-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018,-3.0501002004008018],[-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644,-3.0040080160320644],[-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327,-2.957915831663327],[-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895,-2.9118236472945895],[-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517,-2.8657314629258517],[-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143,-2.8196392785571143],[-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377,-2.773547094188377],[-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395,-2.7274549098196395],[-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902,-2.681362725450902],[-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646,-2.6352705410821646],[-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427,-2.589178356713427],[-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894,-2.5430861723446894],[-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952,-2.496993987975952],[-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145,-2.4509018036072145],[-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477,-2.404809619238477],[-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397,-2.3587174348697397],[-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023,-2.3126252505010023],[-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265,-2.266533066132265],[-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527,-2.220440881763527],[-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896,-2.1743486973947896],[-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522,-2.1282565130260522],[-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315,-2.082164328657315],[-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774,-2.0360721442885774],[-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396,-1.9899799599198396],[-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026,-1.9438877755511026],[-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647,-1.8977955911823647],[-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278,-1.8517034068136278],[-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489,-1.80561122244489],[-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153,-1.759519038076153],[-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415,-1.713426853707415],[-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772,-1.6673346693386772],[-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403,-1.6212424849699403],[-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024,-1.5751503006012024],[-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655,-1.5290581162324655],[-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276,-1.4829659318637276],[-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906,-1.4368737474949906],[-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528,-1.3907815631262528],[-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515,-1.344689378757515],[-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778,-1.298597194388778],[-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004,-1.25250501002004],[-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031,-1.2064128256513031],[-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653,-1.1603206412825653],[-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283,-1.1142284569138283],[-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905,-1.0681362725450905],[-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526,-1.0220440881763526],[-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157,-0.9759519038076157],[-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778,-0.9298597194388778],[-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408,-0.8837675350701408],[-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403,-0.837675350701403],[-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666,-0.791583166332666],[-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282,-0.7454909819639282],[-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903,-0.6993987975951903],[-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533,-0.6533066132264533],[-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155,-0.6072144288577155],[-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785,-0.5611222444889785],[-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407,-0.5150300601202407],[-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037,-0.4689378757515037],[-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584,-0.42284569138276584],[-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028,-0.376753507014028],[-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291,-0.330661322645291],[-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317,-0.28456913827655317],[-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162,-0.2384769539078162],[-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835,-0.19238476953907835],[-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138,-0.14629258517034138],[-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353,-0.10020040080160353],[-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675,-0.054108216432865675],[-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709,-0.008016032064128709],[0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145,0.038076152304609145],[0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611,0.08416833667334611],[0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397,0.13026052104208397],[0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093,0.17635270541082093],[0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879,0.22244488977955879],[0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664,0.26853707414829664],[0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336,0.3146292585170336],[0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146,0.36072144288577146],[0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084,0.4068136272545084],[0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463,0.4529058116232463],[0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325,0.49899799599198325],[0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211,0.5450901803607211],[0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459,0.591182364729459],[0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959,0.6372745490981959],[0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338,0.6833667334669338],[0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707,0.7294589178356707],[0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086,0.7755511022044086],[0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456,0.8216432865731456],[0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834,0.8677354709418834],[0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213,0.9138276553106213],[0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582,0.9599198396793582],[1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096,1.006012024048096],[1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833,1.052104208416833],[1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571,1.098196392785571],[1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079,1.1442885771543079],[1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457,1.1903807615230457],[1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836,1.2364729458917836],[1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205,1.2825651302605205],[1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584,1.3286573146292584],[1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954,1.3747494989979954],[1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332,1.4208416833667332],[1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702,1.4669338677354702],[1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208,1.513026052104208],[1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946,1.559118236472946],[1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829,1.6052104208416829],[1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207,1.6513026052104207],[1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577,1.6973947895791577],[1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955,1.7434869739478955],[1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325,1.7895791583166325],[1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704,1.8356713426853704],[1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082,1.8817635270541082],[1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452,1.9278557114228452],[1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583,1.973947895791583],[2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321,2.020040080160321],[2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058,2.066132264529058],[2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795,2.112224448897795],[2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532,2.158316633266532],[2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705,2.2044088176352705],[2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075,2.2505010020040075],[2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445,2.2965931863727445],[2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483,2.342685370741483],[2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022,2.38877755511022],[2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957,2.434869739478957],[2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694,2.480961923847694],[2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433,2.527054108216433],[2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517,2.57314629258517],[2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068,2.6192384769539068],[2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455,2.6653306613226455],[2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825,2.7114228456913825],[2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194,2.7575150300601194],[2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564,2.8036072144288564],[2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595,2.849699398797595],[2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332,2.895791583166332],[2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069,2.941883767535069],[2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808,2.987975951903808],[3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545,3.034068136272545],[3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818,3.0801603206412818],[3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187,3.1262525050100187],[3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575,3.1723446893787575],[3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944,3.2184368737474944],[3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314,3.2645290581162314],[3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497,3.31062124248497],[3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707,3.356713426853707],[3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444,3.402805611222444],[3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181,3.448897795591181],[3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992,3.49498997995992],[3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567,3.5410821643286567],[3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937,3.5871743486973937],[3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325,3.6332665330661325],[3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694,3.6793587174348694],[3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064,3.7254509018036064],[3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434,3.7715430861723434],[3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082,3.817635270541082],[3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819,3.863727454909819],[3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556,3.909819639278556],[3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948,3.9559118236472948],[4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032,4.002004008016032],[4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769,4.048096192384769],[4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506,4.094188376753506],[4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244,4.140280561122244],[4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981,4.186372745490981],[4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718,4.232464929859718],[4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457,4.278557114228457],[4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194,4.324649298597194],[4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931,4.370741482965931],[4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668,4.416833667334668],[4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407,4.462925851703407],[4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144,4.509018036072144],[4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881,4.555110220440881],[4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619,4.601202404809619],[4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356,4.647294589178356],[4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093,4.693386773547093],[4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583,4.73947895791583],[4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569,4.785571142284569],[4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306,4.831663326653306],[4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043,4.877755511022043],[4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782,4.923847695390782],[4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519,4.969939879759519],[5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256,5.016032064128256],[5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993,5.062124248496993],[5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731,5.108216432865731],[5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468,5.154308617234468],[5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205,5.200400801603205],[5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944,5.246492985971944],[5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681,5.292585170340681],[5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418,5.338677354709418],[5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155,5.384769539078155],[5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894,5.430861723446894],[5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631,5.476953907815631],[5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368,5.523046092184368],[5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106,5.569138276553106],[5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843,5.615230460921843],[5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058,5.66132264529058],[5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317,5.707414829659317],[5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056,5.753507014028056],[5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793,5.799599198396793],[5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553,5.84569138276553],[5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269,5.891783567134269],[5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006,5.937875751503006],[5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743,5.983967935871743],[6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795,6.0300601202404795],[6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218,6.076152304609218],[6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955,6.122244488977955],[6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692,6.168336673346692],[6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431,6.214428857715431],[6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168,6.260521042084168],[6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905,6.306613226452905],[6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642,6.352705410821642],[6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381,6.398797595190381],[6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118,6.444889779559118],[6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545,6.4909819639278545],[6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593,6.537074148296593],[6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533,6.58316633266533],[6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067,6.629258517034067],[6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804,6.675350701402804],[6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543,6.721442885771543],[6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028,6.76753507014028],[6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017,6.813627254509017],[6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756,6.859719438877756],[6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493,6.905811623246493],[6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295,6.9519038076152295],[6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665,6.9979959919839665],[7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705,7.044088176352705],[7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442,7.090180360721442],[7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179,7.136272545090179],[7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918,7.182364729458918],[7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655,7.228456913827655],[7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392,7.274549098196392],[7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129,7.320641282565129],[7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675,7.3667334669338675],[7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045,7.4128256513026045],[7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415,7.4589178356713415],[7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008,7.50501002004008],[7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817,7.551102204408817],[7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554,7.597194388777554],[7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291,7.643286573146291],[7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503,7.68937875751503],[7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767,7.735470941883767],[7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504,7.781563126252504],[7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425,7.8276553106212425],[7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795,7.8737474949899795],[7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165,7.9198396793587165],[7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453,7.965931863727453],[8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192,8.012024048096192],[8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493,8.05811623246493],[8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666,8.104208416833666],[8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405,8.150300601202405],[8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142,8.196392785571142],[8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879,8.242484969939879],[8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616,8.288577154308616],[8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354,8.334669338677354],[8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091,8.380761523046091],[8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828,8.426853707414828],[8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567,8.472945891783567],[8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304,8.519038076152304],[8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041,8.565130260521041],[8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778,8.611222444889778],[8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517,8.657314629258517],[8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254,8.703406813627254],[8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599,8.74949899799599],[8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473,8.79559118236473],[8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466,8.841683366733466],[8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203,8.887775551102203],[8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094,8.93386773547094],[8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968,8.97995991983968],[9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416,9.026052104208416],[9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153,9.072144288577153],[9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892,9.118236472945892],[9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629,9.164328657314629],[9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366,9.210420841683366],[9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103,9.256513026052103],[9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841,9.302605210420841],[9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578,9.348697394789578],[9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315,9.394789579158315],[9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054,9.440881763527054],[9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791,9.486973947895791],[9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528,9.533066132264528],[9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265,9.579158316633265],[9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004,9.625250501002004],[9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074,9.67134268537074],[9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478,9.717434869739478],[9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216,9.763527054108216],[9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953,9.809619238476953],[9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569,9.85571142284569],[9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427,9.901803607214427],[9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166,9.947895791583166],[9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903,9.993987975951903],[10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642,10.040080160320642],[10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377,10.086172344689377],[10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116,10.132264529058116],[10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854,10.178356713426854],[10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559,10.22444889779559],[10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328,10.270541082164328],[10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064,10.316633266533064],[10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802,10.362725450901802],[10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541,10.408817635270541],[10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276,10.454909819639276],[10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015,10.501002004008015],[10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754,10.547094188376754],[10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489,10.593186372745489],[10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228,10.639278557114228],[10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966,10.685370741482966],[10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702,10.731462925851702],[10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044,10.77755511022044],[10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179,10.823647294589179],[10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914,10.869739478957914],[10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653,10.915831663326653],[10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388,10.961923847695388],[11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127,11.008016032064127],[11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866,11.054108216432866],[11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016,11.1002004008016],[11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034,11.14629258517034],[11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078,11.192384769539078],[11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814,11.238476953907814],[11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552,11.284569138276552],[11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291,11.330661322645291],[11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026,11.376753507014026],[11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765,11.422845691382765],[11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504,11.468937875751504],[11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239,11.515030060120239],[11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978,11.561122244488978],[11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713,11.607214428857713],[11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452,11.653306613226452],[11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519,11.69939879759519],[11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925,11.745490981963925],[11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664,11.791583166332664],[11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403,11.837675350701403],[11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138,11.883767535070138],[11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877,11.929859719438877],[11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616,11.975951903807616],[12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635,12.02204408817635],[12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509,12.06813627254509],[12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828,12.114228456913828],[12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564,12.160320641282564],[12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302,12.206412825651302],[12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037,12.252505010020037],[12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776,12.298597194388776],[12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515,12.344689378757515],[12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625,12.39078156312625],[12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989,12.436873747494989],[12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728,12.482965931863728],[12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463,12.529058116232463],[12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202,12.575150300601202],[12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994,12.62124248496994],[12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675,12.667334669338675],[12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414,12.713426853707414],[12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153,12.759519038076153],[12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888,12.805611222444888],[12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627,12.851703406813627],[12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362,12.897795591182362],[12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511,12.9438877755511],[12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984,12.98997995991984],[13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575,13.036072144288575],[13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313,13.082164328657313],[13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052,13.128256513026052],[13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787,13.174348697394787],[13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526,13.220440881763526],[13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265,13.266533066132265],[13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501,13.312625250501],[13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739,13.358717434869739],[13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478,13.404809619238478],[13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213,13.450901803607213],[13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952,13.496993987975952],[13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687,13.543086172344687],[13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425,13.589178356713425],[13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164,13.635270541082164],[13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509,13.6813627254509],[13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638,13.727454909819638],[13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377,13.773547094188377],[13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112,13.819639278557112],[13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585,13.86573146292585],[13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459,13.91182364729459],[13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325,13.957915831663325],[14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063,14.004008016032063],[14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802,14.050100200400802],[14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537,14.096192384769537],[14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276,14.142284569138276],[14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011,14.188376753507011],[14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575,14.23446893787575],[14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489,14.280561122244489],[14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224,14.326653306613224],[14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963,14.372745490981963],[14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701,14.418837675350701],[14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437,14.464929859719437],[14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175,14.511022044088175],[14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914,14.557114228456914],[14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565,14.60320641282565],[14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388,14.649298597194388],[14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127,14.695390781563127],[14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862,14.741482965931862],[14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006,14.7875751503006],[14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336,14.833667334669336],[14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075,14.879759519038075],[14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813,14.925851703406813],[14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549,14.971943887775549],[15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287,15.018036072144287],[15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026,15.064128256513026],[15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761,15.110220440881761],[15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505,15.1563126252505],[15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239,15.202404809619239],[15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974,15.248496993987974],[15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713,15.294589178356713],[15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451,15.340681362725451],[15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187,15.386773547094187],[15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925,15.432865731462925],[15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166,15.47895791583166],[15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004,15.5250501002004],[15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138,15.571142284569138],[15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873,15.617234468937873],[15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612,15.663326653306612],[15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535,15.70941883767535],[15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086,15.755511022044086],[15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825,15.801603206412825],[15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563,15.847695390781563],[15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299,15.893787575150299],[15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037,15.939879759519037],[15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776,15.985971943887776],[16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651,16.03206412825651],[16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525,16.07815631262525],[16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985,16.124248496993985],[16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724,16.170340681362724],[16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463,16.216432865731463],[16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198,16.262525050100198],[16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937,16.308617234468937],[16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675,16.354709418837675],[16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641,16.40080160320641],[16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515,16.44689378757515],[16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888,16.492985971943888],[16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623,16.539078156312623],[16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362,16.585170340681362],[16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501,16.6312625250501],[16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836,16.677354709418836],[16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575,16.723446893787575],[16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631,16.76953907815631],[16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505,16.81563126252505],[16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787,16.861723446893787],[16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523,16.907815631262523],[16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126,16.95390781563126],[17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0,17.0]],\"z\":[[-43.44938758351598,-43.49470954332585,-43.54003150313571,-43.58535346294557,-43.63067542275544,-43.6759973825653,-43.72131934237516,-43.76664130218503,-43.8119632619949,-43.85728522180476,-43.90260718161463,-43.94792914142449,-43.99325110123436,-44.03857306104422,-44.08389502085408,-44.12921698066395,-44.17453894047381,-44.21986090028368,-44.265182860093546,-44.3105048199034,-44.35582677971327,-44.40114873952313,-44.44647069933299,-44.49179265914287,-44.53711461895273,-44.5824365787626,-44.62775853857246,-44.67308049838232,-44.71840245819219,-44.76372441800205,-44.80904637781192,-44.85436833762178,-44.89969029743164,-44.945012257241515,-44.99033421705137,-45.03565617686124,-45.080978136671106,-45.12630009648096,-45.171622056290836,-45.2169440161007,-45.262265975910566,-45.30758793572042,-45.35290989553029,-45.39823185534016,-45.44355381515002,-45.48887577495988,-45.53419773476975,-45.579519694579616,-45.62484165438948,-45.67016361419934,-45.71548557400921,-45.76080753381907,-45.80612949362894,-45.8514514534388,-45.89677341324867,-45.94209537305853,-45.98741733286839,-46.03273929267826,-46.07806125248812,-46.12338321229799,-46.16870517210785,-46.21402713191772,-46.25934909172758,-46.30467105153744,-46.34999301134731,-46.39531497115718,-46.44063693096704,-46.48595889077691,-46.53128085058677,-46.57660281039663,-46.6219247702065,-46.66724673001636,-46.71256868982623,-46.75789064963609,-46.80321260944596,-46.84853456925582,-46.89385652906569,-46.93917848887555,-46.98450044868542,-47.02982240849528,-47.075144368305146,-47.12046632811501,-47.16578828792487,-47.21111024773474,-47.25051121715973,-47.28872798850775,-47.32694475985577,-47.365161531203796,-47.403378302551815,-47.44159507389984,-47.47981184524786,-47.51802861659588,-47.5562453879439,-47.59446215929192,-47.63267893063994,-47.67089570198796,-47.709112473335985,-47.74732924468401,-47.78554601603203,-47.82376278738005,-47.861979558728066,-47.900196330076085,-47.93841310142411,-47.976629872772136,-48.014846644120155,-48.05306341546817,-48.09128018681619,-48.12949695816421,-48.16771372951224,-48.20593050086026,-48.24414727220828,-48.2823640435563,-48.32058081490432,-48.358797586252344,-48.39701435760036,-48.43523112894839,-48.47344790029641,-48.511664671644425,-48.54988144299245,-48.58809821434047,-48.626314985688495,-48.664531757036514,-48.70274852838453,-48.74096529973255,-48.77918207108057,-48.8173988424286,-48.85561561377662,-48.89383238512464,-48.93204915647266,-48.970265927820684,-49.0084826991687,-49.04669947051673,-49.08491624186475,-49.123133013212765,-49.161349784560784,-49.1995665559088,-49.23778332725682,-49.276000098604854,-49.31421686995287,-49.35243364130089,-49.39065041264891,-49.428867183996935,-49.467083955344954,-49.50530072669297,-49.543517498041,-49.58173426938902,-49.61995104073704,-49.65816781208506,-49.69638458343308,-49.734601354781105,-49.772818126129124,-49.81103489747715,-49.84925166882516,-49.88746844017318,-49.925685211521206,-49.96390198286923,-50.00211875421725,-50.04033552556527,-50.07855229691329,-50.11676906826131,-50.15498583960933,-50.19320261095735,-50.23141938230538,-50.2696361536534,-50.30785292500142,-50.34606969634944,-50.38428646769746,-50.266805550959596,-50.071475790178816,-49.87614602939802,-49.68081626861723,-49.48548650783644,-49.29015674705564,-49.09482698627485,-48.89949722549405,-48.704167464713265,-48.50883770393248,-48.31350794315168,-48.11817818237089,-47.922848421590096,-47.7275186608093,-47.532188900028515,-47.33685913924772,-47.14152937846693,-46.94619961768613,-46.75086985690534,-46.55554009612456,-46.36021033534376,-46.16488057456297,-45.969550813782185,-45.77422105300138,-45.57889129222059,-45.383561531439796,-45.188231770659,-44.992902009878215,-44.79757224909741,-44.602242488316634,-44.40691272753584,-44.211582966755046,-44.01625320597426,-43.82092344519346,-43.62559368441267,-43.43026392363187,-43.234934162851076,-43.039604402070296,-42.8442746412895,-42.64894488050871,-42.453615119727914,-42.25828535894713,-42.06295559816633,-41.86762583738554,-41.67229607660474,-41.476966315823944,-41.281636555043164,-41.08630679426237,-40.890977033481576,-40.69564727270078,-40.50031751191999,-40.3049877511392,-40.10965799035841,-39.91432822957761,-39.71899846879681,-39.52366870801603,-39.32833894723524,-39.133009186454444,-38.93767942567365,-38.74234966489286,-38.54701990411207,-38.351690143331275,-38.15636038255049,-37.96103062176969,-37.7657008609889,-37.570371100208106,-37.37504133942731,-37.17971157864652,-36.984381817865724,-36.789052057084945,-36.59372229630414,-36.39839253552336,-36.20306277474256,-36.00773301396176,-35.812403253180975,-35.61707349240019,-35.42174373161939,-35.22641397083859,-35.03108421005781,-34.83575444927702,-34.64042468849622,-34.445094927715424,-34.24976516693463,-34.05443540615384,-33.85910564537304,-33.66377588459226,-33.468446123811475,-33.27311636303067,-33.07778660224989,-32.8824568414691,-32.6871270806883,-32.49179731990749,-32.296467559126725,-32.101137798345924,-31.90580803756512,-31.710478276784336,-31.51514851600355,-31.319818755222748,-31.12448899444196,-30.929159233661174,-30.733829472880373,-30.538499712099586,-30.343169951318803,-30.147840190538,-29.952510429757197,-29.757180668976424,-29.561850908195623,-29.366521147414822,-29.171191386634035,-28.975861625853252,-28.780531865072447,-28.585202104291664,-28.389872343510877,-28.194542582730076,-27.99921282194927,-27.803883061168506,-27.6085533003877,-27.413223539606896,-27.217893778826113,-27.02256401804533,-26.82723425726452,-26.631904496483738,-26.436574735702955,-26.24124497492215,-26.045915214141367,-25.85058545336058,-25.655255692579775,-25.45992593179897,-25.264596171018205,-25.069266410237404,-24.8739366494566,-24.678606888675816,-24.48327712789503,-24.287947367114228,-24.09261760633344,-23.897287845552658,-23.701958084771853,-23.506628323991052,-23.311298563210283,-23.115968802429478,-22.920639041648677,-22.72530928086789,-22.529979520087107,-22.334649759306302,-22.139319998525515,-21.943990237744732,-21.748660476963927,-21.553330716183144,-21.35800095540236,-21.162671194621556,-20.96734143384075,-20.772011673059986,-20.57668191227918,-20.38135215149838,-20.186022390717593,-19.99069262993681,-19.795362869156,-19.600033108375218,-19.40470334759443,-19.209373586813626,-19.01404382603284,-18.818714065252056,-18.623384304471255,-18.42805454369045,-18.232724782909667,-18.03739502212888,-17.890906425283898,-17.84210015631052,-17.79329388733714,-17.744487618363756,-17.695681349390377,-17.646875080417,-17.598068811443618,-17.549262542470235,-17.50045627349686,-17.451650004523476,-17.402843735550093,-17.354037466576713,-17.305231197603334,-17.25642492862995,-17.20761865965657,-17.15881239068319,-17.11000612170981,-17.06119985273643,-17.012393583763053,-16.96358731478967,-16.914781045816287,-16.865974776842908,-16.81716850786953,-16.768362238896145,-16.719555969922766,-16.670749700949386,-16.621943431976003,-16.573137163002627,-16.524330894029248,-16.475524625055865,-16.426718356082482,-16.377912087109106,-16.329105818135723,-16.28029954916234,-16.23149328018896,-16.182687011215585,-16.133880742242198,-16.08507447326882,-16.03626820429544,-15.987461935322056,-15.938655666348678,-15.8898493973753,-15.841043128401916,-15.792236859428533,-15.743430590455153,-15.694624321481776,-15.645818052508393,-15.597011783535013,-15.548205514561634,-15.49939924558825,-15.450592976614871,-15.401786707641492,-15.35298043866811,-15.304174169694727,-15.255367900721353,-15.20656163174797,-15.157755362774587,-15.108949093801208,-15.060142824827828,-15.011336555854445,-14.962530286881066,-14.913724017907686,-14.864917748934303,-14.816111479960925,-14.767305210987546,-14.718498942014163,-14.66969267304078,-14.620886404067406,-14.572080135094023,-14.52327386612064,-14.47446759714726,-14.42566132817388,-14.376855059200498,-14.32804879022712,-14.27924252125374,-14.230436252280358,-14.181629983306975,-14.1328237143336,-14.084017445360217,-14.035211176386834,-13.986404907413455,-13.937598638440075,-13.888792369466692,-13.828127710174815,-13.708171099290421,-13.588214488406026,-13.468257877521634,-13.34830126663726,-13.228344655752863,-13.108388044868468,-12.988431433984097,-12.868474823099703,-12.748518212215306,-12.628561601330933,-12.508604990446539,-12.388648379562143,-12.26869176867775,-12.148735157793375,-12.028778546908981,-11.908821936024585,-11.788865325140215,-11.668908714255819,-11.548952103371423,-11.42899549248705,-11.309038881602657,-11.189082270718261,-11.069125659833889,-10.949169048949495,-10.829212438065099,-10.709255827180703,-10.58929921629633,-10.469342605411935,-10.349385994527541,-10.229429383643168,-10.109472772758773,-9.989516161874379,-9.869559550990006,-9.74960294010561,-9.629646329221217,-9.509689718336821,-9.389733107452448,-9.269776496568053,-9.149819885683659,-9.029863274799286,-8.90990666391489,-8.81920324208427,-8.749394955292065,-8.679586668499844,-8.609778381707628,-8.539970094915422,-8.470161808123201,-8.400353521330983,-8.330545234538764,-8.260736947746558,-8.19092866095434,-8.121120374162121,-8.051312087369915,-7.981503800577695,-7.911695513785476,-7.841887226993271,-7.772078940201052,-7.702270653408833,-7.632462366616614,-7.562654079824409,-7.49284579303219,-7.423037506239971,-7.353229219447764,-7.283420932655546,-7.213612645863327,-7.143804359071121,-7.073996072278902,-7.004187785486684,-6.934379498694478,-6.864571211902258,-6.794762925110039,-6.72495463831782,-6.655146351525614,-6.585338064733396,-6.515529777941177,-6.445721491148971,-6.375913204356753,-6.306104917564533,-6.236296630772328,-6.166488343980109,-6.096680057187889,-6.02687177039567,-5.957063483603465],[-43.14995733427537,-43.19527929408523,-43.24060125389509,-43.28592321370496,-43.33124517351483,-43.3765671333247,-43.42188909313455,-43.46721105294442,-43.51253301275429,-43.55785497256415,-43.60317693237401,-43.64849889218388,-43.69382085199374,-43.7391428118036,-43.78446477161347,-43.82978673142334,-43.8751086912332,-43.92043065104306,-43.96575261085293,-44.0110745706628,-44.05639653047266,-44.10171849028252,-44.14704045009239,-44.19236240990226,-44.23768436971211,-44.28300632952198,-44.32832828933185,-44.373650249141704,-44.41897220895157,-44.46429416876144,-44.50961612857131,-44.55493808838118,-44.60026004819103,-44.6455820080009,-44.69090396781076,-44.73622592762063,-44.78154788743049,-44.82686984724035,-44.87219180705023,-44.91751376686008,-44.96283572666995,-45.00815768647981,-45.05347964628968,-45.09880160609954,-45.1441235659094,-45.18944552571927,-45.23476748552913,-45.280089445339,-45.32541140514887,-45.37073336495873,-45.4160553247686,-45.46137728457846,-45.50669924438833,-45.55202120419819,-45.59734316400805,-45.64266512381791,-45.68798708362778,-45.73330904343765,-45.77863100324751,-45.82395296305738,-45.86927492286725,-45.91459688267711,-45.959918842486964,-46.005240802296825,-46.05056276210669,-46.09588472191656,-46.14120668172642,-46.18622433601661,-46.23063337971931,-46.275042423422,-46.3194514671247,-46.3638605108274,-46.4082695545301,-46.4526785982328,-46.4970876419355,-46.5414966856382,-46.5859057293409,-46.630314773043594,-46.6747238167463,-46.719132860449,-46.7635419041517,-46.8079509478544,-46.852359991557094,-46.896769035259794,-46.93630250332687,-46.97486085626683,-47.01341920920677,-47.05197756214673,-47.090535915086676,-47.129094268026634,-47.16765262096658,-47.20621097390653,-47.24476932684648,-47.28332767978643,-47.32188603272638,-47.36044438566633,-47.39900273860628,-47.437561091546236,-47.47611944448619,-47.51467779742614,-47.5531222898918,-47.59133906123982,-47.62955583258785,-47.66777260393587,-47.70598937528389,-47.74420614663191,-47.78242291797993,-47.820639689327955,-47.85885646067598,-47.897073232024,-47.93529000337202,-47.973506774720036,-48.011723546068055,-48.04994031741609,-48.088157088764106,-48.126373860112125,-48.16459063146014,-48.20280740280816,-48.24102417415618,-48.2792409455042,-48.31745771685223,-48.35567448820025,-48.39389125954827,-48.432108030896295,-48.47032480224431,-48.50854157359233,-48.54675834494035,-48.584975116288376,-48.623191887636395,-48.66140865898441,-48.69962543033244,-48.737842201680465,-48.77605897302848,-48.8142757443765,-48.85249251572452,-48.890709287072546,-48.928926058420565,-48.96714282976859,-49.00535960111661,-49.04357637246463,-49.08179314381265,-49.12000991516067,-49.1582266865087,-49.19644345785672,-49.234660229204735,-49.272877000552754,-49.31109377190078,-49.3493105432488,-49.387527314596824,-49.42574408594484,-49.46396085729286,-49.50217762864088,-49.540394399988905,-49.578611171336924,-49.61682794268495,-49.65504471403297,-49.69326148538099,-49.731478256729005,-49.769695028077024,-49.80791179942505,-49.84612857077307,-49.884345342121094,-49.92256211346911,-49.96077888481713,-49.99899565616516,-50.037212427513175,-50.075429198861194,-49.96529902691087,-49.780995383311385,-49.596691739711886,-49.4123880961124,-49.22808445251292,-49.04378080891342,-48.859477165313926,-48.67517352171443,-48.49086987811494,-48.30656623451546,-48.12226259091596,-47.93795894731647,-47.753655303716975,-47.56935166011748,-47.385048016518,-47.20074437291851,-47.016440729319015,-46.83213708571952,-46.647833442120024,-46.46352979852054,-46.27922615492105,-46.094922511321556,-45.91061886772207,-45.726315224122565,-45.54201158052309,-45.35770793692359,-45.1734042933241,-44.98910064972461,-44.804797006125106,-44.62049336252563,-44.43618971892613,-44.25188607532664,-44.06758243172715,-43.88327878812766,-43.69897514452817,-43.51467150092867,-43.33036785732918,-43.146064213729694,-42.9617605701302,-42.77745692653071,-42.59315328293122,-42.408849639331734,-42.224545995732235,-42.04024235213274,-41.855938708533245,-41.67163506493376,-41.487331421334275,-41.303027777734776,-41.118724134135284,-40.93442049053579,-40.7501168469363,-40.565813203336816,-40.381509559737324,-40.19720591613783,-40.01290227253833,-39.828598628938856,-39.634836294620676,-39.43950653383988,-39.24417677305909,-39.0488470122783,-38.853517251497514,-38.65818749071671,-38.462857729935926,-38.26752796915513,-38.07219820837434,-37.87686844759355,-37.68153868681276,-37.48620892603196,-37.29087916525116,-37.09554940447038,-36.90021964368959,-36.70488988290879,-36.509560122128,-36.31423036134721,-36.11890060056642,-35.92357083978563,-35.72824107900483,-35.53291131822404,-35.337581557443244,-35.14225179666246,-34.94692203588166,-34.75159227510087,-34.55626251432007,-34.360932753539295,-34.165602992758494,-33.9702732319777,-33.77494347119692,-33.57961371041611,-33.384283949635325,-33.188954188854545,-32.993624428073744,-32.798294667292936,-32.60296490651217,-32.40763514573137,-32.21230538495057,-32.016975624169774,-31.821645863388994,-31.626316102608193,-31.4309863418274,-31.23565658104662,-31.04032682026582,-30.844997059485024,-30.649667298704248,-30.454337537923447,-30.259007777142642,-30.063678016361873,-29.86834825558107,-29.673018494800267,-29.477688734019477,-29.282358973238697,-29.087029212457896,-28.891699451677106,-28.696369690896322,-28.50103993011552,-28.305710169334716,-28.11038040855395,-27.915050647773146,-27.71972088699234,-27.524391126211555,-27.329061365430775,-27.13373160464997,-26.93840184386918,-26.7430720830884,-26.5477423223076,-26.352412561526805,-26.157082800746025,-25.961753039965224,-25.76642327918442,-25.57109351840365,-25.37576375762285,-25.180433996842048,-24.985104236061254,-24.789774475280474,-24.594444714499673,-24.39911495371888,-24.2037851929381,-24.008455432157298,-23.813125671376497,-23.617795910595728,-23.422466149814923,-23.227136389034122,-23.03180662825333,-22.83647686747255,-22.641147106691747,-22.44581734591096,-22.250487585130177,-22.055157824349376,-21.85982806356858,-21.6644983027878,-21.469168542006997,-21.273838781226196,-21.07850902044543,-20.883179259664626,-20.68784949888382,-20.492519738103034,-20.29718997732225,-20.10186021654144,-19.90653045576066,-19.711200694979873,-19.51587093419907,-19.320541173418288,-19.125211412637494,-18.929881651856693,-18.734551891075892,-18.53922213029511,-18.34389236951432,-18.196501205021363,-18.14498723310406,-18.093473261186755,-18.04195928926945,-17.990445317352144,-17.938931345434842,-17.887417373517533,-17.835903401600227,-17.784389429682925,-17.732875457765616,-17.681361485848306,-17.629847513931004,-17.578333542013702,-17.526819570096393,-17.47530559817909,-17.42379162626179,-17.37227765434448,-17.320763682427174,-17.269249710509868,-17.217735738592562,-17.166221766675253,-17.114707794757948,-17.063193822840645,-17.011679850923336,-16.960165879006034,-16.90865190708873,-16.85713793517142,-16.805623963254117,-16.75410999133681,-16.70297787417244,-16.654171605199053,-16.60536533622568,-16.556559067252294,-16.507752798278915,-16.458946529305535,-16.410140260332156,-16.361333991358773,-16.312527722385394,-16.263721453412014,-16.21491518443863,-16.166108915465255,-16.117302646491876,-16.068496377518493,-16.01969010854511,-15.97088383957173,-15.92207757059835,-15.873271301624968,-15.824465032651588,-15.775658763678209,-15.726852494704827,-15.678046225731446,-15.62923995675807,-15.580433687784687,-15.531627418811304,-15.482821149837928,-15.434014880864545,-15.385208611891162,-15.336402342917783,-15.287596073944403,-15.23878980497102,-15.18998353599764,-15.141177267024263,-15.09237099805088,-15.043564729077499,-14.994758460104123,-14.94595219113074,-14.897145922157357,-14.84833965318398,-14.799533384210598,-14.750727115237215,-14.701920846263835,-14.653114577290456,-14.604308308317073,-14.555502039343693,-14.506695770370317,-14.457889501396933,-14.40908323242355,-14.360276963450175,-14.311470694476789,-14.262664425503406,-14.213858156530028,-14.165051887556649,-14.116245618583266,-14.05440326761762,-13.927380506690582,-13.800357745763545,-13.673334984836512,-13.546312223909496,-13.41928946298246,-13.292266702055425,-13.165243941128413,-13.038221180201376,-12.91119841927434,-12.784175658347326,-12.657152897420291,-12.530130136493256,-12.403107375566218,-12.276084614639206,-12.149818943497017,-12.029862332612622,-11.909905721728247,-11.789949110843853,-11.66999249995946,-11.550035889075085,-11.43007927819069,-11.310122667306295,-11.190166056421921,-11.070209445537529,-10.950252834653133,-10.830296223768737,-10.710339612884365,-10.590383001999971,-10.470426391115573,-10.350469780231201,-10.230513169346807,-10.110556558462411,-9.99059994757804,-9.870643336693647,-9.75068672580925,-9.630730114924855,-9.510773504040483,-9.390816893156087,-9.270860282271693,-9.150903671387319,-9.030947060502925,-8.940243638672305,-8.870435351880099,-8.800627065087879,-8.73081877829566,-8.661010491503454,-8.591202204711236,-8.521393917919017,-8.451585631126799,-8.381777344334592,-8.311969057542374,-8.242160770750154,-8.17235248395795,-8.102544197165729,-8.03273591037351,-7.962927623581305,-7.893119336789086,-7.823311049996867,-7.753502763204649,-7.683694476412443,-7.6138861896202235,-7.544077902828004,-7.474269616035798,-7.4044613292435795,-7.334653042451361,-7.264844755659155,-7.195036468866936,-7.124927463175744,-7.050067071491204,-6.97520667980665,-6.900346288122096,-6.825485896437542,-6.7506255047530015,-6.675765113068448,-6.600904721383893,-6.526044329699355,-6.4511839380147995,-6.376323546330246,-6.301463154645706,-6.226602762961152,-6.1517423712765975,-6.076881979592043,-6.002021587907503],[-42.85052708503476,-42.895849044844624,-42.94117100465449,-42.98649296446436,-43.03181492427422,-43.077136884084084,-43.12245884389395,-43.16778080370381,-43.213102763513675,-43.25842472332354,-43.30374668313341,-43.34906864294327,-43.394390602753134,-43.439712562563,-43.48503452237287,-43.53035648218274,-43.57567844199259,-43.62100040180246,-43.66632236161233,-43.71164432142219,-43.75696628123205,-43.80228824104192,-43.84761020085178,-43.892932160661644,-43.93825412047151,-43.98357608028138,-44.02889804009124,-44.0742199999011,-44.11954195971097,-44.16486391952083,-44.2101858793307,-44.25550783914057,-44.300829798950424,-44.34615175876029,-44.391473718570154,-44.43679567838002,-44.48211763818989,-44.52743959799975,-44.57276155780963,-44.61808351761948,-44.66340547742935,-44.70872743723921,-44.75404939704907,-44.799371356858934,-44.844693316668796,-44.890015276478664,-44.93533723628853,-44.9806591960984,-45.02598115590826,-45.07130311571813,-45.11662507552799,-45.16118627161396,-45.20559531531666,-45.25000435901936,-45.29441340272205,-45.33882244642475,-45.38323149012746,-45.42764053383016,-45.47204957753285,-45.51645862123556,-45.56086766493825,-45.60527670864095,-45.64968575234365,-45.69409479604634,-45.73850383974905,-45.78291288345175,-45.82732192715444,-45.87173097085715,-45.91614001455984,-45.960549058262544,-46.004958101965244,-46.049367145667944,-46.093776189370644,-46.138185233073344,-46.182594276776044,-46.22700332047875,-46.271412364181444,-46.315821407884144,-46.360230451586844,-46.404639495289544,-46.449048538992244,-46.493457582694944,-46.537866626397644,-46.582275670100344,-46.621809138167414,-46.660367491107365,-46.69892584404732,-46.73748419698727,-46.776042549927226,-46.81460090286717,-46.853159255807114,-46.89171760874707,-46.93027596168702,-46.968834314626974,-47.007392667566926,-47.04595102050687,-47.08450937344683,-47.12306772638678,-47.16162607932673,-47.20018443226668,-47.238742785206625,-47.277301138146576,-47.31585949108653,-47.35441784402648,-47.39297619696643,-47.43153454990638,-47.47009290284633,-47.50865125578628,-47.547209608726234,-47.585767961666185,-47.62432631460614,-47.66288466754609,-47.70144302048604,-47.74000137342599,-47.77855972636594,-47.817118079305885,-47.85567643224584,-47.893950133971906,-47.932166905319924,-47.97038367666794,-48.00860044801597,-48.04681721936399,-48.085033990712006,-48.12325076206003,-48.16146753340805,-48.199684304756076,-48.237901076104094,-48.27611784745211,-48.31433461880013,-48.35255139014815,-48.390768161496176,-48.4289849328442,-48.46720170419222,-48.505418475540246,-48.543635246888265,-48.58185201823628,-48.6200687895843,-48.65828556093232,-48.696502332280346,-48.73471910362837,-48.77293587497639,-48.81115264632441,-48.849369417672435,-48.88758618902045,-48.92580296036847,-48.96401973171649,-49.002236503064516,-49.04045327441254,-49.07867004576056,-49.11688681710858,-49.1551035884566,-49.193320359804616,-49.23153713115265,-49.26975390250067,-49.307970673848686,-49.346187445196705,-49.38440421654472,-49.42262098789275,-49.46083775924077,-49.499054530588786,-49.53727130193681,-49.57548807328483,-49.61370484463285,-49.65192161598087,-49.6901383873289,-49.72835515867692,-49.76657193002494,-49.65644175807461,-49.47213811447513,-49.28783447087563,-49.103530827276145,-48.919227183676654,-48.73492354007715,-48.55061989647767,-48.36631625287817,-48.18201260927869,-47.997708965679195,-47.81340532207969,-47.62910167848021,-47.44479803488071,-47.26049439128123,-47.07619074768175,-46.891887104082244,-46.70758346048275,-46.52327981688326,-46.33897617328377,-46.15467252968429,-45.970368886084785,-45.78606524248529,-45.601761598885815,-45.41745795528631,-45.233154311686825,-45.048850668087326,-44.86454702448784,-44.680243380888356,-44.49593973728885,-44.31163609368937,-44.12733245008987,-43.94302880649039,-43.7587251628909,-43.574421519291406,-43.390117875691914,-43.20581423209241,-43.02151058849293,-42.83720694489344,-42.65290330129395,-42.468599657694455,-42.28429601409496,-42.09999237049547,-41.91568872689598,-41.73138508329649,-41.547081439696996,-41.362777796097504,-41.17847415249801,-40.99417050889852,-40.80986686529903,-40.62556322169954,-40.441259578100045,-40.25695593450055,-40.07265229090106,-39.88834864730157,-39.70404500370207,-39.5197413601026,-39.335437716503094,-39.1511340729036,-38.96683042930411,-38.78252678570462,-38.598223142105134,-38.413919498505635,-38.22961585490615,-38.04531221130665,-37.86100856770717,-37.676704924107675,-37.49240128050818,-37.308097636908684,-37.1237939933092,-36.93949034970971,-36.755186706110216,-36.57088306251073,-36.38657941891124,-36.20227577531174,-36.017972131712256,-35.833668488112764,-35.649364844513265,-35.46506120091377,-35.28075755731429,-35.0964539137148,-34.912150270115305,-34.727846626515806,-34.54354298291632,-34.35923933931683,-34.17493569571733,-33.990632052117846,-33.80632840851836,-33.62202476491886,-33.43772112131937,-33.253417477719886,-33.06911383412039,-32.88481019052089,-32.70050654692142,-32.51620290332191,-32.33189925972241,-32.14759561612293,-31.963291972523443,-31.778988328923944,-31.59468468532446,-31.410381041724975,-31.226077398125472,-31.041773754525984,-30.8574701109265,-30.673166467327,-30.488862823727494,-30.30455918012803,-30.12025553652853,-29.935951892929026,-29.75164824932954,-29.567344605730057,-29.383040962130554,-29.198196799062544,-29.002867038281757,-28.807537277500955,-28.61220751672015,-28.416877755939385,-28.22154799515858,-28.02621823437778,-27.830888473596993,-27.635558712816206,-27.440228952035405,-27.244899191254618,-27.049569430473834,-26.85423966969303,-26.658909908912243,-26.463580148131463,-26.268250387350655,-26.072920626569854,-25.877590865789088,-25.68226110500828,-25.48693134422748,-25.291601583446695,-25.096271822665912,-24.900942061885104,-24.70561230110432,-24.510282540323537,-24.314952779542732,-24.119623018761928,-23.924293257981162,-23.728963497200358,-23.533633736419556,-23.338303975638773,-23.142974214857986,-22.947644454077185,-22.752314693296398,-22.55698493251561,-22.361655171734807,-22.166325410954023,-21.97099565017324,-21.775665889392435,-21.580336128611634,-21.385006367830865,-21.18967660705006,-20.994346846269256,-20.799017085488472,-20.60368732470769,-20.40835756392688,-20.213027803146097,-20.017698042365314,-19.82236828158451,-19.627038520803723,-19.431708760022936,-19.236378999242135,-19.04104923846133,-18.845719477680547,-18.65038971689976,-18.5029985524068,-18.4514845804895,-18.399970608572193,-18.348456636654888,-18.296942664737582,-18.24542869282028,-18.19391472090297,-18.14240074898566,-18.090886777068363,-18.039372805151054,-17.987858833233744,-17.936344861316442,-17.88483088939914,-17.83331691748183,-17.78180294556453,-17.730288973647223,-17.678775001729917,-17.62726102981261,-17.575747057895306,-17.524233085978,-17.47271911406069,-17.421205142143386,-17.369691170226083,-17.318177198308774,-17.266663226391472,-17.215149254474166,-17.16363528255686,-17.112121310639555,-17.06060733872225,-17.00909336680494,-16.957579394887635,-16.906065422970336,-16.854551451053027,-16.803037479135718,-16.751523507218415,-16.700009535301113,-16.648495563383804,-16.5969815914665,-16.545467619549196,-16.493953647631884,-16.44243967571458,-16.39092570379728,-16.33941173187997,-16.28789775996266,-16.23638378804536,-16.184869816128053,-16.133355844210747,-16.08184187229344,-16.030327900376136,-15.978813928458829,-15.927299956541525,-15.875785984624223,-15.824272012706912,-15.772758040789604,-15.721244068872306,-15.669730096954996,-15.618216125037687,-15.566702153120385,-15.515188181203083,-15.46624305408759,-15.417436785114212,-15.368630516140833,-15.31982424716745,-15.27101797819407,-15.22221170922069,-15.173405440247308,-15.124599171273923,-15.07579290230055,-15.026986633327168,-14.978180364353785,-14.929374095380405,-14.880567826407027,-14.831761557433644,-14.782955288460265,-14.734149019486885,-14.685342750513502,-14.636536481540118,-14.587730212566745,-14.538923943593362,-14.49011767461998,-14.441311405646598,-14.39250513667322,-14.343698867699837,-14.281856516734187,-14.154833755807152,-14.027810994880115,-13.90078823395308,-13.773765473026069,-13.64674271209903,-13.519719951171995,-13.392697190244984,-13.265674429317947,-13.13865166839091,-13.011628907463898,-12.884606146536862,-12.757583385609827,-12.630560624682788,-12.503537863755778,-12.37651510282874,-12.249492341901707,-12.122469580974693,-11.995446820047658,-11.868424059120622,-11.741401298193608,-11.614378537266573,-11.487355776339536,-11.360333015412523,-11.233310254485488,-11.106287493558451,-10.979264732631416,-10.852241971704403,-10.725219210777368,-10.598196449850331,-10.471510176819233,-10.351553565934838,-10.231596955050444,-10.111640344166071,-9.991683733281675,-9.871727122397282,-9.751770511512886,-9.631813900628513,-9.511857289744118,-9.391900678859724,-9.271944067975351,-9.151987457090955,-9.061284035260336,-8.99147574846813,-8.92166746167591,-8.851859174883693,-8.782050888091486,-8.712242601299266,-8.642434314507048,-8.57262602771483,-8.502817740922623,-8.433009454130403,-8.363201167338184,-8.292791442748037,-8.217931051063482,-8.14307065937893,-8.06821026769439,-7.993349876009835,-7.918489484325281,-7.843629092640727,-7.768768700956187,-7.693908309271634,-7.619047917587079,-7.544187525902539,-7.469327134217984,-7.39446674253343,-7.31960635084889,-7.2447459591643355,-7.169885567479782,-7.095025175795242,-7.020164784110689,-6.945304392426133,-6.870444000741579,-6.795583609057039,-6.720723217372486,-6.6458628256879315,-6.5710024340033915,-6.496142042318837,-6.421281650634283,-6.346421258949743,-6.271560867265189,-6.196700475580635,-6.12184008389608,-6.04697969221154],[-42.551096835794155,-42.59641879560401,-42.64174075541388,-42.687062715223746,-42.73238467503361,-42.777706634843476,-42.82302859465334,-42.8683505544632,-42.91367251427307,-42.958994474082935,-43.0043164338928,-43.04963839370266,-43.09496035351252,-43.14028231332239,-43.185604273132256,-43.230926232942124,-43.276248192751986,-43.321570152561854,-43.366892112371715,-43.41221407218158,-43.45753603199144,-43.50285799180131,-43.54817995161116,-43.593501911421036,-43.6388238712309,-43.684145831040766,-43.729467790850634,-43.774789750660496,-43.82011171047036,-43.86543367028022,-43.91075563009009,-43.956077589899955,-44.00139954970981,-44.04672150951968,-44.0917391635086,-44.13614820721129,-44.180557250914,-44.2249662946167,-44.2693753383194,-44.3137843820221,-44.35819342572479,-44.4026024694275,-44.44701151313019,-44.49142055683289,-44.53582960053559,-44.58023864423829,-44.62464768794099,-44.66905673164369,-44.71346577534639,-44.75787481904909,-44.80228386275179,-44.84669290645449,-44.89110195015719,-44.93551099385989,-44.97992003756259,-45.02432908126529,-45.06873812496799,-45.11314716867069,-45.15755621237339,-45.20196525607609,-45.24637429977879,-45.290783343481486,-45.33519238718419,-45.379601430886886,-45.424010474589586,-45.468419518292286,-45.512828561994986,-45.557237605697686,-45.60164664940038,-45.64605569310308,-45.69046473680579,-45.73487378050848,-45.77928282421118,-45.82369186791388,-45.86810091161659,-45.91250995531929,-45.95691899902198,-46.00132804272468,-46.04573708642739,-46.09014613013008,-46.13455517383279,-46.17896421753548,-46.22337326123818,-46.26778230494088,-46.30731577300796,-46.3458741259479,-46.38443247888785,-46.4229908318278,-46.461549184767755,-46.500107537707706,-46.53866589064766,-46.57722424358761,-46.61578259652755,-46.65434094946752,-46.69289930240746,-46.73145765534741,-46.77001600828737,-46.808574361227315,-46.847132714167266,-46.88569106710722,-46.92424942004716,-46.96280777298712,-47.00136612592707,-47.03992447886702,-47.078482831806966,-47.11704118474692,-47.15559953768687,-47.19415789062681,-47.23271624356677,-47.27127459650672,-47.30983294944667,-47.34839130238662,-47.386949655326575,-47.42550800826652,-47.46406636120647,-47.50262471414643,-47.54118306708638,-47.57974142002632,-47.61829977296628,-47.656858125906226,-47.695416478846184,-47.73397483178613,-47.77253318472607,-47.81109153766603,-47.84964989060598,-47.88820824354593,-47.92676659648589,-47.965324949425835,-48.00388330236578,-48.04244165530574,-48.081000008245695,-48.11955836118564,-48.15811671412559,-48.19656120670398,-48.234777978052,-48.27299474940002,-48.31121152074804,-48.34942829209606,-48.38764506344408,-48.42586183479211,-48.46407860614013,-48.502295377488146,-48.54051214883617,-48.57872892018418,-48.61694569153221,-48.655162462880234,-48.69337923422825,-48.73159600557627,-48.76981277692429,-48.808029548272316,-48.846246319620334,-48.88446309096836,-48.92267986231638,-48.960896633664404,-48.99911340501242,-49.03733017636044,-49.07554694770847,-49.113763719056486,-49.151980490404505,-49.19019726175252,-49.22841403310055,-49.26663080444857,-49.304847575796586,-49.343064347144605,-49.38128111849264,-49.419497889840656,-49.457714661188675,-49.34758448923834,-49.16328084563886,-48.97897720203937,-48.794673558439875,-48.61036991484039,-48.426066271240884,-48.24176262764141,-48.05745898404191,-47.87315534044242,-47.68885169684293,-47.504548053243425,-47.32024440964395,-47.135940766044456,-46.95163712244496,-46.76733347884548,-46.58302983524598,-46.39872619164649,-46.214422548047,-46.030118904447505,-45.84581526084802,-45.66151161724852,-45.47720797364903,-45.292904330049545,-45.108600686450046,-44.92429704285056,-44.73999339925107,-44.55568975565157,-44.37138611205209,-44.18708246845259,-44.0027788248531,-43.8184751812536,-43.63417153765412,-43.449867894054634,-43.265564250455135,-43.08126060685565,-42.896956963256144,-42.71265331965666,-42.528349676057175,-42.344046032457676,-42.15974238885819,-41.9754387452587,-41.79113510165921,-41.606831458059716,-41.422527814460224,-41.238224170860725,-41.05392052726123,-40.86961688366175,-40.68531324006226,-40.501009596462765,-40.31670595286327,-40.132402309263774,-39.9480986656643,-39.763795022064805,-39.579491378465306,-39.39518773486581,-39.21088409126633,-39.02658044766684,-38.84227680406734,-38.65797316046785,-38.473669516868355,-38.28936587326886,-38.10506222966937,-37.92075858606989,-37.73645494247039,-37.5521512988709,-37.36784765527141,-37.18354401167192,-36.99924036807242,-36.814936724472936,-36.63063308087345,-36.44632943727395,-36.26202579367447,-36.07772215007497,-35.89341850647547,-35.70911486287599,-35.5248112192765,-35.340507575677,-35.1562039320775,-34.971900288478025,-34.78759664487853,-34.603293001279035,-34.41898935767954,-34.23468571408006,-34.050382070480566,-33.86607842688107,-33.68177478328158,-33.49747113968209,-33.31316749608259,-33.12886385248311,-32.94456020888362,-32.760256565284124,-32.575952921684625,-32.39164927808515,-32.207345634485655,-32.02304199088615,-31.838738347286668,-31.65443470368718,-31.47013106008768,-31.285827416488193,-31.10152377288871,-30.91722012928921,-30.73291648568972,-30.548612842090236,-30.364309198490737,-30.18000555489124,-29.995701911291768,-29.811398267692265,-29.627094624092763,-29.44279098049328,-29.258487336893793,-29.074183693294295,-28.889880049694806,-28.705576406095325,-28.521272762495823,-28.33696911889632,-28.15266547529685,-27.96836183169735,-27.78405818809785,-27.59975454449836,-27.41545090089888,-27.231147257299376,-27.04684361369989,-26.862539970100407,-26.678236326500905,-26.49393268290142,-26.309629039301935,-26.125325395702433,-25.94102175210293,-25.756718108503463,-25.572414464903964,-25.38811082130446,-25.203807177704974,-25.019503534105493,-24.83519989050599,-24.650896246906505,-24.46659260330702,-24.282288959707518,-24.097985316108016,-23.91368167250855,-23.729378028909046,-23.545074385309547,-23.360770741710063,-23.176467098110578,-22.992163454511076,-22.807859810911587,-22.623556167312106,-22.439252523712604,-22.25494888011312,-22.07064523651363,-21.88634159291413,-21.702037949314633,-21.517734305715162,-21.33343066211566,-21.149127018516158,-20.964823374916673,-20.780519731317188,-20.596216087717686,-20.4119124441182,-20.227608800518716,-20.04330515691921,-19.85900151331973,-19.674697869720244,-19.49039422612074,-19.306090582521236,-19.121786938921755,-18.944420657763136,-18.808654369774533,-18.756434059976232,-18.7048072876067,-18.653180515237164,-18.60155374286763,-18.549926970498095,-18.498300198128558,-18.44667342575902,-18.39504665338949,-18.343419881019955,-18.291793108650413,-18.240166336280883,-18.188539563911345,-18.136912791541807,-18.085286019172276,-18.033659246802742,-17.982032474433204,-17.93040570206367,-17.878778929694136,-17.827152157324598,-17.77552538495506,-17.72389861258553,-17.67227184021599,-17.620645067846457,-17.569018295476923,-17.51739152310739,-17.46576475073785,-17.414137978368316,-17.36251120599878,-17.310884433629248,-17.259257661259706,-17.20763088889018,-17.15600411652064,-17.1043773441511,-17.052750571781566,-17.001123799412035,-16.949497027042497,-16.897870254672963,-16.84624348230343,-16.79461670993389,-16.742989937564356,-16.691363165194822,-16.639736392825284,-16.58810962045575,-16.536482848086216,-16.48485607571668,-16.433229303347144,-16.38160253097761,-16.32997575860808,-16.27834898623854,-16.226722213869003,-16.175095441499472,-16.123468669129934,-16.071841896760397,-16.020215124390866,-15.96858835202133,-15.91696157965179,-15.865334807282256,-15.813708034912722,-15.762081262543186,-15.710454490173651,-15.658827717804117,-15.607200945434581,-15.555574173065047,-15.503947400695512,-15.452320628325976,-15.400693855956437,-15.349067083586906,-15.29744031121737,-15.245813538847832,-15.194186766478296,-15.142559994108764,-15.090933221739228,-15.039306449369693,-14.987679677000159,-14.936052904630621,-14.884426132261083,-14.832799359891554,-14.781172587522017,-14.729545815152479,-14.677919042782944,-14.626292270413412,-14.574665498043872,-14.509312641647519,-14.375329365117038,-14.241346088586555,-14.112881449410155,-13.985653432142266,-13.858425414874356,-13.731197397606444,-13.603969380338556,-13.476741363070646,-13.349513345802734,-13.222285328534849,-13.095057311266935,-12.967829293999023,-12.840601276731112,-12.713373259463223,-12.586145242195313,-12.458917224927403,-12.331689207659515,-12.204461190391603,-12.077233173123693,-11.950005155855804,-11.822777138587895,-11.695549121319983,-11.568321104052096,-11.441093086784184,-11.313865069516272,-11.186637052248363,-11.059409034980474,-10.932181017712562,-10.804953000444653,-10.677724983176763,-10.550496965908852,-10.423268948640942,-10.296040931373055,-10.168812914105144,-10.041584896837232,-9.91435687956932,-9.787128862301435,-9.659900845033523,-9.53267282776561,-9.405444810497723,-9.278216793229811,-9.181431878518502,-9.106392037061916,-9.031352195605317,-8.956312354148714,-8.881272512692128,-8.806232671235527,-8.731192829778927,-8.656152988322324,-8.581113146865738,-8.506073305409137,-8.431033463952536,-8.355993622495948,-8.280953781039347,-8.205913939582747,-8.13087409812616,-8.05583425666956,-7.980794415212957,-7.905754573756357,-7.83071473229977,-7.755674890843169,-7.6806350493865665,-7.605595207929981,-7.53055536647338,-7.4555155250167795,-7.380475683560192,-7.3054358421035905,-7.23039600064699,-7.1553561591904025,-7.080316317733802,-7.005276476277201,-6.9302366348205995,-6.855196793364013,-6.780156951907412,-6.705117110450811,-6.630077268994224,-6.555037427537623,-6.479997586081022,-6.404957744624435,-6.329917903167834,-6.2530268063338985,-6.1726935391723226,-6.092360272010761],[-42.25166658655355,-42.296988546363416,-42.34231050617328,-42.38763246598314,-42.43295442579301,-42.47827638560287,-42.523598345412736,-42.5689203052226,-42.614242265032466,-42.65956422484233,-42.704886184652196,-42.75020814446206,-42.795530104271926,-42.84085206408179,-42.88617402389165,-42.93149598370152,-42.97681794351138,-43.022139903321246,-43.06670109910595,-43.11111014280864,-43.15551918651134,-43.19992823021404,-43.24433727391674,-43.28874631761944,-43.33315536132214,-43.37756440502484,-43.42197344872754,-43.466382492430235,-43.51079153613294,-43.55520057983564,-43.59960962353834,-43.64401866724104,-43.688427710943735,-43.73283675464644,-43.77724579834914,-43.82165484205184,-43.866063885754535,-43.910472929457235,-43.954881973159935,-43.999291016862635,-44.043700060565335,-44.08810910426803,-44.13251814797073,-44.176927191673435,-44.22133623537613,-44.26574527907883,-44.310154322781536,-44.35456336648423,-44.39897241018693,-44.44338145388963,-44.48779049759233,-44.53219954129503,-44.57660858499773,-44.62101762870043,-44.66542667240313,-44.70983571610583,-44.75424475980853,-44.79865380351123,-44.84306284721392,-44.88747189091663,-44.93188093461933,-44.97628997832203,-45.02069902202473,-45.06510806572743,-45.10951710943013,-45.15392615313283,-45.19833519683553,-45.24274424053823,-45.28715328424092,-45.33156232794362,-45.37597137164632,-45.42038041534902,-45.46478945905172,-45.509198502754415,-45.553607546457116,-45.59801659015982,-45.642425633862516,-45.686834677565216,-45.73124372126792,-45.775652764970616,-45.820061808673316,-45.864470852376016,-45.908879896078716,-45.953288939781416,-45.99282240784849,-46.031380760788444,-46.069939113728395,-46.10849746666835,-46.1470558196083,-46.18561417254825,-46.2241725254882,-46.26273087842815,-46.3012892313681,-46.33984758430805,-46.378405937248004,-46.416964290187956,-46.4555226431279,-46.49408099606785,-46.5326393490078,-46.57119770194775,-46.609756054887704,-46.648314407827655,-46.68687276076761,-46.72543111370756,-46.76398946664751,-46.80254781958746,-46.84110617252741,-46.87966452546736,-46.918222878407306,-46.956781231347264,-46.99533958428721,-47.03389793722717,-47.07245629016711,-47.11101464310707,-47.14957299604701,-47.188131348986964,-47.226689701926915,-47.265248054866866,-47.30380640780682,-47.34236476074677,-47.38092311368672,-47.41948146662667,-47.45803981956662,-47.49659817250657,-47.535156525446524,-47.573714878386475,-47.61227323132643,-47.65083158426637,-47.68938993720632,-47.72794829014627,-47.766506643086224,-47.805064996026175,-47.843623348966126,-47.88218170190608,-47.92074005484603,-47.95929840778598,-47.99785676072593,-48.03641511366588,-48.07497346660583,-48.113531819545784,-48.152090172485735,-48.190648525425686,-48.22920687836564,-48.26776523130559,-48.30632358424553,-48.344881937185484,-48.38344029012544,-48.421998643065386,-48.46055699600534,-48.49911534894529,-48.53738905078407,-48.5756058221321,-48.613822593480116,-48.652039364828134,-48.69025613617616,-48.728472907524186,-48.766689678872204,-48.80490645022022,-48.84312322156824,-48.88133999291627,-48.919556764264286,-48.957773535612304,-48.99599030696034,-49.034207078308356,-49.072423849656374,-49.11064062100439,-49.14885739235241,-49.03872722040209,-48.8544235768026,-48.67011993320311,-48.48581628960362,-48.301512646004134,-48.117209002404635,-47.93290535880515,-47.74860171520565,-47.56429807160616,-47.37999442800668,-47.19569078440718,-47.01138714080769,-46.82708349720819,-46.6427798536087,-46.45847621000921,-46.27417256640972,-46.08986892281023,-45.905565279210734,-45.72126163561125,-45.53695799201176,-45.352654348412266,-45.16835070481278,-44.98404706121329,-44.79974341761378,-44.6154397740143,-44.43113613041481,-44.246832486815315,-44.06252884321583,-43.87822519961633,-43.693921556016846,-43.50961791241735,-43.32531426881786,-43.14101062521838,-42.95670698161888,-42.77240333801939,-42.588099694419896,-42.4037960508204,-42.21949240722092,-42.03518876362142,-41.85088512002193,-41.666581476422444,-41.482277832822945,-41.29797418922346,-41.11367054562396,-40.92936690202446,-40.74506325842498,-40.56075961482549,-40.376455971226,-40.1921523276265,-40.00784868402702,-39.82354504042752,-39.639241396828034,-39.45493775322855,-39.27063410962904,-39.08633046602955,-38.902026822430074,-38.71772317883058,-38.53341953523108,-38.34911589163159,-38.1648122480321,-37.98050860443261,-37.79620496083312,-37.611901317233624,-37.42759767363413,-37.24329403003465,-37.058990386435156,-36.874686742835664,-36.690383099236165,-36.50607945563667,-36.32177581203719,-36.13747216843769,-35.953168524838205,-35.76886488123871,-35.58456123763922,-35.40025759403973,-35.215953950440245,-35.031650306840746,-34.84734666324125,-34.66304301964177,-34.47873937604227,-34.29443573244278,-34.11013208884329,-33.925828445243795,-33.74152480164431,-33.56222253471745,-33.38550162704772,-33.208780719377984,-33.03205981170823,-32.8553389040385,-32.67861799636876,-32.50189708869901,-32.32517618102926,-32.148455273359545,-31.97173436568979,-31.79501345802004,-31.618292550350308,-31.44157164268057,-31.26485073501082,-31.08812982734109,-30.911408919671356,-30.7346880120016,-30.55796710433187,-30.381246196662133,-30.20452528899238,-30.027804381322632,-29.851083473652913,-29.674362565983166,-29.497641658313412,-29.320920750643683,-29.144199842973947,-28.9674789353042,-28.790758027634464,-28.614037119964728,-28.437316212294977,-28.260595304625227,-28.08387439695551,-27.90715348928576,-27.730432581616007,-27.553711673946275,-27.376990766276542,-27.200269858606788,-27.02354895093706,-26.84682804326732,-26.670107135597576,-26.49338622792784,-26.316665320258103,-26.139944412588353,-25.963223504918602,-25.786502597248887,-25.609781689579137,-25.433060781909386,-25.256339874239654,-25.079618966569917,-24.902898058900167,-24.726177151230434,-24.5494562435607,-24.37273533589095,-24.196014428221197,-24.01929352055148,-23.842572612881728,-23.665851705211978,-23.489130797542245,-23.31240988987251,-23.135688982202762,-22.95896807453303,-22.782247166863293,-22.605526259193542,-22.428805351523806,-22.252084443854073,-22.07536353618432,-21.898642628514573,-21.721921720844854,-21.545200813175104,-21.368479905505353,-21.19175899783562,-21.015038090165884,-20.838317182496134,-20.6615962748264,-20.48487536715667,-20.308154459486918,-20.131433551817185,-19.95471264414745,-19.7779917364777,-19.601270828807948,-19.424549921138215,-19.24782901346848,-19.112062725479873,-19.05820567685353,-19.004348628227184,-18.950491579600833,-18.896634530974488,-18.842777482348144,-18.788920433721795,-18.735063385095444,-18.681206336469103,-18.627349287842755,-18.573492239216403,-18.51963519059006,-18.465778141963714,-18.411921093337362,-18.358064044711018,-18.304206996084673,-18.25034994745832,-18.196492898831977,-18.142635850205632,-18.08877880157928,-18.034921752952933,-17.981064704326588,-17.927207655700244,-17.873350607073892,-17.819493558447547,-17.765636509821203,-17.71177946119485,-17.657922412568507,-17.604065363942162,-17.55020831531581,-17.496351266689462,-17.442781996615373,-17.391155224245836,-17.339528451876298,-17.287901679506763,-17.23627490713723,-17.18464813476769,-17.133021362398157,-17.081394590028623,-17.029767817659085,-16.978141045289554,-16.92651427292002,-16.874887500550482,-16.82326072818094,-16.77163395581141,-16.720007183441876,-16.66838041107234,-16.616753638702804,-16.565126866333273,-16.51350009396373,-16.4618733215942,-16.410246549224667,-16.35861977685513,-16.30699300448559,-16.255366232116064,-16.203739459746526,-16.152112687376984,-16.10048591500745,-16.048859142637916,-15.997232370268382,-15.945605597898847,-15.893978825529313,-15.842352053159775,-15.790725280790241,-15.739098508420707,-15.687471736051169,-15.635844963681633,-15.584218191312104,-15.532591418942564,-15.480964646573026,-15.42933787420349,-15.377711101833958,-15.326084329464422,-15.274457557094888,-15.222830784725357,-15.171204012355817,-15.119577239986278,-15.06795046761675,-15.01632369524721,-14.964696922877673,-14.91307015050814,-14.861443378138606,-14.809816605769068,-14.744463749372716,-14.610480472842234,-14.47649719631175,-14.342513919781268,-14.208530643250809,-14.074547366720326,-13.940564090189845,-13.806580813659387,-13.672597537128905,-13.538614260598422,-13.404630984067964,-13.27064770753748,-13.136664431006999,-13.002681154476518,-12.868697877946058,-12.734714601415575,-12.600731324885093,-12.466748048354635,-12.334545865436954,-12.207317848169044,-12.080089830901155,-11.952861813633245,-11.825633796365334,-11.698405779097445,-11.571177761829535,-11.443949744561625,-11.316721727293714,-11.189493710025825,-11.062265692757915,-10.935037675490003,-10.807809658222116,-10.680581640954204,-10.553353623686295,-10.426125606418406,-10.298897589150496,-10.171669571882584,-10.044441554614671,-9.917213537346784,-9.789985520078874,-9.662757502810962,-9.535529485543075,-9.408301468275162,-9.311516553563855,-9.236476712107267,-9.161436870650666,-9.086397029194066,-9.011357187737477,-8.936317346280877,-8.861277504824276,-8.786237663367675,-8.711197821911089,-8.636157980454488,-8.561118138997887,-8.486078297541301,-8.411038456084698,-8.335998614628098,-8.26095877317151,-8.185918931714909,-8.110879090258308,-8.035839248801707,-7.960799407345121,-7.885759565888521,-7.8107197244319195,-7.735679882975331,-7.660640041518731,-7.58560020006213,-7.50578036143688,-7.425447094275304,-7.345113827113728,-7.264780559952166,-7.1844472927905905,-7.1041140256290145,-7.023780758467437,-6.943447491305876,-6.8631142241443,-6.782780956982723,-6.702447689821162,-6.622114422659585,-6.541781155498009,-6.461447888336448,-6.381114621174872,-6.300781354013295,-6.220448086851719,-6.140114819690157],[-41.95223633731293,-41.99725399100058,-42.041663034703284,-42.086072078405984,-42.130481122108684,-42.174890165811384,-42.219299209514084,-42.263708253216784,-42.308117296919484,-42.352526340622184,-42.39693538432488,-42.44134442802758,-42.48575347173028,-42.53016251543298,-42.57457155913568,-42.61898060283838,-42.663389646541084,-42.70779869024378,-42.75220773394648,-42.79661677764918,-42.84102582135188,-42.88543486505458,-42.92984390875728,-42.97425295245998,-43.01866199616268,-43.06307103986538,-43.10748008356808,-43.15188912727078,-43.19629817097348,-43.24070721467617,-43.28511625837888,-43.32952530208158,-43.37393434578428,-43.41834338948698,-43.46275243318968,-43.50716147689238,-43.55157052059507,-43.59597956429778,-43.64038860800047,-43.68479765170317,-43.72920669540588,-43.77361573910857,-43.81802478281127,-43.86243382651397,-43.90684287021667,-43.951251913919364,-43.99566095762207,-44.040070001324764,-44.084479045027464,-44.128888088730164,-44.173297132432864,-44.217706176135565,-44.262115219838265,-44.306524263540965,-44.350933307243665,-44.395342350946365,-44.439751394649065,-44.484160438351765,-44.528569482054465,-44.572978525757165,-44.617387569459865,-44.661796613162565,-44.70620565686526,-44.750614700567965,-44.79502374427066,-44.83943278797336,-44.88384183167605,-44.92825087537876,-44.97265991908146,-45.01706896278416,-45.06147800648685,-45.10588705018956,-45.15029609389225,-45.19470513759495,-45.23911418129765,-45.28352322500036,-45.32793226870305,-45.37234131240575,-45.41675035610845,-45.46115939981115,-45.50556844351385,-45.54997748721655,-45.59438653091925,-45.63879557462195,-45.67832904268903,-45.71688739562898,-45.75544574856893,-45.79400410150888,-45.83256245444883,-45.871120807388785,-45.909679160328736,-45.94823751326868,-45.98679586620863,-46.02535421914859,-46.06391257208853,-46.10247092502849,-46.14102927796844,-46.17958763090839,-46.21814598384834,-46.25670433678829,-46.29526268972824,-46.33382104266819,-46.37237939560814,-46.41093774854809,-46.44949610148804,-46.488054454427996,-46.52661280736795,-46.5651711603079,-46.60372951324785,-46.6422878661878,-46.680846219127744,-46.7194045720677,-46.75796292500765,-46.796521277947605,-46.835079630887556,-46.87363798382751,-46.91219633676745,-46.95075468970741,-46.98931304264735,-47.02787139558731,-47.066429748527256,-47.104988101467214,-47.14354645440716,-47.18210480734711,-47.22066316028706,-47.25922151322701,-47.29777986616696,-47.336338219106906,-47.37489657204686,-47.41345492498681,-47.45201327792676,-47.49057163086671,-47.52912998380667,-47.56768833674661,-47.606246689686564,-47.644805042626516,-47.68336339556646,-47.72192174850642,-47.76048010144637,-47.79903845438632,-47.83759680732627,-47.876155160266215,-47.91471351320617,-47.953271866146125,-47.991830219086076,-48.03038857202603,-48.06894692496597,-48.10750527790592,-48.14606363084587,-48.18462198378583,-48.223180336725775,-48.261738689665734,-48.30029704260568,-48.33885539554563,-48.37741374848558,-48.41597210142553,-48.45453045436548,-48.493088807305426,-48.53164716024538,-48.57020551318533,-48.60876386612529,-48.64732221906524,-48.68588057200519,-48.72443892494514,-48.762997277885084,-48.80155563082504,-48.84000012351615,-48.729869951565824,-48.54556630796634,-48.36126266436685,-48.18002441167178,-48.00330350400204,-47.826582596332294,-47.64986168866256,-47.47314078099282,-47.296419873323075,-47.11969896565334,-46.942978057983595,-46.766257150313855,-46.589536242644115,-46.41281533497437,-46.23609442730463,-46.059373519634896,-45.88265261196515,-45.705931704295416,-45.52921079662567,-45.35248988895593,-45.1757689812862,-44.99904807361645,-44.82232716594671,-44.64560625827696,-44.46888535060723,-44.292164442937484,-44.11544353526775,-43.93872262759801,-43.762001719928264,-43.585280812258524,-43.408559904588785,-43.23183899691904,-43.05511808924931,-42.878397181579565,-42.701676273909825,-42.52495536624008,-42.34823445857034,-42.171513550900606,-41.994792643230866,-41.818071735561126,-41.641350827891394,-41.46462992022165,-41.28790901255191,-41.11118810488217,-40.93446719721242,-40.75774628954268,-40.58102538187295,-40.40430447420321,-40.22758356653346,-40.05086265886372,-39.874141751193974,-39.69742084352425,-39.520699935854495,-39.34397902818476,-39.16725812051501,-38.990537212845275,-38.813816305175536,-38.63709539750579,-38.460374489836056,-38.28365358216631,-38.106932674496576,-37.93021176682683,-37.75349085915709,-37.57676995148735,-37.40004904381762,-37.22332813614787,-37.04660722847813,-36.86988632080839,-36.69316541313865,-36.51644450546891,-36.33972359779917,-36.163002690129424,-35.986281782459685,-35.80956087478994,-35.632839967120205,-35.456119059450465,-35.279398151780725,-35.102677244110986,-34.925956336441246,-34.7492354287715,-34.572514521101766,-34.39579361343202,-34.21907270576228,-34.04235179809255,-33.86563089042279,-33.68890998275306,-33.51218907508333,-33.33546816741358,-33.15874725974384,-32.98202635207411,-32.805305444404354,-32.62858453673461,-32.45186362906489,-32.27514272139514,-32.09842181372539,-31.921700906055655,-31.744979998385915,-31.568259090716168,-31.39153818304644,-31.2148172753767,-31.03809636770695,-30.86137546003722,-30.68465455236748,-30.50793364469773,-30.331212737027982,-30.15449182935826,-29.977770921688514,-29.80105001401876,-29.62432910634903,-29.447608198679294,-29.270887291009544,-29.09416638333981,-28.917445475670075,-28.740724568000324,-28.564003660330577,-28.38728275266086,-28.210561844991105,-28.033840937321358,-27.857120029651625,-27.680399121981885,-27.50367821431214,-27.326957306642406,-27.15023639897267,-26.97351549130292,-26.796794583633186,-26.62007367596345,-26.4433527682937,-26.266631860623953,-26.08991095295423,-25.91319004528448,-25.736469137614733,-25.559748229944997,-25.383027322275268,-25.206306414605514,-25.02958550693578,-24.852864599266045,-24.676143691596295,-24.499422783926548,-24.322701876256826,-24.145980968587075,-23.96926006091733,-23.792539153247592,-23.615818245577856,-23.43909733790811,-23.262376430238376,-23.085655522568644,-22.90893461489889,-22.732213707229157,-22.55549279955942,-22.37877189188967,-22.20205098421992,-22.0253300765502,-21.84860916888045,-21.671888261210704,-21.495167353540968,-21.31844644587123,-21.141725538201484,-20.965004630531748,-20.788283722862012,-20.61156281519226,-20.43484190752253,-20.258120999852792,-20.081400092183046,-19.904679184513295,-19.72795827684356,-19.551237369173826,-19.41547108118522,-19.361614032558876,-19.30775698393253,-19.25389993530618,-19.200042886679835,-19.14618583805349,-19.092328789427143,-19.038471740800787,-18.98461469217445,-18.930757643548098,-18.87690059492175,-18.823043546295402,-18.76918649766906,-18.71532944904271,-18.661472400416365,-18.607615351790017,-18.55375830316367,-18.499901254537324,-18.44604420591098,-18.39218715728463,-18.33833010865828,-18.284473060031935,-18.230616011405587,-18.17675896277924,-18.12290191415289,-18.06904486552655,-18.015187816900198,-17.961330768273854,-17.90747371964751,-17.853616671021157,-17.799759622394806,-17.74590257376847,-17.692045525142117,-17.63818847651577,-17.58433142788942,-17.530474379263076,-17.476617330636728,-17.422760282010383,-17.36890323338404,-17.315046184757687,-17.261189136131343,-17.207332087504998,-17.153475038878646,-17.0996179902523,-17.045760941625954,-16.991903892999606,-16.938046844373254,-16.884189795746913,-16.83033274712057,-16.776475698494217,-16.722618649867872,-16.668761601241524,-16.614904552615172,-16.561047503988828,-16.507190455362487,-16.453333406736135,-16.39947635810979,-16.34561930948344,-16.291762260857094,-16.237905212230746,-16.184048163604402,-16.130191114978054,-16.077503160884973,-16.025876388515442,-15.974249616145908,-15.922622843776368,-15.87099607140683,-15.819369299037303,-15.767742526667764,-15.716115754298226,-15.664488981928692,-15.612862209559157,-15.561235437189623,-15.509608664820089,-15.457981892450553,-15.406355120081015,-15.354728347711479,-15.303101575341948,-15.251474802972412,-15.199848030602872,-15.148221258233338,-15.096594485863806,-15.044967713494268,-14.979614857097914,-14.845631580567433,-14.711648304036947,-14.577665027506468,-14.44368175097601,-14.309698474445526,-14.175715197915045,-14.041731921384587,-13.907748644854102,-13.773765368323621,-13.639782091793164,-13.505798815262681,-13.371815538732198,-13.237832262201717,-13.103848985671258,-12.969865709140775,-12.835882432610294,-12.701899156079834,-12.567915879549354,-12.43393260301887,-12.299949326488411,-12.165966049957929,-12.031982773427448,-11.89799949689699,-11.764016220366507,-11.630032943836024,-11.496049667305542,-11.362066390775084,-11.228083114244601,-11.094099837714118,-10.96011656118366,-10.826133284653178,-10.692150008122695,-10.558166731592237,-10.428982264195849,-10.301754246927937,-10.174526229660026,-10.047298212392139,-9.920070195124229,-9.792842177856315,-9.665614160588428,-9.538386143320517,-9.441601228609208,-9.36656138715262,-9.291521545696021,-9.21648170423942,-9.141441862782832,-9.06640202132623,-8.991362179869629,-8.91632233841303,-8.838867183701424,-8.758533916539848,-8.678200649378272,-8.59786738221671,-8.517534115055135,-8.437200847893559,-8.356867580731997,-8.27653431357042,-8.196201046408843,-8.115867779247267,-8.035534512085706,-7.95520124492413,-7.874867977762554,-7.794534710600993,-7.714201443439415,-7.633868176277838,-7.553534909116278,-7.473201641954702,-7.3928683747931245,-7.312535107631565,-7.232201840469988,-7.15186857330841,-7.071535306146835,-6.991202038985273,-6.910868771823698,-6.8305355046621195,-6.7502022375005595,-6.6698689703389835,-6.589535703177407,-6.509202436015845,-6.428869168854269,-6.348535901692693,-6.268202634531116,-6.187869367369554],[-41.6376269992285,-41.6820360429312,-41.7264450866339,-41.7708541303366,-41.8152631740393,-41.859672217742,-41.904081261444695,-41.9484903051474,-41.9928993488501,-42.0373083925528,-42.081717436255495,-42.126126479958195,-42.170535523660895,-42.214944567363595,-42.25935361106629,-42.303762654768995,-42.348171698471695,-42.39258074217439,-42.43698978587709,-42.48139882957979,-42.52580787328249,-42.57021691698519,-42.61462596068789,-42.65903500439059,-42.703444048093296,-42.74785309179599,-42.79226213549869,-42.836671179201396,-42.88108022290409,-42.92548926660679,-42.96989831030949,-43.01430735401219,-43.05871639771489,-43.10312544141759,-43.14753448512029,-43.19194352882299,-43.23635257252568,-43.28076161622839,-43.32517065993108,-43.36957970363379,-43.413988747336475,-43.45839779103919,-43.502806834741875,-43.54721587844459,-43.591624922147275,-43.636033965849975,-43.68044300955269,-43.724852053255375,-43.769261096958076,-43.813670140660776,-43.858079184363476,-43.902488228066176,-43.946897271768876,-43.991306315471576,-44.035715359174276,-44.080124402876976,-44.124533446579676,-44.168942490282376,-44.213351533985076,-44.257760577687776,-44.302169621390476,-44.346578665093176,-44.390987708795876,-44.435396752498576,-44.479805796201276,-44.524214839903976,-44.568623883606676,-44.613032927309376,-44.65672581291794,-44.700060621074684,-44.74339542923143,-44.78673023738816,-44.83006504554491,-44.873399853701656,-44.91673466185839,-44.960069470015135,-45.00340427817188,-45.04673908632862,-45.09007389448537,-45.13340870264211,-45.17674351079885,-45.2200783189556,-45.26341312711234,-45.30674793526908,-45.34605472582639,-45.384555912863824,-45.42305709990124,-45.461558286938676,-45.500059473976094,-45.53856066101353,-45.577061848050946,-45.61556303508837,-45.6540642221258,-45.69256540916322,-45.73106659620065,-45.769567783238074,-45.8080689702755,-45.846570157312925,-45.88507134435035,-45.92357253138778,-45.96213088427113,-46.000689237211084,-46.039247590151035,-46.077805943090986,-46.11636429603093,-46.15492264897089,-46.19348100191084,-46.23203935485079,-46.270597707790735,-46.30915606073069,-46.34771441367064,-46.386272766610595,-46.42483111955054,-46.4633894724905,-46.50194782543044,-46.5405061783704,-46.579064531310344,-46.617622884250295,-46.656181237190246,-46.6947395901302,-46.73329794307015,-46.7718562960101,-46.81041464895005,-46.84897300189,-46.88753135482995,-46.926089707769904,-46.96464806070986,-47.00320641364981,-47.04176476658976,-47.08032311952971,-47.11888147246965,-47.15743982540961,-47.195998178349555,-47.234556531289506,-47.273114884229464,-47.31167323716941,-47.35023159010936,-47.38878994304931,-47.42734829598926,-47.46590664892921,-47.504465001869164,-47.543023354809115,-47.58158170774906,-47.62014006068901,-47.65869841362896,-47.69725676656891,-47.73581511950887,-47.77437347244882,-47.812931825388766,-47.851490178328724,-47.89004853126867,-47.92860688420863,-47.96716523714857,-48.005723590088515,-48.04428194302847,-48.08284029596842,-48.121398648908375,-48.159957001848326,-48.19851535478828,-48.23707370772823,-48.27563206066817,-48.314190413608124,-48.35274876654808,-48.391307119488026,-48.429865472427984,-48.46842382536793,-48.50698217830788,-48.411932671099365,-48.25007923381663,-48.08822579653388,-47.92637235925112,-47.76451892196839,-47.60266548468563,-47.440812047402886,-47.27895861012014,-47.11710517283739,-46.955251735554654,-46.7933982982719,-46.63154486098915,-46.46969142370641,-46.307837986423664,-46.14598454914093,-45.984131111858176,-45.822277674575425,-45.66042423729267,-45.49857080000993,-45.336717362727185,-45.174863925444434,-45.01301048816169,-44.85115705087895,-44.689303613596195,-44.52745017631346,-44.365596739030714,-44.20374330174796,-44.04188986446522,-43.88003642718247,-43.718182989899724,-43.55632955261698,-43.39447611533423,-43.23262267805149,-43.07076924076873,-42.90891580348599,-42.74706236620324,-42.585208928920494,-42.42335549163776,-42.26150205435501,-42.09964861707226,-41.93779517978952,-41.76482337065654,-41.588126865276294,-41.41143035989605,-41.234733854515795,-41.05803734913555,-40.88134084375531,-40.70464433837507,-40.52794783299482,-40.35125132761456,-40.17455482223432,-39.997858316854085,-39.82116181147383,-39.64446530609358,-39.46776880071334,-39.29107229533309,-39.114375789952845,-38.937679284572596,-38.760982779192354,-38.5842862738121,-38.40758976843186,-38.23089326305161,-38.05419675767136,-37.877500252291114,-37.70080374691088,-37.52410724153063,-37.34741073615037,-37.17071423077013,-36.99401772538988,-36.817321220009646,-36.640624714629396,-36.46392820924915,-36.2872317038689,-36.11053519848865,-35.93383869310841,-35.757142187728164,-35.580445682347914,-35.403749176967665,-35.22705267158742,-35.05035616620717,-34.87365966082693,-34.69696315544668,-34.52026665006644,-34.3435701446862,-34.16687363930593,-33.9901771339257,-33.813480628545456,-33.6367841231652,-33.46008761778496,-33.283391112404715,-33.106694607024465,-32.92999810164421,-32.75330159626398,-32.57660509088373,-32.39990858550347,-32.22321208012323,-32.04651557474299,-31.869819069362734,-31.69312256398249,-31.516426058602256,-31.339729553221996,-31.163033047841758,-30.986336542461515,-30.809640037081262,-30.632943531701002,-30.456247026320778,-30.279550520940525,-30.10285401556027,-29.92615751018003,-29.749461004799787,-29.57276449941953,-29.396067994039292,-29.219371488659053,-29.042674983278793,-28.86597847789854,-28.689281972518316,-28.51258546713806,-28.335888961757803,-28.159192456377564,-27.982495950997325,-27.805799445617065,-27.629102940236827,-27.452406434856588,-27.275709929476328,-27.099013424096093,-26.92231691871585,-26.745620413335594,-26.568923907955337,-26.392227402575116,-26.21553089719486,-26.038834391814603,-25.86213788643436,-25.68544138105412,-25.508744875673862,-25.332048370293627,-25.155351864913385,-24.97865535953313,-24.801958854152872,-24.625262348772647,-24.448565843392394,-24.271869338012138,-24.095172832631896,-23.918476327251657,-23.7417798218714,-23.565083316491158,-23.388386811110916,-23.211690305730663,-23.034993800350424,-22.858297294970182,-22.68160078958993,-22.50490428420967,-22.328207778829444,-22.15151127344919,-21.97481476806893,-21.79811826268869,-21.621421757308454,-21.444725251928197,-21.268028746547955,-21.091332241167716,-20.91463573578746,-20.73793923040722,-20.56124272502698,-20.384546219646722,-20.207849714266466,-20.031153208886227,-19.85445670350599,-19.718075251340487,-19.662449256830374,-19.60840469302773,-19.554360129225074,-19.50031556542243,-19.446271001619785,-19.39222643781713,-19.33818187401448,-19.28413731021184,-19.230092746409184,-19.176048182606536,-19.122003618803888,-19.06795905500124,-19.013914491198587,-18.959869927395943,-18.905825363593294,-18.851780799790642,-18.797736235987994,-18.74369167218535,-18.689647108382697,-18.635602544580046,-18.581557980777397,-18.527513416974752,-18.4734688531721,-18.419424289369452,-18.365379725566807,-18.311335161764156,-18.257290597961507,-18.203246034158862,-18.14920147035621,-18.095156906553555,-18.041112342750914,-17.987067778948266,-17.93302321514561,-17.878978651342965,-17.82493408754032,-17.770889523737665,-17.716844959935017,-17.662800396132372,-17.60875583232972,-17.554711268527075,-17.500666704724427,-17.446622140921775,-17.392577577119123,-17.33853301331648,-17.28448844951383,-17.230443885711175,-17.17639932190853,-17.122354758105885,-17.068310194303233,-17.01426563050059,-16.96022106669794,-16.90617650289529,-16.852131939092633,-16.79808737528999,-16.74404281148734,-16.68999824768469,-16.635953683882043,-16.581909120079395,-16.527864556276747,-16.4738199924741,-16.41977542867145,-16.365730864868798,-16.311686301066153,-16.257641737263505,-16.203597173460853,-16.1495526096582,-16.09550804585556,-16.041463482052908,-15.987418918250256,-15.933374354447611,-15.879329790644961,-15.825285226842311,-15.771240663039661,-15.717196099237016,-15.663151535434364,-15.609106971631713,-15.555062407829071,-15.501017844026418,-15.446973280223768,-15.39292871642112,-15.338884152618473,-15.284839588815823,-15.216318745697054,-15.075416505997637,-14.93451426629822,-14.793612026598803,-14.652709786899411,-14.513813579864824,-14.379426364023422,-14.245039148182045,-14.110651932340646,-13.976264716499246,-13.841877500657867,-13.707490284816467,-13.573103068975067,-13.438715853133667,-13.30432863729229,-13.16994142145089,-13.035554205609488,-12.901166989768111,-12.766779773926713,-12.63239255808531,-12.498005342243935,-12.363618126402534,-12.229230910561133,-12.094843694719758,-11.960456478878356,-11.826069263036956,-11.691682047195556,-11.55729483135418,-11.422907615512777,-11.288520399671379,-11.154133183830002,-11.019745967988602,-10.885358752147201,-10.750971536305826,-10.616584320464423,-10.482197104623022,-10.347809888781622,-10.213422672940247,-10.079035457098847,-9.944648241257443,-9.810261025416068,-9.675873809574668,-9.572792816279698,-9.492073410517898,-9.411354004756081,-9.33063459899427,-9.249915193232468,-9.169195787470654,-9.088476381708837,-9.007756975947025,-8.927037570185224,-8.846318164423408,-8.765598758661593,-8.684879352899793,-8.60415994713798,-8.523440541376164,-8.442721135614363,-8.36200172985255,-8.281282324090734,-8.20056291832892,-8.119843512567119,-8.039124106805303,-7.95840470104349,-7.877685295281689,-7.796965889519875,-7.71624648375806,-7.63552707799626,-7.554807672234444,-7.47408826647263,-7.393368860710829,-7.312649454949015,-7.2319300491872,-7.151210643425385,-7.0704912376635844,-6.98977183190177,-6.909052426139954,-6.828333020378155,-6.74761361461634,-6.666894208854526,-6.581437245020068,-6.495201083229661,-6.408964921439252,-6.322728759648844,-6.236492597858452],[-41.32237854244467,-41.36678758614737,-41.41119662985007,-41.45560567355277,-41.50001471725547,-41.54442376095817,-41.58883280466087,-41.63324184836357,-41.67765089206627,-41.72205993576897,-41.76646897947167,-41.81087802317436,-41.85528706687707,-41.89969611057977,-41.94410515428246,-41.98851419798517,-42.032923241687854,-42.077332285390554,-42.12174132909326,-42.16615037279596,-42.210559416498654,-42.254968460201354,-42.29937750390406,-42.343786547606754,-42.38819559130946,-42.432604635012154,-42.477013678714854,-42.52142272241756,-42.565831766120255,-42.610240809822955,-42.654649853525655,-42.699058897228355,-42.743467940931055,-42.787876984633755,-42.832286028336455,-42.876695072039155,-42.92110411574185,-42.965513159444555,-43.009922203147255,-43.054331246849955,-43.098740290552655,-43.143149334255355,-43.18755837795805,-43.231967421660755,-43.27637646536345,-43.32078550906615,-43.365194552768855,-43.40960359647155,-43.45401264017425,-43.49842168387694,-43.54283072757965,-43.587060730783946,-43.63039553894069,-43.67373034709743,-43.717065155254176,-43.76039996341092,-43.80373477156766,-43.847069579724405,-43.89040438788115,-43.93373919603789,-43.97707400419463,-44.02040881235138,-44.06374362050812,-44.107078428664856,-44.1504132368216,-44.19374804497835,-44.237082853135085,-44.28041766129183,-44.32375246944858,-44.36708727760532,-44.41042208576206,-44.4537568939188,-44.497091702075544,-44.54042651023229,-44.58376131838903,-44.62709612654577,-44.670430934702516,-44.71376574285926,-44.757100551016,-44.800435359172745,-44.84377016732949,-44.88710497548623,-44.930439783642974,-44.97377459179971,-45.01308138235702,-45.051582569394455,-45.09008375643188,-45.128584943469306,-45.16708613050673,-45.20558731754415,-45.244088504581576,-45.282589691619,-45.32109087865643,-45.35959206569386,-45.39809325273128,-45.43659443976871,-45.47509562680613,-45.513596813843556,-45.55209800088098,-45.59059918791841,-45.62910037495583,-45.66760156199326,-45.706102749030684,-45.7446039360681,-45.78310512310553,-45.821606310142954,-45.86010749718038,-45.898608684217805,-45.93710987125524,-45.97561105829266,-46.01411224533008,-46.05261343236751,-46.091114619404934,-46.12961580644236,-46.168116993479785,-46.20661818051721,-46.24514795043987,-46.28370630337983,-46.322264656319774,-46.360823009259725,-46.39938136219968,-46.43793971513963,-46.47649806807958,-46.51505642101953,-46.55361477395948,-46.59217312689943,-46.63073147983938,-46.669289832779334,-46.70784818571928,-46.74640653865924,-46.78496489159919,-46.82352324453913,-46.86208159747909,-46.900639950419034,-46.93919830335899,-46.977756656298936,-47.016315009238895,-47.05487336217884,-47.0934317151188,-47.13199006805874,-47.17054842099869,-47.20910677393864,-47.247665126878594,-47.286223479818545,-47.3247818327585,-47.36334018569845,-47.401898538638406,-47.44045689157835,-47.479015244518294,-47.51757359745825,-47.556131950398196,-47.594690303338155,-47.6332486562781,-47.67180700921805,-47.710365362158,-47.74892371509795,-47.7874820680379,-47.826040420977854,-47.864598773917805,-47.90315712685776,-47.94171547979771,-47.98027383273766,-48.01883218567761,-48.057390538617554,-48.09594889155751,-48.13450724449746,-48.173065597437414,-48.078016090228886,-47.916162652946156,-47.754309215663405,-47.59245577838065,-47.43060234109792,-47.26874890381516,-47.10689546653242,-46.94504202924967,-46.78318859196692,-46.62133515468418,-46.45948171740143,-46.29762828011869,-46.135774842835936,-45.973921405553185,-45.81206796827045,-45.6502145309877,-45.48836109370495,-45.32650765642221,-45.16465421913946,-45.00280078185672,-44.84094734457397,-44.67909390729122,-44.51724047000849,-44.35538703272573,-44.193533595442986,-44.03168015816024,-43.86982672087749,-43.70797328359475,-43.546119846311996,-43.38426640902925,-43.22241297174651,-43.060559534463756,-42.89870609718102,-42.73685265989827,-42.57499922261552,-42.41314578533277,-42.25129234805003,-42.089438910767285,-41.92758547348454,-41.76573203620179,-41.60387859891905,-41.4420251616363,-41.28017172435355,-41.11831828707081,-40.95646484978806,-40.79461141250531,-40.63275797522257,-40.470904537939816,-40.30905110065707,-40.14719766337432,-39.98534422609157,-39.82349078880883,-39.66163735152609,-39.49978391424334,-39.337930476960594,-39.17607703967785,-39.0142236023951,-38.852370165112355,-38.69051672782961,-38.52866329054686,-38.36680985326412,-38.20495641598137,-38.04310297869863,-37.881249541415876,-37.71939610413314,-37.55754266685038,-37.39568922956764,-37.233835792284886,-37.07198235500214,-36.910128917719405,-36.748275480436654,-36.5864220431539,-36.42456860587116,-36.262715168588414,-36.10086173130567,-35.939008294022926,-35.777154856740175,-35.61530141945743,-35.45344798217468,-35.291594544891936,-35.12974110760919,-34.96788767032644,-34.80603423304369,-34.64256865782384,-34.46587215244358,-34.28917564706334,-34.112479141683096,-33.93578263630285,-33.759086130922604,-33.58238962554236,-33.405693120162105,-33.228996614781856,-33.05230010940163,-32.87560360402137,-32.69890709864111,-32.52221059326087,-32.34551408788063,-32.168817582500374,-31.99212107712014,-31.8154245717399,-31.63872806635964,-31.4620315609794,-31.285335055599163,-31.108638550218902,-30.93194204483865,-30.755245539458425,-30.57854903407817,-30.40185252869791,-30.225156023317666,-30.048459517937427,-29.871763012557174,-29.695066507176936,-29.518370001796693,-29.341673496416437,-29.164976991036184,-28.98828048565596,-28.811583980275703,-28.63488747489545,-28.458190969515208,-28.281494464134965,-28.104797958754713,-27.92810145337447,-27.75140494799423,-27.574708442613975,-27.398011937233733,-27.221315431853494,-27.044618926473234,-26.867922421092985,-26.691225915712756,-26.5145294103325,-26.337832904952247,-26.16113639957201,-25.984439894191766,-25.807743388811506,-25.631046883431267,-25.454350378051032,-25.27765387267077,-25.100957367290512,-24.92426086191029,-24.747564356530035,-24.570867851149778,-24.394171345769536,-24.217474840389297,-24.040778335009044,-23.8640818296288,-23.687385324248563,-23.510688818868307,-23.333992313488064,-23.157295808107826,-22.98059930272757,-22.803902797347313,-22.62720629196709,-22.45050978658683,-22.27381328120658,-22.097116775826336,-21.920420270446094,-21.743723765065837,-21.567027259685602,-21.39033075430536,-21.213634248925104,-21.036937743544865,-20.860241238164623,-20.683544732784366,-20.50684822740411,-20.33015172202387,-20.15345521664363,-20.01707376447813,-19.961322418742114,-19.905571073006094,-19.84981972727007,-19.794068381534053,-19.738317035798033,-19.68256569006201,-19.626814344325986,-19.571062998589973,-19.51531165285395,-19.459560307117926,-19.403808961381905,-19.348057615645892,-19.292306269909865,-19.23655492417385,-19.180803578437832,-19.125052232701805,-19.06930088696579,-19.01354954122977,-18.957798195493748,-18.902046849757724,-18.846295504021708,-18.790544158285687,-18.734792812549664,-18.679041466813647,-18.623290121077627,-18.567538775341603,-18.511787429605583,-18.45603608386957,-18.400284738133543,-18.344533392397523,-18.28878204666151,-18.233030700925482,-18.177279355189462,-18.123085322165085,-18.06904075836244,-18.014996194559792,-17.960951630757144,-17.906907066954496,-17.852862503151844,-17.7988179393492,-17.74477337554655,-17.6907288117439,-17.636684247941247,-17.5826396841386,-17.52859512033595,-17.474550556533302,-17.420505992730654,-17.366461428928005,-17.312416865125357,-17.25837230132271,-17.20432773752006,-17.150283173717412,-17.09623860991476,-17.042194046112115,-16.988149482309467,-16.93410491850681,-16.880060354704167,-16.82601579090152,-16.771971227098867,-16.71792666329622,-16.663882099493573,-16.60983753569092,-16.555792971888273,-16.50174840808563,-16.447703844282977,-16.393659280480325,-16.339614716677684,-16.28557015287503,-16.23152558907238,-16.17748102526973,-16.123436461467087,-16.069391897664435,-16.015347333861786,-15.96130277005914,-15.907258206256486,-15.853213642453836,-15.799169078651193,-15.745124514848541,-15.691079951045891,-15.637035387243245,-15.582990823440596,-15.528946259637944,-15.460425416519175,-15.31952317681976,-15.178620937120344,-15.037718697420926,-14.896816457721537,-14.75591421802212,-14.615011978322702,-14.474109738623312,-14.333207498923896,-14.192305259224481,-14.051403019525091,-13.910500779825673,-13.76959854012626,-13.628696300426842,-13.487794060727452,-13.346891821028036,-13.205989581328618,-13.06508734162923,-12.924185101929812,-12.783282862230397,-12.642380622531007,-12.502959901574046,-12.368572685732646,-12.23418546989127,-12.099798254049869,-11.965411038208469,-11.831023822367069,-11.696636606525692,-11.562249390684292,-11.42786217484289,-11.293474959001514,-11.159087743160114,-11.024700527318714,-10.890313311477339,-10.755926095635937,-10.621538879794535,-10.487151663953135,-10.35276444811176,-10.218377232270358,-10.083990016428958,-9.94960280058758,-9.81521558474618,-9.71213459145121,-9.63141518568941,-9.550695779927594,-9.46997637416578,-9.38925696840398,-9.308537562642165,-9.227818156880351,-9.147098751118536,-9.066379345356737,-8.985659939594921,-8.904940533833106,-8.824221128071306,-8.74350172230949,-8.662782316547677,-8.582062910785877,-8.501343505024062,-8.420624099262247,-8.339904693500431,-8.259185287738632,-8.178465881976818,-8.097746476215,-8.011845367369512,-7.925609205579104,-7.839373043788695,-7.753136881998303,-7.666900720207895,-7.580664558417487,-7.494428396627094,-7.408192234836687,-7.3219560730462785,-7.235719911255871,-7.149483749465478,-7.06324758767507,-6.977011425884663,-6.89077526409427,-6.8045391023038615,-6.718302940513453,-6.632066778723061,-6.545830616932655,-6.459594455142245,-6.373358293351838,-6.287122131561446],[-41.00713008566083,-41.05153912936353,-41.09594817306623,-41.14035721676893,-41.18476626047163,-41.22917530417433,-41.27358434787703,-41.31799339157973,-41.36240243528243,-41.406811478985134,-41.451220522687834,-41.49562956639053,-41.540038610093234,-41.58444765379593,-41.628856697498634,-41.67326574120133,-41.71767478490402,-41.76208382860673,-41.80649287230943,-41.85090191601213,-41.89531095971482,-41.93972000341753,-41.98412904712022,-42.02853809082292,-42.07294713452562,-42.11735617822832,-42.16176522193102,-42.20617426563372,-42.25058330933642,-42.29499235303912,-42.33940139674182,-42.38381044044452,-42.42821948414722,-42.47262852784992,-42.51703757155262,-42.56073045680668,-42.60406526496343,-42.647400073120174,-42.69073488127692,-42.73406968943366,-42.777404497590396,-42.82073930574715,-42.86407411390388,-42.90740892206063,-42.950743730217376,-42.99407853837411,-43.03741334653086,-43.0807481546876,-43.12408296284434,-43.16741777100109,-43.21075257915783,-43.25408738731457,-43.29742219547131,-43.340757003628056,-43.3840918117848,-43.42742661994154,-43.47076142809829,-43.51409623625503,-43.55743104441177,-43.600765852568514,-43.64410066072526,-43.687435468882,-43.730770277038744,-43.77410508519549,-43.81743989335223,-43.860774701508966,-43.904109509665716,-43.94744431782246,-43.9907791259792,-44.034113934135945,-44.07744874229269,-44.120783550449424,-44.164118358606174,-44.20745316676292,-44.25078797491966,-44.2941227830764,-44.33745759123314,-44.38079239938989,-44.42412720754663,-44.467462015703376,-44.51079682386011,-44.55413163201686,-44.597466440173605,-44.64080124833035,-44.68010803888765,-44.71860922592508,-44.757110412962504,-44.79561159999994,-44.834112787037355,-44.87261397407478,-44.91111516111221,-44.94961634814963,-44.98811753518706,-45.02661872222448,-45.06511990926191,-45.103621096299335,-45.14212228333676,-45.180623470374194,-45.21912465741161,-45.25762584444903,-45.29612703148646,-45.33462821852388,-45.37312940556131,-45.41163059259874,-45.450131779636166,-45.488632966673585,-45.52713415371102,-45.56563534074844,-45.60413652778587,-45.642637714823294,-45.68113890186071,-45.719640088898146,-45.75814127593557,-45.796642462973,-45.83514365001042,-45.873644837047834,-45.912146024085274,-45.95064721112269,-45.98914839816011,-46.02764958519755,-46.06615077223496,-46.104651959272395,-46.14315314630983,-46.18165433334724,-46.22015552038467,-46.2586567074221,-46.297157894459524,-46.33565908149695,-46.37416026853437,-46.4126614555718,-46.451162642609226,-46.48966382964665,-46.52816501668408,-46.56672336954856,-46.60528172248851,-46.64384007542846,-46.682398428368415,-46.72095678130836,-46.75951513424832,-46.79807348718827,-46.83663184012822,-46.875190193068164,-46.91374854600812,-46.952306898948066,-46.990865251888025,-47.02942360482797,-47.06798195776793,-47.106540310707885,-47.14509866364783,-47.18365701658779,-47.22221536952773,-47.26077372246768,-47.29933207540763,-47.33789042834758,-47.37644878128753,-47.41500713422748,-47.453565487167424,-47.49212384010738,-47.530682193047326,-47.569240545987284,-47.60779889892723,-47.64635725186719,-47.68491560480713,-47.72347395774708,-47.76203231068703,-47.800590663626984,-47.839149016566935,-47.74409950935842,-47.58224607207568,-47.420392634792925,-47.25853919751019,-47.096685760227444,-46.934832322944686,-46.77297888566194,-46.6111254483792,-46.449272011096454,-46.28741857381371,-46.12556513653095,-45.963711699248215,-45.801858261965464,-45.64000482468272,-45.478151387399976,-45.316297950117225,-45.15444451283448,-44.992591075551736,-44.830737638268985,-44.66888420098625,-44.5070307637035,-44.34517732642075,-44.18332388913801,-44.02147045185525,-43.859617014572514,-43.69776357728976,-43.53591014000702,-43.374056702724275,-43.212203265441524,-43.05034982815879,-42.88849639087603,-42.726642953593284,-42.56478951631055,-42.402936079027796,-42.24108264174505,-42.079229204462294,-41.91737576717956,-41.75552232989682,-41.59366889261406,-41.43181545533132,-41.269962018048574,-41.10810858076583,-40.94625514348308,-40.78440170620034,-40.62254826891758,-40.46069483163484,-40.298841394352095,-40.13698795706935,-39.9751345197866,-39.81328108250385,-39.651427645221105,-39.48957420793836,-39.32772077065562,-39.165867333372866,-39.00401389609012,-38.84216045880738,-38.680307021524634,-38.51845358424188,-38.35660014695914,-38.19474670967639,-38.03289327239365,-37.8710398351109,-37.70918639782815,-37.547332960545404,-37.38547952326267,-37.223626085979916,-37.06177264869717,-36.89991921141442,-36.73806577413167,-36.57621233684893,-36.41435889956619,-36.25250546228344,-36.090652025000686,-35.92879858771794,-35.7669451504352,-35.60509171315245,-35.4432382758697,-35.28138483858696,-35.119531401304215,-34.95767796402147,-34.79582452673872,-34.63397108945597,-34.47211765217322,-34.31026421489049,-34.14841077760773,-33.986557340324985,-33.82470390304225,-33.6628504657595,-33.500997028476746,-33.339143591194016,-33.17729015391126,-33.0154367166285,-32.85358327934578,-32.69172984206302,-32.52987640478026,-32.368022967497524,-32.20616953021479,-32.04431609293203,-31.882462655649284,-31.720609218366548,-31.55875578108379,-31.396902343801052,-31.235048906518315,-31.073195469235557,-30.9113420319528,-30.749488594670073,-30.587635157387318,-30.425781720104563,-30.263928282821823,-30.102074845539082,-29.940221408256328,-29.778367970973587,-29.616514533690847,-29.45466109640809,-29.292807659125334,-29.130954221842607,-28.969100784559856,-28.807247347277098,-28.64539390999436,-28.48354047271162,-28.321687035428866,-28.159833598146122,-27.99798016086338,-27.836126723580627,-27.674273286297886,-27.51241984901515,-27.34361743961088,-27.166920934230625,-26.9902244288504,-26.813527923470144,-26.63683141808989,-26.46013491270965,-26.28343840732941,-26.10674190194915,-25.930045396568907,-25.753348891188672,-25.576652385808412,-25.39995588042816,-25.22325937504793,-25.046562869667678,-24.86986636428742,-24.693169858907183,-24.516473353526944,-24.339776848146688,-24.163080342766445,-23.986383837386207,-23.80968733200595,-23.63299082662571,-23.45629432124547,-23.27959781586521,-23.102901310484956,-22.926204805104735,-22.749508299724475,-22.572811794344222,-22.39611528896398,-22.21941878358374,-22.042722278203485,-21.866025772823242,-21.689329267443,-21.512632762062747,-21.33593625668251,-21.159239751302266,-20.98254324592201,-20.805846740541753,-20.629150235161514,-20.452453729781272,-20.31607227761577,-20.260320931879754,-20.204569586143737,-20.148818240407714,-20.093066894671693,-20.037315548935677,-19.981564203199653,-19.92581285746363,-19.870061511727616,-19.814310165991593,-19.75855882025557,-19.702807474519552,-19.647056128783532,-19.59130478304751,-19.535553437311492,-19.479802091575472,-19.42405074583945,-19.36829940010343,-19.312548054367415,-19.25679670863139,-19.201045362895368,-19.145294017159348,-19.08954267142333,-19.033791325687307,-18.97803997995129,-18.92228863421527,-18.866537288479247,-18.81078594274323,-18.75503459700721,-18.69928325127119,-18.643531905535163,-18.58778055979915,-18.532029214063126,-18.476277868327102,-18.420526522591086,-18.36477517685507,-18.309023831119045,-18.253272485383025,-18.19752113964701,-18.141769793910985,-18.086018448174965,-18.03026710243895,-17.97451575670292,-17.9187644109669,-17.86301306523088,-17.807261719494864,-17.75151037375884,-17.69575902802282,-17.640007682286804,-17.58425633655078,-17.528504990814763,-17.472753645078743,-17.41700229934272,-17.3612509536067,-17.305499607870683,-17.24974826213466,-17.19399691639864,-17.13824557066262,-17.0824942249266,-17.02674287919058,-16.97099153345456,-16.91524018771854,-16.859488841982518,-16.803737496246498,-16.74798615051048,-16.692234804774458,-16.63776595130245,-16.583721387499807,-16.52967682369715,-16.475632259894503,-16.421587696091855,-16.367543132289207,-16.313498568486555,-16.25945400468391,-16.20540944088126,-16.15136487707861,-16.097320313275958,-16.043275749473317,-15.989231185670665,-15.935186621868015,-15.881142058065366,-15.827097494262718,-15.773052930460068,-15.704532087341299,-15.563629847641883,-15.422727607942464,-15.28182536824305,-15.14092312854366,-15.000020888844242,-14.859118649144825,-14.718216409445434,-14.577314169746021,-14.436411930046603,-14.295509690347213,-14.154607450647799,-14.01370521094838,-13.872802971248966,-13.731900731549574,-13.59099849185016,-13.450096252150741,-13.309194012451352,-13.168291772751935,-13.02738953305252,-12.886487293353127,-12.745585053653713,-12.604682813954296,-12.463780574254907,-12.32287833455549,-12.181976094856076,-12.041073855156657,-11.900171615457268,-11.75926937575785,-11.618367136058433,-11.477464896359045,-11.336562656659627,-11.195660416960212,-11.054758177260823,-10.913855937561406,-10.77295369786199,-10.632051458162573,-10.492106223283272,-10.357719007441872,-10.223331791600472,-10.088944575759095,-9.954557359917693,-9.851476366622723,-9.770756960860924,-9.690037555099108,-9.609318149337293,-9.528489651509362,-9.442253489718954,-9.356017327928546,-9.269781166138138,-9.183545004347746,-9.09730884255734,-9.01107268076693,-8.924836518976537,-8.83860035718613,-8.752364195395721,-8.666128033605329,-8.579891871814922,-8.493655710024514,-8.407419548234104,-8.321183386443712,-8.234947224653304,-8.148711062862898,-8.062474901072505,-7.976238739282097,-7.890002577491689,-7.803766415701297,-7.717530253910889,-7.631294092120481,-7.545057930330088,-7.45882176853968,-7.372585606749272,-7.286349444958864,-7.200113283168472,-7.113877121378064,-7.027640959587656,-6.941404797797263,-6.855168636006855,-6.768932474216448,-6.682696312426056,-6.5964601506356475,-6.510223988845239,-6.423987827054831,-6.337751665264439],[-40.691881628877006,-40.736290672579706,-40.7806997162824,-40.8251087599851,-40.869517803687806,-40.9139268473905,-40.9583358910932,-41.0027449347959,-41.0471539784986,-41.0915630222013,-41.135972065904,-41.1803811096067,-41.2247901533094,-41.2691991970121,-41.3136082407148,-41.3580172844175,-41.4024263281202,-41.4468353718229,-41.4910653746727,-41.534400182829444,-41.57773499098619,-41.62106979914293,-41.66440460729967,-41.707739415456416,-41.75107422361316,-41.794409031769895,-41.837743839926645,-41.88107864808339,-41.92441345624013,-41.967748264396874,-42.01108307255361,-42.05441788071035,-42.0977526888671,-42.14108749702385,-42.18442230518059,-42.22775711333732,-42.271091921494076,-42.31442672965081,-42.357761537807555,-42.40109634596429,-42.444431154121034,-42.487765962277784,-42.53110077043452,-42.57443557859127,-42.617770386748006,-42.66110519490475,-42.70444000306149,-42.747774811218235,-42.79110961937498,-42.83444442753172,-42.877779235688465,-42.92111404384521,-42.96444885200195,-43.007783660158694,-43.05111846831544,-43.09445327647218,-43.13778808462892,-43.181122892785666,-43.22445770094241,-43.26779250909915,-43.311127317255895,-43.35446212541264,-43.39779693356939,-43.44113174172612,-43.48446654988287,-43.52780135803961,-43.571136166196354,-43.6144709743531,-43.65780578250984,-43.701140590666576,-43.74447539882332,-43.78781020698006,-43.83114501513681,-43.874479823293555,-43.9178146314503,-43.961149439607034,-44.00448424776378,-44.04781905592052,-44.09115386407726,-44.13448867223401,-44.17782348039075,-44.22115828854749,-44.264493096704236,-44.30782790486098,-44.34713469541829,-44.385635882455716,-44.42413706949314,-44.46263825653057,-44.50113944356799,-44.53964063060542,-44.578141817642845,-44.61664300468027,-44.65514419171769,-44.693645378755114,-44.73214656579255,-44.77064775282997,-44.8091489398674,-44.847650126904824,-44.88615131394225,-44.92465250097967,-44.9631536880171,-45.00165487505452,-45.040156062091945,-45.07865724912938,-45.1171584361668,-45.15565962320422,-45.194160810241655,-45.23266199727908,-45.27116318431651,-45.30966437135393,-45.34816555839135,-45.386666745428776,-45.42516793246621,-45.463669119503635,-45.50217030654106,-45.54067149357847,-45.57917268061591,-45.61767386765333,-45.65617505469075,-45.69467624172818,-45.7331774287656,-45.77167861580303,-45.81017980284046,-45.84868098987788,-45.88718217691531,-45.92568336395273,-45.96418455099016,-46.00268573802758,-46.041186925065006,-46.07968811210244,-46.11818929913986,-46.15669048617729,-46.19519167321471,-46.233692860252134,-46.27219404728956,-46.31069523432698,-46.34919642136441,-46.38769760840183,-46.42619879543926,-46.46469998247669,-46.50320116951411,-46.54170235655154,-46.58020354358895,-46.61870473062638,-46.65720591766381,-46.695707104701235,-46.73420829173867,-46.772709478776086,-46.81121066581351,-46.84974043571732,-46.888298788657266,-46.92685714159722,-46.96541549453716,-47.00397384747711,-47.042532200417064,-47.081090553357015,-47.119648906296966,-47.15820725923692,-47.19676561217687,-47.23532396511682,-47.27388231805677,-47.31244067099672,-47.35099902393667,-47.389557376876624,-47.42811572981657,-47.466674082756526,-47.50523243569647,-47.410182928487956,-47.24832949120521,-47.08647605392247,-46.92462261663972,-46.76276917935698,-46.60091574207422,-46.439062304791484,-46.27720886750873,-46.11535543022599,-45.953501992943245,-45.791648555660494,-45.62979511837776,-45.46794168109499,-45.306088243812255,-45.14423480652951,-44.98238136924676,-44.820527931964016,-44.65867449468127,-44.49682105739852,-44.334967620115776,-44.17311418283304,-44.01126074555029,-43.849407308267544,-43.68755387098479,-43.525700433702056,-43.3638469964193,-43.201993559136554,-43.04014012185381,-42.87828668457106,-42.71643324728832,-42.55457981000557,-42.39272637272282,-42.23087293544008,-42.06901949815733,-41.90716606087459,-41.745312623591836,-41.583459186309085,-41.42160574902635,-41.2597523117436,-41.09789887446085,-40.936045437178116,-40.774191999895365,-40.612338562612614,-40.45048512532987,-40.28863168804712,-40.126778250764374,-39.96492481348163,-39.803071376198886,-39.64121793891614,-39.47936450163339,-39.31751106435064,-39.155657627067896,-38.99380418978515,-38.83195075250241,-38.67009731521966,-38.50824387793692,-38.34639044065417,-38.18453700337142,-38.02268356608867,-37.86083012880592,-37.698976691523185,-37.537123254240434,-37.37526981695768,-37.21341637967494,-37.0515629423922,-36.88970950510945,-36.72785606782671,-36.566002630543956,-36.404149193261205,-36.24229575597847,-36.08044231869572,-35.91858888141297,-35.75673544413022,-35.59488200684748,-35.43302856956474,-35.27117513228198,-35.10932169499924,-34.947468257716494,-34.78561482043375,-34.623761383151,-34.46190794586826,-34.300054508585504,-34.13820107130276,-33.976347634020016,-33.814494196737265,-33.65264075945453,-33.490787322171784,-33.328933884889025,-33.16708044760629,-33.00522701032355,-32.84337357304079,-32.681520135758035,-32.51966669847531,-32.357813261192554,-32.1959598239098,-32.03410638662706,-31.872252949344322,-31.710399512061564,-31.54854607477882,-31.386692637496083,-31.22483920021333,-31.062985762930587,-30.901132325647847,-30.739278888365092,-30.577425451082338,-30.41557201379961,-30.253718576516853,-30.091865139234102,-29.930011701951358,-29.76815826466862,-29.606304827385863,-29.444451390103122,-29.282597952820385,-29.120744515537627,-28.958891078254872,-28.79703764097215,-28.63518420368939,-28.473330766406633,-28.311477329123896,-28.149623891841156,-27.987770454558397,-27.82591701727566,-27.66406357999292,-27.50221014271016,-27.340356705427425,-27.17850326814468,-27.01664983086193,-26.85479639357917,-26.692942956296445,-26.53108951901369,-26.369236081730936,-26.207382644448195,-26.04552920716545,-25.8836757698827,-25.721822332599956,-25.559968895317215,-25.39811545803446,-25.236262020751706,-25.07440858346898,-24.912555146186225,-24.75070170890347,-24.588848271620726,-24.426994834337986,-24.265141397055235,-24.103287959772494,-23.941434522489754,-23.779581085207,-23.61772764792426,-23.455874210641518,-23.29402077335876,-23.132167336076,-22.97031389879328,-22.808460461510524,-22.646607024227766,-22.48475358694503,-22.32290014966229,-22.16104671237953,-21.99919327509679,-21.858621147260116,-21.720146993572524,-21.581672839884945,-21.44319868619736,-21.304724532509763,-21.166250378822173,-20.970533572836107,-20.76821198398587,-20.614290385363983,-20.55716876719879,-20.500443498816967,-20.444479916190282,-20.388516333563604,-20.332552750936927,-20.27658916831024,-20.220625585683557,-20.164662003056883,-20.1086984204302,-20.052734837803516,-19.99677125517684,-19.940807672550157,-19.884844089923476,-19.828880507296795,-19.772916924670117,-19.716953342043432,-19.660989759416754,-19.605026176790073,-19.549062594163395,-19.493099011536707,-19.437135428910032,-19.38117184628335,-19.325208263656666,-19.26924468102999,-19.213281098403307,-19.157317515776626,-19.101353933149944,-19.04539035052327,-18.989426767896582,-18.9334631852699,-18.877499602643223,-18.821536020016545,-18.76557243738986,-18.709608854763182,-18.6536452721365,-18.59768168950982,-18.54171810688314,-18.48575452425646,-18.429790941629776,-18.373827359003098,-18.317863776376416,-18.26190019374973,-18.20593661112305,-18.14997302849637,-18.094009445869695,-18.038045863243006,-17.98208228061633,-17.92611869798965,-17.87015511536297,-17.814191532736288,-17.75822795010961,-17.702264367482925,-17.64630078485624,-17.590337202229566,-17.534373619602885,-17.4784100369762,-17.422446454349522,-17.366482871722845,-17.31051928909616,-17.25455570646948,-17.1985921238428,-17.142628541216116,-17.086664958589438,-17.03070137596276,-16.974737793336075,-16.918774210709394,-16.862810628082716,-16.806847045456035,-16.75088346282935,-16.694919880202672,-16.638956297575994,-16.58299271494931,-16.52702913232263,-16.47106554969595,-16.41510196706927,-16.359138384442584,-16.30317480181591,-16.247211219189225,-16.19124763656254,-16.135284053935866,-16.079320471309185,-16.023356888682503,-15.952081037685959,-15.804243844840077,-15.656406651994192,-15.508569459148307,-15.360732266302447,-15.212895073456563,-15.065057880610677,-14.91722068776482,-14.773327432477311,-14.631822770326197,-14.490318108175105,-14.348813446023991,-14.207308783872875,-14.065804121721762,-13.924299459570673,-13.782794797419557,-13.641290135268441,-13.499785473117353,-13.358280810966239,-13.216776148815125,-13.075271486664036,-12.93376682451292,-12.792262162361805,-12.650757500210716,-12.5092528380596,-12.367748175908485,-12.226243513757371,-12.084738851606282,-11.943234189455167,-11.801729527304051,-11.660224865152962,-11.518720203001847,-11.377215540850733,-11.235710878699642,-11.094206216548528,-10.95270155439741,-10.811196892246297,-10.669692230095208,-10.528187567944094,-10.386682905792977,-10.245178243641888,-10.103673581490774,-9.994046541455688,-9.907189231503489,-9.820331921551274,-9.733474611599059,-9.64661730164686,-9.559759991694646,-9.472902681742429,-9.386045371790212,-9.299188061838016,-9.2123307518858,-9.125473441933584,-9.038616131981385,-8.95175882202917,-8.864901512076955,-8.778044202124754,-8.69118689217254,-8.604329582220325,-8.51747227226811,-8.43061496231591,-8.343757652363696,-8.25690034241148,-8.170043032459281,-8.083185722507068,-7.996328412554851,-7.909471102602652,-7.822613792650436,-7.735756482698221,-7.648899172746021,-7.562041862793807,-7.475184552841592,-7.388327242889376,-7.301469932937177,-7.214612622984962,-7.127755313032746,-7.037785736421382,-6.945205883270655,-6.852626030119929,-6.760046176969219,-6.667466323818493,-6.5748864706677645,-6.482306617517038,-6.389726764366328],[-40.37663317209317,-40.42104221579587,-40.46473510069544,-40.50806990885219,-40.55140471700893,-40.59473952516567,-40.63807433332242,-40.68140914147916,-40.724743949635894,-40.768078757792644,-40.81141356594939,-40.85474837410613,-40.89808318226287,-40.941417990419616,-40.98475279857636,-41.028087606733095,-41.071422414889845,-41.11475722304658,-41.158092031203324,-41.201426839360074,-41.24476164751681,-41.28809645567355,-41.331431263830304,-41.37476607198704,-41.41810088014378,-41.461435688300526,-41.50477049645727,-41.54810530461401,-41.591440112770755,-41.6347749209275,-41.67810972908424,-41.721444537240984,-41.76477934539773,-41.80811415355447,-41.85144896171121,-41.894783769867956,-41.9381185780247,-41.98145338618144,-42.024788194338186,-42.06812300249493,-42.11145781065167,-42.154792618808415,-42.19812742696516,-42.2414622351219,-42.284797043278644,-42.32813185143539,-42.37146665959213,-42.41480146774887,-42.45813627590561,-42.50147108406236,-42.544805892219095,-42.588140700375845,-42.63147550853258,-42.674810316689324,-42.71814512484607,-42.76147993300281,-42.80481474115956,-42.8481495493163,-42.89148435747304,-42.934819165629776,-42.97815397378652,-43.02148878194327,-43.06482359010001,-43.10815839825675,-43.1514932064135,-43.19482801457024,-43.23816282272698,-43.28149763088373,-43.32483243904047,-43.36816724719721,-43.41150205535395,-43.4548368635107,-43.498171671667436,-43.54150647982418,-43.58484128798092,-43.62817609613767,-43.67151090429441,-43.71484571245115,-43.758180520607894,-43.80151532876464,-43.84485013692139,-43.88818494507812,-43.931519753234866,-43.97485456139161,-44.01416135194892,-44.05266253898635,-44.09116372602377,-44.12966491306119,-44.16816610009862,-44.20666728713604,-44.24516847417347,-44.2836696612109,-44.32217084824833,-44.360672035285745,-44.39917322232318,-44.437674409360596,-44.47617559639802,-44.51467678343545,-44.55317797047288,-44.5916791575103,-44.63018034454773,-44.66868153158515,-44.707182718622576,-44.74568390566,-44.78418509269743,-44.82268627973485,-44.86118746677228,-44.899688653809704,-44.93818984084713,-44.976691027884556,-45.01519221492198,-45.05369340195941,-45.09219458899683,-45.13069577603426,-45.169196963071684,-45.20769815010911,-45.246199337146535,-45.28470052418396,-45.32320171122138,-45.36170289825881,-45.40020408529623,-45.438705272333664,-45.47720645937108,-45.51570764640851,-45.55420883344594,-45.59271002048336,-45.63121120752079,-45.66971239455821,-45.70821358159564,-45.74671476863307,-45.78521595567049,-45.82371714270792,-45.86221832974534,-45.900719516782765,-45.93922070382019,-45.97772189085761,-46.01622307789505,-46.05472426493247,-46.0932254519699,-46.13172663900732,-46.170227826044744,-46.20872901308217,-46.24723020011959,-46.285731387157014,-46.32423257419445,-46.36273376123187,-46.4012349482693,-46.43973613530672,-46.47823732234415,-46.516738509381575,-46.555239696418994,-46.59374088345643,-46.63224207049385,-46.67074325753128,-46.7092444445687,-46.74774563160612,-46.78624681864355,-46.82474800568098,-46.8632491927184,-46.90175037975583,-46.94025156679326,-46.978752753830676,-47.0172539408681,-47.05575512790553,-47.094256314942946,-47.13275750198038,-47.171315854826005,-47.076266347617484,-46.91441291033475,-46.752559473051996,-46.590706035769244,-46.42885259848651,-46.26699916120375,-46.10514572392101,-45.94329228663827,-45.78143884935551,-45.61958541207277,-45.45773197479002,-45.29587853750728,-45.154407370516765,-45.01593321682917,-44.87745906314159,-44.73898490945401,-44.60051075576642,-44.46203660207883,-44.323562448391236,-44.18508829470366,-44.04661414101608,-43.90813998732848,-43.769665833640914,-43.63119167995332,-43.492717526265736,-43.354243372578146,-43.215769218890564,-43.07729506520298,-42.93882091151539,-42.80034675782781,-42.66187260414023,-42.52339845045264,-42.38492429676505,-42.24645014307747,-42.10797598938988,-41.96950183570229,-41.8310276820147,-41.692553528327124,-41.55407937463954,-41.41560522095195,-41.27713106726437,-41.13865691357679,-41.00018275988919,-40.86170860620162,-40.72323445251402,-40.58476029882644,-40.44628614513886,-40.307811991451274,-40.16933783776368,-40.030863684076095,-39.89238953038851,-39.75391537670093,-39.61544122301334,-39.47696706932575,-39.33849291563817,-39.20001876195059,-39.061544608263,-38.92307045457541,-38.78459630088782,-38.64612214720024,-38.50764799351266,-38.36917383982507,-38.230699686137484,-38.092225532449895,-37.95375137876232,-37.81527722507472,-37.67680307138714,-37.53832891769956,-37.39985476401198,-37.261380610324395,-37.1229064566368,-36.984432302949216,-36.845958149261634,-36.707483995574044,-36.569009841886455,-36.43053568819887,-36.29206153451129,-36.1535873808237,-36.01511322713612,-35.87663907344853,-35.73816491976095,-35.59969076607336,-35.46121661238577,-35.322742458698194,-35.1842683050106,-35.04579415132302,-34.90731999763544,-34.768845843947844,-34.63037169026026,-34.49189753657269,-34.35342338288509,-34.214949229197494,-34.07647507550993,-33.938000921822336,-33.79952676813475,-33.66105261444716,-33.52257846075958,-33.384104307071986,-33.24563015338441,-33.10715599969683,-32.96868184600923,-32.83020769232165,-32.69173353863407,-32.55325938494648,-32.41478523125889,-32.27631107757132,-32.137836923883725,-31.99936277019613,-31.860888616508554,-31.722414462820968,-31.583940309133375,-31.445466155445793,-31.306992001758218,-31.16851784807062,-31.03004369438303,-30.891569540695468,-30.753095387007875,-30.614621233320275,-30.476147079632696,-30.337672925945114,-30.16617417983274,-29.963852590982498,-29.761531002132266,-29.559209413282012,-29.356887824431773,-29.154566235581534,-28.95224464673128,-28.749923057881027,-28.54760146903081,-28.345279880180552,-28.1429582913303,-27.94063670248006,-27.738315113629824,-27.53599352477957,-27.33367193592933,-27.131350347079096,-26.92902875822884,-26.726707169378585,-26.524385580528367,-26.322063991678114,-26.11974240282786,-25.91742081397762,-25.71509922512739,-25.51277763627713,-25.310456047426893,-25.108134458576657,-24.9058128697264,-24.703491280876168,-24.50116969202593,-24.29884810317568,-24.096526514325422,-23.894204925475204,-23.691883336624947,-23.489561747774694,-23.287240158924458,-23.08491857007422,-22.882596981223962,-22.68027539237373,-22.47795380352349,-22.275632214673237,-22.073310625822998,-21.870989036972766,-21.66866744812251,-21.466345859272252,-21.26402427042202,-21.061702681571784,-20.90778108294989,-20.850659464784698,-20.793537846619504,-20.736416228454306,-20.67929461028911,-20.622172992123918,-20.56505137395872,-20.50792975579352,-20.45080813762833,-20.39368651946313,-20.336564901297933,-20.27944328313274,-20.222321664967545,-20.165200046802347,-20.108078428637157,-20.05095681047196,-19.99383519230676,-19.93671357414157,-19.879591955976377,-19.822470337811176,-19.765348719645978,-19.708227101480787,-19.65110548331559,-19.593983865150392,-19.536862246985198,-19.479740628820007,-19.422619010654806,-19.365497392489612,-19.308375774324418,-19.25125415615922,-19.194132537994022,-19.137010919828832,-19.079889301663634,-19.022767683498436,-18.965646065333242,-18.90852444716805,-18.851933596007868,-18.795970013381186,-18.74000643075451,-18.684042848127824,-18.62807926550115,-18.57211568287447,-18.516152100247783,-18.4601885176211,-18.404224934994424,-18.348261352367743,-18.292297769741058,-18.23633418711438,-18.180370604487702,-18.124407021861018,-18.06844343923434,-18.012479856607662,-17.956516273980977,-17.900552691354292,-17.844589108727618,-17.788625526100937,-17.732661943474252,-17.676698360847574,-17.620734778220893,-17.56477119559421,-17.50880761296753,-17.452844030340852,-17.396880447714167,-17.34091686508749,-17.284953282460812,-17.228989699834127,-17.173026117207442,-17.117062534580768,-17.061098951954087,-17.0051353693274,-16.949171786700724,-16.893208204074043,-16.83724462144736,-16.78128103882068,-16.725317456194002,-16.669353873567317,-16.613390290940636,-16.55742670831396,-16.501463125687277,-16.445499543060592,-16.389535960433914,-16.333572377807236,-16.27760879518055,-16.206332944184012,-16.05849575133813,-15.910658558492242,-15.762821365646358,-15.6149841728005,-15.467146979954615,-15.319309787108727,-15.171472594262871,-15.023635401416984,-14.875798208571098,-14.727961015725242,-14.580123822879356,-14.432286630033474,-14.28444943718759,-14.136612244341729,-13.988775051495846,-13.840937858649959,-13.693100665804101,-13.545263472958215,-13.39742628011233,-13.249589087266472,-13.101751894420588,-12.953914701574702,-12.806077508728844,-12.65824031588296,-12.516596779885573,-12.375092117734459,-12.233587455583368,-12.092082793432255,-11.950578131281139,-11.80907346913005,-11.667568806978936,-11.52606414482782,-11.38455948267673,-11.243054820525614,-11.1015501583745,-10.960045496223387,-10.818540834072298,-10.67703617192118,-10.535531509770067,-10.394026847618976,-10.252522185467862,-10.142895145432776,-10.056037835480577,-9.969180525528362,-9.882323215576147,-9.795465905623947,-9.708608595671732,-9.621751285719517,-9.534893975767302,-9.448036665815103,-9.361179355862888,-9.274322045910672,-9.187464735958473,-9.100607426006258,-9.013750116054043,-8.926892806101844,-8.840035496149628,-8.753178186197413,-8.665241622364459,-8.572661769213749,-8.480081916063023,-8.387502062912297,-8.294922209761586,-8.20234235661086,-8.109762503460132,-8.017182650309422,-7.924602797158696,-7.832022944007968,-7.739443090857259,-7.6468632377065315,-7.554283384555804,-7.461703531405077,-7.369123678254368,-7.276543825103641,-7.183963971952913,-7.091384118802204,-6.998804265651477,-6.90622441250075,-6.81364455935004,-6.721064706199314,-6.628484853048587,-6.535904999897859,-6.443325146747149],[-40.04727471579146,-40.0906095239482,-40.13394433210494,-40.17727914026168,-40.220613948418425,-40.263948756575175,-40.30728356473191,-40.350618372888654,-40.3939531810454,-40.43728798920214,-40.48062279735889,-40.523957605515626,-40.56729241367237,-40.61062722182911,-40.653962029985856,-40.6972968381426,-40.74063164629934,-40.783966454456085,-40.82730126261282,-40.87063607076957,-40.91397087892631,-40.95730568708306,-41.00064049523979,-41.043975303396536,-41.08731011155328,-41.13064491971002,-41.173979727866765,-41.21731453602351,-41.26064934418025,-41.303984152336994,-41.34731896049374,-41.39065376865048,-41.433988576807224,-41.47732338496397,-41.52065819312071,-41.56399300127745,-41.607327809434196,-41.65066261759094,-41.69399742574768,-41.737332233904425,-41.78066704206117,-41.82400185021791,-41.867336658374654,-41.9106714665314,-41.95400627468814,-41.99734108284488,-42.04067589100163,-42.08401069915837,-42.12734550731511,-42.17068031547185,-42.2140151236286,-42.25734993178534,-42.300684739942085,-42.34401954809882,-42.38735435625557,-42.430689164412314,-42.47402397256905,-42.51735878072579,-42.560693588882536,-42.60402839703928,-42.64736320519602,-42.69069801335277,-42.734032821509516,-42.77736762966625,-42.820702437822995,-42.864037245979745,-42.90737205413648,-42.950706862293224,-42.994041669012226,-43.03613936109284,-43.07823705317347,-43.12033474525409,-43.162432437334715,-43.20453012941534,-43.246627821495956,-43.28872551357658,-43.330823205657204,-43.37292089773783,-43.415018589818445,-43.45711628189907,-43.49921397397969,-43.54131166606032,-43.58340935814094,-43.62550705022156,-43.66427203208434,-43.70237047190355,-43.74046891172275,-43.77856735154195,-43.81666579136116,-43.85476423118037,-43.89286267099957,-43.93096111081878,-43.96905955063798,-44.007157990457195,-44.045256430276396,-44.0833548700956,-44.121453309914806,-44.159551749734014,-44.19765018955322,-44.236017127049834,-44.27451831408727,-44.313019501124685,-44.35152068816211,-44.39002187519954,-44.428523062236955,-44.46702424927439,-44.50552543631182,-44.54402662334924,-44.58252781038667,-44.62102899742409,-44.65953018446152,-44.69803137149894,-44.73653255853637,-44.7750337455738,-44.81353493261122,-44.852036119648645,-44.89053730668607,-44.929038493723496,-44.967539680760915,-45.00604086779835,-45.04454205483577,-45.0830432418732,-45.12154442891062,-45.16004561594805,-45.198546802985476,-45.237047990022894,-45.27554917706033,-45.314050364097746,-45.35255155113518,-45.391052738172604,-45.42955392521003,-45.468055112247455,-45.506556299284874,-45.5450574863223,-45.583558673359725,-45.622059860397144,-45.66056104743458,-45.699062234472,-45.73756342150943,-45.776064608546854,-45.81456579558427,-45.8530669826217,-45.89156816965913,-45.93006935669655,-45.968570543733975,-46.0070717307714,-46.045572917808826,-46.08407410484626,-46.12257529188368,-46.16107647892111,-46.19957766595853,-46.238078852995955,-46.27658004003339,-46.315081227070806,-46.35358241410824,-46.39208360114566,-46.43058478818308,-46.46908597522051,-46.507587162257934,-46.54608834929536,-46.584589536332786,-46.62309072337021,-46.66159191040764,-46.700093097445055,-46.73859428448249,-46.777095471519914,-46.81559665855734,-46.757241661588004,-46.65045857261531,-46.5436754836426,-46.4368923946699,-46.3301093056972,-46.22332621672449,-46.11654312775178,-46.00976003877908,-45.90297694980637,-45.79619386083367,-45.68941077186096,-45.582627682888265,-45.475844593915554,-45.36906150494285,-45.26227841597016,-45.15549532699745,-45.04871223802475,-44.94192914905204,-44.83514606007933,-44.728362971106634,-44.62157988213392,-44.514796793161224,-44.40801370418852,-44.301230615215815,-44.19444752624311,-44.087664437270405,-43.9808813482977,-43.874098259324995,-43.76731517035229,-43.660532081379586,-43.55374899240688,-43.446965903434176,-43.34018281446147,-43.233399725488766,-43.12661663651607,-43.01983354754336,-42.91305045857065,-42.806267369597954,-42.69948428062524,-42.59270119165254,-42.48591810267985,-42.379135013707135,-42.27235192473443,-42.165568835761725,-42.05878574678901,-41.952002657816315,-41.84521956884362,-41.738436479870906,-41.6316533908982,-41.524870301925496,-41.41808721295279,-41.31130412398009,-41.20452103500739,-41.097737946034684,-40.99095485706198,-40.884171768089274,-40.77738867911657,-40.670605590143865,-40.56382250117116,-40.457039412198455,-40.35025632322575,-40.243473234253045,-40.13669014528034,-40.029907056307636,-39.92312396733493,-39.81634087836223,-39.70955778938952,-39.602774700416816,-39.49599161144412,-39.389208522471414,-39.282425433498716,-39.175642344526004,-39.06885925555329,-38.96207616658059,-38.8552930776079,-38.748509988635185,-38.64172689966249,-38.53494381068978,-38.42816072171708,-38.32137763274437,-38.23286184872525,-38.16565792439248,-38.098454000059704,-37.96292219467166,-37.75906250822834,-37.555202821785024,-37.351343135341715,-37.147483448898384,-36.943623762455076,-36.73976407601177,-36.535904389568444,-36.33204470312511,-36.128185016681826,-35.92432533023849,-35.72046564379516,-35.51770459867474,-35.3153830098245,-35.11306142097425,-34.91073983212401,-34.708418243273776,-34.50609665442352,-34.303775065573284,-34.101453476723044,-33.8991318878728,-33.69681029902254,-33.49448871017232,-33.29216712132206,-33.08984553247181,-32.887523943621574,-32.685202354771334,-32.48288076592108,-32.28055917707084,-32.07823758822061,-31.875915999370353,-31.673594410520096,-31.471272821669885,-31.268951232819624,-31.066629643969367,-30.86430805511914,-30.661986466268896,-30.459664877418643,-30.257343288568403,-30.055021699718168,-29.852700110867918,-29.650378522017675,-29.448056933167443,-29.24573534431719,-29.04341375546693,-28.84109216661671,-28.638770577766458,-28.436448988916204,-28.23412740006597,-28.031805811215726,-27.829484222365473,-27.62716263351524,-27.424841044665005,-27.222519455814748,-27.020197866964494,-26.817876278114273,-26.615554689264016,-26.413233100413763,-26.21091151156353,-26.00858992271329,-25.806268333863034,-25.6039467450128,-25.401625156162567,-25.19930356731231,-24.99698197846207,-24.794660389611835,-24.59233880076158,-24.390017211911324,-24.187695623061106,-23.985374034210846,-23.783052445360596,-23.58073085651036,-23.378409267660125,-23.176087678809868,-22.973766089959632,-22.771444501109396,-22.56912291225914,-22.366801323408904,-22.16447973455867,-21.96215814570841,-21.759836556858154,-21.557514968007922,-21.355193379157686,-21.20127178053579,-21.1441501623706,-21.087028544205406,-21.02990692604021,-20.972785307875014,-20.915663689709824,-20.858542071544623,-20.80142045337942,-20.744298835214234,-20.687177217049037,-20.630055598883835,-20.572933980718645,-20.51581236255345,-20.458690744388253,-20.401569126223055,-20.344447508057865,-20.287325889892664,-20.230204271727473,-20.17308265356228,-20.11596103539708,-20.05883941723188,-20.00171779906669,-19.944596180901495,-19.887474562736298,-19.830352944571104,-19.77323132640591,-19.716109708240708,-19.658988090075518,-19.601866471910323,-19.544744853745126,-19.487623235579925,-19.430501617414738,-19.373379999249536,-19.31625838108434,-19.259136762919145,-19.20201514475395,-19.144893526588753,-19.08777190842356,-19.030650290258365,-18.973528672093167,-18.916407053927973,-18.85928543576278,-18.80216381759758,-18.74504219943238,-18.687920581267186,-18.63079896310199,-18.573677344936794,-18.5165557267716,-18.45943410860641,-18.402312490441208,-18.345190872276014,-18.288069254110823,-18.230947635945622,-18.173826017780424,-18.116704399615237,-18.05958278145004,-18.00246116328484,-17.945339545119644,-17.88821792695445,-17.83109630878925,-17.77397469062406,-17.716853072458864,-17.659731454293663,-17.602609836128472,-17.54548821796328,-17.48836659979808,-17.43124498163288,-17.374123363467692,-17.317001745302495,-17.259880127137293,-17.20342369319877,-17.14746011057209,-17.091496527945406,-17.035532945318728,-16.97956936269205,-16.923605780065365,-16.86764219743868,-16.81167861481201,-16.755715032185325,-16.69975144955864,-16.643787866931962,-16.58782428430528,-16.5318607016786,-16.460584850682057,-16.312747657836173,-16.16491046499029,-16.0170732721444,-15.869236079298544,-15.72139888645266,-15.573561693606774,-15.425724500760916,-15.27788730791503,-15.130050115069146,-14.98221292222329,-14.834375729377403,-14.686538536531518,-14.538701343685632,-14.390864150839775,-14.24302695799389,-14.095189765148005,-13.947352572302147,-13.799515379456261,-13.651678186610376,-13.503840993764518,-13.356003800918634,-13.208166608072748,-13.060329415226889,-12.912492222381005,-12.76465502953512,-12.616817836689235,-12.468980643843379,-12.321143450997493,-12.173306258151605,-12.02546906530575,-11.877631872459864,-11.729794679613978,-11.58195748676812,-11.434120293922234,-11.28628310107635,-11.138445908230466,-10.990608715384607,-10.842771522538722,-10.694934329692838,-10.547097136846979,-10.401370789444947,-10.291743749409862,-10.200117655156843,-10.107537802006117,-10.014957948855391,-9.922378095704682,-9.829798242553954,-9.737218389403225,-9.644638536252497,-9.552058683101789,-9.459478829951061,-9.366898976800334,-9.274319123649626,-9.181739270498898,-9.089159417348172,-8.99657956419746,-8.903999711046735,-8.81141985789601,-8.718840004745282,-8.62626015159457,-8.533680298443844,-8.441100445293117,-8.348520592142407,-8.25594073899168,-8.163360885840953,-8.070781032690244,-7.978201179539516,-7.885621326388789,-7.793041473238079,-7.700461620087353,-7.607881766936625,-7.515301913785898,-7.422722060635188,-7.330142207484461,-7.237562354333734,-7.144982501183025,-7.052402648032297,-6.95982279488157,-6.867242941730861,-6.774663088580134,-6.682083235429407,-6.5895033822786795,-6.4969235291279706],[-39.71667582165517,-39.76001062981191,-39.80334543796865,-39.846680246125395,-39.89001505428214,-39.93334986243888,-39.97668467059562,-40.02001947875237,-40.06335428690911,-40.10668909506585,-40.150023903222596,-40.19335871137933,-40.23669351953608,-40.280028327692825,-40.32336313584957,-40.36669794400631,-40.41003275216305,-40.45336756031979,-40.496702368476534,-40.540037176633284,-40.58337198479002,-40.62670679294676,-40.670041601103506,-40.713376409260256,-40.75671121741699,-40.800046025573735,-40.843380833730485,-40.88671564188722,-40.930050450043964,-40.97338525820071,-41.01672006635745,-41.060054874514194,-41.10338968267094,-41.14672449082768,-41.19005929898442,-41.233394107141166,-41.276728915297916,-41.320063723454645,-41.363398531611395,-41.40673333976813,-41.45006814792488,-41.49340295608162,-41.53673776423837,-41.58007257239511,-41.623407380551846,-41.6667421887086,-41.71007699686533,-41.75341180502208,-41.79674661317882,-41.84008142133557,-41.883416229492305,-41.92675103764905,-41.969467287004484,-42.01156497908511,-42.05366267116573,-42.09576036324635,-42.13785805532698,-42.1799557474076,-42.22205343948822,-42.264151131568845,-42.30624882364946,-42.34834651573009,-42.39044420781071,-42.43254189989133,-42.47463959197196,-42.51673728405258,-42.5588349761332,-42.60093266821382,-42.643030360294446,-42.68512805237507,-42.727225744455694,-42.76932343653631,-42.811421128616935,-42.85351882069756,-42.89561651277818,-42.93771420485881,-42.979811896939424,-43.021909589020055,-43.06400728110068,-43.1061049731813,-43.14820266526192,-43.190300357342544,-43.23239804942317,-43.27449574150379,-43.31326072336656,-43.35135916318577,-43.38945760300497,-43.42755604282418,-43.46565448264339,-43.50375292246259,-43.54185136228179,-43.579949802101,-43.61804824192021,-43.656146681739415,-43.69424512155862,-43.732343561377824,-43.77044200119703,-43.808540441016234,-43.84663888083544,-43.88473732065465,-43.92283576047385,-43.96093420029305,-43.99903264011226,-44.03713107993147,-44.07522951975068,-44.11332795956988,-44.15142639938908,-44.18952483920829,-44.227623279027505,-44.265721718846706,-44.30382015866591,-44.34191859848511,-44.38001703830432,-44.41811547812353,-44.45621391794273,-44.49437948204983,-44.532880669087255,-44.57138185612468,-44.60988304316211,-44.64838423019953,-44.68688541723696,-44.725386604274384,-44.7638877913118,-44.802388978349235,-44.84089016538666,-44.87939135242408,-44.91789253946151,-44.95639372649893,-44.99489491353636,-45.03339610057378,-45.07189728761121,-45.11039847464864,-45.14889966168606,-45.18740084872349,-45.22590203576091,-45.264403222798336,-45.30290440983576,-45.34140559687319,-45.37990678391062,-45.41840797094804,-45.456909157985464,-45.49541034502289,-45.533911532060316,-45.57241271909774,-45.61091390613517,-45.64941509317259,-45.68791628021002,-45.726417467247444,-45.76491865428487,-45.803419841322295,-45.84192102835972,-45.88042221539715,-45.91892340243457,-45.957424589472,-45.995925776509424,-46.03442696354685,-46.072928150584275,-46.11142933762169,-46.14993052465912,-46.188431711696545,-46.22693289873397,-46.265434085771396,-46.30393527280882,-46.34243645984625,-46.38093764688367,-46.4194388339211,-46.45794002095852,-46.39958502398919,-46.29280193501649,-46.18601884604378,-46.07923575707109,-45.972452668098384,-45.86566957912567,-45.758886490152975,-45.65210340118027,-45.545320312207565,-45.43853722323486,-45.331754134262155,-45.22497104528945,-45.118187956316746,-45.01140486734404,-44.904621778371336,-44.79783868939863,-44.691055600425926,-44.58427251145322,-44.47748942248052,-44.37070633350781,-44.26392324453511,-44.1571401555624,-44.050357066589704,-43.94357397761699,-43.836790888644295,-43.73000779967158,-43.623224710698885,-43.51644162172619,-43.409658532753475,-43.30287544378077,-43.196092354808066,-43.08930926583536,-42.98252617686266,-42.87574308788995,-42.76895999891725,-42.66217690994454,-42.55539382097184,-42.44861073199914,-42.34182764302643,-42.23504455405373,-42.128261465081025,-42.02147837610832,-41.914695287135615,-41.80791219816291,-41.7011291091902,-41.5943460202175,-41.487562931244796,-41.3807798422721,-41.273996753299386,-41.16721366432668,-41.060430575353976,-40.95364748638128,-40.84686439740857,-40.74008130843587,-40.63329821946316,-40.52651513049046,-40.419732041517754,-40.31294895254505,-40.20616586357234,-40.09938277459964,-39.992599685626935,-39.92235119651438,-39.85514727218161,-39.78794334784884,-39.72073942351608,-39.653535499183306,-39.58633157485054,-39.519127650517774,-39.451923726185,-39.384719801852235,-39.31751587751947,-39.2503119531867,-39.18310802885393,-39.115904104521164,-39.0487001801884,-38.981496255855625,-38.91429233152286,-38.847088407190085,-38.77988448285733,-38.71268055852455,-38.64547663419179,-38.57827270985902,-38.51106878552625,-38.37553698013821,-38.17167729369488,-37.96781760725157,-37.76395792080826,-37.56009823436493,-37.35623854792162,-37.15237886147831,-36.94851917503498,-36.74465948859165,-36.54079980214836,-36.33694011570503,-36.13308042926171,-35.9292207428184,-35.72536105637509,-35.521501369931755,-35.317641683488446,-35.11378199704514,-34.90992231060181,-34.706062624158506,-34.50220293771519,-34.29834325127186,-34.094483564828536,-33.89062387838524,-33.68676419194191,-33.48290450549859,-33.27904481905527,-33.07518513261197,-32.87132544616863,-32.66746575972533,-32.463606073282016,-32.25974638683869,-32.05588670039536,-31.852027013952068,-31.648167327508748,-31.444307641065414,-31.240447954622102,-31.036588268178797,-30.832728581735466,-30.628868895292158,-30.42500920884885,-30.22114952240552,-30.017289835962213,-29.8134301495189,-29.60957046307557,-29.405710776632244,-29.201851090188953,-28.997991403745623,-28.7941317173023,-28.590272030858987,-28.386412344415675,-28.182552657972344,-27.978692971529043,-27.774833285085727,-27.570973598642396,-27.367113912199073,-27.163254225755786,-26.959394539312452,-26.755534852869125,-26.551675166425817,-26.347815479982508,-26.143955793539178,-25.940096107095865,-25.73623642065256,-25.53237673420923,-25.32851704776592,-25.12465736132261,-24.92079767487928,-24.71693798843595,-24.513078301992664,-24.309218615549334,-24.105358929106004,-23.901499242662695,-23.697639556219386,-23.49377986977606,-23.289920183332747,-23.08606049688944,-22.882200810446115,-22.678341124002802,-22.474481437559486,-22.270621751116163,-22.066762064672837,-21.861117875814394,-21.65243341941177,-21.494008436426885,-21.43610240027749,-21.378196364128108,-21.32061110448171,-21.263312251888213,-21.20601339929471,-21.148714546701207,-21.091415694107706,-21.034116841514212,-20.976817988920708,-20.919519136327203,-20.862220283733706,-20.804921431140208,-20.7476225785467,-20.690323725953203,-20.633024873359705,-20.5757260207662,-20.518427168172703,-20.461128315579206,-20.403829462985705,-20.346530610392197,-20.2892317577987,-20.231932905205202,-20.1746340526117,-20.1173352000182,-20.0600363474247,-20.002737494831194,-19.9454386422377,-19.8881397896442,-19.830840937050695,-19.77354208445719,-19.7162432318637,-19.658944379270196,-19.601645526676695,-19.544346674083197,-19.487047821489693,-19.42974896889619,-19.372450116302694,-19.315151263709197,-19.25785241111569,-19.20055355852219,-19.143254705928694,-19.085955853335193,-19.02865700074169,-18.97135814814819,-18.914059295554694,-18.85676044296119,-18.799461590367688,-18.74216273777419,-18.684863885180686,-18.62756503258719,-18.57026617999369,-18.512967327400183,-18.455668474806682,-18.398369622213192,-18.341070769619687,-18.28377191702618,-18.226473064432682,-18.169174211839184,-18.11187535924568,-18.054576506652182,-17.997277654058685,-17.93997880146518,-17.882679948871683,-17.825381096278182,-17.76808224368468,-17.710783391091176,-17.653484538497683,-17.596185685904178,-17.538886833310674,-17.481587980717176,-17.42428912812368,-17.366990275530178,-17.309691422936677,-17.252392570343176,-17.19509371774967,-17.13779486515617,-17.080496012562676,-17.023197159969175,-16.96589830737567,-16.90859945478217,-16.851300602188672,-16.794001749595168,-16.72044673382622,-16.565610902179973,-16.41077507053373,-16.255939238887482,-16.10110340724127,-15.946267575595023,-15.79143174394878,-15.636595912302562,-15.481760080656317,-15.326924249010073,-15.172088417363856,-15.021850036153094,-14.87320667481677,-14.724563313480445,-14.575919952144146,-14.427276590807821,-14.278633229471497,-14.129989868135198,-13.981346506798873,-13.832703145462549,-13.684059784126248,-13.535416422789925,-13.386773061453601,-13.238129700117302,-13.089486338780977,-12.94084297744465,-12.792199616108325,-12.643556254772028,-12.494912893435703,-12.34626953209938,-12.19762617076308,-12.048982809426754,-11.900339448090431,-11.751696086754132,-11.603052725417806,-11.454409364081481,-11.305766002745155,-11.157122641408858,-11.008479280072534,-10.85983591873621,-10.711192557399912,-10.562549196063586,-10.44609284748137,-10.352627222294956,-10.259161597108525,-10.165695971922094,-10.07223034673568,-9.978764721549247,-9.885299096362814,-9.791833471176385,-9.69836784598997,-9.604902220803538,-9.511436595617107,-9.417970970430694,-9.324505345244262,-9.23103972005783,-9.137574094871416,-9.044108469684984,-8.950642844498553,-8.857177219312122,-8.763711594125708,-8.670245968939277,-8.576780343752844,-8.48331471856643,-8.389849093379999,-8.296383468193568,-8.202917843007153,-8.109452217820722,-8.015986592634292,-7.922520967447876,-7.829055342261444,-7.735589717075014,-7.642124091888582,-7.54615616982357,-7.446792250170327,-7.347428330517086,-7.248064410863862,-7.148700491210619,-7.049336571557378,-6.949972651904154,-6.850608732250912,-6.751244812597669,-6.651880892944426,-6.552516973291203],[-39.386076927518886,-39.42941173567563,-39.47274654383237,-39.516081351989115,-39.55941616014586,-39.6027509683026,-39.64608577645934,-39.68942058461609,-39.73275539277283,-39.77609020092957,-39.819425009086316,-39.86275981724305,-39.9060946253998,-39.949429433556546,-39.99276424171328,-40.03609904987003,-40.07943385802677,-40.12276866618351,-40.16610347434026,-40.209438282497004,-40.25277309065374,-40.29610789881049,-40.33944270696722,-40.38277751512397,-40.42611232328071,-40.469447131437455,-40.5127819395942,-40.556116747750934,-40.599451555907685,-40.64278636406443,-40.68612117222117,-40.72945598037791,-40.77279078853466,-40.8161255966914,-40.859460404848136,-40.90279521291613,-40.94489290499676,-40.98699059707738,-41.029088289158004,-41.07118598123863,-41.113283673319245,-41.155381365399876,-41.19747905748049,-41.23957674956112,-41.28167444164174,-41.32377213372236,-41.36586982580299,-41.407967517883606,-41.45006520996422,-41.49216290204486,-41.53426059412547,-41.5763582862061,-41.61845597828672,-41.660553670367335,-41.702651362447966,-41.74474905452858,-41.786846746609214,-41.82894443868983,-41.871042130770455,-41.91313982285108,-41.9552375149317,-41.99733520701233,-42.039432899092944,-42.08153059117357,-42.12362828325419,-42.16572597533482,-42.20782366741544,-42.24992135949606,-42.29201905157669,-42.334116743657304,-42.376214435737936,-42.41831212781855,-42.460409819899176,-42.5025075119798,-42.54460520406042,-42.58670289614105,-42.628800588221665,-42.67089828030229,-42.71299597238291,-42.75509366446353,-42.79719135654416,-42.83928904862478,-42.8813867407054,-42.923484432786026,-42.962249414648795,-43.000347854468004,-43.038446294287205,-43.07654473410641,-43.114643173925614,-43.15274161374482,-43.19084005356403,-43.22893849338323,-43.26703693320244,-43.30513537302165,-43.34323381284085,-43.38133225266006,-43.41943069247927,-43.45752913229847,-43.49562757211768,-43.53372601193688,-43.571824451756086,-43.609922891575295,-43.6480213313945,-43.686119771213704,-43.724218211032905,-43.762316650852114,-43.80041509067132,-43.83851353049052,-43.87661197030973,-43.91471041012893,-43.95280884994815,-43.99090728976735,-44.02900572958655,-44.06710416940576,-44.10520260922497,-44.143301049044176,-44.18139948886338,-44.219497928682586,-44.25759636850179,-44.295694808320995,-44.3337932481402,-44.371891687959405,-44.40999012777861,-44.448088567597814,-44.48618700741702,-44.52428544723623,-44.56238388705543,-44.60048232687463,-44.63858076669384,-44.67667920651305,-44.71477764633226,-44.75287608615147,-44.79124302408725,-44.82974421112468,-44.8682453981621,-44.90674658519953,-44.945247772236954,-44.98374895927438,-45.022250146311805,-45.06075133334923,-45.099252520386656,-45.13775370742408,-45.17625489446151,-45.21475608149893,-45.25325726853636,-45.29175845557378,-45.33025964261121,-45.368760829648636,-45.40726201668606,-45.44576320372349,-45.484264390760906,-45.52276557779834,-45.561266764835764,-45.59976795187318,-45.63826913891061,-45.676770325948034,-45.71527151298546,-45.75377270002289,-45.79227388706031,-45.83077507409774,-45.869276261135155,-45.90777744817259,-45.946278635210014,-45.98477982224744,-46.02328100928486,-46.06178219632229,-46.10028338335971,-46.04192838639038,-45.93514529741768,-45.82836220844498,-45.721579119472274,-45.61479603049957,-45.508012941526864,-45.40122985255417,-45.29444676358146,-45.18766367460875,-45.08088058563605,-44.97409749666334,-44.86731440769064,-44.76053131871794,-44.65374822974523,-44.54696514077253,-44.44018205179982,-44.33339896282712,-44.22661587385441,-44.11983278488171,-44.01304969590901,-43.9062666069363,-43.799483517963594,-43.6927004289909,-43.585917340018185,-43.47913425104549,-43.372351162072775,-43.26556807310007,-43.15878498412737,-43.05200189515466,-42.94521880618197,-42.83843571720925,-42.73165262823655,-42.62486953926385,-42.51808645029114,-42.411303361318446,-42.304520272345734,-42.197737183373036,-42.09095409440033,-41.98417100542762,-41.87738791645492,-41.770604827482224,-41.67904446863628,-41.61184054430351,-41.544636619970746,-41.47743269563798,-41.4102287713052,-41.34302484697243,-41.27582092263967,-41.2086169983069,-41.141413073974135,-41.07420914964136,-41.007005225308596,-40.93980130097583,-40.87259737664306,-40.8053934523103,-40.73818952797753,-40.67098560364476,-40.603781679311986,-40.53657775497922,-40.469373830646454,-40.40216990631369,-40.334965981980915,-40.26776205764815,-40.20055813331538,-40.13335420898262,-40.066150284649844,-39.99894636031708,-39.93174243598431,-39.86453851165154,-39.79733458731877,-39.73013066298601,-39.66292673865324,-39.59572281432047,-39.528518889987694,-39.461314965654935,-39.39411104132216,-39.326907116989396,-39.25970319265663,-39.19249926832386,-39.12529534399109,-39.058091419658325,-38.99088749532555,-38.923683570992786,-38.78815176560474,-38.584292079161415,-38.380432392718106,-38.1765727062748,-37.97271301983146,-37.76885333338815,-37.56499364694485,-37.36113396050152,-37.15727427405819,-36.9534145876149,-36.74955490117157,-36.54569521472824,-36.34183552828493,-36.13797584184162,-35.934116155398286,-35.730256468954984,-35.526396782511675,-35.322537096068345,-35.118677409625036,-34.91481772318173,-34.710958036738404,-34.50709835029507,-34.30323866385178,-34.09937897740845,-33.89551929096512,-33.69165960452182,-33.4877999180785,-33.28394023163518,-33.08008054519186,-32.87622085874855,-32.67236117230523,-32.46850148586189,-32.26464179941861,-32.060782112975275,-31.856922426531952,-31.653062740088643,-31.44920305364533,-31.245343367202004,-31.041483680758695,-30.837623994315386,-30.633764307872053,-30.429904621428747,-30.22604493498544,-30.022185248542108,-29.818325562098778,-29.614465875655487,-29.41060618921216,-29.20674650276883,-29.00288681632552,-28.799027129882212,-28.595167443438882,-28.391307756995573,-28.187448070552264,-27.98358838410894,-27.779728697665604,-27.57411755732422,-27.365433100921575,-27.156748644518927,-26.948064188116298,-26.73937973171367,-26.530695275311025,-26.322010818908396,-26.113326362505767,-25.90464190610312,-25.69595744970049,-25.487272993297864,-25.278588536895217,-25.06990408049257,-24.861219624089955,-24.65253516768731,-24.44385071128466,-24.23516625488204,-24.026481798479406,-23.81779734207676,-23.60911288567413,-23.400428429271507,-23.191743972868856,-22.98305951646623,-22.774375060063598,-22.56569060366095,-22.357006147258303,-22.148321690855674,-21.939637234453052,-21.781212251468162,-21.72330621531877,-21.665400179169385,-21.60749414301999,-21.5495881068706,-21.491682070721215,-21.43377603457182,-21.375869998422424,-21.317963962273044,-21.26005792612365,-21.202151889974253,-21.144245853824867,-21.08633981767548,-21.028433781526083,-20.970527745376696,-20.912621709227306,-20.854715673077912,-20.796809636928526,-20.738903600779135,-20.680997564629738,-20.623091528480344,-20.56518549233096,-20.507279456181568,-20.449373420032178,-20.391467383882787,-20.3335613477334,-20.275655311584003,-20.217749275434613,-20.159843239285227,-20.101937203135833,-20.04403116698644,-19.986125130837056,-19.928219094687663,-19.87031305853827,-19.812407022388875,-19.754500986239492,-19.696594950090095,-19.638688913940705,-19.580782877791318,-19.52331790982148,-19.46601905722798,-19.408720204634484,-19.35142135204098,-19.294122499447475,-19.236823646853978,-19.17952479426048,-19.122225941666976,-19.064927089073475,-19.007628236479977,-18.950329383886473,-18.893030531292975,-18.835731678699478,-18.778432826105973,-18.72113397351247,-18.663835120918975,-18.606536268325474,-18.54923741573197,-18.49193856313847,-18.43463971054497,-18.377340857951467,-18.32004200535797,-18.26274315276447,-18.205444300170967,-18.14814544757747,-18.09084659498397,-18.033547742390468,-17.976248889796963,-17.91895003720347,-17.861651184609965,-17.80435233201646,-17.747053479422963,-17.689754626829465,-17.632455774235964,-17.575156921642463,-17.517858069048962,-17.460559216455458,-17.403260363861957,-17.345961511268463,-17.28866265867496,-17.231363806081458,-17.174064953487957,-17.11676610089446,-17.059467248300955,-16.98591223253201,-16.831076400885763,-16.676240569239514,-16.521404737593272,-16.366568905947055,-16.21173307430081,-16.056897242654564,-15.902061411008347,-15.747225579362103,-15.59238974771586,-15.437553916069643,-15.282718084423399,-15.127882252777152,-14.973046421130906,-14.81821058948469,-14.663374757838447,-14.508538926192202,-14.353703094545986,-14.198867262899743,-14.044031431253494,-13.88919559960728,-13.734359767961035,-13.579523936314791,-13.424688104668572,-13.269852273022329,-13.115016441376083,-12.960180609729838,-12.805344778083624,-12.65355827822718,-12.504914916890856,-12.356271555554558,-12.207628194218234,-12.058984832881908,-11.910341471545609,-11.761698110209284,-11.613054748872962,-11.464411387536634,-11.315768026200338,-11.167124664864012,-11.018481303527686,-10.869837942191388,-10.721194580855062,-10.604738232272847,-10.511272607086433,-10.417806981900002,-10.324341356713573,-10.230875731527156,-10.137410106340726,-10.043944481154293,-9.950478855967862,-9.85701323078145,-9.763547605595019,-9.670081980408584,-9.576616355222171,-9.483150730035739,-9.389685104849308,-9.29224260815014,-9.192878688496897,-9.093514768843654,-8.994150849190412,-8.894786929537188,-8.795423009883947,-8.696059090230703,-8.59669517057748,-8.497331250924237,-8.397967331270996,-8.298603411617773,-8.19923949196453,-8.099875572311287,-8.000511652658062,-7.90114773300482,-7.8017838133515784,-7.702419893698336,-7.6030559740451125,-7.50369205439187,-7.404328134738629,-7.304964215085404,-7.205600295432161,-7.106236375778918,-7.006872456125695,-6.907508536472453,-6.808144616819211,-6.7087806971659685,-6.609416777512745],[-39.0554780333826,-39.09881284153934,-39.142147649696085,-39.18548245785282,-39.22881726600957,-39.272152074166314,-39.31548688232305,-39.3588216904798,-39.40215649863654,-39.445491306793286,-39.48882611495002,-39.53216092310677,-39.57549573126351,-39.61883053942025,-39.662165347576995,-39.705500155733745,-39.74883496389048,-39.792169772047224,-39.835504580203974,-39.8782208309084,-39.92031852298902,-39.96241621506964,-40.00451390715027,-40.04661159923089,-40.08870929131152,-40.130806983392134,-40.17290467547276,-40.21500236755338,-40.257100059634006,-40.29919775171462,-40.34129544379525,-40.38339313587587,-40.425490827956494,-40.46758852003712,-40.509686212117735,-40.55178390419836,-40.59388159627898,-40.63597928835961,-40.67807698044023,-40.720174672520855,-40.76227236460147,-40.804370056682096,-40.84646774876272,-40.888565440843344,-40.93066313292396,-40.972760825004585,-41.014858517085216,-41.05695620916583,-41.09905390124645,-41.14115159332708,-41.1832492854077,-41.22534697748833,-41.267444669568945,-41.30954236164956,-41.35164005373019,-41.39373774581081,-41.43583543789144,-41.47793312997206,-41.520030822052675,-41.562128514133306,-41.60422620621392,-41.64632389829455,-41.68842159037517,-41.73051928245579,-41.77261697453642,-41.81471466661704,-41.85681235869767,-41.898910050778284,-41.941007742858915,-41.98310543493953,-42.025203127020156,-42.06730081910078,-42.109398511181396,-42.15149620326203,-42.193593895342644,-42.23569158742327,-42.27778927950389,-42.31988697158451,-42.36198466366514,-42.40408235574576,-42.44618004782638,-42.488277739907005,-42.53037543198762,-42.572473124068246,-42.61123810593102,-42.649336545750224,-42.68743498556943,-42.72553342538864,-42.76363186520784,-42.80173030502705,-42.83982874484625,-42.87792718466545,-42.91602562448466,-42.95412406430387,-42.99222250412308,-43.03032094394228,-43.068419383761494,-43.10651782358069,-43.144616263399904,-43.182714703219105,-43.22081314303831,-43.25891158285752,-43.29701002267672,-43.335108462495924,-43.37320690231513,-43.41130534213434,-43.44940378195355,-43.48750222177275,-43.52560066159195,-43.56369910141116,-43.60179754123037,-43.63989598104958,-43.67799442086878,-43.71609286068798,-43.75419130050719,-43.792289740326396,-43.830388180145604,-43.868486619964806,-43.906585059784014,-43.944683499603215,-43.98278193942242,-44.02088037924163,-44.05897881906083,-44.09707725888004,-44.13517569869924,-44.17327413851845,-44.21137257833766,-44.24947101815686,-44.28756945797606,-44.32566789779527,-44.36376633761448,-44.40186477743369,-44.439963217252895,-44.4780616570721,-44.5161600968913,-44.554258536710506,-44.592356976529715,-44.63045541634892,-44.668553856168124,-44.706652295987325,-44.744750735806534,-44.78284917562574,-44.82094761544495,-44.85904605526415,-44.89714449508336,-44.93524293490257,-44.97334137472177,-45.01143981454098,-45.04960537908725,-45.08810656612467,-45.1266077531621,-45.16510894019952,-45.20361012723695,-45.24211131427437,-45.2806125013118,-45.319113688349226,-45.357614875386645,-45.39611606242407,-45.434617249461496,-45.47311843649892,-45.511619623536355,-45.55012081057378,-45.5886219976112,-45.627123184648624,-45.66562437168605,-45.704125558723476,-45.7426267457609,-45.684271748791566,-45.57748865981887,-45.470705570846164,-45.36392248187346,-45.257139392900754,-45.15035630392805,-45.043573214955344,-44.93679012598264,-44.830007037009935,-44.72322394803723,-44.616440859064525,-44.50965777009183,-44.40287468111912,-44.29609159214642,-44.18930850317371,-44.08252541420101,-43.9757423252283,-43.8689592362556,-43.762176147282894,-43.65539305831019,-43.548609969337484,-43.441826880364786,-43.36853381642541,-43.30132989209264,-43.23412596775987,-43.16692204342711,-43.099718119094334,-43.032514194761575,-42.9653102704288,-42.898106346096036,-42.83090242176327,-42.7636984974305,-42.69649457309773,-42.62929064876496,-42.56208672443219,-42.494882800099425,-42.42767887576666,-42.36047495143389,-42.29327102710112,-42.226067102768354,-42.15886317843559,-42.091659254102815,-42.02445532977005,-41.957251405437276,-41.89004748110452,-41.822843556771744,-41.75563963243898,-41.68843570810621,-41.62123178377344,-41.55402785944067,-41.48682393510791,-41.419620010775134,-41.352416086442375,-41.2852121621096,-41.218008237776836,-41.15080431344407,-41.0836003891113,-41.01639646477853,-40.94919254044576,-40.88198861611299,-40.81478469178023,-40.74758076744746,-40.680376843114686,-40.61317291878192,-40.545968994449154,-40.478765070116395,-40.411561145783615,-40.34435722145085,-40.277153297118076,-40.20994937278531,-40.142745448452544,-40.07554152411977,-40.00833759978701,-39.94113367545424,-39.87392975112147,-39.80672582678871,-39.739521902455934,-39.672317978123175,-39.6051140537904,-39.53791012945763,-39.47070620512487,-39.4035022807921,-39.33629835645933,-39.20076655107128,-38.99690686462795,-38.79304717818465,-38.589187491741335,-38.38532780529801,-38.181468118854696,-37.97760843241139,-37.773748745968064,-37.569889059524726,-37.366029373081446,-37.16216968663811,-36.958310000194786,-36.75445031375148,-36.55059062730817,-36.34673094086484,-36.14287125442153,-35.93901156797822,-35.73515188153489,-35.53129219509158,-35.32743250864827,-35.123572822204935,-34.91971313576161,-34.71585344931832,-34.511993762874994,-34.308134076431664,-34.104274389988355,-33.900414703545046,-33.696555017101716,-33.49269533065841,-33.287117238834036,-33.07843278243139,-32.86974832602874,-32.66106386962613,-32.45237941322348,-32.24369495682084,-32.0350105004182,-31.826326044015584,-31.617641587612933,-31.408957131210308,-31.200272674807678,-30.991588218405028,-30.7829037620024,-30.574219305599772,-30.365534849197125,-30.156850392794475,-29.94816593639187,-29.73948147998922,-29.530797023586572,-29.322112567183943,-29.113428110781317,-28.904743654378667,-28.69605919797604,-28.48737474157341,-28.278690285170768,-28.070005828768117,-27.86132137236551,-27.65263691596286,-27.44395245956021,-27.235268003157586,-27.026583546754956,-26.81789909035231,-26.609214633949684,-26.40053017754705,-26.191845721144404,-25.983161264741774,-25.774476808339152,-25.5657923519365,-25.35710789553385,-25.148423439131243,-24.9397389827286,-24.73105452632595,-24.52237006992332,-24.31368561352069,-24.10500115711804,-23.89631670071542,-23.687632244312788,-23.47894778791014,-23.27026333150751,-23.06157887510489,-22.85289441870224,-22.64420996229959,-22.435525505896962,-22.226841049494336,-22.068416066509446,-22.01051003036006,-21.952603994210673,-21.89469795806128,-21.83679192191189,-21.7788858857625,-21.720979849613105,-21.66307381346371,-21.60516777731433,-21.547261741164938,-21.48935570501554,-21.43144966886615,-21.373543632716764,-21.31563759656737,-21.25773156041798,-21.199825524268594,-21.141919488119196,-21.08401345196981,-21.02610741582042,-20.968201379671026,-20.910295343521632,-20.852389307372242,-20.79448327122286,-20.73657723507346,-20.678671198924075,-20.620765162774685,-20.56285912662529,-20.5049530904759,-20.44704705432651,-20.38914101817712,-20.331234982027723,-20.27332894587834,-20.215422909728947,-20.157516873579556,-20.099610837430163,-20.041704801280773,-19.983798765131382,-19.925892728981992,-19.867986692832606,-19.810080656683212,-19.752174620533822,-19.69426858438443,-19.63636254823504,-19.578456512085644,-19.520550475936258,-19.46264443978687,-19.404738403637474,-19.346832367488087,-19.2889263313387,-19.231020295189303,-19.173114259039913,-19.11520822289053,-19.057302186741133,-18.999396150591735,-18.941490114442352,-18.883584078292962,-18.825678042143565,-18.76777200599418,-18.70986596984479,-18.651959933695395,-18.594053897546008,-18.536147861396618,-18.478241825247224,-18.420335789097834,-18.362429752948447,-18.304523716799054,-18.24661768064966,-18.188711644500277,-18.130805608350883,-18.072899572201486,-18.0149935360521,-17.957087499902713,-17.899181463753315,-17.84127542760393,-17.78336939145454,-17.726024715161252,-17.668725862567747,-17.611427009974257,-17.554128157380752,-17.496829304787248,-17.43953045219375,-17.382231599600253,-17.32493274700675,-17.2513777312378,-17.096541899591553,-16.941706067945304,-16.786870236299062,-16.632034404652845,-16.477198573006604,-16.322362741360358,-16.167526909714137,-16.012691078067895,-15.85785524642165,-15.703019414775433,-15.54818358312919,-15.393347751482946,-15.2385119198367,-15.083676088190483,-14.92884025654424,-14.774004424897992,-14.619168593251779,-14.464332761605535,-14.309496929959288,-14.154661098313074,-13.999825266666825,-13.84498943502058,-13.690153603374366,-13.534341206370188,-13.37848634223892,-13.222631478107656,-13.066776613976419,-12.910921749845151,-12.755066885713887,-12.599212021582654,-12.443357157451388,-12.287502293320122,-12.131647429188885,-11.975792565057619,-11.819937700926355,-11.664082836795089,-11.508227972663851,-11.352373108532587,-11.196518244401322,-11.040663380270084,-10.88480851613882,-10.761218784729378,-10.660675576692679,-10.56013236865596,-10.459589160619242,-10.359045952582543,-10.258502744545822,-10.157959536509104,-10.057416328472387,-9.956873120435688,-9.85632991239897,-9.75578670436225,-9.655243496325552,-9.554700288288833,-9.454157080252116,-9.353613872215416,-9.253070664178697,-9.152527456141978,-9.05198424810526,-8.95168673375873,-8.85232281410549,-8.752958894452247,-8.653594974799024,-8.554231055145781,-8.454867135492538,-8.355503215839315,-8.256139296186072,-8.156775376532831,-8.057411456879606,-7.9580475372263635,-7.858683617573121,-7.759319697919878,-7.659955778266655,-7.560591858613413,-7.461227938960171,-7.361864019306946,-7.262500099653704,-7.163136180000462,-7.063772260347238,-6.964408340693996,-6.8650444210407535,-6.765680501387512,-6.6663165817342875],[-38.72487913924631,-38.76821394740306,-38.8115487555598,-38.85364644890067,-38.89574414098129,-38.93784183306191,-38.979939525142534,-39.02203721722316,-39.06413490930378,-39.106232601384406,-39.14833029346503,-39.19042798554565,-39.23252567762627,-39.274623369706894,-39.31672106178752,-39.35881875386814,-39.400916445948766,-39.44301413802938,-39.48511183011001,-39.52720952219063,-39.56930721427125,-39.61140490635187,-39.653502598432496,-39.69560029051312,-39.737697982593744,-39.77979567467436,-39.82189336675499,-39.86399105883561,-39.90608875091623,-39.94818644299686,-39.990284135077474,-40.032381827158105,-40.07447951923872,-40.116577211319346,-40.15867490339997,-40.200772595480586,-40.24287028756122,-40.284967979641834,-40.32706567172246,-40.36916336380308,-40.4112610558837,-40.45335874796433,-40.49545644004495,-40.53755413212557,-40.579651824206195,-40.62174951628682,-40.66384720836744,-40.70594490044806,-40.748042592528684,-40.79014028460931,-40.83223797668993,-40.874335668770556,-40.91643336085117,-40.9585310529318,-41.00062874501242,-41.042726437093044,-41.08482412917367,-41.12692182125429,-41.169019513334916,-41.21111720541554,-41.253214897496164,-41.29531258957679,-41.337410281657405,-41.37950797373803,-41.421605665818646,-41.46370335789928,-41.505801049979894,-41.54789874206052,-41.58999643414114,-41.632094126221766,-41.67419181830239,-41.71628951038301,-41.75838720246363,-41.800484894544255,-41.84258258662488,-41.8846802787055,-41.92677797078612,-41.96887566286674,-42.01097335494737,-42.05307104702799,-42.095168739108615,-42.13726643118923,-42.179364123269856,-42.22146181535048,-42.26022679721326,-42.298325237032465,-42.336423676851666,-42.37452211667087,-42.41262055649008,-42.450718996309284,-42.488817436128485,-42.526915875947694,-42.565014315766895,-42.60311275558611,-42.64121119540532,-42.67930963522451,-42.71740807504373,-42.75550651486292,-42.79360495468214,-42.831703394501346,-42.86980183432055,-42.90790027413975,-42.94599871395896,-42.984097153778166,-43.02219559359737,-43.060294033416575,-43.098392473235776,-43.136490913054985,-43.17458935287419,-43.2126877926934,-43.2507862325126,-43.288884672331804,-43.32698311215101,-43.36508155197022,-43.40317999178943,-43.44127843160863,-43.47937687142783,-43.51747531124704,-43.55557375106625,-43.59367219088546,-43.631770630704665,-43.66986907052386,-43.70796751034307,-43.746065950162276,-43.784164389981484,-43.822262829800685,-43.86036126961989,-43.898459709439095,-43.9365581492583,-43.97465658907751,-44.01275502889672,-44.05085346871593,-44.08895190853512,-44.12705034835433,-44.16514878817354,-44.20324722799275,-44.24134566781195,-44.27944410763116,-44.31754254745036,-44.35564098726957,-44.393739427088775,-44.431837866907976,-44.469936306727185,-44.50803474654639,-44.546133186365594,-44.5842316261848,-44.622330066004004,-44.66042850582321,-44.69852694564242,-44.73662538546162,-44.77472382528083,-44.81282226510004,-44.85092070491924,-44.88901914473844,-44.92711758455765,-44.96521602437686,-45.003314464196066,-45.04141290401527,-45.07951134383447,-45.11760978365368,-45.155708223472885,-45.193806663292094,-45.231905103111295,-45.270003542930496,-45.30810198274971,-45.34646892112466,-45.384970108162086,-45.32661511119276,-45.219832022220054,-45.125227088547305,-45.05802316421454,-44.99081923988177,-44.923615315549,-44.856411391216234,-44.78920746688347,-44.7220035425507,-44.654799618217936,-44.58759569388516,-44.5203917695524,-44.453187845219624,-44.38598392088686,-44.31877999655409,-44.251576072221326,-44.18437214788856,-44.11716822355579,-44.04996429922302,-43.982760374890255,-43.91555645055748,-43.84835252622471,-43.78114860189194,-43.71394467755918,-43.64674075322641,-43.579536828893644,-43.51233290456088,-43.445128980228105,-43.37792505589534,-43.31072113156257,-43.2435172072298,-43.176313282897034,-43.10910935856427,-43.041905434231495,-42.97470150989873,-42.90749758556596,-42.84029366123319,-42.77308973690043,-42.70588581256766,-42.638681888234885,-42.571477963902126,-42.50427403956935,-42.43707011523659,-42.36986619090382,-42.30266226657105,-42.235458342238275,-42.16825441790551,-42.10105049357274,-42.03384656923997,-41.96664264490721,-41.89943872057444,-41.83223479624167,-41.765030871908905,-41.69782694757613,-41.63062302324337,-41.5634190989106,-41.49621517457783,-41.42901125024507,-41.361807325912295,-41.29460340157953,-41.22739947724676,-41.16019555291399,-41.092991628581224,-41.02578770424845,-40.958583779915685,-40.89137985558292,-40.82417593125015,-40.75697200691738,-40.689768082584614,-40.62256415825185,-40.55536023391908,-40.48815630958631,-40.42095238525354,-40.35374846092077,-40.286544536588,-40.219340612255245,-40.15213668792247,-40.084932763589705,-40.01772883925694,-39.950524914924166,-39.8833209905914,-39.81611706625863,-39.74891314192586,-39.61338133653782,-39.40952165009449,-39.20566196365118,-39.00011692034384,-38.7914324639412,-38.58274800753857,-38.37406355113594,-38.16537909473329,-37.956694638330646,-37.74801018192803,-37.53932572552538,-37.33064126912274,-37.121956812720114,-36.913272356317485,-36.704587899914834,-36.495903443512205,-36.28721898710958,-36.07853453070693,-35.8698500743043,-35.66116561790167,-35.45248116149902,-35.24379670509638,-35.03511224869377,-34.82642779229113,-34.61774333588848,-34.40905887948585,-34.20037442308322,-33.991689966680575,-33.783005510277945,-33.574321053875316,-33.36563659747267,-33.15695214107002,-32.948267684667414,-32.73958322826476,-32.53089877186212,-32.32221431545949,-32.11352985905686,-31.904845402654214,-31.696160946251588,-31.48747648984896,-31.278792033446308,-31.070107577043682,-30.86142312064105,-30.6527386642384,-30.444054207835755,-30.235369751433147,-30.02667655973041,-29.81797463183969,-29.60927270394899,-29.400570776058284,-29.191868848167566,-28.983166920276865,-28.77446499238616,-28.565763064495442,-28.35706113660472,-28.148359208714034,-27.939657280823315,-27.73095535293259,-27.52225342504189,-27.313551497151188,-27.104849569260466,-26.89614764136976,-26.68744571347906,-26.478743785588343,-26.27004185769764,-26.061339929806934,-25.852638001916215,-25.643936074025497,-25.43523414613481,-25.22653221824409,-25.01783029035337,-24.809128362462666,-24.600426434571965,-24.391724506681243,-24.183022578790542,-23.97432065089984,-23.765618723009116,-23.556916795118415,-23.348214867227714,-23.139512939336992,-22.930811011446266,-22.722109083555566,-22.513407155664865,-22.354918381991936,-22.29685591675457,-22.238793451517196,-22.18073098627982,-22.122717861516005,-22.064735407527678,-22.006752953539348,-21.948770499551017,-21.890788045562697,-21.83280559157437,-21.77482313758604,-21.716840683597717,-21.65885822960939,-21.600875775621063,-21.54289332163274,-21.484910867644412,-21.426928413656082,-21.36894595966776,-21.310963505679435,-21.252981051691105,-21.194998597702774,-21.13701614371445,-21.079033689726124,-21.021051235737797,-20.963068781749474,-20.90508632776115,-20.847103873772816,-20.789121419784493,-20.73113896579617,-20.673156511807843,-20.61517405781951,-20.557191603831193,-20.49920914984286,-20.44122669585453,-20.38324424186621,-20.32526178787788,-20.26727933388955,-20.209296879901228,-20.151314425912904,-20.093331971924577,-20.03534951793625,-19.977367063947927,-19.919384609959597,-19.861402155971266,-19.803419701982943,-19.74543724799462,-19.68745479400629,-19.629472340017966,-19.571489886029642,-19.513507432041308,-19.455524978052985,-19.397542524064665,-19.33956007007633,-19.281577616088004,-19.223595162099684,-19.165612708111354,-19.107630254123023,-19.0496478001347,-18.991665346146373,-18.933682892158043,-18.875700438169723,-18.8177179841814,-18.75973553019307,-18.701753076204742,-18.64377062221642,-18.58578816822809,-18.527805714239758,-18.469823260251438,-18.41184080626311,-18.35385835227478,-18.295875898286457,-18.23789344429813,-18.1799109903098,-18.121928536321477,-18.063946082333153,-18.005963628344823,-17.947981174356492,-17.889998720368176,-17.832016266379846,-17.774033812391515,-17.71605135840319,-17.658068904414865,-17.600086450426538,-17.52477939149749,-17.36284930786479,-17.200919224232088,-17.038989140599387,-16.87705905696672,-16.715128973334014,-16.553198889701317,-16.391268806068645,-16.229338722435944,-16.067408638803244,-15.905478555170573,-15.743548471537874,-15.581618387905174,-15.419688304272475,-15.261674638405417,-15.105819774274153,-14.949964910142889,-14.794110046011651,-14.638255181880385,-14.48240031774912,-14.326545453617882,-14.170690589486618,-14.014835725355354,-13.858980861224119,-13.703125997092853,-13.547271132961587,-13.39141626883032,-13.235561404699082,-13.079706540567816,-12.923851676436552,-12.767996812305316,-12.61214194817405,-12.456287084042785,-12.30043221991155,-12.144577355780283,-11.988722491649018,-11.832867627517754,-11.677012763386516,-11.52115789925525,-11.365303035123983,-11.209448170992747,-11.053593306861483,-10.930003575452043,-10.829460367415344,-10.728917159378623,-10.628373951341906,-10.527830743305206,-10.427287535268487,-10.32674432723177,-10.226201119195052,-10.125657911158351,-10.025114703121634,-9.924571495084914,-9.824028287048217,-9.723485079011498,-9.62294187097478,-9.522398662938079,-9.421855454901362,-9.321312246864643,-9.220769038827925,-9.120225830791224,-9.019682622754507,-8.919139414717788,-8.81859620668109,-8.71805299864437,-8.617509790607652,-8.516966582570952,-8.416423374534235,-8.315880166497516,-8.215336958460817,-8.111652899625573,-8.005092875941777,-7.898532852257984,-7.791972828574206,-7.685412804890411,-7.578852781206615,-7.472292757522837,-7.365732733839042,-7.259172710155247,-7.15261268647147,-7.046052662787674,-6.939492639103877,-6.8329326154200825,-6.726372591736306],[-38.38130006041326,-38.421999634473465,-38.46269920853367,-38.50339878259388,-38.54409835665409,-38.58479793071429,-38.62549750477449,-38.6661970788347,-38.706896652894905,-38.74759622695511,-38.788295801015316,-38.82899537507553,-38.869694949135734,-38.91039452319593,-38.95109409725614,-38.99249273164048,-39.034590423721106,-39.07668811580172,-39.11878580788235,-39.16088349996297,-39.202981192043595,-39.24507888412422,-39.28717657620484,-39.32927426828547,-39.37137196036609,-39.41346965244671,-39.45556734452733,-39.497665036607955,-39.53976272868858,-39.581860420769196,-39.62395811284982,-39.666055804930444,-39.70815349701107,-39.75025118909169,-39.792348881172316,-39.83444657325293,-39.87654426533356,-39.91864195741418,-39.960739649494805,-40.00283734157543,-40.044935033656046,-40.08703272573667,-40.129130417817294,-40.17122810989792,-40.21332580197854,-40.255423494059166,-40.29752118613979,-40.339618878220406,-40.38171657030103,-40.423814262381654,-40.46591195446227,-40.5080096465429,-40.55010733862352,-40.59220503070414,-40.63430272278477,-40.676400414865384,-40.718498106946015,-40.76059579902663,-40.802693491107256,-40.84479118318788,-40.886888875268504,-40.92898656734912,-40.971084259429745,-41.01318195151037,-41.05527964359099,-41.09737733567162,-41.13947502775224,-41.18157271983286,-41.22367041191348,-41.265768103994105,-41.30786579607473,-41.34996348815535,-41.39206118023597,-41.434158872316594,-41.47625656439722,-41.51835425647784,-41.560451948558466,-41.60254964063908,-41.64464733271971,-41.68674502480033,-41.728842716880955,-41.77094040896157,-41.813038101042196,-41.85513579312282,-41.893317712470925,-41.930716477272526,-41.968115242074134,-42.005514006875735,-42.04291277167734,-42.08031153647894,-42.11771030128054,-42.15510906608215,-42.19250783088375,-42.22990659568535,-42.26730536048696,-42.30470412528855,-42.34210289009017,-42.37950165489176,-42.41713364535677,-42.45523208517598,-42.49333052499519,-42.531428964814395,-42.5695274046336,-42.6076258444528,-42.645724284272006,-42.683822724091215,-42.72192116391042,-42.76001960372963,-42.79811804354883,-42.836216483368034,-42.87431492318724,-42.91241336300645,-42.95051180282566,-42.98861024264486,-43.02670868246406,-43.06480712228327,-43.10290556210248,-43.14100400192168,-43.17910244174088,-43.21720088156009,-43.2552993213793,-43.293397761198506,-43.331496201017714,-43.369594640836915,-43.40769308065612,-43.445791520475325,-43.48388996029453,-43.52198840011374,-43.56008683993294,-43.59818527975215,-43.63628371957135,-43.67438215939056,-43.71248059920977,-43.75057903902897,-43.78867747884818,-43.82677591866738,-43.86487435848659,-43.9029727983058,-43.941071238125005,-43.979169677944206,-44.017268117763415,-44.055366557582616,-44.093464997401824,-44.131563437221025,-44.169661877040234,-44.207760316859435,-44.24585875667864,-44.28395719649785,-44.32205563631705,-44.36015407613627,-44.39825251595547,-44.43635095577467,-44.47444939559388,-44.51254783541309,-44.550646275232296,-44.5887447150515,-44.6268431548707,-44.66494159468991,-44.703040034509115,-44.74113847432832,-44.779236914147525,-44.81733535396673,-44.855433793785934,-44.89353223360514,-44.93163067342435,-44.96972911324355,-45.00782755306276,-44.99857962231761,-44.96565850629029,-44.93273739026297,-44.899816274235654,-44.86689515820833,-44.83397404218101,-44.801052926153695,-44.76813181012636,-44.73521069409905,-44.70228957807173,-44.6693684620444,-44.636447346017086,-44.60352622998977,-44.57060511396245,-44.537683997935126,-44.50476288190781,-44.471841765880484,-44.41958160666585,-44.352377682333085,-44.28517375800032,-44.217969833667546,-44.15076590933477,-44.08356198500201,-44.01635806066924,-43.949154136336475,-43.88195021200371,-43.814746287670935,-43.74754236333817,-43.680338439005396,-43.61313451467263,-43.545930590339864,-43.4787266660071,-43.41152274167433,-43.34431881734156,-43.27711489300879,-43.20991096867602,-43.142707044343254,-43.07550312001049,-43.00829919567772,-42.94109527134495,-42.87389134701219,-42.80668742267942,-42.73948349834665,-42.67227957401388,-42.60507564968111,-42.537871725348346,-42.47066780101558,-42.40346387668281,-42.33625995235004,-42.26905602801727,-42.2018521036845,-42.13464817935174,-42.06744425501897,-42.000240330686196,-41.93303640635343,-41.865832482020664,-41.7986285576879,-41.731424633355125,-41.66422070902236,-41.597016784689586,-41.52981286035682,-41.462608936024054,-41.39540501169128,-41.32820108735852,-41.26099716302575,-41.19379323869299,-41.12658931436022,-41.05938539002745,-40.99218146569468,-40.92497754136191,-40.85777361702914,-40.79056969269638,-40.72336576836361,-40.656161844030834,-40.588957919698075,-40.5217539953653,-40.454550071032536,-40.38734614669977,-40.320142222367,-40.25293829803423,-40.185734373701465,-40.11853044936869,-40.051326525035925,-39.91326337308382,-39.70434099351237,-39.495418613940934,-39.2864962343695,-39.077573854798054,-38.86865147522663,-38.65972909565519,-38.45080671608374,-38.241884336512285,-38.03296195694088,-37.824039577369426,-37.61511719779798,-37.406194818226545,-37.19727243865511,-36.98835005908366,-36.77942767951223,-36.57050529994079,-36.361582920369344,-36.15266054079791,-35.943738161226484,-35.73481578165503,-35.525893402083575,-35.31697102251216,-35.108048642940716,-34.89912626336927,-34.690203883797835,-34.48128850279556,-34.272586574904835,-34.063884647014135,-33.855182719123434,-33.64648079123271,-33.43777886334198,-33.22907693545131,-33.02037500756058,-32.811673079669866,-32.602971151779165,-32.39426922388846,-32.185567295997735,-31.976865368107035,-31.768163440216334,-31.559461512325612,-31.350759584434908,-31.142057656544207,-30.93335572865349,-30.72465380076276,-30.515951872872083,-30.307249944981358,-30.098548017090636,-29.88984608919993,-29.68114416130923,-29.472442233418512,-29.26374030552781,-29.05503837763711,-28.84633644974638,-28.637634521855666,-28.42893259396498,-28.220230666074265,-28.01152873818354,-27.80282681029284,-27.594124882402134,-27.385422954511412,-27.176721026620704,-26.968019098730004,-26.75931717083929,-26.550615242948584,-26.341913315057884,-26.133211387167158,-25.924509459276436,-25.715807531385753,-25.507105603495035,-25.298403675604316,-25.08970174771361,-24.88099981982291,-24.672297891932185,-24.463595964041485,-24.25489403615078,-24.046192108260065,-23.837490180369365,-23.62878825247866,-23.420086324587935,-23.211384396697213,-23.002682468806512,-22.79398054091581,-22.635491767242886,-22.577429302005513,-22.519366836768143,-22.461304371530765,-22.403241906293395,-22.345179441056025,-22.287116975818645,-22.229054510581268,-22.170992045343905,-22.112929580106528,-22.05486711486915,-21.99680464963178,-21.938742184394407,-21.88067971915703,-21.82261725391966,-21.76455478868229,-21.70649232344491,-21.64842985820754,-21.59036739297017,-21.532304927732792,-21.47424246249541,-21.41617999725804,-21.35811753202067,-21.300055066783294,-21.241992601545924,-21.183930136308554,-21.125867671071177,-21.067805205833803,-21.009742740596433,-20.95168027535906,-20.893617810121683,-20.835555344884316,-20.777492879646935,-20.719430414409562,-20.66136794917219,-20.603305483934818,-20.545243018697445,-20.48718055346007,-20.429118088222697,-20.371055622985324,-20.312993157747947,-20.254930692510577,-20.196921568278846,-20.138939114290515,-20.080956660302192,-20.02297420631387,-19.96499175232554,-19.907009298337215,-19.84902684434889,-19.79104439036056,-19.733061936372234,-19.67507948238391,-19.617097028395584,-19.559114574407253,-19.501132120418934,-19.4431496664306,-19.385167212442273,-19.32718475845395,-19.269202304465622,-19.211219850477292,-19.15323739648897,-19.095254942500645,-19.037272488512315,-18.97929003452399,-18.921307580535668,-18.863325126547338,-18.805342672559007,-18.74736021857069,-18.689377764582357,-18.63139531059403,-18.573412856605707,-18.51543040261738,-18.457447948629053,-18.399465494640722,-18.341483040652403,-18.283500586664072,-18.22551813267574,-18.167535678687422,-18.10955322469909,-18.051570770710764,-17.993588316722438,-17.935605862734114,-17.877623408745784,-17.802316349816735,-17.640386266184038,-17.478456182551334,-17.316526098918636,-17.154596015285968,-16.992665931653264,-16.830735848020566,-16.668805764387898,-16.506875680755194,-16.344945597122493,-16.18301551348982,-16.021085429857123,-15.859155346224423,-15.697225262591722,-15.535295178959053,-15.37336509532635,-15.211435011693649,-15.04950492806098,-14.88757484442828,-14.725644760795578,-14.56371467716291,-14.40178459353021,-14.239854509897508,-14.077924426264836,-13.915994342632137,-13.754064258999437,-13.592134175366736,-13.430204091734065,-13.268274008101365,-13.106343924468664,-12.944413840835994,-12.782483757203293,-12.625071874765453,-12.469217010634216,-12.31336214650295,-12.157507282371686,-12.001652418240418,-11.845797554109183,-11.689942689977919,-11.534087825846651,-11.378232961715415,-11.222378097584151,-11.098788366174709,-10.99824515813801,-10.897701950101292,-10.797158742064573,-10.696615534027872,-10.596072325991155,-10.495529117954435,-10.394985909917718,-10.29444270188102,-10.1938994938443,-10.090811433219882,-9.984251409536105,-9.877691385852309,-9.771131362168513,-9.664571338484738,-9.558011314800943,-9.451451291117145,-9.34489126743335,-9.238331243749574,-9.131771220065778,-9.025211196381981,-8.918651172698205,-8.81209114901441,-8.705531125330614,-8.598971101646837,-8.492411077963041,-8.385851054279245,-8.279291030595468,-8.172731006911674,-8.066170983227877,-7.959610959544081,-7.853050935860305,-7.746490912176509,-7.639930888492714,-7.533370864808937,-7.426810841125141,-7.3202508174413445,-7.21369079375757,-7.107130770073773,-7.000570746389977,-6.894010722706181,-6.787450699022406],[-38.03593061017217,-38.07663018423238,-38.117329758292584,-38.15802933235279,-38.198728906412995,-38.2394284804732,-38.280128054533414,-38.32082762859362,-38.361527202653825,-38.40222677671403,-38.442926350774236,-38.48362592483444,-38.52432549889464,-38.56502507295485,-38.60572464701506,-38.646424221075264,-38.68712379513547,-38.727823369195676,-38.76852294325588,-38.80922251731609,-38.8499220913763,-38.8906216654365,-38.931321239496704,-38.97202081355691,-39.012720387617115,-39.05341996167732,-39.094119535737526,-39.13481910979773,-39.17551868385794,-39.21621825791814,-39.256917831978356,-39.2976174071218,-39.339715099202415,-39.381812791283046,-39.42391048336366,-39.46600817544428,-39.50810586752491,-39.55020355960553,-39.59230125168616,-39.63439894376678,-39.67649663584739,-39.718594327928024,-39.76069202000864,-39.80278971208927,-39.844887404169896,-39.88698509625051,-39.929082788331144,-39.97118048041176,-40.01327817249238,-40.055375864573,-40.097473556653625,-40.13957124873425,-40.18166894081487,-40.22376663289549,-40.265864324976114,-40.30796201705674,-40.35005970913736,-40.392157401217986,-40.43425509329861,-40.476352785379234,-40.51845047745985,-40.56054816954048,-40.6026458616211,-40.64474355370172,-40.68684124578235,-40.72893893786297,-40.77103662994359,-40.81313432202421,-40.855232014104836,-40.89732970618546,-40.93942739826608,-40.98152509034671,-41.023622782427324,-41.06572047450795,-41.10781816658857,-41.149915858669196,-41.19201355074982,-41.23411124283044,-41.27620893491106,-41.318306626991685,-41.36040431907231,-41.40250201115293,-41.44459970323355,-41.486697395314174,-41.52487931466228,-41.56227807946388,-41.59967684426548,-41.63707560906708,-41.67447437386869,-41.711873138670285,-41.74927190347189,-41.786670668273494,-41.824069433075096,-41.861468197876704,-41.89886696267831,-41.936265727479906,-41.973664492281515,-42.01106325708311,-42.04846202188472,-42.085860786686325,-42.12325955148792,-42.16065831628953,-42.19805708109112,-42.23545584589273,-42.27285461069433,-42.31025337549593,-42.34765214029754,-42.385050905099135,-42.42244966990074,-42.459848434702344,-42.497247199503946,-42.534645964305554,-42.57204472910715,-42.609443493908756,-42.64684225871036,-42.684824086568725,-42.72292252638793,-42.76102096620714,-42.799119406026335,-42.837217845845544,-42.87531628566475,-42.91341472548396,-42.95151316530317,-42.98961160512236,-43.02771004494158,-43.06580848476078,-43.10390692457999,-43.142005364399196,-43.1801038042184,-43.218202244037606,-43.25630068385681,-43.294399123676016,-43.332497563495224,-43.370596003314425,-43.40869444313363,-43.446792882952835,-43.48489132277204,-43.52298976259125,-43.56108820241046,-43.59918664222966,-43.63728508204886,-43.67538352186807,-43.71348196168728,-43.75158040150648,-43.78967884132569,-43.82777728114489,-43.8658757209641,-43.90397416078331,-43.942072600602515,-43.98017104042172,-44.018269480240924,-44.056367920060126,-44.09446635987933,-44.132564799698535,-44.17066323951775,-44.20876167933695,-44.24686011915616,-44.28495855897536,-44.32305699879457,-44.36115543861377,-44.39925387843298,-44.43735231825219,-44.47545075807139,-44.5135491978906,-44.5516476377098,-44.58974607752901,-44.62784451734821,-44.61859658660307,-44.58567547057575,-44.552754354548426,-44.5198332385211,-44.48691212249378,-44.45399100646647,-44.42106989043914,-44.388148774411825,-44.3552276583845,-44.32230654235718,-44.289385426329865,-44.25646431030255,-44.22354319427522,-44.1906220782479,-44.15770096222058,-44.12477984619326,-44.091858730165946,-44.05893761413862,-44.026016498111304,-43.99309538208398,-43.960174266056654,-43.92725315002934,-43.89433203400202,-43.861410917974695,-43.828489801947384,-43.79556868592006,-43.762647569892735,-43.72972645386542,-43.6968053378381,-43.663884221810775,-43.63096310578345,-43.59804198975613,-43.56512087372881,-43.53219975770149,-43.49927864167417,-43.46635752564684,-43.42992022464321,-43.362716300310446,-43.29551237597768,-43.228308451644914,-43.16110452731215,-43.093900602979375,-43.0266966786466,-42.959492754313835,-42.89228882998107,-42.8250849056483,-42.75788098131554,-42.690677056982764,-42.62347313264999,-42.55626920831723,-42.489065283984466,-42.4218613596517,-42.35465743531893,-42.287453510986154,-42.22024958665339,-42.15304566232062,-42.085841737987856,-42.01863781365509,-41.95143388932232,-41.88422996498955,-41.817026040656785,-41.74982211632401,-41.682618191991246,-41.61541426765847,-41.548210343325714,-41.48100641899294,-41.413802494660175,-41.34659857032741,-41.279394645994635,-41.21219072166187,-41.1449867973291,-41.07778287299634,-41.010578948663564,-40.9433750243308,-40.87617109999803,-40.80896717566526,-40.74176325133249,-40.67455932699973,-40.607355402666954,-40.54015147833419,-40.47294755400142,-40.40574362966865,-40.33853970533588,-40.20047655338378,-39.99155417381233,-39.7826317942409,-39.573709414669466,-39.36478703509802,-39.155864655526585,-38.94694227595515,-38.7380198963837,-38.52909751681225,-38.32017513724084,-38.11125275766939,-37.90233037809793,-37.693407998526496,-37.48448561895508,-37.275563239383615,-37.06664085981219,-36.85771848024076,-36.6487961006693,-36.439873721097875,-36.23095134152644,-36.02202896195499,-35.81310658238354,-35.60418420281212,-35.39526182324067,-35.186339443669226,-34.97741706409779,-34.76849468452636,-34.55957230495491,-34.35064992538348,-34.141727545812046,-33.9328051662406,-33.723882786669144,-33.51496040709773,-33.306038027526284,-33.09711564795483,-32.888193268383404,-32.67927088881196,-32.470348509240516,-32.26142612966909,-32.05250375009764,-31.843581370526195,-31.63465899095476,-31.425736611383336,-31.21681423181188,-31.007891852240434,-30.79896947266902,-30.590047093097567,-30.381124713526116,-30.172202333954687,-29.963279954383253,-29.754357574811802,-29.545435195240373,-29.33651281566894,-29.127590436097485,-28.918668056526037,-28.709745676954626,-28.50082329738317,-28.292102123434482,-28.08340019554378,-27.874698267653077,-27.66599633976236,-27.457294411871658,-27.248592483980957,-27.03989055609023,-26.83118862819953,-26.62248670030883,-26.41378477241811,-26.205082844527386,-25.996380916636703,-25.78767898874598,-25.578977060855262,-25.370275132964558,-25.161573205073857,-24.952871277183135,-24.74416934929243,-24.53546742140173,-24.32676549351101,-24.118063565620304,-23.909361637729603,-23.70065970983888,-23.491957781948162,-23.283255854057458,-23.074553926166754,-22.916065152493832,-22.85800268725646,-22.79994022201909,-22.74187775678171,-22.68381529154434,-22.62575282630697,-22.567690361069594,-22.509627895832217,-22.45156543059485,-22.393502965357474,-22.335440500120097,-22.277378034882723,-22.219315569645353,-22.161253104407976,-22.103190639170606,-22.045128173933236,-21.98706570869586,-21.92900324345849,-21.87094077822112,-21.812878312983738,-21.75481584774636,-21.69675338250899,-21.638690917271617,-21.58062845203424,-21.52256598679687,-21.4645035215595,-21.406441056322123,-21.348378591084753,-21.290316125847383,-21.232253660610006,-21.174191195372625,-21.11612873013526,-21.05806626489788,-21.000003799660504,-20.941941334423134,-20.883878869185764,-20.825816403948387,-20.767753938711017,-20.709691473473647,-20.65162900823627,-20.593566542998893,-20.535504077761523,-20.477441612524146,-20.41937914728677,-20.3613166820494,-20.303254216812032,-20.245191751574655,-20.18712928633728,-20.12906682109991,-20.071004355862534,-20.01294189062516,-19.954879425387787,-19.896816960150414,-19.838754494913037,-19.78069202967567,-19.722629564438293,-19.66456709920092,-19.606504633963546,-19.548442168726176,-19.4903797034888,-19.43231723825143,-19.374254773014055,-19.31619230777668,-19.258129842539308,-19.200067377301938,-19.14200491206456,-19.083942446827184,-19.025879981589817,-18.96781751635244,-18.909755051115063,-18.851692585877693,-18.79363012064032,-18.735567655402946,-18.677505190165576,-18.6194427249282,-18.56138025969082,-18.503317794453448,-18.44525532921608,-18.387192863978704,-18.329130398741324,-18.271125275041687,-18.213142821053363,-18.155160367065033,-18.079853308135988,-17.917923224503287,-17.755993140870583,-17.594063057237886,-17.432132973605214,-17.270202889972513,-17.108272806339812,-16.946342722707143,-16.783455151078755,-16.620282917824277,-16.457110684569834,-16.293938451315356,-16.13076621806088,-15.967593984806403,-15.804421751551956,-15.641249518297483,-15.478077285043007,-15.31490505178856,-15.151732818534088,-14.98856058527961,-14.825388352025165,-14.66221611877069,-14.499043885516214,-14.335871652261767,-14.172699419007293,-14.009527185752816,-13.846354952498341,-13.683182719243895,-13.52001048598942,-13.356838252734944,-13.1936660194805,-13.030493786226025,-12.867321552971546,-12.704149319717102,-12.540977086462625,-12.37780485320815,-12.214632619953676,-12.05146038669923,-11.888288153444753,-11.725115920190277,-11.561943686935832,-11.398771453681357,-11.267750534891686,-11.159694840719744,-11.051639146547785,-10.943583452375822,-10.835527758203884,-10.727472064031922,-10.619416369859962,-10.511360675688001,-10.40330498151606,-10.2952492873441,-10.18719359317214,-10.079137899000198,-9.971082204828237,-9.863026510656276,-9.754970816484336,-9.646915122312375,-9.538859428140414,-9.430803733968453,-9.322748039796513,-9.214692345624552,-9.106636651452591,-8.99858095728065,-8.89052526310869,-8.782469568936728,-8.674413874764788,-8.566358180592829,-8.458302486420866,-8.350246792248926,-8.242191098076965,-8.134135403905004,-8.026079709733043,-7.9180240155611035,-7.809968321389142,-7.701912627217183,-7.594448972095035,-7.487888948411239,-7.381328924727444,-7.274768901043669,-7.168208877359872,-7.0616488536760755,-6.95508882999228,-6.8485288063085035],[-37.6905611599311,-37.731260733991306,-37.771960308051504,-37.81265988211172,-37.85335945617192,-37.89405903023213,-37.934758604292334,-37.97545817835254,-38.01615775241275,-38.05685732647295,-38.097556900533164,-38.13825647459336,-38.17895604865357,-38.21965562271377,-38.260355196773986,-38.301054770834185,-38.3417543448944,-38.382453918954596,-38.4231534930148,-38.46385306707501,-38.50455264113522,-38.54525221519542,-38.58595178925563,-38.62665136331584,-38.66735093737604,-38.70805051143624,-38.748750085496454,-38.78944965955666,-38.830149233616865,-38.87084880767706,-38.911548381737276,-38.95224795579748,-38.99294752985769,-39.03364710391789,-39.074346677978106,-39.11504625203831,-39.15574582609851,-39.196445400158716,-39.23714497421892,-39.27784454827913,-39.31854412233934,-39.359243696399545,-39.39994327045975,-39.44064284451996,-39.481342418580155,-39.52204199264036,-39.56274156670057,-39.60344114076078,-39.64483977468374,-39.686937466764356,-39.72903515884499,-39.7711328509256,-39.813230543006235,-39.85532823508685,-39.89742592716747,-39.9395236192481,-39.981621311328716,-40.02371900340935,-40.065816695489964,-40.10791438757059,-40.15001207965121,-40.192109771731836,-40.23420746381246,-40.27630515589308,-40.3184028479737,-40.360500540054325,-40.40259823213494,-40.444695924215566,-40.4867936162962,-40.528891308376814,-40.57098900045744,-40.61308669253806,-40.655184384618686,-40.69728207669931,-40.739379768779926,-40.78147746086055,-40.823575152941174,-40.8656728450218,-40.90777053710242,-40.94986822918304,-40.99196592126367,-41.03406361334429,-41.076161305424904,-41.118258997505535,-41.15644091685364,-41.193839681655234,-41.23123844645684,-41.268637211258444,-41.306035976060045,-41.343434740861646,-41.38083350566325,-41.418232270464856,-41.45563103526646,-41.49302980006806,-41.530428564869666,-41.56782732967126,-41.60522609447287,-41.64262485927447,-41.68002362407608,-41.71742238887768,-41.75482115367927,-41.79221991848088,-41.82961868328249,-41.867017448084084,-41.90441621288569,-41.941814977687294,-41.979213742488895,-42.0166125072905,-42.0540112720921,-42.091410036893706,-42.12880880169531,-42.16620756649691,-42.203606331298516,-42.24100509610011,-42.27840386090172,-42.31580262570331,-42.35320139050492,-42.390600155306515,-42.42799892010813,-42.46539768490973,-42.50279644971134,-42.540195214512934,-42.577593979314535,-42.614992744116144,-42.65239150891774,-42.68979027371934,-42.72718903852095,-42.764587803322556,-42.80198656812415,-42.83938533292576,-42.87678409772736,-42.914416087961484,-42.952514527780686,-42.99061296759989,-43.028711407419095,-43.066809847238304,-43.104908287057505,-43.14300672687671,-43.18110516669592,-43.21920360651512,-43.25730204633433,-43.29540048615353,-43.33349892597275,-43.37159736579195,-43.40969580561116,-43.44779424543036,-43.48589268524957,-43.523991125068775,-43.56208956488798,-43.60018800470718,-43.638286444526386,-43.676384884345595,-43.714483324164796,-43.752581763984004,-43.790680203803205,-43.828778643622414,-43.86687708344162,-43.90497552326082,-43.94307396308003,-43.98117240289924,-44.01927084271845,-44.05736928253765,-44.09546772235685,-44.13356616217606,-44.17166460199527,-44.209763041814476,-44.24786148163368,-44.23861355088853,-44.205692434861206,-44.172771318833895,-44.13985020280657,-44.106929086779246,-44.07400797075193,-44.04108685472461,-44.008165738697286,-43.97524462266996,-43.94232350664265,-43.90940239061533,-43.87648127458801,-43.843560158560685,-43.81063904253337,-43.77771792650604,-43.74479681047872,-43.71187569445141,-43.67895457842408,-43.64603346239676,-43.61311234636944,-43.580191230342116,-43.5472701143148,-43.51434899828748,-43.481427882260164,-43.44850676623284,-43.415585650205514,-43.382664534178204,-43.34974341815088,-43.316822302123555,-43.28390118609624,-43.25098007006891,-43.218058954041595,-43.18513783801427,-43.152216721986946,-43.119295605959636,-43.08637448993231,-43.05345337390499,-43.020532257877676,-42.98761114185035,-42.95469002582303,-42.921768909795716,-42.88884779376839,-42.85592667774107,-42.82300556171375,-42.79008444568643,-42.75716332965911,-42.72424221363178,-42.69132109760446,-42.65839998157715,-42.62547886554982,-42.592557749522506,-42.55963663349519,-42.52671551746786,-42.493794401440546,-42.46087328541322,-42.427952169385904,-42.373054918287814,-42.30585099395504,-42.238647069622274,-42.17144314528951,-42.10423922095674,-42.03703529662397,-41.9698313722912,-41.90262744795843,-41.835423523625664,-41.76821959929289,-41.70101567496013,-41.633811750627366,-41.56660782629459,-41.49940390196183,-41.432199977629054,-41.36499605329629,-41.29779212896352,-41.230588204630756,-41.16338428029799,-41.09618035596522,-41.028976431632444,-40.96177250729968,-40.89456858296691,-40.827364658634146,-40.76016073430138,-40.69295680996861,-40.62575288563584,-40.48768973368374,-40.27876735411228,-40.06984497454085,-39.86092259496942,-39.65200021539797,-39.443077835826536,-39.2341554562551,-39.025233076683655,-38.8163106971122,-38.60738831754079,-38.39846593796934,-38.18954355839789,-37.98062117882646,-37.77169879925503,-37.56277641968357,-37.35385404011215,-37.14493166054071,-36.93600928096926,-36.727086901397826,-36.51816452182639,-36.309242142254945,-36.1003197626835,-35.89139738311208,-35.68247500354063,-35.473552623969184,-35.26463024439775,-35.05570786482632,-34.84678548525486,-34.63786310568344,-34.428940726112,-34.22001834654055,-34.011095966969094,-33.80217358739769,-33.593251207826235,-33.38432882825478,-33.175406448683354,-32.96648406911192,-32.75756168954047,-32.54863930996904,-32.33971693039761,-32.13079455082615,-31.921872171254723,-31.712949791683286,-31.50402741211184,-31.295105032540388,-31.086182652968972,-30.877260273397525,-30.66833789382607,-30.45941551425464,-30.250493134683207,-30.041570755111756,-29.832648375540327,-29.62372599596889,-29.41480361639744,-29.20588123682599,-28.99695885725458,-28.78803647768313,-28.579114098111678,-28.37019171854024,-28.161269338968815,-27.95234695939736,-27.743424579825927,-27.5345022002545,-27.325579820683046,-27.116657441111613,-26.907735061540183,-26.698812681968732,-26.489890302397278,-26.280967922825866,-26.07204554325442,-25.863123163682964,-25.654200784111538,-25.4452784045401,-25.23635602496865,-25.027433645397224,-24.81851126582579,-24.609588886254336,-24.40047706934916,-24.19131703353272,-23.982156997716256,-23.772996961899796,-23.563836926083347,-23.354676890266905,-23.19604477324225,-23.13846849380117,-23.080892214360087,-23.023315934918998,-22.96573965547792,-22.907930469113474,-22.849958526185368,-22.791986583257263,-22.734014640329168,-22.676042697401066,-22.61807075447296,-22.56009881154486,-22.50212686861676,-22.444154925688657,-22.38618298276056,-22.328211039832457,-22.27023909690435,-22.21226715397625,-22.154295211048154,-22.09632326812005,-22.038351325191947,-21.98037938226385,-21.922407439335743,-21.864435496407637,-21.806463553479546,-21.74849161055144,-21.690519667623338,-21.632547724695236,-21.574575781767138,-21.516603838839035,-21.45863189591093,-21.400659952982835,-21.34268801005473,-21.284716067126624,-21.226744124198525,-21.168772181270423,-21.110800238342318,-21.052828295414223,-20.994856352486124,-20.93688440955802,-20.878912466629917,-20.820940523701818,-20.762968580773716,-20.70499663784561,-20.647024694917512,-20.589052751989406,-20.531080809061304,-20.47310886613321,-20.415136923205107,-20.357164980277002,-20.2991930373489,-20.2412210944208,-20.1832491514927,-20.125277208564594,-20.0673052656365,-20.009333322708393,-19.951361379780288,-19.893389436852193,-19.83541749392409,-19.777445550995985,-19.719473608067883,-19.661501665139788,-19.603529722211682,-19.545557779283584,-19.487585836355485,-19.42961389342738,-19.371641950499274,-19.31367000757118,-19.255698064643077,-19.19772612171497,-19.139754178786873,-19.081782235858775,-19.02381029293067,-18.965838350002567,-18.907866407074472,-18.849894464146363,-18.79192252121826,-18.733950578290163,-18.67597863536206,-18.61800669243396,-18.560034749505856,-18.502062806577758,-18.444090863649656,-18.367592986124563,-18.198465435614498,-18.02933788510443,-17.860210334594363,-17.69108278408433,-17.52195523357426,-17.352827683064195,-17.183700132554158,-17.014572582044096,-16.845445031534027,-16.676317481023986,-16.507189930513924,-16.338062380003855,-16.168934829493786,-15.999807278983752,-15.830679728473683,-15.661552177963618,-15.49423457896047,-15.331062345705993,-15.16789011245152,-15.004717879197074,-14.841545645942595,-14.67837341268812,-14.515201179433678,-14.3520289461792,-14.188856712924725,-14.025684479670247,-13.862512246415802,-13.699340013161327,-13.53616777990685,-13.372995546652406,-13.20982331339793,-13.046651080143455,-12.883478846889007,-12.720306613634532,-12.557134380380058,-12.393962147125581,-12.230789913871137,-12.067617680616658,-11.904445447362184,-11.74127321410774,-11.578100980853264,-11.447080062063593,-11.339024367891652,-11.230968673719694,-11.122912979547731,-11.01485728537579,-10.90680159120383,-10.798745897031868,-10.690690202859907,-10.582634508687967,-10.474578814516008,-10.366523120344047,-10.258467426172105,-10.150411732000144,-10.042356037828183,-9.934300343656243,-9.826244649484282,-9.718188955312321,-9.61013326114036,-9.50207756696842,-9.39402187279646,-9.285966178624498,-9.177910484452559,-9.069854790280598,-8.961799096108635,-8.853743401936693,-8.740431503831513,-8.626283388920864,-8.512135274010237,-8.39798715909959,-8.283839044188941,-8.169690929278293,-8.055542814367666,-7.9413946994570175,-7.827246584546368,-7.713098469635742,-7.598950354725094,-7.484802239814446,-7.370654124903819,-7.256506009993171,-7.1423578950825215,-7.028209780171874,-6.914061665261247],[-37.34519170969001,-37.38589128375022,-37.426590857810424,-37.46729043187063,-37.507990005930836,-37.54868957999104,-37.58938915405125,-37.63008872811145,-37.67078830217166,-37.71148787623187,-37.75218745029207,-37.79288702435228,-37.83358659841248,-37.874286172472694,-37.91498574653289,-37.955685320593105,-37.9963848946533,-38.037084468713516,-38.07778404277372,-38.11848361683393,-38.15918319089413,-38.19988276495434,-38.24058233901454,-38.28128191307475,-38.321981487134956,-38.36268106119516,-38.40338063525537,-38.44408020931557,-38.48477978337578,-38.525479357435984,-38.5661789314962,-38.606878505556395,-38.64757807961661,-38.688277653676806,-38.72897722773702,-38.76967680179722,-38.81037637585743,-38.85107594991763,-38.89177552397784,-38.93247509803804,-38.97317467209825,-39.01387424615845,-39.054573820218664,-39.09527339427887,-39.135972968339075,-39.176672542399274,-39.21737211645949,-39.25807169051969,-39.298771264579905,-39.33947083864011,-39.380170412700316,-39.42086998676052,-39.46156956082073,-39.502269134880926,-39.54296870894113,-39.58366828300134,-39.62436785706154,-39.665067431121756,-39.70576700518196,-39.74646657924217,-39.78716615330237,-39.82786572736258,-39.868565301422784,-39.90926487548299,-39.94996445016505,-39.99206214224567,-40.034159834326296,-40.07625752640692,-40.11835521848754,-40.16045291056816,-40.202550602648785,-40.24464829472941,-40.28674598681003,-40.32884367889065,-40.37094137097127,-40.4130390630519,-40.45513675513252,-40.497234447213145,-40.53933213929377,-40.581429831374386,-40.62352752345501,-40.665625215535634,-40.70772290761626,-40.74982059969688,-40.78800251904499,-40.82540128384659,-40.8628000486482,-40.90019881344979,-40.9375975782514,-40.974996343053,-41.0123951078546,-41.04979387265621,-41.087192637457804,-41.12459140225941,-41.16199016706101,-41.199388931862615,-41.23678769666422,-41.274186461465824,-41.311585226267425,-41.34898399106903,-41.38638275587063,-41.423781520672236,-41.461180285473844,-41.49857905027544,-41.53597781507705,-41.57337657987864,-41.61077534468025,-41.64817410948184,-41.68557287428345,-41.72297163908506,-41.760370403886654,-41.79776916868826,-41.835167933489856,-41.872566698291465,-41.90996546309307,-41.94736422789467,-41.98476299269627,-42.02216175749787,-42.059560522299485,-42.09695928710108,-42.13435805190269,-42.17175681670429,-42.20915558150588,-42.2465543463075,-42.28395311110909,-42.32135187591069,-42.3587506407123,-42.396149405513896,-42.433548170315504,-42.47094693511711,-42.508345699918706,-42.545744464720315,-42.58314322952191,-42.62054199432352,-42.657940759125125,-42.69533952392672,-42.73273828872833,-42.770137053529936,-42.80753581833153,-42.84493458313314,-42.88233334793473,-42.91973211273634,-42.957130877537935,-42.99452964233954,-43.03192840714115,-43.069327171942746,-43.106725936744354,-43.14412470154596,-43.18210652917343,-43.22020496899263,-43.25830340881184,-43.29640184863105,-43.33450028845025,-43.37259872826946,-43.41069716808866,-43.44879560790787,-43.48689404772708,-43.52499248754628,-43.56309092736549,-43.601189367184695,-43.639287807003896,-43.677386246823104,-43.715484686642306,-43.753583126461514,-43.79168156628072,-43.82978000609993,-43.867878445919125,-43.858630515173985,-43.82570939914667,-43.79278828311934,-43.759867167092025,-43.7269460510647,-43.69402493503739,-43.661103819010066,-43.62818270298274,-43.595261586955424,-43.5623404709281,-43.52941935490078,-43.49649823887346,-43.46357712284614,-43.430656006818815,-43.3977348907915,-43.36481377476418,-43.33189265873686,-43.29897154270954,-43.26605042668221,-43.2331293106549,-43.20020819462758,-43.16728707860025,-43.134365962572936,-43.10144484654561,-43.068523730518294,-43.03560261449097,-43.00268149846365,-42.969760382436334,-42.93683926640901,-42.9039181503817,-42.87099703435437,-42.83807591832706,-42.80515480229973,-42.77223368627241,-42.73931257024509,-42.706391454217766,-42.67347033819044,-42.64054922216312,-42.6076281061358,-42.57470699010849,-42.541785874081164,-42.50886475805384,-42.47594364202652,-42.443022525999204,-42.41010140997188,-42.377180293944555,-42.34425917791724,-42.31133806188992,-42.2784169458626,-42.24549582983528,-42.21257471380795,-42.17965359778064,-42.14673248175332,-42.113811365726,-42.080890249698676,-42.04796913367135,-42.01504801764404,-41.98212690161672,-41.94920578558939,-41.916284669562074,-41.88336355353475,-41.85044243750743,-41.81752132148011,-41.78460020545279,-41.75167908942547,-41.71875797339815,-41.68583685737083,-41.652915741343506,-41.61999462531619,-41.58707350928887,-41.554152393261546,-41.52123127723423,-41.48831016120691,-41.45538904517958,-41.42246792915226,-41.38339353626518,-41.31618961193241,-41.24898568759965,-41.18178176326688,-41.11457783893411,-41.047373914601344,-40.98016999026857,-40.9129660659358,-40.774902913983695,-40.56598053441225,-40.35705815484081,-40.148135775269374,-39.93921339569793,-39.7302910161265,-39.52136863655507,-39.31244625698362,-39.10352387741216,-38.894601497840746,-38.6856791182693,-38.47675673869785,-38.26783435912641,-38.058911979554985,-37.84998959998353,-37.641067220412104,-37.43214484084067,-37.22322246126922,-37.01430008169778,-36.80537770212636,-36.5964553225549,-36.387532942983455,-36.17842112613513,-35.96926109031867,-35.7601010545022,-35.55094101868576,-35.34178098286932,-35.13262094705286,-34.92346091123641,-34.714300875419966,-34.5051408396035,-34.29598080378704,-34.08682076797061,-33.87766073215415,-33.66850069633769,-33.45934066052124,-33.2501806247048,-33.04102058888834,-32.83186055307189,-32.622700517255446,-32.413540481438986,-32.20438044562254,-31.995220409806095,-31.786060373989635,-31.57690033817317,-31.367740302356744,-31.158580266540284,-30.949420230723824,-30.74026019490738,-30.531100159090933,-30.321940123274473,-30.112780087458027,-29.90362005164158,-29.694460015825122,-29.485299980008655,-29.27613994419223,-29.06697990837577,-28.857819872559304,-28.648659836742866,-28.43949980092642,-28.230339765109953,-28.02117972929351,-27.81201969347707,-27.602859657660602,-27.39369962184416,-27.184539586027718,-26.97537955021125,-26.76621951439479,-26.557059478578367,-26.3478994427619,-26.13873940694544,-25.929579371128995,-25.720419335312553,-25.511259299496086,-25.302099263679644,-25.0929392278632,-24.883779192046738,-24.674619156230293,-24.465459120413854,-24.256299084597387,-24.04713904878092,-23.83797901296448,-23.628818977148036,-23.47018686012338,-23.412610580682298,-23.35503430124122,-23.297458021800132,-23.23988174235905,-23.182305462917967,-23.124729183476884,-23.067152904035794,-23.00957662459472,-22.952000345153635,-22.89442406571255,-22.83684778627147,-22.779271506830383,-22.721695227389297,-22.664118947948218,-22.60654266850714,-22.548966389066052,-22.49139010962497,-22.433813830183887,-22.3762375507428,-22.318661271301718,-22.261084991860635,-22.203508712419556,-22.145932432978466,-22.088356153537386,-22.030779874096304,-21.97320359465522,-21.915627315214138,-21.858051035773055,-21.800474756331973,-21.742898476890883,-21.685322197449807,-21.62774591800872,-21.570169638567634,-21.512593359126555,-21.45501707968547,-21.397440800244386,-21.339864520803303,-21.282288241362224,-21.224711961921138,-21.167135682480055,-21.109559403038972,-21.051983123597886,-20.994406844156803,-20.93683056471572,-20.879168699012723,-20.821196756084618,-20.763224813156523,-20.70525287022842,-20.647280927300315,-20.589308984372217,-20.531337041444118,-20.473365098516012,-20.415393155587907,-20.357421212659816,-20.29944926973171,-20.241477326803604,-20.183505383875506,-20.125533440947407,-20.067561498019302,-20.009589555091203,-19.9516176121631,-19.893645669235,-19.835673726306897,-19.7777017833788,-19.719729840450693,-19.66175789752259,-19.603785954594493,-19.54581401166639,-19.487842068738285,-19.429870125810186,-19.371898182882084,-19.313926239953982,-19.255954297025884,-19.197982354097785,-19.14001041116968,-19.08203846824157,-19.02406652531348,-18.966094582385374,-18.908122639457268,-18.85015069652917,-18.79217875360107,-18.73420681067297,-18.65770893314788,-18.48858138263781,-18.319453832127742,-18.150326281617676,-17.981198731107643,-17.812071180597574,-17.642943630087508,-17.473816079577475,-17.304688529067406,-17.13556097855734,-16.966433428047303,-16.797305877537234,-16.628178327027168,-16.459050776517103,-16.289923226007065,-16.120795675497,-15.951668124986933,-15.782540574476897,-15.61341302396683,-15.444285473456763,-15.275157922946725,-15.10603037243666,-14.936902821926594,-14.767775271416555,-14.59864772090649,-14.429520170396422,-14.260392619886355,-14.09126506937632,-13.922137518866254,-13.753009968356189,-13.583882417846151,-13.414754867336082,-13.245627316826015,-13.07649976631598,-12.907372215805914,-12.738244665295845,-12.573291674297492,-12.410119441043046,-12.24694720778857,-12.083774974534094,-11.92060274127965,-11.757430508025173,-11.626409589235504,-11.518353895063562,-11.410298200891603,-11.30224250671964,-11.1941868125477,-11.08613111837574,-10.975238266348066,-10.861090151437418,-10.746942036526791,-10.632793921616143,-10.518645806705495,-10.404497691794866,-10.290349576884218,-10.176201461973571,-10.062053347062944,-9.947905232152294,-9.833757117241646,-9.719609002331,-9.605460887420373,-9.491312772509723,-9.377164657599076,-9.263016542688447,-9.148868427777801,-9.034720312867151,-8.920572197956524,-8.806424083045876,-8.692275968135228,-8.578127853224602,-8.463979738313952,-8.349831623403304,-8.235683508492656,-8.12153539358203,-8.007387278671382,-7.893239163760733,-7.7790910488501055,-7.664942933939457,-7.55079481902881,-7.436646704118184,-7.322498589207535,-7.208350474296886,-7.094202359386238,-6.98005424447561],[-36.99982225944893,-37.04052183350914,-37.081221407569345,-37.12192098162955,-37.162620555689756,-37.20332012974997,-37.24401970381017,-37.28471927787037,-37.325418851930586,-37.36611842599079,-37.406818000051,-37.4475175741112,-37.48821714817141,-37.528916722231614,-37.56961629629183,-37.610315870352025,-37.65101544441223,-37.691715018472436,-37.73241459253265,-37.77311416659285,-37.81381374065305,-37.85451331471326,-37.895212888773464,-37.93591246283368,-37.976612036893876,-38.01731161095408,-38.058011185014294,-38.09871075907449,-38.139410333134705,-38.180109907194904,-38.22080948125512,-38.26150905531533,-38.30220862937553,-38.34290820343574,-38.38360777749594,-38.424307351556145,-38.46500692561635,-38.505706499676556,-38.54640607373676,-38.587105647796974,-38.62780522185717,-38.66850479591738,-38.709204369977584,-38.7499039440378,-38.790603518097996,-38.8313030921582,-38.872002666218414,-38.91270224027862,-38.953401814338825,-38.99410138839903,-39.03480096245924,-39.07550053651944,-39.11620011057965,-39.15689968463985,-39.19759925870006,-39.238298832760265,-39.27899840682047,-39.319697980880676,-39.36039755494088,-39.40109712900109,-39.44179670306129,-39.4824962771215,-39.523195851181704,-39.56389542524191,-39.604594999302115,-39.64529457336232,-39.68599414742253,-39.72669372148273,-39.76739329554294,-39.80809286960314,-39.84879244366335,-39.889492017723555,-39.93019159178376,-39.970891165843966,-40.01159073990417,-40.05229031396438,-40.09298988802458,-40.13368946208479,-40.174389036144994,-40.2150886102052,-40.255788184265406,-40.29718681772699,-40.33928450980761,-40.381382201888236,-40.41956412123635,-40.45696288603795,-40.49436165083955,-40.53176041564115,-40.56915918044276,-40.60655794524436,-40.64395671004596,-40.681355474847564,-40.71875423964917,-40.75615300445077,-40.79355176925238,-40.83095053405397,-40.868349298855584,-40.90574806365718,-40.94314682845879,-40.980545593260395,-41.01794435806199,-41.05534312286359,-41.0927418876652,-41.1301406524668,-41.1675394172684,-41.20493818207,-41.2423369468716,-41.27973571167321,-41.31713447647481,-41.354533241276414,-41.391932006078015,-41.429330770879616,-41.46672953568122,-41.504128300482826,-41.54152706528443,-41.57892583008603,-41.61632459488762,-41.65372335968923,-41.69112212449084,-41.72852088929243,-41.76591965409405,-41.80331841889564,-41.840717183697244,-41.878115948498845,-41.91551471330045,-41.952913478102055,-41.990312242903656,-42.027711007705264,-42.06510977250686,-42.102508537308466,-42.13990730211007,-42.17730606691167,-42.21470483171328,-42.25210359651488,-42.28950236131648,-42.32690112611808,-42.36429989091968,-42.40169865572129,-42.43909742052289,-42.47649618532449,-42.513894950126094,-42.551293714927695,-42.5886924797293,-42.626091244530905,-42.663490009332506,-42.70088877413411,-42.73828753893571,-42.77568630373732,-42.81308506853892,-42.85048383334052,-42.88788259814213,-42.92528136294372,-42.96268012774532,-43.000078892546924,-43.03747765734853,-43.07487642215013,-43.112275186951734,-43.14967395175334,-43.187072716554944,-43.224471481356545,-43.261870246158146,-43.299269010959755,-43.336667775761356,-43.37406654056296,-43.411698530566184,-43.44979697038539,-43.487895410204594,-43.478647479459454,-43.44572636343213,-43.41280524740481,-43.37988413137749,-43.34696301535016,-43.314041899322845,-43.28112078329553,-43.2481996672682,-43.215278551240885,-43.18235743521357,-43.14943631918624,-43.11651520315892,-43.0835940871316,-43.050672971104284,-43.01775185507696,-42.98483073904964,-42.951909623022324,-42.91967231220927,-42.89153781124469,-42.86340331028011,-42.83526880931554,-42.807134308350946,-42.77899980738637,-42.75086530642179,-42.7227308054572,-42.69459630449263,-42.66646180352805,-42.63832730256347,-42.610192801598885,-42.58205830063431,-42.553923799669725,-42.52578929870514,-42.497654797740566,-42.46952029677598,-42.4413857958114,-42.41325129484682,-42.38511679388224,-42.356982292917664,-42.32884779195308,-42.3007132909885,-42.27257879002392,-42.244444289059345,-42.21630978809476,-42.18817528713018,-42.160040786165595,-42.13190628520101,-42.103771784236436,-42.07563728327186,-42.04750278230728,-42.01936828134269,-41.99123378037811,-41.96309927941353,-41.93496477844895,-41.906830277484374,-41.87869577651979,-41.85056127555521,-41.82242677459063,-41.79429227362605,-41.76615777266147,-41.73802327169689,-41.709888770732306,-41.68175426976774,-41.653619768803146,-41.62548526783857,-41.59735076687399,-41.56921626590941,-41.54108176494483,-41.512947263980244,-41.48481276301567,-41.456678262051085,-41.4285437610865,-41.400409260121926,-41.37227475915734,-41.344140258192766,-41.31600575722818,-41.2878712562636,-41.259736755299016,-41.23160225433445,-41.20346775336986,-41.17533325240528,-41.1471987514407,-41.119064250476114,-41.09092974951154,-40.97347523438431,-40.76670070509443,-40.55992617580458,-40.353151646514725,-40.146377117224844,-39.93960258793499,-39.73282805864513,-39.52605352935526,-39.319279000065386,-39.11250447077555,-38.90572994148567,-38.698955412195794,-38.492180882905934,-38.285406353616075,-38.0786318243262,-37.87185729503634,-37.66508276574649,-37.45830823645662,-37.25153370716676,-37.0447591778769,-36.837984648587025,-36.63121011929715,-36.424435590007306,-36.21766106071743,-36.01088653142756,-35.8041120021377,-35.59733747284785,-35.390562943557974,-35.18378841426811,-34.977013884978255,-34.77023935568838,-34.5634648263985,-34.35669029710867,-34.1499157678188,-33.94264278321881,-33.73348274740237,-33.524322711585924,-33.31516267576946,-33.10600263995302,-32.89684260413657,-32.68768256832011,-32.47852253250367,-32.26936249668722,-32.06020246087076,-31.8510424250543,-31.64188238923787,-31.432722353421415,-31.223562317604948,-31.014402281788506,-30.805242245972057,-30.596082210155597,-30.38692217433915,-30.17776213852271,-29.968602102706242,-29.759442066889783,-29.55028203107336,-29.34112199525689,-29.13196195944043,-28.922801923623986,-28.713641887807544,-28.504481851991084,-28.29532181617464,-28.086161780358196,-27.877001744541733,-27.667841708725287,-27.458681672908842,-27.24952163709238,-27.04036160127592,-26.831201565459494,-26.622041529643028,-26.412881493826564,-26.203721458010122,-25.994561422193676,-25.785401386377217,-25.57624135056077,-25.36708131474433,-25.157921278927866,-24.94876124311142,-24.739601207294974,-24.530441171478515,-24.32128113566205,-24.112121099845606,-23.902961064029164,-23.744328947004504,-23.686752667563425,-23.629176388122342,-23.571600108681253,-23.51402382924018,-23.456447549799094,-23.39887127035801,-23.34129499091692,-23.28371871147585,-23.226142432034763,-23.168566152593673,-23.110989873152594,-23.05341359371151,-22.995837314270428,-22.938261034829345,-22.880684755388263,-22.823108475947176,-22.765532196506097,-22.707955917065014,-22.650379637623928,-22.59280335818284,-22.535227078741762,-22.47765079930068,-22.420074519859593,-22.362498240418514,-22.30492196097743,-22.247345681536345,-22.189769402095266,-22.132193122654183,-22.074616843213093,-22.01704056377201,-21.959464284330934,-21.901888004889848,-21.84431172544876,-21.78673544600768,-21.729159166566596,-21.671582887125513,-21.61400660768443,-21.55643032824335,-21.498854048802265,-21.441277769361182,-21.3837014899201,-21.326125210479013,-21.268548931037927,-21.210972651596848,-21.153396372155765,-21.09582009271468,-21.038243813273596,-20.980667533832516,-20.92309125439143,-20.865514974950347,-20.807938695509264,-20.75036241606818,-20.6927861366271,-20.63520985718602,-20.577633577744933,-20.520057298303847,-20.462481018862764,-20.404904739421685,-20.3473284599806,-20.28975218053952,-20.232175901098433,-20.174599621657347,-20.117023342216267,-20.059447062775188,-20.001870783334102,-19.944294503893016,-19.886718224451936,-19.82914194501085,-19.771565665569767,-19.713989386128684,-19.6564131066876,-19.59883682724652,-19.541260547805436,-19.483684268364353,-19.42610798892327,-19.368531709482184,-19.3109554300411,-19.253494326696103,-19.196233530717393,-19.138972734738687,-19.081711938759984,-19.024451142781267,-18.94733393473816,-18.772680158526523,-18.62938871456988,-18.486097270613236,-18.342805826656615,-18.19951438269997,-18.05622293874333,-17.912931494786708,-17.769640050830066,-17.626348606873417,-17.4830571629168,-17.33976571896015,-17.19647427500351,-17.053182831046865,-16.909891387090248,-16.7665999431336,-16.623308499176957,-16.48001705522034,-16.33672561126369,-16.19343416730705,-16.05014272335043,-15.906851279393784,-15.763559835437139,-15.62026839148052,-15.476976947523877,-15.33368550356723,-15.190394059610586,-15.04710261565397,-14.903811171697322,-14.760519727740679,-14.61722828378406,-14.473936839827413,-14.330645395870768,-14.187353951914151,-14.044062507957506,-13.90077106400086,-13.757479620044215,-13.614188176087598,-13.470896732130953,-13.327605288174308,-13.184313844217689,-13.041022400261044,-12.8977309563044,-12.75443951234778,-12.611148068391135,-12.46785662443449,-12.32456518047787,-12.181273736521225,-12.037982292564582,-11.894690848607937,-11.75139940465132,-11.608107960694674,-11.464816516738027,-11.321525072781409,-11.178233628824763,-11.03494218486812,-10.891650740911501,-10.748359296954856,-10.60506785299821,-10.461776409041565,-10.318484965084949,-10.175193521128303,-10.031902077171658,-9.888610633215038,-9.745319189258392,-9.602027745301749,-9.45873630134513,-9.315444857388485,-9.17215341343184,-9.028861969475221,-8.885570525518578,-8.74227908156193,-8.598987637605287,-8.455696193648668,-8.312404749692023,-8.169113305735378,-8.02582186177876,-7.882530417822114,-7.73923897386547,-7.595947529908852,-7.4526560859522055,-7.309364641995561,-7.168483642011353,-7.046346607302554],[-36.64268170247337,-36.68182538213876,-36.72096906180415,-36.76011274146954,-36.799256421134935,-36.83840010080033,-36.877543780465714,-36.91668746013111,-36.9558311397965,-36.994974819461895,-37.03411849912729,-37.073262178792675,-37.11240585845806,-37.15154953812346,-37.1909525336999,-37.23165210776011,-37.272351681820325,-37.313051255880524,-37.35375082994073,-37.394450404000935,-37.43514997806115,-37.47584955212135,-37.51654912618155,-37.55724870024176,-37.59794827430196,-37.63864784836217,-37.67934742242238,-37.72004699648258,-37.76074657054279,-37.801446144603,-37.842145718663204,-37.88284529272341,-37.923544866783615,-37.96424444084382,-38.00494401490403,-38.04564358896423,-38.08634316302444,-38.127042737084636,-38.16774231114485,-38.20844188520505,-38.24914145926526,-38.28984103332547,-38.33054060738567,-38.371240181445884,-38.41193975550608,-38.45263932956628,-38.493338903626494,-38.5340384776867,-38.574738051746905,-38.61543762580711,-38.65613719986732,-38.69683677392752,-38.73753634798773,-38.778235922047934,-38.818935496108146,-38.859635070168345,-38.90033464422855,-38.94103421828876,-38.98173379234896,-39.02243336640917,-39.06313294046938,-39.103832514529586,-39.14453208858979,-39.18523166265,-39.2259312367102,-39.26663081077041,-39.307330384830614,-39.34802995889082,-39.388729532951025,-39.42942910701123,-39.47012868107144,-39.51082825513164,-39.55152782919185,-39.59222740325205,-39.632926977312266,-39.673626551372465,-39.71432612543267,-39.75502569949288,-39.79572527355308,-39.836424847613294,-39.87712442167349,-39.9178239957337,-39.95852356979391,-39.99922314385411,-40.03717204353215,-40.07457080833375,-40.111969573135354,-40.14936833793696,-40.18676710273856,-40.22416586754016,-40.261564632341766,-40.29896339714337,-40.336362161944976,-40.37376092674657,-40.41115969154818,-40.44855845634978,-40.48595722115139,-40.52335598595299,-40.5607547507546,-40.59815351555619,-40.635552280357786,-40.6729510451594,-40.710349809961,-40.7477485747626,-40.785147339564205,-40.822546104365806,-40.85994486916741,-40.897343633969015,-40.934742398770624,-40.97214116357222,-41.00953992837382,-41.04693869317542,-41.08433745797703,-41.12173622277863,-41.15913498758023,-41.19653375238183,-41.23393251718343,-41.271331281985034,-41.30873004678664,-41.346128811588244,-41.383527576389845,-41.420926341191446,-41.45832510599305,-41.495723870794656,-41.53312263559626,-41.57052140039786,-41.60792016519946,-41.64531893000107,-41.68271769480266,-41.72011645960427,-41.75751522440587,-41.79491398920747,-41.83231275400908,-41.86971151881069,-41.90711028361228,-41.94450904841389,-41.981907813215486,-42.019306578017094,-42.056705342818695,-42.094104107620296,-42.1315028724219,-42.1689016372235,-42.20630040202511,-42.24369916682671,-42.28109793162831,-42.31849669642991,-42.35589546123151,-42.39329422603312,-42.43069299083472,-42.46809175563632,-42.50549052043793,-42.542889285239525,-42.580288050041126,-42.61720978265319,-42.65365448285668,-42.69009918306016,-42.72654388326366,-42.76298858346715,-42.79943328367064,-42.835877983874134,-42.87232268407762,-42.90876738428111,-42.94521208448461,-42.98165678468809,-43.01810148489158,-43.05454618509508,-43.09099088529857,-43.0995563424627,-43.09418217810713,-43.08880801375157,-43.083433849396,-43.078059685040444,-43.072685520684885,-43.06731135632932,-43.061937191973755,-43.05656302761819,-43.051188863262624,-43.045814698907066,-43.04044053455151,-43.035066370195935,-43.02969220584037,-43.02431804148481,-43.018943877129246,-43.01356971277369,-43.00819554841812,-43.00282138406256,-42.997447219707,-42.97429153862019,-42.9461570376556,-42.918022536691026,-42.88988803572644,-42.86175353476186,-42.833619033797284,-42.8054845328327,-42.777350031868124,-42.74921553090354,-42.72108102993896,-42.69294652897438,-42.664812028009806,-42.63667752704522,-42.60854302608064,-42.580408525116056,-42.55227402415148,-42.524139523186896,-42.49600502222231,-42.46787052125774,-42.439736020293154,-42.41160151932857,-42.38346701836399,-42.35533251739942,-42.327198016434835,-42.29906351547026,-42.27092901450567,-42.24279451354109,-42.21466001257651,-42.18652551161193,-42.15839101064735,-42.130256509682766,-42.10212200871819,-42.07398750775361,-42.045853006789024,-42.01771850582445,-41.989584004859864,-41.96144950389528,-41.93331500293071,-41.90518050196613,-41.877046001001546,-41.84891150003696,-41.820776999072386,-41.7926424981078,-41.76450799714322,-41.73637349617864,-41.70823899521406,-41.68010449424948,-41.65196999328491,-41.623835492320325,-41.59570099135574,-41.56756649039116,-41.53943198942658,-41.51129748846199,-41.483162987497415,-41.45502848653284,-41.426893985568256,-41.39875948460367,-41.37062498363909,-41.34249048267451,-41.31435598170994,-41.286221480745354,-41.25808697978077,-41.22995247881619,-41.112497963688966,-40.905723434399086,-40.698948905109226,-40.492174375819374,-40.2853998465295,-40.07862531723964,-39.87185078794978,-39.66507625865991,-39.458301729370035,-39.2515272000802,-39.044752670790324,-38.83797814150045,-38.631203612210584,-38.42442908292073,-38.21765455363086,-38.010880024341006,-37.80410549505115,-37.59733096576127,-37.39055643647141,-37.183781907181555,-36.977007377891674,-36.77023284860181,-36.56345831931196,-36.35668379002209,-36.14990926073221,-35.943134731442356,-35.7363602021525,-35.52958567286262,-35.322811143572764,-35.11603661428291,-34.90926208499303,-34.70248755570316,-34.49571302641332,-34.288938497123446,-34.08216396783357,-33.87538943854371,-33.668614909253854,-33.46184037996398,-33.25506585067413,-33.04829132138427,-32.841516792094396,-32.63474226280454,-32.42796773351468,-32.221193204224804,-32.01441867493493,-31.807644145645092,-31.60086961635521,-31.394095087065338,-31.18732055777548,-30.980546028485627,-30.773771499195746,-30.56699696990589,-30.360222440616035,-30.153447911326154,-29.94667338203628,-29.739898852746443,-29.53312432345657,-29.326349794166692,-29.119575264876836,-28.912800735586984,-28.706026206297103,-28.49925167700725,-28.292477147717392,-28.08570261842752,-27.87892808913766,-27.6721535598478,-27.465379030557926,-27.258604501268046,-27.05182997197821,-26.845055442688334,-26.63828091339846,-26.43150638410861,-26.22473185481875,-26.017957325528876,-25.811182796239017,-25.604408266949157,-25.397633737659284,-25.190859208369424,-24.98408467907957,-24.779047930278672,-24.57663487813846,-24.37422182599827,-24.17180877385808,-24.018045040434057,-23.961579944442384,-23.90511484845072,-23.84864975245904,-23.792184656467366,-23.735719560475697,-23.67891990995204,-23.621659113973323,-23.564398317994627,-23.507137522015917,-23.449876726037203,-23.392615930058497,-23.33535513407979,-23.27809433810108,-23.22083354212237,-23.163572746143668,-23.106311950164955,-23.04905115418625,-22.991790358207545,-22.934529562228832,-22.877268766250126,-22.820007970271416,-22.762747174292713,-22.705486378314003,-22.648225582335293,-22.59096478635659,-22.53370399037788,-22.476443194399167,-22.419182398420467,-22.361921602441754,-22.304660806463044,-22.247400010484345,-22.190139214505635,-22.13287841852692,-22.075617622548208,-22.01835682656951,-21.961096030590795,-21.90383523461209,-21.846574438633382,-21.789313642654676,-21.732052846675963,-21.674792050697263,-21.61753125471855,-21.560270458739836,-21.503009662761134,-21.445748866782427,-21.388488070803717,-21.33122727482501,-21.273966478846305,-21.21670568286759,-21.159444886888885,-21.10218409091018,-21.04492329493147,-20.98766249895276,-20.93040170297406,-20.873140906995346,-20.815880111016632,-20.75861931503793,-20.701358519059223,-20.64409772308051,-20.586836927101807,-20.529576131123097,-20.472315335144387,-20.415054539165684,-20.357793743186978,-20.300532947208264,-20.24327215122955,-20.186011355250855,-20.12875055927214,-20.07148976329343,-20.014228967314722,-19.95696817133602,-19.899707375357305,-19.842446579378603,-19.785185783399896,-19.727924987421186,-19.670664191442473,-19.613403395463774,-19.55614259948506,-19.49888180350635,-19.441621007527644,-19.384360211548938,-19.327099415570224,-19.24998220752712,-19.073582939161952,-18.89718367079679,-18.720784402431626,-18.544385134066495,-18.367985865701332,-18.19158659733617,-18.015187328971034,-17.83878806060587,-17.66238879224071,-17.48598952387558,-17.309590255510415,-17.13319098714525,-16.95679171878009,-16.780392450414954,-16.603993182049795,-16.427593913684632,-16.251194645319497,-16.074795376954334,-15.898396108589173,-15.721996840224042,-15.568457754487643,-15.425166310530996,-15.281874866574379,-15.138583422617733,-14.995291978661086,-14.852000534704441,-14.708709090747824,-14.56541764679118,-14.422126202834535,-14.278834758877917,-14.135543314921271,-13.992251870964624,-13.848960427008008,-13.70566898305136,-13.562377539094715,-13.419086095138072,-13.275794651181453,-13.13250320722481,-12.989211763268164,-12.845920319311546,-12.7026288753549,-12.559337431398255,-12.416045987441636,-12.272754543484993,-12.129463099528348,-11.986171655571727,-11.842880211615084,-11.699588767658437,-11.556297323701793,-11.413005879745175,-11.269714435788531,-11.126422991831884,-10.983131547875265,-10.839840103918622,-10.696548659961977,-10.553257216005358,-10.409965772048713,-10.266674328092067,-10.123382884135422,-9.980091440178805,-9.83679999622216,-9.693508552265515,-9.56029062492114,-9.438153590212321,-9.316016555503497,-9.193879520794697,-9.071742486085876,-8.949605451377053,-8.827468416668255,-8.705331381959432,-8.583194347250611,-8.46105731254179,-8.33892027783299,-8.216783243124167,-8.094646208415346,-7.9725091737065465,-7.850372138997725,-7.728235104288903,-7.606098069580104,-7.4839610348712835,-7.36182400016246,-7.239686965453638,-7.117549930744839],[-36.28327201623185,-36.32241569589724,-36.36155937556263,-36.40070305522802,-36.439846734893415,-36.47899041455881,-36.518134094224195,-36.55727777388959,-36.59642145355498,-36.63556513322037,-36.67470881288576,-36.713852492551155,-36.75299617221654,-36.792139851881934,-36.83128353154733,-36.87042721121272,-36.909570890878115,-36.9487145705435,-36.987858250208895,-37.02700192987429,-37.066145609539674,-37.10528928920507,-37.144432968870454,-37.183576648535855,-37.222720328201234,-37.261864007866635,-37.30100768753203,-37.34015136719741,-37.37929504686281,-37.418438726528194,-37.45758240619359,-37.49776334871072,-37.53846292277093,-37.57916249683113,-37.619862070891344,-37.66056164495155,-37.701261219011755,-37.74196079307196,-37.782660367132166,-37.82335994119238,-37.86405951525258,-37.90475908931278,-37.94545866337299,-37.986158237433195,-38.0268578114934,-38.067557385553606,-38.10825695961381,-38.148956533674024,-38.18965610773422,-38.230355681794435,-38.271055255854634,-38.31175482991485,-38.352454403975045,-38.39315397803526,-38.43385355209546,-38.47455312615567,-38.51525270021587,-38.55595227427608,-38.59665184833628,-38.63735142239649,-38.67805099645669,-38.7187505705169,-38.75945014457711,-38.800149718637314,-38.84084929269752,-38.881548866757726,-38.92224844081793,-38.96294801487814,-39.00364758893835,-39.044347162998555,-39.08504673705876,-39.12574631111896,-39.166445885179165,-39.20714545923937,-39.247845033299576,-39.28854460735978,-39.329244181419995,-39.3699437554802,-39.4106433295404,-39.451342903600604,-39.49204247766081,-39.53274205172102,-39.57344162578123,-39.614141199841434,-39.65209009951947,-39.68948886432107,-39.72688762912267,-39.76428639392428,-39.801685158725874,-39.83908392352748,-39.876482688329084,-39.913881453130685,-39.951280217932286,-39.98867898273389,-40.026077747535496,-40.06347651233709,-40.1008752771387,-40.1382740419403,-40.17567280674191,-40.21307157154351,-40.25047033634511,-40.28786910114671,-40.32526786594832,-40.36266663074992,-40.40006539555152,-40.43746416035313,-40.474862925154724,-40.51226168995633,-40.549660454757934,-40.587059219559535,-40.624457984361136,-40.66185674916274,-40.69925551396434,-40.73665427876595,-40.77405304356755,-40.81145180836915,-40.84885057317075,-40.88624933797235,-40.92364810277397,-40.96104686757556,-40.99844563237717,-41.03584439717877,-41.07324316198037,-41.110641926781966,-41.148040691583574,-41.185439456385176,-41.22283822118678,-41.26023698598838,-41.297635750789986,-41.33503451559159,-41.37243328039319,-41.4098320451948,-41.4472308099964,-41.484629574798,-41.5220283395996,-41.5594271044012,-41.5968258691549,-41.63327056935839,-41.66971526956188,-41.70615996976537,-41.742604669968856,-41.779049370172345,-41.81549407037584,-41.85193877057933,-41.88838347078283,-41.924828170986316,-41.961272871189806,-41.997717571393295,-42.034162271596784,-42.070606971800274,-42.10705167200377,-42.14349637220726,-42.17994107241075,-42.21638577261424,-42.25283047281773,-42.289275173021224,-42.32571987322471,-42.3621645734282,-42.39860927363169,-42.43505397383518,-42.47149867403868,-42.50794337424217,-42.544388074445656,-42.580832774649146,-42.61727747485264,-42.65372217505613,-42.69016687525962,-42.698732332423745,-42.69335816806818,-42.68798400371262,-42.682609839357056,-42.67723567500149,-42.671861510645925,-42.66648734629037,-42.66111318193481,-42.655739017579236,-42.65036485322368,-42.64499068886812,-42.63961652451255,-42.63424236015699,-42.62886819580143,-42.623494031445865,-42.6181198670903,-42.61274570273474,-42.60737153837918,-42.60199737402361,-42.59662320966805,-42.59124904531249,-42.58587488095692,-42.580500716601364,-42.5751265522458,-42.56975238789023,-42.564378223534675,-42.55900405917911,-42.55362989482355,-42.548255730467986,-42.54288156611242,-42.537507401756855,-42.5321332374013,-42.52675907304573,-42.521384908690166,-42.51601074433461,-42.51063657997904,-42.505262415623484,-42.49988825126792,-42.49451408691235,-42.48913992255679,-42.48376575820123,-42.47839159384567,-42.473017429490106,-42.466220745739484,-42.4380862447749,-42.409951743810325,-42.38181724284574,-42.35368274188116,-42.32554824091658,-42.297413739952,-42.26927923898742,-42.24114473802284,-42.21301023705826,-42.18487573609368,-42.1567412351291,-42.12860673416452,-42.10047223319994,-42.07233773223536,-42.04420323127078,-42.01606873030619,-41.98793422934161,-41.959799728377035,-41.93166522741245,-41.90353072644787,-41.87539622548329,-41.84726172451872,-41.81912722355413,-41.79099272258955,-41.76285822162497,-41.73472372066039,-41.706589219695815,-41.67845471873123,-41.65032021776665,-41.62218571680207,-41.59405121583749,-41.565916714872905,-41.53778221390832,-41.509647712943746,-41.48151321197916,-41.45337871101459,-41.42524421005001,-41.39710970908543,-41.368975208120844,-41.25152069299361,-41.04474616370374,-40.83797163441388,-40.63119710512403,-40.42442257583416,-40.2176480465443,-40.01087351725443,-39.804098987964565,-39.59732445867469,-39.390549929384854,-39.183775400094966,-38.9770008708051,-38.77022634151523,-38.56345181222538,-38.35667728293551,-38.14990275364565,-37.943128224355796,-37.736353695065915,-37.52957916577606,-37.322804636486204,-37.11603010719633,-36.90925557790646,-36.70248104861662,-36.49570651932674,-36.288931990036865,-36.082157460747005,-35.87538293145715,-35.66860840216727,-35.46183387287742,-35.25505934358756,-35.04828481429769,-34.84151028500781,-34.63473575571797,-34.427961226428096,-34.22118669713822,-34.01441216784836,-33.80763763855851,-33.60086310926863,-33.39408857997878,-33.18731405068892,-32.98053952139904,-32.77376499210919,-32.566990462819334,-32.36021593352945,-32.15344140423958,-31.94666687494974,-31.739892345659865,-31.533117816369987,-31.326343287080135,-31.119773205761653,-30.917360153621438,-30.71494710148125,-30.512534049341056,-30.310120997200848,-30.107707945060632,-29.905294892920463,-29.70288184078025,-29.50046878864004,-29.298055736499848,-29.095642684359653,-28.893229632219445,-28.69081658007925,-28.488403527939063,-28.285990475798847,-28.083577423658653,-27.881164371518462,-27.67875131937825,-27.47633826723804,-27.27392521509786,-27.071512162957653,-26.869099110817444,-26.66668605867725,-26.464273006537056,-26.261859954396847,-26.059446902256653,-25.85703385011646,-25.65462079797625,-25.452207745836056,-25.249794693695865,-25.047381641555653,-24.844968589415444,-24.64255553727525,-24.440142485135055,-24.28637875171104,-24.229913655719365,-24.173448559727696,-24.116983463736023,-24.06051836774435,-24.00405327175268,-23.947588175761005,-23.89112307976933,-23.834657983777664,-23.778192887785984,-23.72172779179431,-23.665262695802642,-23.60879759981097,-23.552332503819294,-23.495867407827625,-23.439402311835952,-23.38293721584428,-23.32647211985261,-23.270007023860938,-23.213541927869258,-23.157076831877585,-23.100611735885913,-23.044146639894244,-22.987681543902568,-22.9312164479109,-22.874751351919226,-22.81828625592755,-22.761821159935877,-22.705356063944212,-22.648890967952532,-22.592425871960856,-22.535960775969194,-22.479495679977518,-22.42303058398584,-22.366565487994173,-22.3101003920025,-22.253635296010824,-22.19717020001915,-22.140705104027482,-22.084240008035806,-22.027774912044134,-21.971309816052464,-21.91484472006079,-21.85837962406911,-21.80191452807744,-21.74544943208577,-21.688984336094094,-21.632519240102425,-21.576054144110756,-21.51935395565654,-21.462093159677835,-21.40483236369913,-21.34757156772042,-21.29031077174171,-21.23304997576301,-21.175789179784296,-21.118528383805586,-21.061267587826876,-21.004006791848173,-20.94674599586946,-20.889485199890757,-20.83222440391205,-20.774963607933337,-20.71770281195463,-20.660442015975924,-20.603181219997214,-20.5459204240185,-20.488659628039805,-20.43139883206109,-20.37413803608238,-20.31687724010368,-20.259616444124966,-20.202355648146256,-20.145094852167553,-20.087834056188843,-20.030573260210133,-19.97331246423142,-19.91605166825272,-19.85879087227401,-19.8015300762953,-19.744269280316594,-19.687008484337888,-19.629747688359174,-19.55263048031607,-19.376231211950902,-19.19983194358574,-19.023432675220576,-18.847033406855445,-18.670634138490282,-18.49423487012512,-18.317835601759988,-18.141436333394825,-17.965037065029662,-17.788637796664528,-17.612238528299365,-17.435839259934202,-17.25943999156904,-17.083040723203908,-16.90664145483874,-16.730242186473582,-16.55384291810845,-16.377443649743284,-16.20104438137812,-16.024645113012994,-15.848245844647826,-15.671846576282665,-15.495447307917534,-15.319048039552369,-15.142648771187206,-14.966249502822041,-14.78985023445691,-14.613450966091747,-14.437051697726584,-14.260652429361453,-14.08425316099629,-13.907853892631126,-13.731454624265995,-13.55505535590083,-13.378656087535669,-13.202256819170504,-13.025857550805373,-12.849458282440212,-12.673059014075047,-12.507526794405411,-12.364235350448764,-12.220943906492119,-12.077652462535502,-11.952097607830904,-11.829960573122083,-11.707823538413283,-11.585686503704462,-11.46354946899564,-11.341412434286818,-11.219275399578018,-11.097138364869199,-10.975001330160374,-10.852864295451575,-10.730727260742754,-10.608590226033932,-10.486453191325134,-10.364316156616312,-10.242179121907489,-10.120042087198668,-9.997905052489868,-9.875768017781045,-9.753630983072224,-9.631493948363424,-9.509356913654603,-9.387219878945782,-9.265082844236982,-9.142945809528161,-9.020808774819336,-8.898671740110538,-8.776534705401717,-8.654397670692894,-8.532260635984073,-8.410123601275274,-8.287986566566452,-8.165849531857631,-8.043712497148832,-7.921575462440009,-7.799438427731187,-7.677301393022388,-7.555164358313565,-7.433027323604744,-7.310890288895923,-7.188753254187123],[-35.92386232999032,-35.963006009655714,-36.0021496893211,-36.04129336898649,-36.08043704865189,-36.119580728317274,-36.15872440798267,-36.19786808764806,-36.23701176731345,-36.27615544697885,-36.315299126644234,-36.35444280630962,-36.393586485975014,-36.43273016564041,-36.4718738453058,-36.511017524971194,-36.55016120463658,-36.589304884301974,-36.62844856396737,-36.667592243632754,-36.70673592329814,-36.74587960296354,-36.78502328262893,-36.82416696229433,-36.863310641959714,-36.9024543216251,-36.9415980012905,-36.98074168095589,-37.01988536062128,-37.05902904028667,-37.09817271995206,-37.137316399617454,-37.17646007928285,-37.215603758948234,-37.25474743861362,-37.29389111827902,-37.33303479794441,-37.37217847760979,-37.411322157275194,-37.45046583694058,-37.489609516605974,-37.52875319627137,-37.56789687593675,-37.60704055560215,-37.64618423526754,-37.68532791493293,-37.72447159459832,-37.76387458966133,-37.80457416372153,-37.84527373778174,-37.885973311841944,-37.92667288590215,-37.96737245996236,-38.00807203402256,-38.048771608082774,-38.08947118214297,-38.130170756203185,-38.17087033026339,-38.211569904323596,-38.252269478383795,-38.29296905244401,-38.33366862650421,-38.37436820056442,-38.41506777462462,-38.45576734868483,-38.496466922745036,-38.53716649680524,-38.57786607086545,-38.61856564492565,-38.65926521898586,-38.699964793046064,-38.74066436710627,-38.781363941166475,-38.82206351522669,-38.862763089286894,-38.9034626633471,-38.9441622374073,-38.9848618114675,-39.02556138552771,-39.066260959587915,-39.10696053364813,-39.147660107708326,-39.18835968176853,-39.22905925582874,-39.26700815550677,-39.30440692030838,-39.34180568510998,-39.37920444991158,-39.416603214713184,-39.454001979514786,-39.491400744316394,-39.528799509117995,-39.566198273919596,-39.603597038721205,-39.640995803522806,-39.67839456832441,-39.715793333126015,-39.75319209792761,-39.79059086272922,-39.82798962753082,-39.86538839233242,-39.90278715713403,-39.94018592193562,-39.97758468673723,-40.014983451538825,-40.05238221634043,-40.089780981142034,-40.127179745943636,-40.164578510745244,-40.201977275546845,-40.239376040348446,-40.27677480515005,-40.31417356995165,-40.35157233475326,-40.38897109955486,-40.42636986435646,-40.46376862915806,-40.50116739395966,-40.53856615876126,-40.57596492356287,-40.61288665586008,-40.64933135606357,-40.685776056267066,-40.722220756470556,-40.758665456674045,-40.795110156877534,-40.83155485708104,-40.86799955728452,-40.90444425748801,-40.940888957691506,-40.977333657894995,-41.013778358098484,-41.05022305830198,-41.08666775850546,-41.12311245870896,-41.15955715891245,-41.19600185911594,-41.23244655931943,-41.26889125952292,-41.30533595972641,-41.3417806599299,-41.37822536013339,-41.41467006033688,-41.45111476054038,-41.48755946074387,-41.52400416094736,-41.560448861150846,-41.596893561354335,-41.63333826155783,-41.66978296176132,-41.70622766196481,-41.74267236216831,-41.77911706237179,-41.81556176257528,-41.852006462778775,-41.888451162982264,-41.92489586318575,-41.96134056338924,-41.99778526359273,-42.03422996379622,-42.07067466399972,-42.107119364203214,-42.1435640644067,-42.180008764610186,-42.21645346481368,-42.25289816501717,-42.28934286522066,-42.297908322384785,-42.29253415802922,-42.287159993673654,-42.281785829318096,-42.27641166496254,-42.27103750060697,-42.26566333625141,-42.26028917189585,-42.25491500754028,-42.24954084318472,-42.24416667882916,-42.238792514473595,-42.233418350118036,-42.22804418576247,-42.222670021406906,-42.21729585705135,-42.21192169269578,-42.206547528340224,-42.20117336398466,-42.19579919962909,-42.190425035273535,-42.18505087091797,-42.179676706562404,-42.174302542206846,-42.16892837785128,-42.163554213495715,-42.15818004914016,-42.15280588478459,-42.147431720429026,-42.14205755607347,-42.13668339171791,-42.13130922736234,-42.12593506300678,-42.12056089865122,-42.11518673429565,-42.10981256994009,-42.104438405584524,-42.09906424122897,-42.0936900768734,-42.088315912517835,-42.08294174816227,-42.07756758380671,-42.072193419451146,-42.06681925509559,-42.06144509074002,-42.05607092638446,-42.0506967620289,-42.045322597673334,-42.039948433317775,-42.03457426896221,-42.02920010460665,-42.023825940251086,-42.01845177589552,-42.013077611539956,-42.0077034471844,-42.00232928282883,-41.99695511847327,-41.99158095411771,-41.98620678976215,-41.980832625406585,-41.97545846105102,-41.970084296695454,-41.9647101323399,-41.95933596798434,-41.95396180362877,-41.94858763927321,-41.94321347491765,-41.93001545189421,-41.90188095092962,-41.87374644996504,-41.845611949000464,-41.81747744803589,-41.789342947071304,-41.76120844610672,-41.73307394514214,-41.70493944417756,-41.67680494321298,-41.6486704422484,-41.62053594128382,-41.59240144031924,-41.56426693935466,-41.53613243839008,-41.5079979374255,-41.390543422298265,-41.18376889300839,-40.97699436371853,-40.77021983442869,-40.5634453051388,-40.356670775848954,-40.14989624655909,-39.943121717269214,-39.73634718797935,-39.52957265868951,-39.32279812939962,-39.116023600109756,-38.90924907081989,-38.70247454153004,-38.49570001224016,-38.28892548295031,-38.08215095366045,-37.87537642437057,-37.66860189508072,-37.46182736579086,-37.258085429104426,-37.05567237696422,-36.853259324824045,-36.650846272683836,-36.44843322054362,-36.246020168403426,-36.04360711626324,-35.84119406412302,-35.63878101198283,-35.43636795984264,-35.233954907702426,-35.03154185556222,-34.829128803422044,-34.62671575128183,-34.42430269914162,-34.221889647001426,-34.01947659486124,-33.81706354272102,-33.61465049058083,-33.41223743844064,-33.209824386300426,-33.00741133416023,-32.804998282020044,-32.60258522987983,-32.40017217773962,-32.19775912559945,-31.99534607345924,-31.792933021319026,-31.590519969178835,-31.38810691703864,-31.185693864898433,-30.983280812758235,-30.78086776061804,-30.57845470847783,-30.37604165633762,-30.173628604197447,-29.971215552057235,-29.768802499917022,-29.56638944777683,-29.36397639563664,-29.16156334349643,-28.959150291356238,-28.756737239216044,-28.554324187075835,-28.35191113493564,-28.149498082795446,-27.947085030655238,-27.744671978515026,-27.542258926374853,-27.33984587423464,-27.137432822094432,-26.935019769954238,-26.732606717814047,-26.530193665673835,-26.32778061353364,-26.12536756139345,-25.922954509253238,-25.720541457113043,-25.518128404972853,-25.31571535283264,-25.11330230069243,-24.910889248552238,-24.708476196412043,-24.554712462988025,-24.498247366996356,-24.441782271004687,-24.385317175013007,-24.328852079021342,-24.27238698302967,-24.215921887037993,-24.159456791046317,-24.102991695054648,-24.046526599062975,-23.9900615030713,-23.93359640707963,-23.877131311087957,-23.820666215096285,-23.764201119104612,-23.70773602311294,-23.651270927121264,-23.594805831129595,-23.538340735137922,-23.481875639146246,-23.425410543154573,-23.368945447162904,-23.31248035117123,-23.256015255179555,-23.199550159187886,-23.143085063196217,-23.08661996720454,-23.03015487121287,-22.9736897752212,-22.917224679229523,-22.860759583237844,-22.80429448724618,-22.747829391254502,-22.69136429526283,-22.63489919927116,-22.578434103279488,-22.52196900728781,-22.465503911296143,-22.409038815304466,-22.35257371931279,-22.29610862332112,-22.239643527329452,-22.183178431337776,-22.1267133353461,-22.07024823935443,-22.01378314336276,-21.957318047371082,-21.900852951379413,-21.84438785538774,-21.787922759396064,-21.731457663404395,-21.674992567412726,-21.61852747142105,-21.562062375429374,-21.50559727943771,-21.449132183446036,-21.392667087454353,-21.336201991462687,-21.27973689547101,-21.22327179947934,-21.16680670348767,-21.110341607495997,-21.05387651150432,-20.99741141551265,-20.940946319520982,-20.884481223529306,-20.828016127537627,-20.771933553147658,-20.71604827906488,-20.660163004982103,-20.60427773089933,-20.54839245681655,-20.492507182733775,-20.436621908651002,-20.380736634568226,-20.324851360485447,-20.26896608640267,-20.213080812319898,-20.15719553823712,-20.101310264154343,-20.045424990071567,-19.98953971598879,-19.93365444190601,-19.85647048991657,-19.672793148393744,-19.48911580687092,-19.305438465348097,-19.12176112382531,-18.96910267061071,-18.817882941248477,-18.66666321188628,-18.515443482524052,-18.36422375316182,-18.21300402379962,-18.06178429443739,-17.910564565075163,-17.759344835712934,-17.608125106350734,-17.456905376988505,-17.305685647626277,-17.154465918264076,-17.003246188901848,-16.85202645953962,-16.70080673017742,-16.54958700081519,-16.398367271452962,-16.247147542090758,-16.09592781272853,-15.944708083366303,-15.793488354004074,-15.642268624641872,-15.491048895279645,-15.339829165917417,-15.188609436555216,-15.037389707192988,-14.88616997783076,-14.734950248468559,-14.58373051910633,-14.432510789744098,-14.281291060381871,-14.130071331019671,-13.978851601657441,-13.827631872295216,-13.676412142933012,-13.525192413570785,-13.373972684208557,-13.222752954846355,-13.071533225484126,-12.9203134961219,-12.769093766759697,-12.617874037397469,-12.466654308035238,-12.315434578673012,-12.164214849310811,-12.012995119948583,-11.861775390586354,-11.710555661224152,-11.559335931861922,-11.408116202499695,-11.256896473137493,-11.105676743775264,-10.954457014413036,-10.803237285050807,-10.652017555688607,-10.500797826326378,-10.34957809696415,-10.19835836760195,-10.047138638239721,-9.895918908877492,-9.744699179515292,-9.593479450153064,-9.442259720790835,-9.291039991428633,-9.139820262066404,-8.988600532704176,-8.837380803341947,-8.686161073979745,-8.534941344617518,-8.383721615255288,-8.232501885893088,-8.08128215653086,-7.93006242716863,-7.783204202555648,-7.652655806901131,-7.522107411246611,-7.391559015592093,-7.261010619937599],[-35.564452643748794,-35.60359632341418,-35.64274000307958,-35.68188368274497,-35.721027362410354,-35.760171042075754,-35.79931472174114,-35.83845840140653,-35.87760208107193,-35.916745760737314,-35.955889440402714,-35.9950331200681,-36.03417679973349,-36.07332047939889,-36.112464159064274,-36.15160783872966,-36.19075151839506,-36.22989519806045,-36.26903887772583,-36.308182557391234,-36.34732623705662,-36.38646991672201,-36.4256135963874,-36.464757276052794,-36.50390095571818,-36.54304463538358,-36.582188315048974,-36.62133199471435,-36.660475674379754,-36.69961935404514,-36.73876303371053,-36.77790671337593,-36.81705039304131,-36.85619407270671,-36.8953377523721,-36.93448143203749,-36.97362511170289,-37.012768791368266,-37.05191247103367,-37.09105615069905,-37.13019983036445,-37.16934351002983,-37.208487189695234,-37.24763086936062,-37.286774549026006,-37.32591822869141,-37.36506190835679,-37.40420558802219,-37.44334926768758,-37.482492947352966,-37.52163662701836,-37.56078030668375,-37.59992398634914,-37.63906766601453,-37.67821134567993,-37.71735502534531,-37.75649870501071,-37.7956423846761,-37.834786064341486,-37.87392974400689,-37.91307342367227,-37.95221710333767,-37.99136078300306,-38.030504462668446,-38.07068540467213,-38.111384978732346,-38.152084552792545,-38.19278412685276,-38.23348370091296,-38.27418327497317,-38.314882849033374,-38.35558242309358,-38.396281997153785,-38.43698157121399,-38.4776811452742,-38.5183807193344,-38.55908029339461,-38.599779867454814,-38.64047944151502,-38.681179015575225,-38.72187858963543,-38.762578163695636,-38.80327773775584,-38.84397731181605,-38.88192621149408,-38.919324976295684,-38.95672374109729,-38.99412250589889,-39.031521270700495,-39.0689200355021,-39.1063188003037,-39.1437175651053,-39.1811163299069,-39.21851509470851,-39.255913859510116,-39.29331262431171,-39.33071138911332,-39.36811015391492,-39.40550891871653,-39.44290768351813,-39.48030644831973,-39.51770521312134,-39.55510397792294,-39.59250274236179,-39.62894744256528,-39.665392142768766,-39.70183684297226,-39.738281543175745,-39.774726243379234,-39.81117094358273,-39.84761564378622,-39.88406034398971,-39.920505044193206,-39.956949744396695,-39.993394444600185,-40.02983914480367,-40.06628384500716,-40.10272854521065,-40.13917324541414,-40.17561794561764,-40.21206264582113,-40.24850734602462,-40.28495204622811,-40.3213967464316,-40.35784144663509,-40.39428614683859,-40.43073084704208,-40.46717554724557,-40.50362024744906,-40.540064947652546,-40.57650964785604,-40.61295434805953,-40.64939904826302,-40.68584374846651,-40.72228844867,-40.75873314887349,-40.79517784907698,-40.831622549280475,-40.868067249483964,-40.90451194968746,-40.94095664989095,-40.97740135009444,-41.01384605029793,-41.05029075050142,-41.08673545070491,-41.1231801509084,-41.15962485111189,-41.19606955131538,-41.23251425151888,-41.26895895172237,-41.30540365192586,-41.34184835212935,-41.378293052332836,-41.414737752536325,-41.451182452739815,-41.487627152943304,-41.52407185314679,-41.56051655335029,-41.59696125355378,-41.63340595375727,-41.669850653960765,-41.706295354164254,-41.742740054367744,-41.77918475457123,-41.81562945477472,-41.85207415497822,-41.88851885518171,-41.897084312345825,-41.89171014799027,-41.88633598363471,-41.88096181927914,-41.87558765492358,-41.87021349056802,-41.864839326212454,-41.85946516185689,-41.85409099750133,-41.848716833145765,-41.8433426687902,-41.83796850443464,-41.832594340079076,-41.82722017572351,-41.82184601136795,-41.816471847012394,-41.81109768265682,-41.805723518301264,-41.800349353945705,-41.79497518959014,-41.78960102523457,-41.78422686087901,-41.77885269652346,-41.77347853216789,-41.76810436781233,-41.76273020345676,-41.7573560391012,-41.75198187474564,-41.74660771039007,-41.74123354603451,-41.73585938167895,-41.73048521732339,-41.72511105296782,-41.71973688861226,-41.714362724256695,-41.70898855990113,-41.70361439554557,-41.69824023119001,-41.69286606683444,-41.68749190247888,-41.68211773812332,-41.67674357376776,-41.67136940941219,-41.665995245056635,-41.66062108070106,-41.655246916345504,-41.64987275198994,-41.64449858763438,-41.639124423278815,-41.63375025892325,-41.62837609456769,-41.62300193021213,-41.61762776585657,-41.612253601501,-41.60687943714544,-41.60150527278988,-41.596131108434314,-41.59075694407875,-41.58538277972319,-41.580008615367625,-41.57463445101207,-41.5692602866565,-41.56388612230094,-41.55851195794537,-41.55313779358981,-41.551254450361036,-41.552861910814954,-41.55446937126888,-41.556076831722805,-41.557684292176724,-41.55929175263064,-41.56089921308457,-41.56250667353849,-41.56411413399241,-41.56572159444633,-41.56732905490025,-41.56893651535418,-41.57054397580809,-41.57215143626202,-41.573758896715944,-41.57536635716987,-41.57697381762379,-41.578581278077706,-41.48356248790332,-41.291917447100644,-41.100272406297975,-40.908627365495306,-40.71698232469263,-40.52533728388996,-40.33369224308729,-40.14204720228461,-39.950402161481925,-39.75069261868826,-39.548294905032286,-39.345897191376295,-39.143499477720326,-38.94110176406437,-38.73870405040838,-38.53630633675242,-38.333908623096455,-38.131510909440465,-37.9291131957845,-37.72671548212854,-37.52431776847255,-37.32192005481657,-37.11952234116062,-36.91712462750464,-36.71472691384865,-36.51232920019269,-36.30993148653672,-36.10753377288074,-35.90513605922477,-35.70273834556881,-35.50034063191282,-35.297942918256844,-35.095545204600896,-34.893147490944905,-34.69074977728892,-34.48835206363296,-34.28595434997699,-34.08355663632101,-33.88115892266504,-33.67876120900908,-33.4763634953531,-33.27396578169713,-33.07156806804116,-32.869170354385176,-32.6667726407292,-32.46437492707325,-32.26197721341727,-32.059579499761284,-31.857181786105315,-31.65478407244935,-31.45238635879337,-31.249988645137403,-31.047590931481437,-30.84519321782545,-30.642795504169467,-30.44039779051352,-30.23800007685754,-30.03560236320155,-29.83320464954559,-29.63080693588962,-29.42840922223364,-29.226011508577674,-29.023613794921708,-28.82121608126572,-28.618818367609755,-28.416420653953793,-28.214022940297806,-28.011625226641822,-27.809227512985878,-27.60682979932989,-27.404432085673907,-27.20203437201794,-26.999636658361975,-26.79723894470599,-26.594841231050026,-26.39244351739406,-26.190045803738077,-25.98764809008211,-25.785250376426145,-25.58285266277016,-25.380454949114178,-25.178057235458212,-24.975659521802246,-24.822481870820745,-24.76774434518818,-24.713006819555616,-24.658269293923045,-24.603531768290477,-24.548794242657912,-24.49405671702534,-24.439225877630776,-24.383340603548007,-24.327455329465227,-24.271570055382448,-24.21568478129967,-24.159799507216903,-24.103914233134123,-24.048028959051347,-23.99214368496857,-23.936258410885795,-23.88037313680302,-23.824487862720247,-23.768602588637467,-23.712717314554688,-23.65683204047191,-23.600946766389143,-23.54506149230636,-23.489176218223587,-23.43329094414082,-23.377405670058035,-23.321520395975263,-23.265635121892487,-23.209749847809707,-23.153864573726928,-23.097979299644162,-23.042094025561383,-22.986208751478607,-22.93032347739583,-22.874438203313055,-22.818552929230275,-22.762667655147503,-22.706782381064727,-22.650897106981947,-22.595011832899175,-22.539126558816402,-22.48324128473362,-22.427356010650847,-22.37147073656807,-22.315585462485295,-22.259700188402512,-22.203814914319743,-22.147929640236967,-22.09204436615419,-22.036159092071415,-21.980273817988643,-21.92438854390586,-21.868503269823083,-21.812617995740315,-21.756732721657535,-21.700847447574752,-21.644962173491983,-21.589076899409207,-21.53319162532643,-21.477306351243655,-21.421421077160883,-21.365535803078103,-21.309650528995327,-21.253765254912555,-21.197879980829775,-21.141994706747,-21.08610943266423,-21.030224158581447,-20.97433888449867,-20.918453610415895,-20.862568336333123,-20.806683062250343,-20.750797788167567,-20.6949125140848,-20.639027240002015,-20.58314196591924,-20.527256691836467,-20.471371417753687,-20.41548614367091,-20.359600869588135,-20.303715595505363,-20.247830321422583,-20.170646369433143,-19.986969027910312,-19.80329168638749,-19.619614344864665,-19.435937003341877,-19.252259661819053,-19.06858232029623,-18.884904978773438,-18.70122763725061,-18.517550295727787,-18.333872954205,-18.150195612682175,-17.966518271159348,-17.782840929636524,-17.599163588113733,-17.41548624659091,-17.231808905068085,-17.048131563545294,-16.86445422202247,-16.680776880499646,-16.497099538976855,-16.31342219745403,-16.129744855931207,-15.946067514408417,-15.762390172885592,-15.603689113959966,-15.452469384597737,-15.301249655235537,-15.150029925873309,-14.99881019651108,-14.847590467148878,-14.696370737786648,-14.545151008424423,-14.393931279062222,-14.242711549699994,-14.091491820337763,-13.940272090975535,-13.789052361613333,-13.637832632251104,-13.486612902888876,-13.335393173526679,-13.184173444164449,-13.032953714802222,-12.881733985440018,-12.73051425607779,-12.579294526715561,-12.42807479735336,-12.276855067991132,-12.125635338628904,-11.974415609266675,-11.823195879904475,-11.671976150542246,-11.520756421180014,-11.369536691817814,-11.218316962455587,-11.067097233093357,-10.915877503731156,-10.764657774368928,-10.6134380450067,-10.470428184792738,-10.339879789138243,-10.209331393483724,-10.078782997829205,-9.948234602174711,-9.817686206520191,-9.687137810865673,-9.556589415211178,-9.42604101955666,-9.295492623902142,-9.164944228247649,-9.034395832593127,-8.903847436938609,-8.77329904128409,-8.642750645629595,-8.512202249975077,-8.381653854320557,-8.251105458666064,-8.120557063011546,-7.990008667357026,-7.859460271702531,-7.728911876048014,-7.598363480393494,-7.467815084738976,-7.337266689084481],[-35.205042957507274,-35.24418663717267,-35.283330316838054,-35.32247399650344,-35.36161767616884,-35.40076135583423,-35.43990503549961,-35.47904871516501,-35.5181923948304,-35.557336074495794,-35.59647975416119,-35.635623433826574,-35.67476711349196,-35.71391079315736,-35.75305447282275,-35.79219815248814,-35.831341832153534,-35.87048551181892,-35.90962919148431,-35.94877287114971,-35.98791655081509,-36.02706023048049,-36.06620391014588,-36.105347589811274,-36.14449126947667,-36.18363494914205,-36.22277862880745,-36.26192230847284,-36.301065988138234,-36.34020966780362,-36.379353347469014,-36.41849702713441,-36.4576407067998,-36.496784386465194,-36.53592806613057,-36.57507174579597,-36.61421542546137,-36.653359105126746,-36.69250278479215,-36.73164646445753,-36.77079014412292,-36.80993382378831,-36.84907750345371,-36.8882211831191,-36.927364862784486,-36.96650854244988,-37.00565222211527,-37.04479590178066,-37.08393958144605,-37.12308326111145,-37.16222694077684,-37.201370620442226,-37.24051430010762,-37.27965797977301,-37.3188016594384,-37.35794533910379,-37.39708901876919,-37.43623269843457,-37.475376378099966,-37.51452005776536,-37.553663737430746,-37.59280741709614,-37.63195109676153,-37.67109477642692,-37.71023845609232,-37.749382135757706,-37.78852581542309,-37.827669495088486,-37.86681317475388,-37.90595685441927,-37.945100534084666,-37.98424421375005,-38.023387893415446,-38.06253157308084,-38.101675252746226,-38.14081893241162,-38.17996261207701,-38.2191062917424,-38.25824997140779,-38.297393651073186,-38.33679664562274,-38.377496219682946,-38.41819579374315,-38.45889536780336,-38.4968442674814,-38.534243032283,-38.5716417970846,-38.60856352906698,-38.64500822927047,-38.681452929473956,-38.717897629677445,-38.75434232988094,-38.79078703008443,-38.82723173028793,-38.86367643049142,-38.900121130694906,-38.9365658308984,-38.97301053110189,-39.00945523130538,-39.04589993150887,-39.08234463171236,-39.11878933191585,-39.15523403211934,-39.191678732322835,-39.228123432526324,-39.26456813272981,-39.3010128329333,-39.3374575331368,-39.37390223334029,-39.41034693354378,-39.44679163374727,-39.483236333950764,-39.519681034154246,-39.55612573435774,-39.59257043456123,-39.62901513476472,-39.66545983496822,-39.70190453517171,-39.738349235375196,-39.774793935578685,-39.811238635782175,-39.847683335985664,-39.88412803618915,-39.92057273639265,-39.95701743659614,-39.993462136799636,-40.029906837003125,-40.066351537206614,-40.102796237410104,-40.1392409376136,-40.17568563781709,-40.212130338020586,-40.248575038224075,-40.28501973842756,-40.321464438631054,-40.35790913883454,-40.39435383903803,-40.43079853924152,-40.46724323944502,-40.50368793964851,-40.540132639852,-40.576577340055486,-40.61302204025898,-40.64946674046247,-40.68591144066596,-40.72235614086945,-40.75880084107295,-40.79524554127644,-40.831690241479926,-40.868134941683415,-40.90457964188691,-40.9410243420904,-40.97746904229388,-41.01391374249738,-41.05035844270087,-41.08680314290436,-41.123247843107855,-41.159692543311344,-41.196137243514826,-41.23258194371832,-41.26902664392181,-41.30547134412531,-41.3419160443288,-41.37836074453229,-41.414805444735784,-41.451250144939266,-41.487694845142755,-41.49626030230687,-41.49088613795132,-41.485511973595756,-41.48013780924019,-41.47476364488463,-41.46938948052907,-41.4640153161735,-41.458641151817936,-41.45326698746238,-41.44789282310682,-41.442518658751254,-41.442131381766686,-41.44373884222061,-41.44534630267453,-41.44695376312845,-41.448561223582374,-41.45016868403629,-41.45177614449021,-41.453383604944136,-41.45499106539806,-41.45659852585199,-41.458205986305906,-41.459813446759824,-41.46142090721374,-41.463028367667675,-41.464635828121594,-41.46624328857551,-41.46785074902944,-41.469458209483356,-41.471065669937275,-41.4726731303912,-41.47428059084512,-41.475888051299044,-41.47749551175296,-41.47910297220689,-41.48071043266081,-41.48231789311473,-41.48392535356865,-41.48553281402258,-41.487140274476495,-41.48874773493042,-41.49035519538434,-41.491962655838265,-41.49357011629218,-41.4951775767461,-41.49678503720003,-41.49839249765395,-41.49999995810787,-41.50160741856179,-41.503214879015715,-41.50482233946964,-41.50642979992356,-41.50803726037748,-41.5096447208314,-41.51125218128532,-41.51285964173924,-41.514467102193166,-41.51607456264709,-41.51768202310101,-41.519289483554935,-41.520896944008854,-41.52250440446278,-41.5241118649167,-41.525719325370616,-41.52732678582454,-41.52893424627847,-41.53054170673239,-41.532149167186304,-41.53375662764023,-41.535364088094155,-41.536971548548074,-41.53857900900199,-41.54018646945592,-41.541793929909836,-41.54340139036376,-41.54500885081768,-41.5466163112716,-41.54822377172553,-41.54983123217945,-41.55143869263337,-41.553046153087294,-41.55465361354121,-41.55626107399514,-41.461242283820745,-41.26959724301807,-41.07795220221541,-40.886307161412745,-40.694662120610055,-40.503017079807385,-40.311372039004716,-40.11972699820204,-39.92808195739936,-39.7364369165967,-39.54479187579402,-39.353146834991335,-39.16150179418867,-38.969856753386,-38.77821171258332,-38.58656667178066,-38.39492163097798,-38.2032765901753,-38.01163154937264,-37.81998650856997,-37.628341467767285,-37.4366964269646,-37.245051386161954,-37.053406345359264,-36.86176130455658,-36.67011626375392,-36.47847122295125,-36.286826182148566,-36.095181141345904,-35.903536100543235,-35.71189105974055,-35.52024601893787,-35.32860097813521,-35.13695593733253,-34.94531089652985,-34.749409583182825,-34.547011869526855,-34.34461415587087,-34.14221644221491,-33.93981872855895,-33.737421014902964,-33.535023301246994,-33.332625587591025,-33.13022787393504,-32.92783016027906,-32.72543244662312,-32.52303473296713,-32.32063701931115,-32.11823930565518,-31.915841591999218,-31.713443878343234,-31.511046164687265,-31.308648451031303,-31.10625073737532,-30.903853023719336,-30.701455310063384,-30.499057596407404,-30.296659882751413,-30.09426216909545,-29.89186445543949,-29.689466741783505,-29.48706902812754,-29.284671314471574,-29.08227360081559,-28.87987588715962,-28.67747817350366,-28.47508045984767,-28.27268274619169,-28.070285032535743,-27.867887318879756,-27.665489605223776,-27.463091891567807,-27.260694177911844,-27.05829646425586,-26.85589875059989,-26.65350103694393,-26.451103323287946,-26.248705609631976,-26.046307895976014,-25.84391018232003,-25.641512468664047,-25.439114755008077,-25.236717041352115,-25.083539390370614,-25.02880186473805,-24.97406433910548,-24.91932681347291,-24.864589287840342,-24.809851762207778,-24.75511423657521,-24.700376710942635,-24.645639185310074,-24.590901659677503,-24.53616413404493,-24.481426608412363,-24.426689082779795,-24.371951557147227,-24.31721403151466,-24.26247650588209,-24.207738980249523,-24.153001454616955,-24.09826392898439,-24.04352640335182,-23.988788877719244,-23.93405135208668,-23.879313826454112,-23.82457630082154,-23.76983877518898,-23.71510124955641,-23.660363723923837,-23.60562619829127,-23.550888672658704,-23.496151147026133,-23.441413621393565,-23.386676095760997,-23.331938570128433,-23.277201044495857,-23.22246351886329,-23.16772599323072,-23.112988467598157,-23.058250941965586,-23.00351341633302,-22.948775890700446,-22.894038365067882,-22.839300839435317,-22.784563313802746,-22.72982578817017,-22.675088262537606,-22.620350736905046,-22.56561321127247,-22.510875685639903,-22.456138160007335,-22.401400634374763,-22.346663108742195,-22.291925583109634,-22.23718805747706,-22.18245053184449,-22.126793875256876,-22.070908601174096,-22.015023327091317,-21.959138053008544,-21.903252778925772,-21.847367504842993,-21.791482230760217,-21.735596956677444,-21.679711682594665,-21.62382640851189,-21.567941134429116,-21.51205586034634,-21.45617058626356,-21.400285312180788,-21.34440003809801,-21.288514764015233,-21.232629489932457,-21.176744215849684,-21.120858941766905,-21.064973667684132,-21.009088393601356,-20.95320311951858,-20.8973178454358,-20.84143257135303,-20.785547297270256,-20.72966202318747,-20.673776749104697,-20.617891475021924,-20.562006200939145,-20.4848222489497,-20.301144907426874,-20.117467565904054,-19.93379022438123,-19.75011288285844,-19.566435541335615,-19.38275819981279,-19.19908085829,-19.015403516767172,-18.83172617524435,-18.64804883372156,-18.464371492198737,-18.28069415067591,-18.097016809153086,-17.913339467630298,-17.72966212610747,-17.545984784584647,-17.362307443061855,-17.17863010153903,-16.994952760016208,-16.811275418493416,-16.627598076970592,-16.44392073544777,-16.26024339392498,-16.076566052402153,-15.89288871087933,-15.709211369356506,-15.525534027833714,-15.34185668631089,-15.158179344788067,-14.974502003265275,-14.790824661742452,-14.607147320219628,-14.423469978696836,-14.249920680193467,-14.090550865182024,-13.931181050170583,-13.771811235159168,-13.612441420147727,-13.453071605136284,-13.29370179012487,-13.134331975113431,-12.974962160101988,-12.815592345090577,-12.656222530079132,-12.496852715067691,-12.337482900056278,-12.178113085044837,-12.018743270033394,-11.859373455021954,-11.721619814830238,-11.59107141917572,-11.460523023521201,-11.329974627866704,-11.199426232212186,-11.068877836557668,-10.938329440903173,-10.807781045248653,-10.677232649594135,-10.546684253939617,-10.416135858285124,-10.285587462630605,-10.155039066976085,-10.02449067132159,-9.893942275667072,-9.763393880012552,-9.632845484358057,-9.50229708870354,-9.371748693049021,-9.241200297394528,-9.110651901740006,-8.980103506085491,-8.84955511043097,-8.719006714776476,-8.58845831912196,-8.457909923467438,-8.327361527812943,-8.196813132158427,-8.066264736503907,-7.935716340849412,-7.805167945194896,-7.674619549540374,-7.544071153885858,-7.413522758231363],[-34.83487263767347,-34.874016317338864,-34.91315999700426,-34.95230367666964,-34.99144735633504,-35.03059103600043,-35.06973471566582,-35.10887839533121,-35.148022074996604,-35.187165754662,-35.22630943432738,-35.26545311399278,-35.30459679365817,-35.34374047332356,-35.38288415298895,-35.422027832654344,-35.46117151231973,-35.50031519198512,-35.53945887165052,-35.57860255131591,-35.6177462309813,-35.65688991064669,-35.696033590312084,-35.73517726997747,-35.77432094964286,-35.81346462930826,-35.85260830897364,-35.89175198863904,-35.93089566830443,-35.97003934796982,-36.00918302763521,-36.0483267073006,-36.08747038696599,-36.12661406663139,-36.16575774629678,-36.20490142596217,-36.24404510562756,-36.28318878529295,-36.32233246495835,-36.36147614462374,-36.40061982428912,-36.43976350395452,-36.47890718361991,-36.518050863285296,-36.55719454295069,-36.59633822261608,-36.63548190228148,-36.67462558194686,-36.71376926161225,-36.75291294127765,-36.792056620943036,-36.83120030060843,-36.87034398027382,-36.90948765993921,-36.9486313396046,-36.987775019269996,-37.02691869893539,-37.066062378600776,-37.10520605826617,-37.14434973793156,-37.18349341759695,-37.22263709726234,-37.261780776927736,-37.30092445659312,-37.340068136258516,-37.37921181592391,-37.418355495589296,-37.45749917525469,-37.49664285492008,-37.53578653458547,-37.57493021304242,-37.61237238166664,-37.64981455029087,-37.687256718915094,-37.72469888753931,-37.76214105616354,-37.79958322478776,-37.837025393411984,-37.87446756203621,-37.91190973066044,-37.94935189928466,-37.98679406790888,-38.024236236533106,-38.06167840515733,-38.097299915653025,-38.13255729452301,-38.16781467339299,-38.203072052262975,-38.23832943113296,-38.27358681000294,-38.30884418887293,-38.34410156774292,-38.379358946612896,-38.41461632548288,-38.44987370435287,-38.48513108322285,-38.52038846209283,-38.556437387675224,-38.59288208787871,-38.62932678808221,-38.6657714882857,-38.702216188489196,-38.738660888692685,-38.775105588896174,-38.81155028909967,-38.84799498930316,-38.88443968950665,-38.92088438971014,-38.95732908991363,-38.99377379011712,-39.03021849032061,-39.0666631905241,-39.10310789072759,-39.13955259093109,-39.17599729113458,-39.21244199133807,-39.24888669154156,-39.285331391745046,-39.321776091948536,-39.358220792152025,-39.39466549235552,-39.43111019255901,-39.4675548927625,-39.503999592966,-39.540444293169486,-39.576888993372975,-39.613333693576465,-39.649778393779954,-39.68622309398344,-39.72266779418693,-39.75911249439042,-39.795557194593925,-39.83200189479741,-39.868446595000904,-39.90489129520439,-39.94133599540788,-39.97778069561137,-40.01422539581486,-40.05067009601835,-40.08711479622185,-40.12355949642533,-40.160004196628826,-40.19644889683232,-40.232893597035805,-40.2693382972393,-40.30578299744279,-40.34222769764628,-40.378672397849776,-40.415117098053265,-40.45156179825676,-40.48800649846025,-40.52445119866374,-40.56089589886722,-40.59734059907072,-40.63378529927421,-40.6702299994777,-40.70667469968119,-40.74311939988468,-40.77956410008817,-40.81600880029166,-40.85245350049515,-40.88889820069865,-40.92534290090214,-40.96178760110563,-40.998232301309116,-41.034677001512605,-41.0711217017161,-41.09308641671636,-41.107811139114986,-41.12253586151362,-41.13726058391225,-41.15198530631088,-41.16671002870951,-41.18143475110814,-41.196159473506775,-41.210884195905415,-41.22560891830404,-41.24033364070267,-41.2550583631013,-41.26978308549994,-41.28450780789857,-41.299232530297196,-41.31395725269583,-41.32868197509446,-41.343406697493094,-41.35813141989173,-41.37285614229036,-41.387580864688985,-41.402305587087625,-41.41703030948626,-41.43175503188489,-41.4407081635851,-41.44231562403902,-41.443923084492944,-41.44553054494686,-41.44713800540078,-41.44874546585471,-41.450352926308625,-41.45196038676255,-41.453567847216476,-41.455175307670395,-41.45678276812431,-41.45839022857824,-41.459997689032164,-41.46160514948608,-41.46321260994,-41.46482007039393,-41.46642753084785,-41.468034991301764,-41.46964245175569,-41.47124991220961,-41.47285737266354,-41.47446483311745,-41.47607229357137,-41.4776797540253,-41.479287214479214,-41.48089467493314,-41.482502135387065,-41.484109595840984,-41.48571705629491,-41.48732451674883,-41.48893197720275,-41.49053943765668,-41.4921468981106,-41.493754358564516,-41.495361819018434,-41.49696927947236,-41.498576739926285,-41.500184200380204,-41.50179166083412,-41.503399121288055,-41.505006581741966,-41.50661404219589,-41.50822150264982,-41.50982896310373,-41.51143642355766,-41.51304388401158,-41.514651344465506,-41.51625880491942,-41.51786626537334,-41.519473725827275,-41.521081186281194,-41.522688646735105,-41.52429610718903,-41.525903567642956,-41.527511028096875,-41.52911848855081,-41.53072594900471,-41.532333409458644,-41.53394086991256,-41.43892207973818,-41.2472770389355,-41.05563199813283,-40.86398695733017,-40.67234191652748,-40.48069687572481,-40.28905183492215,-40.09740679411947,-39.90576175331678,-39.714116712514134,-39.52247167171145,-39.33082663090876,-39.1391815901061,-38.947536549303436,-38.755891508500746,-38.564246467698084,-38.372601426895415,-38.180956386092724,-37.98931134529006,-37.7976663044874,-37.60602126368472,-37.41437622288203,-37.22273118207938,-37.031086141276695,-36.83944110047401,-36.64779605967134,-36.45615101886868,-36.264505978066,-36.07286093726333,-35.88121589646066,-35.689570855657976,-35.49792581485529,-35.306280774052645,-35.11463573324996,-34.92299069244728,-34.73134565164461,-34.53970061084195,-34.34805557003926,-34.156410529236595,-33.964765488433926,-33.77312044763124,-33.581475406828574,-33.38983036602591,-33.19818532522323,-33.00654028442054,-32.8148952436179,-32.62325020281521,-32.431605162012524,-32.23996012120986,-32.04831508040719,-31.85667003960451,-31.665024998801844,-31.473379957999175,-31.28173491719649,-31.090089876393805,-30.898444835591157,-30.706799794788473,-30.51515475398579,-30.32350971318312,-30.13186467238046,-29.940219631577776,-29.74812654767741,-29.545728834021446,-29.343331120365463,-29.140933406709493,-28.93853569305353,-28.736137979397547,-28.53374026574156,-28.331342552085616,-28.128944838429632,-27.926547124773645,-27.724149411117683,-27.521751697461717,-27.319353983805733,-27.116956270149768,-26.9145585564938,-26.712160842837818,-26.50976312918185,-26.307365415525886,-26.104967701869903,-25.90256998821392,-25.700172274557954,-25.497774560901984,-25.344596909920483,-25.289859384287922,-25.235121858655354,-25.180384333022783,-25.125646807390215,-25.070909281757647,-25.016171756125075,-24.961434230492507,-24.906696704859947,-24.85195917922737,-24.7972216535948,-24.742484127962236,-24.687746602329668,-24.6330090766971,-24.57827155106453,-24.523534025431964,-24.468796499799392,-24.414058974166828,-24.35932144853426,-24.304583922901692,-24.249846397269117,-24.19510887163655,-24.14037134600398,-24.085633820371413,-24.03089629473885,-23.97615876910628,-23.92142124347371,-23.86668371784114,-23.811946192208573,-23.757208666576,-23.702471140943434,-23.64773361531087,-23.5929960896783,-23.538258564045726,-23.483521038413166,-23.428783512780594,-23.374045987148026,-23.319308461515458,-23.26457093588289,-23.20983341025032,-23.15509588461775,-23.100358358985186,-23.045620833352615,-22.990883307720043,-22.93614578208748,-22.88140825645491,-22.82667073082234,-22.771933205189775,-22.717195679557207,-22.662458153924636,-22.607720628292068,-22.552983102659503,-22.49824557702693,-22.44350805139436,-22.3887705257618,-22.334033000129228,-22.279295474496656,-22.22455794886409,-22.1702142177775,-22.11636272938605,-22.062511240994606,-22.00865975260316,-21.95480826421171,-21.900956775820266,-21.84710528742882,-21.79325379903737,-21.73940231064592,-21.68555082225448,-21.631699333863033,-21.577847845471585,-21.523996357080136,-21.470144868688696,-21.41629338029724,-21.362441891905803,-21.30859040351436,-21.254738915122903,-21.200887426731455,-21.147035938340014,-21.093184449948566,-21.03933296155712,-20.985481473165674,-20.93162998477423,-20.877778496382778,-20.801092058308438,-20.610230871819574,-20.41936968533071,-20.228508498841848,-20.037647312353023,-19.84678612586416,-19.655924939375296,-19.465063752886472,-19.292572504514347,-19.1332026895029,-18.973832874491492,-18.81446305948005,-18.655093244468606,-18.495723429457165,-18.33635361444575,-18.17698379943431,-18.017613984422866,-17.858244169411456,-17.698874354400015,-17.53950453938857,-17.380134724377157,-17.22076490936572,-17.061395094354275,-16.902025279342862,-16.742655464331417,-16.583285649319976,-16.423915834308534,-16.26454601929712,-16.105176204285684,-15.945806389274237,-15.786436574262826,-15.627066759251385,-15.46769694423994,-15.308327129228529,-15.148957314217089,-14.989587499205644,-14.830217684194203,-14.67084786918279,-14.511478054171349,-14.352108239159907,-14.192738424148493,-14.033368609137053,-13.873998794125612,-13.714628979114195,-13.555259164102756,-13.395889349091314,-13.2365195340799,-13.077149719068458,-12.917779904057017,-12.758410089045574,-12.59904027403416,-12.43967045902272,-12.280300644011279,-12.120930828999864,-11.961561013988423,-11.802191198976981,-11.642821383965568,-11.483451568954125,-11.324081753942684,-11.16471193893124,-11.00534212391983,-10.845972308908387,-10.686602493896945,-10.527232678885532,-10.36786286387409,-10.208493048862648,-10.049123233851235,-9.889753418839796,-9.73038360382835,-9.571013788816938,-9.411643973805496,-9.252274158794053,-9.092904343782614,-8.9335345287712,-8.774164713759758,-8.614794898748315,-8.46707798039407,-8.327684528574537,-8.188291076755004,-8.048897624935497,-7.909504173115964,-7.770110721296432,-7.630717269476899,-7.491323817657393],[-34.461978107396185,-34.50112178706158,-34.54026546672697,-34.57940914639236,-34.61855282605775,-34.657696505723145,-34.69684018538853,-34.735983865053925,-34.77512754471932,-34.81427122438471,-34.8534149040501,-34.89255858371549,-34.931702263380885,-34.97084594304627,-35.009989622711664,-35.04913330237706,-35.088276982042444,-35.12742066170784,-35.16656434137323,-35.20570802103862,-35.24485170070401,-35.283995380369404,-35.32313906003479,-35.36228273970019,-35.40142641936557,-35.440570099030964,-35.479713778696365,-35.51885745836175,-35.558001138027144,-35.59714481769254,-35.636288497357924,-35.67543217702332,-35.714575856688704,-35.753719536354104,-35.79286321601949,-35.832006895684884,-35.87115057535028,-35.910294255015664,-35.94943793468106,-35.988581614346444,-36.02772529401184,-36.06686897367723,-36.10601265334262,-36.14515633300802,-36.184300012673404,-36.2234436923388,-36.26258737200419,-36.30173105166958,-36.340874731334964,-36.380018411000364,-36.41916209066575,-36.45830577033114,-36.49744944999654,-36.536593129661924,-36.57488605231754,-36.61232822094176,-36.64977038956599,-36.68721255819021,-36.724654726814435,-36.76209689543866,-36.799539064062884,-36.83698123268711,-36.87442340131133,-36.91186556993555,-36.94930773855978,-36.986749907184,-37.02419207580822,-37.06163424443245,-37.09907641305667,-37.136518581680896,-37.17396075030512,-37.21140291892934,-37.24884508755356,-37.28628725617779,-37.32372942480201,-37.361171593426235,-37.39861376205046,-37.436055930674684,-37.47349809929891,-37.51094026792314,-37.54838243654736,-37.58582460517158,-37.6232667737958,-37.66070894242003,-37.69633045291572,-37.7315878317857,-37.76684521065569,-37.80210258952567,-37.83735996839566,-37.87261734726564,-37.907874726135624,-37.9431321050056,-37.978389483875596,-38.013646862745574,-38.04890424161556,-38.084161620485546,-38.11941899935553,-38.15467637822552,-38.1899337570955,-38.22519113596548,-38.26044851483547,-38.295705893705446,-38.33096327257544,-38.366220651445424,-38.40147803031541,-38.43673540918539,-38.471992788055374,-38.50725016692536,-38.54250754579534,-38.57776492466533,-38.61302230353532,-38.648279682405295,-38.68353706127528,-38.71899232599502,-38.755437026198514,-38.791881726402,-38.82832642660549,-38.86477112680898,-38.90121582701247,-38.93766052721596,-38.97410522741945,-39.01054992762294,-39.046994627826436,-39.083439328029925,-39.119884028233415,-39.156328728436904,-39.1927734286404,-39.22921812884389,-39.26566282904738,-39.30210752925087,-39.33855222945436,-39.374996929657854,-39.41144162986134,-39.44788633006483,-39.48433103026833,-39.52077573047181,-39.55722043067531,-39.5936651308788,-39.63010983108229,-39.66655453128578,-39.70299923148927,-39.73944393169276,-39.77588863189625,-39.81233333209974,-39.84877803230323,-39.88522273250672,-39.921667432710215,-39.958112132913705,-39.9945568331172,-40.03100153332069,-40.06744623352418,-40.10389093372767,-40.14033563393116,-40.17678033413465,-40.213225034338144,-40.24966973454163,-40.286114434745116,-40.32255913494861,-40.3590038351521,-40.3954485353556,-40.43189323555909,-40.46833793576258,-40.504782635966066,-40.541227336169555,-40.577672036373045,-40.61411673657654,-40.65056143678003,-40.67252615178028,-40.687250874178915,-40.701975596577554,-40.71670031897618,-40.73142504137481,-40.746149763773445,-40.76087448617207,-40.77559920857071,-40.790323930969336,-40.80504865336797,-40.8197733757666,-40.83449809816524,-40.84922282056387,-40.86394754296251,-40.87867226536113,-40.893396987759765,-40.9081217101584,-40.92284643255702,-40.93757115495566,-40.95229587735429,-40.96702059975292,-40.98174532215155,-40.99647004455019,-41.01119476694882,-41.02591948934745,-41.040644211746084,-41.05536893414472,-41.07009365654335,-41.08481837894198,-41.099543101340615,-41.11426782373924,-41.12899254613787,-41.143717268536506,-41.15844199093513,-41.17316671333377,-41.187891435732396,-41.202616158131036,-41.21734088052966,-41.232065602928294,-41.24679032532693,-41.26151504772556,-41.27623977012419,-41.290964492522825,-41.30568921492146,-41.32041393732009,-41.335138659718716,-41.34986338211735,-41.36458810451598,-41.379312826914614,-41.394037549313246,-41.40876227171188,-41.42348699411051,-41.438211716509144,-41.45293643890777,-41.46661177312018,-41.468219233574104,-41.46982669402802,-41.47143415448195,-41.473041614935866,-41.47464907538979,-41.4762565358437,-41.477863996297636,-41.479471456751554,-41.48107891720548,-41.4826863776594,-41.48429383811332,-41.485901298567235,-41.48750875902117,-41.48911621947508,-41.490723679929005,-41.49233114038293,-41.49393860083685,-41.49554606129077,-41.49715352174469,-41.49876098219862,-41.50036844265254,-41.501975903106455,-41.50358336356038,-41.505190824014306,-41.506798284468225,-41.50840574492216,-41.51001320537607,-41.511620665829994,-41.41660187565561,-41.224956834852925,-41.03331179405026,-40.841666753247594,-40.65002171244491,-40.45837667164224,-40.26673163083957,-40.075086590036896,-39.883441549234206,-39.69179650843156,-39.500151467628875,-39.30850642682619,-39.11686138602352,-38.92521634522086,-38.73357130441818,-38.54192626361551,-38.35028122281284,-38.158636182010156,-37.966991141207494,-37.775346100404825,-37.58370105960214,-37.39205601879945,-37.20041097799681,-37.00876593719413,-36.817120896391444,-36.625475855588775,-36.433830814786106,-36.24218577398342,-36.05054073318075,-35.858895692378084,-35.6672506515754,-35.475605610772725,-35.28396056997007,-35.092315529167394,-34.9006704883647,-34.70902544756204,-34.51738040675937,-34.32573536595669,-34.13409032515402,-33.94244528435135,-33.75080024354867,-33.559155202746005,-33.367510161943336,-33.17586512114065,-32.98422008033798,-32.79257503953532,-32.60092999873264,-32.409284957929955,-32.217639917127286,-32.02599487632462,-31.834349835521934,-31.642704794719272,-31.451059753916603,-31.25941471311392,-31.067769672311236,-30.87612463150859,-30.684479590705905,-30.49283454990322,-30.301189509100553,-30.109544468297884,-29.9178994274952,-29.72625438669253,-29.53460934588987,-29.342964305087186,-29.151319264284517,-28.959674223481848,-28.768029182679168,-28.576384141876485,-28.384739101073837,-28.193094060271147,-28.00310252001899,-27.815123981550403,-27.62714544308181,-27.43916690461321,-27.251188366144618,-27.063209827676026,-26.87523128920742,-26.687252750738832,-26.499274212270244,-26.311295673801638,-26.123317135333025,-25.935338596864437,-25.74736005839585,-25.604576613009296,-25.552183353786834,-25.499790094564368,-25.447396835341895,-25.39500357611943,-25.34261031689696,-25.290217057674486,-25.23782379845202,-25.185430539229554,-25.13226339061577,-25.07841190222432,-25.024560413832877,-24.970708925441432,-24.91685743704998,-24.86300594865854,-24.809154460267095,-24.755302971875643,-24.7014514834842,-24.647599995092754,-24.593748506701306,-24.53989701830986,-24.486045529918407,-24.43219404152697,-24.378342553135518,-24.32449106474407,-24.27063957635263,-24.216788087961177,-24.162936599569733,-24.10908511117829,-24.055233622786837,-24.00138213439539,-23.947530646003948,-23.893679157612503,-23.83982766922105,-23.785976180829607,-23.73212469243816,-23.67827320404671,-23.624421715655266,-23.570570227263826,-23.516718738872374,-23.46286725048093,-23.409015762089485,-23.355164273698037,-23.301312785306585,-23.24746129691514,-23.193609808523696,-23.139758320132245,-23.0859068317408,-23.032055343349356,-22.978203854957908,-22.924352366566467,-22.870500878175022,-22.81664938978357,-22.76279790139212,-22.70894641300068,-22.65509492460923,-22.601243436217782,-22.547391947826338,-22.493540459434893,-22.439688971043445,-22.385837482652,-22.331985994260553,-22.278134505869104,-22.22428301747766,-22.170431529086216,-22.116580040694764,-22.062728552303312,-22.008877063911875,-21.955025575520423,-21.90117408712898,-21.847322598737534,-21.79347111034609,-21.73961962195464,-21.685768133563194,-21.63191664517175,-21.578065156780298,-21.52421366838885,-21.47036217999741,-21.416510691605957,-21.362659203214513,-21.308807714823068,-21.254956226431624,-21.201104738040172,-21.12441829996583,-20.933557113476965,-20.742695926988105,-20.551834740499245,-20.360973554010418,-20.170112367521554,-19.979251181032687,-19.788389994543863,-19.597528808055003,-19.40666762156614,-19.21580643507731,-19.024945248588452,-18.834084062099585,-18.643222875610725,-18.452361689121897,-18.261500502633034,-18.070639316144174,-17.879778129655346,-17.688916943166483,-17.49805575667762,-17.307194570188795,-17.11633338369993,-16.925472197211068,-16.734611010722244,-16.54374982423338,-16.35288863774452,-16.162027451255653,-15.971166264766826,-15.780305078277966,-15.605189542309958,-15.445819727298542,-15.286449912287102,-15.127080097275659,-14.967710282264246,-14.808340467252805,-14.648970652241362,-14.489600837229919,-14.33023102221851,-14.170861207207066,-14.011491392195625,-13.852121577184212,-13.692751762172769,-13.533381947161327,-13.374012132149915,-13.214642317138471,-13.05527250212703,-12.895902687115617,-12.736532872104176,-12.577163057092733,-12.41779324208129,-12.258423427069879,-12.099053612058436,-11.939683797046994,-11.780313982035581,-11.620944167024138,-11.47489194981421,-11.335498497994704,-11.196105046175173,-11.05671159435564,-10.917318142536107,-10.7779246907166,-10.63853123889707,-10.499137787077535,-10.359744335258029,-10.220350883438496,-10.080957431618964,-9.941563979799456,-9.802170527979925,-9.66277707616039,-9.523383624340886,-9.38399017252135,-9.244596720701818,-9.105203268882288,-8.96580981706278,-8.826416365243247,-8.687022913423716,-8.547629461604208,-8.408236009784675,-8.268842557965144,-8.129449106145636,-7.990055654326103,-7.850662202506571,-7.711268750687038,-7.571875298867532],[-34.0890835771189,-34.1282272567843,-34.167370936449686,-34.20651461611508,-34.24565829578047,-34.28480197544586,-34.32394565511125,-34.363089334776646,-34.40223301444203,-34.44137669410743,-34.48052037377282,-34.519664053438206,-34.5588077331036,-34.59795141276899,-34.63709509243438,-34.67623877209978,-34.715382451765166,-34.75452613143056,-34.79366981109595,-34.83281349076134,-34.871957170426725,-34.911100850092126,-34.95024452975751,-34.9893882094229,-35.0285318890883,-35.067675568753685,-35.10681924841907,-35.14596292808447,-35.18510660774986,-35.22425028741526,-35.263393967080646,-35.30253764674603,-35.341681326411425,-35.38082500607682,-35.41996868574221,-35.4591123654076,-35.49825604507299,-35.537399722968445,-35.57484189159267,-35.61228406021689,-35.649726228841104,-35.68716839746534,-35.72461056608956,-35.762052734713784,-35.79949490333801,-35.83693707196223,-35.87437924058645,-35.91182140921068,-35.9492635778349,-35.98670574645912,-36.02414791508335,-36.06159008370757,-36.099032252331796,-36.13647442095602,-36.173916589580244,-36.21135875820447,-36.24880092682869,-36.28624309545292,-36.32368526407714,-36.36112743270136,-36.39856960132558,-36.43601176994981,-36.47345393857403,-36.51089610719825,-36.54833827582248,-36.585780444446705,-36.62322261307093,-36.660664781695154,-36.69810695031937,-36.735549118943595,-36.77299128756782,-36.810433456192044,-36.84787562481627,-36.88531779344049,-36.92275996206472,-36.96020213068894,-36.99764429931316,-37.03508646793739,-37.072528636561614,-37.10997080518584,-37.14741297381006,-37.18485514243429,-37.22229731105851,-37.259739479682736,-37.29536099017842,-37.33061836904841,-37.36587574791839,-37.40113312678837,-37.43639050565836,-37.47164788452834,-37.50690526339832,-37.54216264226831,-37.577420021138295,-37.61267740000828,-37.647934778878266,-37.683192157748245,-37.71844953661824,-37.753706915488216,-37.7889642943582,-37.82422167322819,-37.85947905209817,-37.89473643096816,-37.92999380983814,-37.96525118870812,-38.00050856757811,-38.03576594644809,-38.07102332531808,-38.106280704188066,-38.14153808305805,-38.17679546192803,-38.212052840798016,-38.247310219667995,-38.28256759853798,-38.31782497740797,-38.35308235627795,-38.38833973514794,-38.42359711401792,-38.45885449288791,-38.49411187175789,-38.52936925062787,-38.564626629497866,-38.59988400836784,-38.63514138723782,-38.670398766107816,-38.705656144977794,-38.74091352384777,-38.776170902717766,-38.81142828158775,-38.84668566045773,-38.88194303932772,-38.9179919645183,-38.9544366647218,-38.990881364925286,-39.027326065128776,-39.063770765332265,-39.100215465535754,-39.13666016573925,-39.17310486594274,-39.20954956614623,-39.24599426634972,-39.282438966553215,-39.3188836667567,-39.35532836696019,-39.39177306716368,-39.42821776736717,-39.46466246757066,-39.50110716777416,-39.53755186797764,-39.57399656818114,-39.61044126838463,-39.64688596858812,-39.68333066879161,-39.7197753689951,-39.75622006919859,-39.79266476940209,-39.82910946960557,-39.865554169809066,-39.901998870012555,-39.938443570216045,-39.974888270419534,-40.01133297062303,-40.04777767082652,-40.08422237103001,-40.1206670712335,-40.15711177143699,-40.193556471640484,-40.230001171843966,-40.251965886844225,-40.26669060924286,-40.28141533164149,-40.29614005404012,-40.31086477643875,-40.32558949883739,-40.340314221236014,-40.35503894363465,-40.36976366603328,-40.38448838843192,-40.399213110830544,-40.41393783322918,-40.42866255562781,-40.44338727802644,-40.458112000425075,-40.47283672282371,-40.48756144522234,-40.502286167620966,-40.517010890019606,-40.53173561241823,-40.546460334816864,-40.561185057215496,-40.57590977961413,-40.59063450201276,-40.60535922441139,-40.62008394681002,-40.63480866920865,-40.64953339160729,-40.66425811400592,-40.67898283640455,-40.69370755880318,-40.708432281201816,-40.72315700360045,-40.737881725999074,-40.752606448397714,-40.76733117079634,-40.78205589319497,-40.796780615593605,-40.81150533799223,-40.82623006039087,-40.840954782789495,-40.855679505188135,-40.87040422758677,-40.88512894998539,-40.899853672384026,-40.91457839478265,-40.92930311718129,-40.94402783957992,-40.95875256197856,-40.97347728437719,-40.98820200677582,-41.002926729174455,-41.01765145157308,-41.03237617397171,-41.04710089637035,-41.06182561876898,-41.07655034116761,-41.09127506356624,-41.105999785964876,-41.1207245083635,-41.13544923076214,-41.15017395316077,-41.1648986755594,-41.17962339795803,-41.194348120356665,-41.209072842755305,-41.22379756515393,-41.23852228755256,-41.253247009951195,-41.26797173234983,-41.282696454748454,-41.297421177147086,-41.31214589954571,-41.32687062194436,-41.341595344342984,-41.35632006674162,-41.37104478914025,-41.38576951153888,-41.40049423393751,-41.41521895633614,-41.42994367873478,-41.448706382595404,-41.4699540143756,-41.391463622952784,-41.213235208326964,-41.03500679370116,-40.84817531033374,-40.660196771865124,-40.47221823339653,-40.28423969492795,-40.09626115645934,-39.90828261799073,-39.720304079522165,-39.53232554105355,-39.344347002584946,-39.156368464116355,-38.96838992564777,-38.780411387179164,-38.59243284871057,-38.40445431024199,-38.216475771773375,-38.02849723330478,-37.84051869483619,-37.65254015636759,-37.46456161789899,-37.27658307943041,-37.0886045409618,-36.90062600249319,-36.712647464024606,-36.52466892555602,-36.33669038708741,-36.14871184861882,-35.96073331015023,-35.772754771681626,-35.58477623321302,-35.39679769474444,-35.20881915627584,-35.02084061780723,-34.83286207933864,-34.644883540870055,-34.45690500240145,-34.26892646393286,-34.08094792546427,-33.89296938699567,-33.70499084852707,-33.51701231005848,-33.32903377158988,-33.141055233121264,-32.953076694652694,-32.76509815618409,-32.57711961771548,-32.38914107924689,-32.201162540778306,-32.0131840023097,-31.825205463841108,-31.63722692537252,-31.44924838690391,-31.261269848435305,-31.07329130996673,-30.885312771498125,-30.697334233029522,-30.50935569456093,-30.32137715609234,-30.133398617623733,-29.945420079155145,-29.75744154068655,-29.569463002217944,-29.38148446374936,-29.193505925280768,-29.00552738681216,-28.817548848343556,-28.629570309874985,-28.44159177140638,-28.253613232937766,-28.065634694469182,-27.87765615600059,-27.689677617531984,-27.501699079063393,-27.313720540594804,-27.125742002126195,-26.937763463657607,-26.749784925189015,-26.561806386720413,-26.373827848251803,-26.185849309783215,-25.997870771314624,-25.85508732592807,-25.80269406670561,-25.750300807483143,-25.697907548260673,-25.645514289038204,-25.593121029815734,-25.540727770593264,-25.488334511370795,-25.435941252148332,-25.38354799292586,-25.331154733703382,-25.27876147448092,-25.226368215258454,-25.17397495603598,-25.121581696813518,-25.06918843759105,-25.01679517836858,-24.96440191914611,-24.912008659923643,-24.85961540070117,-24.807222141478697,-24.75482888225623,-24.702435623033765,-24.650042363811295,-24.597649104588825,-24.545255845366363,-24.492862586143886,-24.440469326921416,-24.388076067698954,-24.33568280847648,-24.28328954925401,-24.23089629003155,-24.178503030809075,-24.126109771586602,-24.073716512364136,-24.021323253141674,-23.9689299939192,-23.916536734696734,-23.864143475474265,-23.81175021625179,-23.759356957029325,-23.70696369780686,-23.654570438584386,-23.602177179361917,-23.54978392013945,-23.497390660916984,-23.444997401694508,-23.392604142472045,-23.34021088324958,-23.287817624027106,-23.235424364804636,-23.18303110558217,-23.130637846359697,-23.078244587137227,-23.025851327914765,-22.973458068692295,-22.921064809469826,-22.868671550247356,-22.81627829102489,-22.763015212700832,-22.709163724309388,-22.65531223591794,-22.60146074752649,-22.54760925913505,-22.493757770743603,-22.439906282352155,-22.386054793960703,-22.332203305569262,-22.278351817177814,-22.224500328786366,-22.17064884039492,-22.116797352003474,-22.062945863612022,-22.00909437522058,-21.955242886829136,-21.90139139843769,-21.847539910046237,-21.7936884216548,-21.739836933263348,-21.685985444871896,-21.632133956480455,-21.57828246808901,-21.52443097969756,-21.447744541623216,-21.256883355134356,-21.066022168645492,-20.875160982156633,-20.684299795667805,-20.49343860917894,-20.302577422690078,-20.111716236201254,-19.920855049712394,-19.729993863223527,-19.5391326767347,-19.348271490245835,-19.157410303756976,-18.966549117268112,-18.775687930779288,-18.584826744290424,-18.393965557801565,-18.203104371312733,-18.012243184823873,-17.821381998335006,-17.630520811846182,-17.43965962535732,-17.24879843886846,-17.057937252379627,-16.889285487777794,-16.721599277893482,-16.553913068009173,-16.386226858124893,-16.21854064824058,-16.050854438356268,-15.883168228471991,-15.715482018587679,-15.547795808703366,-15.380109598819088,-15.212423388934777,-15.044737179050465,-14.877050969166154,-14.709364759281875,-14.541678549397563,-14.373992339513253,-14.206306129628972,-14.038619919744662,-13.87093370986035,-13.70324749997607,-13.535561290091758,-13.36787508020745,-13.200188870323167,-13.032502660438858,-12.864816450554546,-12.697130240670235,-12.529444030785955,-12.361757820901644,-12.194071611017332,-12.026385401133053,-11.858699191248741,-11.69101298136443,-11.52332677148015,-11.355640561595841,-11.18795435171153,-11.020268141827218,-10.858476171926737,-10.719082720107206,-10.579689268287673,-10.440295816468169,-10.300902364648634,-10.1615089128291,-10.022115461009593,-9.882722009190061,-9.743328557370528,-9.603935105551022,-9.46454165373149,-9.325148201911958,-9.185754750092425,-9.046361298272917,-8.906967846453384,-8.767574394633852,-8.628180942814346,-8.488787490994813,-8.34939403917528,-8.210000587355774,-8.07060713553624,-7.931213683716708,-7.7918202318971765,-7.652426780077668],[-33.71618904684163,-33.75533272650702,-33.79447640617241,-33.8336200858378,-33.872763765503194,-33.91190744516858,-33.951051124833974,-33.99019480449937,-34.029338484164754,-34.068482163830154,-34.10762584349554,-34.14676952316093,-34.18591320282632,-34.225056882491714,-34.26420056215711,-34.3033442418225,-34.34248792148789,-34.38163160115328,-34.420775280818674,-34.45991896048407,-34.499062640149454,-34.537355562243576,-34.57479773086779,-34.61223989949202,-34.64968206811624,-34.68712423674046,-34.72456640536468,-34.76200857398891,-34.79945074261313,-34.836892911237356,-34.87433507986158,-34.911777248485805,-34.94921941711003,-34.986661585734254,-35.02410375435848,-35.0615459229827,-35.09898809160693,-35.13643026023115,-35.173872428855375,-35.2113145974796,-35.24875676610382,-35.28619893472805,-35.323641103352266,-35.36108327197649,-35.398525440600714,-35.43596760922493,-35.47340977784916,-35.51085194647339,-35.548294115097605,-35.58573628372183,-35.62317845234605,-35.66062062097028,-35.6980627895945,-35.735504958218726,-35.77294712684295,-35.810389295467175,-35.8478314640914,-35.885273632715624,-35.92271580133984,-35.960157969964065,-35.9976001385883,-36.035042307212514,-36.07248447583674,-36.10992664446096,-36.14736881308519,-36.184810981709404,-36.22225315033363,-36.25969531895786,-36.297137487582084,-36.3345796562063,-36.372021824830526,-36.40946399345475,-36.446906162078974,-36.4843483307032,-36.52179049932742,-36.55923266795165,-36.596674836575865,-36.63411700520009,-36.67155917382432,-36.709001342448545,-36.74644351107277,-36.783885679696986,-36.82132784832121,-36.858770016945435,-36.89439152744112,-36.92964890631111,-36.964906285181094,-37.00016366405108,-37.03542104292106,-37.070678421791044,-37.10593580066103,-37.141193179531015,-37.176450558401,-37.21170793727099,-37.24696531614097,-37.28222269501095,-37.317480073880944,-37.35273745275092,-37.387994831620915,-37.423252210490894,-37.45850958936087,-37.49376696823086,-37.529024347100844,-37.56428172597083,-37.599539104840815,-37.6347964837108,-37.67005386258079,-37.705311241450765,-37.74056862032075,-37.77582599919073,-37.81108337806072,-37.8463407569307,-37.88159813580069,-37.91685551467067,-37.95211289354066,-37.987370272410644,-38.02262765128063,-38.05788503015061,-38.093142409020594,-38.12839978789057,-38.163657166760565,-38.19891454563055,-38.23417192450053,-38.269429303370515,-38.3046866822405,-38.33994406111049,-38.37520143998047,-38.41045881885045,-38.44571619772044,-38.48097357659043,-38.51623095546041,-38.551488334330394,-38.58674571320037,-38.62200309207036,-38.657260470940344,-38.69251784981032,-38.727775228680315,-38.7630326075503,-38.79828998642028,-38.833547365290265,-38.86880474416025,-38.90406212303023,-38.93931950190022,-38.97457688077021,-39.009834259640186,-39.04509163851017,-39.080546902838094,-39.11699160304159,-39.15343630324507,-39.18988100344857,-39.22632570365206,-39.26277040385555,-39.299215104059044,-39.335659804262534,-39.37210450446602,-39.40854920466951,-39.444993904873,-39.48143860507649,-39.51788330527999,-39.55432800548348,-39.590772705686966,-39.62721740589046,-39.66366210609395,-39.70010680629744,-39.73655150650093,-39.77299620670442,-39.80944090690791,-39.83140562190816,-39.8461303443068,-39.860855066705426,-39.875579789104066,-39.89030451150269,-39.905029233901324,-39.91975395629996,-39.93447867869859,-39.94920340109722,-39.963928123495855,-39.97865284589449,-39.99337756829312,-40.008102290691745,-40.02282701309038,-40.03755173548901,-40.05227645788764,-40.067001180286276,-40.08172590268491,-40.09645062508354,-40.111175347482174,-40.1259000698808,-40.14062479227944,-40.15534951467807,-40.170074237076705,-40.18479895947533,-40.199523681873956,-40.214248404272595,-40.22897312667123,-40.24369784906986,-40.25842257146849,-40.27314729386712,-40.28787201626576,-40.30259673866439,-40.31732146106302,-40.33204618346164,-40.34677090586028,-40.361495628258915,-40.37622035065755,-40.39094507305617,-40.40566979545481,-40.42039451785344,-40.43511924025208,-40.44984396265071,-40.464568685049336,-40.47929340744797,-40.498987968977765,-40.52023560075796,-40.54148323253816,-40.562730864318354,-40.58397849609855,-40.605226127878744,-40.62647375965894,-40.64772139143914,-40.66896902321933,-40.69021665499953,-40.71146428677973,-40.732711918559914,-40.75395955034012,-40.77520718212032,-40.79645481390052,-40.81770244568071,-40.83895007746089,-40.8601977092411,-40.88144534102129,-40.90269297280149,-40.92394060458169,-40.945188236361886,-40.96643586814208,-40.98768349992228,-41.00893113170247,-41.03017876348267,-41.051426395262865,-41.07267402704306,-41.09392165882325,-41.11516929060345,-41.136416922383646,-41.15766455416384,-41.178912185944036,-41.20015981772423,-41.221407449504426,-41.242655081284624,-41.26390271306482,-41.285150344845015,-41.206659953422204,-41.02843153879638,-40.85020312417058,-40.67197470954477,-40.49374629491895,-40.31551788029315,-40.137289465667344,-39.95906105104153,-39.78083263641571,-39.60260422178992,-39.4243758071641,-39.246147392538276,-39.06791897791247,-38.88969056328667,-38.71146214866085,-38.53323373403504,-38.355005319409244,-38.176776904783424,-37.99854849015762,-37.82032007553181,-37.642091660906,-37.46386324628017,-37.28563483165439,-37.10740641702857,-36.92917800240274,-36.75094958777694,-36.57272117315114,-36.39449275852532,-36.21626434389951,-36.03803592927371,-35.85980751464789,-35.68157910002207,-35.50335068539628,-35.325122270770464,-35.146893856144644,-34.96866544151883,-34.79043702689303,-34.61220861226722,-34.433980197641404,-34.255751783015604,-34.077523368389784,-33.89929495376398,-33.72106653913818,-33.54283812451235,-33.36460970988654,-33.18638129526075,-33.008152880634924,-32.82763033063426,-32.63965179216567,-32.45167325369708,-32.263694715228475,-32.07571617675988,-31.88773763829129,-31.69975909982269,-31.51178056135408,-31.323802022885506,-31.1358234844169,-30.947844945948297,-30.759866407479706,-30.571887869011114,-30.38390933054251,-30.19593079207392,-30.007952253605332,-29.819973715136726,-29.631995176668134,-29.444016638199543,-29.256038099730937,-29.068059561262327,-28.880081022793757,-28.69210248432515,-28.50412394585654,-28.316145407387957,-28.128166868919365,-27.94018833045076,-27.752209791982168,-27.564231253513576,-27.376252715044973,-27.188274176576382,-27.000295638107794,-26.812317099639188,-26.624338561170582,-26.43636002270199,-26.2483814842334,-26.10559803884685,-26.053204779624384,-26.000811520401918,-25.948418261179448,-25.89602500195698,-25.84363174273451,-25.791238483512043,-25.738845224289573,-25.686451965067107,-25.634058705844637,-25.58166544662216,-25.529272187399695,-25.47687892817723,-25.424485668954755,-25.37209240973229,-25.31969915050982,-25.26730589128735,-25.214912632064888,-25.162519372842418,-25.11012611361995,-25.057732854397475,-25.00533959517501,-24.95294633595254,-24.90055307673007,-24.8481598175076,-24.795766558285134,-24.74337329906266,-24.6909800398402,-24.63858678061773,-24.58619352139526,-24.533800262172786,-24.481407002950323,-24.429013743727854,-24.37662048450538,-24.324227225282915,-24.271833966060445,-24.219440706837975,-24.16704744761551,-24.11465418839304,-24.06226092917057,-24.0098676699481,-23.957474410725638,-23.90508115150316,-23.85268789228069,-23.800294633058225,-23.74790137383576,-23.69550811461329,-23.64311485539082,-23.59072159616835,-23.53832833694588,-23.48593507772341,-23.434123988668453,-23.38296354832761,-23.331803107986772,-23.280642667645942,-23.229482227305102,-23.178321786964258,-23.127161346623424,-23.076000906282587,-23.024840465941747,-22.97368002560091,-22.922519585260076,-22.87135914491924,-22.820198704578402,-22.769038264237565,-22.717877823896725,-22.666717383555884,-22.615556943215054,-22.564396502874214,-22.513236062533373,-22.462075622192536,-22.410915181851706,-22.359754741510862,-22.30859430117003,-22.257433860829188,-22.20627342048835,-22.155112980147514,-22.10395253980668,-22.05279209946584,-22.001631659125003,-21.950471218784163,-21.89931077844333,-21.848150338102485,-21.772558785834526,-21.574811673930917,-21.377064562027297,-21.179317450123687,-20.98157033822011,-20.783823226316496,-20.58607611441288,-20.3883290025093,-20.19058189060569,-19.992834778702075,-19.795087666798498,-19.59734055489488,-19.426566661373865,-19.258880451489553,-19.091194241605276,-18.923508031720964,-18.755821821836655,-18.58813561195237,-18.420449402068062,-18.25276319218375,-18.08507698229947,-17.91739077241516,-17.749704562530844,-17.582018352646568,-17.414332142762255,-17.246645932877946,-17.07895972299363,-16.911273513109354,-16.74358730322504,-16.575901093340732,-16.408214883456452,-16.24052867357214,-16.07284246368783,-15.90515625380355,-15.737470043919238,-15.56978383403493,-15.402097624150615,-15.234411414266336,-15.066725204382024,-14.899038994497715,-14.731352784613435,-14.563666574729123,-14.395980364844814,-14.228294154960533,-14.060607945076221,-13.892921735191912,-13.725235525307632,-13.557549315423321,-13.389863105539009,-13.222176895654698,-13.054490685770418,-12.886804475886105,-12.719118266001797,-12.551432056117516,-12.383745846233204,-12.216059636348895,-12.048373426464615,-11.880687216580302,-11.713001006695992,-11.545314796811681,-11.3776285869274,-11.20994237704309,-11.04225616715878,-10.874569957274499,-10.706883747390187,-10.539197537505878,-10.371511327621597,-10.203825117737287,-10.036138907852976,-9.868452697968696,-9.700766488084383,-9.533080278200073,-9.370519280068578,-9.221858958939029,-9.073198637809451,-8.924538316679874,-8.775877995550324,-8.627217674420748,-8.478557353291169,-8.329897032161622,-8.181236711032044,-8.032576389902466,-7.883916068772889,-7.73525574764334],[-33.34329451656434,-33.38243819622973,-33.42158187589512,-33.46072555556051,-33.49986923289446,-33.537311401518686,-33.57475357014291,-33.61219573876714,-33.64963790739136,-33.68708007601558,-33.72452224463981,-33.76196441326403,-33.79940658188825,-33.83684875051248,-33.8742909191367,-33.91173308776092,-33.94917525638515,-33.98661742500937,-34.024059593633595,-34.06150176225782,-34.098943930882044,-34.13638609950627,-34.17382826813049,-34.21127043675472,-34.24871260537894,-34.28615477400316,-34.32359694262738,-34.36103911125161,-34.39848127987583,-34.435923448500056,-34.47336561712428,-34.5108077857485,-34.54824995437273,-34.58569212299695,-34.62313429162117,-34.660576460245395,-34.69801862886962,-34.73546079749384,-34.77290296611807,-34.81034513474229,-34.847787303366516,-34.88522947199074,-34.922671640614965,-34.96011380923919,-34.997555977863406,-35.03499814648763,-35.072440315111855,-35.10988248373608,-35.147324652360304,-35.18476682098453,-35.222208989608745,-35.25965115823298,-35.2970933268572,-35.33453549548142,-35.37197766410564,-35.40941983272987,-35.44686200135409,-35.484304169978316,-35.52174633860254,-35.559188507226764,-35.59663067585099,-35.63407284447521,-35.67151501309944,-35.708957181723655,-35.746399350347886,-35.7838415189721,-35.82128368759633,-35.85872585622055,-35.896168024844776,-35.933610193469,-35.971052362093225,-36.00849453071745,-36.04593669934167,-36.0833788679659,-36.12082103659012,-36.15826320521435,-36.19570537383857,-36.233147542462795,-36.27058971108702,-36.308031879711244,-36.34547404833547,-36.38291621695969,-36.4203583855839,-36.457800554208134,-36.49342206470383,-36.52867944357381,-36.56393682244379,-36.59919420131378,-36.63445158018376,-36.66970895905374,-36.70496633792373,-36.740223716793714,-36.7754810956637,-36.810738474533686,-36.845995853403664,-36.88125323227366,-36.916510611143636,-36.95176799001362,-36.98702536888361,-37.022282747753586,-37.05754012662358,-37.092797505493564,-37.12805488436355,-37.16331226323353,-37.198569642103514,-37.2338270209735,-37.26908439984348,-37.304341778713464,-37.33959915758345,-37.374856536453436,-37.41011391532342,-37.44537129419341,-37.48062867306339,-37.51588605193337,-37.55114343080336,-37.58640080967334,-37.62165818854332,-37.65691556741331,-37.69217294628329,-37.72743032515328,-37.762687704023264,-37.79794508289325,-37.833202461763236,-37.86845984063322,-37.90371721950321,-37.93897459837318,-37.97423197724317,-38.00948935611315,-38.044746734983136,-38.08000411385312,-38.11526149272311,-38.15051887159309,-38.18577625046308,-38.221033629333064,-38.25629100820304,-38.29154838707303,-38.326805765943014,-38.362063144813,-38.39732052368298,-38.432577902552964,-38.46783528142295,-38.503092660292936,-38.53835003916292,-38.57360741803291,-38.60886479690289,-38.64412217577287,-38.67937955464286,-38.71463693351284,-38.74989431238282,-38.785151691252814,-38.82040907012279,-38.85566644899278,-38.890923827862764,-38.92618120673274,-38.961438585602735,-38.99669596447272,-39.0319533433427,-39.067210722212685,-39.10246810108267,-39.13772547995265,-39.172982858822635,-39.20824023769263,-39.24349761656261,-39.27954654136138,-39.31599124156486,-39.352435941768356,-39.388880641971845,-39.410845356972104,-39.42557007937073,-39.440294801769355,-39.455019524167994,-39.46974424656663,-39.48446896896525,-39.499193691363885,-39.51391841376252,-39.52864313616115,-39.54926955536013,-39.57051718714032,-39.59176481892051,-39.61301245070071,-39.63426008248091,-39.655507714261105,-39.6767553460413,-39.698002977821496,-39.719250609601694,-39.740498241381886,-39.761745873162084,-39.782993504942276,-39.80424113672248,-39.825488768502666,-39.846736400282865,-39.86798403206306,-39.889231663843255,-39.91047929562346,-39.931726927403645,-39.95297455918384,-39.97422219096404,-39.995469822744234,-40.01671745452444,-40.037965086304624,-40.05921271808483,-40.08046034986502,-40.10170798164521,-40.12295561342542,-40.14420324520561,-40.16545087698581,-40.186698508766,-40.2079461405462,-40.2291937723264,-40.25044140410658,-40.27168903588679,-40.292936667666986,-40.31418429944718,-40.33543193122737,-40.356679563007575,-40.377927194787766,-40.399174826567965,-40.420422458348156,-40.44167009012835,-40.462917721908546,-40.484165353688745,-40.50541298546894,-40.52666061724914,-40.547908249029334,-40.56915588080953,-40.590403512589724,-40.61165114436992,-40.63289877615012,-40.65414640793031,-40.67539403971051,-40.6966416714907,-40.7178893032709,-40.7391369350511,-40.76038456683129,-40.78163219861149,-40.80287983039169,-40.82412746217187,-40.84537509395208,-40.86662272573227,-40.88787035751247,-40.90911798929267,-40.93036562107285,-40.95161325285305,-40.97286088463325,-40.99410851641345,-41.015356148193646,-41.03660377997384,-41.05785141175404,-41.07909904353423,-41.10034667531443,-41.021856283891616,-40.843627869265795,-40.665399454639996,-40.48717104001418,-40.30894262538837,-40.13071421076256,-39.952485796136756,-39.774257381510935,-39.596028966885115,-39.41780055225933,-39.239572137633516,-39.06134372300769,-38.88311530838188,-38.70488689375608,-38.52665847913026,-38.348430064504456,-38.170201649878656,-37.99197323525283,-37.81374482062703,-37.63551640600123,-37.4572879913754,-37.27905957674958,-37.1008311621238,-36.922602747497976,-36.744374332872155,-36.566145918246356,-36.38791750362054,-36.20968908899473,-36.03146067436893,-35.853232259743116,-35.6750038451173,-35.49677543049148,-35.31854701586569,-35.14031860123987,-34.96209018661405,-34.78386177198825,-34.60563335736244,-34.42740494273663,-34.24917652811082,-34.07094811348502,-33.892719698859196,-33.71449128423339,-33.53626286960759,-33.35803445498176,-33.17980604035594,-33.00157762573016,-32.82334921110434,-32.645120796478516,-32.46689238185271,-32.28866396722691,-32.11043555260109,-31.93220713797529,-31.753978723349483,-31.575750308723656,-31.397521894097842,-31.219293479472054,-31.041065064846237,-30.862836650220412,-30.68460823559461,-30.506379820968803,-30.32815140634299,-30.14992299171718,-29.971694577091377,-29.793466162465556,-29.615237747839753,-29.437009333213954,-29.25878091858813,-29.08055250396231,-28.902324089336517,-28.724095674710703,-28.545867260084883,-28.367638845459076,-28.18941043083327,-28.01118201620745,-27.83295360158165,-27.654725186955844,-27.477605688045447,-27.311574961879078,-27.145544235712716,-26.979513509546337,-26.813482783379953,-26.64745205721359,-26.48142133104723,-26.354249246000187,-26.30479444319179,-26.255339640383397,-26.205884837574995,-26.1564300347666,-26.106975231958206,-26.057520429149807,-26.008065626341406,-25.958610823533014,-25.909156020724613,-25.859701217916214,-25.80902811026367,-25.757867669922835,-25.706707229581994,-25.65554678924116,-25.604386348900324,-25.553225908559487,-25.502065468218646,-25.450905027877813,-25.399744587536972,-25.34858414719613,-25.297423706855295,-25.24626326651446,-25.195102826173617,-25.143942385832787,-25.09278194549195,-25.041621505151106,-24.990461064810273,-24.939300624469436,-24.888140184128595,-24.836979743787754,-24.78581930344693,-24.734658863106088,-24.683498422765247,-24.632337982424414,-24.581177542083577,-24.530017101742736,-24.478856661401895,-24.427696221061066,-24.37653578072022,-24.325375340379388,-24.274214900038555,-24.223054459697714,-24.17189401935687,-24.120733579016033,-24.0695731386752,-24.018412698334362,-23.967252257993522,-23.916091817652692,-23.864931377311848,-23.81377093697101,-23.76261049663018,-23.711450056289337,-23.6602896159485,-23.609129175607666,-23.557968735266826,-23.506808294925985,-23.45564785458515,-23.404487414244315,-23.353326973903474,-23.30216653356264,-23.251006093221804,-23.199845652880967,-23.14868521254013,-23.097524772199293,-23.046364331858456,-22.995203891517615,-22.944043451176782,-22.89288301083594,-22.8417225704951,-22.790562130154264,-22.73940168981343,-22.68824124947259,-22.637080809131753,-22.58592036879092,-22.53475992845008,-22.483599488109235,-22.43243904776841,-22.381278607427568,-22.330118167086727,-22.27895772674589,-22.227797286405057,-22.176636846064216,-22.101045293796254,-21.903298181892644,-21.705551069989028,-21.507803958085415,-21.310056846181833,-21.11230973427822,-20.914562622374607,-20.71681551047103,-20.519068398567416,-20.321321286663803,-20.123574174760225,-19.92582706285661,-19.728079950952996,-19.530332839049382,-19.332585727145805,-19.134838615242188,-18.937091503338575,-18.739344391434997,-18.541597279531384,-18.34385016762777,-18.146103055724193,-17.948355943820577,-17.750608831916963,-17.552861720013386,-17.355114608109773,-17.157367496206156,-16.959620384302543,-16.761873272398965,-16.56412616049535,-16.366379048591735,-16.168631936688158,-15.970884824784546,-15.773137712880931,-15.575390600977354,-15.402694231816877,-15.235008021932565,-15.067321812048256,-14.899635602163976,-14.731949392279663,-14.564263182395354,-14.396576972511074,-14.228890762626762,-14.061204552742451,-13.89351834285817,-13.72583213297386,-13.55814592308955,-13.390459713205269,-13.222773503320958,-13.05508729343665,-12.887401083552335,-12.726056842244285,-12.577396521114709,-12.428736199985131,-12.28007587885558,-12.131415557726005,-11.982755236596427,-11.834094915466876,-11.6854345943373,-11.536774273207724,-11.388113952078147,-11.239453630948596,-11.090793309819018,-10.942132988689442,-10.793472667559893,-10.644812346430314,-10.496152025300738,-10.347491704171187,-10.198831383041611,-10.050171061912033,-9.901510740782484,-9.752850419652907,-9.604190098523329,-9.455529777393753,-9.306869456264202,-9.158209135134626,-9.009548814005049,-8.860888492875498,-8.71222817174592,-8.563567850616344,-8.414907529486795,-8.266247208357216,-8.117586887227642,-7.968926566098062,-7.820266244968511],[-32.96052787196429,-32.99612790108227,-33.03172793020025,-33.06732795931823,-33.10292798843621,-33.138528017554194,-33.174128046672166,-33.20972807579015,-33.24532810490813,-33.28092813402611,-33.31652816314409,-33.35212819226207,-33.38772822138005,-33.42424931841422,-33.461691487038436,-33.49913365566267,-33.53657582428689,-33.57401799291111,-33.611460161535334,-33.64890233015956,-33.68634449878378,-33.72378666740801,-33.76122883603223,-33.798671004656455,-33.83611317328068,-33.873555341904904,-33.91099751052913,-33.94843967915335,-33.98588184777758,-34.02332401640179,-34.060766185026026,-34.09820835365025,-34.13565052227446,-34.1730926908987,-34.21053485952291,-34.24797702814714,-34.285419196771365,-34.32286136539558,-34.36030353401981,-34.39774570264403,-34.435187871268255,-34.47263003989248,-34.5100722085167,-34.54751437714093,-34.58495654576515,-34.62239871438938,-34.6598408830136,-34.697283051637825,-34.73472522026205,-34.77216738888627,-34.8096095575105,-34.847051726134715,-34.88449389475895,-34.921936063383164,-34.95937823200738,-34.99682040063161,-35.03426256925584,-35.07170473788006,-35.10914690650428,-35.1465890751285,-35.18403124375273,-35.22147341237695,-35.258915581001176,-35.2963577496254,-35.333799918249625,-35.37124208687385,-35.40868425549807,-35.4461264241223,-35.48356859274652,-35.521010761370746,-35.558452929994964,-35.59589509861919,-35.63333726724341,-35.67077943586764,-35.70822160449187,-35.74566377311609,-35.78310594174031,-35.820548110364534,-35.85799027898876,-35.895432447612976,-35.93287461623721,-35.97031678486143,-36.007758953485656,-36.04520112210987,-36.08082263260557,-36.11608001147555,-36.15133739034554,-36.18659476921552,-36.2218521480855,-36.25710952695549,-36.29236690582547,-36.32762428469546,-36.36288166356544,-36.398139042435425,-36.4333964213054,-36.46865380017539,-36.503911179045375,-36.53916855791536,-36.574425936785346,-36.60968331565533,-36.64494069452532,-36.6801980733953,-36.71545545226529,-36.750712831135274,-36.78597021000525,-36.82122758887524,-36.85648496774522,-36.8917423466152,-36.92699972548519,-36.962257104355174,-36.99751448322516,-37.032771862095146,-37.068029240965124,-37.10328661983512,-37.1385439987051,-37.17380137757508,-37.20905875644507,-37.244316135315046,-37.27957351418504,-37.31483089305502,-37.350088271925,-37.38534565079499,-37.42060302966497,-37.45586040853496,-37.49111778740494,-37.526375166274924,-37.56163254514491,-37.59688992401489,-37.632147302884874,-37.66740468175486,-37.702662060624846,-37.73791943949483,-37.77317681836482,-37.8084341972348,-37.84369157610478,-37.87894895497477,-37.91420633384475,-37.94946371271474,-37.98472109158472,-38.01997847045471,-38.05523584932469,-38.090493228194674,-38.12575060706467,-38.161007985934646,-38.19626536480463,-38.23152274367462,-38.266780122544596,-38.30203750141458,-38.33729488028457,-38.37255225915455,-38.40780963802453,-38.44306701689452,-38.4783243957645,-38.51358177463448,-38.54860660062464,-38.5824686705638,-38.61633074050295,-38.650192810442114,-38.68405488038127,-38.71791695032043,-38.75177902025959,-38.785641090198745,-38.819503160137906,-38.85336523007706,-38.88722730001623,-38.92108936995538,-38.95495143989454,-38.98442823135223,-39.0117123835692,-39.03899653578616,-39.066280688003125,-39.09356484022008,-39.12084899243706,-39.14813314465402,-39.17541729687098,-39.202701449087954,-39.22998560130491,-39.257269753521875,-39.284553905738846,-39.3118380579558,-39.339122210172775,-39.36640636238974,-39.393690514606696,-39.42097466682366,-39.44825881904063,-39.47554297125759,-39.50282712347455,-39.53011127569152,-39.55739542790848,-39.58467958012545,-39.61196373234242,-39.63924788455938,-39.66653203677634,-39.6938161889933,-39.72110034121027,-39.74838449342724,-39.775668645644195,-39.80295279786117,-39.83023695007813,-39.85316141677404,-39.874409048554234,-39.89565668033443,-39.916904312114625,-39.93815194389482,-39.95939957567502,-39.98064720745522,-40.00189483923541,-40.0231424710156,-40.0443901027958,-40.065637734576,-40.0868853663562,-40.1081329981364,-40.12938062991658,-40.15062826169678,-40.17187589347698,-40.19312352525718,-40.21437115703738,-40.23561878881756,-40.25686642059776,-40.27811405237796,-40.29936168415816,-40.320609315938356,-40.34185694771855,-40.36310457949874,-40.38435221127894,-40.405599843059136,-40.426847474839334,-40.44809510661953,-40.46934273839972,-40.49059037017992,-40.511838001960115,-40.53308563374031,-40.55433326552051,-40.57558089730071,-40.596828529080895,-40.618076160861094,-40.63932379264129,-40.66057142442149,-40.68181905620169,-40.70306668798189,-40.72431431976207,-40.74556195154227,-40.76680958332247,-40.78805721510267,-40.80930484688286,-40.83055247866305,-40.85180011044325,-40.87304774222345,-40.89429537400365,-40.91554300578384,-40.83705261436103,-40.65882419973521,-40.4805957851094,-40.302367370483594,-40.124138955857774,-39.945910541231974,-39.767682126606175,-39.58945371198035,-39.41122529735453,-39.23299688272874,-39.05476846810292,-38.8765400534771,-38.698311638851294,-38.52008322422549,-38.341854809599674,-38.163626394973875,-37.98539798034807,-37.80716956572225,-37.62894115109644,-37.450712736470635,-37.27248432184482,-37.094255907218994,-36.91602749259321,-36.73779907796739,-36.559570663341574,-36.38134224871576,-36.20311383408996,-36.02488541946414,-35.846657004838335,-35.668428590212535,-35.49020017558671,-35.311971760960894,-35.13374334633511,-34.95551493170929,-34.77728651708346,-34.59905810245766,-34.420829687831855,-34.242601273206034,-34.064372858580235,-33.88614444395443,-33.7079160293286,-33.529687614702794,-33.35866696423034,-33.19263623806396,-33.02660551189758,-32.86057478573123,-32.694544059564855,-32.52851333339848,-32.36248260723211,-32.19645188106575,-32.030421154899365,-31.864390428733003,-31.69835970256664,-31.532328976400258,-31.366298250233882,-31.200267524067534,-31.03423679790115,-30.86820607173477,-30.70217534556841,-30.536144619402044,-30.37011389323567,-30.204083167069303,-30.038052440902938,-29.87202171473656,-29.705990988570196,-29.53996026240383,-29.373929536237455,-29.20789881007107,-29.041868083904724,-28.875837357738348,-28.709806631571965,-28.543775905405603,-28.377745179239238,-28.211714453072858,-28.045683726906493,-27.87965300074013,-27.71362227457375,-27.547591548407386,-27.381560822241024,-27.215530096074644,-27.04949936990826,-26.883468643741903,-26.717437917575538,-26.590265832528495,-26.540811029720103,-26.491356226911705,-26.441901424103307,-26.39244662129491,-26.342991818486517,-26.293537015678112,-26.244082212869714,-26.194627410061326,-26.145172607252924,-26.095717804444522,-26.046263001636127,-25.996808198827736,-25.94735339601933,-25.897898593210936,-25.84844379040254,-25.798988987594143,-25.749534184785748,-25.700079381977353,-25.650624579168948,-25.60116977636055,-25.55171497355215,-25.50226017074376,-25.452805367935362,-25.403350565126964,-25.353895762318565,-25.304440959510167,-25.254986156701772,-25.205531353893377,-25.15607655108498,-25.10662174827658,-25.057166945468186,-25.007712142659784,-24.958257339851386,-24.90880253704299,-24.859347734234596,-24.809892931426194,-24.7604381286178,-24.710983325809405,-24.661528523001003,-24.612073720192605,-24.56261891738421,-24.513164114575815,-24.463709311767413,-24.41425450895902,-24.364799706150624,-24.31534490334222,-24.265890100533824,-24.216435297725432,-24.16698049491703,-24.117525692108636,-24.06807088930024,-24.018616086491836,-23.96916128368344,-23.919706480875046,-23.87025167806665,-23.820796875258253,-23.771342072449855,-23.721887269641456,-23.672432466833058,-23.622977664024663,-23.57352286121627,-23.524068058407867,-23.474613255599472,-23.425158452791077,-23.374850839820184,-23.32369039947934,-23.27252995913851,-23.221369518797665,-23.17020907845683,-23.11904863811599,-23.067888197775158,-23.016727757434317,-22.96556731709348,-22.914406876752647,-22.863246436411806,-22.812085996070966,-22.760925555730132,-22.709765115389292,-22.65860467504845,-22.607444234707618,-22.55628379436678,-22.505123354025944,-22.429531801757985,-22.23178468985437,-22.034037577950752,-21.836290466047142,-21.638543354143565,-21.440796242239948,-21.24304913033633,-21.045302018432757,-20.84755490652914,-20.64980779462553,-20.452060682721953,-20.254313570818336,-20.056566458914723,-19.85881934701111,-19.661072235107532,-19.47599546499986,-19.299968838497303,-19.12394221199478,-18.94791558549223,-18.77188895898967,-18.595862332487147,-18.419835705984596,-18.243809079482038,-18.067782452979518,-17.891755826476963,-17.715729199974408,-17.539702573471853,-17.36367594696933,-17.18764932046678,-17.011622693964224,-16.8355960674617,-16.659569440959146,-16.48354281445659,-16.307516187954068,-16.131489561451513,-15.955462934948962,-15.779436308446403,-15.603409681943884,-15.427383055441329,-15.251356428938774,-15.07532980243625,-14.899303175933696,-14.72327654943114,-14.547249922928621,-14.371223296426066,-14.19519666992351,-14.019170043420987,-13.843143416918434,-13.667116790415879,-13.491090163913324,-13.315063537410804,-13.13903691090825,-12.963010284405694,-12.786983657903171,-12.610957031400616,-12.434930404898061,-12.258903778395538,-12.082877151892983,-11.906850525390432,-11.730823898887877,-11.554797272385354,-11.378770645882799,-11.202744019380244,-11.026717392877721,-10.850690766375168,-10.674664139872613,-10.498637513370092,-10.322610886867537,-10.146584260364982,-9.986521238107658,-9.83786091697808,-9.689200595848504,-9.540540274718925,-9.391879953589376,-9.243219632459798,-9.094559311330222,-8.945898990200671,-8.797238669071096,-8.648578347941518,-8.499918026811967,-8.35125770568239,-8.202597384552814,-8.053937063423234,-7.905276742293686],[-32.57460215225112,-32.6102021813691,-32.645802210487076,-32.681402239605056,-32.717002268723036,-32.75260229784102,-32.788202326958995,-32.823802356076975,-32.859402385194954,-32.89500241431294,-32.930602443430914,-32.96620247254889,-33.00180250166687,-33.03740253078486,-33.07300255990283,-33.10860258902082,-33.14420261813879,-33.17980264725678,-33.21540267637475,-33.25100270549274,-33.28660273461071,-33.3222027637287,-33.35780279284667,-33.393402821964656,-33.42900285108263,-33.464602880200616,-33.500202909318595,-33.53580293843657,-33.571402967554555,-33.607002996672534,-33.64444516446419,-33.68188733308841,-33.71932950171263,-33.75677167033686,-33.794213838961085,-33.83165600758531,-33.86909817620953,-33.90654034483375,-33.94398251345798,-33.9814246820822,-34.018866850706424,-34.056309019330655,-34.09375118795487,-34.1311933565791,-34.16863552520332,-34.20607769382754,-34.24351986245177,-34.28096203107599,-34.31840419970021,-34.355846368324436,-34.39328853694866,-34.430730705572884,-34.46817287419711,-34.505615042821326,-34.54305721144556,-34.58049938006978,-34.617941548694006,-34.65538371731822,-34.69282588594245,-34.73026805456667,-34.76771022319089,-34.80515239181513,-34.842594560439345,-34.88003672906356,-34.91747889768779,-34.95492106631201,-34.992363234936235,-35.02980540356047,-35.067247572184684,-35.10468974080891,-35.14213190943313,-35.17957407805736,-35.21701624668158,-35.254458415305805,-35.29190058393003,-35.329342752554254,-35.36678492117847,-35.4042270898027,-35.44166925842693,-35.47911142705115,-35.51655359567537,-35.55399576429959,-35.59143793292382,-35.62888010154804,-35.66450161204373,-35.699758990913715,-35.7350163697837,-35.770273748653686,-35.805531127523665,-35.84078850639365,-35.876045885263636,-35.91130326413362,-35.94656064300361,-35.98181802187359,-36.01707540074358,-36.052332779613565,-36.08759015848355,-36.12284753735352,-36.15810491622352,-36.1933622950935,-36.22861967396348,-36.26387705283347,-36.29913443170345,-36.334391810573436,-36.36964918944342,-36.40490656831341,-36.440163947183386,-36.47542132605337,-36.51067870492336,-36.54593608379334,-36.58119346266333,-36.61645084153331,-36.65170822040329,-36.68696559927328,-36.722222978143265,-36.75748035701325,-36.79273773588323,-36.827995114753215,-36.86325249362321,-36.898509872493186,-36.93376725136317,-36.96902463023315,-37.004282009103136,-37.03953938797313,-37.07479676684311,-37.110054145713086,-37.14531152458308,-37.180568903453064,-37.21582628232304,-37.25108366119303,-37.286341040063014,-37.32159841893299,-37.356855797802986,-37.39211317667297,-37.42737055554295,-37.462627934412936,-37.49788531328292,-37.5331426921529,-37.56746986443839,-37.60133193437755,-37.6351940043167,-37.66905607425586,-37.702918144195024,-37.73678021413418,-37.77064228407334,-37.8045043540125,-37.838366423951655,-37.872228493890816,-37.90609056382997,-37.93995263376913,-37.97381470370829,-38.00767677364745,-38.04153884358661,-38.07540091352576,-38.10926298346492,-38.143125053404084,-38.17698712334324,-38.2108491932824,-38.24471126322156,-38.278573333160715,-38.31243540309987,-38.34629747303904,-38.38015954297819,-38.41402161291735,-38.447883682856514,-38.48174575279567,-38.51560782273482,-38.54508461419252,-38.57236876640948,-38.59965291862645,-38.62693707084341,-38.654221223060375,-38.68150537527735,-38.708789527494304,-38.73607367971127,-38.76335783192823,-38.790641984145196,-38.81792613636216,-38.84521028857913,-38.87249444079609,-38.89977859301306,-38.92706274523002,-38.95434689744698,-38.981631049663946,-39.00891520188092,-39.03619935409788,-39.06348350631484,-39.0907676585318,-39.11805181074877,-39.14533596296573,-39.1726201151827,-39.19990426739967,-39.227188419616624,-39.254472571833595,-39.28175672405055,-39.30904087626752,-39.33632502848448,-39.363609180701445,-39.39089333291841,-39.418177485135374,-39.44546163735234,-39.4727457895693,-39.500029941786266,-39.52731409400323,-39.554598246220195,-39.58188239843716,-39.60916655065412,-39.636450702871095,-39.66373485508806,-39.69101900730502,-39.71830315952199,-39.745587311738944,-39.772871463955916,-39.80015561617287,-39.82743976838984,-39.8547239206068,-39.882008072823766,-39.90929222504073,-39.9365763772577,-39.963860529474665,-39.99114468169162,-40.018428833908594,-40.04571298612555,-40.072997138342515,-40.10028129055948,-40.12756544277645,-40.154849594993415,-40.18213374721038,-40.20941789942734,-40.23670205164431,-40.263986203861265,-40.291270356078236,-40.3185545082952,-40.34583866051216,-40.37312281272912,-40.40040696494609,-40.42769111716306,-40.45497526938002,-40.482259421596986,-40.50954357381396,-40.536827726030914,-40.56075828201168,-40.58200591379188,-40.60325354557208,-40.62450117735228,-40.64574880913247,-40.66699644091266,-40.68824407269286,-40.70949170447306,-40.73073933625326,-40.65224894483044,-40.47402053020462,-40.29579211557882,-40.11756370095301,-39.93933528632719,-39.76110687170139,-39.58287845707558,-39.40575896658158,-39.239728240415204,-39.073697514248856,-38.90766678808247,-38.7416360619161,-38.575605335749735,-38.409574609583366,-38.24354388341699,-38.07751315725062,-37.91148243108426,-37.745451704917876,-37.579420978751514,-37.41339025258516,-37.24735952641878,-37.0813288002524,-36.91529807408605,-36.74926734791967,-36.583236621753294,-36.41720589558693,-36.25117516942056,-36.08514444325419,-35.91911371708781,-35.75308299092145,-35.58705226475507,-35.42102153858869,-35.25499081242234,-35.088960086255966,-34.92292936008958,-34.75689863392322,-34.59086790775686,-34.424837181590476,-34.25880645542411,-34.09277572925775,-33.92674500309137,-33.76071427692501,-33.594683550758646,-33.42865282459226,-33.26262209842589,-33.09659137225954,-32.930560646093156,-32.76452991992678,-32.59849919376042,-32.43246846759405,-32.26643774142767,-32.10040701526131,-31.934376289094946,-31.768345562928566,-31.602314836762183,-31.43628411059584,-31.27025338442946,-31.10422265826308,-30.938191932096714,-30.772161205930352,-30.60613047976397,-30.440099753597607,-30.274069027431246,-30.10803830126487,-29.9420075750985,-29.77597684893214,-29.609946122765763,-29.443915396599383,-29.277884670433032,-29.111853944266656,-28.945823218100276,-28.77979249193391,-28.613761765767546,-28.44773103960117,-28.281700313434804,-28.11566958726844,-27.94963886110206,-27.783608134935697,-27.61757740876933,-27.451546682602952,-27.285515956436573,-27.119485230270207,-26.953454504103842,-26.826282419056803,-26.776827616248404,-26.72737281344001,-26.677918010631608,-26.628463207823213,-26.579008405014818,-26.529553602206416,-26.480098799398018,-26.43064399658963,-26.381189193781232,-26.331734390972827,-26.28227958816443,-26.232824785356037,-26.183369982547635,-26.13391517973924,-26.084460376930846,-26.035005574122447,-25.98555077131405,-25.936095968505654,-25.886641165697256,-25.837186362888858,-25.78773156008046,-25.73827675727206,-25.688821954463666,-25.63936715165527,-25.589912348846873,-25.540457546038475,-25.491002743230077,-25.441547940421685,-25.39209313761328,-25.34263833480488,-25.29318353199649,-25.24372872918809,-25.194273926379694,-25.144819123571292,-25.095364320762897,-25.0459095179545,-24.996454715146108,-24.94699991233771,-24.897545109529307,-24.848090306720913,-24.79863550391252,-24.749180701104116,-24.699725898295718,-24.65027109548732,-24.601168927403755,-24.553300954852897,-24.505432982302043,-24.45756500975119,-24.409697037200335,-24.36182906464948,-24.31396109209863,-24.26609311954777,-24.21822514699691,-24.170357174446064,-24.12248920189521,-24.074621229344352,-24.026753256793494,-23.978885284242644,-23.93101731169179,-23.883149339140935,-23.835281366590085,-23.787413394039223,-23.739545421488373,-23.69167744893752,-23.64380947638666,-23.595941503835807,-23.548073531284956,-23.500205558734095,-23.45233758618324,-23.40446961363239,-23.356601641081536,-23.308733668530678,-23.260865695979824,-23.21299772342897,-23.165129750878116,-23.11726177832726,-23.06939380577641,-23.021525833225553,-22.973657860674695,-22.925789888123838,-22.87792191557299,-22.830053943022133,-22.756168280707335,-22.552194169572807,-22.34822005843828,-22.144245947303748,-21.940271836169256,-21.73629772503473,-21.5323236139002,-21.32834950276571,-21.12437539163118,-20.920401280496648,-20.71642716936216,-20.51245305822763,-20.308478947093104,-20.104504835958572,-19.90053072482408,-19.696556613689552,-19.516383282257404,-19.340356655754878,-19.164330029252326,-18.98830340274977,-18.81227677624725,-18.636250149744697,-18.460223523242142,-18.284196896739616,-18.10817027023706,-17.932143643734506,-17.756117017231954,-17.58009039072943,-17.404063764226876,-17.22803713772432,-17.052010511221802,-16.875983884719247,-16.699957258216692,-16.52393063171417,-16.347904005211614,-16.17187737870906,-15.995850752206504,-15.819824125703985,-15.643797499201428,-15.467770872698875,-15.291744246196352,-15.115717619693797,-14.939690993191242,-14.76366436668872,-14.587637740186166,-14.41161111368361,-14.23558448718109,-14.059557860678535,-13.88353123417598,-13.707504607673425,-13.531477981170902,-13.355451354668348,-13.179424728165795,-13.00339810166327,-12.827371475160716,-12.651344848658162,-12.47531822215564,-12.299291595653084,-12.123264969150531,-11.947238342647976,-11.771211716145453,-11.5951850896429,-11.419158463140345,-11.243131836637822,-11.067105210135267,-10.891078583632714,-10.715051957130191,-10.539025330627638,-10.368584022377503,-10.210286226095226,-10.05198842981292,-9.893690633530612,-9.735392837248309,-9.577095040966032,-9.418797244683725,-9.26049944840142,-9.102201652119142,-8.943903855836835,-8.78560605955453,-8.627308263272251,-8.469010466989946,-8.310712670707641,-8.152414874425334,-7.9941170781430575],[-32.18867643253793,-32.22427646165591,-32.25987649077389,-32.29547651989187,-32.33107654900985,-32.36667657812783,-32.40227660724581,-32.43787663636378,-32.47347666548177,-32.50907669459975,-32.54467672371773,-32.58027675283571,-32.61587678195369,-32.65147681107167,-32.68707684018965,-32.72267686930763,-32.758276898425606,-32.793876927543586,-32.829476956661566,-32.865076985779545,-32.900677014897525,-32.936277044015505,-32.971877073133484,-33.00747710225147,-33.043077131369444,-33.07867716048742,-33.1142771896054,-33.14987721872338,-33.18547724784136,-33.22107727695934,-33.25667730607733,-33.29227733519531,-33.32787736431328,-33.36347739343127,-33.39907742254925,-33.43467745166723,-33.47027748078521,-33.505877509903186,-33.541477539021166,-33.577077568139146,-33.612677597257125,-33.648277626375105,-33.683877655493085,-33.719477684611064,-33.755077713729044,-33.79067774284702,-33.827198841889924,-33.86464101051415,-33.90208317913837,-33.9395253477626,-33.97696751638682,-34.014409685011046,-34.05185185363526,-34.089294022259494,-34.12673619088371,-34.16417835950794,-34.20162052813216,-34.239062696756385,-34.27650486538061,-34.313947034004826,-34.35138920262906,-34.388831371253275,-34.4262735398775,-34.463715708501724,-34.50115787712595,-34.53860004575018,-34.5760422143744,-34.61348438299862,-34.650926551622845,-34.68836872024707,-34.725810888871294,-34.76325305749552,-34.80069522611974,-34.83813739474396,-34.87557956336819,-34.91302173199241,-34.95046390061663,-34.98790606924086,-35.02534823786509,-35.062790406489306,-35.10023257511353,-35.137674743737755,-35.17511691236198,-35.212559080986196,-35.24818059148189,-35.283437970351876,-35.318695349221855,-35.35395272809184,-35.389210106961826,-35.42446748583181,-35.4597248647018,-35.49498224357178,-35.53023962244177,-35.56549700131175,-35.60075438018174,-35.63601175905171,-35.671269137921705,-35.70652651679168,-35.741783895661676,-35.77704127453166,-35.81229865340164,-35.847556032271626,-35.88281341114161,-35.9180707900116,-35.953328168881576,-35.98858554775156,-36.02384292662155,-36.05910030549153,-36.09435768436152,-36.1296150632315,-36.16487244210148,-36.20012982097147,-36.235387199841455,-36.27064457871144,-36.305901957581426,-36.34115933645141,-36.37641671532139,-36.411674094191376,-36.44693147306136,-36.48218885193134,-36.51744623080133,-36.552471058312975,-36.58633312825213,-36.62019519819128,-36.65405726813045,-36.687919338069605,-36.72178140800876,-36.75564347794792,-36.789505547887074,-36.823367617826236,-36.8572296877654,-36.89109175770456,-36.92495382764372,-36.958815897582866,-36.99267796752203,-37.02654003746119,-37.06040210740035,-37.094264177339504,-37.128126247278665,-37.161988317217826,-37.19585038715698,-37.22971245709614,-37.263574527035296,-37.29743659697446,-37.33129866691362,-37.36516073685277,-37.39902280679193,-37.432884876731094,-37.46674694667025,-37.50060901660941,-37.534471086548564,-37.568333156487725,-37.602195226426886,-37.63605729636603,-37.669919366305194,-37.703781436244356,-37.73764350618352,-37.77150557612268,-37.80536764606183,-37.839229716000986,-37.87309178594015,-37.90695385587931,-37.94081592581847,-37.974677995757624,-38.008540065696785,-38.04240213563594,-38.0762642055751,-38.105740997032804,-38.133025149249754,-38.160309301466725,-38.18759345368369,-38.214877605900654,-38.24216175811762,-38.26944591033458,-38.296730062551546,-38.32401421476851,-38.351298366985475,-38.37858251920244,-38.40586667141941,-38.43315082363637,-38.46043497585333,-38.487719128070296,-38.51500328028726,-38.54228743250423,-38.56957158472119,-38.59685573693815,-38.62413988915512,-38.65142404137208,-38.678708193589046,-38.70599234580601,-38.73327649802298,-38.76056065023994,-38.7878448024569,-38.815128954673874,-38.84241310689083,-38.869697259107795,-38.89698141132476,-38.924265563541724,-38.95154971575869,-38.97883386797565,-39.006118020192616,-39.03340217240958,-39.06068632462656,-39.087970476843516,-39.11525462906047,-39.14253878127744,-39.1698229334944,-39.197107085711366,-39.22439123792833,-39.251675390145294,-39.278959542362266,-39.30624369457922,-39.33352784679619,-39.36081199901316,-39.388096151230116,-39.41538030344708,-39.44266445566405,-39.46994860788101,-39.49723276009797,-39.524516912314944,-39.55180106453191,-39.57908521674887,-39.60636936896584,-39.6336535211828,-39.660937673399765,-39.68822182561672,-39.71550597783369,-39.74279013005065,-39.770074282267615,-39.80045600362063,-39.83168250873343,-39.86290901384624,-39.89413551895905,-39.92536202407186,-39.956588529184664,-39.98781503429748,-40.01904153941028,-40.050268044523094,-40.0814945496359,-40.112721054748704,-40.143947559861516,-40.17517406497432,-40.20640057008713,-40.237627075199946,-40.26885358031275,-40.300080085425556,-40.33130659053837,-40.36253309565117,-40.39375960076398,-40.42498610587679,-40.36937301229361,-40.226920320014436,-40.08446762773528,-39.942014935456115,-39.79956224317695,-39.657109550897786,-39.51465685861863,-39.37220416633946,-39.229751474060286,-39.08729878178114,-38.94484608950198,-38.80239339722281,-38.659940704943644,-38.51748801266449,-38.37503532038532,-38.23258262810616,-38.090129935827,-37.94767724354784,-37.80276419087187,-37.636865320542995,-37.47096645021411,-37.30506757988522,-37.13916870955636,-36.97326983922747,-36.80737096889858,-36.6414720985697,-36.475573228240826,-36.30967435791194,-36.14377548758306,-35.97787661725419,-35.8119777469253,-35.64607887659641,-35.48018000626755,-35.31428113593866,-35.14838226560977,-34.982483395280894,-34.81658452495202,-34.65068565462313,-34.48478678429426,-34.31888791396538,-34.152989043636495,-33.98709017330762,-33.82119130297875,-33.65529243264986,-33.48939356232097,-33.32349469199211,-33.15759582166322,-32.99169695133433,-32.82579808100546,-32.659899210676585,-32.4940003403477,-32.32810147001882,-32.16220259968995,-31.99630372936106,-31.830404859032164,-31.66450598870331,-31.49860711837442,-31.33270824804553,-31.166809377716653,-31.000910507387783,-30.835011637058894,-30.669112766730017,-30.503213896401142,-30.337315026072254,-30.171416155743383,-30.005517285414506,-29.839618415085617,-29.67371954475673,-29.507820674427865,-29.34192180409898,-29.176022933770092,-29.010124063441218,-28.844225193112347,-28.678326322783455,-28.512427452454578,-28.346528582125703,-28.18062971179682,-28.01473084146794,-27.848831971139067,-27.682933100810178,-27.517034230481286,-27.351135360152416,-27.18523648982354,-27.059302356333575,-27.013297696521423,-26.967293036709275,-26.92128837689712,-26.875283717084965,-26.829279057272817,-26.783274397460662,-26.737269737648507,-26.69126507783636,-26.6452604180242,-26.59925575821205,-26.553251098399898,-26.507246438587746,-26.46020337080597,-26.41233539825512,-26.364467425704266,-26.316599453153415,-26.268731480602558,-26.220863508051707,-26.172995535500846,-26.12512756294999,-26.07725959039914,-26.029391617848283,-25.981523645297425,-25.933655672746575,-25.88578770019572,-25.837919727644866,-25.790051755094012,-25.742183782543158,-25.6943158099923,-25.646447837441443,-25.598579864890596,-25.550711892339738,-25.50284391978888,-25.454975947238026,-25.407107974687175,-25.359240002136318,-25.311372029585467,-25.263504057034613,-25.215636084483755,-25.1677681119329,-25.11990013938205,-25.072032166831193,-25.024164194280335,-24.976296221729484,-24.92842824917863,-24.880560276627776,-24.83269230407692,-24.784824331526067,-24.736956358975213,-24.68908838642436,-24.641220413873505,-24.593352441322647,-24.54548446877179,-24.497616496220942,-24.44974852367008,-24.401880551119227,-24.354012578568373,-24.30614460601752,-24.258276633466664,-24.21040866091581,-24.16254068836496,-24.114672715814102,-24.066804743263248,-24.018936770712394,-23.97106879816154,-23.92320082561068,-23.87533285305983,-23.827464880508973,-23.779596907958116,-23.73172893540726,-23.68386096285641,-23.635992990305553,-23.5881250177547,-23.540257045203845,-23.49238907265299,-23.444521100102133,-23.396653127551286,-23.348785155000428,-23.300917182449567,-23.25304920989872,-23.205181237347865,-23.157313264797008,-23.08342760248221,-22.879453491347682,-22.675479380213154,-22.471505269078627,-22.267531157944134,-22.063557046809606,-21.85958293567508,-21.655608824540586,-21.451634713406055,-21.247660602271527,-21.043686491137038,-20.839712380002503,-20.635738268867975,-20.431764157733447,-20.227790046598955,-20.023815935464427,-19.8198418243299,-19.615867713195406,-19.41189360206088,-19.207919490926347,-19.00394537979186,-18.799971268657327,-18.5959971575228,-18.392023046388303,-18.18804893525378,-17.98407482411925,-17.78010071298472,-17.576126601850227,-17.3721524907157,-17.16817837958117,-16.96420426844668,-16.76023015731215,-16.55625604617762,-16.35228193504313,-16.148307823908603,-15.944333712774071,-15.74035960163954,-15.536385490505051,-15.33241137937052,-15.148318639625982,-14.97229201312346,-14.796265386620904,-14.62023876011835,-14.444212133615828,-14.268185507113273,-14.100230523677315,-13.941932727395036,-13.78363493111273,-13.625337134830424,-13.467039338548117,-13.30874154226584,-13.150443745983534,-12.992145949701229,-12.83384815341895,-12.675550357136643,-12.51725256085434,-12.358954764572063,-12.200656968289756,-12.04235917200745,-11.884061375725144,-11.72576357944287,-11.56746578316056,-11.409167986878256,-11.250870190595979,-11.092572394313672,-10.934274598031367,-10.775976801749088,-10.617679005466783,-10.459381209184478,-10.301083412902202,-10.142785616619893,-9.984487820337588,-9.826190024055283,-9.667892227773006,-9.509594431490699,-9.351296635208392,-9.192998838926115,-9.03470104264381,-8.876403246361505,-8.718105450079227,-8.559807653796922,-8.401509857514615,-8.24321206123231,-8.084914264950031],[-31.802750712824746,-31.838350741942726,-31.873950771060706,-31.909550800178685,-31.945150829296665,-31.980750858414645,-32.016350887532624,-32.051950916650604,-32.087550945768584,-32.12315097488656,-32.15875100400454,-32.19435103312252,-32.2299510622405,-32.26555109135848,-32.30115112047646,-32.33675114959444,-32.37235117871242,-32.4079512078304,-32.44355123694838,-32.47915126606636,-32.51475129518434,-32.55035132430232,-32.5859513534203,-32.621551382538286,-32.65715141165626,-32.69275144077424,-32.72835146989222,-32.7639514990102,-32.79955152812818,-32.83515155724616,-32.870751586364136,-32.90635161548212,-32.941951644600096,-32.97755167371808,-33.01315170283606,-33.04875173195404,-33.084351761072014,-33.11995179019,-33.15555181930799,-33.19115184842596,-33.22675187754394,-33.26235190666192,-33.2979519357799,-33.33355196489788,-33.36915199401586,-33.40475202313384,-33.44035205225182,-33.4759520813698,-33.51155211048778,-33.54715213960576,-33.58275216872374,-33.618352197841716,-33.653952226959696,-33.689552256077675,-33.725152285195655,-33.760752314313635,-33.796352343431614,-33.8319523725496,-33.867552401667574,-33.90315243078555,-33.93875245990353,-33.97435248902152,-34.00995251931566,-34.047394687939885,-34.08483685656411,-34.122279025188334,-34.15972119381255,-34.19716336243678,-34.23460553106101,-34.272047699685224,-34.309489868309456,-34.34693203693367,-34.3843742055579,-34.42181637418212,-34.459258542806346,-34.49670071143057,-34.534142880054794,-34.57158504867901,-34.609027217303236,-34.64646938592746,-34.68391155455169,-34.72135372317591,-34.75879589180014,-34.79623806042436,-34.83185957092005,-34.86711694979003,-34.90237432866002,-34.93763170753,-34.97288908639999,-35.008146465269974,-35.04340384413995,-35.07866122300994,-35.113918601879924,-35.14917598074991,-35.184433359619895,-35.219690738489874,-35.254948117359866,-35.290205496229845,-35.32546287509983,-35.360720253969816,-35.3959776328398,-35.43123501170978,-35.46649239057977,-35.50174976944976,-35.53700714831974,-35.57133432212672,-35.60519639206587,-35.63905846200503,-35.67292053194419,-35.70678260188335,-35.74064467182251,-35.77450674176166,-35.808368811700824,-35.84223088163998,-35.87609295157914,-35.9099550215183,-35.943817091457454,-35.977679161396615,-36.01154123133577,-36.04540330127493,-36.07926537121409,-36.11312744115325,-36.14698951109241,-36.18085158103156,-36.21471365097072,-36.248575720909884,-36.282437790849045,-36.3162998607882,-36.35016193072735,-36.38402400066652,-36.417886070605675,-36.45174814054484,-36.48561021048399,-36.519472280423145,-36.55333435036231,-36.58719642030147,-36.62105849024063,-36.65492056017978,-36.68878263011894,-36.7226447000581,-36.75650676999726,-36.79036883993642,-36.82423090987558,-36.85809297981473,-36.89195504975389,-36.92581711969305,-36.95967918963221,-36.993541259571366,-37.02740332951053,-37.06126539944969,-37.09512746938884,-37.128989539328,-37.162851609267165,-37.19671367920632,-37.23057574914547,-37.264437819084634,-37.298299889023795,-37.332161958962956,-37.36602402890211,-37.399886098841264,-37.433748168780426,-37.46761023871959,-37.50147230865875,-37.5353343785979,-37.569196448537056,-37.603058518476224,-37.63692058841538,-37.666397379873075,-37.69368153209004,-37.720965684307004,-37.74824983652396,-37.77553398874093,-37.802818140957896,-37.83010229317486,-37.857386445391825,-37.88467059760879,-37.91195474982575,-37.93923890204272,-37.96652305425969,-37.993807206476646,-38.02109135869361,-38.048375510910574,-38.07565966312754,-38.1029438153445,-38.13022796756147,-38.15751211977843,-38.184796271995396,-38.21208042421236,-38.239364576429324,-38.26664872864629,-38.29393288086325,-38.32121703308022,-38.34850118529718,-38.375785337514145,-38.40306948973111,-38.430353641948074,-38.45763779416504,-38.484921946382,-38.512206098598966,-38.53949025081593,-38.566774403032895,-38.59405855524986,-38.62486266506771,-38.65608917018052,-38.68731567529333,-38.71854218040613,-38.74976868551893,-38.78099519063174,-38.812221695744554,-38.84344820085736,-38.87467470597018,-38.90590121108298,-38.93712771619579,-38.9683542213086,-38.9995807264214,-39.03080723153421,-39.062033736647024,-39.09326024175983,-39.124486746872634,-39.155713251985446,-39.18693975709826,-39.21816626221106,-39.24939276732387,-39.28061927243668,-39.31184577754948,-39.34307228266229,-39.3742987877751,-39.405525292887916,-39.436751798000714,-39.467978303113526,-39.49920480822634,-39.53043131333915,-39.56165781845195,-39.59288432356476,-39.62411082867757,-39.65533733379037,-39.68656383890318,-39.717790344015995,-39.74901684912881,-39.78024335424161,-39.81146985935442,-39.84269636446723,-39.873922869580035,-39.90514937469284,-39.93637587980565,-39.96760238491846,-39.99882889003126,-40.030055395144075,-40.06128190025689,-40.092508405369685,-40.03689531178651,-39.89444261950734,-39.75198992722818,-39.60953723494902,-39.46708454266985,-39.324631850390695,-39.18217915811154,-39.039726465832366,-38.897273773553195,-38.754821081274045,-38.61236838899488,-38.4699156967157,-38.32746300443655,-38.18501031215739,-38.042557619878224,-37.90010492759907,-37.7576522353199,-37.61519954304073,-37.47274685076158,-37.33029415848242,-37.18784146620325,-37.045388773924074,-36.90293608164494,-36.76048338936577,-36.618030697086596,-36.47557800480743,-36.333125312528274,-36.1906726202491,-36.048219927969946,-35.90576723569079,-35.76331454341162,-35.620861851132446,-35.4784091588533,-35.33595646657413,-35.19350377429497,-35.0510510820158,-34.90859838973664,-34.766145697457475,-34.62369300517832,-34.48124031289916,-34.33878762061998,-34.19633492834083,-34.03796201135074,-33.87206314102185,-33.70616427069296,-33.5402654003641,-33.37436653003521,-33.20846765970632,-33.04256878937745,-32.876669919048574,-32.710771048719685,-32.54487217839081,-32.37897330806194,-32.21307443773304,-32.04717556740415,-31.8812766970753,-31.715377826746412,-31.54947895641752,-31.38358008608865,-31.217681215759775,-31.05178234543088,-30.88588347510201,-30.71998460477314,-30.554085734444243,-30.38818686411537,-30.222287993786495,-30.056389123457606,-29.890490253128718,-29.724591382799858,-29.55869251247097,-29.39279364214208,-29.226894771813203,-29.060995901484336,-28.895097031155444,-28.729198160826567,-28.563299290497696,-28.397400420168807,-28.231501549839933,-28.065602679511056,-27.899703809182164,-27.73380493885328,-27.5679060685244,-27.402007198195527,-27.27607306470556,-27.230068404893412,-27.18406374508126,-27.138059085269102,-27.092054425456958,-27.046049765644803,-27.00004510583265,-26.954040446020496,-26.908035786208348,-26.862031126396193,-26.816026466584038,-26.770021806771886,-26.724017146959735,-26.67801248714758,-26.632007827335432,-26.58600316752328,-26.539998507711125,-26.493993847898974,-26.447989188086822,-26.401984528274667,-26.355979868462512,-26.30997520865036,-26.263970548838213,-26.217965889026058,-26.171961229213906,-26.12595656940175,-26.079951909589596,-26.03394724977745,-25.987942589965296,-25.941937930153145,-25.89593327034099,-25.849928610528842,-25.803923950716687,-25.757919290904532,-25.711914631092377,-25.66590997128023,-25.619905311468074,-25.573900651655922,-25.52789599184377,-25.481891332031616,-25.435886672219468,-25.389882012407313,-25.34387735259516,-25.297872692783006,-25.251868032970854,-25.205863373158707,-25.159858713346548,-25.113854053534396,-25.06784939372225,-25.02184473391009,-24.97584007409794,-24.92983541428579,-24.883830754473635,-24.83782609466148,-24.791821434849332,-24.745816775037177,-24.699812115225022,-24.653807455412867,-24.60780279560072,-24.561798135788568,-24.515793475976416,-24.469788816164264,-24.423784156352106,-24.377779496539958,-24.331774836727806,-24.285770176915655,-24.2397655171035,-24.193760857291352,-24.147756197479197,-24.10175153766704,-24.05574687785489,-24.00974221804274,-23.96325231208043,-23.915384339529577,-23.867516366978727,-23.819648394427865,-23.77178042187701,-23.723912449326157,-23.676044476775303,-23.628176504224445,-23.580308531673595,-23.53244055912274,-23.484572586571886,-23.41068692425709,-23.20671281312256,-23.00273870198803,-22.798764590853505,-22.59479047971901,-22.39081636858448,-22.186842257449953,-21.98286814631546,-21.794192952566764,-21.610066173342364,-21.425939394117997,-21.241812614893597,-21.057685835669197,-20.873559056444797,-20.68943227722043,-20.50530549799603,-20.321178718771634,-20.137051939547266,-19.952925160322867,-19.768798381098467,-19.5846716018741,-19.4005448226497,-19.2164180434253,-19.032291264200932,-18.848164484976532,-18.664037705752133,-18.479910926527737,-18.295784147303365,-18.111657368078966,-17.927530588854566,-17.743403809630202,-17.559277030405802,-17.375150251181402,-17.191023471957035,-17.006896692732635,-16.822769913508235,-16.638643134283832,-16.45451635505947,-16.270389575835072,-16.08626279661067,-15.902136017386304,-15.718009238161905,-15.533882458937505,-15.349755679713137,-15.165628900488738,-14.98150212126434,-14.797375342039974,-14.61324856281557,-14.429121783591171,-14.244995004366771,-14.060868225142405,-13.876741445918006,-13.692614666693604,-13.508487887469238,-13.324361108244839,-13.14023432902044,-12.956107549796073,-12.771980770571673,-12.587853991347274,-12.403727212122874,-12.219600432898508,-12.035473653674108,-11.851346874449707,-11.667220095225343,-11.483093316000943,-11.298966536776543,-11.114839757552176,-10.930712978327776,-10.746586199103376,-10.56245941987901,-10.378332640654609,-10.19420586143021,-10.01007908220581,-9.825952302981445,-9.641825523757044,-9.457698744532644,-9.283796025733091,-9.125498229450784,-8.967200433168479,-8.808902636886202,-8.650604840603895,-8.49230704432159,-8.334009248039283,-8.175711451757007],[-31.416824993111568,-31.452425022229548,-31.488025051347524,-31.523625080465507,-31.559225109583487,-31.594825138701466,-31.630425167819446,-31.666025196937426,-31.701625226055405,-31.73722525517339,-31.77282528429137,-31.808425313409344,-31.844025342527328,-31.879625371645307,-31.915225400763287,-31.950825429881267,-31.986425458999246,-32.02202548811722,-32.05762551723521,-32.09322554635318,-32.12882557547117,-32.16442560458914,-32.20002563370712,-32.23562566282511,-32.27122569194309,-32.30682572106106,-32.342425750179046,-32.37802577929702,-32.413625808415006,-32.44922583753298,-32.484825866650965,-32.520425895768945,-32.556025924886924,-32.591625954004904,-32.627225983122884,-32.662826012240856,-32.69842604135884,-32.73402607047682,-32.7696260995948,-32.80522612871278,-32.84082615783076,-32.87642618694874,-32.91202621606672,-32.94762624518471,-32.98322627430268,-33.01882630342067,-33.05442633253864,-33.09002636165662,-33.1256263907746,-33.161226419892586,-33.19682644901056,-33.232426478128545,-33.26802650724652,-33.303626536364504,-33.33922656548248,-33.374826594600464,-33.410426623718436,-33.44602665283642,-33.481626681954396,-33.51722671107238,-33.552826740190355,-33.58842676930834,-33.624026798426314,-33.6596268275443,-33.69522685666227,-33.73082688578026,-33.76642691489823,-33.80202694401622,-33.8376269731342,-33.87322700225218,-33.90882703137015,-33.94442706048814,-33.98002708960611,-34.0156271187241,-34.05122714784207,-34.08682717696006,-34.12242720607803,-34.158027235196016,-34.193627264314,-34.23014836536563,-34.26759053398985,-34.30503270261408,-34.3424748712383,-34.37991703986252,-34.415538550358214,-34.4507959292282,-34.486053308098185,-34.521310686968164,-34.556335516001305,-34.59019758594046,-34.62405965587962,-34.65792172581878,-34.691783795757935,-34.725645865697096,-34.75950793563626,-34.79337000557542,-34.82723207551457,-34.861094145453734,-34.89495621539289,-34.92881828533205,-34.9626803552712,-34.996542425210365,-35.030404495149526,-35.06426656508869,-35.09812863502784,-35.131990704966995,-35.165852774906156,-35.19971484484531,-35.23357691478447,-35.26743898472363,-35.30130105466279,-35.33516312460195,-35.36902519454111,-35.40288726448027,-35.436749334419424,-35.470611404358586,-35.50447347429774,-35.5383355442369,-35.572197614176055,-35.606059684115216,-35.63992175405437,-35.67378382399353,-35.70764589393269,-35.741507963871854,-35.775370033811015,-35.80923210375017,-35.84309417368933,-35.876956243628484,-35.910818313567646,-35.94468038350681,-35.97854245344596,-36.01240452338512,-36.046266593324276,-36.08012866326343,-36.1139907332026,-36.14785280314175,-36.18171487308091,-36.21557694302007,-36.24943901295923,-36.28330108289839,-36.317163152837544,-36.3510252227767,-36.38488729271586,-36.41874936265502,-36.45261143259418,-36.48647350253334,-36.5203355724725,-36.55419764241166,-36.58805971235081,-36.621921782289974,-36.655783852229135,-36.68964592216829,-36.72350799210744,-36.7573700620466,-36.79123213198576,-36.82509420192492,-36.85895627186408,-36.892818341803235,-36.926680411742396,-36.96054248168156,-36.99440455162071,-37.02826662155987,-37.06212869149903,-37.09599076143819,-37.12985283137735,-37.1637149013165,-37.19757697125566,-37.22705376271336,-37.254337914930325,-37.28162206714729,-37.30890621936425,-37.336190371581225,-37.36347452379819,-37.39075867601515,-37.41804282823211,-37.449269326514795,-37.4804958316276,-37.51172233674041,-37.54294884185322,-37.57417534696603,-37.60540185207883,-37.63662835719164,-37.66785486230445,-37.69908136741726,-37.73030787253006,-37.761534377642874,-37.79276088275568,-37.82398738786849,-37.8552138929813,-37.88644039809411,-37.91766690320692,-37.94889340831972,-37.98011991343253,-38.011346418545344,-38.04257292365815,-38.073799428770954,-38.10502593388376,-38.13625243899657,-38.167478944109384,-38.19870544922219,-38.229931954335,-38.2611584594478,-38.29238496456061,-38.323611469673416,-38.35483797478623,-38.38606447989904,-38.417290985011846,-38.44851749012465,-38.47974399523746,-38.51097050035027,-38.54219700546308,-38.573423510575886,-38.6046500156887,-38.6358765208015,-38.667103025914315,-38.69832953102712,-38.729556036139925,-38.76078254125273,-38.79200904636554,-38.823235551478355,-38.85446205659116,-38.88568856170397,-38.91691506681678,-38.94814157192958,-38.979368077042395,-39.0105945821552,-39.04182108726801,-39.07304759238082,-39.10427409749363,-39.135500602606434,-39.16672710771924,-39.19795361283205,-39.229180117944864,-39.26040662305767,-39.291633128170474,-39.32285963328329,-39.35408613839609,-39.3853126435089,-39.41653914862171,-39.447765653734514,-39.478992158847326,-39.51021866396013,-39.541445169072944,-39.57267167418575,-39.603898179298554,-39.635124684411366,-39.66635118952418,-39.69757769463698,-39.72880419974979,-39.7600307048626,-39.70441761127941,-39.561964919000246,-39.41951222672108,-39.27705953444193,-39.13460684216275,-38.9921541498836,-38.84970145760444,-38.707248765325275,-38.5647960730461,-38.422343380766954,-38.27989068848779,-38.13743799620861,-37.994985303929454,-37.8525326116503,-37.710079919371125,-37.567627227091975,-37.42517453481281,-37.28272184253364,-37.14026915025448,-36.997816457975325,-36.855363765696154,-36.71291107341699,-36.57045838113784,-36.42800568885867,-36.2855529965795,-36.14310030430035,-36.00064761202118,-35.85819491974201,-35.715742227462854,-35.5732895351837,-35.430836842904526,-35.288384150625355,-35.14593145834621,-35.00347876606704,-34.86102607378787,-34.71857338150871,-34.576120689229555,-34.43366799695038,-34.291215304671226,-34.14876261239206,-34.00630992011289,-33.86385722783373,-33.721404535554576,-33.578951843275405,-33.436499150996234,-33.29404645871709,-33.15159376643792,-33.00914107415875,-32.86668838187959,-32.724235689600434,-32.58178299732126,-32.439330305042105,-32.29687761276294,-32.15442492048378,-32.011972228204606,-31.869519535925463,-31.72706684364629,-31.58461415136712,-31.442161459087963,-31.299708766808802,-31.15725607452963,-31.014803382250477,-30.87235068997132,-30.72989799769214,-30.587445305412988,-30.439058702158484,-30.273159831829595,-30.107260961500707,-29.941362091171847,-29.77546322084295,-29.60956435051407,-29.443665480185192,-29.277766609856318,-29.111867739527433,-28.945968869198555,-28.78006999886968,-28.614171128540793,-28.448272258211915,-28.28237338788304,-28.11647451755415,-27.95057564722526,-27.784676776896386,-27.618777906567512,-27.49284377307755,-27.4468391132654,-27.400834453453246,-27.35482979364109,-27.30882513382894,-27.26282047401679,-27.216815814204633,-27.17081115439248,-27.124806494580334,-27.078801834768182,-27.032797174956023,-26.986792515143872,-26.940787855331724,-26.89478319551957,-26.848778535707417,-26.802773875895266,-26.756769216083107,-26.71076455627096,-26.66475989645881,-26.618755236646653,-26.572750576834498,-26.526745917022346,-26.480741257210198,-26.43473659739804,-26.38873193758589,-26.34272727777374,-26.296722617961585,-26.250717958149433,-26.204713298337282,-26.158708638525127,-26.11270397871297,-26.066699318900824,-26.02069465908867,-25.974689999276514,-25.928685339464366,-25.882680679652214,-25.83667601984006,-25.790671360027908,-25.744666700215756,-25.698662040403605,-25.65268267966502,-25.608499978782255,-25.564317277899484,-25.520134577016712,-25.475951876133948,-25.431769175251183,-25.387586474368412,-25.343403773485644,-25.29922107260288,-25.255038371720108,-25.21085567083734,-25.166672969954575,-25.122490269071804,-25.07830756818904,-25.034124867306275,-24.989942166423507,-24.945759465540736,-24.90157676465797,-24.857394063775203,-24.81321136289243,-24.769028662009667,-24.724845961126903,-24.68066326024413,-24.636480559361363,-24.592297858478595,-24.548115157595827,-24.50393245671306,-24.459749755830295,-24.415567054947527,-24.371384354064755,-24.32720165318199,-24.283018952299223,-24.238836251416455,-24.194653550533687,-24.15047084965092,-24.10628814876815,-24.06210544788538,-24.01792274700262,-23.973740046119847,-23.92955734523708,-23.885374644354314,-23.841191943471543,-23.797009242588775,-23.725390731783172,-23.51659317136334,-23.307795610943515,-23.098998050523683,-22.890200490103897,-22.68140292968407,-22.472605369264237,-22.263807808844447,-22.055010248424622,-21.84621268800479,-21.637415127585,-21.428617567165176,-21.219820006745344,-21.011022446325512,-20.802224885905723,-20.593427325485898,-20.384629765066066,-20.175832204646284,-19.96703464422645,-19.758237083806623,-19.559086432241347,-19.374959653016944,-19.190832873792544,-19.006706094568177,-18.822579315343777,-18.63845253611938,-18.45432575689498,-18.270198977670614,-18.086072198446214,-17.901945419221814,-17.717818639997446,-17.533691860773047,-17.349565081548647,-17.16543830232428,-16.98131152309988,-16.79718474387548,-16.61305796465108,-16.428931185426716,-16.244804406202316,-16.060677626977917,-15.876550847753549,-15.69242406852915,-15.50829728930475,-15.324170510080384,-15.140043730855982,-14.955916951631584,-14.771790172407218,-14.587663393182819,-14.403536613958419,-14.219409834734018,-14.035283055509653,-13.851156276285252,-13.667029497060852,-13.482902717836486,-13.298775938612087,-13.114649159387687,-12.930522380163321,-12.746395600938921,-12.562268821714522,-12.37814204249012,-12.194015263265754,-12.009888484041355,-11.825761704816955,-11.64163492559259,-11.469786194605941,-11.30148896585645,-11.13319173710699,-10.9648945083575,-10.796597279608008,-10.628300050858547,-10.460002822109056,-10.291705593359566,-10.123408364610075,-9.955111135860612,-9.786813907111123,-9.618516678361633,-9.45021944961217,-9.28192222086268,-9.11362499211319,-8.94532776336373,-8.777030534614239,-8.608733305864746,-8.440436077115256,-8.272138848365795],[-31.022072433688976,-31.057672462806956,-31.093272491924935,-31.128872521042915,-31.164472550160895,-31.200072579278878,-31.235672608396854,-31.271272637514834,-31.306872666632817,-31.342472695750796,-31.378072724868776,-31.413672753986756,-31.449272783104735,-31.484872812222715,-31.5204728413407,-31.556072870458678,-31.591672899576654,-31.627272928694637,-31.662872957812617,-31.698472986930597,-31.734073016048576,-31.769673045166556,-31.805273074284532,-31.84087310340252,-31.87647313252049,-31.91207316163847,-31.947673190756458,-31.98327321987443,-32.01887324899241,-32.05447327811039,-32.09007330722837,-32.12567333634635,-32.16127336546433,-32.19687339458231,-32.23247342370029,-32.26807345281827,-32.30367348193626,-32.33927351105423,-32.37487354017222,-32.41047356929019,-32.44607359840817,-32.48167362752615,-32.517273656644136,-32.55287368576211,-32.58847371488009,-32.62407374399807,-32.659673773116054,-32.69527380223403,-32.73087383135201,-32.766473860469986,-32.802073889587966,-32.837673918705946,-32.87327394782393,-32.90887397694191,-32.94447400605989,-32.98007403517787,-33.01567406429585,-33.05127409341383,-33.08687412253181,-33.12247415164979,-33.15807418076777,-33.19367420988575,-33.22927423900373,-33.26487426812171,-33.30047429723969,-33.33607432635767,-33.37167435547565,-33.40727438459363,-33.442874413711614,-33.47847444282959,-33.514074471947566,-33.549674501065546,-33.58395798413572,-33.61758319056937,-33.65120839700301,-33.68483360343666,-33.7184588098703,-33.75208401630394,-33.78570922273759,-33.81933442917123,-33.852959635604876,-33.886584842038516,-33.92021004847216,-33.953835254905805,-33.98633391508986,-34.01860726602399,-34.05088061695813,-34.083153967892265,-34.115427318826406,-34.14770066976054,-34.17997402069468,-34.21224737162881,-34.24452072256295,-34.276794073497086,-34.30906742443123,-34.34134077730291,-34.37520284724207,-34.409064917181226,-34.44292698712038,-34.47678905705954,-34.510651126998695,-34.54451319693786,-34.57837526687702,-34.61223733681618,-34.64609940675533,-34.67996147669449,-34.713823546633655,-34.74768561657281,-34.78154768651197,-34.81540975645113,-34.849271826390286,-34.88313389632945,-34.9169959662686,-34.95085803620776,-34.98472010614692,-35.01858217608608,-35.05244424602523,-35.08630631596439,-35.120168385903554,-35.15403045584271,-35.18789252578187,-35.22175459572103,-35.255616665660185,-35.289478735599346,-35.32334080553851,-35.35720287547766,-35.39106494541682,-35.424927015355976,-35.45878908529514,-35.4926511552343,-35.52651322517345,-35.560375295112614,-35.59423736505177,-35.62809943499093,-35.66196150493009,-35.69582357486925,-35.729685644808406,-35.76354771474756,-35.79740978468672,-35.83127185462588,-35.86513392456504,-35.8989959945042,-35.93285806444336,-35.96672013438251,-36.000582204321674,-36.03444427426083,-36.068306344199996,-36.10216841413915,-36.136030484078304,-36.169892554017466,-36.20375462395663,-36.23761669389578,-36.27147876383495,-36.305340833774096,-36.33920290371326,-36.37306497365242,-36.40692704359157,-36.44078911353073,-36.47465118346989,-36.50851325340905,-36.54237532334821,-36.576237393287364,-36.610099463226526,-36.64396153316569,-36.67782360310484,-36.711685673044,-36.745547742983156,-36.77885619283058,-36.81188783263214,-36.84491947243369,-36.877951112235245,-36.91098275203679,-36.944014391838344,-36.977046031639894,-37.01007767144145,-37.043109311243,-37.07614095104455,-37.10917259084611,-37.142204230647664,-37.175235870449214,-37.208267510250764,-37.24129915005231,-37.27433078985387,-37.30736242965543,-37.34039406945698,-37.37342570925853,-37.406457349060084,-37.43948898886163,-37.47252062866319,-37.50555226846474,-37.5385839082663,-37.57161554806784,-37.60464718786939,-37.637678827670946,-37.6707104674725,-37.70374210727405,-37.73677374707561,-37.76980538687716,-37.802837026678716,-37.83586866648026,-37.868900306281816,-37.901931946083366,-37.934963585884915,-37.96799522568647,-38.00102686548802,-38.03405850528958,-38.06709014509113,-38.10012178489268,-38.133153424694235,-38.166185064495785,-38.19921670429734,-38.23224834409889,-38.26527998390044,-38.29831162370199,-38.33134326350355,-38.3643749033051,-38.397078335632834,-38.428304840745646,-38.45953134585845,-38.490757850971264,-38.521984356084076,-38.55321086119688,-38.58443736630968,-38.61566387142249,-38.646890376535296,-38.67811688164811,-38.70934338676092,-38.740569891873726,-38.77179639698653,-38.80302290209934,-38.83424940721215,-38.86547591232495,-38.896702417437766,-38.92792892255058,-38.95915542766338,-38.99038193277619,-39.02160843788899,-39.052834943001805,-39.08406144811462,-39.11528795322743,-39.146514458340235,-39.17774096345304,-39.208967468565845,-39.24019397367866,-39.27142047879147,-39.30264698390427,-39.33387348901707,-39.365099994129885,-39.3963264992427,-39.4275530043555,-39.37193991077232,-39.229487218493155,-39.087034526214,-38.94458183393484,-38.80212914165566,-38.65967644937651,-38.517223757097355,-38.37477106481818,-38.232318372539005,-38.08986568025986,-37.94741298798069,-37.80496029570153,-37.66250760342236,-37.520054911143205,-37.377602218864034,-37.23514952658488,-37.09269683430572,-36.95024414202655,-36.80779144974739,-36.665338757468234,-36.52288606518906,-36.38043337290989,-36.23798068063075,-36.09552798835158,-35.953075296072406,-35.81062260379325,-35.66816991151409,-35.52571721923492,-35.38326452695576,-35.2408118346766,-35.098359142397435,-34.95590645011826,-34.81345375783912,-34.67100106555994,-34.52854837328078,-34.38609568100161,-34.243642988722456,-34.10119029644329,-33.958737604164135,-33.81628491188497,-33.6738322196058,-33.53137952732665,-33.388926835047485,-33.24647414276832,-33.10402145048914,-32.96156875820999,-32.81911606593083,-32.67666337365166,-32.5342106813725,-32.39175798909334,-32.24930529681417,-32.10685260453501,-31.96439991225585,-31.821947219976682,-31.679494527697514,-31.537041835418368,-31.39624660893056,-31.258351961080866,-31.12045731323118,-30.98256266538149,-30.84466801753179,-30.706773369682104,-30.56887872183242,-30.430984073982717,-30.293089426133033,-30.15519477828334,-30.017300130433647,-29.87940548258395,-29.741510834734274,-29.603616186884576,-29.465721539034877,-29.32782689118519,-29.1899322433355,-29.052037595485803,-28.914142947636115,-28.77624829978643,-28.638353651936733,-28.500459004087045,-28.36256435623736,-28.22466970838766,-28.086775060537963,-27.948880412688272,-27.810985764838588,-27.70494539610398,-27.662613585599512,-27.620281775095044,-27.577949964590577,-27.535618154086116,-27.493286343581648,-27.45095453307718,-27.408622722572712,-27.36629091206825,-27.323959101563783,-27.281627291059312,-27.239295480554848,-27.19696367005038,-27.154631859545916,-27.11230004904145,-27.069968238536983,-27.025870631394305,-26.98168793051154,-26.937505229628773,-26.893322528746,-26.84913982786323,-26.80495712698046,-26.760774426097697,-26.71659172521493,-26.67240902433216,-26.628226323449397,-26.584043622566625,-26.539860921683857,-26.495678220801093,-26.45149551991833,-26.407312819035553,-26.363130118152796,-26.318947417270024,-26.274764716387253,-26.23058201550449,-26.18639931462172,-26.14221661373895,-26.09803391285618,-26.053851211973416,-26.009668511090645,-25.96548581020788,-25.921303109325116,-25.877120408442345,-25.832937707559573,-25.78875500667681,-25.744572305794044,-25.70038960491127,-25.656206904028505,-25.61202420314574,-25.567841502262972,-25.523658801380208,-25.479476100497436,-25.435293399614665,-25.391110698731897,-25.346927997849136,-25.302745296966368,-25.258562596083596,-25.21437989520083,-25.17019719431806,-25.126014493435292,-25.081831792552528,-25.037649091669763,-24.99346639078699,-24.949283689904224,-24.90510098902146,-24.860918288138688,-24.81673558725592,-24.772552886373155,-24.728370185490384,-24.684187484607616,-24.640004783724848,-24.595822082842083,-24.551639381959312,-24.507456681076548,-24.463273980193783,-24.41909127931101,-24.37490857842824,-24.33072587754548,-24.28654317666271,-24.24236047577994,-24.19817777489717,-24.153995074014404,-24.109812373131636,-24.038193862326033,-23.829396301906204,-23.620598741486376,-23.411801181066547,-23.203003620646754,-22.994206060226926,-22.785408499807097,-22.57661093938731,-22.367813378967483,-22.15901581854765,-21.95021825812786,-21.741420697708033,-21.532623137288205,-21.323825576868373,-21.115028016448584,-20.90623045602876,-20.697432895608927,-20.48863533518914,-20.279837774769312,-20.071040214349484,-19.862242653929695,-19.653445093509866,-19.444647533090038,-19.235849972670245,-19.027052412250416,-18.818254851830588,-18.60945729141076,-18.40065973099097,-18.19186217057114,-17.983064610151313,-17.77426704973152,-17.565469489311695,-17.356671928891863,-17.147874368472074,-16.939076808052246,-16.730279247632417,-16.52148168721259,-16.3126841267928,-16.11015344293797,-15.918658970698367,-15.727164498458798,-15.535670026219194,-15.34417555397959,-15.15268108174002,-14.961186609500416,-14.769692137260812,-14.5968594790064,-14.428562250256908,-14.260265021507417,-14.091967792757927,-13.923670564008466,-13.755373335258975,-13.587076106509485,-13.418778877760023,-13.250481649010531,-13.08218442026104,-12.91388719151158,-12.74558996276209,-12.577292734012598,-12.408995505263109,-12.240698276513648,-12.072401047764156,-11.904103819014667,-11.735806590265204,-11.567509361515715,-11.399212132766223,-11.230914904016764,-11.062617675267273,-10.89432044651778,-10.726023217768322,-10.557725989018829,-10.389428760269338,-10.221131531519847,-10.052834302770387,-9.884537074020896,-9.716239845271405,-9.547942616521944,-9.379645387772452,-9.211348159022961,-9.043050930273502,-8.87475370152401,-8.706456472774521,-8.538159244025028,-8.369862015275569],[-30.623838865665483,-30.65943889478347,-30.695038923901443,-30.730638953019422,-30.76623898213741,-30.801839011255385,-30.83743904037336,-30.873039069491345,-30.908639098609328,-30.944239127727304,-30.979839156845287,-31.015439185963263,-31.051039215081243,-31.086639244199226,-31.122239273317206,-31.157839302435185,-31.193439331553165,-31.229039360671145,-31.264639389789124,-31.300239418907104,-31.335839448025084,-31.371439477143063,-31.407039506261043,-31.442639535379026,-31.478239564497002,-31.513839593614982,-31.549439622732965,-31.585039651850938,-31.620639680968928,-31.656239710086904,-31.69183973920488,-31.72743976832286,-31.763039797440843,-31.798639826558823,-31.8342398556768,-31.869839884794782,-31.905439913912762,-31.941039943030738,-31.976639972148725,-32.012240001266704,-32.047840030384684,-32.08344005950266,-32.11904008862064,-32.15464011773862,-32.1902401468566,-32.22584017597458,-32.26144020509256,-32.29704023421054,-32.33264026332852,-32.3682402924465,-32.40384032156447,-32.43944035068246,-32.47504037980044,-32.51064040891842,-32.54624043803639,-32.5815113321229,-32.61513653855655,-32.64876174499019,-32.68238695142383,-32.71601215785748,-32.74963736429112,-32.783262570724766,-32.816887777158406,-32.85051298359205,-32.884138190025695,-32.917763396459335,-32.951388602892976,-32.98501380932662,-33.018639015760264,-33.05226422219391,-33.085889428627546,-33.11951463506119,-33.153139841494834,-33.186765047928475,-33.22039025436212,-33.25401546079576,-33.287640667229404,-33.32126587366305,-33.35489108009669,-33.38851628653034,-33.42214149296398,-33.45576669939762,-33.48939190583127,-33.52301711226491,-33.55551577244896,-33.587789123383104,-33.62006247431724,-33.65233582525137,-33.68460917618551,-33.716882527119644,-33.749155878053784,-33.78142922898792,-33.81370257992206,-33.84597593085619,-33.87824928179033,-33.910522632724465,-33.942795983658606,-33.975069334592746,-34.00734268552688,-34.03961603646102,-34.07188938739515,-34.10416273832929,-34.13643608926343,-34.16870944019757,-34.2009827911317,-34.23325614206584,-34.265529492999974,-34.29780284393411,-34.33007619486825,-34.36234954580238,-34.39462289673652,-34.426896247670655,-34.45996395978271,-34.49382602972187,-34.52768809966103,-34.56155016960019,-34.59541223953934,-34.62927430947851,-34.663136379417665,-34.696998449356826,-34.73086051929598,-34.76472258923514,-34.798584659174296,-34.83244672911346,-34.86630879905262,-34.90017086899177,-34.93403293893093,-34.96789500887009,-35.00175707880925,-35.03561914874841,-35.06948121868757,-35.10334328862673,-35.137205358565886,-35.17106742850504,-35.2049294984442,-35.23879156838336,-35.27265363832252,-35.30651570826168,-35.34037777820083,-35.37423984813999,-35.40810191807915,-35.44196398801831,-35.47582605795747,-35.509688127896624,-35.543550197835785,-35.577412267774946,-35.61127433771411,-35.64513640765326,-35.678998477592415,-35.71286054753158,-35.74672261747074,-35.7805846874099,-35.81444675734905,-35.84830882728821,-35.88217089722737,-35.91603296716653,-35.949895037105684,-35.983757107044845,-36.017619176984,-36.05148124692316,-36.08534331686232,-36.11920538680148,-36.15306745674064,-36.18692952667979,-36.22079159661895,-36.25465366655811,-36.288515736497274,-36.3218241863447,-36.35485582614625,-36.3878874659478,-36.42091910574935,-36.4539507455509,-36.486982385352455,-36.520014025154005,-36.55304566495556,-36.58607730475711,-36.61910894455866,-36.65214058436022,-36.68517222416177,-36.718203863963325,-36.751235503764875,-36.784267143566424,-36.81729878336798,-36.85033042316954,-36.88336206297109,-36.91639370277264,-36.949425342574195,-36.98245698237574,-37.0154886221773,-37.04852026197885,-37.0815519017804,-37.11458354158195,-37.1476151813835,-37.180646821185064,-37.213678460986614,-37.246710100788164,-37.279741740589714,-37.31277338039126,-37.34580502019282,-37.37883665999438,-37.41186829979593,-37.44489993959748,-37.477931579399026,-37.51096321920058,-37.54399485900213,-37.57702649880368,-37.61005813860524,-37.64308977840679,-37.676121418208346,-37.709153058009896,-37.742184697811446,-37.775216337613,-37.80824797741455,-37.84127961721611,-37.87431125701766,-37.907342896819216,-37.940374536620766,-37.973406176422316,-38.006437816223865,-38.03946945602542,-38.07250109582697,-38.10553273562852,-38.138564375430086,-38.171596015231636,-38.204627655033185,-38.237659294834735,-38.270690934636285,-38.30372257443784,-38.33675421423939,-38.36978585404094,-38.4028174938425,-38.43584913364405,-38.4688807734456,-38.501912413247155,-38.534944053048704,-38.56797569285026,-38.60100733265181,-38.63403897245337,-38.66707061225492,-38.70064695238712,-38.73458642508587,-38.76852589778462,-38.802465370483375,-38.83640484318213,-38.870344315880885,-38.90428378857964,-38.938223261278395,-38.97216273397715,-39.006102206675905,-39.04004167937466,-38.99660050516322,-38.875778684041606,-38.754956862920004,-38.6341350417984,-38.51331322067678,-38.39249139955517,-38.27166957843357,-38.15084775731195,-38.03002593619034,-37.909204115068746,-37.78838229394713,-37.667560472825514,-37.546738651703905,-37.4259168305823,-37.305095009460686,-37.18427318833908,-37.06345136721747,-36.94262954609585,-36.82180772497425,-36.69004604066881,-36.55215139281911,-36.41425674496942,-36.276362097119744,-36.138467449270046,-36.00057280142034,-35.862678153570656,-35.72478350572097,-35.58688885787127,-35.44899421002158,-35.3110995621719,-35.1732049143222,-35.0353102664725,-34.89741561862283,-34.759520970773124,-34.621626322923426,-34.48373167507374,-34.34583702722406,-34.20794237937436,-34.07004773152467,-33.93215308367498,-33.794258435825284,-33.6563637879756,-33.518469140125916,-33.38057449227621,-33.24267984442652,-33.10478519657684,-32.96689054872714,-32.828995900877445,-32.69110125302776,-32.55320660517807,-32.41531195732837,-32.277417309478686,-32.139522661629,-32.0016280137793,-31.863733365929605,-31.72583871807993,-31.58794407023023,-31.45004942238053,-31.312154774530843,-31.174260126681155,-31.036365478831456,-30.898470830981772,-30.760576183132088,-30.622681535282386,-30.484786887432698,-30.346892239583013,-30.208997591733315,-30.071102943883616,-29.93320829603394,-29.795313648184244,-29.657419000334542,-29.519524352484858,-29.381629704635174,-29.243735056785475,-29.105840408935787,-28.9679457610861,-28.8300511132364,-28.692156465386713,-28.55426181753703,-28.41636716968733,-28.27847252183763,-28.140577873987944,-28.002683226138256,-27.89664285740365,-27.85431104689918,-27.811979236394713,-27.769647425890245,-27.727315615385777,-27.684983804881316,-27.64265199437685,-27.600320183872377,-27.557988373367913,-27.515656562863448,-27.473324752358984,-27.430992941854516,-27.388661131350048,-27.346329320845584,-27.30399751034112,-27.26166569983665,-27.219333889332184,-27.17700207882772,-27.134670268323255,-27.092338457818784,-27.050006647314312,-27.007674836809848,-26.965343026305383,-26.923011215800916,-26.880679405296455,-26.838347594791987,-26.796015784287523,-26.75368397378306,-26.71135216327859,-26.66902035277412,-26.626688542269655,-26.58435673176519,-26.542024921260722,-26.49969311075625,-26.45736130025179,-26.415029489747322,-26.372697679242854,-26.330365868738387,-26.288034058233926,-26.245702247729458,-26.20337043722499,-26.16103862672053,-26.118706816216058,-26.07637500571159,-26.034043195207126,-25.991711384702658,-25.94937957419819,-25.907047763693726,-25.86471595318926,-25.82238414268479,-25.78005233218033,-25.73772052167586,-25.695388711171393,-25.653056900666925,-25.610725090162465,-25.568393279657997,-25.526061469153525,-25.48372965864906,-25.441397848144597,-25.399066037640125,-25.356734227135664,-25.314402416631197,-25.272070606126732,-25.229738795622268,-25.1874069851178,-25.145075174613336,-25.10274336410886,-25.060411553604403,-25.018079743099936,-24.975747932595464,-24.933416122090996,-24.891084311586535,-24.84875250108206,-24.8064206905776,-24.764088880073135,-24.721757069568667,-24.6794252590642,-24.63709344855974,-24.594761638055267,-24.5524298275508,-24.510098017046335,-24.466798204557275,-24.422615503674503,-24.3509969928689,-24.14219943244907,-23.948153826983926,-23.75665935474432,-23.565164882504753,-23.37367041026515,-23.182175938025544,-22.990681465785975,-22.799186993546375,-22.607692521306767,-22.416198049067198,-22.224703576827594,-22.03320910458799,-21.841714632348385,-21.650220160108816,-21.458725687869215,-21.26723121562961,-21.075736743390042,-20.884242271150434,-20.692747798910833,-20.501253326671264,-20.30975885443166,-20.118264382192056,-19.926769909952487,-19.735275437712883,-19.54378096547328,-19.352286493233677,-19.16079202099411,-18.9692975487545,-18.777803076514896,-18.586308604275327,-18.394814132035727,-18.20331965979612,-18.01182518755655,-17.82033071531695,-17.628836243077345,-17.43734177083774,-17.24584729859817,-17.054352826358567,-16.862858354118963,-16.671363881879394,-16.47986940963979,-16.288374937400185,-16.096880465160616,-15.905385992921014,-15.71389152068141,-15.52239704844184,-15.330902576202234,-15.139408103962632,-14.947913631723027,-14.75641915948346,-14.564924687243856,-14.373430215004252,-14.181935742764683,-13.990441270525078,-13.798946798285476,-13.607452326045907,-13.415957853806303,-13.224463381566698,-13.032968909327094,-12.841474437087527,-12.649979964847923,-12.458485492608318,-12.26699102036875,-12.075496548129145,-11.88400207588954,-11.692507603649972,-11.501013131410367,-11.309518659170763,-11.118024186931196,-10.926529714691592,-10.735035242451987,-10.543540770212385,-10.352046297972816,-10.160551825733211,-9.969057353493607,-9.777562881254038,-9.586068409014434,-9.394573936774831,-9.203079464535262,-9.011584992295656,-8.820090520056054,-8.635882410934803,-8.467585182185342],[-30.22560529764199,-30.261205326759974,-30.29680535587795,-30.33240538499593,-30.368005414113913,-30.403605443231896,-30.43920547234987,-30.474805501467852,-30.510405530585835,-30.546005559703815,-30.58160558882179,-30.617205617939774,-30.652805647057754,-30.688405676175734,-30.72400570529371,-30.759605734411693,-30.795205763529673,-30.830805792647652,-30.866405821765632,-30.90200585088361,-30.93760588000159,-30.97320590911957,-31.008805938237547,-31.044405967355534,-31.08000599647351,-31.11560602559149,-31.15120605470947,-31.18680608382745,-31.222406112945432,-31.258006142063408,-31.293606171181388,-31.32920620029937,-31.364806229417347,-31.400406258535327,-31.43600628765331,-31.47160631677129,-31.50720634588927,-31.542806375007245,-31.578406404125232,-31.612689886543716,-31.64631509297736,-31.679940299411005,-31.713565505844645,-31.74719071227829,-31.78081591871193,-31.81444112514557,-31.84806633157922,-31.88169153801286,-31.9153167444465,-31.948941950880148,-31.982567157313788,-32.016192363747436,-32.04981757018108,-32.08344277661472,-32.117067983048365,-32.150693189482006,-32.18431839591565,-32.217943602349294,-32.251568808782935,-32.28519401521658,-32.31881922165022,-32.352444428083864,-32.386069634517504,-32.41969484095115,-32.45332004738479,-32.48694525381844,-32.52057046025208,-32.55419566668572,-32.58782087311937,-32.62144607955301,-32.65507128598665,-32.68869649242029,-32.72232169885394,-32.75594690528759,-32.78957211172123,-32.82319731815487,-32.85682252458851,-32.89044773102216,-32.9240729374558,-32.95769814388944,-32.991323350323086,-33.024948556756726,-33.05857376319037,-33.092198969624015,-33.12469762980807,-33.1569709807422,-33.189244331676335,-33.221517682610475,-33.253791033544616,-33.28606438447875,-33.31833773541288,-33.35061108634702,-33.38288443728116,-33.415157788215296,-33.44743113914943,-33.47970449008357,-33.51197784101771,-33.544251191951844,-33.57652454288598,-33.60879789382012,-33.64107124475426,-33.67334459568839,-33.70561794662253,-33.737891297556665,-33.770164648490805,-33.80243799942494,-33.83471135035908,-33.86698470129321,-33.89925805222735,-33.931531403161486,-33.96380475409562,-33.99607810502976,-34.0283514559639,-34.06062480689803,-34.092898157832174,-34.12517150876631,-34.15744485970044,-34.18971821063458,-34.221991561568714,-34.254264912502855,-34.286538263436995,-34.31881161437113,-34.35108496530527,-34.3833583162394,-34.41563166717354,-34.447905018107676,-34.480178369041816,-34.51245171997595,-34.54472507232336,-34.57858714226252,-34.612449212201675,-34.646311282140836,-34.68017335207999,-34.71403542201915,-34.74789749195831,-34.781759561897466,-34.81562163183663,-34.84948370177578,-34.88334577171494,-34.9172078416541,-34.95106991159326,-34.98493198153241,-35.01879405147158,-35.052656121410735,-35.086518191349896,-35.12038026128905,-35.15424233122821,-35.188104401167365,-35.221966471106526,-35.25582854104569,-35.28969061098484,-35.323552680924,-35.357414750863164,-35.39127682080232,-35.42513889074148,-35.45900096068064,-35.492863030619795,-35.526725100558956,-35.56058717049811,-35.59444924043727,-35.628311310376425,-35.662173380315586,-35.69603545025475,-35.7298975201939,-35.76375959013306,-35.797621660072224,-35.83148373001138,-35.8647921798588,-35.89782381966036,-35.93085545946191,-35.96388709926346,-35.99691873906501,-36.029950378866566,-36.062982018668116,-36.09601365846967,-36.12904529827122,-36.16207693807277,-36.19510857787433,-36.228140217675886,-36.261171857477436,-36.294203497278986,-36.327235137080535,-36.360266776882085,-36.39329841668364,-36.4263300564852,-36.45936169628675,-36.4923933360883,-36.52542497588985,-36.558456615691405,-36.59148825549296,-36.62451989529451,-36.65755153509606,-36.69058317489761,-36.72361481469917,-36.756646454500725,-36.789678094302275,-36.822709734103825,-36.855741373905374,-36.88877301370694,-36.92180465350848,-36.95483629331003,-36.98786793311159,-37.02089957291314,-37.0539312127147,-37.08696285251625,-37.119994492317794,-37.15302613211935,-37.1860577719209,-37.21908941172246,-37.25212105152401,-37.28515269132556,-37.318184331127114,-37.35121597092867,-37.38424761073021,-37.41727925053177,-37.45031089033332,-37.48334253013488,-37.51663355099653,-37.550573023695286,-37.58451249639404,-37.61845196909279,-37.65239144179155,-37.6863309144903,-37.72027038718906,-37.75420985988781,-37.78814933258657,-37.82208880528532,-37.85602827798407,-37.88996775068283,-37.92390722338158,-37.95784669608034,-37.99178616877909,-38.02572564147785,-38.0596651141766,-38.09360458687536,-38.127544059574106,-38.16148353227287,-38.19542300497162,-38.22936247767038,-38.26330195036913,-38.29724142306788,-38.331180895766636,-38.36512036846539,-38.39905984116414,-38.4329993138629,-38.466938786561656,-38.50087825926041,-38.53481773195916,-38.56875720465792,-38.602696677356676,-38.55925550314524,-38.43843368202362,-38.31761186090202,-38.19679003978041,-38.075968218658794,-37.95514639753719,-37.83432457641558,-37.71350275529396,-37.59268093417235,-37.471859113050755,-37.35103729192914,-37.23021547080752,-37.10939364968591,-36.98857182856431,-36.867750007442694,-36.74692818632109,-36.626106365199476,-36.50528454407787,-36.38446272295626,-36.263640901834655,-36.14281908071304,-36.02199725959142,-35.90117543846983,-35.78035361734821,-35.659531796226595,-35.53870997510499,-35.417888153983384,-35.29706633286176,-35.176244511740165,-35.055422690618556,-34.93460086949694,-34.813779048375324,-34.69295722725373,-34.57213540613211,-34.451313585010496,-34.33049176388889,-34.209669942767285,-34.08884812164567,-33.968026300524066,-33.84720447940245,-33.72638265828084,-33.60556083715923,-33.48473901603763,-33.36391719491601,-33.2430953737944,-33.122273552672794,-33.001451731551185,-32.88062991042956,-32.75980808930797,-32.63898626818636,-32.51816444706474,-32.39734262594313,-32.27652080482152,-32.155698983699914,-32.0348771625783,-31.9140553414567,-31.779641531529897,-31.641746883680195,-31.503852235830507,-31.365957587980823,-31.228062940131124,-31.09016829228144,-30.952273644431752,-30.81437899658205,-30.676484348732366,-30.538589700882678,-30.40069505303298,-30.262800405183285,-30.124905757333607,-29.98701110948391,-29.84911646163421,-29.711221813784523,-29.57332716593484,-29.435432518085136,-29.297537870235455,-29.159643222385768,-29.02174857453607,-28.883853926686385,-28.745959278836697,-28.608064630986995,-28.470169983137296,-28.332275335287612,-28.194380687437924,-28.08834031870331,-28.046008508198845,-28.00367669769438,-27.961344887189913,-27.919013076685445,-27.876681266180984,-27.834349455676513,-27.79201764517204,-27.749685834667584,-27.707354024163113,-27.665022213658645,-27.622690403154184,-27.580358592649716,-27.538026782145252,-27.495694971640784,-27.453363161136323,-27.411031350631852,-27.368699540127388,-27.32636772962292,-27.284035919118452,-27.24170410861398,-27.19937229810952,-27.15704048760505,-27.114708677100587,-27.07237686659612,-27.030045056091655,-26.98771324558719,-26.945381435082723,-26.90304962457826,-26.860717814073787,-26.81838600356932,-26.776054193064855,-26.733722382560387,-26.69139057205592,-26.64905876155146,-26.60672695104699,-26.56451382658007,-26.523917896193034,-26.483321965806,-26.442726035418957,-26.402130105031922,-26.361534174644888,-26.320938244257846,-26.28034231387081,-26.239746383483773,-26.19915045309674,-26.158554522709696,-26.11795859232266,-26.077362661935627,-26.03676673154859,-25.996170801161554,-25.955574870774516,-25.914978940387478,-25.874383010000436,-25.83378707961341,-25.793191149226363,-25.752595218839325,-25.71199928845229,-25.671403358065255,-25.630807427678214,-25.590211497291182,-25.549615566904144,-25.509019636517106,-25.468423706130068,-25.427827775743033,-25.387231845355995,-25.346635914968957,-25.306039984581922,-25.265444054194884,-25.224848123807845,-25.184252193420807,-25.143656263033776,-25.103060332646734,-25.062464402259696,-25.02186847187266,-24.98127254148562,-24.940676611098585,-24.900080680711554,-24.859484750324512,-24.81888881993747,-24.778292889550436,-24.7376969591634,-24.697101028776363,-24.628118799965467,-24.417205079035224,-24.206291358104988,-23.995377637174748,-23.784463916244547,-23.573550195314315,-23.36263647438407,-23.15172275345388,-22.940809032523635,-22.729895311593403,-22.5189815906632,-22.308067869732962,-22.097154148802726,-21.88624042787249,-21.67532670694229,-21.464412986012054,-21.253499265081814,-21.042585544151617,-20.831671823221377,-20.620758102291138,-20.40984438136094,-20.198930660430705,-19.98801693950046,-19.777103218570268,-19.566189497640025,-19.363979450141855,-19.17248497790225,-18.98099050566268,-18.789496033423077,-18.598001561183473,-18.406507088943904,-18.2150126167043,-18.023518144464695,-17.832023672225127,-17.640529199985526,-17.44903472774592,-17.257540255506317,-17.06604578326675,-16.874551311027144,-16.68305683878754,-16.49156236654797,-16.30006789430837,-16.108573422068766,-15.917078949829195,-15.72558447758959,-15.534090005349986,-15.342595533110417,-15.151101060870813,-14.95960658863121,-14.768112116391608,-14.576617644152039,-14.385123171912435,-14.193628699672828,-14.00213422743326,-13.810639755193655,-13.619145282954051,-13.427650810714484,-13.23615633847488,-13.044661866235277,-12.862336393302058,-12.683603789495358,-12.504871185688625,-12.326138581881892,-12.147405978075192,-11.968673374268459,-11.789940770461726,-11.611208166655027,-11.432475562848293,-11.253742959041562,-11.075010355234863,-10.89627775142813,-10.717545147621397,-10.538812543814663,-10.360079940007964,-10.181347336201231,-10.002614732394498,-9.8238821285878,-9.645149524781065,-9.466416920974334,-9.287684317167633,-9.108951713360902,-8.930219109554168,-8.751486505747435,-8.572753901940736],[-29.82737172961851,-29.862971758736492,-29.89857178785447,-29.934171816972448,-29.96977184609043,-30.00537187520841,-30.040971904326387,-30.07657193344437,-30.11217196256235,-30.14777199168033,-30.18337202079831,-30.21897204991629,-30.25457207903427,-30.290172108152248,-30.325772137270228,-30.361372166388207,-30.396972195506187,-30.43257222462417,-30.468172253742146,-30.503772282860126,-30.53937231197811,-30.574972341096085,-30.610243234530895,-30.64386844096454,-30.677493647398183,-30.711118853831824,-30.744744060265468,-30.778369266699112,-30.811994473132756,-30.845619679566397,-30.87924488600004,-30.912870092433685,-30.94649529886733,-30.980120505300974,-31.013745711734618,-31.047370918168262,-31.080996124601903,-31.114621331035544,-31.14824653746919,-31.181871743902832,-31.215496950336473,-31.249122156770117,-31.28274736320376,-31.316372569637405,-31.349997776071046,-31.38362298250469,-31.417248188938334,-31.450873395371975,-31.48449860180562,-31.518123808239263,-31.551749014672904,-31.58537422110655,-31.61899942754019,-31.65262463397383,-31.686249840407477,-31.719875046841118,-31.753500253274765,-31.787125459708406,-31.820750666142047,-31.854375872575694,-31.888001079009335,-31.921626285442983,-31.95525149187662,-31.98887669831026,-32.022501904743905,-32.05612711117756,-32.08975231761119,-32.123377524044834,-32.15700273047848,-32.19062793691212,-32.22425314334577,-32.25787834977941,-32.29150355621305,-32.3251287626467,-32.35875396908034,-32.39237917551399,-32.42600438194763,-32.45962958838127,-32.493254794814916,-32.52688000124856,-32.5605052076822,-32.594130414115845,-32.62775562054948,-32.661380826983134,-32.69387948716718,-32.726152838101314,-32.75842618903545,-32.79069953996959,-32.82297289090373,-32.85524624183786,-32.887519592772,-32.91979294370614,-32.952066294640275,-32.98433964557441,-33.01661299650855,-33.04888634744268,-33.08115969837682,-33.113433049310956,-33.145706400245096,-33.17797975117924,-33.21025310211337,-33.2425264530475,-33.274799803981644,-33.307073154915784,-33.33934650584992,-33.37161985678405,-33.40389320771819,-33.436166558652324,-33.468439909586465,-33.5007132605206,-33.53298661145474,-33.56525996238888,-33.59753331332301,-33.62980666425715,-33.662080015191286,-33.694353366125426,-33.72662671705956,-33.75890006799369,-33.79117341892783,-33.82344676986197,-33.85572012079611,-33.88799347173024,-33.920266822664374,-33.952540173598514,-33.984813524532655,-34.017086875466795,-34.04936022640093,-34.08163357733507,-34.1139069282692,-34.14618027920334,-34.178453630137476,-34.210726981071616,-34.24300033200575,-34.27527368293988,-34.30754703387402,-34.33982038480816,-34.3720937357423,-34.40436708667643,-34.43664043761057,-34.468913788544704,-34.501187139478844,-34.533460490412985,-34.56573384134712,-34.59800719228125,-34.63028054321539,-34.663348254803175,-34.697210324742336,-34.73107239468149,-34.764934464620644,-34.798796534559806,-34.83265860449896,-34.86652067443812,-34.90038274437728,-34.934244814316436,-34.9681068842556,-35.00196895419476,-35.03583102413392,-35.069693094073074,-35.103555164012235,-35.13741723395139,-35.17127930389055,-35.20514137382971,-35.239003443768866,-35.27286551370803,-35.30672758364719,-35.34058965358634,-35.374451723525496,-35.40776017337292,-35.44079181317447,-35.47382345297602,-35.50685509277758,-35.53988673257913,-35.572918372380684,-35.605950012182234,-35.63898165198379,-35.67201329178534,-35.7050449315869,-35.73807657138845,-35.771108211190004,-35.804139850991554,-35.837171490793104,-35.87020313059465,-35.90323477039621,-35.93626641019776,-35.96929804999932,-36.00232968980087,-36.035361329602416,-36.06839296940397,-36.10142460920552,-36.13445624900708,-36.16748788880864,-36.20051952861018,-36.23355116841173,-36.266582808213286,-36.29961444801484,-36.33264608781639,-36.366559622304706,-36.40049909500346,-36.434438567702216,-36.46837804040097,-36.502317513099726,-36.53625698579849,-36.570196458497236,-36.60413593119599,-36.638075403894746,-36.672014876593494,-36.705954349292256,-36.739893821991004,-36.77383329468976,-36.807772767388514,-36.84171224008727,-36.87565171278602,-36.90959118548478,-36.94353065818353,-36.97747013088229,-37.01140960358104,-37.0453490762798,-37.07928854897855,-37.1132280216773,-37.14716749437606,-37.18110696707481,-37.215046439773566,-37.24898591247232,-37.282925385171076,-37.31686485786983,-37.350804330568586,-37.38474380326734,-37.41868327596609,-37.45262274866485,-37.4865622213636,-37.52050169406236,-37.554441166761116,-37.588380639459864,-37.62232011215862,-37.656259584857374,-37.690199057556136,-37.72413853025488,-37.75807800295364,-37.7920174756524,-37.82595694835115,-37.8598964210499,-37.89383589374866,-37.92777536644741,-37.96171483914616,-37.995654311844916,-38.02959378454367,-38.06353325724243,-38.09747272994119,-38.131412202639936,-38.1653516753387,-38.12191050112725,-38.00108868000564,-37.88026685888404,-37.75944503776243,-37.638623216640816,-37.51780139551921,-37.396979574397605,-37.27615775327599,-37.15533593215437,-37.03451411103278,-36.91369228991116,-36.79287046878954,-36.672048647667935,-36.55122682654633,-36.43040500542472,-36.30958318430311,-36.188761363181506,-36.06793954205989,-35.94711772093828,-35.82629589981668,-35.70547407869506,-35.584652257573445,-35.46383043645185,-35.343008615330234,-35.22218679420861,-35.10136497308701,-34.980543151965406,-34.85972133084379,-34.73889950972218,-34.61807768860058,-34.497255867478955,-34.37643404635734,-34.25561222523575,-34.13479040411413,-34.01396858299252,-33.89314676187091,-33.77232494074931,-33.65150311962769,-33.53068129850608,-33.40985947738447,-33.28903765626286,-33.168215835141254,-33.04739401401965,-32.92657219289803,-32.80575037177641,-32.68492855065482,-32.56410672953321,-32.44328490841159,-32.32246308728998,-32.20164126616837,-32.08081944504676,-31.959997623925155,-31.839175802803553,-31.718353981681933,-31.597532160560316,-31.476710339438718,-31.355888518317105,-31.235066697195492,-31.114244876073883,-30.99342305495228,-30.872601233830657,-30.751779412709055,-30.63095759158745,-30.510135770465833,-30.389313949344228,-30.26849212822262,-30.147670307101002,-30.026848485979386,-29.90602666485779,-29.785204843736178,-29.66438302261456,-29.543561201492953,-29.422739380371347,-29.3140291903129,-29.207678467261662,-29.101327744210426,-28.99497702115918,-28.888626298107944,-28.782275575056705,-28.67592485200546,-28.569574128954212,-28.463223405902976,-28.356872682851737,-28.27297263316474,-28.233973930206226,-28.194975227247713,-28.15597652428919,-28.11697782133068,-28.077979118372163,-28.038980415413643,-27.999981712455128,-27.960983009496616,-27.9219843065381,-27.88298560357958,-27.843986900621065,-27.804988197662553,-27.765989494704034,-27.72699079174552,-27.68799208878701,-27.64899338582849,-27.60999468286997,-27.57099597991146,-27.530799347334945,-27.490203416947907,-27.449607486560872,-27.409011556173837,-27.368415625786795,-27.32781969539976,-27.287223765012726,-27.246627834625684,-27.206031904238646,-27.165435973851615,-27.124840043464573,-27.08424411307754,-27.043648182690504,-27.00305225230346,-26.962456321916427,-26.921860391529385,-26.88126446114235,-26.840668530755313,-26.80007260036828,-26.759476669981243,-26.7188807395942,-26.678284809207163,-26.637688878820136,-26.597092948433094,-26.556497018046052,-26.515901087659014,-26.475305157271983,-26.43470922688494,-26.394113296497906,-26.35351736611087,-26.31292143572383,-26.272325505336795,-26.23172957494976,-26.19113364456272,-26.15053771417568,-26.10994178378865,-26.069345853401607,-26.02874992301457,-25.98815399262753,-25.947558062240496,-25.906962131853458,-25.866366201466423,-25.82577027107939,-25.785174340692347,-25.744578410305316,-25.703982479918274,-25.663386549531236,-25.622790619144197,-25.582194688757166,-25.541598758370125,-25.501002827983086,-25.460406897596055,-25.419810967209017,-25.379215036821975,-25.33861910643494,-25.298023176047902,-25.257427245660864,-25.216831315273826,-25.176235384886798,-25.135639454499756,-25.095043524112715,-25.054447593725676,-25.013851663338645,-24.973255732951603,-24.904273504140704,-24.693359783210465,-24.48244606228023,-24.271532341349992,-24.060618620419795,-23.849704899489556,-23.638791178559316,-23.42787745762912,-23.21696373669888,-23.006050015768643,-22.795136294838443,-22.584222573908207,-22.373308852977967,-22.162395132047727,-21.951481411117534,-21.740567690187294,-21.529653969257055,-21.318740248326858,-21.107826527396618,-20.896912806466382,-20.685999085536185,-20.475085364605945,-20.26417164367571,-20.05325792274551,-19.84234420181527,-19.63143048088503,-19.420516759954797,-19.209603039024596,-18.998689318094357,-18.78777559716412,-18.579325767315964,-18.381983595888364,-18.18464142446077,-17.98729925303321,-17.789957081605614,-17.592614910178018,-17.39527273875042,-17.19793056732286,-17.000588395895264,-16.803246224467667,-16.605904053040106,-16.40856188161251,-16.211219710184913,-16.013877538757352,-15.816535367329756,-15.61919319590216,-15.421851024474599,-15.224508853047002,-15.027166681619406,-14.82982451019181,-14.632482338764248,-14.435140167336652,-14.237797995909055,-14.040455824481494,-13.861446280815924,-13.682713677009193,-13.503981073202493,-13.325248469395756,-13.146515865589025,-12.967783261782294,-12.789050657975595,-12.61031805416886,-12.431585450362128,-12.252852846555427,-12.074120242748696,-11.895387638941962,-11.716655035135265,-11.53792243132853,-11.359189827521796,-11.180457223715099,-11.001724619908366,-10.822992016101633,-10.644259412294899,-10.465526808488201,-10.286794204681467,-10.108061600874734,-9.929328997068035,-9.750596393261302,-9.57186378945457,-9.393131185647869,-9.214398581841138,-9.035665978034404,-8.85693337422767,-8.678200770420972],[-29.42913816159502,-29.464738190713,-29.500338219830976,-29.53593824894896,-29.57153827806694,-29.60713830718492,-29.641421788951714,-29.675046995385358,-29.708672201819002,-29.742297408252647,-29.77592261468629,-29.80954782111993,-29.843173027553576,-29.876798233987216,-29.910423440420857,-29.9440486468545,-29.977673853288145,-30.01129905972179,-30.04492426615543,-30.078549472589074,-30.11217467902272,-30.145799885456363,-30.179425091890003,-30.213050298323648,-30.24667550475729,-30.280300711190932,-30.313925917624577,-30.34755112405822,-30.38117633049186,-30.414801536925502,-30.44842674335915,-30.48205194979279,-30.515677156226438,-30.54930236266008,-30.58292756909372,-30.616552775527367,-30.650177981961008,-30.68380318839465,-30.717428394828293,-30.751053601261937,-30.784678807695578,-30.81830401412922,-30.851929220562866,-30.88555442699651,-30.919179633430154,-30.952804839863795,-30.986430046297443,-31.020055252731076,-31.05368045916472,-31.087305665598365,-31.120930872032005,-31.154556078465653,-31.188181284899294,-31.221806491332934,-31.255431697766582,-31.289056904200223,-31.32268211063387,-31.35630731706751,-31.38993252350115,-31.4235577299348,-31.45718293636844,-31.490808142802088,-31.52443334923572,-31.558058555669366,-31.59168376210301,-31.625308968536658,-31.6589341749703,-31.69255938140394,-31.726184587837587,-31.759809794271227,-31.793435000704875,-31.827060207138516,-31.860685413572156,-31.894310620005804,-31.927935826439445,-31.961561032873092,-31.995186239306733,-32.028811445740374,-32.06243665217402,-32.09606185860766,-32.12968706504131,-32.16331227147494,-32.196937477908584,-32.23056268434223,-32.263061344526285,-32.295334695460426,-32.32760804639456,-32.35988139732869,-32.39215474826283,-32.424428099196966,-32.456701450131106,-32.48897480106524,-32.52124815199938,-32.55352150293352,-32.585794853867654,-32.61806820480179,-32.650341555735935,-32.68261490667007,-32.7148882576042,-32.74716160853834,-32.779434959472475,-32.811708310406615,-32.84398166134075,-32.87625501227489,-32.90852836320902,-32.94080171414316,-32.973075065077296,-33.00534841601143,-33.03762176694557,-33.0698951178797,-33.102168468813844,-33.13444181974798,-33.16671517068212,-33.19898852161626,-33.23126187255039,-33.26353522348453,-33.295808574418665,-33.3280819253528,-33.36035527628694,-33.39262862722107,-33.42490197815521,-33.45717532908935,-33.489448680023486,-33.52172203095762,-33.55399538189176,-33.5862687328259,-33.61854208376003,-33.650815434694174,-33.68308878562831,-33.71536213656245,-33.74763548749658,-33.77990883843072,-33.812182189364854,-33.844455540298995,-33.87672889123313,-33.90900224216726,-33.9412755931014,-33.97354894403554,-34.005822294969676,-34.03809564590381,-34.07036899683795,-34.10264234777209,-34.13491569870622,-34.16718904964036,-34.1994624005745,-34.23173575150864,-34.26400910244277,-34.29628245337691,-34.328555804311044,-34.360829155245185,-34.39310250617932,-34.42537585711346,-34.45764920804759,-34.489922558981725,-34.522195909915865,-34.55446926085,-34.58674261178413,-34.61901596271827,-34.65128931365241,-34.683562664586546,-34.715836015520686,-34.748109367343815,-34.78197143728298,-34.81583350722213,-34.8496955771613,-34.88355764710045,-34.917419717039614,-34.95072816688703,-34.983759806688575,-35.01679144649014,-35.04982308629169,-35.082854726093245,-35.115886365894795,-35.148918005696345,-35.182546220914126,-35.21648569361288,-35.25042516631163,-35.284364639010384,-35.31830411170914,-35.352243584407894,-35.38618305710665,-35.420122529805404,-35.45406200250416,-35.48800147520291,-35.52194094790167,-35.555880420600424,-35.58981989329918,-35.62375936599793,-35.65769883869668,-35.69163831139544,-35.7255777840942,-35.75951725679295,-35.7934567294917,-35.82739620219046,-35.86133567488921,-35.89527514758797,-35.92921462028672,-35.96315409298548,-35.99709356568423,-36.031033038382986,-36.064972511081734,-36.098911983780496,-36.132851456479244,-36.166790929178006,-36.200730401876754,-36.23466987457551,-36.268609347274264,-36.30254881997301,-36.336488292671774,-36.37042776537053,-36.404367238069284,-36.43830671076804,-36.472246183466794,-36.50618565616554,-36.5401251288643,-36.57406460156305,-36.608004074261814,-36.64194354696056,-36.67588301965931,-36.70982249235807,-36.74376196505683,-36.77770143775558,-36.81164091045433,-36.84558038315309,-36.87951985585184,-36.9134593285506,-36.94739880124935,-36.98133827394811,-37.01527774664686,-37.04921721934562,-37.08315669204437,-37.117096164743124,-37.15103563744188,-37.184975110140634,-37.21891458283939,-37.252854055538144,-37.2867935282369,-37.320733000935654,-37.35467247363441,-37.388611946333164,-37.42255141903191,-37.45649089173067,-37.49043036442942,-37.52436983712818,-37.55830930982693,-37.59224878252569,-37.62618825522444,-37.6601277279232,-37.69406720062195,-37.72800667332071,-37.684565499109276,-37.56374367798766,-37.44292185686605,-37.32210003574444,-37.20127821462283,-37.08045639350122,-36.95963457237962,-36.838812751258,-36.71799093013639,-36.59716910901479,-36.47634728789317,-36.35552546677156,-36.23470364564995,-36.11388182452834,-35.99306000340673,-35.87223818228512,-35.751416361163514,-35.630594540041905,-35.509772718920296,-35.38895089779869,-35.26812907667707,-35.147307255555454,-35.026485434433866,-34.90566361331224,-34.784841792190626,-34.664019971069024,-34.543198149947415,-34.4223763288258,-34.301554507704196,-34.18073268658259,-34.05991086546098,-33.94034737066612,-33.83399664761489,-33.727645924563646,-33.621295201512396,-33.51494447846115,-33.408593755409925,-33.302243032358675,-33.19589230930743,-33.0895415862562,-32.98319086320495,-32.87684014015372,-32.770489417102475,-32.66413869405123,-32.55778797099998,-32.45143724794876,-32.34508652489751,-32.23873580184626,-32.132385078795025,-32.02603435574379,-31.919683632692543,-31.813332909641304,-31.706982186590068,-31.600631463538818,-31.494280740487575,-31.387930017436343,-31.281579294385097,-31.175228571333847,-31.068877848282614,-30.96252712523138,-30.856176402180125,-30.749825679128893,-30.643474956077657,-30.53712423302641,-30.43077350997517,-30.324422786923936,-30.21807206387269,-30.11172134082144,-30.005370617770215,-29.89901989471897,-29.79266917166772,-29.68631844861648,-29.579967725565247,-29.473617002513997,-29.367266279462758,-29.260915556411526,-29.154564833360276,-29.04821411030904,-28.941863387257804,-28.835512664206554,-28.729161941155304,-28.62281121810407,-28.516460495052833,-28.432560445365834,-28.39356174240732,-28.354563039448806,-28.31556433649029,-28.276565633531774,-28.23756693057326,-28.198568227614743,-28.15956952465622,-28.12057082169771,-28.081572118739196,-28.04257341578068,-28.003574712822164,-27.96457600986365,-27.92557730690513,-27.886578603946614,-27.8475799009881,-27.808581198029582,-27.76958249507107,-27.730583792112558,-27.69158508915404,-27.652586386195523,-27.613587683237007,-27.57458898027849,-27.535590277319972,-27.49659157436146,-27.457592871402944,-27.418594168444425,-27.379595465485913,-27.340596762527397,-27.30159805956888,-27.262599356610362,-27.22360065365185,-27.18460195069333,-27.145603247734815,-27.1066045447763,-27.067605841817787,-27.028607138859268,-26.989608435900756,-26.95060973294224,-26.911611029983725,-26.872612327025205,-26.833613624066693,-26.794614921108174,-26.755616218149658,-26.716617515191142,-26.677618812232627,-26.63862010927411,-26.599621406315592,-26.560622703357083,-26.521624000398564,-26.482625297440045,-26.443626594481533,-26.404627891523017,-26.365629188564498,-26.326630485605993,-26.287631782647466,-26.248633079688954,-26.209634376730442,-26.17063567377192,-26.131636970813403,-26.09263826785489,-26.053639564896375,-26.01464086193786,-25.975642158979344,-25.936643456020832,-25.897644753062313,-25.858646050103793,-25.819647347145285,-25.780648644186765,-25.741649941228246,-25.702651238269734,-25.663652535311215,-25.624653832352703,-25.585655129394187,-25.54665642643567,-25.507657723477152,-25.468659020518636,-25.429660317560128,-25.39106726069697,-25.353179679221242,-25.315292097745512,-25.27740451626979,-25.239516934794054,-25.173188874070217,-24.964658417105788,-24.75612796014136,-24.54813028896392,-24.35078811753636,-24.153445946108764,-23.956103774681168,-23.758761603253607,-23.561419431826007,-23.364077260398414,-23.166735088970853,-22.969392917543253,-22.77205074611566,-22.574708574688064,-22.377366403260503,-22.180024231832906,-21.98268206040531,-21.78533988897775,-21.587997717550152,-21.390655546122552,-21.193313374694995,-20.9959712032674,-20.798629031839802,-20.601286860412237,-20.403944688984648,-20.206602517557048,-20.009260346129455,-19.811918174701894,-19.614576003274294,-19.417233831846698,-19.219891660419137,-19.02254948899154,-18.825207317563944,-18.627865146136386,-18.430522974708786,-18.233180803281194,-18.035838631853593,-17.838496460426036,-17.64115428899844,-17.44381211757084,-17.24646994614328,-17.049127774715682,-16.851785603288086,-16.654443431860525,-16.457101260432932,-16.259759089005335,-16.062416917577774,-15.865074746150176,-15.66773257472258,-15.470390403294981,-15.273048231867422,-15.075706060439826,-14.878363889012231,-14.68102171758467,-14.483679546157072,-14.286337374729476,-14.088995203301915,-13.891653031874318,-13.694310860446722,-13.496968689019125,-13.299626517591564,-13.102284346163966,-12.90494217473637,-12.70760000330881,-12.510257831881212,-12.312915660453617,-12.11557348902606,-11.918231317598462,-11.720889146170865,-11.523546974743304,-11.326204803315708,-11.128862631888113,-10.931520460460517,-10.734178289032956,-10.53683611760536,-10.339493946177761,-10.142151774750202,-9.944809603322604,-9.747467431895007,-9.550125260467448,-9.353693779719029,-9.164001469068715,-8.9743091584184,-8.784616847768122],[-29.023191177763195,-29.054751308398842,-29.08631143903449,-29.11787156967014,-29.149431700305787,-29.180991830941434,-29.21255196157708,-29.24411209221273,-29.275672222848378,-29.307232353484025,-29.338792484119672,-29.37035261475532,-29.403633642704104,-29.43725884913775,-29.47088405557139,-29.504509262005033,-29.538134468438678,-29.57175967487232,-29.605384881305962,-29.639010087739607,-29.672635294173247,-29.706260500606895,-29.739885707040536,-29.773510913474176,-29.80713611990782,-29.84076132634146,-29.874386532775105,-29.90801173920875,-29.941636945642394,-29.975262152076034,-30.00888735850968,-30.042512564943323,-30.076137771376967,-30.10976297781061,-30.14338818424425,-30.177013390677892,-30.21063859711154,-30.24426380354518,-30.27788900997883,-30.31151421641247,-30.34513942284611,-30.378764629279758,-30.412389835713398,-30.44601504214704,-30.479640248580683,-30.513265455014327,-30.546890661447968,-30.580515867881616,-30.614141074315256,-30.647766280748897,-30.681391487182545,-30.715016693616185,-30.748641900049826,-30.78226710648347,-30.815892312917118,-30.84951751935076,-30.883142725784403,-30.916767932218043,-30.950393138651688,-30.984018345085328,-31.01764355151897,-31.051268757952617,-31.084893964386257,-31.118519170819898,-31.152144377253546,-31.18576958368719,-31.21939479012083,-31.253019996554475,-31.28664520298812,-31.320270409421763,-31.353895615855407,-31.387520822289048,-31.421146028722692,-31.454771235156336,-31.488396441589977,-31.52202164802362,-31.555646854457265,-31.589272060890906,-31.622897267324547,-31.65652247375819,-31.690147680191835,-31.723772886625476,-31.75739809305912,-31.791023299492764,-31.823521959676818,-31.855795310610958,-31.88806866154509,-31.920342012479228,-31.952615363413365,-31.9848887143475,-32.01716206528164,-32.04943541621577,-32.08170876714991,-32.113982118084046,-32.146255469018186,-32.17852881995232,-32.21080217088647,-32.2430755218206,-32.27534887275473,-32.307622223688874,-32.339895574623014,-32.37216892555715,-32.40444227649128,-32.43671562742542,-32.468988978359555,-32.501262329293695,-32.53353568022783,-32.56580903116196,-32.5980823820961,-32.63035573303024,-32.662629083964376,-32.69490243489851,-32.72717578583265,-32.75944913676679,-32.79172248770092,-32.823995838635064,-32.8562691895692,-32.88854254050333,-32.92081589143747,-32.953089242371604,-32.98536259330575,-33.017635944239885,-33.04990929517402,-33.08218264610815,-33.11445599704229,-33.14672934797643,-33.179002698910566,-33.2112760498447,-33.24354940077884,-33.27582275171298,-33.30809610264711,-33.34036945358125,-33.37264280451539,-33.40491615544953,-33.43718950638366,-33.469462857317794,-33.501736208251934,-33.53400955918607,-33.56628291012021,-33.59855626105434,-33.63082961198848,-33.663102962922615,-33.695376313856755,-33.72764966479089,-33.75992301572503,-33.79219636665916,-33.8244697175933,-33.856743068527436,-33.88901641946157,-33.92128977039572,-33.95356312132985,-33.98583647226399,-34.018109823198124,-34.05038317413226,-34.0826565250664,-34.11492987600053,-34.14569707747956,-34.17616304821181,-34.206629018944064,-34.23709498967631,-34.26756096040856,-34.29802693114081,-34.328492901873055,-34.35895887260531,-34.38942484333756,-34.41989081406981,-34.450356784802054,-34.48326554349826,-34.51739569617644,-34.551525848854624,-34.585656001532804,-34.619786154210985,-34.653916306889165,-34.68804645956735,-34.722176612245526,-34.756306764923714,-34.79043691760189,-34.824567070280075,-34.858697222958256,-34.892827375636436,-34.92695752831462,-34.9610876809928,-34.99521783367098,-35.029347986349165,-35.063478139027346,-35.09760829170553,-35.13173844438371,-35.16586859706189,-35.19999874974007,-35.23412890241825,-35.268259055096436,-35.30238920777461,-35.3365193604528,-35.37064951313098,-35.40477966580916,-35.43890981848734,-35.47303997116553,-35.50717012384371,-35.54130027652189,-35.57543042920007,-35.60956058187825,-35.64369073455643,-35.67782088723462,-35.71195103991279,-35.74608119259098,-35.78021134526915,-35.81434149794734,-35.84847165062552,-35.88260180330369,-35.91673195598188,-35.95086210866007,-35.98499226133824,-36.01912241401642,-36.0532525666946,-36.08738271937278,-36.12151287205097,-36.15564302472916,-36.18977317740733,-36.22390333008552,-36.25803348276369,-36.292163635441874,-36.32629378812006,-36.36042394079824,-36.39455409347642,-36.42868424615461,-36.46281439883278,-36.496944551510964,-36.531074704189145,-36.565204856867325,-36.59933500954551,-36.63346516222369,-36.667595314901874,-36.701725467580054,-36.735855620258235,-36.769985772936415,-36.8041159256146,-36.838246078292784,-36.872376230970964,-36.906506383649145,-36.940636536327325,-36.974766689005506,-37.008896841683686,-37.043026994361874,-37.077157147040054,-37.111287299718235,-37.145417452396416,-37.17875250339344,-37.21190047111765,-37.24504843884186,-37.27819640656607,-37.24536815215477,-37.14656367560796,-37.04775919906116,-36.94895472251437,-36.850150245967555,-36.75134576942076,-36.65254129287396,-36.55373681632716,-36.454932339780356,-36.35612786323356,-36.25732338668676,-36.158518910139954,-36.05971443359316,-35.960909957046354,-35.86210548049955,-35.763301003952755,-35.66449652740596,-35.56569205085915,-35.46688757431235,-35.36808309776555,-35.269278621218746,-35.16344241337962,-35.05709169032839,-34.95074096727715,-34.8443902442259,-34.73803952117466,-34.63168879812343,-34.525338075072185,-34.41898735202094,-34.312636628969706,-34.206285905918456,-34.09993518286721,-33.993584459815985,-33.887233736764735,-33.78088301371349,-33.67453229066225,-33.56818156761102,-33.46183084455977,-33.35548012150853,-33.24912939845729,-33.14277867540605,-33.03642795235481,-32.93007722930358,-32.82372650625233,-32.71737578320108,-32.611025060149856,-32.504674337098606,-32.39832361404736,-32.29197289099612,-32.185622167944885,-32.079271444893635,-31.9729207218424,-31.866569998791164,-31.760219275739917,-31.653868552688667,-31.547517829637442,-31.441167106586192,-31.33481638353495,-31.22846566048371,-31.122114937432475,-31.015764214381228,-30.90941349132999,-30.803062768278753,-30.696712045227503,-30.590361322176264,-30.48401059912503,-30.377659876073785,-30.271309153022536,-30.16495842997131,-30.05860770692006,-29.952256983868814,-29.845906260817575,-29.739555537766343,-29.633204814715093,-29.526854091663854,-29.420503368612618,-29.31415264556137,-29.207801922510136,-29.1014511994589,-28.99510047640765,-28.888749753356404,-28.782399030305164,-28.67604830725393,-28.59214825756693,-28.553149554608417,-28.514150851649898,-28.475152148691386,-28.43615344573287,-28.397154742774354,-28.35815603981584,-28.319157336857316,-28.280158633898807,-28.24115993094029,-28.202161227981776,-28.16316252502326,-28.124163822064745,-28.085165119106225,-28.046166416147713,-28.007167713189197,-27.968169010230678,-27.929170307272166,-27.89017160431365,-27.851172901355135,-27.81217419839661,-27.773175495438096,-27.734176792479587,-27.695178089521068,-27.656179386562556,-27.61718068360404,-27.57818198064552,-27.53918327768701,-27.500184574728493,-27.46118587176997,-27.42218716881146,-27.383188465852943,-27.34418976289443,-27.30579512345028,-27.26790754197455,-27.23001996049883,-27.192132379023093,-27.154244797547367,-27.11635721607164,-27.07846963459591,-27.040582053120183,-27.002694471644453,-26.964806890168724,-26.926919308692995,-26.889031727217265,-26.85114414574154,-26.81325656426581,-26.775368982790084,-26.737481401314355,-26.699593819838622,-26.661706238362896,-26.623818656887167,-26.585931075411438,-26.548043493935708,-26.510155912459986,-26.47226833098425,-26.43438074950852,-26.39649316803279,-26.358605586557065,-26.320718005081336,-26.28283042360561,-26.24494284212988,-26.20705526065415,-26.169167679178422,-26.131280097702696,-26.093392516226963,-26.055504934751234,-26.01761735327551,-25.979729771799782,-25.941842190324046,-25.90395460884832,-25.866067027372594,-25.828179445896865,-25.790291864421135,-25.752404282945406,-25.714516701469677,-25.676629119993947,-25.63874153851822,-25.600853957042492,-25.56296637556676,-25.525078794091037,-25.487191212615308,-25.44930363113958,-25.382975570415738,-25.174445113451306,-24.965914656486884,-24.757384199522452,-24.548853742558066,-24.340323285593634,-24.131792828629212,-23.92326237166482,-23.714731914700394,-23.506201457735965,-23.297671000771576,-23.089140543807147,-22.880610086842722,-22.672079629878297,-22.463549172913904,-22.25501871594948,-22.046488258985054,-21.837957802020664,-21.629427345056236,-21.420896888091807,-21.212366431127418,-21.00383597416299,-20.795305517198564,-20.586775060234174,-20.37824460326975,-20.16971414630532,-19.961183689340892,-19.752653232376503,-19.544122775412077,-19.33559231844765,-19.12706186148326,-18.929053727930874,-18.731711556503278,-18.534369385075717,-18.33702721364812,-18.13968504222052,-17.942342870792928,-17.745000699365367,-17.54765852793777,-17.350316356510174,-17.152974185082613,-16.955632013655016,-16.75828984222742,-16.56094767079986,-16.363605499372262,-16.166263327944666,-15.968921156517105,-15.771578985089509,-15.574236813661912,-15.376894642234316,-15.179552470806755,-14.982210299379158,-14.784868127951562,-14.589256277217261,-14.399563966566946,-14.209871655916633,-14.020179345266357,-13.830487034616041,-13.64079472396573,-13.451102413315414,-13.261410102665138,-13.071717792014823,-12.882025481364511,-12.692333170714234,-12.50264086006392,-12.312948549413608,-12.123256238763329,-11.933563928113015,-11.743871617462702,-11.554179306812422,-11.364486996162109,-11.174794685511795,-10.985102374861484,-10.795410064211204,-10.605717753560892,-10.416025442910579,-10.2263331322603,-10.036640821609986,-9.846948510959674,-9.657256200309396,-9.467563889659083,-9.27787157900877,-9.088179268358456,-8.898486957708178],[-28.613560173924142,-28.64512030455979,-28.676680435195436,-28.708240565831083,-28.73980069646673,-28.77136082710238,-28.802920957738028,-28.834481088373675,-28.866041219009325,-28.897601349644972,-28.92916148028062,-28.960721610916266,-28.992281741551913,-29.02384187218756,-29.05540200282321,-29.086962133458858,-29.1185222640945,-29.15008239473015,-29.1816425253658,-29.21320265600145,-29.244762786637093,-29.276322917272743,-29.307883047908387,-29.33944317854404,-29.371003309179684,-29.402563439815335,-29.43412357045098,-29.46568370108663,-29.49793219079568,-29.53155739722932,-29.565182603662965,-29.59880781009661,-29.632433016530253,-29.666058222963898,-29.699683429397535,-29.73330863583118,-29.766933842264827,-29.800559048698464,-29.83418425513211,-29.867809461565752,-29.901434667999396,-29.93505987443304,-29.96868508086668,-30.002310287300325,-30.035935493733966,-30.06956070016761,-30.103185906601254,-30.1368111130349,-30.17043631946854,-30.204061525902183,-30.237686732335828,-30.271311938769472,-30.304937145203112,-30.338562351636753,-30.3721875580704,-30.40581276450404,-30.43943797093769,-30.47306317737133,-30.50668838380497,-30.54031359023862,-30.57393879667226,-30.6075640031059,-30.641189209539544,-30.674814415973188,-30.70843962240683,-30.742064828840476,-30.775690035274117,-30.809315241707758,-30.842940448141405,-30.876565654575046,-30.91019086100869,-30.94381606744233,-30.977441273875975,-31.01106648030962,-31.044691686743263,-31.078316893176904,-31.11194209961055,-31.145567306044192,-31.179192512477833,-31.212817718911477,-31.24644292534512,-31.280068131778762,-31.313693338212406,-31.34731854464605,-31.379817204830097,-31.412090555764237,-31.44436390669837,-31.47663725763251,-31.508910608566644,-31.541183959500785,-31.573457310434925,-31.60573066136906,-31.6380040123032,-31.670277363237332,-31.702550714171473,-31.734824065105606,-31.767097416039746,-31.79937076697388,-31.83164411790802,-31.863917468842153,-31.896190819776294,-31.928464170710427,-31.960737521644567,-31.9930108725787,-32.02528422351284,-32.057557574446975,-32.089830925381115,-32.12210427631525,-32.15437762724939,-32.18665097818352,-32.218924329117655,-32.251197680051796,-32.283471030985936,-32.31574438192007,-32.34801773285421,-32.38029108378834,-32.412564434722476,-32.44483778565662,-32.47711113659076,-32.50938448752489,-32.54165783845903,-32.573931189393164,-32.6062045403273,-32.63847789126144,-32.67075124219557,-32.70302459312971,-32.73529794406385,-32.767571294997985,-32.799844645932126,-32.83211799686626,-32.86439134780039,-32.89666469873453,-32.928938049668666,-32.961211400602814,-32.99348475153695,-33.02575810247108,-33.05803145340522,-33.090304804339354,-33.122578155273494,-33.15424904655525,-33.184715017287495,-33.21518098801974,-33.24564695875199,-33.27611292948424,-33.30657890021649,-33.337044870948745,-33.36751084168099,-33.39797681241324,-33.428442783145485,-33.458908753877736,-33.48937472460999,-33.51984069534224,-33.55030666607449,-33.58077263680674,-33.611238607538986,-33.64170457827124,-33.67217054900348,-33.702636519735734,-33.733102490467985,-33.76356846120024,-33.79403443193249,-33.82450040266473,-33.854966373396984,-33.88543234412923,-33.91589831486149,-33.94636428559373,-33.97683025632598,-34.009739015022184,-34.043869167700365,-34.077999320378545,-34.112129473056726,-34.14625962573491,-34.180389778413094,-34.214519931091274,-34.248650083769455,-34.282780236447636,-34.316910389125816,-34.351040541804,-34.385170694482184,-34.41930084716036,-34.453430999838545,-34.487561152516726,-34.521691305194906,-34.555821457873094,-34.58995161055127,-34.624081763229455,-34.65821191590763,-34.69234206858581,-34.726472221264,-34.76060237394218,-34.79473252662036,-34.82886267929854,-34.862992831976726,-34.8971229846549,-34.93125313733309,-34.96538329001127,-34.99951344268945,-35.03364359536763,-35.06777374804581,-35.10190390072399,-35.13603405340217,-35.17016420608035,-35.20429435875853,-35.23842451143672,-35.2725546641149,-35.30668481679308,-35.34081496947126,-35.37494512214944,-35.40907527482762,-35.4432054275058,-35.47733558018399,-35.51146573286217,-35.54559588554035,-35.579726038218524,-35.61385619089671,-35.64798634357489,-35.68211649625308,-35.71624664893126,-35.750376801609434,-35.78450695428762,-35.8186371069658,-35.85276725964398,-35.88689741232217,-35.921027565000344,-35.95515771767853,-35.98928787035671,-36.02341802303489,-36.05754817571307,-36.09081307046446,-36.123961038188675,-36.15710900591288,-36.19025697363709,-36.2234049413613,-36.25655290908551,-36.28970087680972,-36.32284884453392,-36.35599681225813,-36.38914477998234,-36.42229274770655,-36.455440715430754,-36.488588683154966,-36.52173665087918,-36.55488461860338,-36.58803258632759,-36.6211805540518,-36.65432852177601,-36.68747648950021,-36.720624457224424,-36.75377242494863,-36.78692039267284,-36.75409213826154,-36.65528766171474,-36.556483185167934,-36.45767870862114,-36.35887423207433,-36.26006975552754,-36.161265278980736,-36.062460802433925,-35.96365632588712,-35.86485184934033,-35.76604737279353,-35.66724289624672,-35.56843841969992,-35.46963394315313,-35.370829466606324,-35.27202499005952,-35.173220513512724,-35.074416036965914,-34.975611560419125,-34.87680708387232,-34.77800260732552,-34.679198130778715,-34.580393654231926,-34.481589177685116,-34.38278470113831,-34.28398022459152,-34.18517574804471,-34.0863712714979,-33.98756679495111,-33.88876231840431,-33.78995784185751,-33.6911533653107,-33.59234888876391,-33.493544412217105,-33.3947399356703,-33.2959354591235,-33.1971309825767,-33.0983265060299,-32.9995220294831,-32.9007175529363,-32.801913076389496,-32.7031085998427,-32.6043041232959,-32.50549964674909,-32.40669517020228,-32.3078906936555,-32.2090862171087,-32.11028174056189,-32.011477264015085,-31.91267278746829,-31.81386831092148,-31.715063834374686,-31.616259357827893,-31.517454881281086,-31.41865040473428,-31.319845928187483,-31.221041451640684,-31.122236975093877,-31.02343249854708,-30.924628022000277,-30.82582354545347,-30.727019068906678,-30.62821459235988,-30.52941011581307,-30.430605639266275,-30.331801162719476,-30.232996686172672,-30.134192209625866,-30.035387733079077,-29.93658325653227,-29.837778779985463,-29.738974303438667,-29.640169826891867,-29.54136535034506,-29.442560873798264,-29.343756397251465,-29.250422240330078,-29.17591226486773,-29.101402289405378,-29.026892313943023,-28.952382338480668,-28.87787236301832,-28.80336238755597,-28.74142546223147,-28.704634637182668,-28.667843812133867,-28.631052987085063,-28.59426216203626,-28.557471336987454,-28.52068051193865,-28.48388968688985,-28.44709886184105,-28.41030803679224,-28.373517211743437,-28.336726386694636,-28.299935561645835,-28.26314473659703,-28.22635391154823,-28.189563086499422,-28.152772261450618,-28.115981436401817,-28.079190611353017,-28.042399786304212,-28.005608961255408,-27.968818136206604,-27.9320273111578,-27.89445763455308,-27.856570053077355,-27.81868247160163,-27.780794890125897,-27.742907308650167,-27.70501972717445,-27.667132145698716,-27.62924456422298,-27.591356982747254,-27.553469401271528,-27.5155818197958,-27.47769423832007,-27.43980665684434,-27.40191907536861,-27.364031493892885,-27.32614391241716,-27.28825633094143,-27.2503687494657,-27.21248116798997,-27.174593586514238,-27.13670600503851,-27.098818423562783,-27.060930842087053,-27.023043260611324,-26.985155679135595,-26.947268097659865,-26.90938051618414,-26.871492934708414,-26.833605353232684,-26.795717771756955,-26.757830190281222,-26.7199426088055,-26.682055027329767,-26.644167445854038,-26.60627986437831,-26.568392282902582,-26.53050470142685,-26.492617119951127,-26.454729538475394,-26.416841956999665,-26.37895437552394,-26.34106679404821,-26.30317921257248,-26.265291631096748,-26.227404049621025,-26.189516468145296,-26.151628886669563,-26.113741305193837,-26.07585372371811,-26.03796614224238,-26.000078560766646,-25.962190979290924,-25.924303397815194,-25.886415816339465,-25.848528234863736,-25.810640653388006,-25.772753071912273,-25.734865490436547,-25.69697790896082,-25.659090327485092,-25.59276226676125,-25.384231809796827,-25.175701352832395,-24.96717089586797,-24.75864043890358,-24.55010998193915,-24.341579524974723,-24.133049068010337,-23.92451861104591,-23.715988154081483,-23.50745769711709,-23.298927240152665,-23.090396783188236,-22.88186632622381,-22.67333586925942,-22.464805412294993,-22.256274955330568,-22.04774449836618,-21.83921404140175,-21.63068358443732,-21.42215312747293,-21.213622670508506,-21.005092213544078,-20.796561756579692,-20.595604626315957,-20.394976774754493,-20.194348923193033,-19.993721071631608,-19.793093220070144,-19.59246536850868,-19.39183751694726,-19.191209665385795,-18.99058181382434,-18.78995396226291,-18.58932611070145,-18.388698259139986,-18.188070407578522,-17.9874425560171,-17.786814704455637,-17.586186852894176,-17.38555900133275,-17.184931149771288,-16.984303298209824,-16.7836754466484,-16.58304759508694,-16.382419743525475,-16.18179189196405,-15.98116404040259,-15.780536188841126,-15.579908337279663,-15.37928048571824,-15.178652634156776,-14.978024782595314,-14.77739693103389,-14.576769079472427,-14.376141227910965,-14.17551337634954,-13.974885524788078,-13.774257673226614,-13.573629821665154,-13.375280212605192,-13.185587901954875,-12.995895591304564,-12.806203280654284,-12.616510970003972,-12.42681865935366,-12.23712634870338,-12.04743403805307,-11.857741727402754,-11.668049416752476,-11.478357106102163,-11.288664795451849,-11.098972484801536,-10.909280174151258,-10.719587863500944,-10.529895552850633,-10.340203242200353,-10.150510931550041,-9.960818620899726,-9.771126310249448,-9.581433999599135,-9.391741688948823,-9.202049378298508,-9.01235706764823],[-28.203929170085086,-28.235489300720737,-28.267049431356384,-28.29860956199203,-28.330169692627678,-28.361729823263325,-28.39328995389897,-28.424850084534622,-28.45641021517027,-28.48797034580592,-28.519530476441567,-28.551090607077214,-28.58265073771286,-28.614210868348508,-28.645770998984155,-28.6773311296198,-28.70889126025545,-28.740451390891096,-28.772011521526743,-28.803571652162397,-28.835131782798037,-28.86669191343369,-28.898252044069334,-28.929812174704985,-28.96137230534063,-28.992932435976282,-29.024492566611926,-29.056052697247573,-29.08761282788322,-29.119172958518867,-29.150733089154517,-29.182293219790164,-29.21385335042581,-29.24541348106146,-29.27697361169711,-29.308533742332756,-29.340093872968403,-29.37165400360405,-29.4032141342397,-29.434774264875347,-29.466334395510994,-29.49789452614664,-29.52945465678229,-29.56101478741794,-29.592574918053586,-29.625855945320893,-29.659481151754537,-29.69310635818818,-29.726731564621822,-29.760356771055466,-29.79398197748911,-29.827607183922755,-29.861232390356395,-29.89485759679004,-29.928482803223684,-29.962108009657328,-29.99573321609097,-30.029358422524613,-30.062983628958257,-30.096608835391898,-30.13023404182554,-30.163859248259186,-30.197484454692827,-30.231109661126467,-30.264734867560115,-30.298360073993756,-30.3319852804274,-30.365610486861044,-30.399235693294685,-30.432860899728325,-30.466486106161973,-30.500111312595614,-30.533736519029254,-30.567361725462902,-30.600986931896543,-30.63461213833019,-30.66823734476383,-30.701862551197472,-30.735487757631116,-30.76911296406476,-30.802738170498404,-30.836363376932045,-30.86998858336569,-30.90361378979933,-30.936112449983383,-30.968385800917524,-31.000659151851657,-31.032932502785798,-31.065205853719934,-31.097479204654068,-31.129752555588205,-31.16202590652234,-31.19429925745648,-31.226572608390615,-31.258845959324756,-31.29111931025889,-31.32339266119303,-31.355666012127166,-31.387939363061307,-31.42021271399544,-31.452486064929573,-31.484759415863714,-31.517032766797847,-31.549306117731987,-31.581579468666124,-31.61385281960026,-31.646126170534398,-31.678399521468535,-31.71067287240267,-31.74294622333681,-31.775219574270945,-31.807492925205082,-31.839766276139216,-31.872039627073356,-31.90431297800749,-31.936586328941626,-31.968859679875763,-32.001133030809896,-32.03340638174404,-32.06567973267817,-32.09795308361232,-32.13022643454645,-32.16249978548058,-32.19326698636318,-32.22373295709543,-32.25419892782767,-32.284664898559924,-32.315130869292176,-32.34559684002443,-32.37606281075667,-32.40652878148892,-32.436994752221175,-32.46746072295342,-32.49792669368567,-32.52839266441792,-32.55885863515017,-32.589324605882425,-32.61979057661467,-32.65025654734692,-32.68072251807917,-32.711188488811416,-32.74165445954367,-32.77212043027592,-32.80258640100816,-32.83305237174042,-32.863518342472666,-32.89398431320492,-32.92445028393716,-32.95491625466941,-32.985382225401665,-33.01584819613391,-33.04631416686616,-33.07678013759841,-33.107246108330656,-33.13771207906291,-33.16817804979516,-33.19864402052741,-33.22910999125966,-33.25957596199191,-33.29004193272416,-33.3205079034564,-33.350973874188654,-33.381439844920905,-33.41190581565316,-33.44237178638541,-33.47283775711766,-33.503303727849904,-33.536212486546106,-33.57034263922429,-33.60447279190247,-33.638602944580654,-33.67273309725883,-33.706863249937015,-33.74099340261519,-33.77512355529338,-33.80925370797156,-33.84338386064974,-33.877514013327925,-33.911644166006106,-33.945774318684286,-33.979904471362474,-34.01403462404065,-34.048164776718835,-34.08229492939701,-34.116425082075196,-34.15055523475338,-34.18468538743156,-34.21881554010973,-34.25294569278792,-34.287075845466106,-34.321205998144286,-34.35533615082247,-34.38946630350065,-34.42359645617883,-34.457726608857,-34.49185676153519,-34.52598691421337,-34.56011706689155,-34.59424721956974,-34.62837737224791,-34.6625075249261,-34.69663767760428,-34.73076783028246,-34.76489798296064,-34.79902813563882,-34.833158288317,-34.86728844099518,-34.90141859367337,-34.93554874635155,-34.96967889902973,-35.00287363753549,-35.0360216052597,-35.0691695729839,-35.102317540708114,-35.135465508432326,-35.16861347615653,-35.201761443880734,-35.234909411604946,-35.26805737932915,-35.30120534705336,-35.334353314777566,-35.36750128250178,-35.40064925022599,-35.433797217950186,-35.466945185674405,-35.50009315339861,-35.53324112112283,-35.56638908884703,-35.599537056571236,-35.63268502429545,-35.66583299201965,-35.698980959743864,-35.732128927468075,-35.76527689519228,-35.79842486291649,-35.831572830640695,-35.8647207983649,-35.89786876608911,-35.93101673381332,-35.96416470153753,-35.99731266926173,-36.03046063698595,-36.063608604710154,-36.09675657243436,-36.12990454015857,-36.163052507882774,-36.196200475606986,-36.22934844333119,-36.26249641105541,-36.29564437877961,-36.262816124368314,-36.16401164782151,-36.06520717127471,-35.966402694727904,-35.8675982181811,-35.768793741634305,-35.66998926508751,-35.571184788540705,-35.472380311993895,-35.373575835447106,-35.274771358900296,-35.17596688235349,-35.0771624058067,-34.9783579292599,-34.8795534527131,-34.780748976166294,-34.6819444996195,-34.58314002307269,-34.4843355465259,-34.385531069979095,-34.28672659343229,-34.18792211688549,-34.08911764033869,-33.99031316379189,-33.89150868724508,-33.79270421069828,-33.693899734151486,-33.59509525760468,-33.49629078105788,-33.397486304511084,-33.29868182796428,-33.19987735141747,-33.10107287487068,-33.00226839832388,-32.903463921777075,-32.80465944523027,-32.705854968683475,-32.607050492136665,-32.50824601558987,-32.40944153904307,-32.31063706249627,-32.21183258594947,-32.11302810940267,-32.01422363285587,-31.915419156309056,-31.81661467976227,-31.717810203215464,-31.619005726668657,-31.520201250121865,-31.421396773575065,-31.322592297028258,-31.232475924897564,-31.157965949435216,-31.08345597397286,-31.008945998510505,-30.934436023048164,-30.859926047585805,-30.785416072123454,-30.710906096661102,-30.63639612119875,-30.561886145736402,-30.487376170274047,-30.4128661948117,-30.338356219349343,-30.263846243886995,-30.189336268424647,-30.114826292962288,-30.040316317499936,-29.965806342037595,-29.891296366575233,-29.81678639111288,-29.74227641565053,-29.66776644018818,-29.59325646472583,-29.518746489263478,-29.44423651380113,-29.369726538338774,-29.295216562876426,-29.220706587414078,-29.146196611951723,-29.07168663648936,-28.997176661027016,-28.922666685564664,-28.860729760240165,-28.823938935191364,-28.78714811014256,-28.750357285093756,-28.71356646004496,-28.676775634996154,-28.639984809947347,-28.603193984898542,-28.56640315984974,-28.529612334800937,-28.492821509752133,-28.45603068470333,-28.41923985965453,-28.382449034605727,-28.345658209556923,-28.308867384508122,-28.272076559459315,-28.235285734410517,-28.198494909361713,-28.16170408431291,-28.1249132592641,-28.0881224342153,-28.051331609166496,-28.014540784117692,-27.977749959068888,-27.94095913402009,-27.904168308971286,-27.867377483922482,-27.83058665887368,-27.793795833824873,-27.75700500877607,-27.720214183727272,-27.683423358678468,-27.646632533629663,-27.60984170858086,-27.57305088353206,-27.53626005848325,-27.49946923343445,-27.462678408385646,-27.425887583336838,-27.389096758288037,-27.352305933239236,-27.315515108190432,-27.278724283141628,-27.241933458092827,-27.205142633044026,-27.168351807995215,-27.131560982946418,-27.094770157897614,-27.05797933284881,-27.02118850780001,-26.984397682751204,-26.947606857702404,-26.910816032653596,-26.8740252076048,-26.83723438255599,-26.80044355750718,-26.76365273245838,-26.72686190740958,-26.690071082360777,-26.653280257311977,-26.616489432263172,-26.579698607214368,-26.542907782165564,-26.506116957116763,-26.46932613206796,-26.43253530701915,-26.395744481970354,-26.35895365692155,-26.322162831872745,-26.285372006823945,-26.248581181775137,-26.21170590693262,-26.174697925179274,-26.137689943425933,-26.100681961672585,-26.063673979919233,-26.026665998165896,-25.989658016412548,-25.9526500346592,-25.915642052905852,-25.878634071152508,-25.841626089399163,-25.777526889889472,-25.577971601598023,-25.37841631330658,-25.178861025015134,-24.979305736723724,-24.779750448432278,-24.580195160140832,-24.38063987184942,-24.180532050351264,-23.9799041987898,-23.779276347228375,-23.57864849566691,-23.378020644105447,-23.17739279254399,-22.976764940982562,-22.776137089421102,-22.57550923785964,-22.374881386298213,-22.174253534736753,-21.973625683175293,-21.772997831613868,-21.572369980052404,-21.37174212849094,-21.171114276929515,-20.97048642536805,-20.769858573806587,-20.569230722245127,-20.368602870683706,-20.16797501912224,-19.96734716756078,-19.766719315999353,-19.56609146443789,-19.365463612876432,-19.164835761315004,-18.964207909753544,-18.76358005819208,-18.562952206630616,-18.362324355069195,-18.161696503507734,-17.96106865194627,-17.760440800384846,-17.55981294882338,-17.35918509726192,-17.158557245700496,-16.957929394139033,-16.757301542577572,-16.556673691016147,-16.356045839454687,-16.155417987893223,-15.95479013633176,-15.754162284770336,-15.553534433208874,-15.35290658164741,-15.152278730085985,-14.951650878524521,-14.751023026963063,-14.550395175401636,-14.349767323840172,-14.149139472278712,-13.948511620717252,-13.747883769155823,-13.547255917594363,-13.346628066032899,-13.146000214471476,-12.945372362910014,-12.744744511348552,-12.544116659787125,-12.343488808225665,-12.142860956664201,-11.942233105102776,-11.741605253541316,-11.540977401979852,-11.340349550418392,-11.139721698856967,-10.939093847295503,-10.738465995734042,-10.537422677717714,-10.336157132898563,-10.134891588079414,-9.9336260432603,-9.732360498441151,-9.531094953622,-9.32982940880285,-9.128563863983738],[-27.794298166246026,-27.825858296881673,-27.85741842751732,-27.888978558152967,-27.920538688788618,-27.952098819424265,-27.98365895005991,-28.01521908069556,-28.046779211331206,-28.078339341966856,-28.109899472602503,-28.14145960323815,-28.173019733873797,-28.204579864509444,-28.236139995145095,-28.267700125780742,-28.29926025641639,-28.330820387052036,-28.362380517687683,-28.39394064832333,-28.425500778958977,-28.457060909594624,-28.488621040230274,-28.520181170865925,-28.551741301501565,-28.58330143213722,-28.614861562772866,-28.646421693408513,-28.67798182404416,-28.709541954679807,-28.741102085315454,-28.7726622159511,-28.804222346586748,-28.8357824772224,-28.867342607858046,-28.898902738493696,-28.930462869129343,-28.96202299976499,-28.993583130400637,-29.025143261036288,-29.05670339167193,-29.088263522307578,-29.119823652943225,-29.15138378357888,-29.182943914214523,-29.21450404485017,-29.24606417548582,-29.277624306121467,-29.309184436757114,-29.34074456739276,-29.372304698028408,-29.40386482866406,-29.435424959299706,-29.46698508993535,-29.498545220570996,-29.53010535120665,-29.561665481842297,-29.593225612477944,-29.624785743113588,-29.65634587374924,-29.687906004384885,-29.720154493412462,-29.753779699846106,-29.787404906279747,-29.82103011271339,-29.854655319147035,-29.888280525580676,-29.92190573201432,-29.955530938447964,-29.98915614488161,-30.02278135131525,-30.056406557748893,-30.090031764182534,-30.123656970616175,-30.157282177049822,-30.190907383483463,-30.224532589917104,-30.25815779635075,-30.291783002784392,-30.32540820921804,-30.35903341565168,-30.39265862208532,-30.426283828518965,-30.45990903495261,-30.492407695136663,-30.5246810460708,-30.556954397004937,-30.589227747939074,-30.62150109887321,-30.653774449807344,-30.68604780074148,-30.718321151675617,-30.750594502609754,-30.78286785354389,-30.81514120447803,-30.847414555412165,-30.879687906346305,-30.91196125728044,-30.944234608214582,-30.97650795914872,-31.008781310082856,-31.041054661016993,-31.07332801195113,-31.105601362885267,-31.1378747138194,-31.170148064753537,-31.201818955438853,-31.2322849261711,-31.262750896903352,-31.2932168676356,-31.323682838367855,-31.354148809100103,-31.384614779832347,-31.4150807505646,-31.44554672129685,-31.4760126920291,-31.50647866276135,-31.536944633493597,-31.56741060422585,-31.597876574958097,-31.628342545690348,-31.658808516422596,-31.689274487154844,-31.71974045788709,-31.750206428619343,-31.780672399351594,-31.81113837008384,-31.84160434081609,-31.872070311548338,-31.902536282280593,-31.933002253012837,-31.96346822374509,-31.99393419447734,-32.024400165209585,-32.054866135941836,-32.08533210667409,-32.11579807740634,-32.14626404813858,-32.176730018870835,-32.207195989603086,-32.23766196033533,-32.26812793106758,-32.29859390179983,-32.329059872532085,-32.359525843264336,-32.38999181399658,-32.42045778472883,-32.450923755461076,-32.48138972619333,-32.51185569692558,-32.54232166765782,-32.572787638390075,-32.603253609122326,-32.63371957985458,-32.66418555058683,-32.694651521319074,-32.725117492051325,-32.75558346278358,-32.78604943351583,-32.81651540424808,-32.84698137498032,-32.87744734571257,-32.90791331644482,-32.93837928717707,-32.96884525790932,-32.999311228641574,-33.02977719937382,-33.06268595807002,-33.09681611074821,-33.13094626342638,-33.16507641610457,-33.19920656878274,-33.23333672146093,-33.26746687413911,-33.30159702681729,-33.33572717949548,-33.36985733217366,-33.40398748485184,-33.43811763753002,-33.4722477902082,-33.50637794288639,-33.54050809556456,-33.57463824824275,-33.60876840092093,-33.64289855359911,-33.6770287062773,-33.71115885895547,-33.74528901163366,-33.77941916431184,-33.81354931699002,-33.8476794696682,-33.88178623688229,-33.914934204606496,-33.94808217233071,-33.98123014005492,-34.01437810777912,-34.047526075503335,-34.080674043227546,-34.11382201095175,-34.14696997867596,-34.18011794640016,-34.21326591412437,-34.24641388184858,-34.27956184957279,-34.312709817297,-34.34585778502121,-34.379005752745414,-34.412153720469625,-34.44530168819383,-34.47844965591804,-34.51159762364225,-34.544745591366464,-34.57789355909066,-34.61104152681487,-34.64418949453909,-34.67733746226329,-34.7104854299875,-34.743633397711704,-34.77678136543591,-34.80992933316013,-34.84307730088433,-34.87622526860854,-34.909373236332755,-34.94252120405696,-34.97566917178116,-35.008817139505375,-35.041965107229586,-35.07511307495379,-35.108261042677995,-35.141409010402214,-35.17455697812642,-35.20770494585062,-35.240852913574834,-35.274000881299045,-35.30714884902325,-35.340296816747454,-35.373444784471666,-35.40659275219588,-35.43974071992008,-35.47288868764429,-35.506036655368504,-35.53918462309271,-35.57233259081691,-35.605480558541124,-35.638628526265336,-35.67177649398954,-35.704924461713745,-35.738072429437956,-35.77122039716217,-35.80436836488637,-35.77154011047507,-35.67273563392827,-35.573931157381466,-35.47512668083467,-35.37632220428787,-35.27751772774107,-35.178713251194274,-35.079908774647464,-34.98110429810066,-34.88229982155387,-34.78349534500707,-34.68469086846026,-34.58588639191346,-34.48708191536666,-34.388277438819856,-34.28947296227305,-34.19066848572626,-34.09186400917945,-33.99305953263266,-33.89425505608586,-33.79545057953905,-33.69664610299225,-33.59784162644546,-33.49903714989865,-33.40023267335184,-33.30142819680505,-33.214529609465046,-33.1400196340027,-33.06550965854035,-32.990999683078,-32.91648970761565,-32.841979732153284,-32.76746975669094,-32.692959781228595,-32.61844980576623,-32.543939830303884,-32.469429854841536,-32.39491987937918,-32.32040990391683,-32.245899928454484,-32.17138995299213,-32.09687997752978,-32.02237000206743,-31.947860026605078,-31.87335005114272,-31.798840075680374,-31.724330100218022,-31.649820124755664,-31.57531014929332,-31.500800173830967,-31.426290198368612,-31.35178022290626,-31.277270247443912,-31.20276027198156,-31.128250296519205,-31.053740321056857,-30.979230345594505,-30.90472037013215,-30.830210394669802,-30.75570041920745,-30.681190443745095,-30.606680468282747,-30.5321704928204,-30.457660517358043,-30.383150541895688,-30.308640566433343,-30.234130590970988,-30.159620615508633,-30.085110640046288,-30.01060066458394,-29.936090689121578,-29.86158071365923,-29.78707073819688,-29.712560762734526,-29.638050787272174,-29.563540811809826,-29.48903083634747,-29.414520860885123,-29.340010885422775,-29.265500909960416,-29.190990934498064,-29.116480959035716,-29.041970983573364,-28.980034058248865,-28.943243233200064,-28.906452408151264,-28.869661583102456,-28.83287075805365,-28.79607993300485,-28.759289107956043,-28.72249828290724,-28.68570745785844,-28.648916632809637,-28.612125807760833,-28.575334982712032,-28.538544157663228,-28.501753332614424,-28.46496250756562,-28.42817168251682,-28.391380857468015,-28.354590032419214,-28.317799207370413,-28.281008382321605,-28.2442175572728,-28.207426732224,-28.170635907175196,-28.13384508212639,-28.097054257077588,-28.060263432028787,-28.02347260697998,-27.98668178193118,-27.949890956882378,-27.913100131833577,-27.876188664115396,-27.839180682362056,-27.802172700608704,-27.76516471885536,-27.728156737102015,-27.69114875534867,-27.654140773595323,-27.61713279184198,-27.580124810088634,-27.543116828335286,-27.50610884658194,-27.469100864828597,-27.43209288307525,-27.3950849013219,-27.358076919568557,-27.321068937815213,-27.284060956061865,-27.24705297430852,-27.210044992555176,-27.173037010801828,-27.136029029048483,-27.09902104729514,-27.06201306554179,-27.025005083788443,-26.987997102035102,-26.950989120281754,-26.913981138528406,-26.876973156775062,-26.839965175021717,-26.80295719326837,-26.76594921151502,-26.728941229761677,-26.691933248008333,-26.654925266254985,-26.61791728450164,-26.580909302748296,-26.543901320994948,-26.506893339241604,-26.46988535748826,-26.43287737573491,-26.395869393981563,-26.358861412228222,-26.321853430474874,-26.28484544872153,-26.247837466968186,-26.210829485214838,-26.17382150346149,-26.13681352170815,-26.0998055399548,-26.062797558201453,-26.02578957644811,-25.988781594694764,-25.95177361294142,-25.887674413431725,-25.68811912514028,-25.488563836848833,-25.289008548557383,-25.089453260265977,-24.88989797197453,-24.690342683683085,-24.490787395391674,-24.291232107100228,-24.091676818808782,-23.89212153051737,-23.692566242225926,-23.49301095393448,-23.29345566564303,-23.093900377351623,-22.894345089060177,-22.694789800768728,-22.49523451247732,-22.295679224185875,-22.096123935894425,-21.896568647603015,-21.69701335931157,-21.497458071020123,-21.297902782728713,-21.098347494437267,-20.898792206145824,-20.699236917854375,-20.499681629562964,-20.300126341271515,-20.10057105298007,-19.90101576468866,-19.701460476397216,-19.501905188105773,-19.30234989981436,-19.102794611522913,-18.903239323231467,-18.703684034940018,-18.503308071082586,-18.302680219521122,-18.10205236795966,-17.901424516398237,-17.700796664836773,-17.50016881327531,-17.299540961713884,-17.09891311015242,-16.898285258590963,-16.69765740702954,-16.49677351324428,-16.295507968425127,-16.094242423605976,-15.892976878786865,-15.691711333967714,-15.490445789148565,-15.289180244329453,-15.0879146995103,-14.886649154691153,-14.685383609872039,-14.484118065052888,-14.282852520233737,-14.081586975414588,-13.880321430595476,-13.679055885776323,-13.477790340957176,-13.276524796138062,-13.075259251318913,-12.873993706499762,-12.672728161680649,-12.4714626168615,-12.27019707204235,-12.068931527223237,-11.867665982404088,-11.666400437584937,-11.465134892765787,-11.263869347946674,-11.062603803127523,-10.861338258308374,-10.66007271348926,-10.45880716867011,-10.257541623850962,-10.056276079031848,-9.855010534212699,-9.653744989393548,-9.452479444574397,-9.251213899755285],[-27.384667162406966,-27.416227293042613,-27.44778742367826,-27.479347554313907,-27.510907684949558,-27.542467815585205,-27.574027946220852,-27.6055880768565,-27.637148207492146,-27.668708338127793,-27.700268468763444,-27.731828599399087,-27.763388730034734,-27.794948860670388,-27.826508991306035,-27.858069121941682,-27.88962925257733,-27.921189383212976,-27.952749513848623,-27.98430964448427,-28.015869775119917,-28.047429905755564,-28.078990036391218,-28.110550167026858,-28.142110297662512,-28.17367042829816,-28.205230558933803,-28.236790689569453,-28.2683508202051,-28.299910950840747,-28.331471081476394,-28.36303121211204,-28.39459134274769,-28.426151473383335,-28.457711604018986,-28.489271734654636,-28.520831865290283,-28.55239199592593,-28.583952126561577,-28.615512257197224,-28.64707238783287,-28.67863251846852,-28.710192649104165,-28.741752779739816,-28.773312910375463,-28.804873041011113,-28.83643317164676,-28.867993302282407,-28.899553432918054,-28.9311135635537,-28.96267369418935,-28.994233824824995,-29.025793955460646,-29.05735408609629,-29.088914216731936,-29.12047434736759,-29.152034478003237,-29.183594608638884,-29.21515473927453,-29.24671486991018,-29.278275000545825,-29.309835131181476,-29.341395261817123,-29.372955392452766,-29.404515523088417,-29.436075653724064,-29.46763578435971,-29.49919591499536,-29.53075604563101,-29.562316176266656,-29.593876306902303,-29.62543643753795,-29.6569965681736,-29.688556698809247,-29.720116829444894,-29.75167696008054,-29.783237090716188,-29.814797221351835,-29.84807824793767,-29.881703454371316,-29.91532866080496,-29.9489538672386,-29.98257907367224,-30.01620428010589,-30.04870294028994,-30.080976291224076,-30.113249642158213,-30.14552299309235,-30.177796344026486,-30.21006969496062,-30.24083689524678,-30.271302865979028,-30.30176883671128,-30.33223480744353,-30.36270077817578,-30.393166748908026,-30.42363271964028,-30.454098690372525,-30.484564661104777,-30.51503063183703,-30.545496602569273,-30.575962573301524,-30.606428544033776,-30.636894514766027,-30.667360485498275,-30.697826456230523,-30.728292426962774,-30.758758397695022,-30.78922436842727,-30.81969033915952,-30.850156309891773,-30.88062228062402,-30.91108825135627,-30.94155422208852,-30.97202019282077,-31.00248616355302,-31.032952134285267,-31.06341810501751,-31.093884075749767,-31.124350046482014,-31.154816017214266,-31.185281987946514,-31.21574795867876,-31.246213929411017,-31.276679900143264,-31.307145870875512,-31.33761184160776,-31.36807781234001,-31.398543783072263,-31.429009753804507,-31.45947572453676,-31.48994169526901,-31.52040766600126,-31.550873636733506,-31.581339607465758,-31.611805578198005,-31.642271548930253,-31.67273751966251,-31.703203490394756,-31.733669461127004,-31.764135431859252,-31.7946014025915,-31.825067373323755,-31.855533344056006,-31.88599931478825,-31.916465285520502,-31.946931256252753,-31.977397226985,-32.00786319771725,-32.03832916844949,-32.068795139181745,-32.099261109913996,-32.12972708064625,-32.1601930513785,-32.19065902211075,-32.221124992842995,-32.25159096357525,-32.28205693430749,-32.31252290503974,-32.342988875771994,-32.373454846504245,-32.40392081723649,-32.43438678796874,-32.46485275870099,-32.495318729433244,-32.52578470016549,-32.55625067089774,-32.58915942959394,-32.62328958227212,-32.6574197349503,-32.69154988762849,-32.72568004030667,-32.75981019298485,-32.79384680395331,-32.82699477167752,-32.860142739401724,-32.893290707125935,-32.92643867485014,-32.95958664257435,-32.992734610298555,-33.02588257802277,-33.05903054574697,-33.09217851347118,-33.125326481195394,-33.1584744489196,-33.19162241664381,-33.22477038436802,-33.257918352092226,-33.29106631981644,-33.32421428754064,-33.35736225526485,-33.39051022298906,-33.42365819071327,-33.45680615843747,-33.489954126161685,-33.523102093885896,-33.5562500616101,-33.589398029334305,-33.622545997058516,-33.65569396478273,-33.68884193250693,-33.72198990023114,-33.755137867955355,-33.78828583567956,-33.82143380340377,-33.854581771127975,-33.88772973885218,-33.92087770657639,-33.954025674300595,-33.987173642024814,-34.02032160974902,-34.05346957747322,-34.086617545197434,-34.11976551292164,-34.15291348064585,-34.186061448370054,-34.21920941609427,-34.25235738381848,-34.28550535154268,-34.31865331926689,-34.3518012869911,-34.38494925471531,-34.41809722243952,-34.451245190163725,-34.484393157887936,-34.51754112561214,-34.55068909333635,-34.58383706106056,-34.61698502878476,-34.65013299650898,-34.68328096423318,-34.716428931957395,-34.7495768996816,-34.78272486740581,-34.81587283513002,-34.84902080285423,-34.88216877057843,-34.91531673830264,-34.948464706026854,-34.98161267375106,-35.01476064147527,-35.047908609199474,-35.081056576923686,-35.1142045446479,-35.147352512372095,-35.180500480096306,-35.21364844782052,-35.24679641554472,-35.27994438326893,-35.313092350993145,-35.280264096581845,-35.196583294032536,-35.12207331857019,-35.04756334310784,-34.973053367645484,-34.898543392183136,-34.82403341672079,-34.74952344125843,-34.67501346579608,-34.600373294013664,-34.52566801807743,-34.4509627421412,-34.376257466204976,-34.30155219026876,-34.226846914332526,-34.152141638396294,-34.07743636246008,-34.002731086523845,-33.92802581058762,-33.853320534651395,-33.77861525871516,-33.70390998277893,-33.62920470684272,-33.55449943090649,-33.47979415497026,-33.405088879034025,-33.33038360309781,-33.25567832716158,-33.18097305122535,-33.106267775289126,-33.0315624993529,-32.95685722341667,-32.88215194748045,-32.80744667154422,-32.732741395607995,-32.65803611967176,-32.58333084373554,-32.508625567799314,-32.43392029186309,-32.359215015926864,-32.28450973999063,-32.20980446405441,-32.13509918811819,-32.06039391218196,-31.985688636245722,-31.91098336030951,-31.836278084373276,-31.761572808437045,-31.686867532500823,-31.612162256564595,-31.53745698062837,-31.462751704692142,-31.38804642875592,-31.313341152819685,-31.238635876883457,-31.163930600947243,-31.08922532501101,-31.014520049074775,-30.939814773138554,-30.86510949720233,-30.7904042212661,-30.71569894532988,-30.64099366939365,-30.56628839345742,-30.491583117521195,-30.416877841584977,-30.342172565648745,-30.26746728971251,-30.192762013776296,-30.118056737840064,-30.043351461903836,-29.968646185967607,-29.893940910031386,-29.819235634095154,-29.744530358158933,-29.669825082222708,-29.595119806286476,-29.52041453035025,-29.445709254414027,-29.371003978477802,-29.29629870254157,-29.22159342660534,-29.146888150669117,-29.084890068460815,-29.048306373708368,-29.01172267895592,-28.975138984203465,-28.938555289451013,-28.901971594698566,-28.86538789994611,-28.82880420519366,-28.79222051044121,-28.75563681568876,-28.719053120936305,-28.682469426183854,-28.645885731431406,-28.609302036678955,-28.572718341926503,-28.53613464717405,-28.4995509524216,-28.46296725766915,-28.4263835629167,-28.389799868164246,-28.35321617341179,-28.316632478659344,-28.280048783906892,-28.243465089154437,-28.206881394401993,-28.170297699649538,-28.133714004897087,-28.097130310144635,-28.060352151164345,-28.023344169410997,-27.98633618765765,-27.9493282059043,-27.912320224150957,-27.875312242397612,-27.83830426064427,-27.801296278890923,-27.764288297137576,-27.727280315384235,-27.690272333630887,-27.65326435187754,-27.616256370124194,-27.579248388370846,-27.542240406617502,-27.50523242486415,-27.468224443110806,-27.431216461357465,-27.394208479604117,-27.35720049785077,-27.32019251609743,-27.28318453434408,-27.246176552590732,-27.20916857083739,-27.172160589084044,-27.135152607330696,-27.098144625577355,-27.061136643824007,-27.02412866207066,-26.987120680317314,-26.95011269856397,-26.913104716810622,-26.876096735057274,-26.839088753303933,-26.802080771550585,-26.765072789797237,-26.728064808043897,-26.69105682629055,-26.6540488445372,-26.61704086278386,-26.58003288103051,-26.543024899277164,-26.50601691752382,-26.469008935770475,-26.432000954017127,-26.394992972263783,-26.357984990510438,-26.32097700875709,-26.283969027003742,-26.2469610452504,-26.209953063497053,-26.172945081743705,-26.13593709999036,-26.098929118237017,-26.061921136483672,-25.997821936973978,-25.798266648682535,-25.598711360391082,-25.39915607209964,-25.19960078380823,-25.000045495516783,-24.800490207225334,-24.600934918933923,-24.401379630642477,-24.20182434235103,-24.002269054059624,-23.80271376576818,-23.60315847747673,-23.403603189185286,-23.204047900893876,-23.004492612602427,-22.80493732431098,-22.60538203601957,-22.405254612073108,-22.205055041558694,-22.00485547104432,-21.80465590052991,-21.604456330015495,-21.40425675950112,-21.20405718898671,-21.003857618472296,-20.80365804795788,-20.60345847744351,-20.403258906929096,-20.203059336414682,-20.00285976590031,-19.802660195385897,-19.602460624871487,-19.402261054357112,-19.202061483842698,-19.001861913328288,-18.801662342813874,-18.6014627722995,-18.401263201785085,-18.201063631270674,-18.0008640607563,-17.800664490241886,-17.600464919727475,-17.4002653492131,-17.200065778698686,-16.999866208184276,-16.7996666376699,-16.59946706715549,-16.399267496641077,-16.199067926126666,-15.99886835561229,-15.79866878509788,-15.598469214583467,-15.39826964406909,-15.198070073554678,-14.997870503040266,-14.797670932525891,-14.597471362011477,-14.397271791497069,-14.197072220982655,-13.996872650468282,-13.796673079953868,-13.596473509439457,-13.39627393892508,-13.196074368410668,-12.995874797896256,-12.795378197452195,-12.594112652633044,-12.392847107813896,-12.191581562994783,-11.990316018175632,-11.789050473356482,-11.587784928537332,-11.386519383718218,-11.185253838899069,-10.98398829407992,-10.782722749260806,-10.581457204441655,-10.380191659622508,-10.178926114803392,-9.977660569984243,-9.776395025165094,-9.575129480345943,-9.37386393552683],[-26.96835480113431,-26.999914931769958,-27.031475062405605,-27.06303519304125,-27.0945953236769,-27.126155454312546,-27.157715584948193,-27.18927571558384,-27.22083584621949,-27.25239597685514,-27.283956107490788,-27.315516238126435,-27.34707636876208,-27.37863649939773,-27.410196630033376,-27.44175676066903,-27.473316891304673,-27.50487702194032,-27.536437152575967,-27.567997283211618,-27.59955741384726,-27.631117544482912,-27.66267767511856,-27.69423780575421,-27.725797936389853,-27.7573580670255,-27.78891819766115,-27.820478328296794,-27.852038458932448,-27.88359858956809,-27.915158720203742,-27.94671885083939,-27.978278981475036,-28.009839112110683,-28.04139924274633,-28.072959373381977,-28.10451950401763,-28.136079634653274,-28.167639765288925,-28.19919989592457,-28.23076002656022,-28.262320157195866,-28.293880287831513,-28.32544041846716,-28.357000549102807,-28.388560679738458,-28.420120810374105,-28.451680941009755,-28.483241071645402,-28.51480120228105,-28.546361332916696,-28.577921463552343,-28.60948159418799,-28.641041724823637,-28.672601855459284,-28.704161986094935,-28.73572211673058,-28.76728224736623,-28.798842378001876,-28.830402508637523,-28.86196263927317,-28.89352276990882,-28.925082900544467,-28.956643031180114,-28.98820316181576,-29.019763292451408,-29.05132342308706,-29.082883553722706,-29.114443684358353,-29.146003814994,-29.177563945629647,-29.209124076265297,-29.240684206900944,-29.271529146477196,-29.300943706705244,-29.330358266933292,-29.35977282716134,-29.389187387389388,-29.41860194761744,-29.448016507845484,-29.477431068073532,-29.50684562830158,-29.53626018852963,-29.56567474875768,-29.594276638915293,-29.622715995058822,-29.651155351202352,-29.679594707345885,-29.70803406348941,-29.73647341963294,-29.76491277577647,-29.79335213192,-29.821791488063532,-29.850230844207058,-29.8793457376745,-29.909811708406753,-29.940277679139,-29.970743649871253,-30.001209620603504,-30.031675591335755,-30.062141562068,-30.09260753280025,-30.1230735035325,-30.153539474264747,-30.184005444997,-30.21447141572925,-30.244937386461498,-30.275403357193746,-30.305869327925997,-30.336335298658245,-30.366801269390496,-30.397267240122744,-30.427733210854992,-30.45819918158724,-30.48866515231949,-30.519131123051743,-30.549597093783994,-30.58006306451624,-30.61052903524849,-30.64099500598074,-30.67146097671299,-30.70192694744524,-30.73239291817749,-30.76285888890974,-30.79332485964199,-30.823790830374236,-30.854256801106487,-30.88472277183873,-30.915188742570983,-30.945654713303234,-30.976120684035482,-31.006586654767734,-31.037052625499985,-31.067518596232233,-31.097984566964485,-31.128450537696732,-31.15891650842898,-31.18938247916123,-31.219848449893483,-31.25031442062573,-31.28078039135798,-31.311246362090227,-31.34171233282248,-31.372178303554726,-31.402644274286978,-31.43311024501923,-31.463576215751473,-31.494042186483725,-31.524508157215976,-31.554974127948224,-31.585440098680472,-31.615906069412723,-31.64637204014497,-31.676838010877223,-31.70730398160947,-31.737769952341722,-31.76823592307397,-31.798701893806218,-31.82916786453847,-31.85963383527072,-31.89009980600297,-31.92056577673522,-31.951031747467464,-31.981497718199716,-32.011963688931964,-32.042429659664215,-32.07289563039647,-32.104278005178536,-32.13611858198552,-32.167959158792506,-32.19979973559949,-32.231640312406476,-32.26348088921346,-32.29532146602045,-32.32716204282743,-32.35900261963442,-32.3908431964414,-32.42268377324839,-32.45452435005537,-32.48636492686236,-32.51850931077629,-32.551565118684564,-32.58462092659285,-32.61767673450113,-32.650732542409415,-32.6837883503177,-32.71684415822598,-32.74989996613426,-32.78295577404254,-32.81601158195082,-32.8490673898591,-32.882123197767385,-32.91517900567567,-32.948234813583944,-32.98129062149223,-33.01434642940051,-33.047402237308795,-33.08045804521707,-33.113513853125355,-33.14656966103364,-33.179625468941914,-33.2126812768502,-33.24573708475848,-33.278792892666765,-33.31184870057505,-33.344904508483324,-33.37796031639161,-33.41101612429989,-33.444071932208175,-33.47712774011646,-33.51018354802473,-33.54323935593302,-33.5762951638413,-33.60935097174958,-33.64240677965786,-33.675462587566145,-33.70851839547443,-33.741574203382704,-33.77463001129099,-33.80768581919927,-33.840741627107555,-33.87379743501583,-33.906853242924115,-33.9399090508324,-33.97296485874068,-34.00602066664895,-34.03907647455725,-34.07213228246552,-34.1051880903738,-34.138243898282084,-34.17129970619037,-34.20435551409865,-34.23741132200693,-34.27046712991521,-34.303522937823494,-34.33657874573177,-34.369634553640054,-34.40269036154834,-34.43574616945662,-34.468801977364905,-34.50185778527319,-34.534913593181464,-34.56796940108975,-34.601025208998024,-34.63408101690631,-34.66713682481459,-34.700192632722874,-34.73324844063116,-34.766304248539434,-34.79936005644772,-34.787853211019375,-34.7317837122544,-34.675714213489435,-34.619644714724465,-34.563575215959496,-34.50750571719453,-34.45143621842956,-34.3953667196646,-34.339297220899624,-34.28322772213467,-34.22715822336969,-34.17108872460472,-34.11501922583976,-34.05894972707479,-34.00288022830982,-33.94681072954486,-33.890741230779895,-33.834671732014925,-33.778602233249956,-33.72253273448499,-33.66646323572002,-33.61039373695505,-33.55432423819009,-33.49825473942512,-33.442185240660145,-33.38611574189518,-33.33004624313022,-33.27397674436524,-33.21790724560028,-33.16183774683532,-33.101455793282746,-33.026750517346514,-32.952045241410296,-32.877339965474064,-32.80263468953784,-32.727929413601615,-32.65322413766538,-32.57851886172916,-32.50381358579293,-32.42910830985671,-32.35440303392048,-32.27969775798425,-32.204992482048034,-32.1302872061118,-32.05558193017557,-31.980876654239353,-31.90617137830312,-31.83146610236689,-31.75676082643067,-31.682055550494443,-31.607350274558215,-31.532644998621986,-31.457939722685765,-31.383234446749533,-31.3085291708133,-31.23382389487709,-31.15911861894086,-31.084413343004627,-31.009708067068402,-30.935002791132177,-30.860297515195946,-30.785592239259724,-30.7108869633235,-30.63618168738727,-30.561476411451046,-30.48677113551482,-30.41206585957859,-30.337360583642358,-30.262655307706144,-30.187950031769912,-30.113244755833684,-30.038539479897455,-29.963834203961234,-29.889128928025002,-29.814423652088777,-29.739718376152556,-29.66501310021632,-29.590307824280103,-29.515602548343878,-29.440897272407646,-29.366191996471414,-29.29148672053519,-29.216781444598965,-29.154783362390667,-29.118199667638216,-29.081615972885764,-29.04503227813331,-29.00844858338086,-28.971864888628414,-28.93528119387596,-28.898697499123507,-28.862113804371056,-28.825530109618605,-28.788946414866153,-28.7523627201137,-28.71577902536125,-28.6791953306088,-28.642611635856348,-28.6060279411039,-28.569444246351445,-28.532860551598993,-28.49627685684655,-28.459693162094094,-28.423109467341636,-28.386525772589188,-28.34994207783674,-28.313358383084285,-28.276774688331837,-28.240190993579382,-28.20360729882693,-28.16702360407448,-28.130439909322035,-28.093856214569577,-28.057272519817126,-28.020688825064678,-27.984105130312226,-27.94752143555977,-27.91093774080732,-27.874354046054872,-27.837770351302417,-27.80118665654997,-27.764602961797515,-27.728019267045067,-27.691435572292615,-27.654851877540167,-27.61826818278771,-27.581684488035258,-27.545100793282806,-27.508517098530362,-27.471933403777903,-27.43534970902546,-27.398766014273004,-27.362182319520553,-27.3255986247681,-27.289014930015654,-27.2524312352632,-27.215847540510744,-27.1792638457583,-27.14268015100584,-27.106096456253393,-27.06951276150094,-27.03292906674849,-26.996345371996036,-26.959761677243588,-26.923177982491136,-26.886594287738685,-26.850010592986237,-26.813426898233786,-26.776843203481334,-26.74025950872888,-26.70253506419263,-26.66422223384552,-26.625909403498415,-26.58759657315131,-26.549283742804207,-26.5109709124571,-26.472658082109994,-26.434345251762892,-26.396032421415786,-26.35771959106868,-26.319406760721577,-26.28109393037447,-26.242781100027358,-26.204468269680255,-26.166155439333156,-26.127842608986047,-26.06547579629011,-25.882839071849986,-25.700202347409864,-25.517565622969737,-25.334928898529647,-25.15229217408953,-24.9696554496494,-24.787018725209315,-24.60438200076919,-24.421745276329066,-24.239108551888975,-24.056471827448853,-23.87383510300873,-23.684211030884036,-23.484011460369658,-23.283811889855247,-23.083612319340833,-22.88341274882646,-22.683213178312045,-22.483013607797634,-22.282814037283263,-22.082614466768852,-21.88241489625444,-21.682215325740064,-21.48201575522565,-21.28181618471124,-21.081616614196825,-20.88141704368245,-20.68121747316804,-20.481017902653626,-20.28081833213925,-20.08061876162484,-19.880419191110427,-19.680219620596052,-19.480020050081638,-19.279820479567228,-19.079620909052814,-18.879421338538442,-18.67922176802403,-18.479022197509618,-18.278822626995243,-18.07862305648083,-17.878423485966415,-17.678223915452044,-17.47802434493763,-17.277824774423216,-17.077625203908845,-16.87742563339443,-16.67722606288002,-16.477026492365606,-16.27682692185123,-16.07662735133682,-15.876427780822407,-15.676228210308032,-15.476028639793618,-15.275829069279208,-15.075629498764833,-14.875429928250421,-14.675230357736009,-14.475030787221598,-14.274831216707224,-14.07463164619281,-13.874432075678397,-13.674232505164023,-13.474032934649612,-13.273833364135196,-13.073633793620823,-12.873434223106411,-12.673234652592,-12.473035082077626,-12.272835511563214,-12.062363179482734,-11.848801856145785,-11.63524053280888,-11.42167920947193,-11.208117886134984,-10.994556562798076,-10.780995239461129,-10.567433916124182,-10.353872592787274,-10.140311269450326,-9.926749946113377,-9.713188622776432,-9.499627299439524],[-26.54822452165358,-26.579784652289227,-26.611344782924874,-26.64290491356052,-26.674465044196168,-26.706025174831815,-26.737585305467462,-26.76914543610311,-26.80070556673876,-26.832265697374407,-26.863825828010057,-26.8953859586457,-26.926946089281348,-26.958506219917,-26.990066350552645,-27.021626481188292,-27.05318661182394,-27.08474674245959,-27.116306873095237,-27.147867003730884,-27.17942713436653,-27.21098726500218,-27.242547395637825,-27.274107526273475,-27.305667656909122,-27.33722778754477,-27.36878791818042,-27.400348048816063,-27.431908179451717,-27.463468310087357,-27.49502844072301,-27.526588571358655,-27.558148701994305,-27.589708832629952,-27.6212689632656,-27.652829093901246,-27.684389224536897,-27.71594935517254,-27.747509485808195,-27.779069616443838,-27.810629747079485,-27.84218987771513,-27.873750008350783,-27.90531013898643,-27.936870269622077,-27.968430400257724,-27.999990530893374,-28.031550661529018,-28.063110792164668,-28.09467092280031,-28.126231053435966,-28.15779118407161,-28.18935131470726,-28.220911445342903,-28.25247157597855,-28.2840317066142,-28.31559183724985,-28.34536399126828,-28.374778551496327,-28.40419311172438,-28.433607671952426,-28.463022232180478,-28.49243679240852,-28.521851352636567,-28.551265912864622,-28.580680473092666,-28.610095033320714,-28.639509593548762,-28.668924153776814,-28.698338714004862,-28.727753274232906,-28.757167834460954,-28.786582394689006,-28.815996954917054,-28.845411515145102,-28.87482607537315,-28.904240635601198,-28.933655195829246,-28.963069756057294,-28.992484316285342,-29.02189887651339,-29.051313436741438,-29.080727996969486,-29.110142557197538,-29.13874444735515,-29.16718380349868,-29.19562315964221,-29.22406251578574,-29.25250187192927,-29.2809412280728,-29.309380584216328,-29.337819940359857,-29.366259296503387,-29.394698652646916,-29.423138008790445,-29.451577364933975,-29.480016721077504,-29.508456077221034,-29.536895433364567,-29.565334789508096,-29.593774145651622,-29.62221350179515,-29.650652857938685,-29.67909221408221,-29.707531570225743,-29.73597092636927,-29.7644102825128,-29.792849638656328,-29.821288994799858,-29.849728350943387,-29.87816770708692,-29.908295907514333,-29.93876187824658,-29.96922784897883,-29.999693819711077,-30.030159790443328,-30.06062576117558,-30.091091731907827,-30.121557702640075,-30.152023673372327,-30.182489644104574,-30.21295561483683,-30.243421585569074,-30.273887556301325,-30.304353527033577,-30.33481949776582,-30.365285468498072,-30.395751439230324,-30.426217409962568,-30.45668338069482,-30.48714935142707,-30.51761532215932,-30.54808129289157,-30.57854726362382,-30.60901323435607,-30.639479205088318,-30.669945175820565,-30.700411146552817,-30.73087711728507,-30.761343088017316,-30.791809058749564,-30.822275029481812,-30.852741000214063,-30.88320697094631,-30.913672941678563,-30.944138912410814,-30.97460488314306,-31.00507085387531,-31.035536824607558,-31.066002795339813,-31.096468766072057,-31.12693473680431,-31.157400707536556,-31.187866678268808,-31.218332649001056,-31.248798619733307,-31.27926459046556,-31.309730561197803,-31.340196531930054,-31.370662502662306,-31.401128473394554,-31.431594444126805,-31.462060414859053,-31.4925263855913,-31.522992356323552,-31.5534583270558,-31.58392429778805,-31.615306672570124,-31.647147249377106,-31.67898782618409,-31.710828402991076,-31.74266897979806,-31.774509556605047,-31.806350133412035,-31.838190710219017,-31.870031287026002,-31.901871863832987,-31.933712440639976,-31.965553017446958,-31.997393594253946,-32.02923417106093,-32.06107474786791,-32.0929153246749,-32.12475590148188,-32.15659647828887,-32.18843705509586,-32.22027763190283,-32.25211820870982,-32.28395878551681,-32.315799362323794,-32.34763993913077,-32.379480515937765,-32.41132109274474,-32.443161669551735,-32.47500224635871,-32.5068428231657,-32.53868339997269,-32.57052397677967,-32.60236455358666,-32.63420513039364,-32.666045707200624,-32.6980888215999,-32.73114462950819,-32.76420043741647,-32.79725624532475,-32.83031205323303,-32.86336786114131,-32.8964236690496,-32.92947947695788,-32.962535284866156,-32.99559109277444,-33.02864690068272,-33.061702708591,-33.09475851649928,-33.12781432440757,-33.16087013231585,-33.19392594022413,-33.22698174813241,-33.26003755604069,-33.29309336394898,-33.32614917185725,-33.359204979765536,-33.39226078767382,-33.4253165955821,-33.45837240349038,-33.49142821139866,-33.524484019306946,-33.55753982721522,-33.590595635123506,-33.62365144303179,-33.65670725094007,-33.68976305884836,-33.72281886675663,-33.75587467466492,-33.7889304825732,-33.821986290481476,-33.85504209838976,-33.88809790629804,-33.921153714206326,-33.9542095221146,-33.98726533002289,-34.02032113793117,-34.053376945839446,-34.08643275374773,-34.11948856165601,-34.152544369564296,-34.18560017747257,-34.21865598538086,-34.25171179328914,-34.284767601197416,-34.27326075576908,-34.2171912570041,-34.16112175823914,-34.105052259474164,-34.0489827607092,-33.99291326194424,-33.93684376317927,-33.8807742644143,-33.82470476564933,-33.768635266884374,-33.712565768119404,-33.65649626935443,-33.600426770589465,-33.544357271824495,-33.48828777305953,-33.43221827429456,-33.37614877552959,-33.32007927676463,-33.26400977799966,-33.2079402792347,-33.15187078046972,-33.09580128170475,-33.03973178293979,-32.98366228417482,-32.92759278540985,-32.87152328664489,-32.81545378787992,-32.759384289114955,-32.703314790349985,-32.64724529158502,-32.59117579282005,-32.535106294055076,-32.47903679529012,-32.422967296525144,-32.366897797760174,-32.31082829899521,-32.25475880023025,-32.19868930146528,-32.14261980270031,-32.08655030393535,-32.03048080517038,-31.974411306405408,-31.918341807640445,-31.862272308875472,-31.8062028101105,-31.750133311345543,-31.694063812580573,-31.637994313815604,-31.581924815050638,-31.52585531628567,-31.469785817520698,-31.413716318755732,-31.357646819990766,-31.301577321225796,-31.245507822460823,-31.189438323695867,-31.133368824930898,-31.077299326165928,-31.02122982740096,-30.965160328635996,-30.90909082987102,-30.853021331106056,-30.780780257253344,-30.706074981317116,-30.63136970538089,-30.556664429444666,-30.481959153508434,-30.407253877572202,-30.33254860163599,-30.25784332569976,-30.183138049763528,-30.108432773827303,-30.033727497891082,-29.959022221954847,-29.88431694601862,-29.809611670082404,-29.73490639414617,-29.660201118209944,-29.585495842273723,-29.51079056633749,-29.436085290401262,-29.361380014465034,-29.286674738528816,-29.22467665632051,-29.188092961568064,-29.15150926681561,-29.114925572063157,-29.078341877310706,-29.041758182558258,-29.005174487805803,-28.96859079305335,-28.932007098300907,-28.895423403548453,-28.858839708795998,-28.82225601404355,-28.7856723192911,-28.749088624538643,-28.712504929786196,-28.675921235033748,-28.63933754028129,-28.602753845528845,-28.56617015077639,-28.52958645602394,-28.493002761271484,-28.456419066519036,-28.41983537176658,-28.38325167701413,-28.346667982261685,-28.310084287509234,-28.273500592756783,-28.236586682666612,-28.19827385231951,-28.1599610219724,-28.12164819162529,-28.083335361278188,-28.04502253093108,-28.006709700583976,-27.968396870236873,-27.930084039889767,-27.89177120954266,-27.85345837919556,-27.81514554884845,-27.776832718501346,-27.738519888154244,-27.700207057807134,-27.661894227460028,-27.623581397112922,-27.58526856676582,-27.546955736418713,-27.508642906071607,-27.4703300757245,-27.432017245377395,-27.393704415030292,-27.355391584683183,-27.31707875433608,-27.278765923988978,-27.240453093641865,-27.202140263294766,-27.16382743294766,-27.12551460260055,-27.087201772253444,-27.04888894190634,-27.01057611155923,-26.97226328121213,-26.933950450865026,-26.895637620517924,-26.857324790170814,-26.819011959823712,-26.780699129476602,-26.7423862991295,-26.704073468782394,-26.665760638435287,-26.62744780808818,-26.589134977741075,-26.550822147393973,-26.512509317046863,-26.47419648669976,-26.43588365635265,-26.397570826005552,-26.35925799565844,-26.320945165311343,-26.282632334964234,-26.244319504617124,-26.20600667427002,-26.16769384392292,-26.12938101357581,-26.067014200879875,-25.88437747643975,-25.701740751999626,-25.519104027559504,-25.336467303119413,-25.15383057867929,-24.971193854239168,-24.78855712979908,-24.605920405358955,-24.423283680918832,-24.24064695647874,-24.05801023203862,-23.875373507598496,-23.69273678315837,-23.51010005871828,-23.327463334278157,-23.144826609838034,-22.962189885397947,-22.77955316095782,-22.5969164365177,-22.414279712077608,-22.231642987637485,-22.049006263197363,-21.86636953875727,-21.68373281431715,-21.501096089877027,-21.318459365436905,-21.135822640996814,-20.95318591655669,-20.770549192116565,-20.587912467676475,-20.405275743236356,-20.222639018796233,-20.040002294356142,-19.857365569916016,-19.674728845475894,-19.492092121035768,-19.30945539659568,-19.126818672155558,-18.944181947715432,-18.758707092487832,-18.56291189407156,-18.367116695655287,-18.171321497239052,-17.958631100935786,-17.74506977759884,-17.53150845426193,-17.317947130924985,-17.104385807588038,-16.89082448425109,-16.677263160914183,-16.463701837577236,-16.25014051424029,-16.03657919090338,-15.823017867566433,-15.609456544229486,-15.395895220892578,-15.182333897555631,-14.968772574218685,-14.755211250881736,-14.54164992754483,-14.328088604207883,-14.114527280870934,-13.900965957534027,-13.68740463419708,-13.473843310860133,-13.260281987523225,-13.046720664186278,-12.83315934084933,-12.619598017512422,-12.406036694175473,-12.192475370838526,-11.97891404750158,-11.765352724164673,-11.551791400827726,-11.33823007749078,-11.12466875415387,-10.911107430816923,-10.697546107479976,-10.483984784143068,-10.270423460806121,-10.056862137469174,-9.843300814132226,-9.629739490795318],[-26.12809424217285,-26.159654372808497,-26.191214503444144,-26.22277463407979,-26.25433476471544,-26.285894895351092,-26.317455025986735,-26.349015156622386,-26.380575287258033,-26.41213541789368,-26.443695548529327,-26.475255679164974,-26.50681580980062,-26.53837594043627,-26.56993607107192,-26.601496201707565,-26.633056332343212,-26.664616462978863,-26.69617659361451,-26.727736724250157,-26.759296854885804,-26.79085698552145,-26.822417116157098,-26.85397724679275,-26.885537377428392,-26.917097508064042,-26.94865763869969,-26.980217769335336,-27.011777899970987,-27.043338030606634,-27.074898161242277,-27.10645829187793,-27.13801842251357,-27.169578553149226,-27.20113868378487,-27.23269881442052,-27.264258945056167,-27.295819075691817,-27.327379206327464,-27.35893933696311,-27.389784275831325,-27.41919883605937,-27.44861339628742,-27.47802795651547,-27.507442516743517,-27.536857076971565,-27.566271637199616,-27.59568619742766,-27.62510075765571,-27.654515317883757,-27.683929878111805,-27.713344438339856,-27.7427589985679,-27.77217355879595,-27.801588119024,-27.831002679252045,-27.8604172394801,-27.889831799708144,-27.919246359936192,-27.94866092016424,-27.978075480392288,-28.00749004062034,-28.036904600848388,-28.066319161076436,-28.095733721304484,-28.12514828153253,-28.15456284176058,-28.183977401988628,-28.213391962216676,-28.242806522444724,-28.272221082672772,-28.30163564290082,-28.331050203128868,-28.360464763356916,-28.389879323584964,-28.419293883813015,-28.448708444041063,-28.478123004269108,-28.507537564497156,-28.536952124725207,-28.566366684953255,-28.5957812451813,-28.62519580540935,-28.6546103656374,-28.683212255795013,-28.711651611938546,-28.74009096808207,-28.7685303242256,-28.79696968036913,-28.82540903651266,-28.85384839265619,-28.88228774879972,-28.91072710494325,-28.93916646108678,-28.967605817230307,-28.99604517337384,-29.024484529517366,-29.0529238856609,-29.081363241804425,-29.109802597947954,-29.138241954091487,-29.166681310235013,-29.195120666378546,-29.22356002252208,-29.251999378665605,-29.28043873480913,-29.308878090952664,-29.337317447096193,-29.365756803239723,-29.39419615938325,-29.422635515526782,-29.451074871670315,-29.479514227813837,-29.50795358395737,-29.5363929401009,-29.564832296244425,-29.593271652387962,-29.621711008531488,-29.650150364675017,-29.678589720818547,-29.707029076962076,-29.735468433105606,-29.76390778924913,-29.792347145392664,-29.820786501536197,-29.849225857679723,-29.877665213823253,-29.906780106621913,-29.93724607735416,-29.967712048086412,-29.99817801881866,-30.02864398955091,-30.05910996028316,-30.08957593101541,-30.120041901747662,-30.150507872479906,-30.180973843212158,-30.211439813944406,-30.241905784676657,-30.27237175540891,-30.302837726141156,-30.333303696873404,-30.363769667605656,-30.394235638337904,-30.424701609070155,-30.455167579802406,-30.48563355053465,-30.516099521266902,-30.54656549199915,-30.5770314627314,-30.60749743346365,-30.6379634041959,-30.66842937492815,-30.6988953456604,-30.729361316392648,-30.759827287124896,-30.79029325785715,-30.820759228589395,-30.851225199321647,-30.881691170053895,-30.912157140786146,-30.942623111518397,-30.973089082250645,-31.003555052982893,-31.03402102371514,-31.064486994447392,-31.09495296517964,-31.126335339961717,-31.1581759167687,-31.190016493575683,-31.221857070382672,-31.253697647189654,-31.28553822399664,-31.317378800803624,-31.34921937761061,-31.381059954417594,-31.41290053122458,-31.444741108031568,-31.47658168483855,-31.508422261645535,-31.54026283845252,-31.572103415259505,-31.60394399206649,-31.635784568873476,-31.66762514568046,-31.699465722487446,-31.73130629929443,-31.76314687610141,-31.7949874529084,-31.826828029715386,-31.85866860652237,-31.890509183329357,-31.922349760136335,-31.954190336943327,-31.986030913750312,-32.0178714905573,-32.04971206736428,-32.08155264417126,-32.11339322097825,-32.14523379778524,-32.177074374592216,-32.20891495139921,-32.240755528206186,-32.27259610501317,-32.30443668182016,-32.33627725862714,-32.36811783543413,-32.39995841224111,-32.4317989890481,-32.46363956585508,-32.49548014266207,-32.52732071946905,-32.55916129627604,-32.59100187308302,-32.62284244989001,-32.65468302669699,-32.68652360350398,-32.718364180310964,-32.75020475711794,-32.782045333924934,-32.81388591073191,-32.8457264875389,-32.877668332423525,-32.91072414033181,-32.943779948240085,-32.976835756148375,-33.00989156405666,-33.042947371964935,-33.07600317987322,-33.1090589877815,-33.14211479568978,-33.17517060359806,-33.20822641150634,-33.24128221941463,-33.274338027322905,-33.30739383523119,-33.340449643139465,-33.37350545104775,-33.40656125895603,-33.439617066864315,-33.4726728747726,-33.50572868268088,-33.53878449058916,-33.57184029849745,-33.604896106405725,-33.637951914314,-33.671007722222285,-33.70406353013057,-33.737119338038845,-33.770175145947135,-33.758668300518785,-33.702598801753815,-33.64652930298885,-33.59045980422389,-33.53439030545891,-33.47832080669395,-33.42225130792898,-33.36618180916401,-33.31011231039904,-33.25404281163408,-33.19797331286911,-33.14190381410414,-33.08583431533918,-33.02976481657421,-32.97369531780924,-32.917625819044275,-32.861556320279306,-32.805486821514336,-32.74941732274937,-32.6933478239844,-32.637278325219434,-32.581208826454464,-32.5251393276895,-32.46906982892453,-32.41300033015956,-32.35693083139459,-32.30086133262963,-32.24479183386466,-32.1887223350997,-32.13265283633473,-32.07658333756976,-32.02051383880479,-31.96444434003983,-31.908374841274856,-31.852305342509887,-31.79623584374492,-31.740166344979954,-31.684096846214985,-31.628027347450015,-31.571957848685052,-31.515888349920083,-31.45981885115512,-31.40374935239015,-31.347679853625184,-31.29161035486021,-31.235540856095255,-31.179471357330282,-31.12340185856531,-31.067332359800343,-31.011262861035377,-30.955193362270407,-30.899123863505444,-30.84305436474048,-30.786984865975505,-30.73091536721054,-30.674845868445576,-30.618776369680603,-30.562706870915633,-30.506637372150664,-30.4505678733857,-30.39449837462073,-30.33842887585577,-30.282359377090803,-30.226289878325833,-30.170220379560867,-30.114150880795904,-30.058081382030934,-30.006165692380762,-29.960342287108634,-29.9145188818365,-29.868695476564366,-29.822872071292235,-29.777048666020107,-29.73122526074797,-29.685401855475842,-29.639578450203707,-29.593755044931576,-29.54793163965945,-29.502108234387315,-29.45628482911518,-29.410461423843046,-29.36463801857092,-29.318814613298787,-29.275466877144595,-29.237070479226276,-29.198674081307963,-29.160277683389644,-29.12188128547133,-29.083484887553013,-29.045088489634693,-29.006692091716378,-28.968295693798062,-28.929899295879746,-28.891502897961423,-28.85310650004311,-28.8147101021248,-28.77631370420648,-28.73791730628816,-28.69952090836984,-28.66112451045153,-28.622728112533213,-28.584331714614898,-28.54593531669658,-28.507538918778263,-28.469142520859947,-28.43074612294163,-28.39234972502331,-28.353953327104993,-28.315556929186677,-28.277160531268365,-28.238764133350045,-28.200367735431733,-28.161971337513414,-28.123574939595095,-28.085178541676783,-28.046782143758463,-28.008385745840144,-27.969989347921832,-27.931622444479533,-27.893309614132427,-27.85499678378532,-27.816683953438215,-27.778371123091112,-27.740058292744006,-27.7017454623969,-27.66343263204979,-27.625119801702688,-27.586806971355585,-27.54849414100848,-27.51018131066137,-27.471868480314264,-27.43355564996716,-27.395242819620055,-27.35692998927295,-27.318617158925846,-27.280304328578737,-27.24199149823163,-27.20367866788453,-27.165365837537422,-27.127053007190312,-27.08874017684321,-27.050427346496107,-27.012114516149005,-26.973801685801895,-26.935488855454793,-26.897176025107687,-26.85886319476058,-26.820550364413478,-26.78223753406637,-26.74392470371926,-26.70561187337216,-26.667299043025054,-26.628986212677944,-26.59067338233084,-26.55236055198374,-26.51404772163663,-26.475734891289527,-26.43742206094242,-26.399109230595318,-26.360796400248205,-26.322483569901106,-26.284170739554,-26.24585790920689,-26.207545078859788,-26.16923224851268,-26.130919418165576,-26.068552605469637,-25.88591588102951,-25.703279156589392,-25.520642432149273,-25.33800570770918,-25.155368983269057,-24.97273225882893,-24.790095534388847,-24.60745880994872,-24.424822085508595,-24.242185361068504,-24.05954863662838,-23.875331583726897,-23.679536385310627,-23.48374118689439,-23.287945988478118,-23.092150790061844,-22.89635559164561,-22.70056039322934,-22.50476519481306,-22.308969996396826,-22.113174797980555,-21.91737959956428,-21.721584401148043,-21.525789202731772,-21.3299940043155,-21.134198805899228,-20.938403607482993,-20.742608409066715,-20.54681321065044,-20.351018012234206,-20.155222813817936,-19.959427615401662,-19.763632416985423,-19.56783721856915,-19.37204202015288,-19.17624682173661,-18.98045162332037,-18.7846564249041,-18.588861226487825,-18.393066028071587,-18.197270829655317,-18.001475631239042,-17.805680432822804,-17.609885234406534,-17.414090035990263,-17.218294837574025,-17.02249963915775,-16.82670444074148,-16.630909242325206,-16.435114043908968,-16.239318845492697,-16.043523647076423,-15.847728448660188,-15.651933250243914,-15.456138051827642,-15.260342853411405,-15.064547654995131,-14.86875245657886,-14.672957258162587,-14.477162059746352,-14.281366861330078,-14.085571662913807,-13.889776464497569,-13.693981266081295,-13.49818606766502,-13.302390869248786,-13.106595670832512,-12.910800472416241,-12.715005274000003,-12.51921007558373,-12.322587562194318,-12.109026238857373,-11.895464915520467,-11.681903592183518,-11.468342268846573,-11.254780945509662,-11.041219622172715,-10.827658298835768,-10.614096975498862,-10.400535652161915,-10.186974328824967,-9.97341300548802,-9.759851682151112],[-25.707963962692123,-25.73952409332777,-25.771084223963417,-25.802644354599064,-25.834204485234714,-25.86576461587036,-25.89732474650601,-25.928884877141655,-25.960445007777306,-25.992005138412953,-26.0235652690486,-26.055125399684247,-26.086685530319894,-26.118245660955544,-26.14980579159119,-26.18136592222684,-26.212926052862482,-26.244486183498132,-26.27604631413378,-26.30760644476943,-26.339166575405073,-26.370726706040724,-26.402286836676367,-26.43384696731202,-26.463619120622415,-26.493033680850466,-26.52244824107851,-26.55186280130656,-26.58127736153461,-26.610691921762655,-26.640106481990706,-26.669521042218754,-26.6989356024468,-26.72835016267485,-26.7577647229029,-26.787179283130943,-26.816593843358994,-26.846008403587042,-26.87542296381509,-26.90483752404314,-26.934252084271183,-26.963666644499234,-26.993081204727282,-27.02249576495533,-27.05191032518338,-27.081324885411426,-27.110739445639478,-27.140154005867522,-27.16956856609557,-27.198983126323625,-27.228397686551666,-27.25781224677972,-27.287226807007766,-27.31664136723581,-27.346055927463865,-27.375470487691906,-27.40488504791996,-27.434299608148006,-27.46371416837605,-27.493128728604106,-27.52254328883215,-27.5519578490602,-27.58137240928825,-27.610786969516294,-27.640201529744346,-27.669616089972394,-27.69903065020044,-27.72844521042849,-27.757859770656538,-27.787274330884586,-27.816688891112634,-27.84610345134068,-27.87551801156873,-27.904932571796778,-27.93434713202483,-27.963761692252877,-27.99317625248092,-28.02259081270897,-28.05200537293702,-28.08141993316507,-28.110834493393117,-28.14024905362116,-28.169663613849217,-28.19907817407726,-28.227680064234878,-28.256119420378408,-28.284558776521934,-28.312998132665466,-28.341437488808992,-28.369876844952522,-28.39831620109605,-28.426755557239584,-28.45519491338311,-28.483634269526643,-28.512073625670176,-28.5405129818137,-28.56895233795723,-28.59739169410076,-28.625831050244294,-28.654270406387823,-28.68270976253135,-28.71114911867488,-28.73958847481841,-28.76802783096194,-28.796467187105467,-28.824906543248993,-28.853345899392526,-28.88178525553605,-28.91022461167958,-28.938663967823118,-28.967103323966644,-28.995542680110173,-29.023982036253702,-29.052421392397232,-29.08086074854076,-29.109300104684294,-29.13773946082782,-29.16617881697135,-29.194618173114876,-29.22305752925841,-29.25149688540194,-29.27993624154547,-29.308375597689,-29.336814953832526,-29.365254309976056,-29.39369366611958,-29.422133022263118,-29.450572378406648,-29.479011734550177,-29.507451090693703,-29.535890446837236,-29.564329802980765,-29.59276915912429,-29.621208515267824,-29.649647871411347,-29.67808722755488,-29.706526583698412,-29.73496593984194,-29.763405295985468,-29.791844652129,-29.820284008272527,-29.84872336441606,-29.87716272055959,-29.905602076703115,-29.935730276461747,-29.96619624719399,-29.996662217926243,-30.02712818865849,-30.057594159390742,-30.088060130122994,-30.11852610085524,-30.148992071587493,-30.17945804231974,-30.20992401305199,-30.24038998378424,-30.270855954516488,-30.30132192524874,-30.331787895980987,-30.362253866713235,-30.392719837445487,-30.423185808177735,-30.453651778909986,-30.484117749642238,-30.514583720374482,-30.545049691106733,-30.57551566183898,-30.605981632571233,-30.63736400735331,-30.66920458416029,-30.701045160967276,-30.73288573777426,-30.764726314581246,-30.79656689138823,-30.828407468195216,-30.8602480450022,-30.892088621809187,-30.923929198616168,-30.955769775423157,-30.987610352230142,-31.019450929037127,-31.051291505844112,-31.083132082651098,-31.114972659458083,-31.146813236265068,-31.178653813072053,-31.210494389879035,-31.242334966686023,-31.27417554349301,-31.306016120299994,-31.33785669710698,-31.369697273913964,-31.401537850720945,-31.433378427527927,-31.465219004334916,-31.497059581141897,-31.528900157948886,-31.560740734755868,-31.592581311562853,-31.62442188836984,-31.656262465176827,-31.68810304198381,-31.7199436187908,-31.75178419559778,-31.783624772404764,-31.81546534921175,-31.847305926018727,-31.879146502825723,-31.910987079632704,-31.94282765643969,-31.97466823324667,-32.00650881005366,-32.038349386860645,-32.07018996366763,-32.102030540474615,-32.1338711172816,-32.165711694088586,-32.19755227089557,-32.229392847702556,-32.26123342450954,-32.293074001316526,-32.32491457812351,-32.3567551549305,-32.388595731737475,-32.42043630854446,-32.45227688535145,-32.48411746215843,-32.515958038965415,-32.5477986157724,-32.579639192579386,-32.61147976938637,-32.643320346193356,-32.67516092300034,-32.707001499807326,-32.73884207661431,-32.7706826534213,-32.80252323022828,-32.83436380703527,-32.86620438384225,-32.89804496064924,-32.92988553745622,-32.96172611426321,-32.99356669107019,-33.02540726787718,-33.05724784468416,-33.09030365115543,-33.123359459063714,-33.156415266972,-33.189471074880274,-33.22252688278856,-33.25558269069684,-33.24407584526849,-33.18800634650352,-33.13193684773856,-33.075867348973595,-33.019797850208626,-32.963728351443656,-32.90765885267869,-32.851589353913724,-32.79551985514875,-32.73945035638379,-32.68338085761882,-32.627311358853845,-32.57124186008888,-32.51517236132392,-32.45910286255895,-32.40303336379398,-32.35402538269793,-32.308201977425796,-32.262378572153665,-32.216555166881534,-32.170731761609396,-32.124908356337265,-32.07908495106514,-32.03326154579301,-31.987438140520876,-31.941614735248738,-31.89579132997661,-31.849967924704476,-31.80414451943235,-31.758321114160218,-31.712497708888083,-31.66667430361595,-31.620850898343825,-31.57502749307169,-31.529204087799556,-31.483380682527425,-31.437557277255294,-31.391733871983163,-31.345910466711032,-31.3000870614389,-31.254263656166767,-31.20844025089464,-31.162616845622505,-31.11679344035037,-31.070970035078236,-31.025146629806112,-30.97932322453398,-30.933499819261847,-30.887676413989713,-30.841853008717585,-30.796029603445454,-30.75020619817332,-30.70438279290119,-30.658559387629058,-30.61273598235692,-30.566912577084796,-30.521089171812662,-30.47526576654053,-30.429442361268393,-30.38361895599627,-30.33779555072413,-30.291972145452007,-30.246148740179873,-30.200325334907742,-30.15450192963561,-30.108678524363476,-30.062855119091346,-30.01703171381921,-29.97120830854709,-29.925384903274953,-29.879561498002822,-29.833738092730687,-29.78791468745856,-29.742091282186422,-29.69626787691429,-29.650444471642164,-29.60462106637003,-29.5587976610979,-29.512974255825768,-29.467150850553637,-29.4213274452815,-29.375504040009368,-29.32968063473724,-29.286332898583048,-29.24793650066473,-29.209540102746416,-29.171143704828097,-29.132747306909785,-29.094350908991466,-29.055954511073146,-29.017558113154827,-28.979161715236515,-28.940765317318196,-28.90236891939988,-28.863972521481564,-28.82557612356325,-28.78717972564493,-28.74878332772662,-28.7103869298083,-28.671990531889982,-28.633594133971666,-28.59519773605335,-28.55680133813503,-28.518404940216712,-28.4800085422984,-28.44161214438008,-28.403215746461765,-28.36481934854345,-28.326422950625133,-28.288026552706814,-28.2496301547885,-28.211233756870186,-28.172837358951867,-28.134440961033544,-28.096044563115235,-28.057648165196913,-28.019251767278597,-27.980855369360278,-27.942458971441965,-27.904062573523646,-27.865666175605334,-27.827269777687015,-27.788873379768695,-27.75047698185038,-27.712080583932067,-27.673684186013745,-27.63528778809543,-27.596891390177113,-27.558494992258797,-27.52009859434048,-27.481702196422166,-27.44330579850385,-27.40490940058553,-27.366513002667215,-27.3281166047489,-27.28972020683058,-27.251323808912257,-27.21292741099395,-27.17453101307563,-27.13613461515731,-27.097738217238994,-27.059341819320682,-27.020945421402363,-26.982549023484047,-26.94415262556573,-26.904862126618994,-26.863585786358307,-26.822309446097627,-26.78103310583694,-26.739756765576253,-26.698480425315573,-26.657204085054886,-26.615927744794202,-26.574651404533522,-26.53337506427284,-26.492098724012152,-26.450822383751465,-26.409546043490785,-26.368269703230098,-26.326993362969414,-26.28571702270873,-26.244440682448044,-26.20316434218736,-26.16188800192668,-26.120611661665997,-26.07933532140531,-26.01863327233382,-25.860802679208277,-25.702972086082735,-25.545141492957192,-25.38731089983168,-25.229480306706137,-25.071649713580594,-24.91381912045508,-24.75598852732954,-24.598157934203996,-24.440327341078483,-24.282496747952944,-24.1246661548274,-23.96683556170186,-23.809004968576343,-23.6511743754508,-23.493343782325258,-23.335513189199744,-23.177682596074202,-22.99803330984181,-22.80223811142557,-22.6064429130093,-22.41064771459303,-22.21485251617679,-22.019057317760517,-21.823262119344243,-21.627466920927972,-21.431671722511737,-21.235876524095467,-21.04008132567919,-20.844286127262954,-20.64849092884668,-20.45269573043041,-20.25690053201417,-20.061105333597897,-19.865310135181623,-19.669514936765353,-19.473719738349118,-19.277924539932844,-19.08212934151657,-18.886334143100335,-18.69053894468406,-18.49474374626779,-18.298948547851552,-18.10315334943528,-17.907358151019007,-17.71156295260277,-17.5157677541865,-17.319972555770224,-17.12417735735395,-16.92838215893772,-16.732586960521445,-16.53679176210517,-16.340996563688932,-16.145201365272662,-15.949406166856388,-15.753610968440153,-15.557815770023879,-15.362020571607607,-15.166225373191335,-14.970430174775098,-14.774634976358826,-14.578839777942552,-14.383044579526313,-14.187249381110043,-13.973179980074715,-13.74651386118596,-13.519847742297166,-13.293181623408373,-13.066515504519618,-12.839849385630824,-12.613183266742027,-12.386517147853233,-12.15985102896448,-11.933184910075685,-11.70651879118689,-11.479852672298136,-11.25318655340934,-11.026520434520547,-10.799854315631794,-10.573188196742999,-10.346522077854202,-10.119855958965408,-9.893189840076655],[-25.287833683211396,-25.319393813847043,-25.35095394448269,-25.382514075118337,-25.414074205753987,-25.445634336389634,-25.47719446702528,-25.508039405185453,-25.537453965413505,-25.56686852564155,-25.5962830858696,-25.62569764609765,-25.655112206325697,-25.684526766553745,-25.713941326781793,-25.74335588700984,-25.77277044723789,-25.802185007465937,-25.83159956769399,-25.861014127922033,-25.890428688150084,-25.91984324837813,-25.94925780860618,-25.97867236883423,-26.008086929062273,-26.037501489290324,-26.066916049518372,-26.09633060974642,-26.125745169974472,-26.15515973020252,-26.184574290430568,-26.213988850658616,-26.243403410886664,-26.272817971114712,-26.30223253134276,-26.331647091570808,-26.361061651798856,-26.390476212026904,-26.419890772254952,-26.449305332483,-26.478719892711048,-26.508134452939096,-26.537549013167144,-26.566963573395196,-26.596378133623244,-26.625792693851288,-26.655207254079343,-26.684621814307388,-26.714036374535432,-26.743450934763487,-26.77286549499153,-26.802280055219583,-26.83169461544763,-26.86110917567568,-26.890523735903727,-26.919938296131775,-26.949352856359827,-26.97876741658787,-27.00818197681592,-27.037596537043967,-27.067011097272015,-27.096425657500067,-27.12584021772811,-27.15525477795616,-27.18466933818421,-27.214083898412255,-27.243498458640303,-27.27291301886836,-27.3023275790964,-27.33174213932445,-27.3611566995525,-27.390571259780543,-27.4199858200086,-27.44940038023664,-27.478814940464694,-27.50822950069274,-27.537644060920783,-27.567058621148835,-27.596473181376883,-27.625887741604934,-27.655302301832982,-27.684716862061027,-27.71413142228908,-27.743545982517123,-27.772147872674743,-27.800587228818273,-27.829026584961802,-27.857465941105332,-27.88590529724886,-27.914344653392387,-27.94278400953592,-27.97122336567945,-27.999662721822975,-28.02810207796651,-28.056541434110038,-28.084980790253567,-28.113420146397097,-28.141859502540626,-28.170298858684156,-28.198738214827685,-28.227177570971214,-28.255616927114744,-28.284056283258273,-28.312495639401803,-28.340934995545332,-28.36937435168886,-28.39781370783239,-28.42625306397592,-28.45469242011945,-28.48313177626298,-28.51157113240651,-28.54001048855004,-28.568449844693568,-28.596889200837097,-28.625328556980627,-28.653767913124156,-28.682207269267685,-28.710646625411215,-28.739085981554744,-28.767525337698274,-28.795964693841803,-28.824404049985333,-28.852843406128862,-28.88128276227239,-28.90972211841592,-28.938161474559447,-28.96660083070298,-28.99504018684651,-29.02347954299004,-29.051918899133568,-29.080358255277098,-29.108797611420627,-29.137236967564156,-29.165676323707686,-29.194115679851215,-29.222555035994745,-29.250994392138274,-29.279433748281804,-29.307873104425333,-29.336312460568863,-29.364751816712392,-29.39319117285592,-29.42163052899945,-29.450069885142977,-29.47850924128651,-29.50694859743004,-29.53538795357357,-29.563827309717098,-29.592266665860627,-29.620706022004157,-29.649145378147686,-29.677584734291216,-29.706024090434745,-29.73446344657827,-29.762902802721804,-29.791342158865334,-29.819781515008863,-29.848220871152392,-29.876660227295922,-29.905099583439448,-29.93421447556933,-29.96468044630158,-29.99514641703383,-30.025612387766078,-30.056078358498326,-30.086544329230577,-30.117010299962825,-30.1483926747449,-30.180233251551883,-30.21207382835887,-30.243914405165853,-30.275754981972838,-30.307595558779823,-30.33943613558681,-30.371276712393794,-30.40311728920078,-30.43495786600776,-30.46679844281475,-30.498639019621738,-30.53047959642872,-30.562320173235705,-30.594160750042686,-30.626001326849675,-30.657841903656664,-30.68968248046364,-30.721523057270627,-30.753363634077612,-30.785204210884597,-30.817044787691586,-30.848885364498567,-30.880725941305553,-30.912566518112538,-30.94440709491952,-30.976247671726508,-31.00808824853349,-31.03992882534048,-31.071769402147464,-31.103609976053324,-31.134872178896593,-31.166134381739866,-31.19739658458314,-31.22865878742641,-31.259920990269688,-31.29118319311296,-31.32244539595623,-31.353707598799506,-31.384969801642775,-31.41623200448605,-31.44749420732932,-31.478756410172593,-31.510018613015866,-31.541280815859142,-31.57254301870241,-31.603805221545684,-31.635067424388957,-31.66632962723223,-31.697591830075503,-31.728854032918775,-31.760116235762048,-31.79137843860532,-31.822640641448594,-31.853902844291866,-31.885165047135136,-31.91642724997841,-31.94768945282168,-31.978951655664957,-32.01021385850823,-32.0414760613515,-32.072738264194776,-32.10400046703805,-32.13526266988132,-32.166524872724594,-32.19778707556787,-32.22904927841114,-32.26031148125441,-32.291573684097685,-32.32283588694096,-32.35409808978423,-32.3853602926275,-32.416622495470776,-32.44788469831405,-32.47914690115732,-32.510409104000594,-32.54167130684387,-32.57293350968714,-32.60419571253041,-32.63545791537368,-32.66672011821696,-32.69798232106022,-32.7292445239035,-32.72640550795202,-32.6894652732058,-32.652525038459586,-32.61558480371336,-32.578644568967135,-32.54170433422092,-32.5047640994747,-32.46782386472848,-32.430883629982254,-32.39394339523604,-32.35700316048982,-32.3200629257436,-32.283122690997374,-32.246182456251155,-32.20924222150493,-32.17230198675871,-32.13536175201249,-32.09842151726627,-32.06148128252005,-32.02454104777383,-31.987600813027612,-31.950660578281386,-31.913720343535175,-31.87678010878895,-31.839839874042728,-31.802899639296506,-31.765959404550287,-31.72901916980406,-31.692078935057847,-31.65513870031163,-31.618198465565406,-31.58125823081918,-31.544317996072962,-31.507377761326744,-31.47043752658052,-31.4334972918343,-31.39655705708808,-31.35961682234186,-31.322676587595637,-31.28573635284942,-31.2487961181032,-31.21185588335698,-31.173482867060958,-31.127659461788824,-31.081836056516693,-31.036012651244565,-30.99018924597243,-30.944365840700296,-30.89854243542817,-30.852719030156038,-30.806895624883904,-30.76107221961177,-30.715248814339645,-30.66942540906751,-30.623602003795376,-30.577778598523246,-30.531955193251115,-30.48613178797898,-30.44030838270685,-30.394484977434722,-30.348661572162587,-30.302838166890457,-30.257014761618322,-30.21119135634619,-30.165367951074064,-30.119544545801933,-30.0737211405298,-30.027897735257664,-29.982074329985537,-29.936250924713406,-29.89042751944127,-29.844604114169137,-29.798780708897013,-29.75295730362488,-29.707133898352748,-29.661310493080613,-29.615487087808482,-29.569663682536355,-29.523840277264224,-29.47801687199209,-29.432193466719955,-29.386370061447824,-29.340546656175693,-29.297198920021497,-29.25880252210318,-29.22040612418487,-29.18200972626655,-29.143613328348234,-29.10521693042992,-29.066820532511603,-29.02842413459328,-28.990027736674968,-28.951631338756652,-28.913234940838333,-28.874838542920017,-28.836442145001698,-28.798045747083382,-28.75964934916507,-28.721252951246754,-28.68285655332843,-28.64446015541012,-28.606063757491803,-28.567667359573488,-28.529270961655165,-28.490874563736853,-28.452478165818537,-28.414081767900218,-28.375685369981902,-28.33580194897782,-28.29452560871713,-28.25324926845645,-28.211972928195767,-28.170696587935083,-28.129420247674393,-28.088143907413716,-28.04686756715303,-28.005591226892342,-27.964314886631662,-27.92303854637098,-27.881762206110288,-27.840485865849608,-27.79920952558892,-27.75793318532824,-27.716656845067554,-27.675380504806874,-27.634104164546187,-27.5928278242855,-27.551551484024817,-27.510275143764133,-27.468998803503446,-27.427722463242766,-27.38644612298208,-27.3451697827214,-27.303893442460712,-27.262617102200032,-27.221340761939345,-27.180064421678658,-27.138788081417978,-27.097511741157295,-27.056235400896608,-27.014959060635924,-26.973682720375244,-26.93240638011455,-26.89113003985387,-26.84985369959319,-26.808577359332503,-26.76730101907182,-26.726024678811136,-26.68474833855045,-26.643471998289765,-26.602195658029085,-26.5609193177684,-26.519642977507715,-26.478366637247035,-26.43709029698635,-26.39581395672566,-26.354537616464977,-26.313261276204294,-26.27198493594361,-26.230708595682923,-26.189432255422247,-26.148155915161556,-26.106879574900873,-26.06560323464019,-26.02432689437951,-25.983050554118822,-25.92234850504733,-25.76451791192179,-25.606687318796244,-25.44885672567071,-25.29102613254519,-25.13319553941965,-24.975364946294107,-24.817534353168597,-24.65970376004305,-24.50187316691751,-24.344042573791995,-24.186211980666453,-24.028381387540907,-23.87055079441537,-23.712720201289855,-23.55488960816431,-23.39705901503877,-23.239228421913257,-23.081397828787715,-22.923567235662173,-22.76573664253666,-22.607906049411113,-22.450075456285575,-22.29224486316006,-22.13441427003452,-21.976583676908973,-21.818753083783434,-21.66092249065792,-21.503091897532375,-21.345261304406833,-21.187430711281323,-21.029600118155777,-20.87176952503024,-20.71393893190472,-20.543602153373694,-20.355756773878852,-20.167911394384006,-19.980066014889196,-19.79222063539435,-19.604375255899512,-19.416529876404702,-19.228684496909857,-19.04083911741501,-18.852993737920205,-18.66514835842536,-18.477302978930517,-18.289457599435703,-18.101612219940865,-17.91376684044602,-17.725921460951174,-17.50896055849319,-17.282294439604396,-17.0556283207156,-16.828962201826844,-16.602296082938054,-16.37562996404926,-16.148963845160505,-15.922297726271708,-15.695631607382914,-15.468965488494117,-15.242299369605366,-15.01563325071657,-14.788967131827777,-14.562301012939022,-14.335634894050227,-14.108968775161433,-13.882302656272678,-13.655636537383884,-13.42897041849509,-13.202304299606336,-12.975638180717542,-12.748972061828745,-12.52230594293995,-12.295639824051197,-12.068973705162403,-11.842307586273607,-11.615641467384854,-11.388975348496057,-11.162309229607263,-10.935643110718512,-10.708976991829715,-10.482310872940921,-10.255644754052124,-10.028978635163373],[-24.862018192137892,-24.889132406639575,-24.916246621141255,-24.943360835642938,-24.970475050144614,-24.997589264646297,-25.02470347914798,-25.05181769364966,-25.078931908151343,-25.106046122653023,-25.133543726194816,-25.16295828642286,-25.192372846650912,-25.22178740687896,-25.251201967107008,-25.280616527335056,-25.310031087563104,-25.339445647791152,-25.368860208019203,-25.398274768247248,-25.4276893284753,-25.457103888703344,-25.486518448931395,-25.515933009159443,-25.545347569387488,-25.57476212961554,-25.604176689843587,-25.633591250071635,-25.663005810299687,-25.692420370527735,-25.721834930755783,-25.75124949098383,-25.780664051211875,-25.810078611439923,-25.839493171667975,-25.86890773189602,-25.89832229212407,-25.927736852352115,-25.957151412580167,-25.986565972808215,-26.015980533036263,-26.04539509326431,-26.07480965349236,-26.104224213720407,-26.133638773948455,-26.163053334176503,-26.19246789440455,-26.2218824546326,-26.251297014860647,-26.280711575088695,-26.310126135316743,-26.33954069554479,-26.36895525577284,-26.398369816000887,-26.42778437622894,-26.457198936456983,-26.486613496685038,-26.516028056913083,-26.545442617141127,-26.574857177369182,-26.60427173759723,-26.633686297825278,-26.663100858053323,-26.692515418281367,-26.721929978509422,-26.75134453873747,-26.780759098965518,-26.810173659193566,-26.839588219421614,-26.869002779649662,-26.89841733987771,-26.927831900105758,-26.957246460333806,-26.986661020561854,-27.016075580789902,-27.045490141017954,-27.074904701246002,-27.104319261474046,-27.133733821702094,-27.163148381930146,-27.192562942158194,-27.221977502386242,-27.251392062614286,-27.280806622842338,-27.30940851299995,-27.337847869143484,-27.366287225287014,-27.39472658143054,-27.42316593757407,-27.4516052937176,-27.48004464986113,-27.508484006004657,-27.536923362148187,-27.56536271829172,-27.593802074435246,-27.622241430578775,-27.65068078672231,-27.679120142865834,-27.70755949900937,-27.735998855152896,-27.764438211296426,-27.79287756743995,-27.821316923583485,-27.849756279727018,-27.878195635870544,-27.90663499201407,-27.935074348157602,-27.96351370430113,-27.991953060444658,-28.020392416588187,-28.04883177273172,-28.07727112887525,-28.105710485018776,-28.134149841162305,-28.162589197305834,-28.191028553449367,-28.219467909592893,-28.247907265736423,-28.276346621879956,-28.30478597802348,-28.333225334167018,-28.36166469031054,-28.39010404645407,-28.418543402597603,-28.446982758741132,-28.47542211488466,-28.50386147102819,-28.53230082717172,-28.560740183315254,-28.589179539458783,-28.617618895602313,-28.646058251745842,-28.67449760788937,-28.702936964032897,-28.731376320176427,-28.759815676319956,-28.78825503246349,-28.816694388607015,-28.845133744750548,-28.873573100894077,-28.902012457037607,-28.930451813181133,-28.958891169324666,-28.98733052546819,-29.01576988161172,-29.04420923775525,-29.072648593898784,-29.10108795004231,-29.12952730618584,-29.157966662329372,-29.186406018472898,-29.214845374616427,-29.24328473075996,-29.271724086903486,-29.300163443047015,-29.328602799190545,-29.357042155334078,-29.38439259360829,-29.410654117637854,-29.436915641667426,-29.46317716569699,-29.489438689726562,-29.515700213756126,-29.541961737785698,-29.568223261815263,-29.59448478584483,-29.6207463098744,-29.649595029235577,-29.67973734626256,-29.70987966328954,-29.74002198031652,-29.770164297343506,-29.800306614370488,-29.830448931397473,-29.860591248424456,-29.890733565451434,-29.920875882478416,-29.951018199505402,-29.981160516532384,-30.011302833559366,-30.04144515058635,-30.07158746761333,-30.101807016511078,-30.13306921935435,-30.164331422197623,-30.195593625040896,-30.226855827884165,-30.25811803072744,-30.28938023357071,-30.320642436413983,-30.351904639257256,-30.38316684210053,-30.4144290449438,-30.445691247787074,-30.476953450630347,-30.50821565347362,-30.539477856316893,-30.57074005916017,-30.602002262003438,-30.63326446484671,-30.664526667689984,-30.695788870533256,-30.72705107337653,-30.758313276219805,-30.789575479063075,-30.82083768190635,-30.85209988474962,-30.883362087592893,-30.914624290436166,-30.94588649327944,-30.97714869612271,-31.008410898965984,-31.039673101809253,-31.070935304652526,-31.102197507495802,-31.13345971033907,-31.164721913182348,-31.19598411602562,-31.227246318868893,-31.258508521712166,-31.28977072455544,-31.32103292739871,-31.35229513024198,-31.38355733308525,-31.41481953592853,-31.446081738771795,-31.477343941615075,-31.508606144458348,-31.539868347301613,-31.571130550144893,-31.60239275298816,-31.63365495583144,-31.66491715867471,-31.696179361517984,-31.727441564361257,-31.75870376720453,-31.7899659700478,-31.82122817289107,-31.852490375734344,-31.883752578577617,-31.91501478142089,-31.946276984264166,-31.977539187107432,-32.00880138995071,-32.04006359279398,-32.07132579563726,-32.10258799848052,-32.1338502013238,-32.16511240416707,-32.19637460701034,-32.19353559105887,-32.15659535631264,-32.119655121566424,-32.082714886820206,-32.04577465207399,-32.00883441732776,-31.971894182581543,-31.934953947835325,-31.8980137130891,-31.86107347834288,-31.824133243596663,-31.787193008850437,-31.75025277410422,-31.713312539358,-31.676372304611775,-31.63943206986556,-31.602491835119338,-31.565551600373116,-31.528611365626894,-31.491671130880675,-31.454730896134453,-31.41779066138823,-31.380850426642013,-31.34391019189579,-31.30696995714957,-31.27002972240335,-31.233089487657132,-31.196149252910907,-31.159209018164688,-31.122268783418473,-31.08532854867225,-31.048388313926026,-31.01144807917981,-30.974507844433585,-30.937567609687363,-30.900627374941145,-30.863687140194923,-30.826746905448708,-30.789806670702482,-30.752866435956264,-30.71592620121004,-30.678985966463824,-30.6420457317176,-30.605105496971383,-30.568165262225158,-30.531225027478943,-30.494284792732717,-30.457344557986495,-30.420404323240277,-30.38346408849406,-30.346523853747836,-30.309583619001614,-30.272643384255396,-30.23570314950917,-30.19876291476295,-30.161822680016733,-30.12488244527051,-30.08794221052429,-30.05100197577807,-30.014061741031853,-29.97712150628563,-29.94018127153941,-29.90324103679319,-29.866300802046965,-29.829360567300746,-29.792420332554528,-29.755480097808302,-29.71853986306208,-29.681599628315865,-29.644659393569643,-29.60771915882342,-29.570778924077203,-29.533838689330985,-29.496898454584763,-29.47386090035444,-29.453578883634478,-29.433296866914517,-29.41301485019456,-29.392732833474604,-29.37245081675465,-29.35216880003469,-29.331886783314733,-29.311604766594773,-29.284229371463272,-29.242667219508697,-29.20110506755412,-29.159542915599545,-29.11798076364497,-29.076418611690393,-29.03485645973581,-28.993294307781234,-28.95173215582666,-28.910170003872082,-28.868607851917503,-28.827045699962927,-28.78548354800835,-28.743921396053775,-28.7023592440992,-28.660797092144623,-28.619234940190044,-28.577672788235468,-28.536110636280892,-28.494548484326312,-28.452986332371733,-28.411424180417157,-28.36986202846258,-28.328299876508005,-28.286737724553426,-28.245175572598853,-28.20361342064427,-28.162051268689698,-28.120489116735122,-28.078926964780543,-28.037364812825967,-27.995802660871394,-27.954240508916815,-27.912678356962232,-27.871116205007656,-27.829554053053087,-27.787991901098504,-27.74642974914393,-27.704867597189352,-27.663305445234776,-27.6217432932802,-27.580181141325625,-27.53861898937104,-27.497056837416466,-27.455494685461886,-27.41399037647765,-27.372714036216962,-27.33143769595628,-27.290161355695595,-27.248885015434908,-27.207608675174228,-27.166332334913545,-27.125055994652858,-27.08377965439217,-27.042503314131494,-27.001226973870807,-26.95995063361012,-26.918674293349437,-26.877397953088753,-26.836121612828066,-26.794845272567386,-26.753568932306706,-26.71229259204602,-26.671016251785332,-26.62973991152465,-26.588463571263965,-26.547187231003278,-26.505910890742598,-26.464634550481914,-26.423358210221227,-26.382081869960544,-26.340805529699864,-26.299529189439177,-26.25825284917849,-26.21697650891781,-26.17570016865712,-26.134423828396436,-26.093147488135756,-26.051871147875072,-26.010594807614385,-25.969318467353702,-25.92804212709302,-25.886765786832335,-25.826063737760844,-25.668233144635302,-25.51040255150976,-25.35257195838422,-25.194741365258704,-25.03691077213316,-24.87908017900762,-24.721249585882106,-24.5402825408489,-24.352437161354054,-24.164591781859247,-23.976746402364398,-23.788901022869556,-23.601055643374714,-23.413210263879904,-23.225364884385062,-23.037519504890213,-22.849674125395403,-22.66182874590056,-22.47398336640572,-22.286137986910912,-22.098292607416067,-21.910447227921225,-21.722601848426415,-21.53475646893157,-21.346911089436723,-21.15906570994188,-20.97122033044707,-20.78337495095223,-20.595529571457387,-20.407684191962577,-20.219838812467735,-20.03199343297289,-19.84414805347808,-19.656302673983234,-19.468457294488392,-19.28061191499355,-19.09276653549874,-18.904921156003894,-18.717075776509056,-18.529230397014242,-18.3413850175194,-18.153539638024554,-17.965694258529744,-17.777848879034902,-17.59000349954006,-17.40215812004525,-17.214312740550405,-17.026467361055563,-16.83862198156072,-16.65077660206591,-16.462931222571065,-16.27508584307622,-16.087240463581413,-15.899395084086567,-15.711549704591725,-15.523704325096915,-15.335858945602071,-15.148013566107227,-14.960168186612385,-14.772322807117575,-14.584477427622732,-14.396632048127888,-14.208786668633078,-14.020941289138234,-13.83309590964339,-13.64525053014858,-13.457405150653738,-13.269559771158894,-13.081714391664086,-12.89386901216924,-12.706023632674398,-12.518178253179553,-12.330332873684744,-12.1424874941899,-11.954642114695055,-11.751430262471573,-11.524764143582777,-11.298098024693982,-11.071431905805229,-10.844765786916433,-10.618099668027638,-10.391433549138844,-10.16476743025009],[-24.43234832144606,-24.459462535947743,-24.486576750449423,-24.513690964951106,-24.540805179452786,-24.56791939395447,-24.59503360845615,-24.622147822957828,-24.649262037459515,-24.676376251961194,-24.703490466462874,-24.730604680964554,-24.757718895466237,-24.78483310996792,-24.8119473244696,-24.839061538971283,-24.866175753472962,-24.893289967974646,-24.92040418247633,-24.94751839697801,-24.97463261147969,-25.00174682598137,-25.028861040483054,-25.055975254984737,-25.083089469486417,-25.1102036839881,-25.137317898489776,-25.165965676148947,-25.19538023637699,-25.224794796605043,-25.254209356833087,-25.283623917061135,-25.313038477289183,-25.34245303751723,-25.37186759774528,-25.401282157973327,-25.430696718201375,-25.460111278429423,-25.489525838657475,-25.51894039888552,-25.54835495911357,-25.577769519341615,-25.607184079569667,-25.636598639797715,-25.666013200025763,-25.69542776025381,-25.72484232048186,-25.75425688070991,-25.783671440937958,-25.813086001166003,-25.842500561394054,-25.871915121622102,-25.90132968185015,-25.930744242078198,-25.960158802306246,-25.989573362534294,-26.018987922762342,-26.04840248299039,-26.077817043218438,-26.107231603446486,-26.136646163674534,-26.166060723902582,-26.195475284130634,-26.224889844358678,-26.254304404586726,-26.283718964814778,-26.313133525042826,-26.342548085270874,-26.37196264549892,-26.40137720572697,-26.43079176595502,-26.460206326183066,-26.489620886411117,-26.519035446639162,-26.548450006867213,-26.57786456709526,-26.60727912732331,-26.636693687551357,-26.666108247779405,-26.695522808007453,-26.7249373682355,-26.75435192846355,-26.783766488691597,-26.813181048919645,-26.84178293907726,-26.87022229522079,-26.898661651364314,-26.92710100750785,-26.955540363651373,-26.983979719794903,-27.01241907593844,-27.040858432081965,-27.069297788225498,-27.097737144369024,-27.126176500512557,-27.154615856656086,-27.183055212799616,-27.211494568943145,-27.239933925086675,-27.268373281230204,-27.296812637373733,-27.325251993517263,-27.353691349660792,-27.38213070580432,-27.41057006194785,-27.439009418091377,-27.46744877423491,-27.49588813037844,-27.52432748652197,-27.552766842665495,-27.581206198809028,-27.609645554952557,-27.638084911096087,-27.666524267239616,-27.694963623383146,-27.72340297952667,-27.751842335670204,-27.78028169181373,-27.808721047957263,-27.83716040410079,-27.865599760244322,-27.89403911638785,-27.922478472531374,-27.95091782867491,-27.97935718481844,-28.00779654096197,-28.0362358971055,-28.064675253249025,-28.093114609392558,-28.121553965536087,-28.149993321679613,-28.178432677823146,-28.206872033966675,-28.2353113901102,-28.263750746253734,-28.29219010239726,-28.32062945854079,-28.349068814684323,-28.377508170827856,-28.405947526971378,-28.434386882489967,-28.460648406519535,-28.486909930549103,-28.51317145457867,-28.539432978608243,-28.565694502637808,-28.591956026667376,-28.618217550696944,-28.64447907472651,-28.67074059875608,-28.697002122785648,-28.723263646815216,-28.749525170844784,-28.77578669487435,-28.802048218903916,-28.828309742933484,-28.854571266963053,-28.88083279099262,-28.90709431502219,-28.933355839051757,-28.959617363081325,-28.985878887110896,-29.01214041114046,-29.03840193517003,-29.064663459199597,-29.090924983229165,-29.117186507258733,-29.146035226619908,-29.176177543646894,-29.206319860673872,-29.236462177700854,-29.26660449472784,-29.296746811754822,-29.326889128781808,-29.357031445808786,-29.38717376283577,-29.41731607986275,-29.447458396889736,-29.477600713916715,-29.507743030943697,-29.53788534797068,-29.568027664997665,-29.598169982024643,-29.62831229905163,-29.658454616078608,-29.688596933105593,-29.718739250132575,-29.74888156715956,-29.77902388418654,-29.80916620121352,-29.839308518240504,-29.869450835267486,-29.899593152294475,-29.92973546932145,-29.959877786348436,-29.990020103375418,-30.0201624204024,-30.050304737429382,-30.080447054456364,-30.11058937148335,-30.14073168851033,-30.17087400553731,-30.201016322564296,-30.23115863959128,-30.261300956618257,-30.29144327364524,-30.321585590672225,-30.351727907699207,-30.38187022472619,-30.413016576386283,-30.444278779229556,-30.47554098207283,-30.5068031849161,-30.538065387759367,-30.569327590602647,-30.600589793445916,-30.631851996289193,-30.663114199132465,-30.694376401975735,-30.72563860481901,-30.756900807662277,-30.788163010505556,-30.81942521334883,-30.850687416192095,-30.881949619035375,-30.91321182187864,-30.94447402472192,-30.975736227565186,-31.00699843040846,-31.038260633251735,-31.069522836095008,-31.100785038938284,-31.132047241781557,-31.16330944462483,-31.194571647468102,-31.225833850311375,-31.25709605315464,-31.288358255997913,-31.319620458841186,-31.35088266168446,-31.38214486452773,-31.413407067371004,-31.444669270214277,-31.475931473057553,-31.507193675900826,-31.538455878744095,-31.569718081587368,-31.60098028443064,-31.632242487273913,-31.663504690117186,-31.66066567416571,-31.623725439419488,-31.58678520467327,-31.54984496992705,-31.512904735180825,-31.475964500434607,-31.43902426568839,-31.402084030942163,-31.365143796195945,-31.32820356144973,-31.291263326703508,-31.254323091957282,-31.217382857211064,-31.18044262246484,-31.14350238771862,-31.1065621529724,-31.06962191822618,-31.03268168347996,-30.99574144873374,-30.95880121398752,-30.921860979241302,-30.884920744495076,-30.847980509748858,-30.81104027500264,-30.774100040256414,-30.737159805510196,-30.70021957076397,-30.66327933601775,-30.626339101271533,-30.589398866525315,-30.55245863177909,-30.51551839703287,-30.478578162286652,-30.44163792754043,-30.40469769279421,-30.36775745804799,-30.330817223301768,-30.293876988555546,-30.256936753809327,-30.21999651906311,-30.183056284316883,-30.146116049570665,-30.109175814824447,-30.07223558007822,-30.035295345332003,-30.004492321374308,-29.984210304654347,-29.963928287934394,-29.943646271214433,-29.923364254494473,-29.903082237774516,-29.88280022105456,-29.862518204334602,-29.842236187614645,-29.821954170894685,-29.80167215417473,-29.78139013745477,-29.76110812073481,-29.740826104014857,-29.720544087294897,-29.700262070574937,-29.679980053854983,-29.659698037135023,-29.639416020415066,-29.61913400369511,-29.598851986975156,-29.57856997025519,-29.558287953535235,-29.53800593681528,-29.51772392009532,-29.49744190337536,-29.477159886655404,-29.456877869935447,-29.43659585321549,-29.416313836495533,-29.396031819775573,-29.375749803055616,-29.355467786335655,-29.3351857696157,-29.314903752895745,-29.294621736175785,-29.274339719455824,-29.254057702735867,-29.226682307604367,-29.18512015564979,-29.14355800369522,-29.10199585174064,-29.06043369978606,-29.018871547831488,-28.977309395876908,-28.93574724392233,-28.894185091967756,-28.852622940013177,-28.811060788058597,-28.769498636104025,-28.72793648414945,-28.686374332194873,-28.644812180240294,-28.60325002828572,-28.561687876331135,-28.520125724376562,-28.47856357242199,-28.43700142046741,-28.39543926851283,-28.35387711655825,-28.312314964603672,-28.2707528126491,-28.229190660694524,-28.18762850873995,-28.14606635678537,-28.104504204830793,-28.062942052876217,-28.021379900921637,-27.979817748967058,-27.938255597012493,-27.896693445057913,-27.85513129310333,-27.813569141148754,-27.77200698919418,-27.7304448372396,-27.688882685285026,-27.64732053333045,-27.605758381375868,-27.564196229421295,-27.522634077466716,-27.481071925512136,-27.43950977355756,-27.39794762160298,-27.35638546964841,-27.31482331769383,-27.273261165739257,-27.231699013784677,-27.1901368618301,-27.148574709875525,-27.107012557920953,-27.06545040596637,-27.023888254011787,-26.982326102057222,-26.940763950102642,-26.899201798148063,-26.857639646193483,-26.814584724513473,-26.769663860034747,-26.724742995556017,-26.679822131077295,-26.63490126659857,-26.589980402119842,-26.545059537641116,-26.500138673162382,-26.455217808683656,-26.410296944204934,-26.365376079726204,-26.320455215247478,-26.27553435076875,-26.23061348629003,-26.1856926218113,-26.140771757332573,-26.09585089285385,-26.050930028375117,-26.006009163896387,-25.961088299417668,-25.916167434938934,-25.871246570460208,-25.826325705981482,-25.781404841502756,-25.736483977024026,-25.67802617484925,-25.551883684194195,-25.42574119353914,-25.29959870288408,-25.173456212229045,-25.047313721573985,-24.92117123091893,-24.7950287402639,-24.66888624960884,-24.54274375895378,-24.416601268298745,-24.29045877764369,-24.164316286988633,-24.038173796333574,-23.91203130567854,-23.785888815023483,-23.659746324368424,-23.533603833713393,-23.40746134305833,-23.281318852403274,-23.15517636174824,-23.029033871093183,-22.902891380438124,-22.77674888978309,-22.650606399128034,-22.524463908472978,-22.34347442059879,-22.155629041103982,-21.96778366160914,-21.779938282114294,-21.592092902619484,-21.40424752312464,-21.216402143629796,-21.028556764134986,-20.840711384640144,-20.6528660051453,-20.465020625650457,-20.27717524615565,-20.089329866660805,-19.90148448716596,-19.71363910767115,-19.525793728176307,-19.33794834868146,-19.150102969186655,-18.96225758969181,-18.774412210196964,-18.586566830702157,-18.398721451207315,-18.21087607171247,-18.023030692217624,-17.835185312722814,-17.647339933227972,-17.45949455373313,-17.27164917423832,-17.083803794743474,-16.895958415248632,-16.708113035753826,-16.52026765625898,-16.317779071955627,-16.077218201539736,-15.836657331123895,-15.596096460708006,-15.355535590292117,-15.114974719876276,-14.874413849460389,-14.633852979044503,-14.393292108628659,-14.15273123821277,-13.912170367796882,-13.67160949738104,-13.431048626965152,-13.190487756549263,-12.949926886133376,-12.709366015717535,-12.468805145301646,-12.228244274885759,-11.987683404469916,-11.747122534054029,-11.506561663638141,-11.266000793222297,-11.02543992280641,-10.784879052390522,-10.544318181974635,-10.30375731155879],[-24.002678450754228,-24.02979266525591,-24.05690687975759,-24.084021094259274,-24.111135308760957,-24.138249523262637,-24.165363737764316,-24.192477952266,-24.219592166767683,-24.246706381269362,-24.273820595771046,-24.300934810272725,-24.32804902477441,-24.355163239276088,-24.382277453777768,-24.409391668279454,-24.43650588278113,-24.463620097282814,-24.4907343117845,-24.51784852628618,-24.54496274078786,-24.57207695528954,-24.599191169791222,-24.626305384292905,-24.653419598794585,-24.680533813296268,-24.707648027797948,-24.73476224229963,-24.761876456801314,-24.788990671302994,-24.816104885804673,-24.843219100306356,-24.870333314808036,-24.89744752930972,-24.924561743811402,-24.951675958313082,-24.97879017281476,-25.005904387316445,-25.033018601818124,-25.060132816319808,-25.087247030821487,-25.11436124532317,-25.141475459824854,-25.168973065875022,-25.19838762610307,-25.227802186331115,-25.257216746559166,-25.286631306787214,-25.31604586701526,-25.34546042724331,-25.374874987471358,-25.404289547699406,-25.433704107927454,-25.463118668155502,-25.492533228383554,-25.521947788611598,-25.551362348839646,-25.580776909067698,-25.610191469295742,-25.63960602952379,-25.66902058975184,-25.69843514997989,-25.72784971020794,-25.757264270435982,-25.786678830664034,-25.816093390892085,-25.845507951120133,-25.87492251134818,-25.90433707157623,-25.933751631804277,-25.963166192032325,-25.992580752260373,-26.02199531248842,-26.05140987271647,-26.080824432944517,-26.110238993172565,-26.139653553400613,-26.16906811362866,-26.19848267385671,-26.227897234084757,-26.25731179431281,-26.286726354540853,-26.3161409147689,-26.34555547499695,-26.374157365154566,-26.402596721298096,-26.431036077441625,-26.459475433585155,-26.487914789728684,-26.516354145872214,-26.544793502015743,-26.573232858159272,-26.601672214302802,-26.63011157044633,-26.65855092658986,-26.68699028273339,-26.71542963887692,-26.74386899502045,-26.77230835116398,-26.800747707307508,-26.829187063451037,-26.85762641959457,-26.8860657757381,-26.914505131881626,-26.942944488025155,-26.971383844168685,-26.999823200312214,-27.028262556455743,-27.056701912599273,-27.085141268742806,-27.113580624886332,-27.14201998102986,-27.17045933717339,-27.19889869331692,-27.22733804946045,-27.255777405603983,-27.28421676174751,-27.312656117891038,-27.341095474034567,-27.369534830178097,-27.397974186321633,-27.426413542465156,-27.454852898608685,-27.483292254752218,-27.510642695401213,-27.53690421943078,-27.563165743460353,-27.589427267489917,-27.61568879151948,-27.641950315549057,-27.66821183957862,-27.694473363608193,-27.720734887637757,-27.746996411667322,-27.773257935696897,-27.79951945972646,-27.825780983756026,-27.852042507785594,-27.878304031815162,-27.904565555844734,-27.930827079874298,-27.957088603903866,-27.983350127933438,-28.009611651963002,-28.035873175992574,-28.06213470002214,-28.08839622405171,-28.114657748081274,-28.140919272110843,-28.167180796140414,-28.19344232016998,-28.21970384419955,-28.245965368229115,-28.27222689225868,-28.29848841628825,-28.324749940317815,-28.351011464347383,-28.377272988376955,-28.40353451240652,-28.429796036436088,-28.45605756046566,-28.482319084495227,-28.508580608524795,-28.53484213255436,-28.56110365658393,-28.587365180613496,-28.613626704643064,-28.64247542400424,-28.672617741031225,-28.70276005805821,-28.73290237508519,-28.763044692112167,-28.793187009139153,-28.82332932616614,-28.853471643193117,-28.883613960220103,-28.91375627724708,-28.943898594274067,-28.97404091130105,-29.00418322832803,-29.034325545355017,-29.064467862381996,-29.094610179408974,-29.12475249643596,-29.154894813462946,-29.185037130489924,-29.21517944751691,-29.245321764543895,-29.275464081570874,-29.305606398597853,-29.335748715624838,-29.36589103265182,-29.396033349678802,-29.426175666705788,-29.45631798373277,-29.486460300759752,-29.51660261778673,-29.546744934813717,-29.5768872518407,-29.60702956886768,-29.63717188589466,-29.66731420292164,-29.69745651994863,-29.72759883697561,-29.75774115400259,-29.787883471029573,-29.81802578805656,-29.848168105083538,-29.878310422110523,-29.908452739137505,-29.938595056164484,-29.968737373191466,-29.998879690218452,-30.029022007245434,-30.05916432427242,-30.089306641299395,-30.11944895832638,-30.149591275353366,-30.17973359238034,-30.209875909407327,-30.24001822643431,-30.270160543461294,-30.300302860488276,-30.33044517751526,-30.36058749454224,-30.390729811569223,-30.420872128596205,-30.451014445623187,-30.48115676265017,-30.51129907967715,-30.541441396704137,-30.571583713731115,-30.601726030758098,-30.631868347785083,-30.662010664812065,-30.692963933418216,-30.72422613626149,-30.755488339104758,-30.78675054194803,-30.818012744791304,-30.849274947634576,-30.88053715047785,-30.911799353321122,-30.943061556164395,-30.974323759007667,-31.00558596185094,-31.036848164694213,-31.068110367537486,-31.09937257038076,-31.13063477322403,-31.127795757272555,-31.090855522526333,-31.053915287780114,-31.016975053033896,-30.98003481828767,-30.943094583541452,-30.906154348795233,-30.869214114049008,-30.83227387930279,-30.79533364455657,-30.758393409810346,-30.721453175064127,-30.684512940317905,-30.647572705571687,-30.61063247082546,-30.573692236079246,-30.536752001333024,-30.514841725674223,-30.49455970895426,-30.474277692234306,-30.453995675514346,-30.43371365879439,-30.413431642074436,-30.393149625354475,-30.372867608634515,-30.35258559191456,-30.332303575194597,-30.312021558474644,-30.29173954175469,-30.271457525034727,-30.251175508314773,-30.23089349159481,-30.210611474874852,-30.1903294581549,-30.170047441434935,-30.149765424714978,-30.129483407995025,-30.10920139127506,-30.088919374555108,-30.06863735783515,-30.048355341115187,-30.028073324395233,-30.007791307675276,-29.987509290955316,-29.967227274235363,-29.946945257515402,-29.926663240795442,-29.90638122407548,-29.886099207355528,-29.865817190635575,-29.845535173915614,-29.825253157195654,-29.804971140475697,-29.784689123755737,-29.76440710703578,-29.744125090315826,-29.723843073595866,-29.703561056875905,-29.683279040155952,-29.66299702343599,-29.64271500671604,-29.622432989996078,-29.602150973276117,-29.581868956556164,-29.561586939836204,-29.541304923116247,-29.52102290639629,-29.50074088967633,-29.480458872956376,-29.460176856236416,-29.439894839516455,-29.419612822796502,-29.399330806076545,-29.379048789356585,-29.358766772636628,-29.338484755916667,-29.31820273919671,-29.297920722476753,-29.2776387057568,-29.257356689036836,-29.237074672316876,-29.21679265559692,-29.196510638876966,-29.169135243745465,-29.127573091790893,-29.086010939836317,-29.044448787881734,-29.00288663592716,-28.961324483972586,-28.919762332018003,-28.878200180063423,-28.83663802810885,-28.79507587615427,-28.753513724199696,-28.71195157224512,-28.670389420290544,-28.628827268335964,-28.587265116381392,-28.545702964426816,-28.504140812472237,-28.46257866051766,-28.421016508563085,-28.379454356608502,-28.337892204653926,-28.296330052699346,-28.254767900744774,-28.211246492197695,-28.166325627718972,-28.121404763240243,-28.076483898761516,-28.03156303428279,-27.986642169804064,-27.941721305325338,-27.896800440846604,-27.851879576367885,-27.806958711889155,-27.762037847410426,-27.717116982931703,-27.672196118452973,-27.627275253974247,-27.58235438949552,-27.537433525016798,-27.492512660538065,-27.447591796059342,-27.402670931580616,-27.35775006710189,-27.312829202623156,-27.26790833814443,-27.222987473665707,-27.178066609186978,-27.13314574470825,-27.08822488022953,-27.0433040157508,-26.998383151272073,-26.953462286793346,-26.908541422314613,-26.86362055783589,-26.818699693357168,-26.77377882887844,-26.728857964399708,-26.683937099920982,-26.639016235442263,-26.59409537096353,-26.549174506484803,-26.504253642006077,-26.45933277752735,-26.414411913048628,-26.3694910485699,-26.324570184091165,-26.27964931961244,-26.23472845513372,-26.189807590654993,-26.14488672617626,-26.099965861697534,-26.05504499721881,-26.01012413274008,-25.965203268261355,-25.92028240378263,-25.8753615393039,-25.830440674825173,-25.78551981034645,-25.740598945867717,-25.69567808138899,-25.650757216910268,-25.60583635243154,-25.560915487952812,-25.502457685778033,-25.376315195122977,-25.25017270446792,-25.124030213812865,-24.99788772315783,-24.871745232502768,-24.745602741847712,-24.619460251192677,-24.49331776053762,-24.367175269882566,-24.24103277922753,-24.11489028857247,-23.98874779791742,-23.862605307262356,-23.73646281660732,-23.610320325952266,-23.484177835297206,-23.358035344642175,-23.231892853987112,-23.105750363332056,-22.979607872677022,-22.853465382021966,-22.72732289136691,-22.601180400711876,-22.47503791005682,-22.348895419401757,-22.2227529287467,-22.096610438091666,-21.97046794743661,-21.795226149977527,-21.618198933454163,-21.441171716930775,-21.26414450040738,-21.08711728388402,-20.910090067360628,-20.733062850837236,-20.556035634313844,-20.37900841779048,-20.201981201267092,-20.024953984743696,-19.84792676822034,-19.670899551696944,-19.49387233517355,-19.316845118650193,-19.139817902126797,-18.96279068560341,-18.78576346908005,-18.608736252556653,-18.431709036033265,-18.25468181950987,-18.077654602986513,-17.90062738646312,-17.723600169939726,-17.546572953416366,-17.369545736892974,-17.17970033941822,-16.939139469002374,-16.698578598586487,-16.4580177281706,-16.217456857754712,-15.97689598733887,-15.736335116922982,-15.495774246507093,-15.25521337609125,-15.014652505675361,-14.774091635259477,-14.533530764843633,-14.292969894427745,-14.052409024011858,-13.811848153596014,-13.571287283180126,-13.330726412764237,-13.090165542348352,-12.849604671932507,-12.60904380151662,-12.368482931100733,-12.127922060684888,-11.887361190269,-11.646800319853114,-11.40623944943727,-11.165678579021383,-10.925117708605494,-10.684556838189607,-10.443995967773766],[-23.573008580062396,-23.600122794564076,-23.62723700906576,-23.65435122356744,-23.68146543806912,-23.708579652570805,-23.735693867072484,-23.762808081574164,-23.78992229607585,-23.81703651057753,-23.84415072507921,-23.87126493958089,-23.898379154082576,-23.925493368584256,-23.95260758308594,-23.979721797587622,-24.006836012089302,-24.03395022659098,-24.06106444109266,-24.088178655594348,-24.115292870096027,-24.142407084597707,-24.16952129909939,-24.19663551360107,-24.223749728102753,-24.250863942604433,-24.277978157106116,-24.3050923716078,-24.33220658610948,-24.35932080061116,-24.38643501511284,-24.413549229614524,-24.440663444116204,-24.467777658617887,-24.49489187311957,-24.52200608762125,-24.54912030212293,-24.57623451662461,-24.603348731126296,-24.630462945627976,-24.657577160129655,-24.68469137463134,-24.71180558913302,-24.7389198036347,-24.766034018136384,-24.793148232638064,-24.820262447139747,-24.847376661641427,-24.87449087614311,-24.901605090644793,-24.928719305146473,-24.955833519648156,-24.982947734149835,-25.010061948651515,-25.037176163153198,-25.064290377654878,-25.091404592156564,-25.118518806658244,-25.145633021159924,-25.172747235661607,-25.201395015829142,-25.23080957605719,-25.260224136285238,-25.289638696513286,-25.319053256741338,-25.348467816969386,-25.37788237719743,-25.40729693742548,-25.43671149765353,-25.466126057881578,-25.495540618109626,-25.52495517833767,-25.554369738565722,-25.58378429879377,-25.613198859021818,-25.642613419249866,-25.672027979477914,-25.701442539705965,-25.730857099934013,-25.760271660162058,-25.78968622039011,-25.819100780618157,-25.848515340846205,-25.877929901074253,-25.906531791231867,-25.934971147375396,-25.963410503518926,-25.99184985966246,-26.020289215805985,-26.048728571949514,-26.077167928093044,-26.10560728423657,-26.134046640380102,-26.162485996523632,-26.190925352667165,-26.219364708810687,-26.247804064954224,-26.27624342109775,-26.304682777241283,-26.33312213338481,-26.36156148952834,-26.39000084567187,-26.418440201815397,-26.44687955795893,-26.475318914102456,-26.50375827024599,-26.532197626389518,-26.560636982533044,-26.58689850831245,-26.613160032342023,-26.639421556371587,-26.66568308040116,-26.691944604430724,-26.718206128460295,-26.74446765248986,-26.770729176519428,-26.796990700549,-26.823252224578567,-26.849513748608132,-26.8757752726377,-26.902036796667268,-26.928298320696836,-26.954559844726404,-26.980821368755972,-27.00708289278554,-27.03334441681511,-27.05960594084468,-27.085867464874244,-27.11212898890381,-27.138390512933384,-27.16465203696295,-27.19091356099252,-27.217175085022085,-27.24343660905165,-27.26969813308122,-27.295959657110785,-27.322221181140353,-27.34848270516992,-27.374744229199493,-27.40100575322906,-27.42726727725863,-27.453528801288194,-27.479790325317765,-27.50605184934733,-27.5323133733769,-27.558574897406466,-27.584836421436037,-27.611097945465602,-27.63735946949517,-27.663620993524738,-27.689882517554306,-27.716144041583874,-27.74240556561344,-27.76866708964301,-27.794928613672575,-27.821190137702146,-27.84745166173171,-27.873713185761282,-27.899974709790847,-27.92623623382042,-27.952497757849983,-27.978759281879555,-28.00502080590912,-28.03128232993869,-28.057543853968255,-28.083805377997827,-28.11006690202739,-28.13891562138857,-28.169057938415552,-28.199200255442534,-28.229342572469516,-28.2594848894965,-28.289627206523484,-28.319769523550466,-28.349911840577448,-28.380054157604434,-28.41019647463141,-28.440338791658395,-28.470481108685377,-28.500623425712362,-28.53076574273934,-28.560908059766323,-28.591050376793305,-28.62119269382029,-28.651335010847273,-28.681477327874255,-28.71161964490124,-28.74176196192822,-28.7719042789552,-28.802046595982183,-28.83218891300917,-28.862331230036148,-28.892473547063126,-28.922615864090115,-28.952758181117094,-28.982900498144076,-29.013042815171058,-29.043185132198044,-29.073327449225022,-29.103469766252008,-29.13361208327899,-29.163754400305972,-29.193896717332954,-29.224039034359933,-29.25418135138692,-29.284323668413904,-29.314465985440883,-29.34460830246787,-29.374750619494854,-29.404892936521833,-29.43503525354881,-29.465177570575797,-29.495319887602783,-29.52546220462976,-29.555604521656747,-29.58574683868373,-29.615889155710708,-29.646031472737693,-29.676173789764675,-29.706316106791654,-29.73645842381864,-29.766600740845618,-29.796743057872604,-29.826885374899586,-29.857027691926564,-29.88717000895355,-29.917312325980536,-29.947454643007518,-29.977596960034496,-30.007739277061482,-30.03788159408846,-30.067847074401172,-30.09698730993162,-30.12612754546207,-30.15526778099252,-30.18440801652297,-30.213548252053414,-30.242688487583866,-30.271828723114314,-30.300968958644763,-30.330109194175215,-30.35924942970566,-30.388389665236108,-30.41752990076656,-30.44667013629701,-30.475810371827453,-30.504950607357905,-30.534090842888354,-30.563231078418802,-30.59237131394925,-30.60440610197366,-30.599335442492034,-30.594264783010406,-30.58919412352878,-30.58412346404715,-30.57905280456552,-30.573982145083896,-30.568911485602268,-30.56384082612064,-30.558770166639015,-30.553699507157383,-30.54742989313604,-30.52720883617896,-30.506987779221877,-30.486766722264793,-30.466545665307713,-30.446324608350626,-30.426103551393545,-30.40588249443646,-30.38566143747938,-30.365440380522298,-30.34521932356521,-30.324998266608134,-30.304777209651043,-30.28455615269396,-30.264335095736882,-30.244114038779795,-30.22389298182271,-30.20367192486563,-30.183450867908547,-30.163229810951464,-30.14300875399438,-30.1227876970373,-30.102566640080216,-30.08234558312313,-30.062124526166045,-30.041903469208965,-30.02168241225188,-30.001461355294797,-29.981240298337717,-29.96101924138063,-29.94079818442355,-29.92057712746647,-29.900356070509382,-29.880135013552298,-29.85991395659522,-29.839692899638134,-29.81947184268105,-29.79925078572397,-29.779029728766886,-29.758808671809803,-29.73858761485272,-29.718366557895635,-29.69814550093855,-29.677924443981468,-29.65770338702439,-29.6374823300673,-29.61726127311022,-29.597040216153136,-29.576819159196052,-29.556598102238972,-29.536377045281885,-29.516155988324808,-29.49593493136772,-29.475713874410637,-29.455492817453557,-29.43527176049647,-29.415050703539386,-29.394829646582306,-29.374608589625222,-29.35438753266814,-29.334166475711054,-29.313945418753974,-29.293724361796887,-29.273503304839807,-29.253282247882723,-29.23306119092564,-29.21284013396856,-29.19261907701147,-29.17239802005439,-29.152176963097304,-29.131955906140224,-29.11173484918314,-29.083201475237736,-29.038043467315703,-28.992885459393662,-28.947727451471625,-28.902569443549588,-28.857411435627554,-28.81225342770551,-28.767095419783473,-28.72193741186144,-28.676779403939403,-28.631621396017366,-28.58646338809533,-28.54130538017329,-28.49614737225125,-28.450989364329217,-28.40583135640718,-28.360673348485143,-28.31551534056311,-28.270357332641073,-28.22519932471903,-28.18004131679699,-28.134883308874958,-28.08972530095292,-28.044567293030884,-27.999409285108847,-27.95425127718681,-27.909093269264773,-27.863935261342736,-27.8187772534207,-27.77361924549866,-27.728461237576617,-27.68330322965459,-27.63814522173255,-27.59298721381051,-27.547829205888476,-27.50267119796644,-27.4575131900444,-27.412355182122365,-27.367197174200328,-27.322039166278287,-27.276881158356254,-27.231723150434217,-27.18656514251218,-27.141407134590136,-27.096249126668102,-27.051091118746065,-27.005933110824028,-26.960775102901987,-26.915617094979957,-26.870459087057917,-26.82530107913588,-26.780143071213843,-26.734985063291806,-26.689827055369765,-26.644669047447735,-26.599511039525694,-26.554353031603654,-26.509195023681617,-26.464037015759587,-26.418879007837543,-26.37372099991551,-26.32868515293486,-26.283764288456126,-26.238843423977404,-26.19392255949868,-26.149001695019955,-26.10408083054122,-26.059159966062502,-26.01423910158377,-25.969318237105043,-25.92439737262632,-25.879476508147594,-25.83455564366886,-25.789634779190134,-25.74471391471141,-25.69979305023268,-25.654872185753952,-25.609951321275233,-25.5650304567965,-25.520109592317773,-25.475188727839047,-25.43026786336032,-25.385346998881595,-25.326889196706816,-25.20074670605176,-25.074604215396704,-24.948461724741644,-24.774893654949594,-24.597866438426202,-24.420839221902813,-24.24381200537945,-24.06678478885606,-23.889757572332666,-23.712730355809303,-23.535703139285914,-23.35867592276252,-23.181648706239127,-23.004621489715767,-22.827594273192375,-22.650567056668983,-22.473539840145623,-22.29651262362223,-22.11948540709884,-21.94245819057548,-21.765430974052084,-21.588403757528695,-21.411376541005332,-21.234349324481943,-21.057322107958548,-20.88029489143516,-20.7032676749118,-20.526240458388408,-20.349213241865012,-20.172186025341656,-19.99515880881826,-19.81813159229487,-19.641104375771505,-19.464077159248113,-19.28704994272472,-19.11002272620133,-18.932995509677973,-18.75596829315458,-18.57894107663119,-18.401913860107825,-18.224886643584433,-18.04785942706104,-17.87083221053768,-17.69380499401429,-17.516777777490898,-17.339750560967538,-17.162723344444146,-16.985696127920754,-16.808668911397362,-16.631641694874,-16.454614478350607,-16.277587261827215,-16.100560045303855,-15.923532828780463,-15.74650561225707,-15.56947839573371,-15.392451179210319,-15.215423962686927,-15.038396746163533,-14.861369529640175,-14.684342313116781,-14.507315096593391,-14.33028788007003,-14.153260663546636,-13.976233447023244,-13.799206230499884,-13.622179013976492,-13.4451517974531,-13.26812458092974,-13.091097364406348,-12.914070147882954,-12.737042931359563,-12.560015714836203,-12.382988498312809,-12.205961281789417,-12.028934065266057,-11.851906848742665,-11.674879632219273,-11.497852415695913,-11.30591723523636,-11.06535636482047,-10.824795494404583,-10.58423462398874],[-23.143338709370568,-23.170452923872247,-23.197567138373927,-23.224681352875606,-23.25179556737729,-23.278909781878973,-23.306023996380652,-23.333138210882336,-23.36025242538402,-23.3873666398857,-23.414480854387378,-23.44159506888906,-23.468709283390744,-23.495823497892424,-23.522937712394107,-23.55005192689579,-23.57716614139747,-23.60428035589915,-23.631394570400833,-23.658508784902516,-23.685622999404195,-23.712737213905875,-23.739851428407555,-23.76696564290924,-23.79407985741092,-23.8211940719126,-23.848308286414287,-23.875422500915967,-23.902536715417646,-23.929650929919326,-23.95676514442101,-23.983879358922692,-24.010993573424372,-24.038107787926055,-24.06522200242774,-24.092336216929418,-24.119450431431098,-24.14656464593278,-24.173678860434464,-24.200793074936144,-24.227907289437823,-24.255021503939506,-24.28213571844119,-24.30924993294287,-24.33636414744455,-24.363478361946232,-24.390592576447915,-24.417706790949595,-24.444821005451278,-24.47193521995296,-24.49904943445464,-24.526163648956324,-24.553277863458003,-24.580392077959687,-24.60750629246137,-24.63462050696305,-24.661734721464732,-24.688848935966412,-24.71596315046809,-24.74307736496978,-24.770191579471458,-24.79730579397314,-24.82442000847482,-24.8515342229765,-24.87864843747818,-24.905762651979863,-24.932876866481546,-24.959991080983226,-24.98710529548491,-25.01421950998659,-25.041333724488272,-25.06844793898995,-25.095562153491635,-25.122676367993318,-25.149790582494997,-25.17690479699668,-25.204402405555218,-25.23381696578327,-25.263231526011317,-25.292646086239362,-25.322060646467413,-25.35147520669546,-25.38088976692351,-25.41030432715156,-25.43890621730917,-25.467345573452704,-25.49578492959623,-25.524224285739763,-25.552663641883292,-25.58110299802682,-25.609542354170348,-25.636892797194132,-25.663154321223704,-25.68941584525327,-25.71567736928284,-25.741938893312405,-25.768200417341976,-25.79446194137154,-25.82072346540111,-25.846984989430677,-25.873246513460245,-25.899508037489817,-25.92576956151938,-25.95203108554895,-25.978292609578517,-26.004554133608085,-26.030815657637653,-26.057077181667218,-26.08333870569679,-26.109600229726357,-26.135861753755925,-26.162123277785494,-26.188384801815058,-26.21464632584463,-26.240907849874194,-26.267169373903762,-26.293430897933334,-26.3196924219629,-26.345953945992463,-26.372215470022034,-26.3984769940516,-26.42473851808117,-26.451000042110735,-26.477261566140307,-26.50352309016987,-26.529784614199443,-26.55604613822901,-26.58230766225858,-26.608569186288143,-26.634830710317715,-26.66109223434728,-26.68735375837685,-26.71361528240642,-26.73987680643598,-26.76613833046555,-26.792399854495123,-26.818661378524688,-26.844922902554252,-26.871184426583824,-26.897445950613392,-26.92370747464296,-26.949968998672528,-26.976230522702096,-27.002492046731664,-27.028753570761232,-27.0550150947908,-27.081276618820368,-27.107538142849936,-27.1337996668795,-27.160061190909072,-27.186322714938637,-27.21258423896821,-27.238845762997773,-27.26510728702734,-27.29136881105691,-27.317630335086477,-27.343891859116045,-27.370153383145613,-27.39641490717518,-27.42267643120475,-27.448937955234317,-27.475199479263885,-27.501461003293453,-27.527722527323018,-27.55398405135259,-27.580245575382158,-27.606507099411726,-27.635355818772904,-27.665498135799886,-27.695640452826865,-27.72578276985385,-27.755925086880833,-27.78606740390782,-27.8162097209348,-27.846352037961783,-27.876494354988765,-27.906636672015743,-27.93677898904273,-27.966921306069707,-27.997063623096693,-28.027205940123675,-28.057348257150657,-28.08749057417764,-28.117632891204625,-28.147775208231607,-28.177917525258586,-28.20805984228557,-28.2373769190821,-28.26651715461255,-28.295657390142996,-28.324797625673447,-28.353937861203892,-28.383078096734344,-28.412218332264793,-28.44135856779524,-28.47049880332569,-28.499639038856138,-28.528779274386586,-28.55791950991704,-28.587059745447483,-28.61619998097793,-28.64534021650838,-28.67448045203883,-28.70362068756928,-28.732760923099725,-28.761901158630177,-28.791041394160622,-28.82018162969107,-28.849321865221523,-28.87846210075197,-28.907602336282416,-28.93674257181287,-28.96588280734332,-28.995023042873765,-29.024163278404217,-29.053303513934665,-29.082443749465114,-29.111583984995562,-29.140724220526014,-29.16986445605646,-29.19900469158691,-29.228144927117356,-29.257285162647804,-29.286425398178253,-29.3155656337087,-29.344705869239153,-29.3738461047696,-29.402986340300046,-29.432126575830498,-29.46126681136095,-29.4904070468914,-29.519547282421843,-29.548687517952295,-29.577827753482744,-29.606967989013192,-29.63610822454364,-29.66524846007409,-29.694388695604538,-29.723528931134986,-29.752669166665434,-29.781809402195886,-29.810949637726335,-29.840089873256783,-29.86923010878723,-29.89837034431768,-29.92751057984813,-29.956650815378573,-29.98579105090903,-30.014931286439477,-30.044071521969926,-30.056106309994334,-30.051035650512706,-30.045964991031077,-30.040894331549453,-30.035823672067828,-30.030753012586196,-30.02568235310457,-30.02061169362294,-30.01554103414131,-30.01047037465969,-30.005399715178058,-30.00032905569643,-29.9952583962148,-29.990187736733176,-29.985117077251548,-29.98004641776992,-29.974975758288295,-29.969905098806667,-29.96483443932504,-29.959763779843414,-29.954693120361785,-29.949622460880157,-29.94455180139853,-29.9394811419169,-29.934410482435275,-29.929339822953647,-29.92426916347202,-29.91919850399039,-29.914127844508762,-29.909057185027137,-29.90398652554551,-29.89891586606388,-29.893845206582256,-29.888774547100628,-29.883703887619,-29.878633228137375,-29.873562568655746,-29.868491909174118,-29.86342124969249,-29.846579057328242,-29.826358000371158,-29.806136943414078,-29.785915886456998,-29.765694829499907,-29.74547377254283,-29.725252715585746,-29.705031658628663,-29.68481060167158,-29.664589544714495,-29.644368487757415,-29.624147430800328,-29.603926373843244,-29.583705316886164,-29.56348425992908,-29.543263202971993,-29.523042146014916,-29.502821089057832,-29.48260003210075,-29.462378975143665,-29.442157918186584,-29.421936861229497,-29.401715804272417,-29.381494747315333,-29.361273690358246,-29.341052633401166,-29.320831576444085,-29.300610519486998,-29.280389462529918,-29.260168405572834,-29.23994734861575,-29.219726291658667,-29.199505234701583,-29.179284177744503,-29.159063120787415,-29.138842063830335,-29.118621006873255,-29.09839994991617,-29.078178892959084,-29.057957836002004,-29.03773677904492,-29.017515722087836,-28.997294665130752,-28.97707360817367,-28.94854023422826,-28.903382226306228,-28.858224218384194,-28.813066210462154,-28.76790820254012,-28.722750194618083,-28.677592186696046,-28.632434178774005,-28.587276170851972,-28.54211816292993,-28.496960155007898,-28.451802147085857,-28.406644139163824,-28.361486131241783,-28.316328123319746,-28.27117011539771,-28.226012107475672,-28.180854099553635,-28.1356960916316,-28.09053808370956,-28.04538007578752,-28.000222067865487,-27.95506405994345,-27.909906052021412,-27.864748044099372,-27.81959003617734,-27.7744320282553,-27.729274020333264,-27.684116012411224,-27.63895800448919,-27.593799996567153,-27.548641988645116,-27.503483980723075,-27.45832597280104,-27.413167964879,-27.36800995695696,-27.322851949034927,-27.277693941112894,-27.23253593319086,-27.18737792526882,-27.142219917346782,-27.097061909424745,-27.051903901502705,-27.00674589358067,-26.96158788565863,-26.916429877736597,-26.871271869814557,-26.826113861892523,-26.780955853970482,-26.735797846048445,-26.69063983812641,-26.645481830204375,-26.600323822282334,-26.555165814360294,-26.509585905145123,-26.46148324679521,-26.4133805884453,-26.36527793009539,-26.317175271745484,-26.26907261339557,-26.22096995504566,-26.172867296695753,-26.124764638345837,-26.076661979995933,-26.028559321646018,-25.980456663296106,-25.932354004946195,-25.88425134659629,-25.83614868824638,-25.788046029896464,-25.739943371546556,-25.691840713196648,-25.643738054846732,-25.595635396496824,-25.54753273814692,-25.499430079797,-25.451327421447093,-25.40322476309719,-25.355122104747274,-25.30701944639736,-25.258916788047447,-25.21081412969754,-25.162711471347627,-25.107775880794996,-25.018675629228728,-24.92957537766246,-24.84047512609619,-24.751374874529937,-24.662274622963665,-24.573174371397393,-24.484074119831142,-24.39497386826487,-24.305873616698598,-24.216773365132347,-24.127673113566075,-24.038572861999807,-23.94947261043354,-23.860372358867284,-23.771272107301012,-23.68217185573474,-23.59307160416849,-23.503971352602218,-23.414871101035953,-23.3257708494697,-23.236670597903426,-23.14757034633715,-23.058470094770904,-22.969369843204632,-22.880269591638363,-22.79116934007209,-22.702069088505837,-22.612968836939565,-22.523868585373297,-22.434768333807042,-22.345668082240774,-22.256567830674506,-22.155743796047798,-21.978716579524406,-21.80168936300101,-21.62466214647762,-21.447634929954262,-21.270607713430866,-21.093580496907478,-20.916553280384115,-20.739526063860723,-20.56249884733733,-20.38547163081397,-20.20844441429058,-20.031417197767187,-19.854389981243823,-19.677362764720435,-19.50033554819704,-19.323308331673648,-19.14368125390859,-18.88865320394742,-18.63362515398625,-18.37859710402513,-18.123569054063964,-17.868541004102795,-17.613512954141676,-17.358484904180507,-17.10345685421934,-16.84842880425817,-16.59340075429705,-16.33837270433588,-16.083344654374716,-15.828316604413594,-15.573288554452429,-15.31826050449126,-15.063232454530137,-14.808204404568972,-14.553176354607803,-14.298148304646684,-14.043120254685515,-13.788092204724347,-13.533064154763181,-13.278036104802059,-13.023008054840894,-12.767980004879725,-12.512951954918604,-12.257923904957435,-12.002895854996268,-11.747867805035149,-11.49283975507398,-11.237811705112811,-10.982783655151646,-10.727755605190524],[-22.708416038823046,-22.733098819354378,-22.757781599885707,-22.78246438041704,-22.807147160948375,-22.83182994147971,-22.85651272201104,-22.881195502542372,-22.905878283073708,-22.93056106360504,-22.95727004275723,-22.98438425725891,-23.011498471760596,-23.038612686262272,-23.065726900763956,-23.09284111526564,-23.11995532976732,-23.147069544269,-23.17418375877068,-23.20129797327236,-23.228412187774044,-23.255526402275727,-23.282640616777407,-23.30975483127909,-23.336869045780773,-23.363983260282453,-23.391097474784136,-23.418211689285815,-23.4453259037875,-23.472440118289178,-23.499554332790858,-23.52666854729254,-23.553782761794224,-23.580896976295904,-23.608011190797587,-23.63512540529927,-23.66223961980095,-23.68935383430263,-23.716468048804312,-23.743582263305996,-23.770696477807675,-23.797810692309355,-23.82492490681104,-23.85203912131272,-23.8791533358144,-23.90626755031608,-23.933381764817764,-23.960495979319447,-23.987610193821126,-24.01472440832281,-24.041838622824493,-24.068952837326172,-24.096067051827852,-24.123181266329535,-24.15029548083122,-24.177409695332898,-24.204523909834577,-24.23163812433626,-24.258752338837944,-24.285866553339623,-24.312980767841303,-24.340094982342986,-24.36720919684467,-24.394323411346353,-24.421437625848036,-24.44855184034971,-24.475666054851395,-24.502780269353075,-24.52989448385476,-24.557008698356434,-24.58412291285812,-24.6112371273598,-24.638351341861483,-24.665465556363166,-24.692579770864842,-24.719693985366526,-24.74680819986821,-24.773922414369892,-24.80103662887157,-24.82815084337326,-24.855265057874934,-24.882379272376614,-24.909493486878297,-24.93660770137998,-24.961113555809373,-24.985097738224308,-25.00908192063924,-25.033066103054175,-25.05705028546911,-25.081034467884038,-25.105018650298973,-25.12900283271391,-25.15298701512884,-25.178489428701397,-25.20475095273096,-25.23101247676053,-25.2572740007901,-25.28353552481967,-25.309797048849237,-25.3360585728788,-25.36232009690837,-25.38858162093794,-25.414843144967506,-25.44110466899707,-25.467366193026646,-25.49362771705621,-25.519889241085778,-25.546150765115343,-25.57241228914491,-25.598673813174486,-25.62493533720405,-25.65119686123362,-25.677458385263183,-25.703719909292758,-25.729981433322322,-25.75624295735189,-25.782504481381455,-25.808766005411023,-25.83502752944059,-25.861289053470163,-25.88755057749973,-25.913812101529295,-25.940073625558867,-25.96633514958843,-25.992596673618003,-26.018858197647567,-26.04511972167714,-26.071381245706704,-26.09764276973627,-26.12390429376584,-26.150165817795404,-26.176427341824976,-26.20268886585454,-26.228950389884112,-26.25521191391368,-26.281473437943248,-26.307734961972812,-26.333996486002384,-26.36025801003195,-26.38651953406152,-26.412781058091085,-26.439042582120656,-26.46530410615022,-26.49156563017979,-26.517827154209357,-26.54408867823893,-26.570350202268493,-26.596611726298065,-26.62287325032763,-26.6491347743572,-26.675396298386765,-26.70165782241633,-26.727919346445905,-26.754180870475473,-26.78044239450504,-26.806703918534605,-26.832965442564173,-26.859226966593738,-26.88548849062331,-26.911750014652874,-26.938011538682446,-26.96427306271201,-26.990534586741582,-27.016796110771146,-27.043057634800718,-27.069319158830286,-27.09558068285985,-27.12315303713325,-27.151380806528557,-27.17960857592387,-27.207836345319183,-27.236064114714495,-27.26429188410981,-27.292519653505117,-27.320747422900432,-27.348975192295743,-27.377202961691054,-27.405430731086366,-27.433658500481677,-27.46188626987699,-27.490114039272303,-27.518341808667614,-27.546569578062925,-27.57479734745824,-27.603025116853548,-27.63125288624886,-27.659936891572322,-27.68907712710277,-27.71821736263322,-27.747357598163667,-27.77649783369412,-27.805638069224564,-27.834778304755016,-27.863918540285464,-27.893058775815913,-27.92219901134636,-27.95133924687681,-27.980479482407258,-28.00961971793771,-28.038759953468155,-28.067900188998603,-28.097040424529055,-28.1261806600595,-28.155320895589952,-28.1844611311204,-28.21360136665085,-28.242741602181294,-28.271881837711746,-28.301022073242194,-28.330162308772643,-28.35930254430309,-28.388442779833547,-28.417583015363988,-28.446723250894436,-28.475863486424885,-28.505003721955337,-28.53414395748579,-28.563284193016237,-28.592424428546686,-28.621564664077127,-28.650704899607582,-28.67984513513803,-28.70898537066848,-28.738125606198924,-28.767265841729376,-28.79640607725982,-28.825546312790273,-28.85468654832072,-28.88382678385117,-28.912967019381618,-28.94210725491207,-28.97124749044252,-29.000387725972963,-29.02952796150342,-29.05866819703386,-29.087808432564316,-29.11694866809476,-29.14608890362521,-29.175229139155658,-29.20436937468611,-29.233509610216558,-29.262649845747003,-29.291790081277455,-29.320930316807903,-29.35007055233835,-29.379210787868796,-29.40835102339925,-29.437491258929693,-29.46663149446015,-29.4957717299906,-29.507806518015006,-29.502735858533377,-29.49766519905175,-29.492594539570124,-29.487523880088492,-29.482453220606867,-29.47738256112524,-29.472311901643614,-29.467241242161986,-29.462170582680358,-29.45709992319873,-29.452029263717105,-29.446958604235476,-29.44188794475385,-29.436817285272223,-29.431746625790595,-29.42667596630897,-29.421605306827338,-29.416534647345713,-29.411463987864085,-29.406393328382457,-29.401322668900832,-29.396252009419204,-29.391181349937575,-29.38611069045595,-29.381040030974322,-29.375969371492694,-29.370898712011066,-29.36582805252944,-29.360757393047813,-29.355686733566184,-29.350616074084556,-29.34554541460293,-29.3404747551213,-29.335404095639674,-29.330333436158046,-29.325262776676418,-29.320192117194793,-29.315121457713165,-29.310050798231536,-29.304980138749908,-29.299909479268283,-29.294838819786655,-29.289768160305027,-29.2846975008234,-29.279626841341774,-29.274556181860145,-29.269485522378517,-29.26441486289689,-29.25934420341526,-29.254273543933635,-29.249202884452007,-29.24413222497038,-29.239061565488754,-29.233990906007126,-29.228920246525497,-29.22384958704387,-29.21877892756224,-29.213708268080616,-29.20863760859899,-29.203566949117363,-29.198496289635735,-29.19342563015411,-29.18835497067248,-29.183284311190853,-29.178213651709225,-29.165949278477527,-29.145728221520443,-29.12550716456336,-29.105286107606283,-29.08506505064919,-29.06484399369211,-29.04462293673503,-29.02440187977794,-29.004180822820864,-28.98395976586378,-28.963738708906696,-28.943517651949616,-28.92329659499253,-28.903075538035445,-28.88285448107836,-28.86263342412128,-28.842412367164194,-28.81387899321879,-28.76872098529676,-28.72356297737472,-28.678404969452682,-28.633246961530645,-28.58808895360861,-28.54293094568657,-28.49777293776453,-28.4526149298425,-28.40745692192046,-28.36229891399842,-28.317140906076382,-28.27198289815435,-28.22682489023231,-28.181666882310275,-28.136508874388237,-28.0913508664662,-28.046192858544167,-28.00103485062213,-27.95587684270009,-27.91071883477805,-27.864286530882207,-27.8161838725323,-27.768081214182388,-27.71997855583248,-27.671875897482572,-27.623773239132657,-27.575670580782752,-27.52756792243284,-27.479465264082926,-27.431362605733014,-27.383259947383113,-27.335157289033194,-27.287054630683283,-27.238951972333375,-27.190849313983467,-27.14274665563355,-27.094643997283647,-27.04654133893374,-26.998438680583824,-26.950336022233913,-26.902233363884005,-26.85413070553409,-26.806028047184178,-26.757925388834273,-26.709822730484365,-26.66172007213445,-26.613617413784546,-26.565514755434634,-26.51741209708472,-26.46930943873481,-26.421206780384903,-26.37310412203499,-26.325001463685076,-26.276898805335172,-26.22879614698526,-26.18069348863535,-26.132590830285437,-26.084488171935533,-26.036385513585618,-25.98828285523571,-25.940180196885798,-25.892077538535887,-25.84397488018598,-25.79587222183607,-25.747769563486152,-25.69966690513624,-25.651564246786336,-25.603461588436428,-25.555358930086513,-25.5072562717366,-25.459153613386697,-25.41105095503678,-25.362948296686874,-25.314845638336966,-25.26674297998705,-25.21864032163714,-25.170537663287234,-25.12243500493732,-25.074332346587408,-25.0262296882375,-24.978127029887588,-24.930024371537677,-24.87508878098505,-24.78598852941878,-24.6968882778525,-24.607788026286237,-24.518687774719982,-24.429587523153714,-24.340487271587442,-24.25138702002119,-24.16228676845492,-24.073186516888647,-23.984086265322397,-23.894986013756125,-23.805885762189853,-23.71678551062358,-23.62768525905733,-23.538585007491058,-23.449484755924793,-23.360384504358535,-23.271284252792267,-23.182184001226,-23.09308374965974,-23.003983498093472,-22.914883246527204,-22.825782994960946,-22.664785867686508,-22.50066262056597,-22.336539373445426,-22.17241612632492,-22.008292879204376,-21.844169632083837,-21.680046384963326,-21.51592313784279,-21.351799890722248,-21.187676643601737,-21.023553396481198,-20.85943014936066,-20.69530690224012,-20.531183655119605,-20.367060407999066,-20.202937160878527,-20.03881391375802,-19.874690666637477,-19.710567419516938,-19.546444172396427,-19.382320925275888,-19.21819767815535,-19.054074431034834,-18.8899511839143,-18.72582793679376,-18.56170468967322,-18.39758144255271,-18.233458195432167,-18.069334948311628,-17.90521170119112,-17.741088454070578,-17.57696520695004,-17.41284195982953,-17.24871871270899,-17.08459546558845,-16.92047221846791,-16.73741027482734,-16.48238222486617,-16.227354174905003,-15.972326124943883,-15.717298074982716,-15.462270025021546,-15.207241975060427,-14.95221392509926,-14.697185875138093,-14.442157825176972,-14.187129775215805,-13.932101725254636,-13.67707367529347,-13.422045625332348,-13.16701757537118,-12.911989525410013,-12.656961475448892,-12.401933425487725,-12.146905375526558,-11.891877325565437,-11.63684927560427,-11.381821225643103,-11.126793175681934,-10.871765125720813],[-22.269291126749906,-22.293973907281238,-22.318656687812567,-22.3433394683439,-22.368022248875235,-22.39270502940657,-22.4173878099379,-22.442070590469232,-22.466753371000568,-22.4914361515319,-22.516118932063236,-22.540801712594565,-22.565484493125897,-22.590167273657233,-22.614850054188565,-22.6395328347199,-22.66421561525123,-22.688898395782566,-22.713581176313898,-22.73826395684523,-22.762946737376566,-22.787629517907895,-22.812312298439227,-22.836995078970563,-22.861677859501892,-22.886360640033228,-22.911853901799056,-22.938968116300735,-22.966082330802422,-22.9931965453041,-23.02031075980578,-23.04742497430746,-23.07453918880914,-23.101653403310827,-23.12876761781251,-23.15588183231419,-23.182996046815873,-23.210110261317553,-23.237224475819232,-23.264338690320912,-23.2914529048226,-23.31856711932428,-23.345681333825958,-23.37279554832764,-23.399909762829324,-23.427023977331004,-23.454138191832687,-23.48125240633437,-23.508366620836046,-23.53548083533773,-23.56259504983941,-23.589709264341096,-23.616823478842775,-23.643937693344455,-23.671051907846138,-23.698166122347818,-23.725280336849504,-23.752394551351184,-23.77950876585286,-23.806622980354547,-23.833737194856226,-23.860851409357913,-23.88796562385959,-23.915079838361272,-23.942194052862952,-23.96930826736463,-23.996422481866315,-24.023536696367998,-24.050650910869678,-24.07776512537136,-24.10487933987304,-24.131993554374723,-24.159107768876403,-24.186221983378086,-24.21333619787977,-24.24045041238145,-24.267564626883132,-24.294678841384812,-24.321793055886495,-24.348907270388178,-24.376021484889858,-24.40313569939154,-24.43024991389322,-24.4573641283949,-24.481869982824293,-24.505854165239228,-24.529838347654163,-24.553822530069098,-24.577806712484033,-24.60179089489896,-24.625775077313897,-24.64975925972883,-24.673743442143763,-24.6977276245587,-24.721711806973637,-24.745695989388565,-24.769680171803504,-24.793664354218436,-24.81764853663337,-24.841632719048306,-24.86561690146324,-24.889601083878173,-24.913585266293108,-24.937569448708043,-24.961553631122975,-24.98553781353791,-25.009521995952845,-25.033506178367777,-25.05749036078271,-25.081854103172184,-25.108115627201748,-25.13437715123132,-25.160638675260884,-25.186900199290456,-25.213161723320024,-25.239423247349592,-25.26568477137916,-25.291946295408728,-25.318207819438296,-25.34446934346786,-25.370730867497432,-25.396992391527,-25.423253915556568,-25.449515439586133,-25.475776963615704,-25.50203848764527,-25.52830001167484,-25.554561535704405,-25.580823059733973,-25.60708458376354,-25.63334610779311,-25.659607631822677,-25.685869155852245,-25.712130679881813,-25.73839220391138,-25.764653727940946,-25.790915251970517,-25.817176776000085,-25.843438300029653,-25.86969982405922,-25.89596134808879,-25.922222872118354,-25.948484396147926,-25.97474592017749,-26.001007444207062,-26.027268968236626,-26.053530492266198,-26.079792016295766,-26.106053540325334,-26.1323150643549,-26.15857658838447,-26.184838112414035,-26.211099636443603,-26.23736116047317,-26.26362268450274,-26.289884208532307,-26.31614573256187,-26.342407256591443,-26.368668780621007,-26.39493030465058,-26.421191828680143,-26.447453352709715,-26.47371487673928,-26.49997640076885,-26.526237924798416,-26.552499448827987,-26.578760972857552,-26.606333327130947,-26.634561096526262,-26.662788865921577,-26.691016635316885,-26.719244404712196,-26.747472174107507,-26.775699943502822,-26.80392771289813,-26.832155482293444,-26.86038325168876,-26.888611021084067,-26.91683879047938,-26.94506655987469,-26.973294329270004,-27.001522098665315,-27.029749868060623,-27.05797763745594,-27.08620540685125,-27.114433176246564,-27.14266094564187,-27.170888715037183,-27.199116484432498,-27.22734425382781,-27.255572023223124,-27.28379979261843,-27.312027562013743,-27.340255331409054,-27.368483100804365,-27.39671087019968,-27.42493863959499,-27.4531664089903,-27.481394178385614,-27.509621947780925,-27.537849717176236,-27.56607748657155,-27.59430525596686,-27.622533025362173,-27.65076079475748,-27.678988564152792,-27.707216333548107,-27.73544410294342,-27.763671872338733,-27.79189964173404,-27.820127411129352,-27.848355180524667,-27.876582949919978,-27.90481071931529,-27.9330384887106,-27.961266258105915,-27.989494027501223,-28.017721796896538,-28.045949566291846,-28.07417733568716,-28.10240510762825,-28.1315453431587,-28.160685578689154,-28.189825814219596,-28.21896604975005,-28.248106285280493,-28.277246520810944,-28.306386756341393,-28.335526991871845,-28.364667227402293,-28.39380746293274,-28.42294769846319,-28.452087933993635,-28.481228169524087,-28.510368405054535,-28.539508640584984,-28.568648876115432,-28.59778911164588,-28.62692934717633,-28.65606958270678,-28.685209818237226,-28.714350053767674,-28.743490289298123,-28.772630524828575,-28.801770760359023,-28.83091099588947,-28.860051231419924,-28.88919146695037,-28.918331702480817,-28.94747193801127,-28.959506726035677,-28.95443606655405,-28.94936540707242,-28.944294747590796,-28.939224088109164,-28.93415342862754,-28.929082769145914,-28.924012109664282,-28.918941450182658,-28.91387079070103,-28.9088001312194,-28.903729471737776,-28.89865881225615,-28.893588152774523,-28.888517493292895,-28.883446833811263,-28.878376174329638,-28.873305514848013,-28.868234855366385,-28.863164195884753,-28.85809353640313,-28.853022876921504,-28.847952217439875,-28.842881557958247,-28.837810898476615,-28.832740238994994,-28.827669579513366,-28.822598920031734,-28.817528260550105,-28.812457601068488,-28.807386941586856,-28.802316282105227,-28.797245622623606,-28.792174963141974,-28.78710430366035,-28.782033644178718,-28.776962984697093,-28.771892325215468,-28.766821665733836,-28.761751006252208,-28.75668034677058,-28.751609687288955,-28.746539027807327,-28.741468368325698,-28.736397708844073,-28.73132704936245,-28.72625638988082,-28.721185730399192,-28.716115070917564,-28.711044411435935,-28.70597375195431,-28.700903092472682,-28.695832432991054,-28.69076177350943,-28.685691114027797,-28.68062045454617,-28.67554979506454,-28.670479135582912,-28.668087763506016,-28.667857119167536,-28.667626474829053,-28.66739583049057,-28.66716518615209,-28.666934541813607,-28.666703897475124,-28.66647325313664,-28.66624260879816,-28.666011964459678,-28.665781320121194,-28.66555067578271,-28.66532003144423,-28.665089387105745,-28.664858742767265,-28.664628098428786,-28.664397454090302,-28.66416680975182,-28.663936165413336,-28.663705521074856,-28.663474876736373,-28.66324423239789,-28.66301358805941,-28.66278294372093,-28.662552299382444,-28.64634691203968,-28.598192038688353,-28.55003716533703,-28.501882291985705,-28.453727418634386,-28.40557254528306,-28.357417671931735,-28.30926279858041,-28.261107925229087,-28.21295305187776,-28.16479817852644,-28.116643305175113,-28.06848843182379,-28.020333558472466,-27.97217868512114,-27.92402381176982,-27.875868938418495,-27.827714065067173,-27.779559191715848,-27.731404318364522,-27.683249445013196,-27.635094571661874,-27.58693969831055,-27.538784824959226,-27.4906299516079,-27.442475078256578,-27.394320204905256,-27.346165331553934,-27.298010458202608,-27.249855584851282,-27.201700711499953,-27.153545838148638,-27.10539096479731,-27.057236091445983,-27.00908121809466,-26.960926344743342,-26.912771471392013,-26.86461659804069,-26.81646172468937,-26.76830685133804,-26.72015197798672,-26.671997104635395,-26.62384223128407,-26.575687357932743,-26.52753248458142,-26.4793776112301,-26.43122273787877,-26.383067864527447,-26.334912991176125,-26.286758117824803,-26.23860324447348,-26.19044837112216,-26.142293497770826,-26.094138624419504,-26.045983751068185,-25.997828877716856,-25.949674004365527,-25.90151913101421,-25.85336425766289,-25.80520938431156,-25.757054510960238,-25.708899637608916,-25.66074476425759,-25.612589890906268,-25.564435017554942,-25.516280144203616,-25.46812527085229,-25.419970397500975,-25.371815524149646,-25.323660650798317,-25.275505777446995,-25.227350904095676,-25.179196030744347,-25.131041157393025,-25.082886284041702,-25.034731410690377,-24.986576537339047,-24.938421663987732,-24.890266790636407,-24.84211191728508,-24.79395704393376,-24.745802170582433,-24.697647297231107,-24.648318141271048,-24.567578773569455,-24.403455526448912,-24.239332279328373,-24.075209032207862,-23.911085785087323,-23.74696253796678,-23.582839290846273,-23.41871604372573,-23.25459279660519,-23.090469549484684,-22.926346302364145,-22.762223055243602,-22.598099808123067,-22.433976561002552,-22.269853313882013,-22.105730066761474,-21.941606819640963,-21.77748357252042,-21.61336032539988,-21.449237078279374,-21.28511383115883,-21.12099058403829,-20.95686733691778,-20.792744089797242,-20.628620842676703,-20.464497595556164,-20.300374348435653,-20.13625110131511,-19.972127854194575,-19.808004607074068,-19.643881359953525,-19.479758112832982,-19.315634865712475,-19.151511618591936,-18.987388371471393,-18.823265124350854,-18.659141877230343,-18.495018630109804,-18.33089538298926,-18.166772135868754,-18.00264888874821,-17.838525641627673,-17.67440239450716,-17.510279147386623,-17.346155900266083,-17.182032653145573,-17.017909406025034,-16.853786158904494,-16.689662911783955,-16.525539664663444,-16.361416417542905,-16.197293170422363,-16.033169923301855,-15.869046676181313,-15.704923429060774,-15.540800181940263,-15.376676934819724,-15.212553687699184,-15.048430440578645,-14.884307193458135,-14.720183946337595,-14.556060699217053,-14.391937452096544,-14.227814204976005,-14.063690957855464,-13.899567710734953,-13.735444463614414,-13.571321216493875,-13.407197969373366,-13.243074722252825,-13.078951475132286,-12.914828228011746,-12.750704980891236,-12.586581733770695,-12.422458486650154,-12.258335239529645,-12.094211992409104,-11.930088745288565,-11.765965498168056,-11.601842251047517,-11.437719003926976,-11.273595756806435,-11.015826868028732],[-21.830166214676762,-21.854848995208094,-21.879531775739427,-21.90421455627076,-21.928897336802095,-21.953580117333427,-21.97826289786476,-22.002945678396088,-22.027628458927424,-22.05231123945876,-22.076994019990092,-22.101676800521425,-22.126359581052757,-22.15104236158409,-22.175725142115425,-22.200407922646757,-22.22509070317809,-22.249773483709422,-22.274456264240754,-22.29913904477209,-22.32382182530342,-22.348504605834755,-22.373187386366084,-22.39787016689742,-22.422552947428752,-22.447235727960084,-22.47191850849142,-22.49660128902275,-22.521284069554085,-22.545966850085417,-22.570649630616753,-22.595332411148085,-22.620015191679414,-22.64469797221075,-22.669380752742082,-22.694063533273415,-22.71874631380475,-22.74342909433608,-22.768111874867415,-22.792794655398744,-22.81747743593008,-22.842160216461416,-22.866842996992748,-22.89355197534256,-22.920666189844244,-22.947780404345927,-22.974894618847607,-23.002008833349286,-23.02912304785097,-23.056237262352653,-23.083351476854332,-23.110465691356012,-23.1375799058577,-23.16469412035938,-23.191808334861058,-23.21892254936274,-23.24603676386442,-23.273150978366104,-23.300265192867784,-23.327379407369467,-23.35449362187115,-23.38160783637283,-23.40872205087451,-23.435836265376192,-23.462950479877875,-23.490064694379555,-23.517178908881235,-23.544293123382914,-23.5714073378846,-23.598521552386284,-23.625635766887964,-23.652749981389643,-23.679864195891327,-23.706978410393006,-23.734092624894693,-23.761206839396372,-23.78832105389805,-23.81543526839973,-23.842549482901415,-23.869663697403098,-23.89677791190478,-23.923892126406457,-23.95100634090814,-23.978120555409824,-24.002626409839216,-24.02661059225415,-24.050594774669083,-24.074578957084018,-24.098563139498953,-24.122547321913885,-24.14653150432882,-24.17051568674375,-24.194499869158687,-24.21848405157362,-24.242468233988554,-24.26645241640349,-24.290436598818424,-24.31442078123336,-24.338404963648294,-24.362389146063226,-24.38637332847816,-24.410357510893093,-24.434341693308028,-24.458325875722963,-24.482310058137898,-24.50629424055283,-24.530278422967765,-24.554262605382696,-24.57824678779763,-24.602230970212567,-24.626215152627502,-24.650199335042434,-24.67418351745737,-24.6981676998723,-24.722151882287235,-24.74613606470217,-24.770120247117106,-24.794104429532037,-24.818088611946973,-24.842072794361904,-24.86605697677684,-24.890041159191775,-24.914025341606706,-24.938009524021645,-24.961993706436573,-24.985977888851508,-25.011480301672538,-25.03774182570211,-25.064003349731674,-25.090264873761242,-25.116526397790807,-25.14278792182038,-25.169049445849947,-25.195310969879515,-25.221572493909083,-25.24783401793865,-25.27409554196822,-25.300357065997787,-25.32661859002735,-25.352880114056923,-25.37914163808649,-25.40540316211606,-25.431664686145623,-25.457926210175195,-25.48418773420476,-25.51044925823433,-25.536710782263896,-25.562972306293467,-25.589233830323032,-25.615495354352603,-25.641756878382168,-25.668018402411732,-25.694279926441304,-25.720541450470876,-25.74680297450044,-25.773064498530005,-25.799326022559576,-25.82558754658914,-25.851849070618712,-25.878110594648277,-25.90437211867785,-25.930633642707413,-25.956895166736984,-25.98315669076655,-26.00941821479612,-26.035679738825685,-26.061941262855257,-26.089513617128652,-26.11774138652396,-26.145969155919275,-26.174196925314586,-26.202424694709897,-26.230652464105212,-26.25888023350052,-26.287108002895835,-26.315335772291142,-26.343563541686457,-26.371791311081772,-26.40001908047708,-26.428246849872394,-26.456474619267702,-26.484702388663017,-26.512930158058325,-26.54115792745364,-26.569385696848954,-26.597613466244262,-26.625841235639577,-26.654069005034884,-26.6822967744302,-26.71052454382551,-26.73875231322082,-26.766980082616136,-26.795207852011444,-26.82343562140676,-26.851663390802067,-26.87989116019738,-26.908118929592693,-26.936346698988004,-26.964574468383315,-26.992802237778626,-27.021030007173934,-27.049257776569252,-27.07748554596456,-27.10571331535988,-27.133941084755186,-27.162168854150494,-27.19039662354581,-27.21862439294112,-27.24685216233643,-27.275079931731742,-27.303307701127054,-27.33153547052237,-27.35976323991768,-27.38799100931299,-27.4162187787083,-27.444446548103613,-27.472674317498928,-27.500902086894236,-27.52912985628955,-27.55735762568486,-27.585585395080173,-27.613813164475484,-27.642040933870796,-27.670268703266107,-27.698496472661418,-27.726724242056733,-27.754952011452044,-27.783179780847355,-27.811407550242663,-27.839635319637974,-27.86786308903329,-27.896090858428604,-27.92431862782391,-27.952546397219223,-27.980774166614534,-28.00900193600985,-28.037229705405164,-28.065457474800475,-28.093685244195783,-28.121913013591094,-28.150140782986405,-28.17836855238172,-28.20659632177703,-28.23482409117234,-28.263051860567654,-28.291160187666883,-28.317954610959344,-28.344749034251805,-28.371543457544266,-28.398337880836724,-28.415222899909878,-28.42219851476373,-28.42917412961758,-28.43614974447143,-28.44312535932528,-28.45010097417913,-28.45707658903298,-28.45954826766508,-28.459317623326598,-28.459086978988115,-28.45885633464963,-28.458625690311152,-28.458395045972665,-28.458164401634185,-28.457933757295706,-28.457703112957223,-28.45747246861874,-28.457241824280256,-28.457011179941777,-28.456780535603297,-28.45654989126481,-28.456319246926327,-28.456088602587847,-28.455857958249364,-28.45562731391088,-28.455396669572398,-28.45516602523392,-28.454935380895435,-28.454704736556952,-28.454474092218472,-28.45424344787999,-28.45401280354151,-28.453782159203023,-28.453551514864543,-28.453320870526067,-28.453090226187577,-28.452859581849097,-28.45262893751061,-28.45239829317213,-28.452167648833647,-28.45193700449517,-28.451706360156688,-28.451475715818205,-28.451245071479722,-28.45101442714124,-28.45078378280276,-28.450553138464276,-28.450322494125796,-28.450091849787313,-28.449861205448826,-28.44963056111035,-28.449399916771867,-28.449169272433384,-28.4489386280949,-28.448707983756417,-28.448477339417938,-28.448246695079455,-28.448016050740975,-28.447785406402488,-28.44755476206401,-28.447324117725525,-28.447093473387046,-28.446862829048563,-28.446632184710083,-28.4464015403716,-28.446170896033117,-28.445940251694637,-28.445709607356154,-28.44547896301767,-28.44524831867919,-28.445017674340704,-28.444787030002225,-28.44455638566374,-28.444325741325258,-28.44409509698678,-28.443864452648295,-28.443633808309812,-28.44340316397133,-28.44317251963285,-28.44294187529437,-28.442711230955886,-28.442480586617403,-28.442249942278924,-28.426044554936155,-28.37788968158483,-28.32973480823351,-28.281579934882185,-28.233425061530863,-28.18527018817954,-28.13711531482821,-28.088960441476885,-28.040805568125567,-27.99265069477424,-27.94449582142291,-27.89634094807159,-27.848186074720267,-27.80003120136894,-27.75187632801762,-27.703721454666294,-27.655566581314968,-27.60741170796365,-27.559256834612324,-27.511101961260998,-27.462947087909672,-27.41479221455835,-27.36663734120703,-27.318482467855702,-27.270327594504376,-27.222172721153054,-27.174017847801732,-27.125862974450406,-27.077708101099084,-27.02955322774776,-26.981398354396433,-26.933243481045114,-26.88508860769379,-26.83693373434246,-26.788778860991137,-26.740623987639818,-26.692469114288492,-26.644314240937163,-26.59615936758584,-26.54800449423452,-26.499849620883197,-26.45169474753187,-26.403539874180545,-26.35538500082922,-26.307230127477894,-26.25907525412658,-26.21092038077525,-26.162765507423927,-26.114610634072605,-26.066455760721272,-26.018300887369954,-25.969368197466505,-25.919566175363602,-25.869764153260704,-25.819962131157812,-25.770160109054913,-25.72035808695201,-25.67055606484912,-25.62075404274622,-25.570952020643322,-25.52114999854043,-25.471347976437528,-25.421545954334626,-25.371743932231738,-25.321941910128835,-25.27213988802594,-25.222337865923038,-25.17253584382015,-25.122733821717247,-25.072931799614345,-25.02312977751145,-24.973327755408555,-24.923525733305652,-24.873723711202757,-24.823921689099862,-24.774119666996963,-24.724317644894064,-24.67451562279117,-24.62471360068827,-24.57491157858537,-24.525109556482473,-24.475307534379578,-24.42550551227668,-24.3759247043781,-24.32744996750108,-24.278975230624063,-24.230500493747048,-24.182025756870036,-24.133551019993018,-24.085076283116,-24.03660154623899,-23.988126809361972,-23.939652072484954,-23.891177335607942,-23.842702598730924,-23.794227861853905,-23.745753124976886,-23.697278388099875,-23.648803651222856,-23.60032891434584,-23.551854177468833,-23.503379440591814,-23.454904703714796,-23.406429966837784,-23.357955229960766,-23.309480493083747,-23.261005756206735,-23.21253101932972,-23.1640562824527,-23.11558154557568,-23.06710680869867,-23.01863207182165,-22.970157334944638,-22.921682598067626,-22.873207861190604,-22.82473312431359,-22.776258387436577,-22.72778365055956,-22.67930891368254,-22.63083417680552,-22.58235943992851,-22.53388470305149,-22.485409966174473,-22.436935229297465,-22.388460492420446,-22.21661390268104,-21.94699559070682,-21.677377278732557,-21.407758966758294,-21.138140654784074,-20.868522342809808,-20.59890403083554,-20.32928571886127,-20.05966740688706,-19.790049094912792,-19.520430782938526,-19.250812470964313,-18.981194158990043,-18.71157584701578,-18.441957535041563,-18.172339223067297,-17.902720911093027,-17.63310259911876,-17.363484287144548,-17.09386597517028,-16.824247663196015,-16.5546293512218,-16.285011039247532,-16.015392727273266,-15.74577441529905,-15.476156103324783,-15.206537791350517,-14.9369194793763,-14.667301167402034,-14.397682855427767,-14.128064543453501,-13.858446231479286,-13.58882791950502,-13.319209607530752,-13.049591295556537,-12.77997298358227,-12.510354671608006,-12.24073635963379,-11.971118047659523,-11.701499735685257,-11.43188142371099,-11.162263111736774],[-21.391041302603618,-21.415724083134954,-21.440406863666286,-21.46508964419762,-21.48977242472895,-21.514455205260287,-21.539137985791616,-21.56382076632295,-21.588503546854284,-21.613186327385616,-21.637869107916952,-21.66255188844828,-21.687234668979613,-21.71191744951095,-21.73660023004228,-21.761283010573614,-21.785965791104946,-21.810648571636282,-21.835331352167614,-21.860014132698947,-21.88469691323028,-21.909379693761615,-21.934062474292944,-21.95874525482428,-21.983428035355608,-22.008110815886944,-22.032793596418276,-22.05747637694961,-22.082159157480945,-22.106841938012277,-22.13152471854361,-22.156207499074945,-22.180890279606274,-22.20557306013761,-22.230255840668942,-22.254938621200274,-22.27962140173161,-22.30430418226294,-22.328986962794275,-22.353669743325604,-22.37835252385694,-22.403035304388272,-22.427718084919608,-22.45240086545094,-22.477083645982272,-22.501766426513605,-22.526449207044937,-22.551131987576273,-22.575814768107605,-22.600497548638938,-22.62518032917027,-22.649863109701602,-22.674545890232935,-22.699228670764267,-22.7239114512956,-22.748594231826935,-22.77327701235827,-22.797959792889603,-22.822642573420936,-22.848135834384387,-22.87525004888607,-22.90236426338775,-22.929478477889432,-22.956592692391112,-22.983706906892795,-23.010821121394475,-23.037935335896158,-23.065049550397838,-23.09216376489952,-23.119277979401204,-23.146392193902884,-23.173506408404563,-23.20062062290625,-23.22773483740793,-23.254849051909613,-23.281963266411292,-23.309077480912972,-23.336191695414655,-23.36330590991634,-23.390420124418018,-23.4175343389197,-23.444648553421377,-23.47176276792306,-23.498876982424747,-23.52338283685414,-23.547367019269075,-23.571351201684003,-23.595335384098938,-23.619319566513873,-23.64330374892881,-23.667287931343743,-23.69127211375867,-23.715256296173607,-23.739240478588542,-23.763224661003477,-23.78720884341841,-23.811193025833344,-23.83517720824828,-23.859161390663214,-23.883145573078146,-23.90712975549308,-23.931113937908016,-23.95509812032295,-23.979082302737886,-24.003066485152814,-24.02705066756775,-24.051034849982685,-24.07501903239762,-24.099003214812555,-24.12298739722749,-24.14697157964242,-24.170955762057353,-24.19493994447229,-24.218924126887224,-24.24290830930216,-24.266892491717094,-24.290876674132026,-24.314860856546957,-24.338845038961892,-24.362829221376824,-24.386813403791763,-24.410797586206694,-24.434781768621626,-24.458765951036565,-24.482750133451496,-24.50673431586643,-24.530718498281367,-24.554702680696302,-24.57868686311123,-24.602671045526165,-24.6266552279411,-24.650639410356035,-24.67462359277097,-24.698607775185906,-24.72259195760084,-24.74657614001577,-24.770560322430704,-24.79454450484564,-24.818528687260574,-24.84251286967551,-24.866497052090438,-24.89048123450538,-24.91484497614333,-24.941106500172893,-24.967368024202464,-24.99362954823203,-25.019891072261597,-25.046152596291165,-25.072414120320733,-25.0986756443503,-25.124937168379866,-25.151198692409437,-25.17746021643901,-25.203721740468573,-25.22998326449814,-25.25624478852771,-25.282506312557274,-25.308767836586846,-25.33502936061641,-25.36129088464598,-25.387552408675546,-25.413813932705118,-25.440075456734682,-25.46633698076425,-25.49259850479382,-25.518860028823386,-25.545121552852954,-25.57269390712635,-25.600921676521665,-25.62914944591698,-25.657377215312287,-25.6856049847076,-25.71383275410291,-25.742060523498225,-25.770288292893536,-25.798516062288847,-25.826743831684155,-25.854971601079473,-25.88319937047478,-25.911427139870092,-25.939654909265407,-25.967882678660715,-25.996110448056026,-26.02433821745134,-26.052565986846652,-26.080793756241967,-26.109021525637278,-26.137249295032586,-26.1654770644279,-26.19370483382321,-26.221932603218523,-26.250160372613834,-26.278388142009145,-26.306615911404457,-26.33484368079977,-26.363071450195083,-26.391299219590394,-26.4195269889857,-26.447754758381016,-26.47598252777633,-26.50421029717164,-26.53243806656695,-26.56066583596226,-26.58889360535758,-26.617121374752887,-26.645349144148195,-26.67357691354351,-26.70180468293882,-26.730032452334136,-26.758260221729444,-26.78648799112476,-26.81471576052007,-26.84294352991538,-26.871171299310692,-26.89838378464234,-26.9251782079348,-26.951972631227264,-26.97876705451972,-27.005561477812186,-27.032355901104648,-27.059150324397105,-27.08594474768957,-27.112739170982024,-27.139533594274482,-27.166328017566947,-27.193122440859405,-27.21991686415187,-27.246711287444327,-27.273505710736785,-27.300300134029246,-27.327094557321704,-27.353888980614173,-27.38068340390663,-27.40747782719909,-27.434272250491553,-27.46106667378401,-27.48786109707647,-27.514655520368933,-27.54144994366139,-27.568244366953852,-27.59503879024631,-27.62183321353877,-27.648627636831232,-27.67542206012369,-27.70221648341615,-27.729010906708616,-27.755805330001074,-27.782599753293535,-27.809394176585997,-27.836188599878454,-27.853073618951612,-27.86004923380546,-27.867024848659312,-27.87400046351316,-27.88097607836701,-27.887951693220863,-27.894927308074713,-27.901902922928564,-27.908878537782414,-27.915854152636264,-27.922829767490118,-27.929805382343964,-27.936780997197815,-27.943756612051665,-27.950732226905515,-27.957707841759365,-27.964683456613216,-27.971659071467066,-27.978634686320916,-27.985610301174766,-27.99258591602862,-27.99956153088247,-28.00653714573632,-28.013512760590167,-28.02048837544402,-28.02746399029787,-28.034439605151718,-28.041415220005575,-28.048390834859422,-28.055366449713272,-28.062342064567122,-28.069317679420973,-28.076293294274823,-28.083268909128673,-28.090244523982527,-28.097220138836377,-28.104195753690224,-28.111171368544078,-28.118146983397924,-28.125122598251778,-28.13209821310563,-28.13907382795947,-28.14604944281333,-28.15302505766718,-28.16000067252103,-28.16697628737488,-28.173951902228726,-28.180927517082583,-28.18790313193643,-28.194878746790284,-28.20185436164413,-28.20882997649798,-28.21580559135183,-28.22278120620568,-28.228405626652894,-28.22817498231441,-28.22794433797593,-28.227713693637448,-28.227483049298964,-28.22725240496049,-28.227021760621998,-28.226791116283522,-28.226560471945035,-28.226329827606556,-28.22609918326807,-28.225868538929593,-28.22563789459111,-28.22540725025263,-28.225176605914143,-28.224945961575663,-28.22471531723718,-28.2244846728987,-28.224254028560217,-28.224023384221734,-28.223792739883255,-28.22356209554477,-28.223331451206292,-28.223100806867805,-28.222870162529325,-28.222639518190846,-28.22240887385236,-28.22217822951388,-28.221947585175393,-28.205742197832627,-28.157587324481305,-28.109432451129983,-28.061277577778657,-28.013122704427335,-27.964967831076017,-27.916812957724687,-27.86865808437336,-27.82050321102204,-27.772348337670714,-27.724193464319388,-27.676038590968066,-27.627883717616744,-27.579728844265418,-27.531573970914092,-27.483419097562773,-27.435264224211448,-27.387109350860126,-27.338954477508803,-27.290639467866278,-27.240837445763376,-27.191035423660484,-27.141233401557585,-27.091431379454683,-27.041629357351788,-26.991827335248892,-26.94202531314599,-26.892223291043095,-26.8424212689402,-26.7926192468373,-26.742817224734402,-26.69301520263151,-26.643213180528612,-26.59341115842571,-26.543609136322814,-26.49380711421992,-26.444005092117017,-26.39420307001412,-26.344401047911223,-26.294599025808324,-26.244797003705433,-26.194994981602534,-26.14519295949963,-26.095390937396733,-26.04558891529384,-25.99578689319094,-25.945984871088044,-25.89618284898515,-25.846380826882246,-25.796578804779347,-25.746776782676456,-25.69697476057356,-25.64717273847066,-25.597370716367756,-25.547568694264868,-25.497766672161962,-25.447964650059063,-25.398162627956175,-25.348360605853276,-25.29855858375037,-25.24875656164748,-25.19895453954458,-25.149152517441685,-25.09935049533879,-25.04954847323589,-24.999746451132992,-24.94994442903009,-24.9001424069272,-24.850340384824296,-24.800538362721397,-24.750736340618506,-24.700934318515607,-24.651132296412705,-24.60133027430981,-24.551528252206914,-24.501726230104016,-24.451924208001117,-24.402122185898225,-24.352320163795323,-24.30251814169242,-24.25271611958953,-24.202914097486634,-24.15311207538373,-24.103531267485153,-24.055056530608134,-24.006581793731115,-23.9581070568541,-23.909632319977092,-23.861157583100074,-23.81268284622305,-23.764208109346043,-23.715733372469025,-23.667258635592006,-23.618783898714995,-23.570309161837976,-23.521834424960957,-23.47335968808394,-23.424884951206927,-23.37641021432991,-23.32793547745289,-23.279460740575885,-23.230986003698867,-23.134272582412898,-22.98449659693498,-22.834720611457037,-22.684944625979092,-22.535168640501176,-22.38539265502323,-22.235616669545287,-22.085840684067346,-21.93606469858943,-21.786288713111485,-21.636512727633544,-21.486736742155628,-21.336960756677684,-21.18718477119974,-21.037408785721823,-20.88763280024388,-20.737856814765934,-20.588080829287993,-20.438304843810073,-20.288528858332132,-20.138752872854187,-19.98897688737627,-19.839200901898327,-19.689424916420382,-19.53964893094247,-19.389872945464525,-19.24009695998658,-19.090320974508664,-18.940544989030723,-18.790769003552775,-18.640993018074834,-18.491217032596914,-18.341441047118973,-18.19166506164103,-18.041889076163116,-17.892113090685168,-17.742337105207227,-17.592561119729307,-17.442785134251366,-17.29300914877342,-17.143233163295477,-16.993457177817564,-16.84368119233962,-16.693905206861675,-16.544129221383756,-16.394353235905815,-16.161828970981308,-15.89221065900709,-15.622592347032825,-15.352974035058558,-15.083355723084344,-14.813737411110075,-14.544119099135807,-14.274500787161545,-14.004882475187326,-13.735264163213062,-13.465645851238794,-13.196027539264579,-12.92640922729031,-12.656790915316046,-12.387172603341828,-12.117554291367563,-11.847935979393297,-11.57831766741903,-11.308699355444814],[-20.951916390530478,-20.976599171061814,-21.001281951593143,-21.02596473212448,-21.05064751265581,-21.075330293187143,-21.100013073718475,-21.12469585424981,-21.14937863478114,-21.174061415312476,-21.198744195843812,-21.22342697637514,-21.248109756906477,-21.27279253743781,-21.29747531796914,-21.322158098500477,-21.346840879031806,-21.37152365956314,-21.396206440094474,-21.420889220625806,-21.44557200115714,-21.47025478168847,-21.494937562219803,-21.51962034275114,-21.544303123282468,-21.568985903813804,-21.59366868434514,-21.618351464876465,-21.643034245407804,-21.667717025939137,-21.69239980647047,-21.717082587001805,-21.741765367533134,-21.76644814806447,-21.791130928595802,-21.815813709127134,-21.840496489658467,-21.865179270189802,-21.88986205072113,-21.914544831252467,-21.9392276117838,-21.96391039231513,-21.988593172846464,-22.013275953377796,-22.03795873390913,-22.06264151444046,-22.087324294971797,-22.11200707550313,-22.13668985603446,-22.161372636565797,-22.18605541709713,-22.210738197628462,-22.235420978159794,-22.260103758691127,-22.28478653922246,-22.309469319753795,-22.334152100285127,-22.35883488081646,-22.383517661347792,-22.408200441879124,-22.43288322241046,-22.457566002941793,-22.482248783473125,-22.506931564004457,-22.53161434453579,-22.556297125067125,-22.580979905598458,-22.605662686129786,-22.630345466661122,-22.65502824719246,-22.679711027723787,-22.70439380825512,-22.729076588786455,-22.753759369317788,-22.77844214984912,-22.803124930380452,-22.829833907927895,-22.856948122429575,-22.88406233693126,-22.91117655143294,-22.938290765934624,-22.9654049804363,-22.992519194937984,-23.01963340943967,-23.044139263869056,-23.06812344628399,-23.092107628698926,-23.11609181111386,-23.140075993528797,-23.164060175943725,-23.18804435835866,-23.212028540773595,-23.23601272318853,-23.259996905603465,-23.2839810880184,-23.307965270433332,-23.331949452848267,-23.3559336352632,-23.379917817678137,-23.40390200009307,-23.427886182508004,-23.45187036492294,-23.475854547337875,-23.499838729752803,-23.523822912167738,-23.547807094582673,-23.571791276997608,-23.595775459412543,-23.61975964182747,-23.643743824242407,-23.66772800665734,-23.691712189072277,-23.715696371487212,-23.739680553902147,-23.763664736317075,-23.78764891873201,-23.811633101146946,-23.83561728356188,-23.859601465976816,-23.883585648391747,-23.907569830806686,-23.931554013221614,-23.95553819563655,-23.979522378051488,-24.003506560466416,-24.027490742881348,-24.05147492529629,-24.075459107711218,-24.099443290126153,-24.12342747254109,-24.147411654956024,-24.17139583737096,-24.195380019785894,-24.219364202200822,-24.243348384615757,-24.267332567030692,-24.291316749445627,-24.315300931860563,-24.339285114275498,-24.363269296690433,-24.38725347910536,-24.411237661520296,-24.43522184393523,-24.45920602635016,-24.4831902087651,-24.50717439118003,-24.531158573594965,-24.5551427560099,-24.579126938424835,-24.60311112083977,-24.627095303254706,-24.651079485669634,-24.675063668084576,-24.699047850499504,-24.72303203291444,-24.747016215329374,-24.77100039774431,-24.794984580159237,-24.818968762574173,-24.84447117464368,-24.870732698673248,-24.89699422270282,-24.923255746732384,-24.94951727076195,-24.97577879479152,-25.002040318821088,-25.028301842850656,-25.055874197124055,-25.084101966519366,-25.112329735914678,-25.140557505309992,-25.1687852747053,-25.197013044100615,-25.225240813495926,-25.253468582891237,-25.281696352286552,-25.30992412168186,-25.33815189107717,-25.366379660472486,-25.394607429867797,-25.42283519926311,-25.45106296865842,-25.478812958325342,-25.505607381617803,-25.532401804910265,-25.559196228202723,-25.585990651495187,-25.61278507478764,-25.639579498080106,-25.666373921372564,-25.693168344665022,-25.719962767957487,-25.746757191249944,-25.773551614542406,-25.800346037834863,-25.82714046112733,-25.85393488441979,-25.880729307712247,-25.90752373100471,-25.93431815429717,-25.96111257758963,-25.98790700088209,-26.01470142417455,-26.04149584746701,-26.06829027075947,-26.095084694051927,-26.121879117344392,-26.14867354063685,-26.17546796392931,-26.202262387221772,-26.229056810514233,-26.255851233806695,-26.282645657099152,-26.309440080391614,-26.336234503684075,-26.363028926976533,-26.389823350268998,-26.416617773561452,-26.443412196853913,-26.470206620146378,-26.497001043438832,-26.5237954667313,-26.55058989002376,-26.577384313316216,-26.604178736608677,-26.63097315990114,-26.6577675831936,-26.684562006486058,-26.711356429778515,-26.73815085307098,-26.764945276363434,-26.7917396996559,-26.818534122948364,-26.84532854624082,-26.87212296953328,-26.89891739282574,-26.925711816118202,-26.952506239410663,-26.97930066270312,-27.006095085995582,-27.032889509288044,-27.059683932580505,-27.086478355872963,-27.113272779165424,-27.140067202457885,-27.166861625750343,-27.193656049042808,-27.220450472335266,-27.247244895627723,-27.274039318920188,-27.29092433799334,-27.29789995284719,-27.304875567701043,-27.31185118255489,-27.318826797408743,-27.325802412262593,-27.33277802711644,-27.339753641970297,-27.346729256824144,-27.353704871677994,-27.360680486531844,-27.3676561013857,-27.37463171623955,-27.3816073310934,-27.38858294594725,-27.3955585608011,-27.40253417565495,-27.4095097905088,-27.41648540536265,-27.4234610202165,-27.43043663507035,-27.437412249924204,-27.44438786477805,-27.4513634796319,-27.45833909448575,-27.4653147093396,-27.47229032419345,-27.479265939047302,-27.486241553901156,-27.493217168755002,-27.500192783608856,-27.507168398462703,-27.514144013316553,-27.521119628170403,-27.528095243024254,-27.535070857878107,-27.542046472731954,-27.54902208758581,-27.555997702439655,-27.562973317293505,-27.56994893214736,-27.576924547001205,-27.583900161855063,-27.590875776708906,-27.597851391562763,-27.60482700641661,-27.611802621270463,-27.618778236124314,-27.625753850978164,-27.632729465832014,-27.63970508068586,-27.646680695539715,-27.65365631039356,-27.660631925247415,-27.667607540101265,-27.67458315495511,-27.68155876980897,-27.688534384662816,-27.695509999516666,-27.702485614370516,-27.709461229224367,-27.716436844078217,-27.723412458932067,-27.730388073785917,-27.737363688639764,-27.74433930349362,-27.751314918347468,-27.75829053320132,-27.765266148055172,-27.77224176290902,-27.781186493101167,-27.795710415890976,-27.81023433868079,-27.8247582614706,-27.839282184260412,-27.853806107050225,-27.868330029840035,-27.882853952629848,-27.89737787541966,-27.911901798209474,-27.926425720999283,-27.940949643789097,-27.955473566578913,-27.948591222861708,-27.898896346130513,-27.849201469399315,-27.799506592668113,-27.74981171593691,-27.700116839205716,-27.650421962474514,-27.60072708574331,-27.551032209012114,-27.50133733228091,-27.45164245554971,-27.40194757881851,-27.352252702087313,-27.30255782535611,-27.252862948624912,-27.203168071893714,-27.153473195162512,-27.103778318431313,-27.054083441700115,-27.00438856496891,-26.954693688237708,-26.904998811506506,-26.85530393477531,-26.805609058044105,-26.755914181312907,-26.706219304581712,-26.65652442785051,-26.60682955111931,-26.55713467438811,-26.507439797656907,-26.457744920925702,-26.40805004419451,-26.35835516746331,-26.308660290732107,-26.258965414000905,-26.20927053726971,-26.159575660538508,-26.109880783807306,-26.06018590707611,-26.010491030344905,-25.960796153613707,-25.911101276882512,-25.861406400151303,-25.811711523420108,-25.762016646688906,-25.712321769957708,-25.662626893226502,-25.612932016495307,-25.563237139764112,-25.513542263032903,-25.46384738630171,-25.41415250957051,-25.364457632839304,-25.314762756108102,-25.265067879376907,-25.215373002645705,-25.165678125914503,-25.115983249183305,-25.066288372452107,-25.016593495720905,-24.966898618989706,-24.917203742258508,-24.867508865527306,-24.817813988796107,-24.76811911206491,-24.7184242353337,-24.668729358602498,-24.61903448187131,-24.569339605140105,-24.519644728408903,-24.469949851677704,-24.420254974946502,-24.370560098215304,-24.320865221484105,-24.271170344752907,-24.2214754680217,-24.171780591290496,-24.122085714559308,-24.07260714469256,-24.02350476276587,-23.974402380839187,-23.9252999989125,-23.876197616985813,-23.834249715837093,-23.82807421857816,-23.821898721319236,-23.815723224060307,-23.809547726801384,-23.803372229542454,-23.797196732283524,-23.7910212350246,-23.731850042257445,-23.582074056779504,-23.432298071301584,-23.282522085823643,-23.1327461003457,-22.982970114867754,-22.833194129389838,-22.683418143911894,-22.533642158433953,-22.383866172956033,-22.234090187478092,-22.08431420200015,-21.934538216522235,-21.78476223104429,-21.634986245566346,-21.48521026008843,-21.335434274610485,-21.18565828913254,-21.035882303654596,-20.88610631817668,-20.736330332698735,-20.586554347220794,-20.436778361742878,-20.287002376264933,-20.13722639078699,-19.987450405309072,-19.83767441983113,-19.687898434353187,-19.538122448875242,-19.388346463397326,-19.23857047791938,-19.088794492441437,-18.93901850696352,-18.78924252148558,-18.639466536007635,-18.48969055052972,-18.339914565051778,-18.190138579573834,-18.040362594095914,-17.890586608617973,-17.740810623140028,-17.591034637662087,-17.441258652184167,-17.291482666706223,-17.14170668122828,-16.991930695750366,-16.84215471027242,-16.692378724794477,-16.54260273931656,-16.392826753838616,-16.243050768360675,-16.09327478288273,-15.943498797404814,-15.79372281192687,-15.643946826448927,-15.494170840971009,-15.344394855493066,-15.19461887001512,-15.044842884537207,-14.89506689905926,-14.745290913581318,-14.595514928103404,-14.445738942625457,-14.295962957147516,-14.146186971669573,-13.996410986191655,-13.84663500071371,-13.696859015235768,-13.440338069496642,-13.156732257670631,-12.87312644584462,-12.589520634018664,-12.305914822192653,-12.02230901036664,-11.73870319854063,-11.455097386714673],[-20.50705644055887,-20.529434537661057,-20.551812634763248,-20.574190731865436,-20.596568828967627,-20.618946926069814,-20.641325023172005,-20.663703120274196,-20.686081217376383,-20.709611657747306,-20.73429443827864,-20.75897721880997,-20.783659999341303,-20.80834277987264,-20.83302556040397,-20.857708340935304,-20.882391121466636,-20.90707390199797,-20.931756682529304,-20.956439463060633,-20.98112224359197,-21.0058050241233,-21.030487804654634,-21.05517058518597,-21.079853365717298,-21.104536146248634,-21.129218926779963,-21.1539017073113,-21.17858448784263,-21.203267268373963,-21.2279500489053,-21.25263282943663,-21.277315609967964,-21.3019983904993,-21.32668117103063,-21.351363951561964,-21.376046732093293,-21.40072951262463,-21.425412293155965,-21.450095073687294,-21.47477785421863,-21.49946063474996,-21.524143415281294,-21.548826195812627,-21.57350897634396,-21.59819175687529,-21.622874537406624,-21.64755731793796,-21.672240098469292,-21.696922879000624,-21.72160565953196,-21.74628844006329,-21.770971220594625,-21.795654001125957,-21.82033678165729,-21.84501956218862,-21.869702342719954,-21.89438512325129,-21.919067903782622,-21.943750684313954,-21.96843346484529,-21.99311624537662,-22.017799025907955,-22.042481806439287,-22.06716458697062,-22.091847367501956,-22.116530148033284,-22.14121292856462,-22.165895709095953,-22.19057848962729,-22.21526127015862,-22.239944050689953,-22.264626831221285,-22.28930961175262,-22.31399239228395,-22.338675172815286,-22.36335795334662,-22.38804073387795,-22.412723514409286,-22.437406294940615,-22.46208907547195,-22.486771856003283,-22.511454636534616,-22.536137417065948,-22.56023803250028,-22.584222214915215,-22.60820639733015,-22.63219057974508,-22.656174762160017,-22.680158944574952,-22.704143126989884,-22.72812730940482,-22.752111491819754,-22.776095674234686,-22.80007985664962,-22.824064039064552,-22.84804822147949,-22.872032403894423,-22.896016586309358,-22.920000768724293,-22.943984951139225,-22.96796913355416,-22.991953315969095,-23.015937498384027,-23.03992168079896,-23.063905863213897,-23.087890045628832,-23.111874228043764,-23.135858410458695,-23.15984259287363,-23.183826775288566,-23.2078109577035,-23.231795140118432,-23.255779322533368,-23.2797635049483,-23.303747687363234,-23.32773186977817,-23.3517160521931,-23.37570023460804,-23.399684417022968,-23.423668599437907,-23.447652781852838,-23.471636964267773,-23.49562114668271,-23.51960532909764,-23.54358951151257,-23.56757369392751,-23.591557876342442,-23.615542058757377,-23.639526241172312,-23.663510423587248,-23.687494606002183,-23.71147878841711,-23.73546297083205,-23.75944715324698,-23.783431335661916,-23.80741551807685,-23.831399700491783,-23.85538388290672,-23.879368065321653,-23.903352247736585,-23.927336430151524,-23.951320612566455,-23.975304794981387,-23.999288977396326,-24.023273159811257,-24.04725734222619,-24.071241524641128,-24.09522570705606,-24.119209889470994,-24.14319407188593,-24.16717825430086,-24.191162436715796,-24.215146619130728,-24.239130801545663,-24.263114983960598,-24.287099166375533,-24.311083348790465,-24.33466870463983,-24.356259917979223,-24.377851131318614,-24.399442344658006,-24.42103355799739,-24.44262477133678,-24.46421598467617,-24.48580719801556,-24.507398411354945,-24.532005461928552,-24.558120431119253,-24.584235400309957,-24.610350369500665,-24.636465338691373,-24.662580307882077,-24.68869527707278,-24.71481024626349,-24.740925215454194,-24.7670401846449,-24.79315515383561,-24.81927012302631,-24.84538509221702,-24.871500061407726,-24.897615030598434,-24.92372999978914,-24.949844968979843,-24.975959938170547,-25.002074907361255,-25.028189876551963,-25.054304845742667,-25.08041981493337,-25.106534784124076,-25.132649753314784,-25.158764722505488,-25.184879691696196,-25.211402333584132,-25.23819675687659,-25.264991180169055,-25.291785603461513,-25.318580026753978,-25.345374450046435,-25.372168873338893,-25.398963296631354,-25.425757719923816,-25.452552143216277,-25.479346566508738,-25.506140989801196,-25.532935413093654,-25.55972983638612,-25.586524259678576,-25.613318682971034,-25.6401131062635,-25.666907529555957,-25.69370195284842,-25.72049637614088,-25.747290799433337,-25.774085222725798,-25.80087964601826,-25.82767406931072,-25.854468492603182,-25.88126291589564,-25.908057339188105,-25.93485176248056,-25.961646185773024,-25.988440609065485,-26.015235032357943,-26.0420294556504,-26.06882387894286,-26.09561830223533,-26.122412725527788,-26.149207148820246,-26.176001572112703,-26.20279599540516,-26.229590418697626,-26.256384841990084,-26.28317926528255,-26.30997368857501,-26.33676811186747,-26.36356253515993,-26.390356958452386,-26.41715138174485,-26.443945805037313,-26.470740228329767,-26.497534651622228,-26.52432907491469,-26.55112349820715,-26.577917921499612,-26.60471234479207,-26.63150676808453,-26.658301191376992,-26.685095614669454,-26.71189003796191,-26.728775057035065,-26.73575067188892,-26.742726286742766,-26.749701901596616,-26.75667751645047,-26.763653131304316,-26.77062874615817,-26.77760436101202,-26.784579975865874,-26.79155559071972,-26.79853120557357,-26.805506820427425,-26.812482435281268,-26.819458050135125,-26.826433664988976,-26.833409279842826,-26.840384894696673,-26.847360509550526,-26.854336124404377,-26.861311739258227,-26.868287354112077,-26.875262968965924,-26.882238583819777,-26.889214198673624,-26.896189813527478,-26.90316542838133,-26.91014104323518,-26.91711665808903,-26.92409227294288,-26.931067887796733,-26.938043502650576,-26.94501911750443,-26.951994732358283,-26.95897034721213,-26.965945962065987,-26.97292157691983,-26.97989719177368,-26.98884193517865,-27.00336585796846,-27.017889780758274,-27.032413703548087,-27.046937626337893,-27.061461549127706,-27.07598547191752,-27.090509394707333,-27.105033317497146,-27.11955724028696,-27.13408116307677,-27.14860508586658,-27.163129008656394,-27.177652931446207,-27.192176854236017,-27.20670077702583,-27.221224699815643,-27.235748622605456,-27.250272545395266,-27.264796468185075,-27.27932039097489,-27.293844313764698,-27.308368236554514,-27.322892159344324,-27.337416082134137,-27.351940004923947,-27.366463927713763,-27.380987850503573,-27.395511773293386,-27.4100356960832,-27.424559618873005,-27.439083541662818,-27.453607464452634,-27.468131387242444,-27.482655310032257,-27.497179232822067,-27.51170315561188,-27.526227078401693,-27.540751001191502,-27.555274923981315,-27.56979884677113,-27.584322769560938,-27.59884669235075,-27.613370615140564,-27.627894537930374,-27.642418460720187,-27.635536117002985,-27.58584124027179,-27.53614636354059,-27.48645148680939,-27.436756610078188,-27.387061733346993,-27.33736685661579,-27.287671979884585,-27.23797710315339,-27.188282226422185,-27.13858734969099,-27.088892472959788,-27.03919759622859,-26.98950271949739,-26.93980784276619,-26.890112966034987,-26.840418089303785,-26.790723212572587,-26.74102833584139,-26.691333459110187,-26.641638582378988,-26.591943705647783,-26.542248828916584,-26.492553952185382,-26.442859075454187,-26.393164198722985,-26.343469321991783,-26.293774445260585,-26.244079568529386,-26.194384691798184,-26.144689815066982,-26.094994938335788,-26.045300061604586,-25.995605184873384,-25.94591030814218,-25.896215431410987,-25.84652055467978,-25.796825677948583,-25.747130801217388,-25.697435924486182,-25.647741047754984,-25.59804617102379,-25.548351294292587,-25.498656417561378,-25.448961540830183,-25.399266664098988,-25.349571787367783,-25.299876910636584,-25.250468876885357,-25.20136649495867,-25.15226411303198,-25.103161731105295,-25.0540593491786,-25.004956967251914,-24.955854585325234,-24.90675220339854,-24.857649821471853,-24.808547439545173,-24.759445057618482,-24.71034267569179,-24.661240293765104,-24.612137911838424,-24.563035529911737,-24.513933147985046,-24.464830766058363,-24.41572838413167,-24.36662600220498,-24.3175236202783,-24.268421238351607,-24.21931885642492,-24.170216474498236,-24.12111409257155,-24.07201171064486,-24.02290932871817,-23.973806946791484,-23.924704564864797,-23.87560218293811,-23.826499801011426,-23.77739741908474,-23.72829503715805,-23.67919265523136,-23.630090273304674,-23.580987891377983,-23.539039990229263,-23.532864492970337,-23.52668899571141,-23.520513498452484,-23.514338001193558,-23.508162503934628,-23.501987006675698,-23.495811509416775,-23.489636012157845,-23.48346051489892,-23.477285017639993,-23.471109520381063,-23.464934023122137,-23.45875852586321,-23.45258302860428,-23.446407531345358,-23.440232034086428,-23.4340565368275,-23.427881039568575,-23.421705542309645,-23.41553004505072,-23.409354547791793,-23.403179050532863,-23.397003553273937,-23.39082805601501,-23.38465255875608,-23.378477061497154,-23.372301564238228,-23.366126066979298,-23.35995056972037,-23.353775072461442,-23.34759957520252,-23.34142407794359,-23.335248580684663,-23.329073083425737,-23.32289758616681,-23.31404544711778,-23.179390724772045,-23.04473600242629,-22.910081280080533,-22.775426557734797,-22.64077183538904,-22.50611711304328,-22.37146239069755,-22.236807668351787,-22.102152946006033,-21.9674982236603,-21.81112145730799,-21.527515645481984,-21.243909833655973,-20.960304021830016,-20.676698210004005,-20.39309239817799,-20.109486586352034,-19.82588077452602,-19.542274962700013,-19.258669150874056,-18.97506333904805,-18.691457527222035,-18.40785171539602,-18.124245903570067,-17.840640091744056,-17.557034279918042,-17.273428468092085,-16.989822656266078,-16.706216844440064,-16.422611032614107,-16.139005220788096,-15.855399408962082,-15.571793597136127,-15.288187785310114,-15.004581973484104,-14.720976161658093,-14.437370349832138,-14.153764538006126,-13.870158726180115,-13.586552914354156,-13.302947102528144,-13.019341290702135,-12.735735478876176,-12.452129667050167,-12.168523855224155,-11.884918043398145,-11.601312231572187],[-20.056798806864755,-20.079176903966946,-20.101555001069137,-20.123933098171328,-20.146311195273515,-20.168689292375706,-20.191067389477894,-20.213445486580085,-20.235823583682276,-20.258201680784463,-20.28057977788665,-20.30295787498884,-20.325335972091032,-20.34771406919322,-20.37009216629541,-20.392470263397602,-20.41484836049979,-20.43722645760198,-20.459604554704168,-20.48198265180636,-20.504360748908546,-20.526738846010737,-20.549116943112928,-20.571495040215115,-20.593873137317306,-20.61625123559338,-20.640934016124714,-20.66561679665605,-20.690299577187382,-20.714982357718714,-20.739665138250047,-20.76434791878138,-20.78903069931271,-20.813713479844047,-20.83839626037538,-20.86307904090671,-20.887761821438044,-20.91244460196938,-20.937127382500712,-20.961810163032045,-20.986492943563377,-21.01117572409471,-21.03585850462604,-21.060541285157377,-21.08522406568871,-21.109906846220042,-21.134589626751378,-21.159272407282707,-21.183955187814043,-21.20863796834537,-21.233320748876707,-21.25800352940804,-21.282686309939375,-21.307369090470708,-21.332051871002037,-21.356734651533372,-21.381417432064705,-21.406100212596037,-21.430782993127373,-21.455465773658702,-21.480148554190038,-21.50483133472137,-21.529514115252702,-21.554196895784038,-21.57887967631537,-21.603562456846703,-21.62824523737804,-21.652928017909367,-21.6776107984407,-21.702293578972032,-21.726976359503368,-21.751659140034697,-21.776341920566036,-21.80102470109737,-21.825707481628697,-21.850390262160033,-21.875073042691366,-21.899755823222694,-21.924438603754034,-21.949121384285363,-21.9738041648167,-21.99848694534803,-22.023169725879363,-22.047852506410695,-22.071953121845027,-22.095937304259966,-22.119921486674897,-22.143905669089833,-22.167889851504768,-22.1918740339197,-22.21585821633463,-22.239842398749566,-22.2638265811645,-22.287810763579436,-22.31179494599437,-22.335779128409303,-22.35976331082424,-22.38374749323917,-22.40773167565411,-22.43171585806904,-22.455700040483975,-22.47968422289891,-22.503668405313842,-22.527652587728777,-22.55163677014371,-22.575620952558644,-22.59960513497358,-22.623589317388515,-22.64757349980345,-22.67155768221838,-22.695541864633316,-22.719526047048248,-22.743510229463183,-22.76749441187812,-22.79147859429305,-22.815462776707985,-22.839446959122917,-22.863431141537852,-22.887415323952787,-22.911399506367722,-22.935383688782657,-22.95936787119759,-22.98335205361252,-23.00733623602746,-23.03132041844239,-23.055304600857323,-23.07928878327226,-23.103272965687193,-23.127257148102125,-23.15124133051706,-23.175225512931995,-23.19920969534693,-23.223193877761865,-23.247178060176797,-23.271162242591732,-23.295146425006664,-23.3191306074216,-23.343114789836534,-23.36709897225147,-23.3910831546664,-23.415067337081332,-23.43905151949627,-23.461440390413028,-23.483031603752416,-23.504622817091807,-23.526214030431195,-23.547805243770586,-23.569396457109974,-23.590987670449366,-23.612578883788753,-23.63417009712814,-23.655761310467533,-23.67735252380692,-23.69894373714631,-23.7205349504857,-23.742126163825088,-23.76371737716448,-23.785308590503867,-23.806899803843255,-23.828491017182643,-23.850082230522034,-23.87167344386142,-23.893264657200813,-23.9148558705402,-23.936447083879592,-23.958038297218984,-23.979629510558368,-24.00423656113197,-24.030351530322672,-24.05646649951338,-24.082581468704085,-24.108696437894793,-24.1348114070855,-24.160926376276205,-24.18704134546691,-24.213156314657617,-24.23927128384832,-24.26538625303903,-24.29150122222973,-24.317616191420438,-24.343731160611146,-24.36984612980185,-24.395961098992558,-24.42207606818326,-24.44819103737397,-24.474306006564674,-24.500420975755382,-24.526535944946083,-24.55265091413679,-24.5787658833275,-24.604880852518207,-24.63099582170891,-24.657110790899615,-24.683225760090323,-24.709340729281024,-24.735455698471732,-24.76157066766244,-24.787685636853144,-24.81380060604385,-24.839915575234556,-24.866030544425264,-24.892145513615965,-24.918260482806673,-24.94437545199738,-24.97049042118808,-24.99660539037879,-25.022720359569497,-25.0488353287602,-25.074950297950906,-25.101065267141617,-25.12718023633232,-25.153295205523026,-25.17941017471373,-25.20552514390444,-25.231640113095146,-25.257755082285847,-25.283870051476555,-25.309985020667263,-25.336099989857964,-25.362214959048675,-25.38832992823938,-25.414444897430087,-25.440559866620788,-25.466674835811496,-25.4927898050022,-25.518904774192908,-25.545019743383612,-25.571134712574313,-25.59724968176502,-25.62336465095573,-25.649479620146433,-25.675594589337138,-25.701709558527845,-25.72782452771855,-25.753939496909254,-25.780054466099962,-25.80616943529067,-25.832284404481378,-25.858399373672082,-25.88451434286279,-25.91062931205349,-25.936744281244202,-25.962859250434906,-25.98897421962561,-26.015768640541342,-26.0425630638338,-26.069357487126265,-26.096151910418723,-26.122946333711184,-26.14974075700364,-26.166625776076796,-26.17360139093065,-26.180577005784496,-26.18755262063835,-26.19649737725614,-26.21102130004595,-26.225545222835763,-26.240069145625576,-26.25459306841539,-26.2691169912052,-26.28364091399501,-26.298164836784824,-26.312688759574634,-26.327212682364447,-26.34173660515426,-26.35626052794407,-26.37078445073388,-26.385308373523692,-26.399832296313505,-26.414356219103315,-26.42888014189313,-26.44340406468294,-26.45792798747275,-26.472451910262564,-26.486975833052377,-26.50149975584219,-26.516023678632,-26.53054760142181,-26.54507152421162,-26.559595447001435,-26.574119369791248,-26.58864329258106,-26.60316721537087,-26.617691138160684,-26.632215060950497,-26.646738983740306,-26.66126290653012,-26.67578682931993,-26.69031075210974,-26.70483467489955,-26.719358597689368,-26.733882520479177,-26.74840644326899,-26.762930366058804,-26.777454288848617,-26.791978211638423,-26.806502134428236,-26.82102605721805,-26.835549980007862,-26.850073902797675,-26.864597825587484,-26.8791217483773,-26.893645671167107,-26.90816959395692,-26.922693516746733,-26.93721743953654,-26.95174136232636,-26.966265285116165,-26.980789207905982,-26.99531313069579,-27.009837053485604,-27.024360976275414,-27.038884899065224,-27.05340882185504,-27.06793274464485,-27.082456667434663,-27.096980590224476,-27.11150451301429,-27.1260284358041,-27.14055235859391,-27.15507628138372,-27.16960020417353,-27.184124126963344,-27.198648049753157,-27.21317197254297,-27.227695895332783,-27.242219818122592,-27.256743740912405,-27.27126766370222,-27.285791586492028,-27.300315509281837,-27.31483943207165,-27.329363354861467,-27.32248101114427,-27.272786134413067,-27.223091257681872,-27.173396380950667,-27.12370150421947,-27.074006627488274,-27.024311750757064,-26.974616874025866,-26.924921997294668,-26.875227120563466,-26.825532243832267,-26.775837367101065,-26.726142490369867,-26.676447613638665,-26.626752736907466,-26.57705786017627,-26.527362983445066,-26.477668106713868,-26.428330609078152,-26.379228227151465,-26.33012584522477,-26.281023463298084,-26.2319210813714,-26.18281869944471,-26.133716317518022,-26.08461393559134,-26.035511553664648,-25.986409171737964,-25.93730678981128,-25.888204407884587,-25.8391020259579,-25.789999644031216,-25.74089726210453,-25.691794880177838,-25.64269249825115,-25.593590116324467,-25.544487734397777,-25.49538535247109,-25.446282970544402,-25.397180588617715,-25.348078206691028,-25.298975824764348,-25.249873442837654,-25.200771060910967,-25.15166867898428,-25.102566297057592,-25.0534639151309,-25.00436153320422,-24.95525915127753,-24.906156769350844,-24.857054387424157,-24.80795200549747,-24.758849623570786,-24.709747241644088,-24.660644859717408,-24.611542477790724,-24.56244009586403,-24.513337713937347,-24.46423533201066,-24.415132950083965,-24.366030568157285,-24.316928186230598,-24.26782580430391,-24.218723422377224,-24.169621040450536,-24.120518658523846,-24.07141627659716,-24.02231389467048,-23.973211512743784,-23.924109130817097,-23.87500674889041,-23.825904366963726,-23.776801985037036,-23.72769960311035,-23.678597221183665,-23.629494839256974,-23.580392457330284,-23.531290075403604,-23.482187693476916,-23.433085311550222,-23.383982929623535,-23.334880547696855,-23.28577816577016,-23.24383026462144,-23.237654767362514,-23.231479270103584,-23.22530377284466,-23.21912827558573,-23.212952778326805,-23.206777281067875,-23.200601783808953,-23.194426286550023,-23.188250789291097,-23.182075292032167,-23.17589979477324,-23.16972429751431,-23.163548800255384,-23.157373302996458,-23.076251634465276,-22.94159691211952,-22.806942189773785,-22.672287467428028,-22.53763274508227,-22.402978022736537,-22.268323300390776,-22.133668578045018,-21.999013855699285,-21.864359133353528,-21.72970441100777,-21.595049688662012,-21.460394966316276,-21.32574024397052,-21.191085521624764,-21.05643079927903,-20.921776076933273,-20.787121354587512,-20.65246663224178,-20.51781190989602,-20.383157187550264,-20.248502465204506,-20.113847742858773,-19.979193020513016,-19.844538298167258,-19.70988357582153,-19.575228853475767,-19.44057413113001,-19.305919408784277,-19.17126468643852,-19.03660996409276,-18.901955241747025,-18.767300519401267,-18.63264579705551,-18.497991074709752,-18.36333635236402,-18.228681630018265,-18.094026907672504,-17.95937218532677,-17.824717462981013,-17.690062740635256,-17.555408018289523,-17.42075329594376,-17.286098573598004,-17.151443851252246,-17.016789128906513,-16.882134406560755,-16.747479684214998,-16.612824961869265,-16.478170239523507,-16.34351551717775,-16.208860794832017,-16.07420607248626,-15.939551350140501,-15.718008441993637,-15.434402630167629,-15.150796818341616,-14.867191006515608,-14.583585194689649,-14.299979382863638,-14.016373571037628,-13.732767759211669,-13.449161947385658,-13.165556135559648,-12.881950323733689,-12.59834451190768,-12.31473870008167,-12.031132888255657,-11.747527076429698],[-19.606541173170648,-19.62891927027284,-19.651297367375026,-19.673675464477217,-19.696053561579404,-19.718431658681595,-19.740809755783783,-19.763187852885974,-19.78556594998816,-19.807944047090352,-19.830322144192543,-19.85270024129473,-19.87507833839692,-19.89745643549911,-19.9198345326013,-19.94221262970349,-19.964590726805678,-19.98696882390787,-20.00934692101006,-20.031725018112247,-20.05410311521444,-20.076481212316626,-20.098859309418817,-20.121237406521004,-20.143615503623195,-20.165993600725383,-20.188371697827574,-20.21074979492976,-20.233127892031955,-20.255505989134143,-20.277884086236334,-20.30026218333852,-20.322640280440712,-20.345018377542903,-20.36739647464509,-20.38977457174728,-20.41215266884947,-20.43453076595166,-20.45690886305385,-20.47928696015604,-20.50166505725823,-20.52404315436042,-20.54757359397079,-20.572256374502125,-20.59693915503346,-20.62162193556479,-20.646304716096125,-20.670987496627458,-20.69567027715879,-20.720353057690126,-20.745035838221455,-20.76971861875279,-20.79440139928412,-20.819084179815455,-20.843766960346787,-20.86844974087812,-20.893132521409456,-20.917815301940784,-20.942498082472117,-20.967180863003456,-20.991863643534785,-21.01654642406612,-21.041229204597453,-21.065911985128785,-21.090594765660118,-21.11527754619145,-21.139960326722782,-21.164643107254115,-21.18932588778545,-21.214008668316787,-21.238691448848115,-21.263374229379448,-21.288057009910784,-21.312739790442112,-21.33742257097345,-21.36210535150478,-21.38678813203611,-21.41147091256745,-21.43615369309878,-21.460836473630113,-21.48551925416145,-21.510202034692778,-21.53488481522411,-21.55956759575545,-21.583668211189778,-21.607652393604713,-21.631636576019645,-21.65562075843458,-21.679604940849515,-21.703589123264447,-21.727573305679382,-21.751557488094313,-21.77554167050925,-21.799525852924184,-21.82351003533912,-21.847494217754054,-21.87147840016899,-21.89546258258392,-21.919446764998856,-21.94343094741379,-21.967415129828723,-21.991399312243658,-22.015383494658593,-22.03936767707353,-22.063351859488456,-22.087336041903395,-22.111320224318327,-22.13530440673326,-22.159288589148193,-22.18327277156313,-22.207256953978064,-22.231241136393,-22.25522531880793,-22.279209501222866,-22.303193683637797,-22.327177866052732,-22.351162048467668,-22.375146230882603,-22.399130413297538,-22.42311459571247,-22.447098778127405,-22.471082960542333,-22.495067142957268,-22.51905132537221,-22.54303550778714,-22.56662086284683,-22.58821207618622,-22.60980328952561,-22.631394502864996,-22.652985716204388,-22.674576929543775,-22.69616814288317,-22.717759356222555,-22.739350569561942,-22.760941782901334,-22.78253299624072,-22.80412420958011,-22.8257154229195,-22.84730663625889,-22.86889784959828,-22.890489062937668,-22.912080276277056,-22.933671489616447,-22.955262702955835,-22.976853916295227,-22.998445129634614,-23.020036342974002,-23.041627556313394,-23.063218769652785,-23.084809982992173,-23.10640119633156,-23.127992409670952,-23.149583623010336,-23.171174836349728,-23.19276604968912,-23.214357263028507,-23.235948476367895,-23.257539689707286,-23.27913090304667,-23.300722116386062,-23.322313329725453,-23.343904543064845,-23.36549575640423,-23.38708696974362,-23.408678183083012,-23.4302693964224,-23.451860609761788,-23.47646766033539,-23.5025826295261,-23.5286975987168,-23.554812567907508,-23.580927537098212,-23.60704250628892,-23.633157475479624,-23.659272444670332,-23.685387413861037,-23.711502383051744,-23.73761735224245,-23.763732321433153,-23.78984729062386,-23.81596225981457,-23.84207722900527,-23.868192198195977,-23.89430716738668,-23.920422136577386,-23.946537105768094,-23.972652074958802,-23.998767044149503,-24.02488201334021,-24.05099698253092,-24.077111951721626,-24.103226920912327,-24.129341890103035,-24.155456859293743,-24.181571828484444,-24.20768679767515,-24.233801766865856,-24.259916736056567,-24.286031705247268,-24.312146674437976,-24.338261643628684,-24.364376612819388,-24.390491582010092,-24.4166065512008,-24.442721520391505,-24.46883648958221,-24.494951458772917,-24.52106642796362,-24.547181397154326,-24.573296366345033,-24.59941133553574,-24.62552630472645,-24.65164127391715,-24.677756243107858,-24.703871212298562,-24.729986181489267,-24.756101150679974,-24.782216119870682,-24.80833108906139,-24.83444605825209,-24.860561027442802,-24.886675996633503,-24.912790965824207,-24.938905935014915,-24.96502090420562,-24.991135873396328,-25.017250842587032,-25.04336581177774,-25.069480780968444,-25.093983904536422,-25.11817706114587,-25.142370217755325,-25.166563374364774,-25.190756530974227,-25.21494968758368,-25.239142844193132,-25.263336000802582,-25.28752915741203,-25.311722314021488,-25.335915470630937,-25.360108627240386,-25.38430178384984,-25.40849494045929,-25.432688097068745,-25.456881253678194,-25.481074410287647,-25.505267566897096,-25.52946072350655,-25.553653880116,-25.57784703672545,-25.600878832498683,-25.6227492674357,-25.64461970237271,-25.666490137309722,-25.688360572246737,-25.71023100718375,-25.73210144212076,-25.753971877057776,-25.775842311994793,-25.7977127469318,-25.819583181868815,-25.84145361680583,-25.863324051742843,-25.885194486679858,-25.90706492161687,-25.92893535655388,-25.950805791490893,-25.972676226427907,-25.99454666136492,-26.016417096301932,-26.038287531238943,-26.057208978885654,-26.072270695553634,-26.087332412221613,-26.102394128889596,-26.117455845557572,-26.13251756222556,-26.147579278893538,-26.16264099556152,-26.177702712229504,-26.192764428897483,-26.207826145565463,-26.222887862233446,-26.23794957890143,-26.253011295569408,-26.268073012237387,-26.283134728905374,-26.29819644557335,-26.313258162241333,-26.328319878909312,-26.3433815955773,-26.358443312245274,-26.373505028913254,-26.388566745581237,-26.403628462249223,-26.418690178917203,-26.43375189558518,-26.448813612253165,-26.46387532892114,-26.47893704558912,-26.493998762257103,-26.509060478925086,-26.52412219559307,-26.53918391226105,-26.55424562892903,-26.56930734559701,-26.584369062264997,-26.599430778932977,-26.614492495600956,-26.629554212268935,-26.64461592893692,-26.659677645604898,-26.67473936227288,-26.68980107894086,-26.704862795608843,-26.719924512276823,-26.734986228944802,-26.75004794561279,-26.765109662280764,-26.78017137894875,-26.79523309561673,-26.81029481228471,-26.825356528952693,-26.840418245620672,-26.855479962288655,-26.870541678956634,-26.885603395624614,-26.900665112292597,-26.915726828960576,-26.930788545628555,-26.945850262296542,-26.96091197896452,-26.975973695632504,-26.96968779492686,-26.920706659473986,-26.871725524021116,-26.822744388568243,-26.77376325311537,-26.724782117662503,-26.67580098220963,-26.626819846756753,-26.577838711303887,-26.528857575851013,-26.479876440398137,-26.430895304945267,-26.381914169492397,-26.33293303403952,-26.283951898586654,-26.23497076313378,-26.185989627680904,-26.137008492228038,-26.088027356775164,-26.039046221322295,-25.990065085869418,-25.941083950416548,-25.892102814963675,-25.8431216795108,-25.79414054405793,-25.74515940860506,-25.696178273152185,-25.647197137699315,-25.598216002246442,-25.54923486679357,-25.500253731340695,-25.45127259588783,-25.402291460434952,-25.35331032498208,-25.304329189529213,-25.255348054076336,-25.206366918623463,-25.157385783170596,-25.108404647717723,-25.059423512264846,-25.010442376811977,-24.96146124135911,-24.912480105906234,-24.863498970453357,-24.81451783500049,-24.765536699547617,-24.71655556409474,-24.667574428641874,-24.618593293189004,-24.569612157736124,-24.520631022283258,-24.471649886830384,-24.422668751377515,-24.373687615924638,-24.324706480471768,-24.2757253450189,-24.22674420956602,-24.17776307411315,-24.128781938660282,-24.079800803207405,-24.030819667754535,-23.98183853230167,-23.93285739684879,-23.88387626139592,-23.834895125943053,-23.785913990490172,-23.736932855037303,-23.687951719584436,-23.638970584131556,-23.589989448678686,-23.541008313225817,-23.492027177772943,-23.44304604232007,-23.3940649068672,-23.346894592957337,-23.301748142157898,-23.256601691358448,-23.211455240559015,-23.16630878975957,-23.12116233896012,-23.076015888160683,-23.03086943736124,-22.985722986561797,-22.953995918331742,-22.98936576294858,-23.024735607565425,-23.060105452182267,-23.0954752967991,-23.130845141415943,-23.166214986032784,-23.20158483064962,-23.236954675266464,-23.272324519883302,-23.307694364500136,-23.343064209116978,-23.37843405373382,-23.413803898350665,-23.449173742967496,-23.48454358758434,-23.519167390048263,-23.38451266770253,-23.249857945356773,-23.115203223011015,-22.980548500665282,-22.845893778319525,-22.711239055973767,-22.57658433362803,-22.441929611282276,-22.30727488893652,-22.17262016659076,-22.037965444245028,-21.90331072189927,-21.76865599955351,-21.63400127720778,-21.49934655486202,-21.36469183251626,-21.230037110170528,-21.09538238782477,-20.960727665479013,-20.826072943133255,-20.69141822078752,-20.556763498441764,-20.422108776096007,-20.287454053750274,-20.152799331404516,-20.01814460905876,-19.883489886713022,-19.748835164367264,-19.614180442021507,-19.479525719675774,-19.344870997330016,-19.21021627498426,-19.0755615526385,-18.940906830292768,-18.80625210794701,-18.671597385601252,-18.53694266325552,-18.40228794090976,-18.267633218564,-18.132978496218268,-17.998323773872514,-17.863669051526752,-17.729014329180995,-17.594359606835262,-17.459704884489504,-17.325050162143746,-17.19039543979801,-17.055740717452256,-16.921085995106495,-16.786431272760765,-16.625620402949295,-16.329785386914153,-16.03395037087906,-15.738115354843917,-15.442280338808771,-15.146445322773626,-14.850610306738536,-14.554775290703391,-14.258940274668248,-13.963105258633156,-13.667270242598011,-13.371435226562866,-13.075600210527776,-12.779765194492631,-12.483930178457484,-12.18809516242234,-11.892260146387251],[-19.156283539476533,-19.178661636578724,-19.20103973368091,-19.2234178307831,-19.245795927885293,-19.26817402498748,-19.29055212208967,-19.31293021919186,-19.33530831629405,-19.357686413396237,-19.38006451049843,-19.40244260760062,-19.424820704702807,-19.447198801804998,-19.469576898907185,-19.491954996009376,-19.514333093111567,-19.536711190213754,-19.559089287315945,-19.581467384418136,-19.603845481520324,-19.626223578622515,-19.648601675724706,-19.670979772826893,-19.69335786992908,-19.71573596703127,-19.738114064133462,-19.76049216123565,-19.78287025833784,-19.80524835544003,-19.82762645254222,-19.85000454964441,-19.8723826467466,-19.89476074384879,-19.917138840950976,-19.939516938053167,-19.961895035155354,-19.98427313225755,-20.006651229359736,-20.029029326461924,-20.051407423564115,-20.073785520666306,-20.096163617768493,-20.118541714870684,-20.140919811972875,-20.163297909075062,-20.18567600617725,-20.208054103279444,-20.23043220038163,-20.25281029748382,-20.27518839458601,-20.2975664916882,-20.31994458879039,-20.34232268589258,-20.364700782994767,-20.387078880096958,-20.40945697719915,-20.431835074301336,-20.454213171816868,-20.478895952348203,-20.503578732879536,-20.528261513410868,-20.5529442939422,-20.577627074473533,-20.602309855004865,-20.626992635536197,-20.651675416067533,-20.676358196598866,-20.701040977130198,-20.725723757661534,-20.750406538192863,-20.775089318724195,-20.79977209925553,-20.824454879786863,-20.849137660318195,-20.87382044084953,-20.898503221380864,-20.923186001912192,-20.94786878244353,-20.97255156297486,-20.997234343506197,-21.02191712403753,-21.046599904568858,-21.071282685100194,-21.095383300534525,-21.119367482949464,-21.143351665364392,-21.167335847779327,-21.191320030194262,-21.215304212609198,-21.239288395024133,-21.263272577439064,-21.287256759854,-21.31124094226893,-21.33522512468387,-21.3592093070988,-21.383193489513737,-21.40717767192867,-21.431161854343607,-21.45514603675854,-21.47913021917347,-21.503114401588405,-21.52709858400334,-21.551082766418276,-21.575066948833207,-21.599051131248142,-21.623035313663074,-21.64701949607801,-21.671003678492944,-21.69339254862002,-21.714983761959413,-21.7365749752988,-21.75816618863819,-21.77975740197758,-21.801348615316968,-21.82293982865636,-21.844531041995747,-21.866122255335135,-21.887713468674526,-21.909304682013918,-21.930895895353302,-21.95248710869269,-21.97407832203208,-21.995669535371473,-22.01726074871086,-22.03885196205025,-22.060443175389636,-22.08203438872903,-22.10362560206842,-22.125216815407807,-22.146808028747195,-22.168399242086586,-22.189990455425978,-22.211581668765362,-22.233172882104753,-22.25476409544414,-22.27635530878353,-22.29794652212292,-22.319537735462312,-22.341128948801703,-22.362720162141088,-22.38431137548048,-22.405902588819867,-22.427493802159255,-22.449085015498646,-22.470676228838034,-22.492267442177425,-22.513858655516813,-22.535449868856205,-22.557041082195592,-22.57863229553498,-22.60022350887437,-22.621814722213756,-22.643405935553147,-22.66499714889254,-22.686588362231923,-22.708179575571318,-22.729770788910706,-22.75136200225009,-22.772953215589485,-22.794544428928873,-22.816135642268264,-22.83772685560765,-22.85931806894704,-22.88090928228643,-22.90250049562582,-22.924091708965207,-22.94869875953881,-22.974813728729515,-23.00092869792022,-23.027043667110927,-23.05315863630163,-23.07927360549234,-23.105388574683044,-23.13150354387375,-23.157618513064456,-23.18373348225516,-23.20984845144587,-23.235963420636573,-23.26207838982728,-23.288193359017985,-23.314308328208693,-23.340423297399397,-23.3665382665901,-23.39265323578081,-23.418768204971517,-23.44488317416222,-23.470998143352926,-23.49711311254363,-23.523228081734338,-23.549343050925042,-23.57545802011575,-23.601572989306455,-23.627687958497162,-23.653802927687867,-23.67991789687857,-23.70603286606928,-23.732147835259987,-23.758262804450688,-23.784377773641395,-23.810492742832103,-23.836607712022808,-23.862722681213512,-23.88883765040422,-23.914332678272075,-23.93852583488153,-23.96271899149098,-23.986912148100433,-24.011105304709886,-24.03529846131934,-24.059491617928792,-24.08368477453824,-24.10787793114769,-24.13207108775714,-24.156264244366593,-24.180457400976046,-24.2046505575855,-24.22884371419495,-24.2530368708044,-24.277230027413854,-24.301423184023307,-24.325616340632756,-24.349809497242205,-24.374002653851655,-24.39819581046111,-24.42238896707056,-24.44658212368001,-24.470775280289462,-24.494968436898915,-24.51916159350837,-24.54335475011782,-24.56754790672727,-24.591741063336723,-24.615934219946173,-24.640127376555625,-24.664320533165075,-24.68851368977453,-24.71270684638398,-24.736900002993433,-24.761093159602886,-24.785286316212336,-24.809479472821785,-24.833672629431234,-24.857865786040687,-24.88205894265014,-24.90625209925959,-24.930445255869046,-24.954638412478495,-24.978831569087948,-25.003024725697397,-25.02605652147063,-25.047926956407643,-25.069797391344657,-25.09166782628167,-25.113538261218686,-25.135408696155693,-25.157279131092707,-25.17914956602972,-25.20102000096674,-25.222890435903746,-25.24476087084076,-25.266631305777775,-25.28850174071479,-25.3103721756518,-25.332242610588814,-25.354113045525825,-25.37598348046284,-25.397853915399853,-25.419724350336868,-25.441594785273878,-25.463465220210892,-25.485335655147907,-25.507206090084917,-25.529076525021935,-25.550946959958942,-25.572817394895957,-25.59468782983297,-25.616558264769985,-25.638428699707,-25.66029913464401,-25.68216956958102,-25.704040004518042,-25.72591043945505,-25.747780874392063,-25.769651309329078,-25.791521744266092,-25.813392179203102,-25.835262614140117,-25.857133049077127,-25.879003484014138,-25.900873918951152,-25.922744353888167,-25.944614788825177,-25.96648522376219,-25.988355658699206,-26.008448030950063,-26.023509747618043,-26.038571464286026,-26.05363318095401,-26.068694897621988,-26.083756614289968,-26.098818330957947,-26.113880047625933,-26.128941764293913,-26.144003480961892,-26.15906519762987,-26.174126914297858,-26.189188630965837,-26.204250347633817,-26.219312064301796,-26.234373780969783,-26.249435497637762,-26.26449721430574,-26.279558930973725,-26.294620647641704,-26.309682364309687,-26.324744080977666,-26.33980579764565,-26.35486751431363,-26.36992923098161,-26.384990947649595,-26.400052664317574,-26.415114380985557,-26.430176097653536,-26.445237814321516,-26.460299530989495,-26.475361247657478,-26.49042296432546,-26.50548468099344,-26.52054639766142,-26.535608114329403,-26.550669830997382,-26.56573154766536,-26.559445646959723,-26.510464511506854,-26.46148337605398,-26.412502240601107,-26.363521105148237,-26.314539969695367,-26.26555883424249,-26.216577698789617,-26.16759656333675,-26.118615427883874,-26.069634292431,-26.02065315697813,-25.971672021525258,-25.922690886072388,-25.87370975061952,-25.824728615166645,-25.775747479713772,-25.726766344260902,-25.677785208808032,-25.628804073355155,-25.57982293790228,-25.53084180244941,-25.48186066699654,-25.432879531543662,-25.383898396090792,-25.334917260637923,-25.285936125185046,-25.23695498973218,-25.187973854279306,-25.13899271882643,-25.090011583373556,-25.041030447920694,-24.99204931246782,-24.943068177014943,-24.894087041562074,-24.845105906109204,-24.796124770656327,-24.747143635203457,-24.698162499750588,-24.64918136429771,-24.60020022884484,-24.55121909339197,-24.502237957939094,-24.453256822486225,-24.40427568703335,-24.356146704716313,-24.31100025391687,-24.265853803117427,-24.220707352317987,-24.175560901518544,-24.1304144507191,-24.08526799991966,-24.040121549120215,-23.994975098320772,-23.949828647521333,-23.904682196721886,-23.859535745922443,-23.814389295123004,-23.769242844323564,-23.724096393524118,-23.678949942724678,-23.633803491925235,-23.588657041125792,-23.54351059032635,-23.49836413952691,-23.453217688727467,-23.40807123792802,-23.36292478712858,-23.317778336329138,-23.272631885529695,-23.227485434730255,-23.182338983930812,-23.137192533131365,-23.09204608233193,-23.046899631532487,-23.00175318073304,-22.956606729933597,-22.91146027913416,-22.86631382833471,-22.821167377535268,-22.776020926735825,-22.730874475936385,-22.68572802513694,-22.654000956906888,-22.68937080152373,-22.724740646140567,-22.760110490757413,-22.79548033537425,-22.83085017999109,-22.86622002460793,-22.901589869224765,-22.93695971384161,-22.97232955845845,-23.007699403075282,-23.043069247692124,-23.078439092308965,-23.113808936925807,-23.149178781542645,-23.184548626159486,-23.219918470776328,-23.255288315393162,-23.290658160010004,-23.32602800462685,-23.36139784924368,-23.39676769386052,-23.432137538477363,-23.4675073830942,-23.502877227711043,-23.538247072327884,-23.573616916944722,-23.608986761561557,-23.644356606178402,-23.679726450795243,-23.715096295412078,-23.75046614002892,-23.676117978627545,-23.556591617671405,-23.437065256715243,-23.317538895759082,-23.19801253480292,-23.078486173846784,-22.958959812890622,-22.83943345193446,-22.71990709097832,-22.60038073002216,-22.480854369065995,-22.361328008109858,-22.241801647153697,-22.12227528619754,-22.002748925241395,-21.883222564285234,-21.763696203329076,-21.644169842372914,-21.524643481416774,-21.405117120460613,-21.20478246703317,-20.90894745099808,-20.613112434962936,-20.317277418927787,-20.0214424028927,-19.725607386857554,-19.429772370822413,-19.133937354787264,-18.838102338752176,-18.54226732271703,-18.246432306681886,-17.950597290646794,-17.654762274611652,-17.358927258576504,-17.063092242541416,-16.76725722650627,-16.471422210471125,-16.175587194436034,-15.87975217840089,-15.583917162365745,-15.288082146330598,-14.99224713029551,-14.696412114260365,-14.40057709822522,-14.104742082190128,-13.808907066154985,-13.51307205011984,-13.21723703408475,-12.921402018049605,-12.62556700201446,-12.329731985979315,-12.033896969944223],[-18.706025905782425,-18.728404002884613,-18.750782099986804,-18.77316019708899,-18.795538294191182,-18.817916391293373,-18.84029448839556,-18.86267258549775,-18.88505068259994,-18.90742877970213,-18.92980687680432,-18.95218497390651,-18.974563071008696,-18.996941168110887,-19.019319265213078,-19.04169736231527,-19.064075459417456,-19.086453556519647,-19.108831653621834,-19.131209750724025,-19.153587847826213,-19.175965944928404,-19.19834404203059,-19.220722139132782,-19.243100236234973,-19.265478333337164,-19.287856430439355,-19.31023452754154,-19.33261262464373,-19.35499072174592,-19.37736881884811,-19.3997469159503,-19.422125013052487,-19.444503110154677,-19.46688120725687,-19.48925930435906,-19.511637401461243,-19.534015498563438,-19.556393595665625,-19.578771692767816,-19.601149789870007,-19.623527886972195,-19.645905984074382,-19.668284081176576,-19.690662178278764,-19.71304027538095,-19.735418372483142,-19.757796469585333,-19.78017456668752,-19.80255266378971,-19.8249307608919,-19.84730885799409,-19.86968695509628,-19.89206505219847,-19.914443149300656,-19.93682124640285,-19.959199343505038,-19.981577440607225,-20.003955537709416,-20.026333634811607,-20.048711731913794,-20.071089829015985,-20.093467926118176,-20.115846023220364,-20.138224120322555,-20.160602217424742,-20.182980314526933,-20.205358411629124,-20.22773650873131,-20.250114605833502,-20.272492702935693,-20.29487080003788,-20.317248897140068,-20.339626994242263,-20.36200509134445,-20.38553553019428,-20.41021831072561,-20.43490109125694,-20.459583871788276,-20.484266652319608,-20.508949432850944,-20.533632213382276,-20.558314993913612,-20.58299777444494,-20.607098389879276,-20.63108257229421,-20.655066754709143,-20.679050937124074,-20.703035119539013,-20.727019301953945,-20.75100348436888,-20.774987666783815,-20.798573021053823,-20.82016423439321,-20.8417554477326,-20.86334666107199,-20.88493787441138,-20.90652908775077,-20.928120301090157,-20.94971151442955,-20.971302727768936,-20.992893941108328,-21.014485154447716,-21.036076367787107,-21.057667581126495,-21.079258794465883,-21.100850007805274,-21.122441221144662,-21.144032434484053,-21.16562364782344,-21.18721486116283,-21.20880607450222,-21.230397287841612,-21.251988501181,-21.273579714520388,-21.29517092785978,-21.316762141199163,-21.338353354538555,-21.359944567877946,-21.381535781217337,-21.40312699455672,-21.424718207896113,-21.446309421235505,-21.467900634574892,-21.48949184791428,-21.511083061253668,-21.532674274593063,-21.554265487932447,-21.57585670127184,-21.597447914611227,-21.619039127950614,-21.640630341290006,-21.662221554629397,-21.68381276796878,-21.705403981308173,-21.726995194647564,-21.748586407986956,-21.77017762132634,-21.79176883466573,-21.813360048005123,-21.83495126134451,-21.8565424746839,-21.87813368802329,-21.899724901362674,-21.92131611470207,-21.942907328041457,-21.964498541380845,-21.986089754720236,-22.007680968059624,-22.029272181399016,-22.050863394738403,-22.072454608077795,-22.09404582141718,-22.11563703475657,-22.13722824809596,-22.158819461435346,-22.180410674774738,-22.202001888114125,-22.223593101453517,-22.245184314792905,-22.266775528132296,-22.288366741471684,-22.309957954811075,-22.33154916815046,-22.35314038148985,-22.374731594829242,-22.39632280816863,-22.420929858742234,-22.447044827932935,-22.47315979712364,-22.499274766314347,-22.52538973550505,-22.551504704695763,-22.577619673886463,-22.603734643077168,-22.629849612267876,-22.655964581458583,-22.682079550649288,-22.708194519839992,-22.7343094890307,-22.758874608617187,-22.78306776522664,-22.80726092183609,-22.831454078445542,-22.855647235054995,-22.879840391664448,-22.9040335482739,-22.92822670488335,-22.9524198614928,-22.976613018102253,-23.000806174711705,-23.024999331321155,-23.04919248793061,-23.07338564454006,-23.09757880114951,-23.121771957758963,-23.145965114368416,-23.170158270977865,-23.194351427587318,-23.218544584196767,-23.242737740806223,-23.26693089741567,-23.291124054025122,-23.31531721063457,-23.339510367244024,-23.363703523853474,-23.38789668046293,-23.412089837072383,-23.436282993681832,-23.460476150291285,-23.484669306900738,-23.508862463510187,-23.53305562011964,-23.55724877672909,-23.581441933338542,-23.605635089947995,-23.629828246557445,-23.654021403166897,-23.67821455977635,-23.7024077163858,-23.726600872995252,-23.7507940296047,-23.774987186214155,-23.799180342823604,-23.823373499433057,-23.847566656042506,-23.87175981265196,-23.89595296926141,-23.920146125870865,-23.944339282480314,-23.968532439089767,-23.992725595699216,-24.01691875230867,-24.041111908918122,-24.06530506552757,-24.089498222137024,-24.113691378746474,-24.137884535355926,-24.16207769196538,-24.186270848574832,-24.210464005184285,-24.23465716179373,-24.258850318403184,-24.283043475012636,-24.30723663162209,-24.33142978823154,-24.35562294484099,-24.379816101450444,-24.404009258059894,-24.428202414669343,-24.45123421044258,-24.473104645379593,-24.494975080316603,-24.516845515253618,-24.53871595019063,-24.560586385127642,-24.582456820064657,-24.60432725500167,-24.62619768993868,-24.648068124875696,-24.669938559812707,-24.691808994749724,-24.713679429686735,-24.73554986462375,-24.75742029956076,-24.77929073449777,-24.801161169434785,-24.8230316043718,-24.844902039308813,-24.866772474245828,-24.888642909182842,-24.910513344119853,-24.932383779056863,-24.954254213993877,-24.97612464893089,-24.997995083867906,-25.01986551880492,-25.041735953741934,-25.063606388678945,-25.085476823615956,-25.10734725855297,-25.129217693489984,-25.15108812842699,-25.17295856336401,-25.194828998301023,-25.216699433238038,-25.23856986817505,-25.260440303112063,-25.282310738049073,-25.304181172986087,-25.326051607923098,-25.347922042860112,-25.369792477797127,-25.39166291273414,-25.41353334767115,-25.435403782608166,-25.457274217545176,-25.47914465248219,-25.501015087419205,-25.522885522356216,-25.544755957293233,-25.566626392230244,-25.588496827167255,-25.61036726210427,-25.632237697041283,-25.65410813197829,-25.675978566915308,-25.697849001852326,-25.719719436789337,-25.741589871726347,-25.76346030666336,-25.785330741600376,-25.80720117653739,-25.8290716114744,-25.850942046411415,-25.872812481348426,-25.89468291628544,-25.916553351222454,-25.938423786159465,-25.959687083014472,-25.974748799682455,-25.989810516350435,-26.004872233018418,-26.019933949686397,-26.03499566635438,-26.05005738302236,-26.065119099690342,-26.08018081635832,-26.0952425330263,-26.110304249694284,-26.125365966362267,-26.140427683030246,-26.155489399698226,-26.149203498992584,-26.100222363539714,-26.051241228086845,-26.00226009263397,-25.9532789571811,-25.904297821728232,-25.85531668627535,-25.80633555082248,-25.757354415369615,-25.70837327991674,-25.65939214446387,-25.610411009010996,-25.561429873558122,-25.51244873810525,-25.46346760265238,-25.41448646719951,-25.365505331746633,-25.32025236567585,-25.275105914876406,-25.22995946407696,-25.184813013277516,-25.139666562478077,-25.094520111678634,-25.04937366087919,-25.004227210079748,-24.959080759280305,-24.91393430848086,-24.868787857681422,-24.823641406881986,-24.77849495608254,-24.73334850528309,-24.688202054483657,-24.64305560368421,-24.59790915288476,-24.552762702085325,-24.507616251285885,-24.46246980048644,-24.417323349686995,-24.37217689888756,-24.327030448088117,-24.281883997288674,-24.23673754648923,-24.191591095689787,-24.146444644890344,-24.1012981940909,-24.05615174329146,-24.011005292492015,-23.965858841692572,-23.920712390893137,-23.875565940093686,-23.830419489294243,-23.785273038494807,-23.74012658769536,-23.694980136895918,-23.64983368609648,-23.604687235297032,-23.55954078449759,-23.51439433369815,-23.469247882898706,-23.424101432099263,-23.37895498129982,-23.33380853050038,-23.288662079700934,-23.243515628901495,-23.198369178102055,-23.153222727302612,-23.108076276503166,-23.06292982570373,-23.017783374904283,-22.972636924104837,-22.9274904733054,-22.882344022505958,-22.83719757170651,-22.79205112090707,-22.746904670107632,-22.701758219308186,-22.656611768508743,-22.611465317709303,-22.56631886690986,-22.521172416110417,-22.476025965310974,-22.43087951451153,-22.385733063712085,-22.354005995482034,-22.38937584009887,-22.424745684715713,-22.460115529332562,-22.495485373949393,-22.53085521856623,-22.566225063183076,-22.601594907799914,-22.636964752416755,-22.672334597033593,-22.707704441650428,-22.691442256635373,-22.57191589567921,-22.452389534723046,-22.33286317376691,-22.213336812810745,-22.093810451854583,-21.974284090898443,-21.854757729942282,-21.73523136898612,-21.615705008029984,-21.496178647073823,-21.37665228611766,-21.25712592516152,-21.13759956420536,-21.018073203249198,-20.89854684229304,-20.7790204813369,-20.65949412038074,-20.539967759424577,-20.420441398468437,-20.300915037512276,-20.181388676556114,-20.061862315599974,-19.942335954643813,-19.82280959368765,-19.703283232731494,-19.583756871775353,-19.464230510819192,-19.344704149863034,-19.22517778890689,-19.105651427950733,-18.986125066994568,-18.86659870603843,-18.74707234508227,-18.627545984126108,-18.508019623169968,-18.388493262213807,-18.268966901257645,-18.149440540301484,-18.029914179345347,-17.910387818389182,-17.790861457433024,-17.671335096476884,-17.551808735520723,-17.43228237456456,-17.31275601360842,-17.193229652652263,-17.0737032916961,-16.954176930739937,-16.8346505697838,-16.71512420882764,-16.595597847871478,-16.476071486915338,-16.356545125959176,-16.237018765003015,-16.117492404046875,-15.997966043090715,-15.878439682134553,-15.758913321178415,-15.639386960222254,-15.519860599266092,-15.40033423830993,-15.133883953852484,-14.838048937817339,-14.542213921782194,-14.246378905747104,-13.950543889711959,-13.654708873676814,-13.358873857641724,-13.063038841606577,-12.767203825571436,-12.471368809536289,-12.175533793501199],[-18.250341314415053,-18.27271941151724,-18.295097508619435,-18.31747560572162,-18.339853702823813,-18.362231799926,-18.384609897028188,-18.40698799413038,-18.42936609123257,-18.451744188334757,-18.47412228543695,-18.49650038253914,-18.518878479641327,-18.541256576743518,-18.563634673845705,-18.586012770947896,-18.608390868050083,-18.630768965152274,-18.653147062254465,-18.675525159356656,-18.697903256458844,-18.72028135356103,-18.74265945066322,-18.765037547765413,-18.7874156448676,-18.80979374196979,-18.832171839071982,-18.854549936174173,-18.87692803327636,-18.899306130378548,-18.92168422748074,-18.94406232458293,-18.96644042168512,-18.98881851878731,-19.011196615889496,-19.033574712991687,-19.055952810093874,-19.07833090719607,-19.100709004298256,-19.123087101400444,-19.145465198502635,-19.167843295604825,-19.190221392707013,-19.212599489809204,-19.23497758691139,-19.257355684013582,-19.27973378111577,-19.30211187821796,-19.324489975320148,-19.34686807242234,-19.36924616952453,-19.39162426662672,-19.41400236372891,-19.436380460831096,-19.458758557933287,-19.481136655035478,-19.50351475213767,-19.525892849239856,-19.548270946342043,-19.570649043444234,-19.593027140546425,-19.615405237648613,-19.637783334750804,-19.66016143185299,-19.682539528955182,-19.704917626057373,-19.72729572315956,-19.74967382026175,-19.77205191736394,-19.79443001446613,-19.81680811156832,-19.839186208670508,-19.861564305772696,-19.88394240287489,-19.906320499977078,-19.92869859707927,-19.949718224513305,-19.970058617573738,-19.99039901063417,-20.010739403694608,-20.03107979675504,-20.051420189815474,-20.07176058287591,-20.092100975936344,-20.111381698986655,-20.130450488034935,-20.14951927708322,-20.1685880661315,-20.18765685517978,-20.206725644228065,-20.225794433276345,-20.244863222324625,-20.26645443528401,-20.288045648623395,-20.309636861962787,-20.331228075302178,-20.352819288641566,-20.374410501980954,-20.396001715320345,-20.417592928659733,-20.439184141999124,-20.460775355338512,-20.4823665686779,-20.503957782017288,-20.52554899535668,-20.54714020869607,-20.568731422035455,-20.590322635374847,-20.611913848714238,-20.633505062053622,-20.655096275393014,-20.676687488732405,-20.698278702071793,-20.719869915411184,-20.741461128750572,-20.76305234208996,-20.784643555429348,-20.80623476876874,-20.827825982108127,-20.84941719544752,-20.871008408786906,-20.892599622126294,-20.914190835465682,-20.935782048805073,-20.957373262144465,-20.97896447548385,-21.00055568882324,-21.022146902162632,-21.043738115502023,-21.065329328841408,-21.0869205421808,-21.10851175552019,-21.13010296885958,-21.151694182198966,-21.173285395538358,-21.194876608877745,-21.216467822217133,-21.238059035556525,-21.259650248895916,-21.281241462235304,-21.30283267557469,-21.324423888914083,-21.34601510225347,-21.36760631559286,-21.38919752893225,-21.410788742271638,-21.432379955611026,-21.453971168950417,-21.475562382289805,-21.497153595629197,-21.518744808968584,-21.540336022307972,-21.561927235647364,-21.58351844898675,-21.605109662326143,-21.626700875665534,-21.64829208900492,-21.66988330234431,-21.691474515683698,-21.71306572902309,-21.734656942362477,-21.756248155701865,-21.777839369041256,-21.799430582380648,-21.821021795720032,-21.842613009059423,-21.86420422239881,-21.887263810337767,-21.911057585576504,-21.934851360815237,-21.95864513605397,-21.982438911292707,-22.006232686531444,-22.03002646177018,-22.053820237008914,-22.077614012247647,-22.10140778748638,-22.12520156272512,-22.148995337963854,-22.172789113202587,-22.196582888441323,-22.22037666368006,-22.244170438918793,-22.26796421415753,-22.29175798939626,-22.315551764635,-22.339345539873737,-22.36313931511247,-22.386933090351206,-22.410726865589943,-22.434520640828676,-22.45831441606741,-22.482108191306146,-22.505901966544883,-22.52969574178362,-22.55348951702235,-22.577283292261086,-22.601077067499823,-22.62487084273856,-22.648664617977293,-22.67245839321603,-22.696252168454762,-22.7200459436935,-22.743839718932236,-22.76763349417097,-22.791427269409706,-22.81522104464844,-22.839014819887172,-22.862808595125912,-22.886602370364646,-22.91039614560338,-22.934189920842115,-22.958233309091586,-22.982426465701035,-23.006619622310488,-23.03081277891994,-23.055005935529394,-23.079199092138843,-23.103392248748296,-23.127585405357745,-23.1517785619672,-23.175971718576648,-23.2001648751861,-23.224358031795553,-23.248551188405003,-23.272744345014452,-23.296937501623905,-23.321130658233358,-23.34532381484281,-23.369516971452256,-23.393710128061713,-23.417903284671162,-23.442096441280615,-23.466289597890068,-23.490482754499517,-23.51467591110897,-23.538869067718423,-23.563062224327872,-23.58725538093732,-23.611448537546778,-23.635641694156227,-23.659834850765677,-23.684028007375133,-23.708221163984582,-23.732414320594035,-23.756607477203485,-23.780800633812937,-23.804993790422387,-23.82918694703184,-23.853380103641292,-23.876411899414524,-23.89828233435154,-23.920152769288553,-23.942023204225563,-23.963893639162578,-23.98576407409959,-24.007634509036603,-24.029504943973617,-24.051375378910627,-24.07324581384764,-24.095116248784652,-24.11698668372167,-24.13885711865868,-24.160727553595695,-24.182597988532706,-24.204468423469716,-24.22633885840673,-24.24820929334375,-24.27007972828076,-24.291950163217773,-24.313820598154784,-24.3356910330918,-24.35756146802881,-24.379431902965823,-24.40130233790284,-24.42317277283985,-24.445043207776866,-24.46691364271388,-24.48878407765089,-24.5106545125879,-24.53252494752492,-24.554395382461934,-24.57626581739894,-24.59813625233596,-24.620006687272973,-24.641877122209983,-24.663747557146994,-24.685617992084012,-24.70748842702102,-24.729358861958037,-24.751493373846227,-24.774080583237055,-24.79666779262788,-24.819255002018703,-24.84184221140953,-24.86442942080036,-24.887016630191184,-24.90960383958201,-24.932191048972832,-24.95477825836366,-24.97736546775449,-24.999952677145316,-25.022539886536137,-25.04512709592697,-25.067714305317793,-25.09030151470862,-25.112888724099445,-25.135475933490277,-25.158063142881094,-25.180650352271922,-25.203237561662753,-25.225824771053578,-25.2484119804444,-25.27099918983523,-25.293586399226054,-25.31617360861688,-25.338760818007707,-25.361348027398535,-25.383935236789355,-25.406522446180187,-25.42910965557101,-25.451696864961836,-25.474284074352664,-25.496871283743488,-25.519458493134316,-25.54204570252514,-25.564632911915965,-25.587220121306792,-25.60980733069762,-25.632394540088445,-25.654981749479276,-25.677568958870097,-25.700156168260925,-25.702506235672825,-25.664382019126887,-25.626257802580955,-25.588133586035017,-25.55000936948908,-25.511885152943144,-25.473760936397206,-25.43563671985127,-25.39751250330534,-25.359388286759398,-25.32126407021346,-25.283139853667524,-25.24501563712159,-25.202979430097066,-25.157835549959852,-25.11269166982264,-25.067547789685424,-25.02240390954821,-24.977260029411,-24.93211614927378,-24.886972269136564,-24.84182838899935,-24.796684508862135,-24.751540628724914,-24.706396748587707,-24.661252868450493,-24.61610898831328,-24.570965108176065,-24.52582122803885,-24.480677347901633,-24.43553346776442,-24.390389587627205,-24.345245707489987,-24.30010182735277,-24.254957947215555,-24.209814067078348,-24.16467018694113,-24.119526306803913,-24.074382426666702,-24.029238546529484,-23.984094666392267,-23.938950786255056,-23.89380690611784,-23.84866302598062,-23.80351914584341,-23.758375265706192,-23.713231385568978,-23.668087505431767,-23.622943625294553,-23.577799745157336,-23.532655865020125,-23.487511984882907,-23.44236810474569,-23.39722422460848,-23.35208034447126,-23.30693646433405,-23.261792584196833,-23.21664870405962,-23.171504823922405,-23.126360943785187,-23.081217063647976,-23.036073183510762,-22.990929303373544,-22.945785423236334,-22.90064154309912,-22.855497662961902,-22.810353782824684,-22.765209902687474,-22.72006602255026,-22.67492214241304,-22.629778262275828,-22.584634382138614,-22.539490502001396,-22.494346621864185,-22.449202741726968,-22.404058861589753,-22.358914981452536,-22.31377110131533,-22.26862722117811,-22.223483341040893,-22.17833946090368,-22.133195580766465,-22.088051700629247,-22.062621626561636,-22.135760582841986,-22.20889953912234,-22.28203849540269,-22.355177451683033,-22.428316407963386,-22.50145536424374,-22.574594320524078,-22.64773327680443,-22.720872233084783,-22.794011189365122,-22.867150145645475,-22.940289101925828,-23.013428058206184,-23.086567014486523,-23.159705970766872,-23.232844927047225,-23.305983883327567,-23.37912283960792,-23.45226179588827,-23.525400752168615,-23.598539708448968,-23.67167866472932,-23.74481762100966,-23.81795657729001,-23.891095533570365,-23.964234489850714,-23.90798615619728,-23.788459795241117,-23.668933434284956,-23.54940707332882,-23.429880712372658,-23.310354351416496,-23.190827990460356,-23.071301629504195,-22.951775268548033,-22.83224890759187,-22.71272254663573,-22.593196185679574,-22.473669824723412,-22.354143463767272,-22.23461710281111,-22.11509074185495,-21.995564380898813,-21.876038019942648,-21.756511658986486,-21.636985298030346,-21.51745893707419,-21.397932576118027,-21.278406215161866,-21.158879854205725,-21.039353493249564,-20.919827132293403,-20.800300771337263,-20.6807744103811,-20.56124804942494,-20.441721688468803,-20.230591232136227,-19.926044081586646,-19.62149693103707,-19.316949780487548,-19.012402629937966,-18.70785547938839,-18.403308328838868,-18.09876117828929,-17.794214027739713,-17.48966687719019,-17.185119726640615,-16.880572576091033,-16.576025425541513,-16.271478274991935,-15.966931124442354,-15.66238397389278,-15.357836823343257,-15.053289672793678,-14.748742522244099,-14.444195371694576,-14.139648221145,-13.835101070595421,-13.530553920045898,-13.22600676949632,-12.921459618946743,-12.616912468397164,-12.312365317847643],[-17.788652429557274,-17.811030526659465,-17.833408623761652,-17.855786720863843,-17.87816481796603,-17.900542915068222,-17.922921012170413,-17.945299109272604,-17.96767720637479,-17.99005530347698,-18.01243340057917,-18.03481149768136,-18.057189594783548,-18.07956769188574,-18.10194578898793,-18.124323886090117,-18.146701983192308,-18.1690800802945,-18.191458177396687,-18.213836274498878,-18.236214371601065,-18.258592468703256,-18.280970565805443,-18.303348662907634,-18.32572676000982,-18.348104857112013,-18.370482954214204,-18.39286105131639,-18.415239148418582,-18.43761724552077,-18.45999534262296,-18.48237343972515,-18.50475153682734,-18.52712963392953,-18.549507731031717,-18.571885828133908,-18.5942639252361,-18.616642022338286,-18.639020119440477,-18.66139821654267,-18.683776313644856,-18.706154410747047,-18.728532507849234,-18.750910604951425,-18.773288702053613,-18.795666799155804,-18.818044896257994,-18.840422993360185,-18.862801090462373,-18.88517918756456,-18.90755728466675,-18.929935381768942,-18.952313478871133,-18.97469157597332,-18.997069673075508,-19.0194477701777,-19.04182586727989,-19.06420396438208,-19.086582061484265,-19.10862054060296,-19.128960933663393,-19.14930132672383,-19.169641719784266,-19.1899821128447,-19.210322505905133,-19.230662898965566,-19.251003292026,-19.271343685086435,-19.291684078146872,-19.312024471207305,-19.33236486426774,-19.35270525732817,-19.373045650388608,-19.39338604344904,-19.413726436509474,-19.43406682956991,-19.454407222630344,-19.474747615690777,-19.495088008751214,-19.515428401811647,-19.535768794872084,-19.556109187932517,-19.576449580992954,-19.596789974053387,-19.616070697103694,-19.635139486151974,-19.654208275200258,-19.673277064248538,-19.69234585329682,-19.711414642345105,-19.730483431393385,-19.749552220441668,-19.768621009489948,-19.78768979853823,-19.806758587586515,-19.825827376634795,-19.844896165683075,-19.863964954731358,-19.88303374377964,-19.902102532827925,-19.921171321876205,-19.940240110924485,-19.959308899972772,-19.978377689021052,-19.99744647806933,-20.016515267117615,-20.0355840561659,-20.05465284521418,-20.074982845611807,-20.096574058951195,-20.118165272290586,-20.139756485629977,-20.161347698969365,-20.182938912308753,-20.204530125648144,-20.226121338987532,-20.24771255232692,-20.269303765666308,-20.2908949790057,-20.31248619234509,-20.33407740568448,-20.355668619023866,-20.377259832363258,-20.39885104570265,-20.420442259042034,-20.44203347238142,-20.463624685720816,-20.485215899060204,-20.506807112399592,-20.52839832573898,-20.54998953907837,-20.571580752417763,-20.59317196575715,-20.61476317909654,-20.636354392435926,-20.657945605775318,-20.67953681911471,-20.701128032454097,-20.722719245793485,-20.744310459132876,-20.765901672472264,-20.787492885811652,-20.809084099151043,-20.83067531249043,-20.852266525829823,-20.87385773916921,-20.8954489525086,-20.91704016584799,-20.938631379187377,-20.96022259252677,-20.98181380586616,-21.003405019205545,-21.024996232544936,-21.046587445884324,-21.06817865922371,-21.089769872563103,-21.11136108590249,-21.13295229924188,-21.15454351258127,-21.176134725920658,-21.19772593926005,-21.219317152599437,-21.24090836593883,-21.262499579278217,-21.284090792617604,-21.305682005956996,-21.327273219296384,-21.35033280723534,-21.374126582474073,-21.397920357712806,-21.421714132951546,-21.445507908190276,-21.469301683429013,-21.49309545866775,-21.516889233906483,-21.540683009145216,-21.564476784383952,-21.588270559622693,-21.612064334861422,-21.63585811010016,-21.659651885338896,-21.68344566057763,-21.707239435816366,-21.731033211055102,-21.754826986293835,-21.778620761532572,-21.80241453677131,-21.826208312010042,-21.850002087248775,-21.873795862487512,-21.89758963772625,-21.92138341296498,-21.945177188203715,-21.96897096344245,-21.992764738681185,-22.016558513919925,-22.04035228915866,-22.06414606439739,-22.087939839636128,-22.111733614874865,-22.1355273901136,-22.159321165352335,-22.183114940591068,-22.206908715829805,-22.23070249106854,-22.25449626630727,-22.27829004154601,-22.302083816784744,-22.325877592023478,-22.349671367262218,-22.37346514250095,-22.397258917739684,-22.42105269297842,-22.444846468217158,-22.46864024345589,-22.492434018694624,-22.51622779393336,-22.540021569172097,-22.56381534441083,-22.587609119649567,-22.611402894888304,-22.635196670127037,-22.658990445365774,-22.68278422060451,-22.70657799584324,-22.730371771081977,-22.754165546320714,-22.77795932155945,-22.801753096798187,-22.82554687203692,-22.849340647275653,-22.87313442251439,-22.896928197753127,-22.92072197299186,-22.9445157482306,-22.96830952346933,-22.992103298708066,-23.015897073946803,-23.038584104806166,-23.059903982956946,-23.08122386110773,-23.102543739258515,-23.123863617409295,-23.145183495560076,-23.166503373710864,-23.187823251861644,-23.20914313001243,-23.23046300816321,-23.251782886313993,-23.273102764464777,-23.29612933286415,-23.32086259151212,-23.34559585016009,-23.370329108808054,-23.395062367456024,-23.419795626103994,-23.444528884751964,-23.469262143399934,-23.493995402047904,-23.51872866069587,-23.54346191934384,-23.568195177991807,-23.59292843663978,-23.617661695287744,-23.642394953935714,-23.667128212583684,-23.69186147123165,-23.716594729879624,-23.741327988527587,-23.766061247175557,-23.790794505823527,-23.815527764471497,-23.840261023119464,-23.864271633113276,-23.8868588425041,-23.90944605189493,-23.93203326128575,-23.95462047067658,-23.977207680067405,-23.99979488945823,-24.022382098849057,-24.044969308239885,-24.06755651763071,-24.090143727021538,-24.112730936412362,-24.135318145803186,-24.157905355194014,-24.18049256458484,-24.203079773975666,-24.22566698336649,-24.24825419275732,-24.270841402148143,-24.29342861153897,-24.3160158209298,-24.338603030320623,-24.361190239711448,-24.383777449102276,-24.406364658493104,-24.428951867883928,-24.451539077274752,-24.47412628666558,-24.496713496056408,-24.519300705447233,-24.541887914838057,-24.56447512422888,-24.58706233361971,-24.609649543010537,-24.63223675240136,-24.654823961792186,-24.677411171183014,-24.699998380573838,-24.722585589964666,-24.74517279935549,-24.767760008746322,-24.790347218137143,-24.81293442752797,-24.8355216369188,-24.858108846309626,-24.88069605570045,-24.903283265091275,-24.925870474482103,-24.94845768387293,-24.971044893263752,-24.99363210265458,-25.016219312045408,-25.038806521436236,-25.061393730827056,-25.083980940217884,-25.106568149608712,-25.129155358999537,-25.151742568390365,-25.17432977778119,-25.196916987172013,-25.199267054583913,-25.161142838037982,-25.123018621492047,-25.084894404946105,-25.046770188400174,-25.008645971854236,-24.970521755308297,-24.93239753876236,-24.894273322216428,-24.85614910567049,-24.81802488912455,-24.779900672578616,-24.74177645603268,-24.703652239486743,-24.665528022940812,-24.627403806394874,-24.589279589848935,-24.551155373303,-24.513031156757066,-24.474906940211127,-24.43678272366519,-24.39865850711925,-24.36053429057332,-24.32241007402738,-24.284285857481443,-24.24616164093551,-24.208037424389573,-24.169913207843635,-24.131788991297704,-24.093664774751765,-24.055540558205827,-24.017416341659896,-23.979292125113957,-23.94116790856802,-23.903043692022084,-23.86491947547615,-23.82679525893021,-23.788671042384276,-23.75054682583834,-23.7124226092924,-23.674298392746465,-23.636174176200534,-23.598049959654592,-23.553545901010594,-23.50840202087338,-23.463258140736166,-23.418114260598948,-23.372970380461737,-23.327826500324523,-23.282682620187305,-23.23753874005009,-23.19239485991288,-23.147250979775663,-23.102107099638445,-23.056963219501235,-23.011819339364017,-22.9666754592268,-22.92153157908959,-22.876387698952374,-22.831243818815157,-22.786099938677946,-22.74095605854073,-22.695812178403514,-22.6506682982663,-22.605524418129086,-22.560380537991872,-22.51523665785465,-22.470092777717444,-22.424948897580226,-22.379805017443008,-22.334661137305797,-22.289517257168587,-22.24437337703137,-22.19922949689415,-22.15408561675694,-22.10894173661972,-22.063797856482502,-22.01865397634529,-21.973510096208077,-21.92836621607086,-21.883222335933645,-21.838078455796435,-21.79293457565922,-21.767504501591606,-21.84064345787196,-21.91378241415231,-21.986921370432665,-22.060060326713003,-22.133199282993356,-22.20633823927371,-22.279477195554048,-22.3526161518344,-22.42575510811475,-22.49889406439509,-22.57203302067545,-22.645171976955798,-22.718310933236154,-22.791449889516493,-22.864588845796845,-22.937727802077198,-23.010866758357537,-23.08400571463789,-23.157144670918242,-23.23028362719858,-23.303422583478934,-23.376561539759287,-23.449700496039625,-23.522839452319978,-23.59597840860033,-23.669117364880684,-23.741328706546778,-23.636416885433995,-23.53150506432121,-23.42659324320845,-23.321681422095665,-23.216769600982886,-23.11185777987012,-23.00694595875734,-22.902034137644556,-22.797122316531777,-22.692210495419015,-22.58729867430623,-22.482386853193447,-22.377475032080685,-22.272563210967903,-22.167651389855124,-22.062739568742362,-21.95782774762958,-21.852915926516797,-21.748004105404036,-21.643092284291253,-21.53818046317847,-21.433268642065684,-21.328356820952923,-21.22344499984014,-21.118533178727358,-21.013621357614596,-20.908709536501817,-20.803797715389035,-20.66665340587149,-20.362106255321912,-20.057559104772327,-19.753011954222757,-19.44846480367323,-19.143917653123655,-18.839370502574074,-18.534823352024553,-18.23027620147498,-17.925729050925398,-17.621181900375873,-17.316634749826296,-17.012087599276718,-16.707540448727194,-16.402993298177616,-16.09844614762804,-15.793898997078461,-15.489351846528939,-15.18480469597936,-14.880257545429782,-14.57571039488026,-14.271163244330682,-13.966616093781106,-13.662068943231581,-13.357521792682004,-13.052974642132424,-12.748427491582847,-12.443880341033324],[-17.326963544699492,-17.349341641801683,-17.37171973890387,-17.39409783600606,-17.416475933108252,-17.438854030210443,-17.46123212731263,-17.483610224414818,-17.50598832151701,-17.5283664186192,-17.55074451572139,-17.573122612823575,-17.595500709925766,-17.617878807027957,-17.640256904130148,-17.66263500123234,-17.685013098334522,-17.707391195436713,-17.729769292538904,-17.752147389641095,-17.774525486743283,-17.79690358384547,-17.81928168094766,-17.841659778049852,-17.86403787515204,-17.88641597225423,-17.90879406935642,-17.93117216645861,-17.9535502635608,-17.97592836066299,-17.99830645776518,-18.02068455486737,-18.043062651969556,-18.065440749071747,-18.08781884617394,-18.110196943276126,-18.132575040378317,-18.154953137480504,-18.177331234582695,-18.199709331684883,-18.222087428787074,-18.244465525889265,-18.266843622991452,-18.287863249753045,-18.30820364281348,-18.328544035873914,-18.348884428934348,-18.369224821994784,-18.389565215055217,-18.40990560811565,-18.430246001176087,-18.450586394236524,-18.470926787296953,-18.49126718035739,-18.511607573417827,-18.53194796647826,-18.552288359538693,-18.57262875259913,-18.592969145659563,-18.613309538719996,-18.633649931780432,-18.653990324840866,-18.6743307179013,-18.694671110961735,-18.71501150402217,-18.7353518970826,-18.75569229014304,-18.77603268320347,-18.796373076263905,-18.81671346932434,-18.837053862384778,-18.857394255445207,-18.877734648505644,-18.898075041566077,-18.918415434626514,-18.938755827686947,-18.959096220747384,-18.979436613807817,-18.99977700686825,-19.020117399928687,-19.04045779298912,-19.060798186049553,-19.08113857910999,-19.101478972170423,-19.12075969522073,-19.13982848426901,-19.158897273317294,-19.177966062365577,-19.19703485141386,-19.216103640462137,-19.23517242951042,-19.254241218558704,-19.273310007606987,-19.292378796655267,-19.31144758570355,-19.33051637475183,-19.349585163800114,-19.368653952848398,-19.387722741896678,-19.406791530944957,-19.42586031999324,-19.444929109041524,-19.463997898089808,-19.483066687138088,-19.502135476186368,-19.52120426523465,-19.540273054282935,-19.559341843331215,-19.578410632379498,-19.597479421427778,-19.61654821047606,-19.635616999524345,-19.654685788572625,-19.673754577620908,-19.692823366669188,-19.71189215571747,-19.73096094476575,-19.750029733814035,-19.769098522862315,-19.7881673119106,-19.80723610095888,-19.826304890007165,-19.84537367905544,-19.864442468103725,-19.883511257152012,-19.90510246927899,-19.926693682618378,-19.94828489595777,-19.969876109297157,-19.991467322636545,-20.013058535975937,-20.034649749315328,-20.056240962654716,-20.077832175994104,-20.09942338933349,-20.121014602672883,-20.14260581601227,-20.164197029351662,-20.18578824269105,-20.207379456030438,-20.22897066936983,-20.25056188270922,-20.27215309604861,-20.293744309387996,-20.315335522727388,-20.336926736066776,-20.358517949406163,-20.380109162745555,-20.401700376084943,-20.423291589424334,-20.444882802763722,-20.46647401610311,-20.4880652294425,-20.50965644278189,-20.53124765612128,-20.55283886946067,-20.574430082800056,-20.596021296139448,-20.61761250947884,-20.639203722818223,-20.660794936157615,-20.682386149497002,-20.70397736283639,-20.72556857617578,-20.747159789515173,-20.76875100285456,-20.79034221619395,-20.813401804132905,-20.837195579371638,-20.860989354610375,-20.884783129849108,-20.90857690508784,-20.932370680326578,-20.956164455565318,-20.979958230804048,-21.003752006042784,-21.027545781281518,-21.051339556520258,-21.07513333175899,-21.098927106997728,-21.122720882236464,-21.146514657475194,-21.170308432713934,-21.194102207952668,-21.2178959831914,-21.241689758430137,-21.26548353366887,-21.289277308907607,-21.313071084146344,-21.336864859385074,-21.360658634623817,-21.384452409862547,-21.408246185101284,-21.43203996034002,-21.45583373557875,-21.479627510817487,-21.503421286056223,-21.52721506129496,-21.551008836533693,-21.57480261177243,-21.598596387011163,-21.6223901622499,-21.646183937488637,-21.669977712727373,-21.693771487966103,-21.71756526320484,-21.741359038443576,-21.76515281368231,-21.78894658892105,-21.812740364159783,-21.836534139398516,-21.860327914637253,-21.88412168987599,-21.907915465114723,-21.931709240353456,-21.955503015592193,-21.97929679083093,-22.003090566069666,-22.02584269898984,-22.047162577140625,-22.06848245529141,-22.089802333442194,-22.111122211592978,-22.13244208974376,-22.15376196789454,-22.17508184604532,-22.196401724196107,-22.21772160234689,-22.23904148049767,-22.260361358648456,-22.281681236799237,-22.30300111495002,-22.3243209931008,-22.345640871251586,-22.366960749402367,-22.388280627553154,-22.409600505703935,-22.430920383854716,-22.452240262005503,-22.473560140156284,-22.494880018307068,-22.51619989645785,-22.53751977460863,-22.558839652759413,-22.580159530910198,-22.60147940906098,-22.622799287211762,-22.644119165362547,-22.665439043513327,-22.68675892166411,-22.709785490063485,-22.734518748711455,-22.759252007359425,-22.78398526600739,-22.80871852465536,-22.83345178330333,-22.858185041951298,-22.88291830059927,-22.90765155924724,-22.932384817895205,-22.957118076543175,-22.981851335191145,-23.00658459383911,-23.03131785248708,-23.05605111113505,-23.080784369783018,-23.105517628430988,-23.130250887078954,-23.154984145726928,-23.17971740437489,-23.20445066302286,-23.22918392167083,-23.253917180318798,-23.278650438966768,-23.303383697614734,-23.328116956262704,-23.352850214910674,-23.377583473558644,-23.40231673220661,-23.42704999085458,-23.451783249502547,-23.47651650815052,-23.501249766798487,-23.525983025446454,-23.550716284094428,-23.575449542742394,-23.60018280139036,-23.62491606003833,-23.649649318686297,-23.674382577334267,-23.69911583598224,-23.723849094630204,-23.74858235327817,-23.77331561192614,-23.79804887057411,-23.822782129222077,-23.847515387870047,-23.872248646518017,-23.896981905165987,-23.921715163813957,-23.946448422461923,-23.971181681109893,-23.99591493975786,-24.02064819840583,-24.0453814570538,-24.070114715701767,-24.094847974349737,-24.119581232997707,-24.144314491645673,-24.16904775029364,-24.19378100894161,-24.21851426758958,-24.24193361826658,-24.264520827657407,-24.28710803704823,-24.30969524643906,-24.332282455829887,-24.35486966522071,-24.377456874611532,-24.400044084002364,-24.422631293393188,-24.445218502784016,-24.467805712174844,-24.490392921565668,-24.512980130956493,-24.535567340347317,-24.55815454973815,-24.580741759128976,-24.603328968519794,-24.625916177910625,-24.64850338730145,-24.671090596692277,-24.693677806083105,-24.696027873495,-24.657903656949067,-24.619779440403132,-24.581655223857194,-24.54353100731126,-24.50540679076532,-24.46728257421939,-24.429158357673447,-24.391034141127516,-24.352909924581578,-24.314785708035643,-24.276661491489705,-24.23853727494377,-24.20041305839783,-24.162288841851893,-24.12416462530596,-24.086040408760024,-24.04791619221409,-24.00979197566815,-23.971667759122212,-23.933543542576274,-23.895419326030343,-23.857295109484408,-23.81917089293847,-23.78104667639253,-23.742922459846596,-23.704798243300658,-23.666674026754727,-23.62854981020879,-23.59042559366285,-23.552301377116912,-23.514177160570984,-23.476052944025042,-23.437928727479104,-23.399804510933173,-23.361680294387234,-23.323556077841296,-23.28543186129536,-23.24730764474943,-23.209183428203488,-23.17105921165755,-23.13293499511162,-23.094810778565677,-23.056686562019742,-23.018562345473804,-22.980438128927872,-22.942313912381934,-22.904189695836,-22.86606547929006,-22.827941262744122,-22.789817046198188,-22.751692829652256,-22.713568613106315,-22.675444396560376,-22.637320180014445,-22.59919596346851,-22.561071746922572,-22.522947530376634,-22.4848233138307,-22.44669909728476,-22.408574880738826,-22.37045066419289,-22.332326447646956,-22.294202231101018,-22.25607801455508,-22.217953798009148,-22.179829581463206,-22.141705364917275,-22.103581148371337,-22.0654569318254,-22.027332715279464,-21.98920849873353,-21.949256252061332,-21.90411237192412,-21.85896849178691,-21.813824611649686,-21.768680731512475,-21.72353685137526,-21.678392971238043,-21.633249091100826,-21.588105210963615,-21.5429613308264,-21.497817450689183,-21.47238737662157,-21.54552633290192,-21.618665289182275,-21.691804245462627,-21.76494320174297,-21.83808215802332,-21.911221114303675,-21.984360070584014,-21.92025139578611,-21.815339574673335,-21.71042775356057,-21.605515932447787,-21.500604111335008,-21.39569229022222,-21.29078046910946,-21.185868647996678,-21.080956826883895,-20.976045005771134,-20.87113318465835,-20.766221363545565,-20.661309542432804,-20.556397721320025,-20.451485900207242,-20.34657407909448,-20.241662257981698,-20.136750436868915,-20.031838615756133,-19.926926794643368,-19.82201497353059,-19.717103152417806,-19.612191331305045,-19.507279510192262,-19.402367689079483,-19.29745586796672,-19.192544046853936,-19.087632225741153,-18.982720404628367,-18.87780858351561,-18.772896762402823,-18.66798494129004,-18.563073120177283,-18.4581612990645,-18.353249477951717,-18.248337656838956,-18.143425835726177,-18.03851401461339,-17.93360219350063,-17.828690372387847,-17.723778551275064,-17.61886673016228,-17.51395490904952,-17.409043087936737,-17.304131266823955,-17.199219445711194,-17.09430762459841,-16.98939580348563,-16.884483982372867,-16.779572161260084,-16.6746603401473,-16.56974851903452,-16.464836697921758,-16.359924876808975,-16.255013055696196,-16.15010123458343,-16.045189413470652,-15.940277592357866,-15.835365771245105,-15.730453950132322,-15.62554212901954,-15.520630307906778,-15.415718486793995,-15.310806665681215,-15.20589484456843,-15.100983023455669,-14.996071202342886,-14.891159381230107,-14.707225418065946,-14.402678267516368,-14.09813111696679,-13.793583966417268,-13.48903681586769,-13.184489665318111,-12.879942514768532,-12.57539536421901],[-16.865274659841713,-16.8876527569439,-16.91003085404609,-16.932408951148282,-16.95478704825047,-16.97716514535266,-16.99954324245485,-17.02192133955704,-17.04429943665923,-17.066677533761418,-17.08905563086361,-17.111433727965796,-17.133811825067987,-17.156189922170178,-17.17856801927237,-17.200946116374556,-17.223324213476744,-17.245702310578935,-17.268080407681126,-17.290458504783317,-17.312836601885504,-17.33521469898769,-17.357592796089882,-17.379970893192073,-17.40234899029426,-17.42472708739645,-17.446765565842703,-17.467105958903133,-17.48744635196357,-17.507786745024006,-17.52812713808444,-17.548467531144873,-17.56880792420531,-17.589148317265742,-17.609488710326175,-17.629829103386612,-17.650169496447045,-17.67050988950748,-17.690850282567915,-17.711190675628348,-17.73153106868878,-17.751871461749218,-17.77221185480965,-17.792552247870084,-17.81289264093052,-17.833233033990954,-17.853573427051387,-17.873913820111824,-17.894254213172257,-17.91459460623269,-17.934934999293127,-17.955275392353563,-17.975615785413996,-17.99595617847443,-18.016296571534866,-18.0366369645953,-18.056977357655732,-18.07731775071617,-18.097658143776602,-18.117998536837035,-18.138338929897472,-18.158679322957905,-18.17901971601834,-18.199360109078775,-18.219700502139208,-18.24004089519964,-18.260381288260078,-18.28072168132051,-18.301062074380944,-18.32140246744138,-18.341742860501814,-18.36208325356225,-18.382423646622684,-18.40276403968312,-18.423104432743553,-18.443444825803986,-18.463785218864423,-18.484125611924856,-18.50446600498529,-18.524806398045726,-18.54514679110616,-18.565487184166592,-18.585827577227032,-18.606167970287462,-18.62544869333777,-18.644517482386053,-18.663586271434333,-18.682655060482617,-18.7017238495309,-18.72079263857918,-18.739861427627464,-18.758930216675743,-18.777999005724027,-18.79706779477231,-18.81613658382059,-18.835205372868874,-18.854274161917154,-18.873342950965437,-18.89241174001372,-18.911480529062,-18.93054931811028,-18.949618107158564,-18.968686896206847,-18.98775568525513,-19.00682447430341,-19.025893263351694,-19.044962052399974,-19.064030841448258,-19.08309963049654,-19.10216841954482,-19.121237208593104,-19.140305997641384,-19.159374786689668,-19.17844357573795,-19.197512364786228,-19.216581153834515,-19.235649942882795,-19.254718731931074,-19.273787520979354,-19.29285631002764,-19.31192509907592,-19.330993888124205,-19.350062677172485,-19.369131466220768,-19.38820025526905,-19.40726904431733,-19.426337833365615,-19.4454066224139,-19.46447541146218,-19.483544200510458,-19.50261298955874,-19.521681778607025,-19.540750567655305,-19.55981935670359,-19.57888814575187,-19.597956934800152,-19.617025723848435,-19.636094512896715,-19.655163301945,-19.67423209099328,-19.69330088004156,-19.71363087960679,-19.735222092946177,-19.75681330628557,-19.77840451962496,-19.799995732964344,-19.821586946303736,-19.843178159643127,-19.864769372982515,-19.886360586321903,-19.90795179966129,-19.929543013000682,-19.951134226340073,-19.972725439679458,-19.99431665301885,-20.01590786635824,-20.03749907969763,-20.059090293037016,-20.080681506376408,-20.102272719715796,-20.123863933055187,-20.145455146394575,-20.167046359733963,-20.18863757307335,-20.210228786412742,-20.231819999752133,-20.25341121309152,-20.276470801030474,-20.30026457626921,-20.324058351507944,-20.34785212674668,-20.371645901985413,-20.39543967722415,-20.419233452462887,-20.44302722770162,-20.466821002940357,-20.49061477817909,-20.514408553417827,-20.53820232865656,-20.561996103895297,-20.585789879134033,-20.609583654372766,-20.6333774296115,-20.657171204850236,-20.680964980088973,-20.70475875532771,-20.728552530566443,-20.75234630580518,-20.776140081043913,-20.799933856282646,-20.823727631521386,-20.84752140676012,-20.871315181998852,-20.89510895723759,-20.918902732476326,-20.942696507715063,-20.966490282953796,-20.99028405819253,-21.013101293173527,-21.03442117132431,-21.05574104947509,-21.077060927625876,-21.09838080577666,-21.119700683927444,-21.141020562078225,-21.16234044022901,-21.183660318379793,-21.204980196530574,-21.226300074681355,-21.24761995283214,-21.26893983098292,-21.290259709133707,-21.311579587284488,-21.33289946543527,-21.354219343586053,-21.375539221736837,-21.396859099887617,-21.4181789780384,-21.439498856189182,-21.460818734339966,-21.482138612490747,-21.503458490641535,-21.52477836879232,-21.546098246943096,-21.567418125093884,-21.588738003244664,-21.61005788139545,-21.63137775954623,-21.65269763769701,-21.674017515847794,-21.695337393998578,-21.716657272149362,-21.737977150300143,-21.75929702845093,-21.78061690660171,-21.801936784752492,-21.823256662903276,-21.84457654105406,-21.86589641920484,-21.887216297355625,-21.908536175506406,-21.92985605365719,-21.951175931807974,-21.972495809958758,-21.993815688109535,-22.01513556626032,-22.036455444411104,-22.057775322561888,-22.079095200712672,-22.100415078863453,-22.123441647262826,-22.148174905910796,-22.172908164558766,-22.197641423206733,-22.222374681854703,-22.247107940502673,-22.27184119915064,-22.296574457798613,-22.321307716446583,-22.346040975094546,-22.370774233742516,-22.395507492390486,-22.420240751038452,-22.44497400968642,-22.46970726833439,-22.49444052698236,-22.519173785630326,-22.543907044278292,-22.568640302926266,-22.593373561574232,-22.618106820222202,-22.642840078870172,-22.66757333751814,-22.69230659616611,-22.717039854814075,-22.741773113462045,-22.766506372110015,-22.791239630757985,-22.815972889405952,-22.840706148053922,-22.86543940670189,-22.890172665349862,-22.914905923997825,-22.939639182645795,-22.964372441293765,-22.98910569994173,-23.0138389585897,-23.03857221723767,-23.063305475885638,-23.088038734533608,-23.11277199318158,-23.137505251829545,-23.16223851047751,-23.18697176912548,-23.21170502777345,-23.236438286421418,-23.261171545069388,-23.285904803717358,-23.310638062365328,-23.335371321013294,-23.360104579661268,-23.384837838309235,-23.4095710969572,-23.43430435560517,-23.45903761425314,-23.483770872901108,-23.508504131549078,-23.533237390197048,-23.557970648845014,-23.582703907492984,-23.60743716614095,-23.632170424788917,-23.656903683436887,-23.681636942084857,-23.706370200732827,-23.73110345938079,-23.756095421879532,-23.781098511624414,-23.806101601369285,-23.831104691114163,-23.85610778085904,-23.881110870603923,-23.9061139603488,-23.93111705009368,-23.956120139838557,-23.981123229583435,-24.006126319328317,-24.03112940907319,-24.056132498818066,-24.081135588562947,-24.10613867830783,-24.131141768052704,-24.15614485779758,-24.16315406657717,-24.13417551342619,-24.10519696027521,-24.076218407124234,-24.047239853973252,-24.018261300822275,-23.989282747671293,-23.96030419452031,-23.931325641369334,-23.902347088218352,-23.873368535067367,-23.84438998191639,-23.81541142876541,-23.78643287561443,-23.754664744232805,-23.716959815564795,-23.67925488689678,-23.641549958228765,-23.603845029560755,-23.56614010089274,-23.528435172224725,-23.490730243556712,-23.453025314888702,-23.415320386220685,-23.377615457552672,-23.339910528884662,-23.302205600216645,-23.26450067154863,-23.22679574288062,-23.1890908142126,-23.151385885544585,-23.11368095687658,-23.075976028208565,-23.038271099540545,-23.00056617087253,-22.96286124220452,-22.925156313536505,-22.88745138486849,-22.84974645620048,-22.812041527532465,-22.77433659886445,-22.736631670196438,-22.698926741528425,-22.66122181286041,-22.623516884192398,-22.585811955524385,-22.54810702685637,-22.510402098188358,-22.472697169520345,-22.43499224085233,-22.397287312184318,-22.359582383516305,-22.32187745484829,-22.284172526180274,-22.246467597512265,-22.20876266884425,-22.171057740176234,-22.133352811508225,-22.09564788284021,-22.057942954172194,-22.020238025504185,-21.98253309683617,-21.944828168168154,-21.90712323950014,-21.86941831083213,-21.831713382164114,-21.794008453496097,-21.75630352482809,-21.71859859616007,-21.680893667492057,-21.643188738824044,-21.60548381015603,-21.567778881488017,-21.530073952820004,-21.49236902415199,-21.454664095483977,-21.416959166815964,-21.37925423814795,-21.341549309479937,-21.303844380811917,-21.26613945214391,-21.228434523475897,-21.190729594807877,-21.176564496785446,-21.280098551990857,-21.383632607196276,-21.487166662401684,-21.590700717607085,-21.6942347728125,-21.797768828017915,-21.90130288322331,-22.004836938428724,-22.10837099363414,-22.211905048839537,-22.31543910404495,-22.418973159250367,-22.52250721445578,-22.62604126966118,-22.729575324866595,-22.833109380072006,-22.936643435277404,-23.04017749048282,-23.143711545688234,-23.247245600893628,-23.350779656099043,-23.45431371130446,-23.557847766509855,-23.661381821715274,-23.764915876920686,-23.868449932126097,-23.971983987331495,-24.075518042536913,-24.17905209774232,-24.282586152947722,-24.386120208153137,-24.489654263358553,-24.593188318563946,-24.69672237376936,-24.800256428974777,-24.903790484180192,-25.00732453938559,-25.110858594591004,-25.21439264979642,-25.196333793053057,-25.091421971940278,-24.986510150827495,-24.881598329714734,-24.658974679803197,-24.35227200834799,-24.04556933689284,-23.73886666543763,-23.432163993982424,-23.12546132252722,-22.818758651072066,-22.51205597961686,-22.205353308161648,-21.898650636706503,-21.591947965251293,-21.285245293796084,-20.978542622340935,-20.67183995088573,-20.36513727943052,-20.05843460797531,-19.751731936520162,-19.445029265064953,-19.138326593609747,-18.831623922154595,-18.52492125069939,-18.21821857924418,-17.91151590778903,-17.604813236333825,-17.298110564878616,-16.991407893423464,-16.684705221968258,-16.37800255051305,-16.071299879057843,-15.76459720760269,-15.457894536147485,-15.151191864692278,-14.844489193237127,-14.537786521781918,-14.231083850326712,-13.924381178871561,-13.617678507416354,-13.310975835961145,-13.004273164505939,-12.697570493050787],[-16.403585774983934,-16.425963872086125,-16.448341969188313,-16.470720066290504,-16.493098163392695,-16.515476260494882,-16.537854357597073,-16.56023245469926,-16.58261055180145,-16.604988648903642,-16.62600827499279,-16.646348668053225,-16.666689061113658,-16.687029454174095,-16.70736984723453,-16.727710240294964,-16.748050633355398,-16.768391026415834,-16.788731419476267,-16.8090718125367,-16.829412205597137,-16.84975259865757,-16.870092991718003,-16.89043338477844,-16.910773777838873,-16.931114170899306,-16.951454563959743,-16.971794957020176,-16.992135350080613,-17.012475743141046,-17.032816136201482,-17.053156529261916,-17.07349692232235,-17.093837315382785,-17.11417770844322,-17.13451810150365,-17.15485849456409,-17.17519888762452,-17.195539280684955,-17.21587967374539,-17.236220066805824,-17.256560459866257,-17.276900852926694,-17.29724124598713,-17.31758163904756,-17.337922032107997,-17.358262425168434,-17.378602818228867,-17.3989432112893,-17.419283604349737,-17.43962399741017,-17.459964390470606,-17.48030478353104,-17.500645176591473,-17.520985569651906,-17.541325962712342,-17.561666355772775,-17.58200674883321,-17.602347141893645,-17.62268753495408,-17.643027928014515,-17.663368321074948,-17.683708714135385,-17.704049107195818,-17.72438950025625,-17.744729893316688,-17.76507028637712,-17.785410679437554,-17.80575107249799,-17.826091465558424,-17.84643185861886,-17.866772251679294,-17.887112644739727,-17.907453037800163,-17.927793430860596,-17.948133823921033,-17.968474216981466,-17.9888146100419,-18.009155003102336,-18.02949539616277,-18.049835789223202,-18.070176182283635,-18.090516575344072,-18.11085696840451,-18.130137691454813,-18.149206480503096,-18.168275269551376,-18.187344058599656,-18.20641284764794,-18.225481636696223,-18.244550425744503,-18.263619214792786,-18.282688003841066,-18.30175679288935,-18.320825581937633,-18.339894370985913,-18.358963160034197,-18.378031949082477,-18.39710073813076,-18.416169527179044,-18.435238316227327,-18.454307105275607,-18.47337589432389,-18.49244468337217,-18.51151347242045,-18.530582261468734,-18.549651050517014,-18.568719839565297,-18.58778862861358,-18.60685741766186,-18.625926206710144,-18.644994995758424,-18.664063784806707,-18.68313257385499,-18.70220136290327,-18.721270151951554,-18.740338940999834,-18.759407730048117,-18.7784765190964,-18.79754530814468,-18.816614097192964,-18.835682886241244,-18.854751675289528,-18.873820464337808,-18.89288925338609,-18.91195804243437,-18.931026831482654,-18.950095620530938,-18.969164409579218,-18.9882331986275,-19.00730198767578,-19.026370776724065,-19.045439565772348,-19.064508354820628,-19.08357714386891,-19.10264593291719,-19.121714721965475,-19.14078351101376,-19.159852300062038,-19.17892108911032,-19.1979898781586,-19.217058667206885,-19.23612745625517,-19.255196245303445,-19.274265034351732,-19.293333823400012,-19.312402612448295,-19.33147140149658,-19.35054019054486,-19.369608979593142,-19.388677768641426,-19.407746557689705,-19.426815346737985,-19.44588413578627,-19.46495292483455,-19.484021713882832,-19.503090502931112,-19.5221592919794,-19.543750503273976,-19.565341716613364,-19.586932929952756,-19.608524143292147,-19.630115356631535,-19.651706569970923,-19.673297783310314,-19.694888996649702,-19.71648020998909,-19.739539797928046,-19.76333357316678,-19.787127348405516,-19.810921123644253,-19.834714898882982,-19.858508674121722,-19.882302449360456,-19.90609622459919,-19.92988999983793,-19.95368377507666,-19.977477550315395,-20.000359887357213,-20.021679765507997,-20.042999643658774,-20.06431952180956,-20.085639399960343,-20.106959278111127,-20.12827915626191,-20.149599034412695,-20.170918912563476,-20.192238790714256,-20.21355866886504,-20.234878547015825,-20.256198425166605,-20.27751830331739,-20.29883818146817,-20.320158059618954,-20.341477937769735,-20.362797815920523,-20.3841176940713,-20.405437572222084,-20.426757450372868,-20.448077328523652,-20.469397206674433,-20.490717084825217,-20.512036962976,-20.533356841126782,-20.554676719277566,-20.57599659742835,-20.59731647557913,-20.61863635372991,-20.639956231880696,-20.66127611003148,-20.682595988182264,-20.70391586633305,-20.725235744483825,-20.74655562263461,-20.767875500785394,-20.789195378936178,-20.810515257086962,-20.831835135237743,-20.853155013388523,-20.874474891539307,-20.89579476969009,-20.917114647840876,-20.93843452599166,-20.959754404142437,-20.98107428229322,-21.002394160444002,-21.02371403859479,-21.04503391674557,-21.06635379489635,-21.08767367304714,-21.10899355119792,-21.130313429348703,-21.151633307499488,-21.172953185650268,-21.194273063801052,-21.215592941951833,-21.236912820102617,-21.2582326982534,-21.279552576404182,-21.300872454554966,-21.322192332705747,-21.34351221085653,-21.364832089007315,-21.3861519671581,-21.40747184530888,-21.42879172345966,-21.45011160161044,-21.47143147976123,-21.492751357912013,-21.514071236062794,-21.537097804462167,-21.561831063110137,-21.586564321758104,-21.611297580406074,-21.636030839054044,-21.660764097702014,-21.68549735634998,-21.710230614997954,-21.73496387364592,-21.759697132293887,-21.784430390941857,-21.809163649589827,-21.833896908237794,-21.85863016688576,-21.883363425533734,-21.9080966841817,-21.93282994282967,-21.95756320147764,-21.982296460125603,-22.007029718773573,-22.031762977421543,-22.056496236069513,-22.08122949471748,-22.105962753365446,-22.13069601201342,-22.155429270661386,-22.180184783012177,-22.20518787275705,-22.23019096250193,-22.255194052246807,-22.28019714199169,-22.30520023173657,-22.33020332148144,-22.355206411226323,-22.3802095009712,-22.40521259071608,-22.430215680460954,-22.45521877020584,-22.480221859950717,-22.505224949695595,-22.53022803944047,-22.555231129185348,-22.580234218930226,-22.605237308675107,-22.630240398419986,-22.655243488164864,-22.68024657790974,-22.70524966765462,-22.730252757399498,-22.755255847144376,-22.780258936889254,-22.805262026634132,-22.83026511637901,-22.85526820612389,-22.880271295868766,-22.905274385613644,-22.930277475358526,-22.9552805651034,-22.98028365484828,-23.00528674459316,-23.03028983433804,-23.055292924082913,-23.08029601382779,-23.105299103572673,-23.13030219331755,-23.155305283062425,-23.180308372807303,-23.20531146255219,-23.23031455229706,-23.255317642041938,-23.28032073178682,-23.305323821531697,-23.33032691127658,-23.355330001021457,-23.380333090766335,-23.405336180511206,-23.43033927025609,-23.455342360000966,-23.48034544974584,-23.505348539490726,-23.530351629235607,-23.555354718980478,-23.58035780872536,-23.587367017504945,-23.558388464353968,-23.52940991120299,-23.500431358052005,-23.471452804901027,-23.44247425175005,-23.413495698599068,-23.384517145448086,-23.35553859229711,-23.326560039146127,-23.297581485995146,-23.268602932844168,-23.23962437969319,-23.21064582654221,-23.181667273391227,-23.15268872024025,-23.123710167089268,-23.094731613938286,-23.065753060787312,-23.036774507636327,-23.007795954485346,-22.978817401334368,-22.949838848183386,-22.920860295032405,-22.891881741881427,-22.86290318873045,-22.833924635579468,-22.804946082428486,-22.77596752927751,-22.746988976126527,-22.718010422975546,-22.68903186982457,-22.66005331667359,-22.631074763522605,-22.602096210371624,-22.57311765722065,-22.544139104069668,-22.515160550918687,-22.48618199776771,-22.45720344461673,-22.428224891465746,-22.399246338314768,-22.37026778516379,-22.341289232012805,-22.312310678861827,-22.28147241428638,-22.243767485618363,-22.20606255695035,-22.168357628282337,-22.130652699614323,-22.09294777094631,-22.0552428422783,-22.017537913610283,-21.979832984942266,-21.94212805627426,-21.904423127606243,-21.86671819893823,-21.829013270270213,-21.791308341602203,-21.753603412934186,-21.715898484266177,-21.678193555598163,-21.640488626930146,-21.602783698262137,-21.565078769594123,-21.527373840926106,-21.489668912258093,-21.451963983590083,-21.41425905492207,-21.37655412625405,-21.338849197586036,-21.30114426891803,-21.26343934025001,-21.225734411582,-21.18802948291399,-21.15032455424597,-21.112619625577956,-21.074914696909943,-21.03720976824193,-20.999504839573916,-20.961799910905903,-20.92409498223789,-20.886390053569873,-20.872224955547438,-20.975759010752853,-21.079293065958268,-21.182827121163683,-21.286361176369077,-21.389895231574496,-21.493429286779907,-21.596963341985305,-21.700497397190716,-21.80403145239613,-21.90756550760153,-22.011099562806947,-22.11463361801236,-22.218167673217778,-22.32170172842317,-22.425235783628587,-22.528769838834002,-22.632303894039396,-22.73583794924481,-22.839372004450226,-22.94290605965562,-23.04644011486104,-23.14997417006645,-23.253508225271844,-23.171099890115674,-23.0806072919504,-22.990114693785124,-22.899622095619865,-22.809129497454588,-22.718636899289308,-22.62814430112405,-22.537651702958772,-22.447159104793496,-22.356666506628237,-22.26617390846296,-22.17568131029768,-22.085188712132403,-21.994696113967144,-21.904203515801868,-21.81371091763659,-21.723218319471332,-21.632725721306056,-21.542233123140775,-21.451740524975516,-21.36124792681024,-21.270755328644967,-21.180262730479704,-21.089770132314428,-20.99927753414915,-20.908784935983874,-20.81829233781861,-20.727799739653335,-20.63730714148806,-20.5468145433228,-20.456321945157523,-20.365829346992246,-20.275336748826984,-20.184844150661707,-20.09435155249643,-20.003858954331154,-19.86832279245899,-19.561620121003784,-19.254917449548575,-18.948214778093423,-18.641512106638217,-18.33480943518301,-18.02810676372786,-17.721404092272653,-17.414701420817444,-17.10799874936229,-16.801296077907086,-16.494593406451877,-16.18789073499667,-15.881188063541519,-15.574485392086313,-15.267782720631107,-14.961080049175955,-14.654377377720746,-14.34767470626554,-14.040972034810387,-13.734269363355182,-13.427566691899973,-13.120864020444767,-12.814161348989614],[-15.938760175692611,-15.957026055046649,-15.975291934400687,-15.993557813754725,-16.011823693108767,-16.030089572462803,-16.04835545181684,-16.06662133117088,-16.08661596992291,-16.106956362983343,-16.12729675604378,-16.147637149104213,-16.167977542164646,-16.188317935225083,-16.208658328285516,-16.228998721345953,-16.249339114406386,-16.26967950746682,-16.290019900527255,-16.31036029358769,-16.33070068664812,-16.35104107970856,-16.37138147276899,-16.391721865829425,-16.41206225888986,-16.432402651950294,-16.45274304501073,-16.473083438071164,-16.4934238311316,-16.51376422419203,-16.534104617252467,-16.554445010312904,-16.574785403373337,-16.59512579643377,-16.615466189494203,-16.63580658255464,-16.656146975615073,-16.67648736867551,-16.696827761735946,-16.717168154796376,-16.737508547856812,-16.757848940917242,-16.778189333977682,-16.798529727038115,-16.81887012009855,-16.839210513158985,-16.859550906219418,-16.879891299279855,-16.900231692340288,-16.92057208540072,-16.940912478461158,-16.96125287152159,-16.981593264582024,-17.00193365764246,-17.022274050702894,-17.042614443763327,-17.062954836823764,-17.083295229884197,-17.10363562294463,-17.123976016005066,-17.1443164090655,-17.164656802125936,-17.18499719518637,-17.205337588246802,-17.225677981307236,-17.246018374367672,-17.266358767428105,-17.286699160488542,-17.307039553548975,-17.327379946609412,-17.347720339669845,-17.368060732730278,-17.388401125790715,-17.408741518851148,-17.42908191191158,-17.449422304972018,-17.46976269803245,-17.490103091092884,-17.510443484153324,-17.530783877213757,-17.55112427027419,-17.571464663334623,-17.59180505639506,-17.612145449455497,-17.6314261725058,-17.650494961554084,-17.669563750602364,-17.688632539650644,-17.707701328698928,-17.72677011774721,-17.74583890679549,-17.764907695843775,-17.783976484892055,-17.803045273940338,-17.822114062988618,-17.8411828520369,-17.860251641085185,-17.879320430133465,-17.898389219181748,-17.917458008230028,-17.93652679727831,-17.95559558632659,-17.97466437537488,-17.993733164423155,-18.01280195347144,-18.03187074251972,-18.050939531568,-18.07000832061628,-18.089077109664565,-18.10814589871285,-18.127214687761132,-18.146283476809412,-18.165352265857692,-18.184421054905975,-18.20348984395426,-18.222558633002542,-18.24162742205082,-18.260696211099102,-18.279765000147385,-18.29883378919567,-18.317902578243952,-18.336971367292232,-18.356040156340512,-18.375108945388796,-18.39417773443708,-18.41324652348536,-18.432315312533643,-18.451384101581926,-18.470452890630206,-18.48952167967849,-18.50859046872677,-18.527659257775053,-18.546728046823333,-18.565796835871616,-18.5848656249199,-18.60393441396818,-18.62300320301646,-18.642071992064743,-18.661140781113026,-18.68020957016131,-18.69927835920959,-18.71834714825787,-18.737415937306153,-18.756484726354437,-18.775553515402716,-18.794622304451,-18.813691093499283,-18.832759882547563,-18.851828671595843,-18.870897460644127,-18.88996624969241,-18.909035038740694,-18.928103827788977,-18.947172616837257,-18.966241405885537,-18.98531019493382,-19.004378983982104,-19.023447773030387,-19.042516562078667,-19.061585351126947,-19.078469801918708,-19.09491738812802,-19.111364974337338,-19.12781256054665,-19.144260146755965,-19.16070773296528,-19.177155319174595,-19.195091569165033,-19.213772151046033,-19.23245273292704,-19.25113331480804,-19.269813896689044,-19.288494478570044,-19.307175060451044,-19.325855642332048,-19.345663737999292,-19.366997300498852,-19.388330862998405,-19.40966442549797,-19.43099798799753,-19.452331550497085,-19.473665112996642,-19.494998675496202,-19.51633223799576,-19.537665800495315,-19.558999362994875,-19.58033292549443,-19.60166648799399,-19.62300005049355,-19.64433361299311,-19.66566717549267,-19.68700073799222,-19.70833430049178,-19.72966786299134,-19.751001425490898,-19.772334987990458,-19.793668550490015,-19.815002112989575,-19.83633567548913,-19.857669237988688,-19.879002800488248,-19.900336362987808,-19.921669925487365,-19.943003487986925,-19.96433705048648,-19.98567061298604,-20.007004175485598,-20.028337737985154,-20.049671300484714,-20.071004862984275,-20.09233842548383,-20.113671987983388,-20.13500555048295,-20.156339112982504,-20.177672675482064,-20.19900623798162,-20.22033980048118,-20.24167336298074,-20.263006925480298,-20.284340487979854,-20.30567405047941,-20.327007612978974,-20.34834117547853,-20.36967473797809,-20.391008300477647,-20.412341862977208,-20.433675425476764,-20.45500898797632,-20.476342550475877,-20.497676112975434,-20.519009675474997,-20.540343237974554,-20.561676800474114,-20.583010362973674,-20.60434392547323,-20.625677487972787,-20.647011050472347,-20.668344612971907,-20.689678175471464,-20.711011737971024,-20.732345300470577,-20.753678862970137,-20.775012425469697,-20.796345987969254,-20.817679550468814,-20.83901311296837,-20.86034667546793,-20.881680237967487,-20.903013800467047,-20.924347362966603,-20.947623302393055,-20.972841618746394,-20.998059935099732,-21.023278251453068,-21.04849656780641,-21.07371488415975,-21.098933200513084,-21.124151516866426,-21.149369833219765,-21.1745881495731,-21.19980646592644,-21.22502478227978,-21.250243098633117,-21.275461414986456,-21.300679731339798,-21.325898047693137,-21.351116364046476,-21.376334680399815,-21.401552996753153,-21.426771313106492,-21.45198962945983,-21.47720794581317,-21.50242626216651,-21.527644578519848,-21.552862894873186,-21.578081211226525,-21.603299527579864,-21.628517843933203,-21.65373616028654,-21.67895447663988,-21.70417279299322,-21.72939110934656,-21.75441627240922,-21.779419362154098,-21.80442245189898,-21.829425541643854,-21.85442863138873,-21.879431721133614,-21.90443481087849,-21.92943790062337,-21.954440990368248,-21.979444080113126,-22.004447169858,-22.029450259602882,-22.05445334934776,-22.079456439092638,-22.104459528837516,-22.129462618582394,-22.154465708327272,-22.17946879807215,-22.204471887817032,-22.22947497756191,-22.254478067306785,-22.279481157051666,-22.304484246796545,-22.32948733654142,-22.354490426286297,-22.37949351603118,-22.404496605776057,-22.429499695520935,-22.454502785265813,-22.479505875010688,-22.504508964755566,-22.529512054500447,-22.554515144245325,-22.579518233990203,-22.60452132373508,-22.629524413479963,-22.654527503224838,-22.679530592969716,-22.704533682714597,-22.729536772459475,-22.754539862204354,-22.77954295194923,-22.804546041694106,-22.829549131438984,-22.854552221183866,-22.87955531092874,-22.904558400673622,-22.929561490418504,-22.95456458016338,-22.979567669908256,-23.004570759653134,-23.01157996843272,-22.982601415281742,-22.95362286213076,-22.92464430897978,-22.895665755828805,-22.866687202677824,-22.837708649526842,-22.80873009637586,-22.779751543224886,-22.7507729900739,-22.721794436922924,-22.692815883771942,-22.663837330620964,-22.63485877746998,-22.605880224319005,-22.576901671168024,-22.547923118017042,-22.518944564866064,-22.489966011715087,-22.460987458564105,-22.43200890541312,-22.403030352262142,-22.374051799111164,-22.345073245960183,-22.3160946928092,-22.287116139658224,-22.258137586507246,-22.229159033356268,-22.200180480205287,-22.171201927054305,-22.14222337390332,-22.113244820752346,-22.084266267601365,-22.05528771445038,-22.0263091612994,-21.997330608148424,-21.968352054997442,-21.939373501846468,-21.910394948695483,-21.881416395544505,-21.85243784239352,-21.823459289242546,-21.794480736091565,-21.76550218294058,-21.736523629789602,-21.707545076638624,-21.678566523487643,-21.64958797033666,-21.620609417185683,-21.591630864034705,-21.562652310883724,-21.533673757732746,-21.504695204581765,-21.475716651430783,-21.44673809827981,-21.417759545128824,-21.388780991977846,-21.359802438826865,-21.330823885675887,-21.301845332524902,-21.272866779373924,-21.243888226222946,-21.21490967307196,-21.185931119920987,-21.156952566770006,-21.127974013619028,-21.09899546046804,-21.070016907317072,-21.041038354166083,-21.012059801015102,-20.983081247864128,-20.954102694713146,-20.925124141562165,-20.896145588411184,-20.867167035260206,-20.838188482109224,-20.80828008433995,-20.77057515567194,-20.732870227003925,-20.695165298335912,-20.6574603696679,-20.619755440999885,-20.582050512331868,-20.567885414309433,-20.671419469514845,-20.77495352472026,-20.878487579925675,-20.982021635131073,-20.9044639294926,-20.813971331327323,-20.72347873316206,-20.632986134996784,-20.54249353683151,-20.45200093866625,-20.361508340500972,-20.271015742335695,-20.180523144170422,-20.09003054600516,-19.999537947839883,-19.909045349674606,-19.818552751509344,-19.728060153344067,-19.63756755517879,-19.54707495701353,-19.45658235884825,-19.36608976068298,-19.275597162517716,-19.18510456435244,-19.094611966187163,-19.004119368021886,-18.913626769856627,-18.82313417169135,-18.732641573526074,-18.64214897536081,-18.551656377195535,-18.461163779030258,-18.370671180865,-18.28017858269972,-18.189685984534446,-18.099193386369166,-18.008700788203907,-17.91820819003863,-17.827715591873353,-17.737222993708095,-17.646730395542818,-17.55623779737754,-17.46574519921228,-17.375252601047002,-17.284760002881725,-17.194267404716467,-17.103774806551186,-17.013282208385913,-16.922789610220633,-16.83229701205537,-16.741804413890097,-16.651311815724817,-16.56081921755956,-16.470326619394285,-16.37983402122901,-16.289341423063746,-16.19884882489847,-16.108356226733193,-16.017863628567916,-15.927371030402657,-15.836878432237379,-15.746385834072104,-15.655893235906841,-15.565400637741565,-15.474908039576288,-15.384415441411027,-15.29392284324575,-15.203430245080472,-15.112937646915213,-15.022445048749937,-14.93195245058466,-14.841459852419383,-14.750967254254121,-14.660474656088846,-14.569982057923568,-14.479489459758309,-14.388996861593032,-14.298504263427755,-14.157562890749219,-13.85086021929401,-13.544157547838802,-13.237454876383595,-12.930752204928444],[-15.469849553863886,-15.488115433217924,-15.50638131257196,-15.524647191925999,-15.542913071280038,-15.561178950634076,-15.579444829988113,-15.59771070934215,-15.61597658869619,-15.634242468050228,-15.652508347404266,-15.670774226758304,-15.689040106112342,-15.70730598546638,-15.725571864820418,-15.743837744174456,-15.762103623528494,-15.780369502882532,-15.798635382236569,-15.816901261590608,-15.835167140944645,-15.853433020298684,-15.87169889965272,-15.88996477900676,-15.908922160563298,-15.92926255362373,-15.949602946684166,-15.969943339744601,-15.990283732805032,-16.01062412586547,-16.030964518925902,-16.051304911986335,-16.071645305046772,-16.091985698107205,-16.112326091167642,-16.132666484228075,-16.153006877288508,-16.17334727034895,-16.193687663409378,-16.214028056469814,-16.234368449530248,-16.25470884259068,-16.275049235651117,-16.295389628711554,-16.315730021771984,-16.33607041483242,-16.356410807892853,-16.37675120095329,-16.397091594013723,-16.41743198707416,-16.437772380134593,-16.458112773195026,-16.478453166255463,-16.498793559315896,-16.51913395237633,-16.539474345436766,-16.5598147384972,-16.580155131557632,-16.60049552461807,-16.6208359176785,-16.641176310738935,-16.66151670379937,-16.681857096859808,-16.70219748992024,-16.722537882980674,-16.742878276041107,-16.76321866910154,-16.783559062161977,-16.803899455222414,-16.824239848282847,-16.84458024134328,-16.864920634403713,-16.88526102746415,-16.905601420524583,-16.92594181358502,-16.946282206645453,-16.966622599705886,-16.986962992766323,-17.007303385826756,-17.027643778887192,-17.047984171947625,-17.06832456500806,-17.088664958068495,-17.10900535112893,-17.128286074179236,-17.14735486322752,-17.1664236522758,-17.18549244132408,-17.204561230372363,-17.223630019420646,-17.242698808468926,-17.26176759751721,-17.28083638656549,-17.299905175613773,-17.318973964662057,-17.338042753710337,-17.35711154275862,-17.3761803318069,-17.395249120855183,-17.414317909903467,-17.433386698951747,-17.45245548800003,-17.47152427704831,-17.490593066096594,-17.509661855144877,-17.528730644193157,-17.547799433241437,-17.56686822228972,-17.585937011338004,-17.605005800386287,-17.624074589434567,-17.643143378482847,-17.66221216753113,-17.681280956579414,-17.700349745627694,-17.719418534675977,-17.738487323724257,-17.75755611277254,-17.776624901820824,-17.795693690869104,-17.814762479917388,-17.833831268965668,-17.85290005801395,-17.871968847062234,-17.891037636110514,-17.910106425158798,-17.929175214207078,-17.94824400325536,-17.967312792303645,-17.986381581351925,-18.005450370400208,-18.024519159448488,-18.043587948496768,-18.062656737545055,-18.081725526593335,-18.10079431564162,-18.119863104689898,-18.138931893738178,-18.158000682786465,-18.177069471834745,-18.196138260883025,-18.21520704993131,-18.23427583897959,-18.252470890758335,-18.26891847696765,-18.285366063176966,-18.30181364938628,-18.318261235595592,-18.33470882180491,-18.351156408014226,-18.367603994223536,-18.384051580432853,-18.400499166642167,-18.41694675285148,-18.433394339060797,-18.44984192527011,-18.466289511479424,-18.48273709768874,-18.499184683898054,-18.515632270107368,-18.532079856316685,-18.548527442525998,-18.56497502873531,-18.58142261494463,-18.597870201153942,-18.614317787363255,-18.630765373572572,-18.648701623563014,-18.667382205444014,-18.686062787325014,-18.704743369206017,-18.723423951087018,-18.74210453296802,-18.76078511484902,-18.779465696730025,-18.798146278611025,-18.81682686049203,-18.83550744237303,-18.854188024254032,-18.872868606135036,-18.891549188016036,-18.910229769897033,-18.92891035177804,-18.947590933659043,-18.966271515540043,-18.984952097421044,-19.003632679302044,-19.02231326118305,-19.04099384306405,-19.05967442494505,-19.07835500682605,-19.097035588707055,-19.115716170588055,-19.13439675246906,-19.154271172148363,-19.175604734647923,-19.19693829714748,-19.21827185964704,-19.2396054221466,-19.260938984646153,-19.282272547145713,-19.303606109645273,-19.324939672144833,-19.34627323464439,-19.36760679714395,-19.388940359643506,-19.410273922143062,-19.431607484642623,-19.45294104714218,-19.474274609641736,-19.495608172141296,-19.516941734640856,-19.538275297140416,-19.55960885963997,-19.58094242213953,-19.602275984639093,-19.623609547138646,-19.644943109638206,-19.666276672137766,-19.68761023463732,-19.70894379713688,-19.73027735963644,-19.751610922135995,-19.772944484635556,-19.79427804713511,-19.815611609634672,-19.83694517213423,-19.858278734633785,-19.879612297133345,-19.900945859632905,-19.922279422132462,-19.94361298463202,-19.96494654713158,-19.98628010963114,-20.007613672130695,-20.02894723463025,-20.050280797129812,-20.071614359629372,-20.09294792212893,-20.114281484628485,-20.135615047128045,-20.1569486096276,-20.17828217212716,-20.199615734626718,-20.22094929712628,-20.242282859625835,-20.263616422125395,-20.284949984624955,-20.30628354712451,-20.327617109624068,-20.350893049050516,-20.376111365403858,-20.401329681757197,-20.426547998110536,-20.45176631446387,-20.476984630817213,-20.50220294717055,-20.52742126352389,-20.55263957987723,-20.577857896230565,-20.603076212583908,-20.628294528937246,-20.653512845290585,-20.678731161643924,-20.703949477997263,-20.7291677943506,-20.75438611070394,-20.77960442705728,-20.804822743410618,-20.830041059763957,-20.855259376117296,-20.880477692470638,-20.905696008823973,-20.930914325177312,-20.95613264153065,-20.98135095788399,-21.00656927423733,-21.031787590590667,-21.057005906944006,-21.082224223297345,-21.107442539650684,-21.132660856004026,-21.15787917235736,-21.1830974887107,-21.208315805064043,-21.233534121417378,-21.258752437770717,-21.283970754124056,-21.309189070477395,-21.334407386830733,-21.359625703184072,-21.38484401953741,-21.41006233589075,-21.43528065224409,-21.460498968597427,-21.485717284950766,-21.51093560130411,-21.536153917657447,-21.561372234010786,-21.58659055036412,-21.611808866717464,-21.6370271830708,-21.662245499424138,-21.687463815777477,-21.71268213213082,-21.737900448484158,-21.763118764837497,-21.78833708119084,-21.813555397544174,-21.838773713897513,-21.863992030250852,-21.88921034660419,-21.91442866295753,-21.939646979310865,-21.964865295664204,-21.990083612017543,-22.01530192837088,-22.040520244724224,-22.065738561077563,-22.090956877430905,-22.116175193784244,-22.14139351013758,-22.165703397466416,-22.189740754476578,-22.213778111486736,-22.237815468496894,-22.261852825507056,-22.285890182517214,-22.309927539527376,-22.333964896537537,-22.358002253547696,-22.382039610557857,-22.406076967568016,-22.415727577404635,-22.39660469289418,-22.377481808383724,-22.35835892387327,-22.339236039362817,-22.32011315485236,-22.300990270341906,-22.281867385831454,-22.262744501321002,-22.243621616810547,-22.22449873230009,-22.20537584778964,-22.186252963279184,-22.167130078768732,-22.148007194258273,-22.12888430974782,-22.10121546831654,-22.073134784896673,-22.045054101476808,-22.016973418056946,-21.98889273463708,-21.960812051217218,-21.932731367797356,-21.904650684377486,-21.87657000095762,-21.84848931753776,-21.820408634117893,-21.792327950698027,-21.764247267278165,-21.7361665838583,-21.708085900438434,-21.68000521701857,-21.651924533598706,-21.623843850178844,-21.595763166758978,-21.567682483339112,-21.539601799919247,-21.51152111649938,-21.48344043307952,-21.455359749659657,-21.42727906623979,-21.399198382819925,-21.37111769940006,-21.343037015980194,-21.314956332560328,-21.286875649140466,-21.2587949657206,-21.230714282300738,-21.202633598880873,-21.174552915461007,-21.14647223204114,-21.11839154862128,-21.090310865201413,-21.06223018178155,-21.034149498361685,-21.00606881494182,-20.977988131521954,-20.94990744810209,-20.92182676468223,-20.89374608126236,-20.8656653978425,-20.837584714422633,-20.809504031002767,-20.781423347582905,-20.753342664163043,-20.725261980743177,-20.69718129732331,-20.669100613903446,-20.641019930483584,-20.612939247063714,-20.584858563643852,-20.55677788022399,-20.528697196804124,-20.50061651338426,-20.472535829964393,-20.44445514654453,-20.416374463124665,-20.388293779704803,-20.360213096284937,-20.33213241286507,-20.304051729445206,-20.27597104602534,-20.247890362605474,-20.244917943815924,-20.367486848177915,-20.490055752539906,-20.6126246569019,-20.735193561263866,-20.857762465625857,-20.980331369987844,-21.102900274349814,-21.22546917871181,-21.3480380830738,-21.47060698743577,-21.59317589179776,-21.715744796159747,-21.838313700521738,-21.960882604883707,-22.083451509245698,-22.20602041360769,-22.32858931796966,-22.45115822233165,-22.57372712669364,-22.696296031055606,-22.8188649354176,-22.94143383977959,-23.064002744141558,-23.186571648503552,-23.309140552865536,-23.43170945722753,-23.554278361589503,-23.67684726595149,-23.799416170313478,-23.921985074675447,-24.044553979037442,-24.167122883399433,-24.2896917877614,-24.41226069212339,-24.53482959648538,-24.65739850084737,-24.779967405209337,-24.90343179748949,-25.028473200682598,-25.153514603875692,-25.278556007068804,-25.16923900868295,-24.892523152026534,-24.615807295370065,-24.33909143871359,-24.045500579162535,-23.747808627936283,-23.450116676710028,-23.152424725483773,-22.85473277425757,-22.557040823031315,-22.259348871805063,-21.96165692057886,-21.663964969352605,-21.36627301812635,-21.068581066900148,-20.770889115673896,-20.47319716444764,-20.175505213221385,-19.877813261995183,-19.580121310768927,-19.28242935954267,-18.98473740831647,-18.687045457090214,-18.38935350586396,-18.09166155463776,-17.793969603411504,-17.49627765218525,-17.19858570095905,-16.900893749732795,-16.60320179850654,-16.305509847280284,-16.007817896054085,-15.71012594482783,-15.41243399360157,-15.114742042375372,-14.817050091149117,-14.519358139922863,-14.221666188696663,-13.923974237470407,-13.626282286244148,-13.328590335017894,-13.030898383791694],[-15.000938932035158,-15.019204811389198,-15.037470690743234,-15.055736570097274,-15.07400244945131,-15.09226832880535,-15.110534208159386,-15.128800087513426,-15.147065966867462,-15.165331846221502,-15.183597725575538,-15.201863604929576,-15.220129484283614,-15.238395363637654,-15.256661242991692,-15.274927122345728,-15.293193001699766,-15.311458881053804,-15.329724760407842,-15.34799063976188,-15.366256519115918,-15.384522398469956,-15.402788277823994,-15.421054157178032,-15.43932003653207,-15.457585915886108,-15.475851795240146,-15.494117674594182,-15.512383553948222,-15.530649433302258,-15.548915312656298,-15.567181192010334,-15.585447071364374,-15.60371295071841,-15.62197883007245,-15.640244709426486,-15.658510588780526,-15.676776468134562,-15.6950423474886,-15.713308226842639,-15.731574106196678,-15.75156874426412,-15.771909137324554,-15.79224953038499,-15.812589923445422,-15.832930316505855,-15.853270709566292,-15.873611102626725,-15.893951495687158,-15.914291888747595,-15.934632281808028,-15.954972674868465,-15.975313067928898,-15.995653460989331,-16.015993854049768,-16.0363342471102,-16.056674640170638,-16.07701503323107,-16.097355426291504,-16.117695819351937,-16.138036212412374,-16.15837660547281,-16.178716998533243,-16.199057391593676,-16.21939778465411,-16.239738177714546,-16.26007857077498,-16.280418963835416,-16.30075935689585,-16.321099749956282,-16.34144014301672,-16.361780536077152,-16.38212092913759,-16.40246132219802,-16.422801715258455,-16.44314210831889,-16.463482501379325,-16.48382289443976,-16.504163287500194,-16.524503680560628,-16.544844073621064,-16.565184466681494,-16.58552485974193,-16.605865252802367,-16.62514597585267,-16.644214764900955,-16.663283553949235,-16.68235234299752,-16.7014211320458,-16.72048992109408,-16.739558710142365,-16.758627499190645,-16.77769628823893,-16.796765077287212,-16.815833866335492,-16.83490265538377,-16.85397144443206,-16.87304023348034,-16.892109022528622,-16.911177811576902,-16.930246600625185,-16.94931538967347,-16.96838417872175,-16.987452967770032,-17.006521756818312,-17.025590545866592,-17.044659334914876,-17.06372812396316,-17.08279691301144,-17.101865702059722,-17.120934491108002,-17.140003280156286,-17.15907206920457,-17.17814085825285,-17.197209647301133,-17.216278436349416,-17.235347225397696,-17.254416014445976,-17.27348480349426,-17.29255359254254,-17.311622381590826,-17.330691170639106,-17.349759959687386,-17.368828748735673,-17.38789753778395,-17.406966326832233,-17.426035115880513,-17.44291956580728,-17.45936715201659,-17.47581473822591,-17.492262324435224,-17.508709910644537,-17.525157496853854,-17.541605083063168,-17.55805266927248,-17.574500255481798,-17.59094784169111,-17.607395427900425,-17.623843014109738,-17.64029060031905,-17.65673818652837,-17.673185772737682,-17.689633358947,-17.706080945156312,-17.722528531365626,-17.738976117574943,-17.755423703784256,-17.77187128999357,-17.788318876202887,-17.804766462412204,-17.821214048621513,-17.83766163483083,-17.85410922104014,-17.870556807249457,-17.88700439345877,-17.903451979668084,-17.9198995658774,-17.936347152086718,-17.952794738296028,-17.969242324505345,-17.98568991071466,-18.002137496923975,-18.01858508313329,-18.035032669342602,-18.05148025555192,-18.067927841761232,-18.084375427970546,-18.102311677960987,-18.120992259841987,-18.13967284172299,-18.15835342360399,-18.17703400548499,-18.195714587365995,-18.214395169247,-18.233075751128,-18.251756333009002,-18.270436914890002,-18.289117496771006,-18.307798078652006,-18.32647866053301,-18.34515924241401,-18.363839824295013,-18.382520406176013,-18.401200988057013,-18.419881569938017,-18.43856215181902,-18.45724273370002,-18.47592331558102,-18.494603897462024,-18.513284479343024,-18.53196506122403,-18.55064564310503,-18.569326224986032,-18.588006806867035,-18.606687388748036,-18.62536797062904,-18.64404855251004,-18.662729134391043,-18.681409716272046,-18.700090298153047,-18.718770880034047,-18.737451461915047,-18.75613204379605,-18.77481262567705,-18.793493207558054,-18.81217378943906,-18.830854371320058,-18.849534953201058,-18.868215535082065,-18.886896116963065,-18.90557669884407,-18.92425728072507,-18.94293786260607,-18.96287860629744,-18.984212168796994,-19.005545731296554,-19.026879293796114,-19.04821285629567,-19.069546418795227,-19.090879981294787,-19.112213543794343,-19.133547106293904,-19.15488066879346,-19.176214231293017,-19.197547793792577,-19.218881356292137,-19.240214918791693,-19.261548481291253,-19.28288204379081,-19.30421560629037,-19.325549168789927,-19.346882731289487,-19.368216293789043,-19.389549856288603,-19.41088341878816,-19.43221698128772,-19.45355054378728,-19.474884106286837,-19.496217668786393,-19.517551231285953,-19.53888479378551,-19.56021835628507,-19.581551918784626,-19.602885481284186,-19.624219043783743,-19.645552606283303,-19.66688616878286,-19.68821973128242,-19.709553293781976,-19.730886856281536,-19.754162795707984,-19.779381112061323,-19.80459942841466,-19.829817744768,-19.85503606112134,-19.880254377474678,-19.905472693828017,-19.930691010181356,-19.955909326534695,-19.98112764288803,-20.006345959241372,-20.03156427559471,-20.05678259194805,-20.08200090830139,-20.107219224654727,-20.132437541008066,-20.157655857361405,-20.182874173714744,-20.208092490068083,-20.23331080642142,-20.25852912277476,-20.283747439128103,-20.308965755481438,-20.334184071834777,-20.35940238818812,-20.384620704541454,-20.409839020894793,-20.435057337248132,-20.46027565360147,-20.485493969954813,-20.510712286308152,-20.53593060266149,-20.561148919014826,-20.58636723536817,-20.611585551721507,-20.636803868074846,-20.66202218442818,-20.687240500781524,-20.712458817134863,-20.7376771334882,-20.762895449841537,-20.788113766194876,-20.813332082548214,-20.838550398901557,-20.863768715254896,-20.88898703160823,-20.91420534796157,-20.939310110390192,-20.96334746740035,-20.987384824410512,-21.01142218142067,-21.03545953843083,-21.059496895440986,-21.083534252451148,-21.10757160946131,-21.131608966471468,-21.155646323481626,-21.17968368049179,-21.203721037501946,-21.227758394512108,-21.25179575152227,-21.275833108532428,-21.299870465542583,-21.323907822552748,-21.347945179562906,-21.371982536573064,-21.396019893583222,-21.420057250593388,-21.444094607603546,-21.468131964613704,-21.492169321623866,-21.516206678634024,-21.540244035644186,-21.564281392654344,-21.588318749664502,-21.61235610667466,-21.636393463684826,-21.660430820694984,-21.684468177705142,-21.708505534715304,-21.732542891725465,-21.756580248735624,-21.780617605745782,-21.7902682155824,-21.77114533107195,-21.752022446561494,-21.73289956205104,-21.713776677540586,-21.69465379303013,-21.675530908519676,-21.65640802400922,-21.637285139498772,-21.618162254988313,-21.599039370477858,-21.579916485967406,-21.56079360145695,-21.541670716946495,-21.522547832436043,-21.50342494792559,-21.484302063415136,-21.46517917890468,-21.44605629439423,-21.426933409883773,-21.407810525373318,-21.388687640862866,-21.369564756352407,-21.35044187184195,-21.3313189873315,-21.312196102821048,-21.293073218310592,-21.273950333800137,-21.254827449289685,-21.235704564779226,-21.216581680268774,-21.197458795758322,-21.178335911247867,-21.15921302673741,-21.140090142226956,-21.120967257716504,-21.10184437320605,-21.082721488695594,-21.06359860418514,-21.044475719674686,-21.025352835164234,-21.006229950653783,-20.987107066143327,-20.96798418163287,-20.948861297122416,-20.929738412611965,-20.910615528101506,-20.891492643591054,-20.870233279661498,-20.842152596241633,-20.814071912821767,-20.785991229401905,-20.75791054598204,-20.729829862562173,-20.70174917914231,-20.673668495722445,-20.64558781230258,-20.617507128882714,-20.589426445462852,-20.561345762042986,-20.533265078623124,-20.50518439520326,-20.477103711783393,-20.44902302836353,-20.420942344943665,-20.392861661523803,-20.364780978103934,-20.33670029468407,-20.30861961126421,-20.28053892784434,-20.252458244424478,-20.224377561004616,-20.19629687758475,-20.16821619416488,-20.14013551074502,-20.112054827325156,-20.083974143905287,-20.05589346048543,-20.027812777065563,-19.999732093645694,-19.971651410225828,-19.943570726805966,-19.915490043386104,-19.91251762459655,-20.03508652895854,-20.15765543332053,-20.280224337682522,-20.40279324204449,-20.525362146406483,-20.647931050768474,-20.770499955130443,-20.89306885949243,-21.01563776385442,-21.13820666821639,-21.260775572578382,-21.383344476940373,-21.505913381302364,-21.628482285664333,-21.751051190026324,-21.873620094388315,-21.996188998750284,-22.118757903112275,-22.241326807474266,-22.365397439617364,-22.49043884281048,-22.615480246003596,-22.740521649196687,-22.865563052389795,-22.990604455582908,-23.11564585877602,-23.240687261969107,-23.365728665162216,-23.49077006835533,-23.615811471548422,-23.740852874741538,-23.86589427793465,-23.99093568112774,-24.115977084320853,-24.241018487513962,-24.366059890707074,-24.491101293900165,-24.61614269709328,-24.74118410028639,-24.86622550347948,-24.991266906672593,-24.881949908286746,-24.605234051630326,-24.328518194973853,-24.05180233831738,-23.775086481660963,-23.49837062500449,-23.221654768348017,-22.94493891169155,-22.66822305503513,-22.391507198378655,-22.114791341722185,-21.838075485065765,-21.561359628409292,-21.28464377175282,-21.007927915096403,-20.731212058439933,-20.45449620178346,-20.17778034512699,-19.901064488470567,-19.624348631814097,-19.347632775157628,-19.070916918501208,-18.782469254383695,-18.48477730315744,-18.18708535193124,-17.889393400704982,-17.591701449478727,-17.294009498252528,-16.996317547026273,-16.698625595800017,-16.40093364457376,-16.103241693347563,-15.805549742121308,-15.50785779089505,-15.210165839668852,-14.912473888442594,-14.614781937216339,-14.31708998599014,-14.019398034763885,-13.72170608353763,-13.424014132311374,-13.126322181085174],[-14.532028310206432,-14.550294189560471,-14.568560068914508,-14.586825948268547,-14.605091827622584,-14.623357706976623,-14.64162358633066,-14.6598894656847,-14.678155345038736,-14.696421224392775,-14.714687103746812,-14.732952983100851,-14.751218862454888,-14.769484741808927,-14.787750621162964,-14.806016500517003,-14.82428237987104,-14.84254825922508,-14.860814138579116,-14.879080017933155,-14.897345897287192,-14.915611776641232,-14.933877655995266,-14.952143535349308,-14.970409414703342,-14.98867529405738,-15.00694117341142,-15.025207052765456,-15.043472932119496,-15.061738811473532,-15.080004690827572,-15.09827057018161,-15.116536449535646,-15.134802328889686,-15.153068208243724,-15.17133408759776,-15.1895999669518,-15.207865846305836,-15.226131725659876,-15.244397605013912,-15.262663484367952,-15.280929363721988,-15.299195243076028,-15.317461122430064,-15.335727001784104,-15.35399288113814,-15.372258760492176,-15.390524639846216,-15.408790519200252,-15.427056398554292,-15.445322277908328,-15.463588157262368,-15.481854036616408,-15.500119915970444,-15.51838579532448,-15.53665167467852,-15.55491755403256,-15.573874934904508,-15.594215327964942,-15.614555721025376,-15.63489611408581,-15.655236507146245,-15.67557690020668,-15.695917293267113,-15.716257686327548,-15.736598079387983,-15.756938472448415,-15.777278865508851,-15.797619258569286,-15.817959651629721,-15.838300044690154,-15.858640437750587,-15.878980830811024,-15.899321223871459,-15.919661616931892,-15.940002009992327,-15.96034240305276,-15.980682796113195,-16.00102318917363,-16.021363582234066,-16.0417039752945,-16.062044368354933,-16.08238476141537,-16.102725154475802,-16.12200587752611,-16.14107466657439,-16.160143455622674,-16.179212244670957,-16.198281033719237,-16.217349822767517,-16.2364186118158,-16.255487400864084,-16.274556189912364,-16.293624978960647,-16.312693768008927,-16.33176255705721,-16.350831346105494,-16.369900135153774,-16.38896892420206,-16.408037713250337,-16.42710650229862,-16.446175291346904,-16.465244080395184,-16.484312869443468,-16.50338165849175,-16.52245044754003,-16.541519236588314,-16.560588025636594,-16.579656814684878,-16.59872560373316,-16.616920654646904,-16.63336824085622,-16.649815827065538,-16.66626341327485,-16.682710999484165,-16.69915858569348,-16.715606171902795,-16.73205375811211,-16.748501344321422,-16.76494893053074,-16.781396516740053,-16.79784410294937,-16.814291689158683,-16.830739275367996,-16.847186861577313,-16.863634447786627,-16.88008203399594,-16.896529620205257,-16.912977206414567,-16.929424792623884,-16.9458723788332,-16.962319965042514,-16.978767551251828,-16.99521513746114,-17.011662723670458,-17.02811030987977,-17.044557896089085,-17.0610054822984,-17.077453068507715,-17.093900654717032,-17.110348240926342,-17.12679582713566,-17.143243413344972,-17.159690999554286,-17.176138585763603,-17.192586171972916,-17.209033758182233,-17.225481344391547,-17.24192893060086,-17.258376516810173,-17.27482410301949,-17.291271689228807,-17.307719275438117,-17.324166861647434,-17.340614447856748,-17.35706203406606,-17.373509620275378,-17.38995720648469,-17.406404792694005,-17.422852378903322,-17.439299965112635,-17.45574755132195,-17.472195137531266,-17.48864272374058,-17.505090309949892,-17.52153789615921,-17.53798548236852,-17.55592173235896,-17.57460231423996,-17.593282896120968,-17.611963478001968,-17.630644059882968,-17.64932464176397,-17.668005223644972,-17.686685805525975,-17.70536638740698,-17.72404696928798,-17.742727551168983,-17.761408133049983,-17.780088714930983,-17.798769296811987,-17.81744987869299,-17.83613046057399,-17.854811042454994,-17.873491624335994,-17.892172206216998,-17.910852788097998,-17.929533369978998,-17.94821395186,-17.966894533741005,-17.985575115622005,-18.004255697503005,-18.02293627938401,-18.04161686126501,-18.06029744314601,-18.078978025027013,-18.097658606908016,-18.11633918878902,-18.13501977067002,-18.15370035255102,-18.172380934432024,-18.191061516313024,-18.209742098194027,-18.22842268007503,-18.24710326195603,-18.265783843837035,-18.284464425718035,-18.303145007599035,-18.32182558948004,-18.340506171361042,-18.359186753242042,-18.377867335123042,-18.396547917004046,-18.415228498885046,-18.43390908076605,-18.45258966264705,-18.471270244528057,-18.489950826409057,-18.508631408290057,-18.527311990171057,-18.54599257205206,-18.564673153933064,-18.583353735814065,-18.602034317695068,-18.62071489957607,-18.639395481457072,-18.658076063338072,-18.676756645219072,-18.695437227100076,-18.71411780898108,-18.73279839086208,-18.75147897274308,-18.77148604044651,-18.792819602946064,-18.814153165445628,-18.835486727945185,-18.85682029044474,-18.8781538529443,-18.899487415443858,-18.920820977943418,-18.942154540442974,-18.96348810294253,-18.98482166544209,-19.00615522794165,-19.027488790441208,-19.048822352940764,-19.070155915440324,-19.091489477939884,-19.11282304043944,-19.134156602939,-19.15743254236545,-19.182650858718787,-19.207869175072126,-19.233087491425465,-19.258305807778804,-19.283524124132143,-19.308742440485478,-19.33396075683882,-19.359179073192163,-19.384397389545494,-19.409615705898837,-19.43483402225218,-19.460052338605514,-19.485270654958853,-19.510488971312192,-19.53570728766553,-19.560925604018866,-19.58614392037221,-19.611362236725547,-19.63658055307889,-19.661798869432225,-19.687017185785564,-19.712235502138903,-19.73695418032412,-19.76099153733428,-19.78502889434444,-19.8090662513546,-19.833103608364762,-19.85714096537492,-19.88117832238508,-19.905215679395237,-19.929253036405402,-19.953290393415557,-19.97732775042572,-20.00136510743588,-20.025402464446042,-20.049439821456197,-20.07347717846636,-20.09751453547652,-20.121551892486675,-20.145589249496837,-20.169626606507,-20.193663963517153,-20.21770132052732,-20.24173867753748,-20.265776034547635,-20.289813391557797,-20.31385074856796,-20.337888105578116,-20.361925462588275,-20.385962819598436,-20.410000176608598,-20.434037533618756,-20.458074890628914,-20.482112247639076,-20.506149604649234,-20.530186961659396,-20.554224318669554,-20.578261675679713,-20.602299032689878,-20.626336389700036,-20.650373746710194,-20.674411103720352,-20.698448460730518,-20.722485817740672,-20.746523174750834,-20.770560531760992,-20.794597888771154,-20.81863524578131,-20.84267260279147,-20.866709959801632,-20.89074731681179,-20.914784673821952,-20.93882203083211,-20.962859387842272,-20.98689674485243,-21.01093410186259,-21.03497145887275,-21.05900881588291,-21.08304617289307,-21.107083529903232,-21.131120886913386,-21.155158243923548,-21.164808853760167,-21.145685969249712,-21.12656308473926,-21.107440200228808,-21.08831731571835,-21.069194431207897,-21.050071546697442,-21.030948662186987,-21.011825777676535,-20.992702893166083,-20.973580008655627,-20.954457124145172,-20.93533423963472,-20.91621135512426,-20.89708847061381,-20.877965586103358,-20.8588427015929,-20.839719817082447,-20.820596932571995,-20.801474048061536,-20.78235116355108,-20.76322827904063,-20.744105394530177,-20.72498251001972,-20.70585962550927,-20.68673674099881,-20.66761385648836,-20.648490971977907,-20.629368087467448,-20.610245202956996,-20.59112231844654,-20.571999433936092,-20.552876549425633,-20.53375366491518,-20.514630780404723,-20.49550789589427,-20.47638501138382,-20.457262126873363,-20.438139242362908,-20.419016357852456,-20.399893473342,-20.38077058883155,-20.361647704321093,-20.342524819810635,-20.323401935300183,-20.30427905078973,-20.285156166279275,-20.26603328176882,-20.246910397258368,-20.22778751274791,-20.20866462823746,-20.189541743727005,-20.17041885921655,-20.151295974706095,-20.132173090195643,-20.11305020568519,-20.093927321174732,-20.07480443666428,-20.055681552153825,-20.03655866764337,-20.017435783132917,-19.998312898622466,-19.979190014112007,-19.960067129601555,-19.9409442450911,-19.921821360580648,-19.90269847607019,-19.88357559155974,-19.864452707049285,-19.845329822538826,-19.826206938028374,-19.807084053517922,-19.787961169007467,-19.768838284497008,-19.749715399986556,-19.730592515476104,-19.71146963096565,-19.692346746455197,-19.67322386194474,-19.654100977434286,-19.63497809292383,-19.61117040758659,-19.583089724166726,-19.580117305377172,-19.702686209739163,-19.82736308174527,-19.95240448493838,-20.07744588813147,-20.202487291324584,-20.327528694517696,-20.452570097710783,-20.577611500903895,-20.70265290409701,-20.827694307290102,-20.952735710483214,-21.077777113676326,-21.20281851686944,-21.32785992006253,-21.45290132325564,-21.577942726448754,-21.702984129641845,-21.828025532834957,-21.953066936028065,-22.078108339221156,-22.20314974241427,-22.328191145607384,-22.45323254880047,-22.578273951993587,-22.703315355186696,-22.82835675837981,-22.9533981615729,-23.07843956476601,-23.203480967959123,-23.328522371152214,-23.453563774345326,-23.578605177538442,-23.70364658073153,-23.82868798392464,-23.953729387117757,-24.07877079031087,-24.203812193503957,-24.32885359669707,-24.45389499989018,-24.578936403083272,-24.703977806276384,-24.594660807890534,-24.317944951234118,-24.041229094577645,-23.764513237921175,-23.48779738126475,-23.21108152460828,-22.93436566795181,-22.657649811295336,-22.38093395463892,-22.10421809798245,-21.82750224132598,-21.550786384669557,-21.274070528013084,-20.99735467135661,-20.720638814700195,-20.44392295804372,-20.167207101387252,-19.890491244730782,-19.61377538807436,-19.33705953141789,-19.06034367476142,-18.783627818104996,-18.506911961448523,-18.230196104792054,-17.953480248135634,-17.67676439147916,-17.40004853482269,-17.12333267816627,-16.846616821509798,-16.56990096485333,-16.29318510819686,-16.016469251540435,-15.739753394883968,-15.463037538227494,-15.186321681571075,-14.909605824914603,-14.632889968258132,-14.356174111601712,-14.07945825494524,-13.80274239828877,-13.519437929604852,-13.22174597837865],[-14.063117688377702,-14.081383567731741,-14.099649447085778,-14.117915326439816,-14.136181205793854,-14.154447085147892,-14.172712964501928,-14.190978843855968,-14.209244723210006,-14.227510602564044,-14.245776481918083,-14.26404236127212,-14.282308240626158,-14.300574119980196,-14.318839999334234,-14.337105878688272,-14.35537175804231,-14.373637637396348,-14.391903516750386,-14.410169396104422,-14.428435275458462,-14.446701154812498,-14.464967034166536,-14.483232913520574,-14.501498792874614,-14.51976467222865,-14.53803055158269,-14.556296430936726,-14.574562310290766,-14.592828189644802,-14.611094068998842,-14.629359948352878,-14.647625827706914,-14.665891707060954,-14.684157586414992,-14.70242346576903,-14.720689345123068,-14.738955224477104,-14.757221103831142,-14.77548698318518,-14.79375286253922,-14.812018741893258,-14.830284621247294,-14.848550500601334,-14.86681637995537,-14.88508225930941,-14.903348138663446,-14.921614018017486,-14.939879897371522,-14.958145776725562,-14.976411656079598,-14.994677535433638,-15.012943414787676,-15.031209294141714,-15.04947517349575,-15.067741052849788,-15.086006932203826,-15.104272811557864,-15.122538690911902,-15.14080457026594,-15.159070449619978,-15.177336328974016,-15.195602208328054,-15.213868087682092,-15.23213396703613,-15.250399846390167,-15.268665725744205,-15.286931605098243,-15.305197484452282,-15.323463363806319,-15.341729243160358,-15.359995122514395,-15.378261001868434,-15.39652688122247,-15.416521518605322,-15.436861911665758,-15.457202304726191,-15.477542697786625,-15.497883090847061,-15.518223483907496,-15.53856387696793,-15.558904270028364,-15.579244663088797,-15.599585056149234,-15.61886577919954,-15.637934568247822,-15.657003357296103,-15.676072146344387,-15.695140935392669,-15.714209724440948,-15.733278513489232,-15.752347302537514,-15.771416091585795,-15.790484880634077,-15.807369329695844,-15.823816915905157,-15.840264502114476,-15.856712088323789,-15.873159674533104,-15.889607260742416,-15.906054846951733,-15.922502433161048,-15.93895001937036,-15.955397605579673,-15.97184519178899,-15.988292777998304,-16.004740364207617,-16.021187950416934,-16.03763553662625,-16.05408312283556,-16.070530709044874,-16.08697829525419,-16.103425881463505,-16.11987346767282,-16.136321053882135,-16.15276864009145,-16.169216226300765,-16.18566381251008,-16.202111398719392,-16.218558984928706,-16.235006571138022,-16.25145415734734,-16.26790174355665,-16.284349329765966,-16.30079691597528,-16.317244502184597,-16.33369208839391,-16.350139674603227,-16.366587260812537,-16.383034847021854,-16.39948243323117,-16.415930019440484,-16.432377605649798,-16.44882519185911,-16.465272778068424,-16.48172036427774,-16.49816795048706,-16.514615536696372,-16.531063122905685,-16.547510709115002,-16.563958295324312,-16.58040588153363,-16.596853467742942,-16.613301053952256,-16.629748640161573,-16.646196226370886,-16.662643812580203,-16.679091398789517,-16.69553898499883,-16.711986571208147,-16.72843415741746,-16.744881743626777,-16.761329329836087,-16.777776916045404,-16.794224502254718,-16.81067208846403,-16.827119674673348,-16.84356726088266,-16.860014847091975,-16.876462433301292,-16.892910019510605,-16.90935760571992,-16.925805191929236,-16.94225277813855,-16.958700364347866,-16.97514795055718,-16.991595536766493,-17.00953178675693,-17.028212368637934,-17.046892950518934,-17.065573532399938,-17.084254114280938,-17.10293469616194,-17.121615278042945,-17.140295859923945,-17.158976441804946,-17.17765702368595,-17.196337605566953,-17.215018187447953,-17.233698769328953,-17.252379351209957,-17.271059933090957,-17.28974051497196,-17.308421096852964,-17.327101678733964,-17.345782260614968,-17.364462842495968,-17.38314342437697,-17.40182400625797,-17.420504588138975,-17.439185170019975,-17.45786575190098,-17.476546333781975,-17.49522691566298,-17.513907497543983,-17.532588079424983,-17.551268661305983,-17.56994924318699,-17.58862982506799,-17.60731040694899,-17.62599098882999,-17.644671570710997,-17.663352152591997,-17.682032734472998,-17.700713316354,-17.719393898235005,-17.738074480116005,-17.756755061997005,-17.77543564387801,-17.794116225759012,-17.812796807640012,-17.831477389521016,-17.85015797140202,-17.86883855328302,-17.88751913516402,-17.906199717045023,-17.924880298926023,-17.943560880807027,-17.962241462688027,-17.980922044569027,-17.99960262645003,-18.018283208331034,-18.036963790212035,-18.055644372093038,-18.074324953974042,-18.093005535855042,-18.111686117736042,-18.130366699617046,-18.149047281498046,-18.16772786337905,-18.18640844526005,-18.205089027141053,-18.223769609022053,-18.242450190903057,-18.261130772784057,-18.27981135466506,-18.29849193654606,-18.317172518427064,-18.335853100308064,-18.354533682189068,-18.373214264070068,-18.39189484595107,-18.410575427832075,-18.42925600380865,-18.447465738439547,-18.465675473070448,-18.483885207701352,-18.50209494233225,-18.52030467696315,-18.538514411594047,-18.558825740025124,-18.581238662256382,-18.60485810754862,-18.628744263669326,-18.652630419790032,-18.676516575910735,-18.700402732031442,-18.72428888815215,-18.748175044272852,-18.772061200393555,-18.795947356514265,-18.81983351263497,-18.843719668755675,-18.86760582487638,-18.891491980997085,-18.915378137117788,-18.939264293238494,-18.9631504493592,-18.987036605479908,-19.01092276160061,-19.034808917721314,-19.058695073842024,-19.082581229962724,-19.10646738608343,-19.130353542204137,-19.154239698324844,-19.178125854445547,-19.202012010566257,-19.22589816668696,-19.249784322807663,-19.27367047892837,-19.297556635049077,-19.32144279116978,-19.345328947290486,-19.369215103411193,-19.3931012595319,-19.4169874156526,-19.44087357177331,-19.464759727894013,-19.488645884014716,-19.512532040135426,-19.53641819625613,-19.560304352376832,-19.584190508497542,-19.608076664618245,-19.63196282073895,-19.65584897685966,-19.679735132980362,-19.70362128910107,-19.727507445221775,-19.751393601342482,-19.775279757463185,-19.799165913583888,-19.823052069704595,-19.8469382258253,-19.870824381946004,-19.89471053806671,-19.918596694187418,-19.94248285030812,-19.966369006428828,-19.990255162549534,-20.014141318670237,-20.03802747479094,-20.06191363091165,-20.085799787032354,-20.109685943153057,-20.133572099273767,-20.15745825539447,-20.181344411515173,-20.20523056763588,-20.229116723756587,-20.25300287987729,-20.276889035997996,-20.300775192118703,-20.324661348239406,-20.348547504360113,-20.37243366048082,-20.396319816601522,-20.420205972722226,-20.444092128842936,-20.46797828496364,-20.491864441084346,-20.51575059720505,-20.528380677316818,-20.518498605410727,-20.508616533504636,-20.49873446159854,-20.488852389692454,-20.47897031778636,-20.469088245880272,-20.459206173974177,-20.449324102068083,-20.43944203016199,-20.429559958255897,-20.41967788634981,-20.409795814443715,-20.399913742537624,-20.39003167063153,-20.380149598725442,-20.370267526819347,-20.356893567507928,-20.33906440715088,-20.32123524679383,-20.303406086436777,-20.285576926079727,-20.267747765722678,-20.24991860536563,-20.232089445008576,-20.214260284651527,-20.196431124294474,-20.178601963937425,-20.160772803580375,-20.142943643223326,-20.125114482866273,-20.107285322509224,-20.089456162152175,-20.07162700179512,-20.053797841438072,-20.035968681081023,-20.01813952072397,-20.00031036036692,-19.98248120000987,-19.964652039652822,-19.94682287929577,-19.92899371893872,-19.911164558581667,-19.893335398224615,-19.87550623786757,-19.857677077510516,-19.839847917153467,-19.822018756796417,-19.804189596439368,-19.78636043608232,-19.768531275725266,-19.750702115368217,-19.732872955011167,-19.715043794654115,-19.697214634297065,-19.679385473940016,-19.661556313582963,-19.643727153225917,-19.625897992868865,-19.60806883251181,-19.590239672154762,-19.572410511797713,-19.55458135144066,-19.53675219108361,-19.51892303072656,-19.501093870369512,-19.48326471001246,-19.46543554965541,-19.44760638929836,-19.429777228941308,-19.41194806858426,-19.39411890822721,-19.37628974787016,-19.358460587513107,-19.340631427156058,-19.32280226679901,-19.304973106441956,-19.287143946084907,-19.269314785727857,-19.251485625370805,-19.233656465013755,-19.215827304656706,-19.197998144299653,-19.204159848173532,-19.33027587320204,-19.45639189823055,-19.582507923259058,-19.708623948287546,-19.834739973316054,-19.960855998344563,-20.08697202337305,-20.21308804840156,-20.33920407343007,-20.465320098458555,-20.591436123487064,-20.717552148515573,-20.84366817354408,-20.969784198572565,-21.095900223601078,-21.222016248629586,-21.34813227365807,-21.474248298686582,-21.60036432371509,-21.72648034874358,-21.852596373772087,-21.978712398800596,-22.10482842382908,-22.230944448857592,-22.357060473886097,-22.48317649891461,-22.609292523943097,-22.735408548971606,-22.861524574000114,-22.987640599028598,-23.11375662405711,-23.23987264908562,-23.365988674114107,-23.48669655104757,-23.599832975435696,-23.712969399823827,-23.826105824211936,-23.939242248600067,-24.05237867298819,-24.1655150973763,-24.27865152176443,-24.18911641278277,-23.954815922822785,-23.720515432862758,-23.486214942902734,-23.25191445294275,-23.017613962982722,-22.783313473022694,-22.549012983062667,-22.285967419485353,-22.01334023887147,-21.740713058257587,-21.468085877643748,-21.195458697029867,-20.922831516415982,-20.650204335802147,-20.377577155188263,-20.104949974574378,-19.832322793960493,-19.55969561334666,-19.287068432732774,-19.014441252118885,-18.741814071505054,-18.46918689089117,-18.196559710277285,-17.92393252966345,-17.651305349049565,-17.378678168435677,-17.106050987821845,-16.833423807207957,-16.560796626594076,-16.288169445980188,-16.015542265366356,-15.742915084752468,-15.470287904138585,-15.19766072352475,-14.925033542910864,-14.65240636229698,-14.379779181683146,-14.107152001069261,-13.834524820455375,-13.561897639841488,-13.289270459227657],[-13.592992867262007,-13.611258746616047,-13.629524625970085,-13.647790505324123,-13.666056384678159,-13.684322264032199,-13.702588143386237,-13.720854022740275,-13.73911990209431,-13.757385781448349,-13.775651660802389,-13.793917540156427,-13.812183419510465,-13.830449298864501,-13.848715178218539,-13.866981057572577,-13.885246936926617,-13.903512816280653,-13.921778695634691,-13.940044574988729,-13.958310454342767,-13.976576333696803,-13.994842213050843,-14.01310809240488,-14.03137397175892,-14.049639851112955,-14.067905730466995,-14.086171609821033,-14.104437489175071,-14.122703368529107,-14.140969247883147,-14.159235127237183,-14.177501006591223,-14.19576688594526,-14.214032765299297,-14.232298644653335,-14.250564524007373,-14.268830403361413,-14.28709628271545,-14.305362162069489,-14.323628041423525,-14.341893920777563,-14.3601598001316,-14.37842567948564,-14.396691558839676,-14.414957438193715,-14.433223317547752,-14.451489196901791,-14.469755076255828,-14.488020955609867,-14.506286834963904,-14.524552714317943,-14.542818593671981,-14.56108447302602,-14.579350352380056,-14.597616231734094,-14.615882111088133,-14.63414799044217,-14.652413869796208,-14.670679749150246,-14.688945628504284,-14.707211507858322,-14.72547738721236,-14.743743266566398,-14.762009145920436,-14.780275025274474,-14.79854090462851,-14.81680678398255,-14.835072663336588,-14.853338542690624,-14.871604422044664,-14.8898703013987,-14.90813618075274,-14.926402060106776,-14.944667939460816,-14.962933818814854,-14.981199698168892,-14.998659320004434,-15.014506437838845,-15.030353555673257,-15.04620067350767,-15.06204779134208,-15.077894909176493,-15.093742027010904,-15.107852060756331,-15.121614677683962,-15.13537729461159,-15.149139911539221,-15.16290252846685,-15.17666514539448,-15.191322747999184,-15.207770334208497,-15.224217920417814,-15.240665506627128,-15.257113092836441,-15.273560679045758,-15.290008265255072,-15.306455851464388,-15.322903437673702,-15.339351023883015,-15.355798610092332,-15.372246196301646,-15.388693782510959,-15.405141368720273,-15.42158895492959,-15.438036541138903,-15.454484127348216,-15.47093171355753,-15.487379299766847,-15.50382688597616,-15.520274472185477,-15.53672205839479,-15.553169644604107,-15.56961723081342,-15.586064817022734,-15.602512403232048,-15.618959989441365,-15.635407575650678,-15.651855161859991,-15.668302748069305,-15.684750334278622,-15.701197920487935,-15.717645506697252,-15.734093092906566,-15.750540679115879,-15.766988265325196,-15.78343585153451,-15.799883437743825,-15.816331023953136,-15.832778610162453,-15.849226196371767,-15.865673782581082,-15.882121368790397,-15.89856895499971,-15.915016541209027,-15.93146412741834,-15.947911713627654,-15.964359299836968,-15.980806886046285,-15.997254472255598,-16.01370205846491,-16.03014964467423,-16.046597230883542,-16.063044817092855,-16.079492403302172,-16.095939989511486,-16.112387575720803,-16.128835161930116,-16.14528274813943,-16.161730334348746,-16.17817792055806,-16.194625506767373,-16.211073092976687,-16.227520679186,-16.243968265395317,-16.26041585160463,-16.276863437813944,-16.29331102402326,-16.309758610232574,-16.326206196441888,-16.342653782651205,-16.359101368860518,-16.37554895506983,-16.391996541279145,-16.408444127488462,-16.424891713697775,-16.44133929990709,-16.457519687971494,-16.47356647696344,-16.48961326595539,-16.505660054947338,-16.521706843939285,-16.53775363293124,-16.553800421923185,-16.569847210915132,-16.585893999907082,-16.603251660202783,-16.621461394833684,-16.63967112946458,-16.657880864095482,-16.676090598726383,-16.69430033335728,-16.71251006798818,-16.730719802619078,-16.74892953724998,-16.767139271880882,-16.78534900651178,-16.80355874114268,-16.821768475773574,-16.839978210404475,-16.85818794503538,-16.876397679666276,-16.894607414297177,-16.912817148928074,-16.93102688355897,-16.949236618189875,-16.967446352820772,-16.985656087451673,-17.003865822082574,-17.02207555671347,-17.04028529134437,-17.05849502597527,-17.07670476060617,-17.09491449523707,-17.11312422986797,-17.131333964498868,-17.149543699129765,-17.167753433760666,-17.185963168391567,-17.204172903022467,-17.222382637653368,-17.240592372284265,-17.258802106915166,-17.277011841546067,-17.295221576176964,-17.313431310807864,-17.331641045438765,-17.349850780069662,-17.36806051470056,-17.386270249331464,-17.40447998396236,-17.42268971859326,-17.44089945322416,-17.459109187855056,-17.477318922485956,-17.495528657116857,-17.513738391747758,-17.53194812637866,-17.550157861009556,-17.568367595640456,-17.586577330271357,-17.604787064902254,-17.622996799533155,-17.641206534164056,-17.659416268794953,-17.677626003425853,-17.69583573805675,-17.71404547268765,-17.732255207318552,-17.75046494194945,-17.76867467658035,-17.786884411211247,-17.805094145842148,-17.82330388047305,-17.84151361510395,-17.859723349734846,-17.877933084365747,-17.896142818996648,-17.914352553627545,-17.932562288258445,-17.952873616689523,-17.975286538920777,-17.99769946115203,-18.020112383383285,-18.042525305614543,-18.064938227845794,-18.087351150077048,-18.109764072308305,-18.132176994539563,-18.154589916770817,-18.17700283900207,-18.199415761233325,-18.22182868346458,-18.244241605695834,-18.26665452792709,-18.289067450158345,-18.3114803723896,-18.333893294620854,-18.35630621685211,-18.378719139083362,-18.40113206131462,-18.423544983545877,-18.445957905777128,-18.468370828008382,-18.49078375023964,-18.513196672470894,-18.535609594702148,-18.558022516933402,-18.58043543916466,-18.602848361395914,-18.625261283627168,-18.647674205858422,-18.670087128089676,-18.692500050320934,-18.715065372528077,-18.738951528648784,-18.762837684769487,-18.786723840890197,-18.810609997010896,-18.834496153131603,-18.858382309252306,-18.882268465373016,-18.90615462149372,-18.930040777614426,-18.953926933735133,-18.977813089855836,-19.00169924597654,-19.025585402097246,-19.049471558217952,-19.073357714338655,-19.097243870459366,-19.12113002658007,-19.145016182700772,-19.16890233882148,-19.192788494942185,-19.21667465106289,-19.240560807183595,-19.2644469633043,-19.288333119425005,-19.31221927554571,-19.336105431666418,-19.35999158778712,-19.383877743907824,-19.407763900028534,-19.431650056149238,-19.455536212269944,-19.47942236839065,-19.503308524511354,-19.527194680632057,-19.551080836752767,-19.57496699287347,-19.598853148994177,-19.62273930511488,-19.646625461235587,-19.67051161735629,-19.694397773476997,-19.718283929597703,-19.742170085718406,-19.76605624183911,-19.78994239795982,-19.813828554080523,-19.837714710201226,-19.861600866321936,-19.874230946433705,-19.86434887452761,-19.854466802621523,-19.84458473071543,-19.834702658809338,-19.824820586903243,-19.814938514997152,-19.80505644309106,-19.79517437118497,-19.785292299278876,-19.77541022737278,-19.76552815546669,-19.7556460835606,-19.745764011654508,-19.735881939748417,-19.725999867842326,-19.716117795936235,-19.70623572403014,-19.696353652124046,-19.686471580217955,-19.676589508311864,-19.666707436405773,-19.65682536449968,-19.646943292593587,-19.637061220687492,-19.627179148781405,-19.61729707687531,-19.60741500496922,-19.59753293306313,-19.587650861157034,-19.577768789250943,-19.567886717344848,-19.558004645438757,-19.548122573532666,-19.538240501626575,-19.528358429720484,-19.518476357814386,-19.5085942859083,-19.498712214002207,-19.488830142096113,-19.47894807019002,-19.46906599828393,-19.459183926377836,-19.44930185447174,-19.43941978256565,-19.42953771065956,-19.41965563875347,-19.409773566847377,-19.399891494941283,-19.390009423035192,-19.380127351129097,-19.370245279223006,-19.352897753752146,-19.335068593395096,-19.317239433038047,-19.299410272680998,-19.281581112323945,-19.263751951966896,-19.245922791609846,-19.228093631252797,-19.210264470895744,-19.192435310538695,-19.174606150181646,-19.156776989824593,-19.138947829467547,-19.121118669110494,-19.10328950875344,-19.085460348396396,-19.067631188039343,-19.04980202768229,-19.03197286732524,-19.01414370696819,-18.996314546611142,-18.97848538625409,-18.96065622589704,-18.94282706553999,-18.924997905182938,-18.90716874482589,-18.88933958446884,-18.871510424111786,-18.853681263754737,-18.835852103397688,-18.818022943040635,-18.824184646914517,-18.950300671943022,-19.07641669697153,-19.20253272200004,-19.328648747028524,-19.454764772057036,-19.580880797085545,-19.706996822114032,-19.83311284714254,-19.95922887217105,-20.085344897199537,-20.211460922228046,-20.337576947256554,-20.463692972285063,-20.589808997313547,-20.715925022342056,-20.842041047370568,-20.95535776472861,-21.06849418911674,-21.181630613504872,-21.294767037892974,-21.407903462281105,-21.521039886669236,-21.634176311057338,-21.747312735445476,-21.8604491598336,-21.97358558422173,-22.08672200860984,-22.199858432997967,-22.312994857386094,-22.426131281774204,-22.539267706162335,-22.65240413055046,-22.76554055493857,-22.8786769793267,-22.99181340371483,-23.10494982810296,-23.21808625249107,-23.331222676879197,-23.444359101267324,-23.557495525655433,-23.670631950043564,-23.5810968410619,-23.346796351101915,-23.112495861141888,-22.878195371181867,-22.643894881221883,-22.409594391261855,-22.175293901301828,-21.9409934113418,-21.706692921381816,-21.472392431421788,-21.23809194146176,-21.003791451501776,-20.76949096154175,-20.53519047158172,-20.30088998162174,-20.066589491661716,-19.832289001701685,-19.59798851174166,-19.363688021781677,-19.12938753182165,-18.895087041861622,-18.660786551901637,-18.42648606194161,-18.192185571981582,-17.957885082021598,-17.71666443389954,-17.44403725328565,-17.171410072671815,-16.89878289205793,-16.626155711444042,-16.35352853083016,-16.080901350216326,-15.808274169602441,-15.535646988988555,-15.263019808374722,-14.990392627760837,-14.71776544714695,-14.445138266533116,-14.17251108591923,-13.899883905305346,-13.62725672469146,-13.354629544077627],[-13.121000048066309,-13.139265927420347,-13.157531806774386,-13.175797686128423,-13.19406356548246,-13.212329444836499,-13.230595324190535,-13.248861203544575,-13.267127082898613,-13.28539296225265,-13.303658841606689,-13.321924720960725,-13.340190600314765,-13.358456479668803,-13.37672235902284,-13.394988238376879,-13.413254117730915,-13.431519997084953,-13.449785876438993,-13.46805175579303,-13.486317635147069,-13.504583514501105,-13.522849393855147,-13.541115273209181,-13.559381152563223,-13.577647031917257,-13.595912911271295,-13.614178790625335,-13.632444669979373,-13.650710549333409,-13.668976428687447,-13.687242308041485,-13.705508187395523,-13.723774066749561,-13.7420399461036,-13.760305825457637,-13.778571704811675,-13.796837584165715,-13.81510346351975,-13.833369342873791,-13.851635222227827,-13.869901101581865,-13.888166980935901,-13.906432860289941,-13.924698739643977,-13.942964618998017,-13.961230498352053,-13.979496377706093,-13.99776225706013,-14.01602813641417,-14.034294015768205,-14.052559895122243,-14.070825774476283,-14.08909165383032,-14.107357533184357,-14.125623412538395,-14.143889291892433,-14.162155171246471,-14.180421050600508,-14.198686929954548,-14.216952809308586,-14.233203051703066,-14.249050169537478,-14.264897287371891,-14.280744405206303,-14.296591523040714,-14.312438640875126,-14.328285758709537,-14.34413287654395,-14.359979994378362,-14.375827112212773,-14.391674230047187,-14.407521347881596,-14.423368465716008,-14.439215583550421,-14.455062701384833,-14.470909819219246,-14.486756937053658,-14.502604054888069,-14.518451172722482,-14.534298290556894,-14.550145408391304,-14.565992526225717,-14.581839644060128,-14.595949677805555,-14.609712294733187,-14.623474911660814,-14.637237528588445,-14.651000145516075,-14.664762762443704,-14.678525379371335,-14.692287996298964,-14.706050613226594,-14.719813230154223,-14.733575847081854,-14.747338464009484,-14.761101080937113,-14.774863697864744,-14.788626314792374,-14.802388931720003,-14.816151548647632,-14.82991416557526,-14.843676782502893,-14.857439399430522,-14.87120201635815,-14.884964633285781,-14.89872725021341,-14.914727338922846,-14.931174925132163,-14.947622511341477,-14.964070097550792,-14.980517683760105,-14.99696526996942,-15.013412856178736,-15.029860442388049,-15.046308028597364,-15.06275561480668,-15.079203201015993,-15.095650787225308,-15.112098373434621,-15.128545959643938,-15.144993545853252,-15.161441132062565,-15.17788871827188,-15.194336304481196,-15.21078389069051,-15.227231476899828,-15.243679063109141,-15.260126649318453,-15.27657423552777,-15.293021821737083,-15.309469407946398,-15.325916994155712,-15.342364580365027,-15.35881216657434,-15.375259752783654,-15.391707338992969,-15.408154925202284,-15.4246025114116,-15.441050097620915,-15.457497683830228,-15.473945270039541,-15.490392856248857,-15.506840442458172,-15.523288028667487,-15.5397356148768,-15.556183201086116,-15.57263078729543,-15.589078373504744,-15.60552595971406,-15.621973545923373,-15.63842113213269,-15.654868718342001,-15.671316304551317,-15.687763890760632,-15.704211476969945,-15.720659063179259,-15.737106649388576,-15.753554235597889,-15.770001821807204,-15.786449408016518,-15.802896994225833,-15.819344580435148,-15.835792166644461,-15.852239752853778,-15.868687339063092,-15.885134925272405,-15.90131531333681,-15.91736210232876,-15.933408891320706,-15.949455680312656,-15.965502469304603,-15.981549258296553,-15.997596047288502,-16.01364283628045,-16.0296896252724,-16.045736414264347,-16.061783203256297,-16.077829992248244,-16.09387678124019,-16.10992357023214,-16.12597035922409,-16.142017148216038,-16.158063937207988,-16.174110726199935,-16.190157515191885,-16.20620430418383,-16.222251093175778,-16.23829788216773,-16.254344671159675,-16.270391460151625,-16.286438249143572,-16.302485038135522,-16.318531827127472,-16.33457861611942,-16.350625405111366,-16.366672194103316,-16.382718983095266,-16.398765772087213,-16.41612343337787,-16.43433316800877,-16.452542902639667,-16.47075263727057,-16.488962371901465,-16.507172106532366,-16.525381841163266,-16.543591575794167,-16.561801310425064,-16.58001104505597,-16.598220779686866,-16.616430514317763,-16.634640248948664,-16.652849983579564,-16.67105971821046,-16.68926945284136,-16.70747918747226,-16.72568892210316,-16.74389865673406,-16.762108391364958,-16.78031812599586,-16.79852786062676,-16.81673759525766,-16.834947329888557,-16.853157064519454,-16.87136679915036,-16.889576533781256,-16.907786268412156,-16.925996003043053,-16.944205737673954,-16.962415472304855,-16.980625206935752,-16.998834941566653,-17.017044676197553,-17.03525441082845,-17.05346414545935,-17.07167388009025,-17.08988361472115,-17.10809334935205,-17.126303083982947,-17.144512818613848,-17.16272255324475,-17.180932287875645,-17.199142022506546,-17.217351757137447,-17.235561491768348,-17.253771226399245,-17.271980961030145,-17.290190695661046,-17.308400430291947,-17.326610164922844,-17.34692149335392,-17.36933441558518,-17.39174733781643,-17.414160260047684,-17.43657318227894,-17.458986104510196,-17.48139902674145,-17.503811948972704,-17.526224871203958,-17.548637793435212,-17.571050715666466,-17.593463637897727,-17.61587656012898,-17.638289482360232,-17.66070240459149,-17.683115326822744,-17.705528249053998,-17.727941171285252,-17.750354093516506,-17.77276701574776,-17.795179937979015,-17.817592860210276,-17.840005782441526,-17.86241870467278,-17.884831626904038,-17.907244549135292,-17.929657471366546,-17.9520703935978,-17.974483315829055,-17.996896238060312,-18.019309160291566,-18.04172208252282,-18.064135004754075,-18.086547926985332,-18.108960849216587,-18.13137377144784,-18.153786693679095,-18.176199615910352,-18.198612538141603,-18.221025460372857,-18.243438382604115,-18.265851304835365,-18.28826422706662,-18.310677149297877,-18.333090071529135,-18.355502993760386,-18.377915915991643,-18.400328838222897,-18.42274176045415,-18.445154682685406,-18.467567604916663,-18.489980527147914,-18.51239344937917,-18.534806371610426,-18.55721929384168,-18.579632216072934,-18.60204513830419,-18.624458060535446,-18.6468709827667,-18.669283904997954,-18.69169682722921,-18.714109749460462,-18.736522671691716,-18.758935593922974,-18.781348516154228,-18.803761438385482,-18.82617436061674,-18.849158793628238,-18.873044949748945,-18.89693110586965,-18.920817261990354,-18.94470341811106,-18.968589574231768,-18.99247573035247,-19.016361886473177,-19.04024804259388,-19.06413419871459,-19.08802035483529,-19.111906510955997,-19.135792667076704,-19.15967882319741,-19.183564979318113,-19.207451135438816,-19.22008121555059,-19.210199143644495,-19.200317071738407,-19.190434999832313,-19.18055292792622,-19.17067085602013,-19.160788784114036,-19.150906712207945,-19.141024640301854,-19.13114256839576,-19.121260496489665,-19.111378424583577,-19.101496352677486,-19.09161428077139,-19.0817322088653,-19.07185013695921,-19.061968065053115,-19.052085993147028,-19.042203921240933,-19.03232184933484,-19.02243977742875,-19.012557705522656,-19.002675633616562,-18.992793561710474,-18.982911489804376,-18.97302941789829,-18.963147345992194,-18.953265274086107,-18.943383202180012,-18.93350113027392,-18.923619058367827,-18.913736986461736,-18.90385491455564,-18.893972842649553,-18.88409077074346,-18.874208698837368,-18.864326626931273,-18.854444555025182,-18.844562483119095,-18.834680411212997,-18.82479833930691,-18.814916267400815,-18.805034195494724,-18.79515212358863,-18.785270051682538,-18.775387979776447,-18.765505907870352,-18.755623835964258,-18.745741764058167,-18.735859692152076,-18.725977620245985,-18.716095548339894,-18.7062134764338,-18.696331404527708,-18.686449332621617,-18.676567260715522,-18.666685188809428,-18.65680311690334,-18.646921044997246,-18.63703897309115,-18.62715690118506,-18.617274829278973,-18.607392757372878,-18.597510685466784,-18.587628613560696,-18.5777465416546,-18.567864469748507,-18.557982397842416,-18.548100325936325,-18.538218254030234,-18.528336182124143,-18.51845411021805,-18.50960052518271,-18.501177058740787,-18.492753592298865,-18.484330125856935,-18.475906659415013,-18.467483192973088,-18.459059726531166,-18.45063626008924,-18.442212793647318,-18.43378932720539,-18.425365860763463,-18.436938707961936,-18.548493123362384,-18.660047538762832,-18.77160195416328,-18.883156369563707,-18.994710784964155,-19.106265200364607,-19.217819615765034,-19.329374031165482,-19.442246797902772,-19.55538322229088,-19.66851964667901,-19.78165607106714,-19.894792495455267,-20.007928919843373,-20.121065344231507,-20.23420176861963,-20.34733819300774,-20.46047461739587,-20.573611041783998,-20.686747466172108,-20.79988389056024,-20.913020314948366,-21.026156739336475,-21.139293163724602,-21.252429588112733,-21.365566012500864,-21.47870243688897,-21.5918388612771,-21.704975285665228,-21.818111710053337,-21.931248134441464,-22.044384558829595,-22.1575209832177,-22.27065740760583,-22.383793831993962,-22.496930256382093,-22.610066680770196,-22.72320310515833,-22.836339529546457,-22.949475953934567,-23.062612378322697,-22.973077269341033,-22.73877677938105,-22.50447628942102,-22.270175799461,-22.035875309501012,-21.801574819540985,-21.567274329580957,-21.33297383962093,-21.09867334966095,-20.86437285970092,-20.630072369740894,-20.39577187978091,-20.161471389820882,-19.927170899860855,-19.692870409900873,-19.458569919940846,-19.22426942998082,-18.98996894002079,-18.75566845006081,-18.521367960100783,-18.28706747014075,-18.05276698018077,-17.818466490220743,-17.584166000260716,-17.34986551030073,-17.115565020340703,-16.88126453038068,-16.646964040420695,-16.412663550460664,-16.17836306050064,-15.944062570540613,-15.709762080580628,-15.475461590620602,-15.243127564393987,-15.01472658325575,-14.786325602117474,-14.557924620979197,-14.329523639840964,-14.101122658702687,-13.872721677564408,-13.644320696426131,-13.415919715287897],[-12.649007228870609,-12.667273108224649,-12.685538987578685,-12.703804866932725,-12.72207074628676,-12.7403366256408,-12.758602504994839,-12.776868384348877,-12.795134263702913,-12.813400143056953,-12.831666022410989,-12.849931901765027,-12.868197781119065,-12.886463660473105,-12.904729539827143,-12.922995419181179,-12.941261298535217,-12.959527177889255,-12.977793057243293,-12.996058936597331,-13.014324815951369,-13.032590695305407,-13.050856574659445,-13.069122454013485,-13.087388333367521,-13.105654212721559,-13.123920092075597,-13.142185971429633,-13.160451850783673,-13.17871773013771,-13.196983609491749,-13.215249488845785,-13.233515368199825,-13.251781247553863,-13.270047126907901,-13.288313006261937,-13.306578885615977,-13.324844764970013,-13.343110644324053,-13.36137652367809,-13.379642403032127,-13.397908282386165,-13.416174161740203,-13.434440041094241,-13.451899665567286,-13.467746783401697,-13.483593901236109,-13.499441019070524,-13.515288136904934,-13.531135254739345,-13.546982372573758,-13.56282949040817,-13.578676608242581,-13.594523726076993,-13.610370843911406,-13.626217961745818,-13.64206507958023,-13.657912197414642,-13.673759315249054,-13.689606433083465,-13.705453550917877,-13.721300668752288,-13.737147786586702,-13.752994904421113,-13.768842022255527,-13.784689140089938,-13.800536257924348,-13.816383375758761,-13.832230493593173,-13.848077611427584,-13.863924729261997,-13.879771847096407,-13.895618964930819,-13.911466082765232,-13.927313200599645,-13.943160318434057,-13.959007436268468,-13.974854554102881,-13.990701671937293,-14.006548789771704,-14.022395907606116,-14.038243025440527,-14.05409014327494,-14.069937261109352,-14.084047294854777,-14.09780991178241,-14.111572528710038,-14.125335145637667,-14.139097762565298,-14.152860379492928,-14.166622996420557,-14.180385613348188,-14.194148230275818,-14.207910847203447,-14.221673464131076,-14.235436081058706,-14.249198697986337,-14.262961314913966,-14.276723931841596,-14.290486548769227,-14.304249165696856,-14.318011782624485,-14.331774399552113,-14.345537016479746,-14.359299633407375,-14.373062250335003,-14.386824867262632,-14.400587484190263,-14.414350101117893,-14.428112718045522,-14.441875334973153,-14.455637951900783,-14.469400568828412,-14.483163185756043,-14.496925802683673,-14.510688419611302,-14.524451036538933,-14.53821365346656,-14.551976270394192,-14.565738887321821,-14.57950150424945,-14.593264121177082,-14.60702673810471,-14.621684343637197,-14.63813192984651,-14.654579516055826,-14.671027102265143,-14.687474688474456,-14.70392227468377,-14.720369860893086,-14.7368174471024,-14.753265033311713,-14.769712619521027,-14.786160205730344,-14.802607791939657,-14.81905537814897,-14.835502964358286,-14.8519505505676,-14.868398136776916,-14.88484572298623,-14.901293309195545,-14.917740895404858,-14.934188481614173,-14.950636067823488,-14.967083654032804,-14.983531240242117,-14.999978826451432,-15.016426412660747,-15.03287399887006,-15.049321585079376,-15.06576917128869,-15.082216757498006,-15.09866434370732,-15.115111929916633,-15.13155951612595,-15.148007102335264,-15.164454688544577,-15.18090227475389,-15.197349860963204,-15.21379744717252,-15.230245033381834,-15.24669261959115,-15.263140205800465,-15.279587792009778,-15.296035378219093,-15.312482964428408,-15.328930550637722,-15.345110938702126,-15.361157727694074,-15.377204516686023,-15.393251305677971,-15.409298094669918,-15.42534488366187,-15.441391672653818,-15.457438461645769,-15.473485250637715,-15.489532039629665,-15.505578828621612,-15.521625617613562,-15.537672406605509,-15.553719195597457,-15.569765984589406,-15.585812773581353,-15.601859562573303,-15.617906351565251,-15.6339531405572,-15.649999929549146,-15.666046718541095,-15.682093507533047,-15.698140296524993,-15.714187085516942,-15.73023387450889,-15.746280663500837,-15.762327452492787,-15.778374241484734,-15.794421030476682,-15.81046781946863,-15.826514608460581,-15.842561397452531,-15.858608186444478,-15.874654975436425,-15.890701764428373,-15.906748553420323,-15.922795342412272,-15.938842131404218,-15.954888920396167,-15.970935709388117,-15.986982498380065,-16.003029287372012,-16.019076076363962,-16.035122865355913,-16.05116965434786,-16.06721644333981,-16.083263232331756,-16.099310021323703,-16.115356810315653,-16.1314035993076,-16.14745038829955,-16.163497177291497,-16.179543966283447,-16.195590755275393,-16.21163754426734,-16.228995206552955,-16.247204941183853,-16.265414675814753,-16.283624410445654,-16.301834145076555,-16.320043879707452,-16.338253614338353,-16.356463348969253,-16.37467308360015,-16.392882818231048,-16.41109255286195,-16.42930228749285,-16.44751202212375,-16.465721756754647,-16.483931491385547,-16.502141226016448,-16.520350960647345,-16.538560695278246,-16.556770429909147,-16.574980164540044,-16.593189899170945,-16.611399633801845,-16.629609368432746,-16.647819103063643,-16.66602883769454,-16.68423857232544,-16.70244830695634,-16.72065804158724,-16.740969370018316,-16.763382292249574,-16.785795214480828,-16.808208136712082,-16.83062105894334,-16.85303398117459,-16.875446903405845,-16.897859825637102,-16.92027274786836,-16.94268567009961,-16.965098592330865,-16.987511514562122,-17.009924436793376,-17.03233735902463,-17.054750281255888,-17.07716320348714,-17.099576125718396,-17.12198904794965,-17.144401970180905,-17.16681489241216,-17.189227814643417,-17.211640736874674,-17.234053659105925,-17.25646658133718,-17.278879503568437,-17.30129242579969,-17.323705348030945,-17.3461182702622,-17.368531192493453,-17.39094411472471,-17.413357036955965,-17.43576995918722,-17.458182881418473,-17.480595803649727,-17.503008725880985,-17.525421648112236,-17.547834570343493,-17.570247492574747,-17.592660414806,-17.615073337037256,-17.637486259268513,-17.659899181499767,-17.682312103731018,-17.704725025962276,-17.727137948193533,-17.749550870424784,-17.77196379265604,-17.794376714887296,-17.81678963711855,-17.8392025593498,-17.861615481581058,-17.884028403812312,-17.906441326043566,-17.928854248274824,-17.95126717050608,-17.973680092737332,-17.99609301496859,-18.018505937199844,-18.040918859431102,-18.06225715602689,-18.083322534745854,-18.10438791346482,-18.12545329218378,-18.146518670902744,-18.167584049621702,-18.188649428340664,-18.20971480705963,-18.230780185778592,-18.251845564497554,-18.272910943216516,-18.293976321935478,-18.31504170065444,-18.336107079373402,-18.357172458092368,-18.378237836811326,-18.39930321553029,-18.420368594249254,-18.441433972968213,-18.462499351687175,-18.48356473040614,-18.504630109125102,-18.525695487844065,-18.546760866563027,-18.560092488401885,-18.55795659648054,-18.5558207045592,-18.553684812637854,-18.55154892071651,-18.54941302879517,-18.547277136873824,-18.545141244952482,-18.543005353031138,-18.540869461109793,-18.53873356918845,-18.536597677267107,-18.534461785345766,-18.53232589342442,-18.530190001503076,-18.52805410958173,-18.52591821766039,-18.523782325739045,-18.521646433817704,-18.514794864048447,-18.50637139760652,-18.497947931164596,-18.48952446472267,-18.481100998280745,-18.47267753183882,-18.464254065396897,-18.45583059895497,-18.44740713251305,-18.438983666071124,-18.4305601996292,-18.422136733187273,-18.41371326674535,-18.405289800303425,-18.3968663338615,-18.388442867419574,-18.380019400977652,-18.371595934535726,-18.3631724680938,-18.35474900165188,-18.346325535209953,-18.33790206876803,-18.329478602326105,-18.32105513588418,-18.312631669442254,-18.30420820300033,-18.295784736558407,-18.28736127011648,-18.27893780367456,-18.270514337232633,-18.262090870790708,-18.253667404348782,-18.24524393790686,-18.236820471464934,-18.22839700502301,-18.219973538581087,-18.21155007213916,-18.203126605697236,-18.19470313925531,-18.186279672813384,-18.177856206371462,-18.16943273992954,-18.161009273487615,-18.15258580704569,-18.144162340603764,-18.135738874161838,-18.127315407719912,-18.118891941277987,-18.11046847483607,-18.102045008394143,-18.093621541952217,-18.08519807551029,-18.07677460906837,-18.068351142626444,-18.059927676184518,-18.051504209742596,-18.04308074330067,-18.034657276858745,-18.02623381041682,-18.017810343974894,-18.009386877532968,-18.000963411091046,-17.992539944649124,-17.9841164782072,-17.99568932540567,-18.107243740806116,-18.218798156206564,-18.330352571607012,-18.441906987007442,-18.553461402407887,-18.665015817808335,-18.776570233208766,-18.888124648609214,-18.999679064009662,-19.11123347941009,-19.22278789481054,-19.334342310210985,-19.445896725611433,-19.557451141011864,-19.66900555641231,-19.78055997181276,-19.892114387213187,-20.003668802613635,-20.115223218014084,-20.22677763341451,-20.33833204881496,-20.449886464215407,-20.561440879615834,-20.672995295016282,-20.784549710416734,-20.896104125817182,-21.00765854121761,-21.119212956618057,-21.230767372018505,-21.33770037207567,-21.423799211310254,-21.50989805054484,-21.595996889779407,-21.682095729013994,-21.768194568248582,-21.854293407483162,-21.94039224671773,-22.026491085952316,-22.1125899251869,-22.19868876442147,-22.284787603656053,-22.217948233763558,-22.041867285923228,-21.865786338082863,-21.689705390242498,-21.513624442402165,-21.3375434945618,-21.161462546721435,-20.985381598881073,-20.80930065104074,-20.63321970320038,-20.45713875536001,-20.281057807519677,-20.05343543139422,-19.825034450255945,-19.596633469117712,-19.368232487979434,-19.139831506841155,-18.91143052570288,-18.683029544564647,-18.45462856342637,-18.226227582288093,-17.997826601149857,-17.76942562001158,-17.541024638873303,-17.312623657735067,-17.08422267659679,-16.855821695458513,-16.62742071432028,-16.399019733182,-16.170618752043723,-15.94221777090545,-15.713816789767215,-15.485415808628936,-15.25701482749066,-15.028613846352426,-14.80021286521415,-14.571811884075872,-14.343410902937638,-14.11500992179936,-13.886608940661084,-13.658207959522805,-13.42980697838457],[-12.17701440967491,-12.19528028902895,-12.213546168382987,-12.231812047737025,-12.250077927091063,-12.268343806445102,-12.286609685799139,-12.304875565153177,-12.323141444507215,-12.341407323861254,-12.35967320321529,-12.377939082569329,-12.396204961923367,-12.414470841277405,-12.432736720631443,-12.45100259998548,-12.469268479339519,-12.487534358693557,-12.505800238047595,-12.524066117401633,-12.54233199675567,-12.560597876109707,-12.578863755463745,-12.597129634817785,-12.615395514171823,-12.633661393525859,-12.651927272879899,-12.670193152233935,-12.686443397265919,-12.70229051510033,-12.718137632934742,-12.733984750769155,-12.749831868603565,-12.765678986437978,-12.78152610427239,-12.797373222106803,-12.813220339941214,-12.829067457775626,-12.844914575610037,-12.860761693444449,-12.87660881127886,-12.892455929113273,-12.908303046947685,-12.924150164782098,-12.93999728261651,-12.955844400450921,-12.971691518285333,-12.987538636119744,-13.003385753954156,-13.019232871788569,-13.03507998962298,-13.05092710745739,-13.066774225291805,-13.082621343126217,-13.098468460960628,-13.11431557879504,-13.130162696629453,-13.146009814463865,-13.161856932298274,-13.17770405013269,-13.1935511679671,-13.20939828580151,-13.225245403635924,-13.241092521470337,-13.256939639304747,-13.27278675713916,-13.288633874973572,-13.304480992807983,-13.320328110642395,-13.336175228476808,-13.35202234631122,-13.367869464145631,-13.383716581980043,-13.399563699814456,-13.415410817648866,-13.431257935483279,-13.447105053317692,-13.462952171152104,-13.478799288986515,-13.494646406820927,-13.51049352465534,-13.52634064248975,-13.542187760324163,-13.558034878158574,-13.572144911904001,-13.585907528831632,-13.59967014575926,-13.613432762686891,-13.62719537961452,-13.64095799654215,-13.654720613469781,-13.66848323039741,-13.682245847325039,-13.696008464252671,-13.7097710811803,-13.723533698107929,-13.73729631503556,-13.75105893196319,-13.764821548890819,-13.778584165818447,-13.79234678274608,-13.806109399673709,-13.819872016601337,-13.833634633528966,-13.847397250456595,-13.861159867384227,-13.874922484311856,-13.888685101239485,-13.902447718167117,-13.916210335094746,-13.929972952022375,-13.943735568950006,-13.957498185877636,-13.971260802805265,-13.985023419732894,-13.998786036660523,-14.012548653588155,-14.026311270515784,-14.040073887443413,-14.053836504371045,-14.067599121298674,-14.081361738226303,-14.095124355153931,-14.108886972081562,-14.122649589009193,-14.136412205936821,-14.150174822864452,-14.16393743979208,-14.177700056719711,-14.19146267364734,-14.205225290574969,-14.218987907502601,-14.23275052443023,-14.246513141357863,-14.260275758285491,-14.274038375213118,-14.287800992140749,-14.301563609068378,-14.315326225996008,-14.329088842923639,-14.34508893456086,-14.361536520770176,-14.37798410697949,-14.394431693188803,-14.41087927939812,-14.427326865607434,-14.443774451816747,-14.460222038026062,-14.476669624235377,-14.493117210444693,-14.509564796654006,-14.526012382863323,-14.542459969072635,-14.558907555281948,-14.575355141491263,-14.591802727700577,-14.608250313909892,-14.624697900119207,-14.641145486328522,-14.657593072537837,-14.674040658747153,-14.690488244956466,-14.70693583116578,-14.723383417375096,-14.73983100358441,-14.756278589793725,-14.772726176003038,-14.788906564067442,-14.804953353059393,-14.82100014205134,-14.837046931043288,-14.853093720035236,-14.869140509027186,-14.885187298019135,-14.901234087011082,-14.91728087600303,-14.933327664994978,-14.949374453986927,-14.965421242978877,-14.981468031970826,-14.997514820962774,-15.013561609954722,-15.029608398946671,-15.04565518793862,-15.061701976930568,-15.077748765922514,-15.093795554914461,-15.109842343906411,-15.12588913289836,-15.141935921890308,-15.157982710882258,-15.174029499874205,-15.190076288866155,-15.206123077858104,-15.222169866850049,-15.238216655841999,-15.254263444833947,-15.270310233825898,-15.286357022817846,-15.302403811809793,-15.31845060080174,-15.334497389793691,-15.35054417878564,-15.366590967777586,-15.382637756769537,-15.398684545761483,-15.414731334753434,-15.43077812374538,-15.44682491273733,-15.462871701729277,-15.478918490721226,-15.494965279713174,-15.511012068705123,-15.527058857697071,-15.54310564668902,-15.559152435680968,-15.575199224672918,-15.591246013664867,-15.607292802656813,-15.623339591648763,-15.639386380640712,-15.655433169632659,-15.671479958624607,-15.687526747616557,-15.703573536608506,-15.719620325600452,-15.7356671145924,-15.75171390358435,-15.767760692576298,-15.783807481568246,-15.799854270560196,-15.815901059552143,-15.83194784854409,-15.847994637536042,-15.86404142652799,-15.880088215519937,-15.896135004511887,-15.912181793503834,-15.928228582495784,-15.94427537148773,-15.960322160479679,-15.976368949471627,-15.992415738463576,-16.008462527455524,-16.024509316447475,-16.04186697972804,-16.06007671435894,-16.07828644898984,-16.09649618362074,-16.11470591825164,-16.135017246682715,-16.157430168913972,-16.179843091145226,-16.20225601337648,-16.224668935607735,-16.24708185783899,-16.269494780070243,-16.291907702301504,-16.314320624532755,-16.336733546764005,-16.359146468995267,-16.3804335932165,-16.40149897193546,-16.422564350654426,-16.443629729373388,-16.46469510809235,-16.48576048681131,-16.506825865530274,-16.527891244249233,-16.5489566229682,-16.57002200168716,-16.591087380406123,-16.612152759125085,-16.633218137844047,-16.65428351656301,-16.67534889528197,-16.696414274000933,-16.7174796527199,-16.73854503143886,-16.759610410157823,-16.780675788876785,-16.801741167595747,-16.82280654631471,-16.84387192503367,-16.864937303752633,-16.8860026824716,-16.907068061190557,-16.92813343990952,-16.94919881862848,-16.970264197347444,-16.99132957606641,-17.012394954785368,-17.03346033350433,-17.054525712223295,-17.075591090942257,-17.09665646966122,-17.11772184838018,-17.138787227099147,-17.15985260581811,-17.180917984537068,-17.201983363256033,-17.223048741974996,-17.244114120693958,-17.26517949941292,-17.286244878131882,-17.307310256850844,-17.328375635569806,-17.34944101428877,-17.37050639300773,-17.391571771726692,-17.412637150445654,-17.433702529164616,-17.45476790788358,-17.475833286602544,-17.496898665321503,-17.51796404404047,-17.53902942275943,-17.560094801478392,-17.581160180197354,-17.602225558916317,-17.623290937635282,-17.64435631635424,-17.665421695073206,-17.686487073792165,-17.707552452511127,-17.72861783123009,-17.74968320994905,-17.770748588668013,-17.791813967386975,-17.812879346105937,-17.833944724824903,-17.855010103543865,-17.876075482262827,-17.889407104101686,-17.887271212180345,-17.885135320259,-17.882999428337655,-17.88086353641631,-17.87872764449497,-17.876591752573624,-17.874455860652283,-17.87231996873094,-17.870184076809597,-17.868048184888252,-17.86591229296691,-17.863776401045566,-17.86164050912422,-17.859504617202877,-17.857368725281532,-17.85523283336019,-17.85309694143885,-17.850961049517505,-17.84882515759616,-17.84668926567482,-17.844553373753474,-17.842417481832133,-17.840281589910788,-17.838145697989443,-17.8360098060681,-17.833873914146757,-17.831738022225412,-17.82960213030407,-17.827466238382726,-17.82533034646138,-17.82319445454004,-17.821058562618695,-17.818922670697354,-17.81678677877601,-17.814650886854665,-17.812514994933323,-17.810379103011982,-17.808243211090634,-17.806107319169293,-17.80397142724795,-17.801835535326607,-17.79969964340526,-17.797563751483917,-17.795427859562572,-17.79329196764123,-17.791156075719886,-17.789020183798545,-17.7868842918772,-17.784748399955856,-17.782612508034518,-17.780476616113173,-17.77834072419183,-17.776204832270484,-17.774068940349142,-17.770300689582893,-17.761877223140967,-17.75345375669904,-17.74503029025712,-17.736606823815194,-17.72818335737327,-17.719759890931346,-17.71133642448942,-17.702912958047495,-17.694489491605573,-17.686066025163647,-17.677642558721722,-17.669219092279796,-17.66079562583787,-17.652372159395945,-17.643948692954023,-17.6355252265121,-17.627101760070175,-17.61867829362825,-17.610254827186324,-17.6018313607444,-17.593407894302473,-17.58498442786055,-17.576560961418625,-17.5681374949767,-17.559714028534778,-17.551290562092852,-17.54286709565093,-17.5544399428494,-17.665994358249847,-17.777548773650295,-17.889103189050743,-18.00065760445117,-18.11221201985162,-18.223766435252067,-18.335320850652494,-18.446875266052945,-18.558429681453394,-18.669984096853824,-18.781538512254272,-18.89309292765472,-19.001503286441338,-19.087602125675907,-19.173700964910488,-19.259799804145075,-19.345898643379645,-19.43199748261423,-19.518096321848816,-19.604195161083382,-19.690294000317966,-19.77639283955255,-19.86249167878712,-19.948590518021703,-20.034689357256287,-20.120788196490874,-20.20688703572544,-20.292985874960024,-20.37908471419461,-20.465183553429178,-20.55128239266376,-20.63738123189835,-20.72348007113292,-20.809578910367502,-20.895677749602086,-20.98177658883667,-21.06787542807124,-21.153974267305827,-21.24007310654041,-21.326171945774977,-21.412270785009564,-21.34543141511707,-21.16935046727674,-20.99326951943637,-20.817188571596006,-20.641107623755676,-20.46502667591531,-20.288945728074946,-20.11286478023458,-19.936783832394248,-19.760702884553883,-19.584621936713518,-19.408540988873185,-19.23246004103282,-19.056379093192454,-18.880298145352125,-18.70421719751176,-18.528136249671395,-18.35205530183103,-18.175974353990696,-17.99989340615033,-17.823812458309966,-17.647731510469637,-17.47165056262927,-17.295569614788906,-17.119488666948573,-16.943407719108208,-16.767326771267847,-16.59124582342751,-16.41290699627868,-16.1845060151404,-15.956105034002123,-15.727704052863887,-15.49930307172561,-15.270902090587336,-15.042501109449098,-14.814100128310823,-14.585699147172546,-14.35729816603431,-14.128897184896037,-13.900496203757754,-13.672095222619479,-13.443694241481243],[-11.705021590479213,-11.723287469833252,-11.741553349187289,-11.759819228541327,-11.778085107895365,-11.796350987249404,-11.814616866603439,-11.832882745957477,-11.851148625311517,-11.869414504665555,-11.887680384019593,-11.905140011130136,-11.92098712896455,-11.93683424679896,-11.952681364633372,-11.968528482467784,-11.984375600302197,-12.000222718136609,-12.01606983597102,-12.031916953805434,-12.047764071639845,-12.063611189474257,-12.079458307308668,-12.095305425143081,-12.111152542977493,-12.126999660811904,-12.142846778646316,-12.158693896480727,-12.174541014315139,-12.19038813214955,-12.206235249983964,-12.222082367818377,-12.237929485652788,-12.2537766034872,-12.269623721321611,-12.285470839156023,-12.301317956990436,-12.317165074824848,-12.33301219265926,-12.34885931049367,-12.364706428328084,-12.380553546162496,-12.396400663996907,-12.412247781831319,-12.42809489966573,-12.443942017500142,-12.459789135334555,-12.475636253168968,-12.49148337100338,-12.507330488837791,-12.523177606672203,-12.539024724506614,-12.55487184234103,-12.570718960175437,-12.586566078009849,-12.602413195844262,-12.618260313678675,-12.634107431513087,-12.649954549347498,-12.665801667181912,-12.681648785016321,-12.697495902850736,-12.713343020685146,-12.72919013851956,-12.745037256353971,-12.760884374188384,-12.776731492022794,-12.792578609857205,-12.808425727691619,-12.82427284552603,-12.840119963360443,-12.855967081194855,-12.871814199029266,-12.887661316863678,-12.903508434698091,-12.919355552532503,-12.935202670366914,-12.951049788201326,-12.966896906035737,-12.98274402387015,-12.998591141704562,-13.014438259538975,-13.030285377373385,-13.046132495207797,-13.060242528953225,-13.074005145880854,-13.087767762808483,-13.101530379736113,-13.115292996663744,-13.129055613591373,-13.142818230519001,-13.156580847446634,-13.170343464374263,-13.184106081301895,-13.197868698229522,-13.211631315157152,-13.22539393208478,-13.23915654901241,-13.25291916594004,-13.26668178286767,-13.2804443997953,-13.29420701672293,-13.307969633650561,-13.321732250578192,-13.33549486750582,-13.34925748443345,-13.36302010136108,-13.376782718288709,-13.39054533521634,-13.404307952143967,-13.418070569071599,-13.431833185999228,-13.445595802926857,-13.459358419854489,-13.473121036782118,-13.486883653709747,-13.500646270637379,-13.514408887565008,-13.528171504492637,-13.541934121420267,-13.555696738347894,-13.569459355275526,-13.583221972203155,-13.596984589130784,-13.610747206058416,-13.624509822986045,-13.638272439913676,-13.652035056841306,-13.665797673768934,-13.679560290696564,-13.693322907624193,-13.707085524551825,-13.720848141479454,-13.734610758407083,-13.748373375334712,-13.76213599226234,-13.775898609189971,-13.789661226117602,-13.80342384304523,-13.817186459972861,-13.830949076900488,-13.84471169382812,-13.85847431075575,-13.872236927683378,-13.885999544611009,-13.89976216153864,-13.913524778466272,-13.927287395393899,-13.94105001232153,-13.954812629249158,-13.968575246176789,-13.982337863104421,-13.996100480032048,-14.009863096959677,-14.02362571388731,-14.037388330814936,-14.052045939275208,-14.068493525484524,-14.084941111693837,-14.101388697903152,-14.117836284112467,-14.134283870321783,-14.150731456531098,-14.167179042740411,-14.183626628949725,-14.20007421515904,-14.216521801368355,-14.232702189432759,-14.248748978424707,-14.264795767416656,-14.280842556408604,-14.296889345400551,-14.312936134392501,-14.32898292338445,-14.345029712376398,-14.361076501368348,-14.377123290360295,-14.393170079352243,-14.409216868344192,-14.42526365733614,-14.441310446328089,-14.457357235320037,-14.473404024311986,-14.489450813303934,-14.505497602295883,-14.521544391287833,-14.53759118027978,-14.55363796927173,-14.569684758263676,-14.585731547255627,-14.601778336247577,-14.617825125239522,-14.63387191423147,-14.649918703223417,-14.665965492215367,-14.682012281207315,-14.698059070199264,-14.71410585919121,-14.73015264818316,-14.746199437175111,-14.762246226167058,-14.778293015159006,-14.794339804150955,-14.810386593142903,-14.826433382134853,-14.841567736178273,-14.85662605281339,-14.871684369448506,-14.886742686083622,-14.901801002718738,-14.916859319353854,-14.93191763598897,-14.946975952624086,-14.962034269259203,-14.977092585894317,-14.992150902529435,-15.007209219164551,-15.022267535799667,-15.037325852434783,-15.0523841690699,-15.067442485705014,-15.082500802340128,-15.097559118975246,-15.112617435610362,-15.12767575224548,-15.142734068880594,-15.157792385515709,-15.172850702150825,-15.187909018785941,-15.202967335421059,-15.218025652056173,-15.23308396869129,-15.248142285326406,-15.263200601961522,-15.278258918596638,-15.293317235231754,-15.30837555186687,-15.323433868501986,-15.338492185137103,-15.353550501772219,-15.368608818407333,-15.383667135042451,-15.398725451677565,-15.413783768312681,-15.4288420849478,-15.443900401582916,-15.45895871821803,-15.474017034853148,-15.489075351488262,-15.504133668123377,-15.521769184056334,-15.54198189928713,-15.562194614517924,-15.582407329748717,-15.602620044979513,-15.622832760210308,-15.643045475441104,-15.6632581906719,-15.683470905902695,-15.70368362113349,-15.723896336364286,-15.744109051595082,-15.764321766825875,-15.784534482056669,-15.804747197287465,-15.82495991251826,-15.845172627749053,-15.865385342979849,-15.885598058210645,-15.905810773441438,-15.926023488672236,-15.94623620390303,-15.966448919133823,-15.98666163436462,-16.006874349595414,-16.027087064826212,-16.047299780057006,-16.0675124952878,-16.087725210518595,-16.10793792574939,-16.128150640980188,-16.148363356210986,-16.168576071441777,-16.18878878667257,-16.209001501903366,-16.22921421713416,-16.249426932364955,-16.269639647595753,-16.289852362826547,-16.31006507805734,-16.33027779328814,-16.35049050851893,-16.370703223749725,-16.390915938980523,-16.411128654211318,-16.43134136944211,-16.451554084672907,-16.471766799903705,-16.4919795151345,-16.51219223036529,-16.532404945596088,-16.552617660826883,-16.57342873639376,-16.594494115112717,-16.615559493831682,-16.63662487255064,-16.657690251269607,-16.678755629988572,-16.69982100870753,-16.720886387426493,-16.741951766145455,-16.76301714486442,-16.78408252358338,-16.805147902302345,-16.826213281021303,-16.847278659740265,-16.868344038459227,-16.889409417178193,-16.91047479589715,-16.931540174616117,-16.95260555333508,-16.97367093205404,-16.994736310773003,-17.015801689491965,-17.03686706821093,-17.05793244692989,-17.078997825648855,-17.100063204367814,-17.121128583086776,-17.142193961805738,-17.163259340524704,-17.184324719243666,-17.205390097962628,-17.218721719801486,-17.21658582788014,-17.214449935958797,-17.212314044037456,-17.210178152116114,-17.20804226019477,-17.205906368273425,-17.20377047635208,-17.20163458443074,-17.199498692509394,-17.197362800588053,-17.19522690866671,-17.193091016745363,-17.190955124824022,-17.18881923290268,-17.186683340981332,-17.18454744905999,-17.182411557138646,-17.1802756652173,-17.17813977329596,-17.17600388137462,-17.173867989453274,-17.17173209753193,-17.169596205610585,-17.16746031368924,-17.1653244217679,-17.163188529846558,-17.161052637925213,-17.15891674600387,-17.156780854082527,-17.154644962161182,-17.152509070239837,-17.150373178318493,-17.14823728639715,-17.146101394475807,-17.143965502554465,-17.141829610633124,-17.139693718711776,-17.137557826790434,-17.135421934869093,-17.13328604294775,-17.131150151026407,-17.129014259105062,-17.12687836718372,-17.124742475262373,-17.12260658334103,-17.120470691419687,-17.118334799498342,-17.116198907577,-17.114063015655656,-17.11192712373431,-17.109791231812974,-17.10765533989163,-17.105519447970284,-17.10338355604894,-17.101247664127598,-17.099746281977936,-17.098994794208625,-17.098243306439315,-17.097491818670004,-17.096740330900694,-17.095988843131387,-17.095237355362073,-17.094485867592763,-17.093734379823456,-17.092982892054145,-17.092231404284835,-17.091479916515524,-17.090728428746214,-17.0899769409769,-17.089225453207593,-17.088473965438283,-17.08772247766897,-17.086970989899662,-17.08621950213035,-17.08546801436104,-17.08471652659173,-17.08396503882242,-17.08321355105311,-17.0824620632838,-17.081710575514485,-17.08095908774518,-17.080207599975868,-17.093481084821914,-17.17687943274473,-17.26027778066755,-17.34367612859037,-17.427074476513173,-17.510472824435993,-17.593871172358813,-17.677269520281616,-17.760667868204436,-17.844066216127256,-17.92746456405006,-18.01086291197288,-18.094261259895696,-18.177659607818516,-18.26105795574132,-18.34445630366414,-18.42785465158696,-18.511252999509765,-18.594651347432585,-18.6780496953554,-18.761448043278207,-18.844846391201024,-18.928244739123844,-19.01164308704665,-19.095041434969467,-19.178439782892287,-19.261838130815107,-19.34523647873791,-19.428634826660726,-19.512033174583546,-19.595431522506352,-19.678829870429173,-19.764864413251857,-19.850963252486427,-19.93706209172101,-20.023160930955598,-20.109259770190178,-20.19535860942475,-20.281457448659335,-20.36755628789392,-20.453655127128485,-20.539753966363072,-20.472914596470577,-20.296833648630248,-20.12075270078988,-19.944671752949517,-19.768590805109184,-19.59250985726882,-19.416428909428454,-19.24034796158809,-19.06426701374776,-18.88818606590739,-18.71321681081947,-18.542972261279218,-18.37272771173893,-18.202483162198643,-18.032238612658382,-17.861994063118097,-17.69174951357781,-17.52150496403752,-17.351260414497265,-17.181015864956976,-17.010771315416687,-16.840526765876433,-16.670282216336144,-16.500037666795855,-16.329793117255598,-16.159548567715312,-15.989304018175023,-15.819059468634766,-15.648814919094477,-15.478570369554191,-15.308325820013902,-15.138081270473647,-14.96783672093336,-14.797592171393072,-14.627347621852813,-14.457103072312526,-14.286858522772238,-14.116613973231981,-13.946369423691696,-13.776124874151405,-13.605880324611118,-13.43563577507086],[-11.232187631477961,-11.245289159005898,-11.258390686533833,-11.27149221406177,-11.284593741589708,-11.297695269117646,-11.311254397649646,-11.327101515484058,-11.342948633318471,-11.358795751152883,-11.374642868987294,-11.390489986821708,-11.406337104656119,-11.422184222490529,-11.438031340324942,-11.453878458159354,-11.469725575993767,-11.485572693828177,-11.50141981166259,-11.517266929497001,-11.533114047331413,-11.548961165165826,-11.564808283000238,-11.580655400834651,-11.596502518669062,-11.612349636503472,-11.628196754337885,-11.644043872172297,-11.659890990006708,-11.675738107841122,-11.691585225675531,-11.707432343509947,-11.723279461344358,-11.73912657917877,-11.754973697013181,-11.770820814847593,-11.786667932682004,-11.802515050516417,-11.818362168350829,-11.834209286185242,-11.850056404019652,-11.865903521854065,-11.881750639688475,-11.897597757522888,-11.9134448753573,-11.929291993191711,-11.945139111026126,-11.960986228860534,-11.976833346694947,-11.99268046452936,-12.008527582363772,-12.024374700198184,-12.040221818032595,-12.056068935867007,-12.07191605370142,-12.087763171535832,-12.103610289370243,-12.119457407204656,-12.135304525039066,-12.151151642873478,-12.16699876070789,-12.182845878542302,-12.198692996376716,-12.214540114211125,-12.230387232045537,-12.24623434987995,-12.262081467714362,-12.277928585548775,-12.293775703383186,-12.309622821217598,-12.325469939052011,-12.341317056886421,-12.357164174720833,-12.373011292555246,-12.388858410389657,-12.40470552822407,-12.42055264605848,-12.436399763892892,-12.452246881727307,-12.468093999561718,-12.48394111739613,-12.499788235230541,-12.515635353064953,-12.531482470899366,-12.545592504644791,-12.559355121572423,-12.573117738500052,-12.586880355427681,-12.600642972355311,-12.61440558928294,-12.628168206210571,-12.641930823138201,-12.65569344006583,-12.669456056993461,-12.68321867392109,-12.69698129084872,-12.71074390777635,-12.72450652470398,-12.73826914163161,-12.752031758559237,-12.76579437548687,-12.779556992414498,-12.793319609342129,-12.80708222626976,-12.820844843197388,-12.834607460125017,-12.848370077052646,-12.862132693980277,-12.875895310907907,-12.889657927835536,-12.903420544763167,-12.917183161690796,-12.930945778618426,-12.944708395546055,-12.958471012473685,-12.972233629401316,-12.985996246328945,-12.999758863256574,-13.013521480184203,-13.027284097111835,-13.041046714039464,-13.054809330967093,-13.068571947894723,-13.082334564822354,-13.096097181749982,-13.109859798677611,-13.123622415605244,-13.137385032532872,-13.151147649460501,-13.164910266388132,-13.17867288331576,-13.192435500243391,-13.20619811717102,-13.219960734098652,-13.233723351026281,-13.24748596795391,-13.261248584881539,-13.27501120180917,-13.2887738187368,-13.30253643566443,-13.316299052592061,-13.33006166951969,-13.34382428644732,-13.357586903374951,-13.37134952030258,-13.38511213723021,-13.39887475415784,-13.41263737108547,-13.426399988013099,-13.440162604940728,-13.453925221868358,-13.467687838795989,-13.481450455723618,-13.495213072651246,-13.508975689578879,-13.522738306506506,-13.536500923434136,-13.550263540361767,-13.564026157289396,-13.577788774217026,-13.591551391144655,-13.603946545581596,-13.614974232308889,-13.626001919036183,-13.637029605763473,-13.648057292490767,-13.65908497921806,-13.671678102826524,-13.685053944875573,-13.698429786924626,-13.711805628973677,-13.725181471022726,-13.738557313071777,-13.751933155120827,-13.765308997169878,-13.778684839218927,-13.792060681267978,-13.8060189212062,-13.821077237841314,-13.83613555447643,-13.851193871111544,-13.866252187746662,-13.881310504381776,-13.896368821016894,-13.911427137652009,-13.926485454287125,-13.941543770922245,-13.956602087557357,-13.971660404192473,-13.98671872082759,-14.001777037462706,-14.016835354097823,-14.031893670732938,-14.046951987368054,-14.062010304003168,-14.077068620638286,-14.092126937273402,-14.107185253908517,-14.122243570543633,-14.13730188717875,-14.152360203813867,-14.167418520448983,-14.1824768370841,-14.197535153719215,-14.21259347035433,-14.227651786989446,-14.242710103624564,-14.257768420259676,-14.272826736894793,-14.287885053529909,-14.302943370165025,-14.318001686800143,-14.333060003435257,-14.348118320070375,-14.36317663670549,-14.378234953340606,-14.393293269975722,-14.408351586610838,-14.423409903245954,-14.43846821988107,-14.453526536516186,-14.468584853151302,-14.483643169786419,-14.498701486421535,-14.513759803056649,-14.528818119691767,-14.543876436326883,-14.558934752962,-14.573993069597115,-14.589051386232232,-14.604109702867348,-14.61916801950246,-14.634226336137578,-14.649284652772693,-14.664342969407812,-14.679401286042927,-14.694459602678043,-14.709517919313157,-14.724576235948273,-14.739634552583391,-14.754692869218506,-14.76975118585362,-14.784809502488738,-14.799867819123854,-14.81492613575897,-14.829984452394086,-14.845042769029202,-14.860101085664317,-14.875159402299435,-14.89021771893455,-14.907853234867506,-14.9280659500983,-14.948278665329095,-14.968491380559891,-14.988704095790686,-15.008916811021482,-15.029129526252275,-15.049342241483071,-15.069554956713867,-15.08976767194466,-15.109980387175456,-15.130193102406253,-15.150405817637047,-15.170618532867842,-15.190831248098638,-15.211043963329432,-15.231256678560227,-15.251469393791021,-15.271682109021816,-15.291894824252612,-15.312107539483407,-15.332320254714205,-15.352532969944997,-15.372745685175794,-15.392958400406588,-15.413171115637384,-15.433383830868175,-15.453596546098973,-15.473809261329766,-15.494021976560562,-15.514234691791357,-15.534447407022155,-15.554660122252947,-15.574872837483746,-15.59508555271454,-15.615298267945334,-15.635510983176129,-15.655723698406923,-15.675936413637718,-15.696149128868512,-15.716361844099309,-15.736574559330103,-15.7567872745609,-15.776999989791694,-15.79721270502249,-15.817425420253283,-15.83763813548408,-15.857850850714875,-15.878063565945668,-15.898276281176464,-15.91848899640726,-15.938701711638055,-15.95891442686885,-15.979127142099646,-15.999339857330442,-16.019552572561235,-16.03976528779203,-16.059978003022827,-16.08019071825362,-16.100403433484416,-16.12061614871521,-16.140828863946005,-16.1610415791768,-16.181254294407594,-16.20146700963839,-16.221679724869183,-16.241892440099978,-16.26210515533078,-16.28231787056157,-16.30034692874024,-16.318069190406277,-16.33579145207231,-16.353513713738348,-16.371235975404385,-16.38895823707042,-16.406680498736456,-16.424402760402494,-16.44212502206853,-16.459847283734565,-16.477569545400602,-16.495291807066643,-16.513014068732673,-16.53073633039871,-16.543814788335528,-16.54760563881391,-16.55139648929229,-16.555187339770672,-16.558978190249054,-16.562769040727435,-16.566559891205817,-16.5703507416842,-16.57414159216258,-16.57793244264096,-16.581723293119342,-16.585514143597727,-16.589304994076105,-16.593095844554487,-16.596886695032868,-16.600677545511253,-16.60446839598963,-16.608259246468016,-16.612050096946398,-16.615840947424775,-16.61963179790316,-16.619544661309334,-16.61879317354002,-16.618041685770713,-16.6172901980014,-16.616538710232092,-16.615787222462778,-16.61503573469347,-16.61428424692416,-16.61353275915485,-16.612781271385536,-16.61202978361623,-16.611278295846923,-16.61052680807761,-16.609775320308298,-16.609023832538988,-16.608272344769677,-16.607520857000367,-16.60676936923106,-16.606017881461746,-16.60526639369244,-16.604514905923125,-16.603763418153818,-16.603011930384504,-16.602260442615197,-16.601508954845887,-16.600757467076576,-16.600005979307262,-16.599254491537955,-16.59850300376864,-16.597751515999335,-16.597000028230024,-16.596248540460714,-16.595497052691403,-16.59474556492209,-16.59399407715278,-16.593242589383472,-16.592491101614158,-16.59173961384485,-16.590988126075537,-16.590236638306227,-16.589485150536916,-16.58873366276761,-16.587982174998295,-16.58723068722899,-16.586479199459678,-16.585727711690367,-16.584976223921057,-16.584224736151747,-16.583473248382436,-16.582721760613126,-16.581970272843815,-16.581218785074505,-16.580467297305194,-16.579715809535884,-16.578964321766573,-16.578212833997263,-16.577461346227953,-16.576709858458642,-16.57595837068933,-16.57520688292002,-16.57445539515071,-16.573703907381404,-16.586977392227446,-16.670375740150263,-16.753774088073083,-16.837172435995903,-16.92057078391871,-17.00396913184153,-17.087367479764346,-17.170765827687152,-17.254164175609972,-17.33756252353279,-17.42096087145559,-17.504359219378415,-17.587757567301228,-17.671155915224052,-17.754554263146854,-17.837952611069674,-17.92135095899249,-18.004749306915297,-18.088147654838117,-18.171546002760937,-18.25494435068374,-18.338342698606557,-18.421741046529377,-18.505139394452183,-18.588537742375,-18.671936090297823,-18.75533443822064,-18.81835927066419,-18.87209241432042,-18.92582555797665,-18.979558701632875,-19.033291845289106,-19.08702498894534,-19.14075813260156,-19.194491276257796,-19.248224419914024,-19.301957563570255,-19.355690707226483,-19.409423850882714,-19.463156994538945,-19.516890138195166,-19.570623281851397,-19.526164362213322,-19.411568254507923,-19.296972146802503,-19.182376039097086,-19.06777993139169,-18.953183823686274,-18.838587715980854,-18.72399160827544,-18.60939550057004,-18.494799392864625,-18.380203285159205,-18.26560717745381,-18.151011069748392,-18.036414962042972,-17.921818854337577,-17.78051788859033,-17.610273339050046,-17.440028789509753,-17.269784239969496,-17.09953969042921,-16.92929514088892,-16.759050591348668,-16.58880604180838,-16.41856149226809,-16.248316942727833,-16.078072393187544,-15.907827843647256,-15.737583294107,-15.567338744566714,-15.397094195026424,-15.226849645486137,-15.05660509594588,-14.886360546405593,-14.716115996865305,-14.545871447325048,-14.375626897784759,-14.20538234824447,-14.035137798704216,-13.864893249163927,-13.694648699623638,-13.524404150083353,-13.354159600543095],[-10.757815587847881,-10.770917115375818,-10.784018642903753,-10.79712017043169,-10.81022169795963,-10.823323225487567,-10.836424753015502,-10.849526280543438,-10.862627808071377,-10.875729335599313,-10.888830863127252,-10.901932390655189,-10.915033918183125,-10.928135445711062,-10.941236973239,-10.954338500766937,-10.967440028294874,-10.98054155582281,-10.993643083350747,-11.006744610878684,-11.01984613840662,-11.032947665934559,-11.046049193462494,-11.06098111669471,-11.076828234529124,-11.092675352363536,-11.108522470197947,-11.124369588032359,-11.14021670586677,-11.156063823701182,-11.171910941535595,-11.187758059370005,-11.20360517720442,-11.219452295038831,-11.235299412873243,-11.251146530707654,-11.266993648542066,-11.282840766376479,-11.298687884210889,-11.314535002045304,-11.330382119879713,-11.346229237714127,-11.362076355548538,-11.37792347338295,-11.393770591217361,-11.409617709051773,-11.425464826886186,-11.4413119447206,-11.457159062555009,-11.473006180389422,-11.488853298223834,-11.504700416058245,-11.520547533892657,-11.536394651727068,-11.552241769561482,-11.568088887395893,-11.583936005230306,-11.599783123064718,-11.61563024089913,-11.631477358733541,-11.647324476567952,-11.663171594402364,-11.679018712236777,-11.694865830071189,-11.710712947905602,-11.726560065740014,-11.742407183574423,-11.758254301408837,-11.774101419243248,-11.789948537077661,-11.805795654912073,-11.821642772746483,-11.837489890580896,-11.853337008415307,-11.86918412624972,-11.885031244084132,-11.900878361918545,-11.916725479752957,-11.932572597587368,-11.948419715421782,-11.964266833256193,-11.980113951090603,-11.995961068925016,-12.011808186759428,-12.025918220504852,-12.039680837432485,-12.053443454360112,-12.067206071287742,-12.080968688215371,-12.094731305143002,-12.108493922070632,-12.122256538998261,-12.136019155925892,-12.14978177285352,-12.163544389781151,-12.177307006708782,-12.19106962363641,-12.204832240564041,-12.218594857491672,-12.232357474419299,-12.246120091346928,-12.25988270827456,-12.273645325202189,-12.287407942129821,-12.30117055905745,-12.314933175985079,-12.328695792912708,-12.342458409840338,-12.356221026767969,-12.369983643695598,-12.383746260623226,-12.397508877550857,-12.411271494478488,-12.425034111406116,-12.438796728333747,-12.452559345261378,-12.466321962189006,-12.480084579116635,-12.493847196044264,-12.507609812971896,-12.521372429899525,-12.535135046827154,-12.548897663754786,-12.562660280682415,-12.576422897610044,-12.590185514537673,-12.603948131465303,-12.617710748392932,-12.631473365320565,-12.645235982248192,-12.658998599175824,-12.672761216103456,-12.686523833031085,-12.700286449958714,-12.714049066886343,-12.727811683813972,-12.741574300741602,-12.755336917669233,-12.769099534596862,-12.78286215152449,-12.796624768452121,-12.810387385379752,-12.82415000230738,-12.837912619235011,-12.851675236162642,-12.86270292504815,-12.873730611775443,-12.884758298502735,-12.895785985230027,-12.90681367195732,-12.917841358684614,-12.928869045411908,-12.939896732139196,-12.950924418866489,-12.961952105593781,-12.972979792321073,-12.984007479048369,-12.99503516577566,-13.006062852502952,-13.017090539230246,-13.028118225957538,-13.039145912684832,-13.050173599412124,-13.061201286139415,-13.072228972866709,-13.083256659594001,-13.094284346321293,-13.10687746992976,-13.120253311978809,-13.13362915402786,-13.147004996076909,-13.16038083812596,-13.17375668017501,-13.187132522224061,-13.200508364273112,-13.213884206322161,-13.227260048371212,-13.240635890420265,-13.254011732469314,-13.267387574518365,-13.280763416567414,-13.294139258616465,-13.307515100665515,-13.320890942714566,-13.334266784763617,-13.347642626812666,-13.361018468861715,-13.374394310910766,-13.387770152959819,-13.401145995008868,-13.414521837057919,-13.42789767910697,-13.441273521156017,-13.454649363205071,-13.46802520525412,-13.481401047303173,-13.494776889352222,-13.50815273140127,-13.521528573450322,-13.534904415499373,-13.548280257548422,-13.561656099597474,-13.575031941646522,-13.588407783695576,-13.601783625744623,-13.61515946779367,-13.628794154435727,-13.643852471070844,-13.65891078770596,-13.673969104341076,-13.689027420976192,-13.704085737611308,-13.719144054246424,-13.734202370881539,-13.749260687516657,-13.764319004151773,-13.779377320786889,-13.794435637422005,-13.80949395405712,-13.824552270692235,-13.839610587327352,-13.854668903962468,-13.869727220597584,-13.884785537232698,-13.899843853867816,-13.914902170502932,-13.929960487138048,-13.945018803773163,-13.960077120408279,-13.975135437043395,-13.990193753678511,-14.005252070313627,-14.020310386948745,-14.03536870358386,-14.050427020218978,-14.065485336854092,-14.080543653489208,-14.095601970124322,-14.11066028675944,-14.125718603394557,-14.140776920029673,-14.155835236664787,-14.170893553299905,-14.18595186993502,-14.201010186570135,-14.216068503205253,-14.231126819840368,-14.246185136475486,-14.2612434531106,-14.276301769745718,-14.293937285678672,-14.314150000909468,-14.334362716140262,-14.354575431371057,-14.374788146601853,-14.395000861832646,-14.41521357706344,-14.435426292294238,-14.455639007525033,-14.475851722755827,-14.496064437986625,-14.51627715321742,-14.536489868448212,-14.556702583679005,-14.576915298909805,-14.5971280141406,-14.617340729371392,-14.637553444602188,-14.657766159832983,-14.677978875063776,-14.698191590294574,-14.718404305525368,-14.738617020756163,-14.758829735986959,-14.779042451217755,-14.79925516644855,-14.819467881679344,-14.839680596910139,-14.859893312140933,-14.880106027371728,-14.900318742602526,-14.92053145783332,-14.940744173064113,-14.960956888294909,-14.981169603525705,-15.001382318756498,-15.021595033987294,-15.04180774921809,-15.062020464448885,-15.08223317967968,-15.102445894910474,-15.121720180169294,-15.139442441835332,-15.157164703501369,-15.174886965167403,-15.19260922683344,-15.210331488499477,-15.228053750165511,-15.245776011831548,-15.263498273497582,-15.281220535163621,-15.298942796829657,-15.31666505849569,-15.33438732016173,-15.352109581827765,-15.369831843493799,-15.38755410515984,-15.405276366825875,-15.42299862849191,-15.440720890157946,-15.458443151823984,-15.476165413490019,-15.493887675156056,-15.51160993682209,-15.529332198488127,-15.547054460154165,-15.564776721820198,-15.582498983486238,-15.600221245152271,-15.61794350681831,-15.635665768484346,-15.653388030150381,-15.671110291816417,-15.688832553482456,-15.70655481514849,-15.724277076814527,-15.741999338480564,-15.759721600146596,-15.777443861812635,-15.79516612347867,-15.812888385144706,-15.830610646810745,-15.84833290847678,-15.861411366413595,-15.86520221689198,-15.868993067370358,-15.872783917848743,-15.876574768327124,-15.880365618805504,-15.884156469283887,-15.887947319762269,-15.89173817024065,-15.89552902071903,-15.899319871197413,-15.903110721675795,-15.906901572154176,-15.910692422632557,-15.914483273110939,-15.91827412358932,-15.922064974067702,-15.925855824546083,-15.929646675024465,-15.933437525502846,-15.937228375981228,-15.94101922645961,-15.94481007693799,-15.948600927416372,-15.952391777894753,-15.956182628373135,-15.959973478851518,-15.963764329329898,-15.96755517980828,-15.97134603028666,-15.975136880765044,-15.978927731243424,-15.982718581721805,-15.986509432200188,-15.99030028267857,-15.994091133156951,-15.997881983635331,-16.001672834113712,-16.005463684592094,-16.009254535070475,-16.013045385548857,-16.01683623602724,-16.02062708650562,-16.024417936984005,-16.028208787462383,-16.031999637940764,-16.035790488419146,-16.039581338897527,-16.04337218937591,-16.047163039854293,-16.050953890332675,-16.054744740811053,-16.058535591289434,-16.06232644176782,-16.066117292246197,-16.069908142724582,-16.073698993202964,-16.077489843681345,-16.081280694159727,-16.08448443348107,-16.08373294571176,-16.082981457942445,-16.082229970173138,-16.081478482403828,-16.080726994634517,-16.079975506865207,-16.079224019095896,-16.078472531326586,-16.077721043557275,-16.076969555787965,-16.076218068018655,-16.075466580249344,-16.074715092480034,-16.073963604710723,-16.073212116941413,-16.072460629172102,-16.071709141402792,-16.07095765363348,-16.070206165864175,-16.069454678094864,-16.06870319032555,-16.067951702556243,-16.067200214786933,-16.080473699632975,-16.163872047555795,-16.247270395478616,-16.330668743401436,-16.414067091324238,-16.497465439247055,-16.580863787169875,-16.66426213509268,-16.7476604830155,-16.831058830938318,-16.913135896800643,-16.96686904045687,-17.020602184113105,-17.074335327769337,-17.128068471425557,-17.181801615081792,-17.235534758738023,-17.289267902394243,-17.343001046050478,-17.396734189706713,-17.45046733336293,-17.504200477019165,-17.557933620675396,-17.61166676433162,-17.665399907987855,-17.719133051644082,-17.772866195300313,-17.82659933895654,-17.880332482612772,-17.934065626269,-17.987798769925227,-18.041531913581455,-18.09526505723769,-18.14899820089391,-18.20273134455014,-18.256464488206372,-18.310197631862607,-18.363930775518828,-18.41766391917506,-18.471397062831294,-18.525130206487514,-18.57886335014375,-18.534404430505667,-18.41980832280027,-18.30521221509485,-18.190616107389438,-18.07601999968404,-17.961423891978622,-17.846827784273202,-17.732231676567785,-17.61763556886239,-17.50303946115697,-17.388443353451553,-17.273847245746158,-17.159251138040737,-17.04465503033532,-16.930058922629925,-16.81546281492451,-16.700866707219088,-16.58627059951367,-16.471674491808276,-16.357078384102856,-16.24248227639744,-16.127886168692044,-16.013290060986623,-15.898693953281207,-15.784097845575811,-15.669501737870391,-15.554905630164974,-15.440309522459579,-15.325713414754158,-15.211117307048745,-15.096521199343325,-14.975128921418113,-14.804884371877826,-14.634639822337537,-14.464395272797281,-14.294150723256994,-14.123906173716705,-13.953661624176448,-13.783417074636159,-13.613172525095873,-13.442927975555584,-13.272683426015329],[-10.283443544217807,-10.296545071745744,-10.30964659927368,-10.322748126801617,-10.335849654329554,-10.348951181857492,-10.362052709385427,-10.375154236913366,-10.388255764441302,-10.40135729196924,-10.414458819497177,-10.427560347025114,-10.44066187455305,-10.453763402080988,-10.466864929608924,-10.479966457136861,-10.493067984664798,-10.506169512192734,-10.519271039720673,-10.532372567248611,-10.545474094776548,-10.558575622304485,-10.571677149832421,-10.584778677360358,-10.597880204888295,-10.610981732416231,-10.624083259944168,-10.637184787472105,-10.650286315000043,-10.663387842527982,-10.676489370055918,-10.689590897583855,-10.70269242511179,-10.715793952639729,-10.728895480167665,-10.741997007695602,-10.755098535223539,-10.768200062751475,-10.781301590279412,-10.794860717905369,-10.81070783573978,-10.826554953574195,-10.842402071408603,-10.858249189243018,-10.87409630707743,-10.889943424911841,-10.905790542746255,-10.921637660580664,-10.937484778415076,-10.95333189624949,-10.9691790140839,-10.985026131918314,-11.000873249752726,-11.016720367587137,-11.032567485421549,-11.04841460325596,-11.064261721090373,-11.080108838924783,-11.095955956759195,-11.11180307459361,-11.12765019242802,-11.143497310262434,-11.159344428096844,-11.175191545931256,-11.191038663765669,-11.206885781600079,-11.222732899434492,-11.238580017268905,-11.254427135103315,-11.270274252937728,-11.286121370772142,-11.30196848860655,-11.317815606440965,-11.333662724275376,-11.34950984210979,-11.365356959944199,-11.38120407777861,-11.397051195613024,-11.412898313447437,-11.428745431281847,-11.44459254911626,-11.460439666950672,-11.476286784785085,-11.492133902619496,-11.506243936364921,-11.520006553292552,-11.53376917022018,-11.547531787147811,-11.56129440407544,-11.57505702100307,-11.588819637930701,-11.60258225485833,-11.61634487178596,-11.630107488713591,-11.643870105641218,-11.657632722568847,-11.67139533949648,-11.685157956424108,-11.698920573351737,-11.712683190279368,-11.726445807206998,-11.740208424134627,-11.753971041062258,-11.767733657989886,-11.781496274917517,-11.795258891845148,-11.809021508772776,-11.822784125700405,-11.836546742628036,-11.850309359555666,-11.864071976483295,-11.877834593410924,-11.891597210338556,-11.905359827266185,-11.919122444193814,-11.932885061121445,-11.946647678049075,-11.960410294976704,-11.974172911904333,-11.987935528831963,-12.001698145759594,-12.015460762687223,-12.029223379614852,-12.042985996542482,-12.056748613470113,-12.070511230397742,-12.084273847325372,-12.098036464253001,-12.110431617787416,-12.12145930451471,-12.132486991242002,-12.143514677969296,-12.154542364696589,-12.165570051423881,-12.17659773815117,-12.187625424878462,-12.198653111605758,-12.209680798333048,-12.220708485060342,-12.231736171787635,-12.242763858514927,-12.253791545242219,-12.264819231969511,-12.275846918696804,-12.286874605424096,-12.297902292151388,-12.308929978878684,-12.319957665605976,-12.330985352333268,-12.34201303906056,-12.353040725787853,-12.364068412515145,-12.375096099242437,-12.38612378596973,-12.397151472697024,-12.408179159424318,-12.419206846151607,-12.430234532878899,-12.441262219606191,-12.452289906333485,-12.463317593060777,-12.47434527978807,-12.485372966515364,-12.496400653242656,-12.507428339969948,-12.518456026697242,-12.529483713424533,-12.542076837032997,-12.555452679082048,-12.568828521131097,-12.58220436318015,-12.595580205229199,-12.608956047278252,-12.6223318893273,-12.635707731376352,-12.6490835734254,-12.662459415474451,-12.675835257523502,-12.689211099572553,-12.702586941621604,-12.715962783670655,-12.729338625719702,-12.742714467768755,-12.756090309817806,-12.769466151866855,-12.782841993915905,-12.796217835964956,-12.809593678014005,-12.822969520063058,-12.836345362112107,-12.849721204161158,-12.863097046210209,-12.876472888259258,-12.889848730308309,-12.90322457235736,-12.91660041440641,-12.929976256455461,-12.943352098504509,-12.956727940553561,-12.97010378260261,-12.983479624651661,-12.996855466700714,-13.010231308749763,-13.023607150798814,-13.036982992847864,-13.050358834896912,-13.063734676945964,-13.077110518995013,-13.090486361044064,-13.103862203093115,-13.117238045142166,-13.130613887191217,-13.143989729240268,-13.157365571289315,-13.170741413338368,-13.184117255387417,-13.197493097436467,-13.210868939485518,-13.22424478153457,-13.23762062358362,-13.25099646563267,-13.26437230768172,-13.277748149730773,-13.29112399177982,-13.304499833828872,-13.317875675877922,-13.331251517926972,-13.344627359976023,-13.358003202025072,-13.371379044074125,-13.384754886123174,-13.398130728172223,-13.411506570221274,-13.424882412270327,-13.438258254319376,-13.451634096368426,-13.466627704300379,-13.481686020935497,-13.496744337570611,-13.511802654205729,-13.526860970840843,-13.54191928747596,-13.556977604111076,-13.572035920746192,-13.587094237381308,-13.602152554016424,-13.61721087065154,-13.632269187286656,-13.647327503921774,-13.662385820556889,-13.680021336489844,-13.70023405172064,-13.720446766951435,-13.74065948218223,-13.760872197413024,-13.781084912643818,-13.801297627874613,-13.821510343105409,-13.841723058336203,-13.861935773566998,-13.882148488797794,-13.90236120402859,-13.922573919259385,-13.94278663449018,-13.960815693264392,-13.978537954930427,-13.996260216596465,-14.0139824782625,-14.031704739928536,-14.049427001594571,-14.067149263260607,-14.084871524926648,-14.10259378659268,-14.120316048258719,-14.138038309924754,-14.155760571590791,-14.173482833256827,-14.191205094922863,-14.208927356588898,-14.226649618254935,-14.244371879920973,-14.26209414158701,-14.279816403253042,-14.29753866491908,-14.315260926585117,-14.332983188251152,-14.350705449917188,-14.368427711583227,-14.38614997324926,-14.403872234915296,-14.421594496581333,-14.439316758247369,-14.457039019913406,-14.474761281579442,-14.49248354324548,-14.510205804911514,-14.527928066577552,-14.545650328243587,-14.563372589909623,-14.58109485157566,-14.598817113241697,-14.616539374907731,-14.634261636573768,-14.651983898239806,-14.669706159905841,-14.687428421571877,-14.705150683237914,-14.72287294490395,-14.740595206569985,-14.758317468236022,-14.77603972990206,-14.793761991568093,-14.811484253234129,-14.829206514900166,-14.846928776566203,-14.864651038232237,-14.882373299898276,-14.900095561564314,-14.917817823230347,-14.935540084896383,-14.95326234656242,-14.970984608228457,-14.988706869894491,-15.00642913156053,-15.024151393226564,-15.041873654892601,-15.059595916558637,-15.077318178224674,-15.09504043989071,-15.112762701556747,-15.130484963222784,-15.148207224888818,-15.165929486554855,-15.179007944491671,-15.182798794970054,-15.186589645448436,-15.190380495926817,-15.194171346405199,-15.197962196883578,-15.201753047361962,-15.205543897840343,-15.209334748318724,-15.213125598797106,-15.216916449275487,-15.220707299753869,-15.22449815023225,-15.228289000710632,-15.232079851189015,-15.235870701667395,-15.239661552145776,-15.24345240262416,-15.24724325310254,-15.25103410358092,-15.254824954059304,-15.258615804537687,-15.262406655016067,-15.266197505494448,-15.269988355972831,-15.273779206451213,-15.27757005692959,-15.281360907407976,-15.285151757886355,-15.288942608364737,-15.292733458843118,-15.2965243093215,-15.300315159799883,-15.304106010278264,-15.307896860756644,-15.311687711235026,-15.315478561713409,-15.31926941219179,-15.32306026267017,-15.326851113148551,-15.330641963626933,-15.334432814105314,-15.338223664583698,-15.342014515062077,-15.34580536554046,-15.349855666208136,-15.354741999689423,-15.359628333170711,-15.364514666651996,-15.369401000133283,-15.374287333614571,-15.379173667095856,-15.384060000577144,-15.38894633405843,-15.393832667539716,-15.398719001021004,-15.40360533450229,-15.408491667983577,-15.413378001464864,-15.418264334946151,-15.423150668427438,-15.428037001908722,-15.43292333539001,-15.437809668871296,-15.442696002352584,-15.44758233583387,-15.452468669315156,-15.457355002796444,-15.462241336277732,-15.467127669759016,-15.472014003240304,-15.476900336721592,-15.481786670202876,-15.486673003684166,-15.49155933716545,-15.496445670646736,-15.501332004128026,-15.50621833760931,-15.511104671090598,-15.515991004571886,-15.520877338053172,-15.525763671534458,-15.530650005015744,-15.543309655644077,-15.594835892007652,-15.646362128371226,-15.697888364734803,-15.749414601098367,-15.800940837461942,-15.852467073825515,-15.903993310189083,-15.955519546552656,-16.00704578291623,-16.058572019279794,-16.11009825564337,-16.161624492006943,-16.213150728370515,-16.264676964734083,-16.316203201097657,-16.367729437461232,-16.4192556738248,-16.47078191018837,-16.522308146551946,-16.57383438291551,-16.625360619279085,-16.676886855642657,-16.728413092006225,-16.7799393283698,-16.831465564733374,-16.88299180109695,-16.934518037460514,-16.98604427382409,-17.037570510187663,-17.089096746551228,-17.140622982914802,-17.192149219278377,-17.24367545564194,-17.295201692005516,-17.34672792836909,-17.398254164732666,-17.44978040109623,-17.501306637459805,-17.548997767075026,-17.574226020733484,-17.599454274391945,-17.573377489076954,-17.510654247352388,-17.446933718203297,-17.336342054404618,-17.22575039060596,-17.11515872680728,-17.0045670630086,-16.89397539920992,-16.78338373541127,-16.67279207161259,-16.56220040781391,-16.451608744015257,-16.341017080216577,-16.230425416417898,-16.11983375261924,-16.009242088820564,-15.898650425021884,-15.788058761223207,-15.677467097424547,-15.56687543362587,-15.456283769827191,-15.345692106028533,-15.235100442229857,-15.12450877843118,-15.013917114632521,-14.903325450833844,-14.792733787035164,-14.682142123236506,-14.571550459437827,-14.46095879563915,-14.350367131840473,-14.239775468041815,-14.129183804243137,-14.01859214044446,-13.908000476645801,-13.797408812847122,-13.686817149048444,-13.576225485249788,-13.46563382145111,-13.35504215765243,-13.244450493853753,-13.133858830055097],[-9.809071500587732,-9.82217302811567,-9.835274555643606,-9.848376083171543,-9.86147761069948,-9.874579138227418,-9.887680665755353,-9.900782193283291,-9.913883720811228,-9.926985248339165,-9.940086775867103,-9.953188303395038,-9.966289830922976,-9.979391358450913,-9.99249288597885,-10.005594413506788,-10.018695941034723,-10.031797468562662,-10.044898996090598,-10.058000523618535,-10.071102051146472,-10.08420357867441,-10.097305106202345,-10.110406633730284,-10.123508161258219,-10.136609688786157,-10.149711216314095,-10.162812743842032,-10.175914271369969,-10.189015798897906,-10.202117326425842,-10.21521885395378,-10.228320381481716,-10.241421909009654,-10.25452343653759,-10.267624964065527,-10.280726491593466,-10.293828019121403,-10.30692954664934,-10.320031074177276,-10.333132601705213,-10.34623412923315,-10.359335656761086,-10.372437184289025,-10.385538711816961,-10.398640239344898,-10.411741766872835,-10.424843294400771,-10.437944821928708,-10.451046349456647,-10.464147876984583,-10.47724940451252,-10.490350932040458,-10.503452459568393,-10.516553987096332,-10.529655514624269,-10.54458743695044,-10.560434554784852,-10.576281672619263,-10.592128790453675,-10.607975908288088,-10.6238230261225,-10.639670143956911,-10.655517261791323,-10.671364379625736,-10.687211497460147,-10.703058615294559,-10.71890573312897,-10.734752850963384,-10.750599968797795,-10.766447086632207,-10.78229420446662,-10.79814132230103,-10.813988440135441,-10.829835557969854,-10.845682675804266,-10.86152979363868,-10.87737691147309,-10.893224029307502,-10.909071147141916,-10.924918264976327,-10.940765382810737,-10.95661250064515,-10.972459618479563,-10.986569652224988,-11.000332269152619,-11.014094886080247,-11.027857503007876,-11.041620119935507,-11.055382736863136,-11.069145353790766,-11.082907970718397,-11.096670587646027,-11.110433204573656,-11.124195821501287,-11.137958438428917,-11.151721055356546,-11.165483672284177,-11.179246289211807,-11.193008906139436,-11.206771523067065,-11.220534139994694,-11.234296756922326,-11.248059373849955,-11.261821990777584,-11.275584607705214,-11.289347224632843,-11.303109841560474,-11.316872458488104,-11.330635075415733,-11.344397692343364,-11.358160309270993,-11.369187997253974,-11.380215683981268,-11.39124337070856,-11.402271057435852,-11.413298744163146,-11.424326430890437,-11.435354117617731,-11.446381804345023,-11.457409491072315,-11.468437177799608,-11.4794648645269,-11.490492551254192,-11.501520237981484,-11.512547924708777,-11.523575611436069,-11.534603298163361,-11.545630984890657,-11.556658671617948,-11.56768635834524,-11.578714045072534,-11.589741731799826,-11.600769418527118,-11.61179710525441,-11.622824791981703,-11.633852478708995,-11.64488016543629,-11.655907852163581,-11.666935538890874,-11.677963225618166,-11.68899091234546,-11.700018599072752,-11.711046285800045,-11.722073972527337,-11.73310165925463,-11.744129345981921,-11.755157032709215,-11.766184719436506,-11.7772124061638,-11.788240092891092,-11.799267779618383,-11.810295466345679,-11.82132315307297,-11.832350839800263,-11.843378526527555,-11.854406213254848,-11.86543389998214,-11.876461586709432,-11.887489273436724,-11.898516960164017,-11.909544646891309,-11.920572333618603,-11.931600020345895,-11.942627707073187,-11.953655393800481,-11.964683080527774,-11.977276204136238,-11.990652046185287,-12.004027888234338,-12.01740373028339,-12.030779572332438,-12.044155414381489,-12.05753125643054,-12.07090709847959,-12.084282940528642,-12.097658782577692,-12.111034624626743,-12.124410466675792,-12.137786308724843,-12.151162150773892,-12.164537992822943,-12.177913834871994,-12.191289676921045,-12.204665518970096,-12.218041361019145,-12.231417203068197,-12.244793045117245,-12.258168887166297,-12.271544729215346,-12.284920571264397,-12.298296413313448,-12.311672255362495,-12.32504809741155,-12.338423939460599,-12.351799781509651,-12.365175623558702,-12.37855146560775,-12.3919273076568,-12.405303149705851,-12.418678991754899,-12.432054833803953,-12.445430675853002,-12.458806517902053,-12.472182359951102,-12.485558202000151,-12.498934044049204,-12.512309886098253,-12.525685728147304,-12.539061570196356,-12.552437412245405,-12.565813254294456,-12.579189096343507,-12.592564938392556,-12.605940780441607,-12.619316622490658,-12.632692464539707,-12.646068306588758,-12.659444148637808,-12.67281999068686,-12.68619583273591,-12.69957167478496,-12.71294751683401,-12.726323358883059,-12.739699200932112,-12.753075042981163,-12.766450885030212,-12.779826727079262,-12.793202569128312,-12.806578411177364,-12.819954253226413,-12.832373851585139,-12.844278547105178,-12.85618324262522,-12.868087938145258,-12.879992633665301,-12.89189732918534,-12.903802024705382,-12.915706720225423,-12.92761141574546,-12.939516111265501,-12.951420806785542,-12.963325502305583,-12.975230197825624,-12.987134893345663,-12.999039588865703,-13.010944284385744,-13.022848979905785,-13.034753675425826,-13.046658370945865,-13.060241548831689,-13.075503209083298,-13.090764869334905,-13.106026529586511,-13.12128818983812,-13.136549850089727,-13.151811510341336,-13.167073170592943,-13.182334830844551,-13.197596491096157,-13.212858151347767,-13.228119811599376,-13.243381471850983,-13.25864313210259,-13.274418090125678,-13.292136242555562,-13.309854394985448,-13.327572547415336,-13.345290699845219,-13.363008852275104,-13.38072700470499,-13.398445157134876,-13.41616330956476,-13.433881461994648,-13.451599614424534,-13.469317766854418,-13.487035919284304,-13.504754071714189,-13.522472224144074,-13.54019037657396,-13.557908529003848,-13.575626681433734,-13.593344833863615,-13.6110629862935,-13.628781138723387,-13.646499291153273,-13.664217443583158,-13.681935596013046,-13.69965374844293,-13.717371900872813,-13.735090053302699,-13.752808205732586,-13.77052635816247,-13.788244510592357,-13.805962663022246,-13.823680815452125,-13.841398967882013,-13.859117120311899,-13.876835272741786,-13.894553425171669,-13.912271577601558,-13.92998973003144,-13.947707882461327,-13.96542603489121,-13.983144187321098,-14.000862339750984,-14.018580492180869,-14.036298644610756,-14.05401679704064,-14.071734949470523,-14.089453101900412,-14.107171254330297,-14.12488940676018,-14.142607559190068,-14.16032571161995,-14.178043864049837,-14.195762016479723,-14.21348016890961,-14.231198321339495,-14.24891647376938,-14.266634626199266,-14.284352778629152,-14.302070931059035,-14.319789083488923,-14.337507235918808,-14.355225388348693,-14.372943540778577,-14.390661693208463,-14.408379845638347,-14.426097998068236,-14.44381615049812,-14.461534302928007,-14.47925245535789,-14.49364041709083,-14.501367997429874,-14.50909557776892,-14.516823158107965,-14.524550738447012,-14.532278318786057,-14.540005899125099,-14.547733479464146,-14.555461059803191,-14.563188640142236,-14.570916220481282,-14.578643800820325,-14.58637138115937,-14.594098961498416,-14.601826541837463,-14.609554122176506,-14.61728170251555,-14.625009282854597,-14.632736863193642,-14.640464443532686,-14.648192023871733,-14.655919604210776,-14.663647184549824,-14.669357060881548,-14.674243394362833,-14.679129727844119,-14.684016061325405,-14.688902394806693,-14.69378872828798,-14.698675061769265,-14.703561395250553,-14.70844772873184,-14.713334062213129,-14.718220395694416,-14.723106729175703,-14.727993062656985,-14.732879396138273,-14.737765729619559,-14.742652063100847,-14.747538396582135,-14.75242473006342,-14.757311063544705,-14.762197397025993,-14.76708373050728,-14.771970063988569,-14.776856397469855,-14.78174273095114,-14.786629064432429,-14.791515397913713,-14.796401731395001,-14.801288064876287,-14.806174398357573,-14.811060731838861,-14.815947065320149,-14.820833398801433,-14.825719732282721,-14.830606065764009,-14.835492399245293,-14.840378732726581,-14.845265066207865,-14.850151399689157,-14.855037733170441,-14.859924066651729,-14.864810400133013,-14.869696733614301,-14.874583067095587,-14.879469400576877,-14.884355734058161,-14.889242067539449,-14.894128401020737,-14.899014734502021,-14.903901067983309,-14.908787401464597,-14.913673734945881,-14.918560068427167,-14.923446401908455,-14.928332735389743,-14.933219068871027,-14.938105402352313,-14.942991735833601,-14.94787806931489,-14.952764402796173,-14.957650736277461,-14.970310386905798,-15.02183662326937,-15.073362859632944,-15.124889095996519,-15.176415332360087,-15.227941568723658,-15.279467805087233,-15.3309940414508,-15.382520277814375,-15.434046514177949,-15.485572750541511,-15.537098986905086,-15.58862522326866,-15.640151459632236,-15.6916776959958,-15.743203932359375,-15.79473016872295,-15.846256405086516,-15.89778264145009,-15.949308877813664,-16.000835114177228,-16.052361350540803,-16.103887586904378,-16.155413823267942,-16.181737837776897,-16.20696609143536,-16.23219434509382,-16.257422598752278,-16.282650852410736,-16.307879106069194,-16.333107359727656,-16.358335613386117,-16.38356386704458,-16.408792120703033,-16.434020374361495,-16.459248628019957,-16.484476881678418,-16.509705135336873,-16.534933388995334,-16.560161642653796,-16.585389896312254,-16.610618149970712,-16.584541364655728,-16.52181812293116,-16.45909488120658,-16.396371639482,-16.333648397757432,-16.27092515603285,-16.208201914308273,-16.14547867258369,-16.08275543085912,-16.02003218913454,-15.957308947409963,-15.894585705685394,-15.831862463960814,-15.769139222236234,-15.706415980511668,-15.643692738787085,-15.580969497062505,-15.518246255337925,-15.445550404619146,-15.334958740820468,-15.224367077021792,-15.11377541322313,-15.003183749424455,-14.892592085625775,-14.782000421827119,-14.67140875802844,-14.560817094229762,-14.450225430431104,-14.339633766632424,-14.229042102833748,-14.11845043903507,-14.00785877523641,-13.897267111437735,-13.786675447639057,-13.676083783840397,-13.565492120041721,-13.454900456243042,-13.344308792444386,-13.233717128645708,-13.123125464847028,-13.01253380104835,-12.901942137249694],[-9.334699456957658,-9.347800984485595,-9.360902512013531,-9.374004039541468,-9.387105567069407,-9.400207094597343,-9.41330862212528,-9.426410149653217,-9.439511677181153,-9.452613204709092,-9.465714732237029,-9.478816259764965,-9.491917787292902,-9.505019314820839,-9.518120842348777,-9.531222369876714,-9.54432389740465,-9.557425424932587,-9.570526952460524,-9.583628479988462,-9.596730007516399,-9.609831535044336,-9.62293306257227,-9.63603459010021,-9.649136117628146,-9.662237645156084,-9.67533917268402,-9.688440700211956,-9.701542227739894,-9.714643755267833,-9.727745282795768,-9.740846810323706,-9.753948337851641,-9.767049865379581,-9.780151392907518,-9.793252920435455,-9.806354447963392,-9.819455975491326,-9.832557503019265,-9.8456590305472,-9.858760558075138,-9.871862085603077,-9.884963613131013,-9.89806514065895,-9.911166668186887,-9.924268195714825,-9.937369723242762,-9.950471250770699,-9.963572778298635,-9.976674305826572,-9.989775833354509,-10.002877360882446,-10.015978888410384,-10.02908041593832,-10.042181943466257,-10.055283470994194,-10.068384998522133,-10.08148652605007,-10.094588053578006,-10.107689581105943,-10.12079110863388,-10.133892636161818,-10.146994163689754,-10.16009569121769,-10.173197218745628,-10.186298746273565,-10.199400273801501,-10.212501801329438,-10.225603328857375,-10.238704856385313,-10.25180638391325,-10.264907911441187,-10.278467038161097,-10.294314155995508,-10.310161273829921,-10.326008391664333,-10.341855509498746,-10.357702627333158,-10.37354974516757,-10.389396863001982,-10.405243980836394,-10.421091098670804,-10.436938216505217,-10.452785334339628,-10.466895368085055,-10.480657985012687,-10.494420601940314,-10.508183218867945,-10.521945835795574,-10.535708452723204,-10.549471069650835,-10.563233686578464,-10.576996303506094,-10.590758920433723,-10.604521537361354,-10.616916689993241,-10.627944376720535,-10.638972063447827,-10.64999975017512,-10.661027436902412,-10.672055123629706,-10.683082810356998,-10.69411049708429,-10.705138183811583,-10.716165870538875,-10.727193557266167,-10.73822124399346,-10.749248930720753,-10.760276617448046,-10.771304304175338,-10.78233199090263,-10.793359677629923,-10.804387364357215,-10.815415051084509,-10.826442737811801,-10.837470424539093,-10.848498111266386,-10.859525797993678,-10.870553484720972,-10.881581171448264,-10.892608858175556,-10.903636544902849,-10.914664231630141,-10.925691918357433,-10.936719605084726,-10.947747291812018,-10.958774978539312,-10.969802665266602,-10.980830351993895,-10.991858038721189,-11.002885725448483,-11.013913412175775,-11.024941098903067,-11.035968785630358,-11.046996472357652,-11.058024159084944,-11.069051845812236,-11.08007953253953,-11.091107219266823,-11.102134905994115,-11.113162592721407,-11.1241902794487,-11.135217966175993,-11.146245652903284,-11.157273339630578,-11.16830102635787,-11.17932871308516,-11.190356399812453,-11.201384086539745,-11.21241177326704,-11.223439459994331,-11.234467146721625,-11.245494833448918,-11.256522520176208,-11.267550206903502,-11.278577893630795,-11.289605580358089,-11.30063326708538,-11.311660953812673,-11.322688640539965,-11.333716327267258,-11.34474401399455,-11.355771700721842,-11.366799387449136,-11.377827074176428,-11.38885476090372,-11.399882447631015,-11.412475571239478,-11.425851413288528,-11.43922725533758,-11.452603097386628,-11.46597893943568,-11.47935478148473,-11.49273062353378,-11.506106465582832,-11.51948230763188,-11.53285814968093,-11.546233991729983,-11.559609833779032,-11.572985675828082,-11.586361517877133,-11.599737359926182,-11.613113201975233,-11.626489044024286,-11.639864886073333,-11.653240728122386,-11.666616570171437,-11.679992412220484,-11.693368254269537,-11.706744096318587,-11.720119938367638,-11.733495780416689,-11.746871622465736,-11.759364777592614,-11.771269473112651,-11.783174168632696,-11.795078864152734,-11.806983559672775,-11.818888255192816,-11.830792950712855,-11.842697646232896,-11.854602341752937,-11.866507037272976,-11.878411732793015,-11.890316428313056,-11.902221123833097,-11.914125819353137,-11.926030514873178,-11.937935210393217,-11.949839905913258,-11.961744601433297,-11.973649296953338,-11.98555399247338,-11.997458687993419,-12.009363383513461,-12.0212680790335,-12.033172774553542,-12.045077470073583,-12.05698216559362,-12.068886861113663,-12.080791556633702,-12.092696252153743,-12.104600947673784,-12.116505643193822,-12.128410338713863,-12.140315034233904,-12.152219729753945,-12.164124425273984,-12.176029120794023,-12.187933816314066,-12.199838511834106,-12.211743207354147,-12.223647902874186,-12.235552598394227,-12.247457293914266,-12.259361989434307,-12.271266684954348,-12.28317138047439,-12.295076075994428,-12.30698077151447,-12.318885467034509,-12.330790162554548,-12.34269485807459,-12.354599553594632,-12.366504249114671,-12.37840894463471,-12.390313640154751,-12.402218335674792,-12.414123031194833,-12.426027726714873,-12.439610904600697,-12.454872564852305,-12.470134225103912,-12.48539588535552,-12.500657545607128,-12.515919205858737,-12.531180866110343,-12.54644252636195,-12.56170418661356,-12.576965846865164,-12.592227507116775,-12.607489167368382,-12.622750827619988,-12.638012487871599,-12.653274148123206,-12.668535808374813,-12.68379746862642,-12.699059128878028,-12.714320789129635,-12.729582449381242,-12.74484410963285,-12.76010576988446,-12.775367430136066,-12.790629090387675,-12.805890750639284,-12.82115241089089,-12.836414071142498,-12.851675731394106,-12.866937391645713,-12.882199051897322,-12.897460712148929,-12.912722372400538,-12.927984032652144,-12.943245692903753,-12.95850735315536,-12.97376901340697,-12.989030673658576,-13.004292333910184,-13.019553994161791,-13.034815654413396,-13.050077314665007,-13.065338974916614,-13.08060063516822,-13.098043805277147,-13.115761957707033,-13.133480110136915,-13.151198262566803,-13.168916414996689,-13.186634567426573,-13.204352719856459,-13.222070872286345,-13.23978902471623,-13.257507177146115,-13.275225329576003,-13.292943482005889,-13.310661634435771,-13.328379786865657,-13.346097939295545,-13.363816091725429,-13.381534244155313,-13.3992523965852,-13.416970549015085,-13.43468870144497,-13.452406853874857,-13.470125006304741,-13.487843158734627,-13.505561311164513,-13.523279463594399,-13.540997616024283,-13.558715768454169,-13.576433920884055,-13.594152073313941,-13.611870225743825,-13.629588378173711,-13.647306530603597,-13.665024683033483,-13.682742835463369,-13.700460987893253,-13.718179140323137,-13.735897292753023,-13.753615445182911,-13.771333597612795,-13.78905175004268,-13.803439711775619,-13.811167292114664,-13.818894872453708,-13.826622452792755,-13.8343500331318,-13.842077613470845,-13.849805193809889,-13.857532774148936,-13.86526035448798,-13.872987934827027,-13.88071551516607,-13.888443095505117,-13.89617067584416,-13.903898256183204,-13.911625836522251,-13.919353416861297,-13.927080997200342,-13.934808577539386,-13.94253615787843,-13.950263738217476,-13.957991318556521,-13.965718898895567,-13.97344647923461,-13.981174059573657,-13.9889016399127,-13.996629220251748,-14.004356800590793,-14.012084380929837,-14.019811961268882,-14.027539541607927,-14.035267121946973,-14.042994702286018,-14.050722282625063,-14.058449862964109,-14.066177443303152,-14.073905023642197,-14.081632603981245,-14.089360184320288,-14.097087764659335,-14.104815344998379,-14.112542925337424,-14.12027050567647,-14.127998086015513,-14.13572566635456,-14.143453246693605,-14.15118082703265,-14.158908407371696,-14.16663598771074,-14.174363568049786,-14.18209114838883,-14.189818728727875,-14.197546309066922,-14.205273889405964,-14.213001469745011,-14.220729050084055,-14.228456630423102,-14.236184210762145,-14.243911791101192,-14.251639371440236,-14.259366951779281,-14.267094532118325,-14.274822112457372,-14.282549692796415,-14.29027727313546,-14.296697464876017,-14.301583798357305,-14.306470131838594,-14.311356465319879,-14.316242798801166,-14.32112913228245,-14.326015465763739,-14.330901799245026,-14.335788132726313,-14.3406744662076,-14.345560799688887,-14.350447133170173,-14.35533346665146,-14.360219800132747,-14.365106133614033,-14.36999246709532,-14.374878800576605,-14.379765134057893,-14.384651467539179,-14.397311118167515,-14.44883735453109,-14.500363590894663,-14.551889827258238,-14.603416063621802,-14.654942299985377,-14.706468536348952,-14.757994772712516,-14.789249654820312,-14.814477908478771,-14.839706162137228,-14.86493441579569,-14.890162669454151,-14.915390923112612,-14.940619176771069,-14.96584743042953,-14.991075684087992,-15.016303937746448,-15.041532191404908,-15.06676044506337,-15.091988698721828,-15.11721695238029,-15.14244520603875,-15.167673459697209,-15.192901713355669,-15.218129967014129,-15.24335822067259,-15.268586474331045,-15.293814727989506,-15.319042981647968,-15.344271235306426,-15.369499488964884,-15.394727742623349,-15.419955996281805,-15.445184249940265,-15.470412503598727,-15.495640757257188,-15.520869010915646,-15.546097264574106,-15.571325518232566,-15.596553771891022,-15.621782025549486,-15.595705240234498,-15.532981998509928,-15.470258756785347,-15.407535515060768,-15.344812273336201,-15.282089031611621,-15.219365789887041,-15.156642548162461,-15.093919306437892,-15.031196064713312,-14.968472822988733,-14.905749581264164,-14.843026339539586,-14.780303097815004,-14.717579856090438,-14.654856614365855,-14.592133372641278,-14.529410130916697,-14.466686889192129,-14.403963647467545,-14.341240405742969,-14.278517164018398,-14.21579392229382,-14.15307068056924,-14.09034743884467,-14.02762419712009,-13.964900955395509,-13.902177713670943,-13.839454471946363,-13.776731230221783,-13.714007988497201,-13.651284746772635,-13.588561505048055,-13.525838263323473,-13.444167091034995,-13.333575427236315,-13.22298376343764,-13.112392099638981,-13.001800435840305,-12.891208772041626,-12.780617108242947,-12.67002544444429],[-8.859564718184101,-8.869694788534172,-8.879824858884241,-8.88995492923431,-8.90008499958438,-8.91021506993445,-8.922821354983114,-8.93592288251105,-8.949024410038987,-8.962125937566926,-8.975227465094862,-8.9883289926228,-9.001430520150736,-9.014532047678674,-9.027633575206611,-9.040735102734548,-9.053836630262484,-9.066938157790421,-9.080039685318358,-9.093141212846296,-9.106242740374231,-9.11934426790217,-9.132445795430106,-9.145547322958043,-9.158648850485982,-9.171750378013918,-9.184851905541853,-9.197953433069792,-9.211054960597728,-9.224156488125665,-9.237258015653602,-9.250359543181538,-9.263461070709477,-9.276562598237414,-9.28966412576535,-9.302765653293287,-9.315867180821224,-9.328968708349162,-9.342070235877099,-9.355171763405036,-9.368273290932972,-9.381374818460909,-9.394476345988846,-9.407577873516784,-9.42067940104472,-9.43378092857266,-9.446882456100596,-9.459983983628533,-9.47308551115647,-9.486187038684406,-9.499288566212343,-9.51239009374028,-9.525491621268218,-9.538593148796153,-9.55169467632409,-9.564796203852028,-9.577897731379966,-9.590999258907903,-9.60410078643584,-9.617202313963777,-9.630303841491713,-9.64340536901965,-9.656506896547587,-9.669608424075523,-9.682709951603462,-9.695811479131399,-9.708913006659335,-9.722014534187272,-9.735116061715209,-9.748217589243147,-9.761319116771082,-9.77442064429902,-9.787522171826957,-9.800623699354894,-9.813725226882832,-9.826826754410769,-9.839928281938706,-9.853029809466642,-9.86613133699458,-9.879232864522516,-9.892334392050454,-9.905435919578391,-9.918537447106328,-9.931638974634264,-9.940696906412864,-9.948946119041596,-9.957195331670327,-9.965444544299059,-9.97369375692779,-9.983795285981014,-9.994822972708306,-10.0058506594356,-10.016878346162892,-10.027906032890185,-10.038933719617477,-10.049961406344769,-10.060989093072063,-10.072016779799355,-10.083044466526648,-10.09407215325394,-10.105099839981232,-10.116127526708526,-10.127155213435818,-10.13818290016311,-10.149210586890401,-10.160238273617695,-10.171265960344988,-10.18229364707228,-10.193321333799574,-10.204349020526866,-10.215376707254158,-10.22640439398145,-10.237432080708743,-10.248459767436035,-10.259487454163327,-10.27051514089062,-10.281542827617914,-10.292570514345206,-10.303598201072498,-10.314625887799792,-10.325653574527085,-10.336681261254377,-10.347708947981669,-10.358736634708961,-10.369764321436254,-10.380792008163546,-10.39181969489084,-10.40284738161813,-10.413875068345424,-10.424902755072717,-10.435930441800007,-10.446958128527301,-10.457985815254595,-10.469013501981888,-10.48004118870918,-10.491068875436472,-10.502096562163764,-10.513124248891057,-10.524151935618349,-10.535179622345643,-10.546207309072933,-10.557234995800227,-10.568262682527521,-10.579290369254812,-10.590318055982106,-10.601345742709398,-10.61237342943669,-10.623401116163983,-10.634428802891275,-10.645456489618569,-10.65648417634586,-10.667511863073154,-10.678539549800446,-10.68956723652774,-10.700594923255032,-10.711622609982324,-10.722650296709615,-10.733677983436907,-10.744705670164201,-10.755733356891493,-10.766761043618786,-10.777788730346078,-10.78881641707337,-10.799844103800664,-10.810871790527957,-10.821899477255249,-10.832927163982541,-10.84372263118501,-10.854401988625062,-10.865081346065114,-10.875760703505168,-10.886440060945223,-10.897119418385277,-10.907798775825327,-10.918478133265383,-10.929157490705437,-10.93983684814549,-10.950516205585544,-10.961195563025598,-10.972068396081058,-10.983973091601095,-10.995877787121136,-11.007782482641177,-11.019687178161218,-11.031591873681258,-11.043496569201299,-11.05540126472134,-11.067305960241379,-11.079210655761418,-11.091115351281458,-11.1030200468015,-11.11492474232154,-11.12682943784158,-11.138734133361622,-11.15063882888166,-11.162543524401704,-11.174448219921741,-11.18635291544178,-11.198257610961821,-11.210162306481863,-11.222067002001904,-11.233971697521945,-11.245876393041984,-11.257781088562023,-11.269685784082064,-11.281590479602105,-11.293495175122144,-11.305399870642185,-11.317304566162225,-11.329209261682266,-11.341113957202307,-11.353018652722348,-11.364923348242387,-11.376828043762426,-11.388732739282469,-11.400637434802508,-11.41254213032255,-11.424446825842589,-11.436351521362628,-11.448256216882669,-11.46016091240271,-11.472065607922751,-11.483970303442792,-11.49587499896283,-11.507779694482872,-11.519684390002912,-11.531589085522953,-11.543493781042994,-11.555398476563031,-11.567303172083074,-11.579207867603113,-11.591112563123154,-11.603017258643195,-11.614921954163234,-11.626826649683274,-11.638731345203317,-11.650636040723356,-11.662540736243397,-11.674445431763436,-11.686350127283477,-11.698254822803516,-11.710159518323557,-11.722064213843598,-11.733968909363636,-11.745873604883677,-11.757778300403718,-11.769682995923759,-11.7815876914438,-11.793492386963841,-11.80539708248388,-11.818980260369703,-11.834241920621313,-11.84950358087292,-11.864765241124527,-11.880026901376137,-11.895288561627744,-11.910550221879351,-11.92581188213096,-11.941073542382568,-11.956335202634174,-11.971596862885782,-11.986858523137391,-12.002120183389,-12.017381843640607,-12.032643503892213,-12.047905164143822,-12.063166824395427,-12.078428484647038,-12.093690144898645,-12.108951805150252,-12.124213465401859,-12.139475125653467,-12.154736785905074,-12.169998446156683,-12.185260106408293,-12.2005217666599,-12.215783426911507,-12.231045087163114,-12.246306747414721,-12.26156840766633,-12.276830067917938,-12.292091728169545,-12.307353388421154,-12.322615048672763,-12.33787670892437,-12.353138369175976,-12.368400029427583,-12.383661689679194,-12.398923349930799,-12.414185010182406,-12.429446670434015,-12.444708330685621,-12.459969990937228,-12.475231651188839,-12.490493311440446,-12.505754971692053,-12.521016631943661,-12.53627829219527,-12.551539952446877,-12.566801612698484,-12.582063272950093,-12.597324933201701,-12.612586593453308,-12.627848253704917,-12.643109913956526,-12.65837157420813,-12.673633234459741,-12.688894894711348,-12.704156554962955,-12.719418215214562,-12.734679875466172,-12.749941535717777,-12.765203195969386,-12.780464856220995,-12.795726516472602,-12.81098817672421,-12.826249836975817,-12.841511497227426,-12.856773157479031,-12.872034817730642,-12.88729647798225,-12.90395136799873,-12.921669520428614,-12.939387672858501,-12.957105825288386,-12.974823977718271,-12.992542130148157,-13.010260282578042,-13.027978435007926,-13.045696587437813,-13.063414739867701,-13.081132892297584,-13.09885104472747,-13.113239006460407,-13.120966586799453,-13.128694167138498,-13.136421747477542,-13.144149327816587,-13.151876908155634,-13.15960448849468,-13.167332068833725,-13.175059649172768,-13.182787229511813,-13.190514809850859,-13.198242390189904,-13.205969970528951,-13.213697550867995,-13.22142513120704,-13.229152711546085,-13.23688029188513,-13.244607872224176,-13.25233545256322,-13.260063032902265,-13.26779061324131,-13.275518193580357,-13.2832457739194,-13.290973354258448,-13.298700934597491,-13.306428514936535,-13.314156095275582,-13.321883675614629,-13.329611255953669,-13.337338836292716,-13.345066416631761,-13.352793996970806,-13.360521577309852,-13.368249157648899,-13.375976737987944,-13.383704318326986,-13.391431898666033,-13.399205368627358,-13.407538664341715,-13.41587196005607,-13.424205255770426,-13.432538551484782,-13.440871847199137,-13.449205142913494,-13.45753843862785,-13.465871734342207,-13.474205030056561,-13.482538325770918,-13.490871621485272,-13.499204917199629,-13.507538212913984,-13.51587150862834,-13.524204804342697,-13.532538100057053,-13.54087139577141,-13.549204691485762,-13.557537987200119,-13.565871282914475,-13.57420457862883,-13.582537874343188,-13.590871170057543,-13.5992044657719,-13.607537761486256,-13.61587105720061,-13.624204352914965,-13.632537648629322,-13.640870944343678,-13.649204240058033,-13.65753753577239,-13.665870831486746,-13.6742041272011,-13.682537422915455,-13.690870718629812,-13.699204014344168,-13.707537310058523,-13.71587060577288,-13.724203901487236,-13.73253719720159,-13.740870492915947,-13.749203788630304,-13.757537084344658,-13.765870380059013,-13.774203675773371,-13.785167881551653,-13.80928663764957,-13.833405393747489,-13.857524149845407,-13.88164290594332,-13.905761662041238,-13.929880418139156,-13.953999174237069,-13.978117930334989,-14.002236686432905,-14.02635544253082,-14.050474198628736,-14.074592954726656,-14.098711710824572,-14.122830466922487,-14.146949223020403,-14.171067979118323,-14.195186735216236,-14.219305491314152,-14.243424247412072,-14.267543003509985,-14.291661759607903,-14.315780515705823,-14.339899271803732,-14.364018027901652,-14.38813678399957,-14.412255540097487,-14.436374296195401,-14.46049305229332,-14.484611808391238,-14.508730564489149,-14.532849320587069,-14.556968076684985,-14.5810868327829,-14.605205588880818,-14.629324344978736,-14.640648445204693,-14.646907462834934,-14.653166480465178,-14.659425498095418,-14.66568451572566,-14.671943533355904,-14.657234746885752,-14.627548957486763,-14.597863168087768,-14.568177378688773,-14.538491589289785,-14.508805799890789,-14.465036169674251,-14.404071728229402,-14.343107286784564,-14.282142845339715,-14.221178403894864,-14.160213962450026,-14.099249521005177,-14.038285079560328,-13.97732063811549,-13.91635619667064,-13.85539175522579,-13.79442731378094,-13.733462872336105,-13.672498430891252,-13.611533989446404,-13.550569548001565,-13.489605106556716,-13.428640665111867,-13.367676223667027,-13.30671178222218,-13.24574734077733,-13.184782899332491,-13.12381845788764,-13.062854016442792,-13.001889574997943,-12.940925133553105,-12.879960692108254,-12.818996250663407,-12.758031809218568,-12.697067367773718,-12.636102926328869,-12.57513848488403,-12.514174043439183,-12.453209601994331,-12.392245160549482,-12.331280719104644],[-8.382756970623477,-8.392887040973546,-8.403017111323615,-8.413147181673684,-8.423277252023754,-8.433407322373824,-8.443537392723893,-8.453667463073963,-8.463797533424033,-8.473927603774102,-8.484057674124172,-8.49418774447424,-8.50431781482431,-8.51444788517438,-8.52457795552445,-8.534708025874519,-8.544838096224588,-8.554968166574659,-8.565098236924728,-8.575228307274797,-8.585358377624866,-8.595488447974937,-8.606609003944376,-8.619710531472315,-8.632812059000251,-8.645913586528188,-8.659015114056125,-8.672116641584061,-8.685218169112,-8.698319696639935,-8.711421224167873,-8.72452275169581,-8.737624279223747,-8.750725806751685,-8.76382733427962,-8.776928861807558,-8.790030389335495,-8.803131916863432,-8.816233444391369,-8.829334971919305,-8.842436499447242,-8.855538026975179,-8.868639554503119,-8.881741082031054,-8.89484260955899,-8.907944137086929,-8.921045664614866,-8.934147192142802,-8.947248719670739,-8.960350247198676,-8.973451774726614,-8.98655330225455,-8.999654829782488,-9.012756357310424,-9.025857884838361,-9.038959412366298,-9.052060939894234,-9.065162467422173,-9.07826399495011,-9.091365522478046,-9.104467050005983,-9.11756857753392,-9.130670105061858,-9.143771632589795,-9.156873160117732,-9.169974687645668,-9.183076215173605,-9.196177742701542,-9.20927927022948,-9.222380797757417,-9.235482325285354,-9.24858385281329,-9.261685380341229,-9.274786907869165,-9.2878884353971,-9.30098996292504,-9.314091490452975,-9.327193017980914,-9.34029454550885,-9.353396073036787,-9.366497600564724,-9.37959912809266,-9.3927006556206,-9.405802183148536,-9.414860114927134,-9.423109327555865,-9.431358540184597,-9.439607752813329,-9.44785696544206,-9.45610617807079,-9.464355390699524,-9.472604603328254,-9.480853815956987,-9.489103028585717,-9.49735224121445,-9.50560145384318,-9.513850666471914,-9.522099879100644,-9.530349091729377,-9.538598304358107,-9.546847516986839,-9.55509672961557,-9.563345942244302,-9.571595154873034,-9.579844367501764,-9.588556659047258,-9.59958434577455,-9.610612032501844,-9.621639719229139,-9.632667405956429,-9.643695092683721,-9.654722779411014,-9.665750466138308,-9.6767781528656,-9.687805839592892,-9.698833526320184,-9.709861213047478,-9.72088889977477,-9.731916586502063,-9.742944273229355,-9.753971959956647,-9.764999646683941,-9.776027333411234,-9.787055020138526,-9.798082706865818,-9.80911039359311,-9.820138080320405,-9.831165767047695,-9.842193453774989,-9.853221140502281,-9.864248827229574,-9.875276513956866,-9.886304200684158,-9.89733188741145,-9.908359574138744,-9.919387260866037,-9.930414947593329,-9.941442634320621,-9.952470321047915,-9.963498007775208,-9.9745256945025,-9.985553381229792,-9.996581067957084,-10.007608754684377,-10.018636441411669,-10.029664128138961,-10.040691814866255,-10.05171950159355,-10.06274718832084,-10.073774875048134,-10.084802561775426,-10.095830248502718,-10.10685793523001,-10.117885621957303,-10.128913308684595,-10.139940995411887,-10.15096868213918,-10.161996368866472,-10.173024055593764,-10.184051742321058,-10.19507942904835,-10.206107115775643,-10.217134802502937,-10.228162489230227,-10.239190175957521,-10.250217862684813,-10.261245549412106,-10.272041016614573,-10.282720374054627,-10.29339973149468,-10.304079088934733,-10.314758446374787,-10.325437803814841,-10.336117161254894,-10.346796518694948,-10.357475876135004,-10.368155233575054,-10.37883459101511,-10.389513948455162,-10.400193305895217,-10.41087266333527,-10.421552020775323,-10.432231378215377,-10.442910735655431,-10.453590093095485,-10.464269450535538,-10.474948807975592,-10.485628165415644,-10.4963075228557,-10.506986880295752,-10.517666237735806,-10.52834559517586,-10.539024952615913,-10.549704310055967,-10.560383667496021,-10.571063024936075,-10.581742382376127,-10.592421739816182,-10.603101097256236,-10.61378045469629,-10.624459812136342,-10.635139169576398,-10.645818527016448,-10.656497884456503,-10.667177241896557,-10.67785659933661,-10.688535956776665,-10.699215314216719,-10.70989467165677,-10.720574029096825,-10.731253386536878,-10.741932743976932,-10.752612101416986,-10.76329145885704,-10.773970816297094,-10.784650173737148,-10.795329531177202,-10.806008888617255,-10.816688246057307,-10.827625572651671,-10.83953026817171,-10.851434963691752,-10.863339659211793,-10.875244354731834,-10.887149050251873,-10.899053745771914,-10.910958441291955,-10.922863136811994,-10.934767832332033,-10.946672527852076,-10.958577223372115,-10.970481918892157,-10.982386614412196,-10.994291309932237,-11.006196005452278,-11.018100700972317,-11.030005396492358,-11.041910092012397,-11.053814787532437,-11.06571948305248,-11.07762417857252,-11.089528874092558,-11.101433569612599,-11.11333826513264,-11.12524296065268,-11.137147656172719,-11.149052351692761,-11.1609570472128,-11.172861742732842,-11.184766438252883,-11.198349616138705,-11.213611276390315,-11.228872936641922,-11.244134596893527,-11.259396257145138,-11.274657917396746,-11.289919577648352,-11.30518123789996,-11.320442898151569,-11.335704558403176,-11.350966218654783,-11.366227878906393,-11.381489539158,-11.396751199409607,-11.412012859661214,-11.427274519912823,-11.442536180164431,-11.457797840416038,-11.473059500667645,-11.488321160919254,-11.503582821170863,-11.51884448142247,-11.534106141674076,-11.549367801925685,-11.564629462177294,-11.5798911224289,-11.595152782680508,-11.610414442932116,-11.625676103183725,-11.640937763435332,-11.656199423686939,-11.67146108393855,-11.686722744190154,-11.701984404441763,-11.717246064693374,-11.732507724944977,-11.747769385196586,-11.763031045448194,-11.778292705699801,-11.793554365951408,-11.808816026203017,-11.824077686454626,-11.839339346706232,-11.85460100695784,-11.86986266720945,-11.885124327461053,-11.900385987712664,-11.915647647964272,-11.930105299729924,-11.944170752897048,-11.958236206064171,-11.972301659231295,-11.98636711239842,-12.000432565565545,-12.01449801873267,-12.02856347189979,-12.042628925066914,-12.056694378234038,-12.070759831401164,-12.08482528456829,-12.098890737735411,-12.112956190902535,-12.127021644069659,-12.141087097236783,-12.155152550403908,-12.169218003571032,-12.183283456738156,-12.197348909905282,-12.211414363072404,-12.225479816239528,-12.239545269406651,-12.253610722573775,-12.267676175740899,-12.281741628908023,-12.295807082075147,-12.309872535242269,-12.323937988409396,-12.338003441576518,-12.352068894743642,-12.366134347910766,-12.380199801077891,-12.394265254245013,-12.408330707412137,-12.420916707866601,-12.43054380289574,-12.440170897924876,-12.449797992954014,-12.459425087983153,-12.469052183012293,-12.478679278041431,-12.48830637307057,-12.497933468099708,-12.507560563128846,-12.517187658157985,-12.526814753187123,-12.536441848216262,-12.546068943245402,-12.555696038274537,-12.565323133303679,-12.574950228332817,-12.584577323361955,-12.594204418391092,-12.603831513420232,-12.61345860844937,-12.62308570347851,-12.632712798507647,-12.642339893536786,-12.651966988565926,-12.661248071084714,-12.669581366799068,-12.677914662513427,-12.686247958227781,-12.694581253942138,-12.702914549656494,-12.711247845370849,-12.719581141085206,-12.727914436799562,-12.736247732513917,-12.744581028228273,-12.75291432394263,-12.761247619656984,-12.76958091537134,-12.777914211085697,-12.786247506800052,-12.794580802514407,-12.802914098228763,-12.81124739394312,-12.819580689657478,-12.827913985371833,-12.836247281086187,-12.844580576800544,-12.852913872514899,-12.861247168229255,-12.86958046394361,-12.877913759657966,-12.886247055372323,-12.894580351086681,-12.902913646801034,-12.91124694251539,-12.919580238229749,-12.927913533944103,-12.936246829658458,-12.944580125372815,-12.952913421087171,-12.961246716801526,-12.96958001251588,-12.977913308230237,-12.986246603944593,-12.994579899658948,-13.002913195373306,-13.01124649108766,-13.019579786802016,-13.027913082516372,-13.036246378230729,-13.044579673945083,-13.05291296965944,-13.061246265373796,-13.069579561088151,-13.077912856802506,-13.086246152516864,-13.094579448231219,-13.102912743945573,-13.111246039659932,-13.119579335374286,-13.127912631088641,-13.136245926802998,-13.14721013258128,-13.171328888679199,-13.195447644777115,-13.219566400875035,-13.243685156972948,-13.267803913070864,-13.291922669168782,-13.316041425266697,-13.340160181364617,-13.364278937462533,-13.388397693560446,-13.412516449658364,-13.43663520575628,-13.460753961854198,-13.484872717952115,-13.508991474050031,-13.53311023014795,-13.55722898624586,-13.58134774234378,-13.605466498441697,-13.629249195089493,-13.635508212719735,-13.641767230349975,-13.648026247980217,-13.654285265610461,-13.660544283240704,-13.666803300870946,-13.673062318501188,-13.67932133613143,-13.685580353761672,-13.691839371391913,-13.698098389022157,-13.704357406652399,-13.710616424282641,-13.716875441912881,-13.723134459543125,-13.729393477173367,-13.73565249480361,-13.741911512433852,-13.748170530064092,-13.754429547694334,-13.760688565324577,-13.745979778854428,-13.716293989455439,-13.686608200056446,-13.65692241065745,-13.627236621258458,-13.597550831859465,-13.56786504246047,-13.538179253061474,-13.508493463662486,-13.47880767426349,-13.449121884864493,-13.419436095465505,-13.389750306066512,-13.360064516667515,-13.330378727268526,-13.30069293786953,-13.271007148470535,-13.24132135907154,-13.21163556967255,-13.181949780273555,-13.15226399087456,-13.117953650501928,-13.056989209057079,-12.996024767612228,-12.935060326167392,-12.87409588472254,-12.81313144327769,-12.752167001832852,-12.691202560388003,-12.630238118943154,-12.569273677498304,-12.508309236053467,-12.447344794608618,-12.38638035316377,-12.32541591171893,-12.264451470274079,-12.20348702882923,-12.142522587384391,-12.081558145939542,-12.020593704494694,-11.959629263049845,-11.898664821605005],[-7.905949223062861,-7.916079293412931,-7.926209363763,-7.936339434113069,-7.946469504463139,-7.956599574813209,-7.966729645163278,-7.976859715513348,-7.9869897858634165,-7.997119856213487,-8.007249926563556,-8.017379996913625,-8.027510067263695,-8.037640137613765,-8.047770207963834,-8.057900278313904,-8.068030348663973,-8.078160419014043,-8.088290489364113,-8.098420559714182,-8.10855063006425,-8.118680700414322,-8.12881077076439,-8.13894084111446,-8.149070911464529,-8.1592009818146,-8.169331052164669,-8.179461122514738,-8.189591192864807,-8.199721263214878,-8.209851333564945,-8.219981403915016,-8.230111474265085,-8.240241544615156,-8.250371614965225,-8.260501685315294,-8.270631755665365,-8.280761826015432,-8.290891896365503,-8.303498180433586,-8.316599707961524,-8.329701235489459,-8.3428027630174,-8.355904290545334,-8.369005818073271,-8.38210734560121,-8.395208873129146,-8.408310400657083,-8.42141192818502,-8.434513455712956,-8.447614983240895,-8.46071651076883,-8.473818038296768,-8.486919565824705,-8.500021093352641,-8.51312262088058,-8.526224148408515,-8.539325675936453,-8.55242720346439,-8.565528730992327,-8.578630258520263,-8.5917317860482,-8.604833313576139,-8.617934841104075,-8.63103636863201,-8.644137896159949,-8.657239423687887,-8.670340951215824,-8.68344247874376,-8.696544006271697,-8.709645533799634,-8.722747061327572,-8.735848588855509,-8.748950116383446,-8.76205164391138,-8.775153171439321,-8.788254698967258,-8.801356226495193,-8.814457754023131,-8.82755928155107,-8.840660809079004,-8.853762336606941,-8.86686386413488,-8.879965391662816,-8.889023323441414,-8.897272536070146,-8.905521748698877,-8.913770961327609,-8.92202017395634,-8.930269386585072,-8.938518599213804,-8.946767811842536,-8.955017024471267,-8.963266237099997,-8.97151544972873,-8.97976466235746,-8.988013874986194,-8.996263087614924,-9.004512300243658,-9.012761512872387,-9.02101072550112,-9.02925993812985,-9.037509150758583,-9.045758363387314,-9.054007576016044,-9.062256788644776,-9.070506001273507,-9.07875521390224,-9.08700442653097,-9.095253639159703,-9.103502851788434,-9.111752064417166,-9.120001277045898,-9.128250489674627,-9.136499702303361,-9.14474891493209,-9.152998127560824,-9.161247340189554,-9.169496552818288,-9.177745765447018,-9.185994978075751,-9.194244190704481,-9.204345718840809,-9.215373405568101,-9.226401092295394,-9.237428779022688,-9.24845646574998,-9.259484152477272,-9.270511839204564,-9.281539525931857,-9.292567212659149,-9.303594899386443,-9.314622586113734,-9.325650272841026,-9.33667795956832,-9.347705646295612,-9.358733333022904,-9.369761019750197,-9.38078870647749,-9.391816393204783,-9.402844079932073,-9.413871766659367,-9.424899453386661,-9.435927140113952,-9.446954826841246,-9.457982513568538,-9.46901020029583,-9.480037887023123,-9.491065573750415,-9.502093260477707,-9.513120947205001,-9.524148633932292,-9.535176320659584,-9.546204007386876,-9.55723169411417,-9.568259380841464,-9.579287067568757,-9.590314754296049,-9.601342441023341,-9.612370127750633,-9.623397814477926,-9.634425501205218,-9.64545318793251,-9.656480874659803,-9.667508561387097,-9.678536248114389,-9.689563934841681,-9.700359402044148,-9.711038759484202,-9.721718116924256,-9.732397474364308,-9.743076831804363,-9.753756189244417,-9.76443554668447,-9.775114904124523,-9.785794261564579,-9.79647361900463,-9.807152976444684,-9.817832333884738,-9.828511691324792,-9.839191048764846,-9.8498704062049,-9.860549763644954,-9.871229121085006,-9.88190847852506,-9.892587835965115,-9.903267193405167,-9.913946550845221,-9.924625908285275,-9.935305265725328,-9.945984623165382,-9.956663980605436,-9.967343338045488,-9.978022695485542,-9.988702052925596,-9.99938141036565,-10.010060767805705,-10.020740125245757,-10.031419482685813,-10.042098840125865,-10.052778197565917,-10.063457555005971,-10.074136912446026,-10.08481626988608,-10.095495627326134,-10.106174984766188,-10.116854342206242,-10.127533699646294,-10.138213057086347,-10.1488924145264,-10.159571771966455,-10.170251129406509,-10.180930486846563,-10.191609844286614,-10.20228920172667,-10.212968559166724,-10.223647916606778,-10.23432727404683,-10.245006631486884,-10.255685988926938,-10.26636534636699,-10.277044703807046,-10.287724061247097,-10.298403418687153,-10.309082776127205,-10.31976213356726,-10.330441491007313,-10.341120848447368,-10.35180020588742,-10.362479563327474,-10.373158920767528,-10.38383827820758,-10.394517635647635,-10.405196993087689,-10.415876350527743,-10.426555707967797,-10.43723506540785,-10.447914422847903,-10.458593780287956,-10.469273137728011,-10.479952495168064,-10.490631852608118,-10.50131121004817,-10.511990567488224,-10.520732218112357,-10.529473863952493,-10.53821550979263,-10.546957155632764,-10.555698801472902,-10.56444044731304,-10.575163190944274,-10.587867032366605,-10.600570873788937,-10.613274715211269,-10.625978556633601,-10.63868239805593,-10.651386239478263,-10.664090080900596,-10.676793922322927,-10.689497763745258,-10.70220160516759,-10.714905446589922,-10.728698582991786,-10.74276403615891,-10.756829489326035,-10.770894942493157,-10.784960395660281,-10.799025848827407,-10.813091301994529,-10.827156755161653,-10.841222208328778,-10.855287661495902,-10.869353114663024,-10.883418567830148,-10.897484020997274,-10.911549474164396,-10.92561492733152,-10.939680380498647,-10.953745833665769,-10.967811286832893,-10.981876740000017,-10.995942193167142,-11.010007646334262,-11.02407309950139,-11.038138552668514,-11.052204005835637,-11.066269459002761,-11.080334912169885,-11.094400365337009,-11.108465818504133,-11.122531271671255,-11.13659672483838,-11.150662178005502,-11.164727631172628,-11.178793084339754,-11.192858537506876,-11.206923990674,-11.220989443841125,-11.235054897008247,-11.249120350175371,-11.263185803342495,-11.277251256509619,-11.291316709676742,-11.305382162843866,-11.319447616010992,-11.333513069178114,-11.347578522345238,-11.361643975512365,-11.375709428679487,-11.389774881846611,-11.403840335013737,-11.41790578818086,-11.431971241347982,-11.446036694515108,-11.460102147682232,-11.474167600849354,-11.48823305401648,-11.502298507183603,-11.516363960350725,-11.53042941351785,-11.544494866684975,-11.558560319852097,-11.57262577301922,-11.586691226186346,-11.600756679353472,-11.614822132520592,-11.62888758568772,-11.642953038854841,-11.657018492021965,-11.671083945189089,-11.685149398356215,-11.699214851523337,-11.713280304690462,-11.725866305144924,-11.735493400174063,-11.745120495203198,-11.75474759023234,-11.764374685261478,-11.774001780290616,-11.783628875319755,-11.793255970348895,-11.80288306537803,-11.812510160407168,-11.822137255436308,-11.831764350465447,-11.841391445494583,-11.851018540523725,-11.860645635552862,-11.870272730582,-11.87989982561114,-11.889526920640279,-11.899154015669415,-11.908781110698555,-11.918408205727694,-11.928035300756832,-11.93766239578597,-11.947289490815109,-11.956916585844247,-11.966543680873388,-11.976170775902524,-11.985797870931666,-11.995424965960801,-12.00505206098994,-12.014679156019081,-12.024306251048216,-12.033933346077355,-12.043560441106493,-12.053187536135635,-12.062814631164773,-12.072441726193912,-12.08206882122305,-12.091695916252188,-12.101323011281327,-12.110950106310465,-12.120577201339604,-12.130204296368742,-12.13983139139788,-12.149458486427019,-12.159085581456157,-12.168712676485296,-12.178339771514436,-12.187966866543576,-12.197593961572714,-12.20722105660185,-12.21684815163099,-12.22647524666013,-12.236102341689268,-12.245729436718403,-12.255356531747545,-12.264983626776683,-12.274610721805821,-12.28423781683496,-12.293864911864098,-12.303492006893237,-12.313119101922375,-12.322746196951513,-12.332373291980653,-12.342000387009788,-12.351627482038928,-12.361254577068069,-12.370881672097205,-12.380508767126345,-12.38995533354601,-12.398288629260366,-12.406621924974722,-12.414955220689079,-12.423288516403433,-12.43162181211779,-12.439955107832144,-12.448288403546501,-12.456621699260856,-12.464954994975212,-12.473288290689569,-12.481621586403925,-12.48995488211828,-12.498288177832636,-12.509252383610917,-12.533371139708835,-12.557489895806754,-12.581608651904672,-12.605727408002586,-12.624108962604552,-12.630367980234794,-12.636626997865037,-12.642886015495279,-12.64914503312552,-12.655404050755763,-12.661663068386003,-12.667922086016247,-12.67418110364649,-12.680440121276732,-12.686699138906974,-12.692958156537216,-12.699217174167458,-12.7054761917977,-12.711735209427943,-12.717994227058185,-12.724253244688427,-12.730512262318669,-12.736771279948911,-12.743030297579153,-12.749289315209396,-12.755548332839638,-12.76180735046988,-12.768066368100122,-12.774325385730364,-12.780584403360606,-12.786843420990849,-12.793102438621093,-12.799361456251331,-12.805620473881575,-12.811879491511817,-12.81813850914206,-12.824397526772302,-12.830656544402544,-12.836915562032786,-12.843174579663028,-12.849433597293272,-12.83472481082312,-12.805039021424129,-12.775353232025136,-12.745667442626141,-12.715981653227152,-12.686295863828157,-12.656610074429162,-12.626924285030167,-12.597238495631176,-12.567552706232181,-12.537866916833188,-12.508181127434197,-12.478495338035202,-12.448809548636207,-12.419123759237218,-12.389437969838223,-12.359752180439228,-12.330066391040233,-12.300380601641244,-12.27069481224225,-12.24100902284325,-12.211323233444263,-12.181637444045268,-12.151951654646275,-12.122265865247284,-12.09258007584829,-12.062894286449295,-12.033208497050305,-12.00352270765131,-11.973836918252314,-11.94415112885332,-11.91446533945433,-11.884779550055335,-11.85509376065634,-11.825407971257352,-11.795722181858356,-11.76603639245936,-11.709906689884761,-11.648942248439912,-11.587977806995063,-11.527013365550212,-11.466048924105374],[-7.429141475502236,-7.439271545852305,-7.449401616202374,-7.459531686552444,-7.469661756902514,-7.479791827252583,-7.4899218976026525,-7.5000519679527216,-7.510182038302792,-7.5203121086528615,-7.5304421790029314,-7.540572249353,-7.5507023197030705,-7.56083239005314,-7.5709624604032095,-7.5810925307532795,-7.591222601103349,-7.601352671453418,-7.611482741803487,-7.621612812153557,-7.631742882503626,-7.641872952853696,-7.652003023203765,-7.662133093553834,-7.672263163903905,-7.682393234253973,-7.692523304604043,-7.702653374954113,-7.712783445304182,-7.722913515654252,-7.733043586004321,-7.74317365635439,-7.75330372670446,-7.76343379705453,-7.773563867404599,-7.783693937754669,-7.793824008104737,-7.803954078454808,-7.814084148804877,-7.824214219154946,-7.834344289505016,-7.844474359855085,-7.854604430205155,-7.864734500555224,-7.874864570905293,-7.884994641255363,-7.895124711605433,-7.905254781955502,-7.915384852305572,-7.9255149226556405,-7.935644993005711,-7.945775063355781,-7.9559051337058495,-7.966035204055919,-7.9761652744059885,-7.98728582939485,-8.000387356922786,-8.013488884450723,-8.02659041197866,-8.039691939506596,-8.052793467034535,-8.065894994562472,-8.07899652209041,-8.092098049618345,-8.105199577146283,-8.11830110467422,-8.131402632202155,-8.144504159730094,-8.15760568725803,-8.170707214785967,-8.183808742313905,-8.19691026984184,-8.210011797369779,-8.223113324897716,-8.236214852425652,-8.249316379953589,-8.262417907481527,-8.275519435009464,-8.2886209625374,-8.301722490065337,-8.314824017593276,-8.32792554512121,-8.341027072649148,-8.354128600177086,-8.363186531955686,-8.371435744584417,-8.379684957213147,-8.387934169841879,-8.39618338247061,-8.404432595099342,-8.412681807728074,-8.420931020356806,-8.429180232985537,-8.437429445614269,-8.445678658243,-8.45392787087173,-8.462177083500464,-8.470426296129194,-8.478675508757927,-8.486924721386657,-8.495173934015389,-8.50342314664412,-8.511672359272852,-8.519921571901584,-8.528170784530316,-8.536419997159047,-8.544669209787779,-8.55291842241651,-8.561167635045242,-8.569416847673972,-8.577666060302706,-8.585915272931436,-8.594164485560167,-8.602413698188899,-8.61066291081763,-8.618912123446362,-8.627161336075094,-8.635410548703824,-8.643659761332557,-8.651908973961287,-8.66015818659002,-8.66840739921875,-8.676656611847482,-8.684905824476214,-8.693155037104946,-8.701404249733677,-8.70965346236241,-8.71790267499114,-8.726151887619872,-8.734401100248604,-8.742650312877334,-8.750899525506066,-8.759148738134797,-8.76739795076353,-8.77564716339226,-8.783896376020992,-8.792145588649724,-8.800394801278456,-8.809107091907055,-8.820134778634348,-8.83116246536164,-8.842190152088932,-8.853217838816226,-8.864245525543518,-8.87527321227081,-8.886300898998103,-8.897328585725395,-8.90835627245269,-8.91938395917998,-8.930411645907274,-8.941439332634566,-8.952467019361858,-8.96349470608915,-8.974522392816443,-8.985550079543737,-8.99657776627103,-9.007605452998321,-9.018633139725614,-9.029660826452906,-9.040688513180198,-9.05171619990749,-9.062743886634783,-9.073771573362077,-9.084799260089369,-9.095826946816661,-9.106854633543954,-9.117882320271246,-9.128677787473713,-9.139357144913767,-9.15003650235382,-9.160715859793873,-9.171395217233925,-9.182074574673981,-9.192753932114034,-9.20343328955409,-9.214112646994144,-9.224792004434196,-9.23547136187425,-9.246150719314302,-9.256830076754357,-9.26750943419441,-9.278188791634465,-9.288868149074517,-9.299547506514571,-9.310226863954625,-9.32090622139468,-9.331585578834732,-9.342264936274786,-9.35294429371484,-9.363623651154894,-9.374303008594946,-9.384982366035,-9.395661723475055,-9.406341080915109,-9.417020438355161,-9.427699795795215,-9.43837915323527,-9.449058510675322,-9.459737868115377,-9.47041722555543,-9.481096582995484,-9.491775940435536,-9.502455297875592,-9.513134655315644,-9.523814012755697,-9.53449337019575,-9.545172727635805,-9.555852085075859,-9.566531442515911,-9.577210799955967,-9.58789015739602,-9.598569514836072,-9.609248872276128,-9.61992822971618,-9.630607587156234,-9.641071645549413,-9.649813291389549,-9.658554937229686,-9.66729658306982,-9.67603822890996,-9.684779874750095,-9.693521520590233,-9.702263166430367,-9.711004812270502,-9.719746458110642,-9.728488103950777,-9.737229749790915,-9.745971395631049,-9.754713041471188,-9.763454687311324,-9.77219633315146,-9.780937978991595,-9.789679624831733,-9.798421270671868,-9.807162916512006,-9.815904562352141,-9.824646208192277,-9.833387854032416,-9.842129499872552,-9.850871145712688,-9.859612791552824,-9.868354437392961,-9.877096083233097,-9.885837729073234,-9.89457937491337,-9.903321020753506,-9.912062666593641,-9.920804312433779,-9.929545958273916,-9.938287604114052,-9.949010347745286,-9.961714189167619,-9.97441803058995,-9.987121872012281,-9.999825713434614,-10.012529554856943,-10.025233396279276,-10.037937237701609,-10.05064107912394,-10.063344920546271,-10.076048761968604,-10.088752603390935,-10.101456444813266,-10.114160286235599,-10.12686412765793,-10.139567969080261,-10.152271810502594,-10.164975651924925,-10.177679493347256,-10.190383334769589,-10.203087176191922,-10.215791017614253,-10.228494859036582,-10.241198700458916,-10.25390254188125,-10.266606383303579,-10.27931022472591,-10.292014066148242,-10.304717907570573,-10.317421748992905,-10.330125590415237,-10.34282943183757,-10.3555332732599,-10.36823711468223,-10.380940956104563,-10.393644797526896,-10.406348638949227,-10.419052480371558,-10.431756321793891,-10.44446016321622,-10.457164004638553,-10.469867846060886,-10.482571687483217,-10.495275528905548,-10.507979370327881,-10.52068321175021,-10.533387053172543,-10.546090894594876,-10.558794736017207,-10.571498577439538,-10.58420241886187,-10.596906260284202,-10.609610101706533,-10.622313943128866,-10.635017784551199,-10.647721625973528,-10.660425467395859,-10.673129308818192,-10.685833150240525,-10.698536991662854,-10.711240833085188,-10.723944674507518,-10.73692083862629,-10.750986291793417,-10.76505174496054,-10.779117198127663,-10.793182651294789,-10.807248104461912,-10.821313557629034,-10.83537901079616,-10.849444463963284,-10.863509917130408,-10.877575370297532,-10.891640823464657,-10.90570627663178,-10.919771729798903,-10.933837182966029,-10.94790263613315,-10.961968089300274,-10.9760335424674,-10.990098995634524,-11.004164448801648,-11.01822990196877,-11.030815902423234,-11.040442997452372,-11.05007009248151,-11.059697187510649,-11.069324282539787,-11.078951377568925,-11.088578472598064,-11.098205567627202,-11.10783266265634,-11.117459757685479,-11.127086852714617,-11.136713947743758,-11.146341042772896,-11.155968137802034,-11.165595232831173,-11.175222327860311,-11.18484942288945,-11.194476517918588,-11.204103612947726,-11.213730707976865,-11.223357803006005,-11.232984898035143,-11.24261199306428,-11.252239088093418,-11.261866183122558,-11.271493278151695,-11.281120373180835,-11.290747468209974,-11.300374563239112,-11.310001658268252,-11.31962875329739,-11.329255801474993,-11.338881491029039,-11.348507180583084,-11.35813287013713,-11.367758559691175,-11.377384249245221,-11.387009938799268,-11.396635628353312,-11.40626131790736,-11.415887007461405,-11.42551269701545,-11.435138386569498,-11.444764076123544,-11.45438976567759,-11.464015455231635,-11.473641144785681,-11.483266834339727,-11.49289252389377,-11.50251821344782,-11.512143903001864,-11.52176959255591,-11.531395282109955,-11.541020971664002,-11.550646661218046,-11.560272350772095,-11.569898040326139,-11.579523729880183,-11.589149419434232,-11.598775108988278,-11.608400798542323,-11.618026488096369,-11.627652177650415,-11.63727786720446,-11.646903556758506,-11.656529246312552,-11.666154935866599,-11.675780625420643,-11.685406314974689,-11.695032004528736,-11.704657694082782,-11.714283383636827,-11.723909073190875,-11.73353476274492,-11.743160452298964,-11.752786141853012,-11.762411831407057,-11.772037520961103,-11.781663210515148,-11.791288900069194,-11.80091458962324,-11.810540279177285,-11.820165968731331,-11.829192584475738,-11.835223831171962,-11.841255077868183,-11.847286324564408,-11.85331757126063,-11.859348817956853,-11.865380064653076,-11.871411311349299,-11.877442558045521,-11.883473804741744,-11.889505051437965,-11.895536298134187,-11.90156754483041,-11.907598791526633,-11.913630038222855,-11.919661284919076,-11.9256925316153,-11.931723778311524,-11.937755025007746,-11.943786271703969,-11.94981751840019,-11.955848765096412,-11.961880011792637,-11.967911258488858,-11.97394250518508,-11.979973751881303,-11.986004998577526,-11.992036245273749,-11.99806749196997,-12.004098738666194,-12.010129985362417,-12.016161232058638,-12.021584496569757,-12.018086676361278,-12.014588856152798,-12.011091035944318,-12.007593215735834,-12.004095395527356,-12.000597575318876,-11.997099755110392,-11.993601934901912,-11.990104114693434,-11.979638680742102,-11.964196379831598,-11.948754078921091,-11.933311778010587,-11.917869477100083,-11.902427176189576,-11.886984875279074,-11.871542574368565,-11.856100273458063,-11.839223363372861,-11.809834370234162,-11.780445377095468,-11.75105638395677,-11.721667390818071,-11.692278397679377,-11.66288940454068,-11.63350041140198,-11.604111418263281,-11.57472242512459,-11.545333431985888,-11.515944438847193,-11.486555445708497,-11.457166452569798,-11.4277774594311,-11.398388466292406,-11.368999473153707,-11.339610480015008,-11.310221486876316,-11.280832493737616,-11.251443500598917,-11.22205450746022,-11.192665514321526,-11.163276521182826,-11.133887528044129,-11.104498534905435,-11.075109541766736,-11.045720548628038,-11.016331555489344,-10.986942562350647,-10.957553569211946,-10.928164576073248,-10.898775582934555],[-6.952333727941621,-6.96246379829169,-6.972593868641759,-6.982723938991829,-6.992854009341899,-7.002984079691968,-7.013114150042037,-7.023244220392108,-7.033374290742176,-7.043504361092246,-7.053634431442316,-7.0637645017923845,-7.073894572142455,-7.084024642492524,-7.094154712842594,-7.104284783192663,-7.1144148535427325,-7.1245449238928025,-7.1346749942428715,-7.144805064592942,-7.1549351349430115,-7.1650652052930806,-7.17519527564315,-7.185325345993219,-7.19545541634329,-7.205585486693359,-7.215715557043428,-7.225845627393498,-7.235975697743566,-7.246105768093637,-7.256235838443706,-7.266365908793775,-7.276495979143844,-7.286626049493915,-7.296756119843984,-7.306886190194054,-7.317016260544124,-7.327146330894193,-7.337276401244262,-7.347406471594331,-7.3575365419444,-7.36766661229447,-7.37779668264454,-7.387926752994609,-7.398056823344678,-7.408186893694749,-7.418316964044818,-7.428447034394887,-7.438577104744957,-7.448707175095026,-7.458837245445096,-7.468967315795166,-7.479097386145235,-7.489227456495304,-7.499357526845374,-7.509487597195443,-7.519617667545513,-7.529747737895582,-7.539877808245652,-7.550007878595721,-7.560137948945791,-7.5702680192958605,-7.58039808964593,-7.5905281599959995,-7.600658230346069,-7.610788300696139,-7.620918371046208,-7.631048441396278,-7.6411785117463475,-7.651308582096417,-7.661438652446487,-7.671568722796556,-7.684175005884059,-7.697276533411996,-7.7103780609399335,-7.723479588467871,-7.736581115995807,-7.7496826435237445,-7.762784171051681,-7.775885698579619,-7.788987226107556,-7.802088753635492,-7.815190281163429,-7.828291808691366,-7.837349740469966,-7.845598953098698,-7.8538481657274275,-7.862097378356159,-7.870346590984891,-7.8785958036136226,-7.886845016242354,-7.895094228871086,-7.903343441499818,-7.911592654128549,-7.919841866757281,-7.928091079386011,-7.936340292014744,-7.944589504643474,-7.952838717272208,-7.961087929900938,-7.969337142529669,-7.977586355158401,-7.985835567787133,-7.994084780415864,-8.002333993044596,-8.010583205673328,-8.01883241830206,-8.02708163093079,-8.035330843559521,-8.043580056188253,-8.051829268816984,-8.060078481445716,-8.068327694074448,-8.07657690670318,-8.084826119331911,-8.093075331960643,-8.101324544589374,-8.109573757218104,-8.117822969846838,-8.126072182475568,-8.134321395104301,-8.142570607733031,-8.150819820361763,-8.159069032990496,-8.167318245619226,-8.175567458247958,-8.18381667087669,-8.192065883505421,-8.200315096134153,-8.208564308762885,-8.216813521391614,-8.225062734020346,-8.233311946649078,-8.24156115927781,-8.249810371906541,-8.258059584535273,-8.266308797164005,-8.274558009792736,-8.282807222421468,-8.2910564350502,-8.29930564767893,-8.307554860307661,-8.315804072936395,-8.324053285565126,-8.332302498193858,-8.340551710822588,-8.34880092345132,-8.357050136080051,-8.365299348708783,-8.373548561337515,-8.381797773966246,-8.390046986594978,-8.39829619922371,-8.406545411852441,-8.414794624481173,-8.424896151700604,-8.435923838427899,-8.44695152515519,-8.457979211882481,-8.469006898609775,-8.480034585337068,-8.49106227206436,-8.502089958791652,-8.513117645518944,-8.524145332246238,-8.53517301897353,-8.546200705700823,-8.55699617290329,-8.567675530343342,-8.578354887783396,-8.589034245223448,-8.599713602663503,-8.610392960103557,-8.62107231754361,-8.631751674983665,-8.642431032423717,-8.653110389863771,-8.663789747303825,-8.67446910474388,-8.685148462183932,-8.695827819623986,-8.70650717706404,-8.717186534504094,-8.727865891944148,-8.7385452493842,-8.749224606824255,-8.759903964264307,-8.770152718826616,-8.778894364666753,-8.787636010506889,-8.796377656347026,-8.805119302187162,-8.8138609480273,-8.822602593867437,-8.831344239707573,-8.840085885547708,-8.848827531387844,-8.857569177227981,-8.866310823068117,-8.875052468908255,-8.88379411474839,-8.892535760588528,-8.901277406428663,-8.910019052268801,-8.918760698108937,-8.927502343949072,-8.93624398978921,-8.944985635629346,-8.953727281469481,-8.962468927309619,-8.971210573149754,-8.979952218989892,-8.98869386483003,-8.997435510670165,-9.0061771565103,-9.014918802350437,-9.023660448190574,-9.032402094030711,-9.041143739870847,-9.049885385710983,-9.05862703155112,-9.067368677391256,-9.076110323231394,-9.08485196907153,-9.093593614911665,-9.102335260751802,-9.11107690659194,-9.119818552432076,-9.128560198272211,-9.137301844112347,-9.146043489952486,-9.154785135792622,-9.163526781632758,-9.172268427472893,-9.181010073313029,-9.189751719153167,-9.198493364993304,-9.20723501083344,-9.215976656673575,-9.224718302513711,-9.23345994835385,-9.242201594193986,-9.250943240034122,-9.25968488587426,-9.268426531714395,-9.27716817755453,-9.285909823394668,-9.294651469234804,-9.30339311507494,-9.312134760915077,-9.32285750454631,-9.335561345968642,-9.348265187390975,-9.360969028813305,-9.373672870235637,-9.38637671165797,-9.399080553080301,-9.411784394502632,-9.424488235924965,-9.437192077347294,-9.449895918769627,-9.46259976019196,-9.475303601614293,-9.488007443036622,-9.500711284458955,-9.513415125881286,-9.526118967303617,-9.53882280872595,-9.551526650148281,-9.564230491570614,-9.576934332992945,-9.589638174415278,-9.602342015837609,-9.61504585725994,-9.627749698682273,-9.640453540104605,-9.653157381526935,-9.665861222949268,-9.678565064371599,-9.69126890579393,-9.703972747216262,-9.716676588638595,-9.729380430060925,-9.742084271483257,-9.75478811290559,-9.767491954327921,-9.780195795750252,-9.792899637172585,-9.805603478594916,-9.818307320017245,-9.831011161439578,-9.84371500286191,-9.856418844284242,-9.869122685706575,-9.881826527128906,-9.894530368551235,-9.907234209973568,-9.9199380513959,-9.932641892818232,-9.945345734240563,-9.958049575662894,-9.970753417085227,-9.983457258507558,-9.99616109992989,-10.008864941352224,-10.021568782774553,-10.034272624196886,-10.046976465619217,-10.05968030704155,-10.072384148463879,-10.085087989886212,-10.097791831308545,-10.110495672730874,-10.123199514153207,-10.135903355575538,-10.14649674724806,-10.156898282407976,-10.167299817567892,-10.177701352727807,-10.188102887887723,-10.19850442304764,-10.208905958207556,-10.21930749336747,-10.229709028527385,-10.240110563687303,-10.250512098847217,-10.260913634007132,-10.271315169167048,-10.281716704326964,-10.29211823948688,-10.302519774646797,-10.312921309806711,-10.323322844966626,-10.333492510299418,-10.343198435977957,-10.352904361656496,-10.362610287335034,-10.372316213013573,-10.382022138692111,-10.391728064370653,-10.40143399004919,-10.411139915727729,-10.420845841406267,-10.430551767084808,-10.440257692763346,-10.449963618441885,-10.459669544120423,-10.469375469798964,-10.479081395477502,-10.48878732115604,-10.49849324683458,-10.50819917251312,-10.517905098191658,-10.527611023870199,-10.537316949548735,-10.547022875227274,-10.556728800905814,-10.566434726584353,-10.576140652262891,-10.58584657794143,-10.595552503619968,-10.605221654530576,-10.614847344084623,-10.624473033638667,-10.634098723192713,-10.643724412746758,-10.653350102300804,-10.662975791854851,-10.672601481408897,-10.68222717096294,-10.69185286051699,-10.701478550071034,-10.71110423962508,-10.720729929179125,-10.730355618733173,-10.739981308287218,-10.749606997841266,-10.75923268739531,-10.768858376949353,-10.778484066503403,-10.788109756057446,-10.797735445611494,-10.80736113516554,-10.816986824719585,-10.82661251427363,-10.836238203827676,-10.845863893381722,-10.855489582935768,-10.865115272489815,-10.87474096204386,-10.884366651597905,-10.893992341151952,-10.903618030705998,-10.913243720260043,-10.922869409814089,-10.932495099368136,-10.942120788922182,-10.951746478476226,-10.961372168030273,-10.970997857584319,-10.980623547138364,-10.99024923669241,-10.999874926246456,-11.009500615800501,-11.019126305354547,-11.028751994908594,-11.03837768446264,-11.048003374016684,-11.05762906357073,-11.067254753124777,-11.07688044267882,-11.086506132232868,-11.096131821786916,-11.105757511340961,-11.115383200895007,-11.125008890449053,-11.13403550619346,-11.140066752889682,-11.146097999585905,-11.15212924628213,-11.15816049297835,-11.164191739674573,-11.170222986370796,-11.176254233067018,-11.182285479763243,-11.188316726459464,-11.194347973155685,-11.200379219851909,-11.20641046654813,-11.212441713244353,-11.218472959940575,-11.2245042066368,-11.23053545333302,-11.236566700029243,-11.234135929700024,-11.230638109491544,-11.227140289283064,-11.223642469074582,-11.220144648866103,-11.216646828657623,-11.21314900844914,-11.20965118824066,-11.206153368032178,-11.2026555478237,-11.199157727615216,-11.195659907406736,-11.192162087198257,-11.188664266989775,-11.185166446781295,-11.181668626572815,-11.178170806364335,-11.174672986155853,-11.171175165947371,-11.167677345738891,-11.164179525530411,-11.160681705321931,-11.157183885113449,-11.153686064904969,-11.143220630953639,-11.127778330043135,-11.112336029132631,-11.096893728222124,-11.081451427311622,-11.066009126401115,-11.050566825490609,-11.035124524580104,-11.019682223669601,-11.004239922759094,-10.988797621848589,-10.973355320938087,-10.957913020027581,-10.942470719117074,-10.927028418206572,-10.911586117296066,-10.896143816385559,-10.880701515475053,-10.865259214564551,-10.849816913654044,-10.834374612743536,-10.818932311833034,-10.80349001092253,-10.788047710012023,-10.768719231802928,-10.739330238664229,-10.70994124552553,-10.680552252386837,-10.651163259248138,-10.621774266109439,-10.592385272970741,-10.562996279832047,-10.533607286693348,-10.50421829355465,-10.474829300415955,-10.445440307277257,-10.416051314138558,-10.386662320999866,-10.357273327861165,-10.32788433472247,-10.29849534158377,-10.269106348445074],[-6.474933148283943,-6.4850632186340125,-6.4951932889840815,-6.5053233593341515,-6.5154534296842215,-6.5255835000342906,-6.53571357038436,-6.54584364073443,-6.5559737110844996,-6.5661037814345695,-6.576233851784639,-6.586363922134708,-6.596493992484777,-6.606624062834847,-6.616754133184917,-6.626884203534987,-6.637014273885055,-6.647144344235125,-6.657274414585194,-6.667404484935265,-6.677534555285334,-6.687664625635403,-6.697794695985472,-6.707924766335542,-6.718054836685612,-6.728184907035681,-6.738314977385751,-6.748445047735819,-6.75857511808589,-6.768705188435959,-6.778835258786028,-6.788965329136098,-6.799095399486166,-6.809225469836237,-6.819355540186306,-6.829485610536376,-6.839615680886446,-6.849745751236514,-6.859875821586584,-6.870005891936653,-6.880135962286723,-6.890266032636793,-6.900396102986862,-6.910526173336931,-6.9206562436870005,-6.930786314037071,-6.94091638438714,-6.9510464547372095,-6.961176525087279,-6.9713065954373485,-6.9814366657874185,-6.9915667361374885,-7.0016968064875575,-7.011826876837626,-7.021956947187697,-7.032087017537766,-7.042217087887836,-7.052347158237905,-7.062477228587975,-7.072607298938044,-7.082737369288113,-7.092867439638183,-7.102997509988253,-7.113127580338322,-7.123257650688391,-7.133387721038462,-7.14351779138853,-7.153647861738599,-7.16377793208867,-7.173908002438739,-7.184038072788809,-7.194168143138878,-7.204298213488947,-7.214428283839017,-7.224558354189086,-7.234688424539156,-7.244818494889225,-7.254948565239294,-7.265078635589364,-7.2741712424476574,-7.281188928819834,-7.288206615192009,-7.295224301564186,-7.3022419879363625,-7.310285946189001,-7.318535158817733,-7.326784371446465,-7.3350335840751955,-7.343282796703927,-7.351532009332659,-7.35978122196139,-7.368030434590121,-7.376279647218853,-7.384528859847585,-7.392778072476316,-7.401027285105048,-7.409276497733781,-7.417525710362511,-7.425774922991243,-7.434024135619975,-7.4422733482487065,-7.450522560877437,-7.458771773506169,-7.467020986134901,-7.475270198763631,-7.483519411392363,-7.491768624021095,-7.5000178366498265,-7.508267049278558,-7.51651626190729,-7.5247654745360215,-7.533014687164753,-7.541263899793484,-7.549513112422216,-7.557762325050948,-7.566011537679678,-7.57426075030841,-7.5825099629371415,-7.590759175565873,-7.599008388194605,-7.607257600823337,-7.615506813452068,-7.623756026080799,-7.632005238709532,-7.640254451338262,-7.648503663966994,-7.656752876595726,-7.665002089224457,-7.673251301853188,-7.68150051448192,-7.689749727110652,-7.697998939739383,-7.706248152368115,-7.714497364996846,-7.722746577625578,-7.73099579025431,-7.739245002883041,-7.7474942155117725,-7.755743428140503,-7.763992640769235,-7.772241853397967,-7.780491066026698,-7.78874027865543,-7.796989491284162,-7.805238703912893,-7.813487916541625,-7.821737129170356,-7.829986341799088,-7.838235554427818,-7.84648476705655,-7.854733979685282,-7.862983192314014,-7.871232404942746,-7.879481617571477,-7.8877308302002085,-7.89598004282894,-7.904229255457671,-7.912478468086403,-7.920727680715134,-7.928976893343865,-7.937226105972598,-7.945475318601329,-7.953254961858869,-7.9586867700237205,-7.964118578188573,-7.969550386353424,-7.974982194518276,-7.982100615230786,-7.990062342217126,-7.998024069203467,-8.005985796189806,-8.013947523176148,-8.021909250162489,-8.029870977148828,-8.037832704135168,-8.045794431121509,-8.053756158107849,-8.06171788509419,-8.06967961208053,-8.07764133906687,-8.08560306605321,-8.093564793039551,-8.10152652002589,-8.10948824701223,-8.117774938107221,-8.126516583947357,-8.135258229787492,-8.14399987562763,-8.152741521467766,-8.161483167307903,-8.17022481314804,-8.178966458988175,-8.18770810482831,-8.196449750668448,-8.205191396508585,-8.213933042348723,-8.222674688188858,-8.231416334028994,-8.24015797986913,-8.248899625709267,-8.257641271549405,-8.26638291738954,-8.275124563229676,-8.283866209069814,-8.29260785490995,-8.301349500750085,-8.310091146590223,-8.318832792430358,-8.327574438270494,-8.336316084110631,-8.345057729950767,-8.353799375790905,-8.362541021631042,-8.371282667471178,-8.380024313311313,-8.38876595915145,-8.397507604991587,-8.406249250831722,-8.41499089667186,-8.423732542511996,-8.432474188352133,-8.441215834192269,-8.449957480032406,-8.458699125872542,-8.46744077171268,-8.476182417552815,-8.484924063392953,-8.493665709233088,-8.502407355073224,-8.511149000913361,-8.519890646753497,-8.528632292593633,-8.53737393843377,-8.546115584273906,-8.554857230114044,-8.56359887595418,-8.572340521794317,-8.581082167634452,-8.58982381347459,-8.598565459314724,-8.607307105154861,-8.616048750994999,-8.624790396835134,-8.633532042675272,-8.642273688515408,-8.651015334355543,-8.65975698019568,-8.668498626035817,-8.677240271875954,-8.68598191771609,-8.696704661347324,-8.709408502769657,-8.722112344191988,-8.734816185614319,-8.74752002703665,-8.760223868458983,-8.772927709881314,-8.785631551303647,-8.798335392725978,-8.811039234148309,-8.823743075570642,-8.836446916992974,-8.849150758415306,-8.861854599837637,-8.874558441259968,-8.8872622826823,-8.899966124104632,-8.912669965526963,-8.925373806949294,-8.938077648371626,-8.950781489793957,-8.96348533121629,-8.97618917263862,-8.988893014060952,-9.001596855483285,-9.014300696905618,-9.02700453832795,-9.03970837975028,-9.052412221172611,-9.065116062594944,-9.077819904017275,-9.090523745439606,-9.103227586861937,-9.114684342654758,-9.125085877814676,-9.13548741297459,-9.145888948134509,-9.156290483294423,-9.16669201845434,-9.177093553614252,-9.18749508877417,-9.197896623934085,-9.208298159094001,-9.218699694253917,-9.229101229413834,-9.239502764573746,-9.249904299733664,-9.260305834893582,-9.270707370053497,-9.281108905213411,-9.291510440373326,-9.301911975533244,-9.312313510693158,-9.322715045853077,-9.333116581012991,-9.343518116172906,-9.353919651332824,-9.364321186492738,-9.374722721652653,-9.385124256812569,-9.395525791972485,-9.4059273271324,-9.416328862292316,-9.426730397452232,-9.437131932612147,-9.447533467772063,-9.457935002931979,-9.468336538091895,-9.478738073251812,-9.489139608411726,-9.499541143571644,-9.509942678731559,-9.520344213891473,-9.53074574905139,-9.541147284211304,-9.55154881937122,-9.561950354531138,-9.572351889691053,-9.582753424850967,-9.593154960010885,-9.6035564951708,-9.613958030330714,-9.62435956549063,-9.634529230823421,-9.64423515650196,-9.653941082180499,-9.663647007859037,-9.673352933537576,-9.683058859216114,-9.692764784894655,-9.702470710573195,-9.712176636251732,-9.721882561930272,-9.73158848760881,-9.74129441328735,-9.751000338965888,-9.760706264644428,-9.770412190322967,-9.780118116001507,-9.789824041680045,-9.799529967358584,-9.809235893037123,-9.818941818715661,-9.828647744394202,-9.83835367007274,-9.848059595751279,-9.857765521429819,-9.867471447108358,-9.877177372786896,-9.886883298465435,-9.896589224143973,-9.906295149822512,-9.916001075501052,-9.92570700117959,-9.935412926858127,-9.945118852536668,-9.954824778215208,-9.964530703893747,-9.974236629572285,-9.983942555250824,-9.993648480929362,-10.003354406607901,-10.01306033228644,-10.022766257964978,-10.032472183643517,-10.042178109322055,-10.051884035000597,-10.061589960679136,-10.071295886357674,-10.081001812036213,-10.090707737714752,-10.10041366339329,-10.110119589071829,-10.119825514750369,-10.129531440428908,-10.139237366107446,-10.148943291785987,-10.158649217464525,-10.168355143143064,-10.178061068821602,-10.18776699450014,-10.197472920178681,-10.20717884585722,-10.216884771535758,-10.226590697214297,-10.236296622892837,-10.246002548571376,-10.255708474249914,-10.265414399928453,-10.275120325606991,-10.28482625128553,-10.29453217696407,-10.304238102642607,-10.313944028321147,-10.323649953999688,-10.333355879678226,-10.343061805356767,-10.352767731035303,-10.362471985288437,-10.372097674842484,-10.38172336439653,-10.391349053950576,-10.400974743504623,-10.410600433058667,-10.420226122612712,-10.42985181216676,-10.438878427911167,-10.44490967460739,-10.450940921303612,-10.450185183038755,-10.446687362830275,-10.443189542621795,-10.439691722413315,-10.436193902204833,-10.432696081996353,-10.429198261787871,-10.42570044157939,-10.422202621370909,-10.41870480116243,-10.415206980953949,-10.411709160745469,-10.408211340536987,-10.404713520328507,-10.401215700120026,-10.397717879911546,-10.394220059703065,-10.390722239494584,-10.387224419286103,-10.383726599077622,-10.380228778869144,-10.376730958660662,-10.37323313845218,-10.3697353182437,-10.36623749803522,-10.362739677826738,-10.359241857618258,-10.355744037409778,-10.352246217201298,-10.348748396992816,-10.345250576784336,-10.341752756575856,-10.338254936367374,-10.334757116158894,-10.331259295950414,-10.327761475741934,-10.324263655533452,-10.320765835324972,-10.31726801511649,-10.30680258116516,-10.291360280254656,-10.27591797934415,-10.260475678433645,-10.245033377523145,-10.229591076612635,-10.214148775702128,-10.198706474791624,-10.183264173881122,-10.167821872970617,-10.15237957206011,-10.136937271149606,-10.121494970239102,-10.106052669328594,-10.09061036841809,-10.075168067507585,-10.05972576659708,-10.044283465686576,-10.02884116477607,-10.013398863865564,-9.997956562955059,-9.982514262044557,-9.96707196113405,-9.951629660223544,-9.93618735931304,-9.920745058402535,-9.905302757492029,-9.889860456581527,-9.87441815567102,-9.858975854760514,-9.843533553850008,-9.828091252939506,-9.812648952028999,-9.797206651118493,-9.781764350207991,-9.766322049297484,-9.750879748386978,-9.735437447476475,-9.719995146565969,-9.698215100232977,-9.668826107094278,-9.639437113955584],[-5.995951683348538,-6.006081753698607,-6.016211824048676,-6.026341894398746,-6.036471964748816,-6.046602035098886,-6.056732105448954,-6.066862175799024,-6.076992246149093,-6.087122316499164,-6.097252386849233,-6.107382457199302,-6.117512527549372,-6.127642597899442,-6.137772668249511,-6.14790273859958,-6.158032808949649,-6.168162879299719,-6.178292949649789,-6.188423019999858,-6.198553090349927,-6.208683160699997,-6.218813231050066,-6.228943301400136,-6.239073371750206,-6.249203442100275,-6.259333512450344,-6.269463582800414,-6.279593653150483,-6.289723723500553,-6.299853793850623,-6.309983864200692,-6.320113934550761,-6.330244004900831,-6.340374075250901,-6.35050414560097,-6.360634215951039,-6.3707642863011085,-6.380894356651179,-6.391024427001248,-6.4011544973513175,-6.4112845677013865,-6.4214146380514565,-6.4315447084015265,-6.4416747787515956,-6.451804849101665,-6.461934919451735,-6.472064989801804,-6.482195060151874,-6.492325130501943,-6.502455200852012,-6.512585271202083,-6.522715341552152,-6.532845411902221,-6.542975482252291,-6.553105552602361,-6.56323562295243,-6.573365693302499,-6.583495763652569,-6.593625834002638,-6.603755904352708,-6.613885974702777,-6.624016045052847,-6.631552459408649,-6.638570145780826,-6.6455878321530015,-6.652605518525179,-6.659623204897355,-6.666640891269531,-6.673658577641708,-6.680676264013885,-6.687693950386061,-6.694711636758237,-6.701729323130414,-6.7087470095025905,-6.715764695874767,-6.722782382246944,-6.729800068619119,-6.736817754991296,-6.743835441363474,-6.75085312773565,-6.757870814107826,-6.764888500480002,-6.771906186852179,-6.779950145104817,-6.788199357733549,-6.79644857036228,-6.804697782991012,-6.812946995619743,-6.821196208248474,-6.829445420877206,-6.837694633505937,-6.84594384613467,-6.854193058763402,-6.862442271392133,-6.870691484020863,-6.878940696649597,-6.887189909278327,-6.895439121907059,-6.903688334535791,-6.911937547164522,-6.920186759793253,-6.928435972421985,-6.936685185050717,-6.9449343976794475,-6.953183610308179,-6.961432822936911,-6.969682035565642,-6.977931248194374,-6.986180460823105,-6.994429673451837,-7.002678886080568,-7.0109280987093,-7.019177311338032,-7.0274265239667635,-7.035675736595495,-7.043924949224227,-7.0521741618529585,-7.060423374481688,-7.068672587110422,-7.076921799739152,-7.0851710123678835,-7.093420224996615,-7.101669437625347,-7.1099186502540785,-7.11816786288281,-7.126417075511542,-7.134666288140274,-7.142915500769004,-7.151164713397736,-7.159413926026467,-7.167663138655199,-7.17591235128393,-7.184161563912662,-7.1924107765413945,-7.200659989170125,-7.208909201798857,-7.217158414427589,-7.22540762705632,-7.233656839685051,-7.241906052313783,-7.250155264942514,-7.258404477571246,-7.266653690199978,-7.2749029028287095,-7.28315211545744,-7.289523056018169,-7.29495486418302,-7.300386672347872,-7.305818480512724,-7.311250288677575,-7.3166820968424275,-7.32211390500728,-7.327545713172131,-7.332977521336983,-7.338409329501834,-7.343841137666686,-7.349272945831538,-7.35470475399639,-7.360136562161242,-7.365568370326093,-7.371000178490945,-7.376431986655798,-7.3818637948206485,-7.387295602985501,-7.392727411150353,-7.398159219315204,-7.405277640027714,-7.4132393670140555,-7.421201094000395,-7.429162820986736,-7.437124547973076,-7.445086274959417,-7.453048001945757,-7.461009728932098,-7.468971455918437,-7.476933182904777,-7.484894909891118,-7.492856636877459,-7.500818363863798,-7.508780090850139,-7.516741817836479,-7.5247035448228194,-7.53266527180916,-7.540626998795501,-7.5485887257818405,-7.556550452768182,-7.56451217975452,-7.5724739067408615,-7.580435633727202,-7.588397360713542,-7.5963590876998826,-7.604320814686222,-7.612282541672564,-7.620244268658903,-7.628205995645244,-7.636167722631584,-7.644129449617925,-7.652091176604266,-7.660052903590605,-7.668014630576946,-7.675976357563285,-7.683938084549626,-7.691899811535966,-7.699861538522307,-7.7078232655086465,-7.715784992494989,-7.723746719481328,-7.731708446467668,-7.739670173454008,-7.747631900440348,-7.7555936274266895,-7.76355535441303,-7.771517081399369,-7.779478808385709,-7.78744053537205,-7.795402262358391,-7.8033639893447315,-7.811325716331071,-7.819287443317412,-7.827249170303752,-7.835210897290093,-7.843172624276432,-7.851134351262772,-7.859096078249113,-7.867057805235453,-7.875019532221795,-7.882981259208134,-7.890942986194474,-7.898904713180816,-7.906866440167155,-7.914828167153495,-7.922789894139836,-7.930751621126176,-7.9387133481125165,-7.946675075098857,-7.954636802085198,-7.9625985290715375,-7.970560256057877,-7.978521983044218,-7.986483710030559,-7.994445437016898,-8.00240716400324,-8.010368890989579,-8.01833061797592,-8.026292344962261,-8.0342540719486,-8.042345782836842,-8.051087428676977,-8.059829074517115,-8.070551818148349,-8.082871938061475,-8.09327347322139,-8.103675008381304,-8.114076543541222,-8.124478078701136,-8.134879613861052,-8.145281149020969,-8.155682684180885,-8.1660842193408,-8.176485754500714,-8.186887289660632,-8.197288824820548,-8.207690359980463,-8.218091895140379,-8.228493430300295,-8.23889496546021,-8.249296500620126,-8.25969803578004,-8.270099570939955,-8.280501106099873,-8.29090264125979,-8.301304176419704,-8.31170571157962,-8.322107246739536,-8.33250878189945,-8.342910317059365,-8.353311852219282,-8.3637133873792,-8.374114922539114,-8.38451645769903,-8.394917992858947,-8.405319528018861,-8.415721063178777,-8.426122598338694,-8.436524133498608,-8.446925668658524,-8.45732720381844,-8.467728738978355,-8.478130274138271,-8.488531809298188,-8.498933344458104,-8.509334879618017,-8.519736414777935,-8.530137949937853,-8.540539485097765,-8.550941020257682,-8.561342555417598,-8.571744090577514,-8.582145625737427,-8.592547160897345,-8.602948696057261,-8.613350231217176,-8.623751766377092,-8.634153301537008,-8.644554836696923,-8.654956371856839,-8.665357907016755,-8.67575944217667,-8.686160977336586,-8.696562512496502,-8.706964047656417,-8.717365582816333,-8.72776711797625,-8.738168653136164,-8.74857018829608,-8.758971723455996,-8.769373258615913,-8.779774793775827,-8.790176328935743,-8.80057786409566,-8.810979399255574,-8.82138093441549,-8.831782469575407,-8.842184004735321,-8.852585539895237,-8.862987075055154,-8.873388610215068,-8.883790145374984,-8.8941916805349,-8.904593215694817,-8.914994750854733,-8.925396286014648,-8.935565951347439,-8.945271877025977,-8.954977802704516,-8.964683728383054,-8.974389654061593,-8.984095579740131,-8.993801505418674,-9.003507431097212,-9.013213356775749,-9.02291928245429,-9.03262520813283,-9.042331133811368,-9.052037059489905,-9.061742985168445,-9.071448910846984,-9.081154836525522,-9.090860762204063,-9.100566687882601,-9.11027261356114,-9.119978539239678,-9.129684464918219,-9.139390390596756,-9.149096316275296,-9.158802241953834,-9.168508167632373,-9.178214093310912,-9.18792001898945,-9.197191371796064,-9.206288895059533,-9.215386418323,-9.224483941586469,-9.233581464849935,-9.242678988113404,-9.251776511376871,-9.26087403464034,-9.269971557903805,-9.279069081167275,-9.288166604430742,-9.29726412769421,-9.306361650957676,-9.315459174221145,-9.324556697484613,-9.33365422074808,-9.342751744011549,-9.351849267275018,-9.360946790538483,-9.370044313801952,-9.379141837065418,-9.388239360328887,-9.397336883592354,-9.406434406855823,-9.41553193011929,-9.424629453382758,-9.433726976646227,-9.442824499909692,-9.45192202317316,-9.46101954643663,-9.470117069700098,-9.479214592963565,-9.488312116227032,-9.497409639490499,-9.506507162753968,-9.515604686017436,-9.524702209280903,-9.53379973254437,-9.542897255807839,-9.551994779071308,-9.561092302334774,-9.570189825598241,-9.57928734886171,-9.588384872125177,-9.597482395388644,-9.606579918652113,-9.615677441915581,-9.62477496517905,-9.633872488442515,-9.642970011705984,-9.65206753496945,-9.66116505823292,-9.670262581496386,-9.679360104759853,-9.688457628023322,-9.69755515128679,-9.703916694965628,-9.696598340721325,-9.68927998647702,-9.681961632232715,-9.67464327798841,-9.667324923744108,-9.660006569499803,-9.652688215255498,-9.645369861011195,-9.63805150676689,-9.630733152522588,-9.623414798278283,-9.616096444033978,-9.610313669940265,-9.606855018966993,-9.603396367993719,-9.599937717020447,-9.596479066047177,-9.593020415073903,-9.589561764100631,-9.58610311312736,-9.58264446215409,-9.579185811180816,-9.575727160207544,-9.57226850923427,-9.568809858260998,-9.565351207287726,-9.561892556314454,-9.558433905341182,-9.55497525436791,-9.551516603394637,-9.548057952421367,-9.544599301448095,-9.541140650474821,-9.53768199950155,-9.534223348528277,-9.530764697555004,-9.527306046581732,-9.52384739560846,-9.520388744635188,-9.516930093661916,-9.513471442688644,-9.502999480531447,-9.487518010385735,-9.472036540240019,-9.456555070094305,-9.441073599948595,-9.42559212980288,-9.410110659657164,-9.394629189511452,-9.37914771936574,-9.363666249220024,-9.34818477907431,-9.332703308928599,-9.317221838782883,-9.30174036863717,-9.286258898491457,-9.270777428345744,-9.25529595820003,-9.239814488054314,-9.224333017908604,-9.20885154776289,-9.193370077617175,-9.177888607471463,-9.162407137325749,-9.146925667180033,-9.131444197034321,-9.11596272688861,-9.100481256742892,-9.084999786597184,-9.069518316451466,-9.055736661939694,-9.042466140263404,-9.029195618587112,-9.01592509691082,-9.002654575234526,-8.989384053558236,-8.976113531881944,-8.962843010205649,-8.94957248852936,-8.936301966853069,-8.923031445176775,-8.909760923500482,-8.896490401824192],[-5.516970218413122,-5.527100288763192,-5.537230359113261,-5.547360429463331,-5.5574904998134,-5.56762057016347,-5.577750640513539,-5.587880710863608,-5.598010781213678,-5.608140851563748,-5.618270921913817,-5.628400992263886,-5.638531062613956,-5.648661132964026,-5.658791203314095,-5.668921273664165,-5.679051344014233,-5.689181414364303,-5.699311484714373,-5.709441555064443,-5.719571625414512,-5.729701695764581,-5.739831766114651,-5.7499618364647205,-5.76009190681479,-5.7702219771648595,-5.7803520475149295,-5.790482117864999,-5.8006121882150685,-5.810742258565138,-5.820872328915207,-5.831002399265277,-5.841132469615346,-5.851262539965417,-5.861392610315486,-5.871522680665555,-5.881652751015625,-5.891782821365694,-5.901912891715764,-5.912042962065833,-5.922173032415902,-5.932303102765971,-5.942433173116041,-5.952563243466111,-5.96269331381618,-5.97282338416625,-5.9819159899974546,-5.988933676369631,-5.995951362741808,-6.002969049113984,-6.0099867354861605,-6.017004421858337,-6.024022108230514,-6.03103979460269,-6.038057480974867,-6.0450751673470435,-6.052092853719219,-6.059110540091396,-6.066128226463572,-6.073145912835749,-6.080163599207925,-6.087181285580102,-6.094198971952278,-6.101216658324455,-6.108234344696632,-6.115252031068808,-6.122269717440984,-6.12928740381316,-6.1363050901853375,-6.143322776557514,-6.150340462929689,-6.157358149301866,-6.164375835674043,-6.17139352204622,-6.178411208418396,-6.185428894790573,-6.192446581162749,-6.199464267534926,-6.206481953907103,-6.213499640279279,-6.220517326651455,-6.2275350130236315,-6.234552699395808,-6.241570385767985,-6.249614344020623,-6.257863556649355,-6.266112769278086,-6.274361981906818,-6.28261119453555,-6.290860407164281,-6.299109619793013,-6.307358832421743,-6.3156080450504755,-6.323857257679208,-6.332106470307939,-6.34035568293667,-6.348604895565402,-6.356854108194133,-6.365103320822866,-6.373352533451596,-6.381601746080328,-6.38985095870906,-6.398100171337791,-6.406349383966523,-6.414598596595255,-6.422847809223985,-6.431097021852718,-6.439346234481448,-6.44759544711018,-6.455844659738911,-6.464093872367643,-6.472343084996375,-6.4805922976251065,-6.488841510253838,-6.49709072288257,-6.5053399355113015,-6.513589148140032,-6.521838360768763,-6.530087573397496,-6.5383367860262265,-6.546585998654959,-6.55483521128369,-6.563084423912421,-6.571333636541153,-6.579582849169884,-6.587832061798617,-6.596081274427348,-6.60433048705608,-6.612579699684812,-6.620359342012606,-6.625791150177458,-6.63122295834231,-6.636654766507162,-6.642086574672013,-6.647518382836865,-6.652950191001716,-6.6583819991665685,-6.663813807331421,-6.669245615496273,-6.674677423661125,-6.680109231825975,-6.685541039990828,-6.690972848155679,-6.696404656320531,-6.701836464485384,-6.707268272650234,-6.712700080815086,-6.718131888979938,-6.72356369714479,-6.7289955053096415,-6.734427313474493,-6.739859121639345,-6.745290929804197,-6.750722737969048,-6.7561545461339,-6.7615863542987515,-6.7670181624636045,-6.772449970628455,-6.777881778793308,-6.783313586958159,-6.788745395123012,-6.7941772032878625,-6.7996090114527155,-6.805040819617567,-6.810472627782418,-6.81590443594727,-6.821336244112122,-6.8284546648246325,-6.836416391810973,-6.844378118797312,-6.8523398457836535,-6.860301572769994,-6.868263299756334,-6.876225026742674,-6.884186753729015,-6.892148480715355,-6.900110207701696,-6.908071934688036,-6.916033661674376,-6.923995388660716,-6.931957115647057,-6.939918842633396,-6.947880569619737,-6.955842296606077,-6.963804023592418,-6.971765750578758,-6.979727477565098,-6.9876892045514385,-6.995650931537779,-7.003612658524119,-7.01157438551046,-7.019536112496801,-7.02749783948314,-7.035459566469481,-7.043421293455821,-7.051383020442161,-7.059344747428501,-7.067306474414842,-7.075268201401183,-7.083229928387523,-7.091191655373863,-7.099153382360202,-7.107115109346544,-7.115076836332884,-7.123038563319224,-7.131000290305565,-7.138962017291905,-7.146923744278245,-7.154885471264585,-7.162847198250926,-7.170808925237266,-7.178770652223607,-7.186732379209948,-7.1946941061962875,-7.202655833182627,-7.210617560168968,-7.218579287155308,-7.226541014141649,-7.234502741127989,-7.2424644681143295,-7.25042619510067,-7.25838792208701,-7.26634964907335,-7.27431137605969,-7.282273103046031,-7.290234830032372,-7.298196557018711,-7.306158284005052,-7.314120010991392,-7.3199609561333006,-7.325519134143399,-7.331077312153499,-7.336635490163599,-7.342193668173698,-7.347751846183797,-7.353310024193895,-7.358868202203995,-7.364426380214095,-7.369984558224193,-7.3755427362342925,-7.381100914244391,-7.38665909225449,-7.392217270264589,-7.397775448274689,-7.4033336262847875,-7.408891804294887,-7.414449982304986,-7.420008160315086,-7.425566338325185,-7.431124516335284,-7.43767068317219,-7.445204838835904,-7.452738994499617,-7.460273150163331,-7.467807305827044,-7.475341461490758,-7.482875617154471,-7.490409772818184,-7.4979439284819,-7.5054780841456115,-7.513012239809325,-7.520546395473039,-7.528080551136752,-7.535614706800466,-7.54314886246418,-7.550683018127892,-7.558217173791607,-7.5657513294553205,-7.573285485119032,-7.580819640782746,-7.588353796446461,-7.595887952110174,-7.603422107773887,-7.6109562634376005,-7.620177912750172,-7.630594081546205,-7.641010250342237,-7.65142641913827,-7.661842587934302,-7.672258756730335,-7.682674925526367,-7.6930910943224,-7.70350726311843,-7.713923431914464,-7.724339600710497,-7.7347557695065285,-7.745171938302561,-7.755588107098594,-7.766004275894626,-7.776420444690658,-7.786836613486691,-7.7972527822827224,-7.807668951078756,-7.818085119874788,-7.828501288670821,-7.838917457466852,-7.849333626262886,-7.859749795058919,-7.870165963854951,-7.880582132650982,-7.8909983014470155,-7.901414470243048,-7.9118306390390805,-7.922246807835112,-7.9326629766311445,-7.943079145427177,-7.953495314223209,-7.963911483019243,-7.974327651815274,-7.984743820611307,-7.995159989407339,-8.005576158203372,-8.015992326999404,-8.026408495795437,-8.03682466459147,-8.047240833387502,-8.057657002183532,-8.068073170979567,-8.078489339775597,-8.088905508571631,-8.099321677367664,-8.109737846163695,-8.120154014959727,-8.130570183755761,-8.140986352551792,-8.151402521347825,-8.161818690143857,-8.172234858939891,-8.182651027735922,-8.193067196531954,-8.203483365327989,-8.21389953412402,-8.224315702920052,-8.234046896642676,-8.242408140218483,-8.25076938379429,-8.259130627370098,-8.267491870945905,-8.275853114521714,-8.284214358097522,-8.29257560167333,-8.300936845249137,-8.309298088824944,-8.317659332400751,-8.326020575976559,-8.334381819552366,-8.342743063128175,-8.351104306703983,-8.359465550279788,-8.367826793855597,-8.376188037431405,-8.384549281007212,-8.39291052458302,-8.401271768158828,-8.409633011734636,-8.417994255310443,-8.42635549888625,-8.43471674246206,-8.443077986037865,-8.451439229613673,-8.45980047318948,-8.46816171676529,-8.476522960341097,-8.484884203916904,-8.49338805992728,-8.502485583190749,-8.511583106454216,-8.520680629717685,-8.529778152981152,-8.53887567624462,-8.547973199508087,-8.557070722771556,-8.566168246035023,-8.57526576929849,-8.584363292561958,-8.593460815825427,-8.602558339088894,-8.611655862352361,-8.62075338561583,-8.629850908879297,-8.638948432142765,-8.648045955406232,-8.6571434786697,-8.666241001933168,-8.675338525196636,-8.684436048460103,-8.693533571723572,-8.702631094987037,-8.711728618250508,-8.720826141513975,-8.729923664777441,-8.739021188040908,-8.748118711304379,-8.757216234567846,-8.766313757831313,-8.77541128109478,-8.784508804358246,-8.793606327621715,-8.802703850885184,-8.811801374148652,-8.820898897412118,-8.829996420675586,-8.839093943939055,-8.848191467202522,-8.857288990465989,-8.866386513729458,-8.875484036992926,-8.884581560256393,-8.893679083519862,-8.90277660678333,-8.911874130046796,-8.920971653310264,-8.930069176573733,-8.9391666998372,-8.948264223100667,-8.957361746364136,-8.963723290042973,-8.956404935798668,-8.949086581554365,-8.94176822731006,-8.934449873065756,-8.927131518821453,-8.919813164577148,-8.912494810332845,-8.90517645608854,-8.897858101844236,-8.890539747599933,-8.883221393355628,-8.875903039111323,-8.86858468486702,-8.861266330622716,-8.85394797637841,-8.846629622134108,-8.839311267889805,-8.8319929136455,-8.824674559401195,-8.817356205156893,-8.810037850912586,-8.802719496668283,-8.79540114242398,-8.788082788179675,-8.78076443393537,-8.773446079691066,-8.766127725446763,-8.759177704618626,-8.755719053645352,-8.75226040267208,-8.748801751698808,-8.745343100725535,-8.741884449752265,-8.73842579877899,-8.734967147805719,-8.731508496832447,-8.728049845859175,-8.724591194885903,-8.721132543912631,-8.717673892939358,-8.714215241966087,-8.703743279808888,-8.688261809663176,-8.672780339517463,-8.657298869371747,-8.641817399226037,-8.626335929080321,-8.610854458934607,-8.595372988788894,-8.579891518643182,-8.564410048497468,-8.548928578351752,-8.53344710820604,-8.517965638060325,-8.502641667406461,-8.489371145730171,-8.47610062405388,-8.462830102377588,-8.449559580701294,-8.436289059025004,-8.42301853734871,-8.409748015672418,-8.396477493996128,-8.383206972319837,-8.369936450643543,-8.356665928967253,-8.343395407290961,-8.330124885614667,-8.316854363938377,-8.303583842262086,-8.290313320585792,-8.2770427989095,-8.26377227723321,-8.250501755556916,-8.237231233880625,-8.223960712204335,-8.210690190528041,-8.197419668851747,-8.184149147175459,-8.170878625499165,-8.157608103822874,-8.14433758214658,-8.13106706047029],[-5.037988753477707,-5.048118823827776,-5.058248894177845,-5.068378964527916,-5.078509034877985,-5.088639105228054,-5.098769175578124,-5.1088992459281934,-5.119029316278263,-5.1291593866283325,-5.1392894569784024,-5.1494195273284715,-5.1595495976785415,-5.169679668028611,-5.1798097383786805,-5.1899398087287505,-5.20006987907882,-5.210199949428889,-5.220330019778958,-5.230460090129028,-5.240590160479098,-5.250720230829167,-5.260850301179236,-5.270980371529307,-5.281110441879376,-5.291240512229445,-5.301370582579514,-5.311500652929583,-5.321630723279654,-5.331760793629723,-5.339297206958438,-5.346314893330614,-5.353332579702791,-5.360350266074967,-5.367367952447143,-5.37438563881932,-5.381403325191497,-5.388421011563673,-5.39543869793585,-5.402456384308026,-5.4094740706802025,-5.416491757052379,-5.423509443424555,-5.430527129796732,-5.437544816168908,-5.444562502541085,-5.451580188913261,-5.458597875285438,-5.465615561657614,-5.472633248029791,-5.479650934401967,-5.486668620774144,-5.49368630714632,-5.5007039935184965,-5.507721679890673,-5.514739366262849,-5.521757052635026,-5.528774739007203,-5.535792425379379,-5.542810111751555,-5.549827798123732,-5.556845484495908,-5.5638631708680855,-5.570880857240261,-5.577898543612438,-5.584916229984614,-5.5919339163567905,-5.598951602728967,-5.605969289101143,-5.61298697547332,-5.620004661845496,-5.6270223482176736,-5.634040034589849,-5.641057720962025,-5.648075407334202,-5.655093093706379,-5.662110780078556,-5.669128466450731,-5.676146152822908,-5.6831638391950845,-5.690181525567262,-5.697199211939437,-5.704216898311614,-5.711234584683791,-5.719278542936429,-5.727527755565161,-5.735776968193893,-5.744026180822624,-5.752275393451356,-5.760524606080087,-5.7687738187088184,-5.77702303133755,-5.785272243966281,-5.7935214565950135,-5.801770669223745,-5.810019881852476,-5.818269094481208,-5.826518307109939,-5.834767519738671,-5.843016732367403,-5.851265944996134,-5.859515157624865,-5.867764370253598,-5.876013582882329,-5.884262795511059,-5.892512008139791,-5.900761220768523,-5.909010433397254,-5.917259646025986,-5.925508858654718,-5.9337580712834495,-5.942007283912181,-5.950256496540912,-5.956627436171896,-5.962059244336748,-5.967491052501599,-5.972922860666451,-5.978354668831303,-5.983786476996155,-5.989218285161006,-5.994650093325859,-6.00008190149071,-6.0055137096555615,-6.010945517820414,-6.016377325985266,-6.021809134150116,-6.027240942314968,-6.03267275047982,-6.038104558644672,-6.0435363668095246,-6.048968174974376,-6.054399983139227,-6.059831791304079,-6.065263599468931,-6.0706954076337825,-6.076127215798635,-6.081559023963486,-6.086990832128338,-6.09242264029319,-6.097854448458041,-6.1032862566228925,-6.108718064787745,-6.114149872952597,-6.119581681117448,-6.125013489282301,-6.130445297447153,-6.135877105612003,-6.1413089137768555,-6.146740721941708,-6.152172530106559,-6.157604338271411,-6.163036146436262,-6.168467954601114,-6.173899762765966,-6.1793315709308185,-6.18476337909567,-6.190195187260521,-6.195626995425374,-6.201058803590224,-6.206490611755076,-6.211922419919929,-6.21735422808478,-6.222786036249633,-6.228217844414484,-6.233649652579335,-6.239081460744187,-6.2445132689090395,-6.251631689621551,-6.25959341660789,-6.2675551435942305,-6.275516870580571,-6.283478597566911,-6.2914403245532515,-6.299402051539593,-6.307363778525932,-6.3153255055122735,-6.323287232498613,-6.331248959484954,-6.3392106864712945,-6.347172413457635,-6.355134140443974,-6.363095867430315,-6.371057594416655,-6.379019321402996,-6.386981048389336,-6.394942775375676,-6.402904502362016,-6.410866229348356,-6.418827956334697,-6.426789683321037,-6.434751410307378,-6.442713137293717,-6.4506748642800575,-6.4586365912664,-6.466598318252739,-6.4745600452390795,-6.48252177222542,-6.490483499211759,-6.4984452261981005,-6.506406953184441,-6.514368680170781,-6.522330407157121,-6.530292134143461,-6.538253861129803,-6.546215588116143,-6.554177315102483,-6.561644189897644,-6.567202367907742,-6.572760545917841,-6.578318723927941,-6.583876901938041,-6.58943507994814,-6.594993257958238,-6.600551435968337,-6.606109613978437,-6.611667791988536,-6.6172259699986355,-6.6227841480087335,-6.628342326018833,-6.633900504028933,-6.639458682039031,-6.6450168600491315,-6.65057503805923,-6.656133216069329,-6.66169139407943,-6.667249572089528,-6.6728077500996275,-6.678365928109727,-6.683924106119825,-6.689482284129925,-6.695040462140025,-6.700598640150124,-6.706156818160223,-6.711714996170322,-6.717273174180421,-6.72283135219052,-6.728389530200619,-6.733947708210719,-6.739505886220817,-6.745064064230916,-6.750622242241016,-6.756180420251114,-6.761738598261214,-6.767296776271314,-6.772854954281412,-6.7784131322915115,-6.783971310301611,-6.78952948831171,-6.79508766632181,-6.800645844331909,-6.807192011168814,-6.8147261668325285,-6.822260322496242,-6.829794478159956,-6.837328633823669,-6.844862789487382,-6.852396945151096,-6.859931100814809,-6.867465256478523,-6.874999412142236,-6.88253356780595,-6.890067723469663,-6.897601879133377,-6.905136034797091,-6.912670190460804,-6.9202043461245175,-6.92773850178823,-6.935272657451945,-6.9428068131156575,-6.950340968779371,-6.957875124443085,-6.9654092801067975,-6.972943435770512,-6.980477591434226,-6.988011747097939,-6.995545902761653,-7.003080058425366,-7.01061421408908,-7.018148369752792,-7.0256825254165065,-7.033216681080219,-7.040750836743934,-7.0482849924076465,-7.05581914807136,-7.063353303735075,-7.070887459398787,-7.078421615062501,-7.085955770726215,-7.093489926389928,-7.101024082053641,-7.108558237717355,-7.116092393381069,-7.123626549044781,-7.1311607047084955,-7.138694860372209,-7.146229016035922,-7.153763171699636,-7.161297327363349,-7.168831483027063,-7.178147938432903,-7.1885641072289355,-7.198980276024969,-7.2093964448209995,-7.219812613617033,-7.230228782413066,-7.240644951209097,-7.251061120005129,-7.261477288801163,-7.271893457597194,-7.282309626393228,-7.29272579518926,-7.303141963985292,-7.313558132781324,-7.323974301577357,-7.334390470373389,-7.344806639169422,-7.355222807965454,-7.3656389767614865,-7.376055145557517,-7.386471314353551,-7.396887483149584,-7.407303651945616,-7.417719820741649,-7.428135989537681,-7.438552158333714,-7.448968327129744,-7.459384495925779,-7.469800664721809,-7.480216833517842,-7.490633002313874,-7.501049171109908,-7.511465339905939,-7.521881508701972,-7.531612702424597,-7.539973946000403,-7.548335189576212,-7.55669643315202,-7.565057676727826,-7.5734189203036335,-7.581780163879442,-7.590141407455249,-7.5985026510310565,-7.606863894606865,-7.615225138182673,-7.623586381758479,-7.631947625334287,-7.640308868910096,-7.6486701124859025,-7.65703135606171,-7.665392599637517,-7.6737538432133245,-7.682115086789133,-7.690476330364939,-7.698837573940748,-7.707198817516556,-7.715560061092363,-7.7239213046681705,-7.73228254824398,-7.740643791819786,-7.749005035395594,-7.7573662789714,-7.765727522547209,-7.774088766123017,-7.782450009698825,-7.79081125327463,-7.799172496850439,-7.807533740426248,-7.815894984002054,-7.8242562275778615,-7.83261747115367,-7.840978714729477,-7.8493399583052845,-7.857701201881092,-7.866062445456898,-7.874423689032707,-7.882784932608515,-7.891146176184323,-7.8995074197601305,-7.907868663335937,-7.916229906911745,-7.924591150487553,-7.93295239406336,-7.941313637639167,-7.9496748812149765,-7.958036124790782,-7.96639736836659,-7.9747586119423985,-7.983119855518206,-7.991481099094014,-7.9998423426698215,-8.008203586245628,-8.016564829821435,-8.024926073397245,-8.033287316973052,-8.041648560548857,-8.050009804124667,-8.058371047700474,-8.066732291276281,-8.075093534852089,-8.083454778427898,-8.091816022003703,-8.10017726557951,-8.10853850915532,-8.116899752731127,-8.125260996306935,-8.133622239882742,-8.14198348345855,-8.150344727034357,-8.158705970610166,-8.167067214185973,-8.175428457761779,-8.183789701337586,-8.192150944913397,-8.200512188489203,-8.20887343206501,-8.21723467564082,-8.223529885120318,-8.216211530876013,-8.20889317663171,-8.201574822387405,-8.194256468143102,-8.186846224129635,-8.179370349505033,-8.171894474880434,-8.164418600255834,-8.156942725631232,-8.149466851006634,-8.141990976382035,-8.134515101757433,-8.127039227132832,-8.119563352508234,-8.112087477883634,-8.104611603259032,-8.097135728634433,-8.089659854009831,-8.082183979385233,-8.074708104760633,-8.067232230136032,-8.059756355511432,-8.052280480886832,-8.044804606262232,-8.037328731637631,-8.02985285701303,-8.022376982388431,-8.01490110776383,-8.00742523313923,-7.999949358514631,-7.992473483890031,-7.984997609265431,-7.977521734640831,-7.9700458600162305,-7.96256998539163,-7.955094110767029,-7.9476182361424295,-7.94014236151783,-7.932666486893228,-7.92519061226863,-7.917714737644029,-7.9069040017421655,-7.893711222070832,-7.880518442399494,-7.867325662728158,-7.854132883056824,-7.840940103385487,-7.82774732371415,-7.814554544042813,-7.80136176437148,-7.7881689847001425,-7.774976205028805,-7.761783425357472,-7.748590645686136,-7.735397866014798,-7.722205086343464,-7.709012306672127,-7.695819527000791,-7.682626747329454,-7.6694339676581205,-7.656241187986784,-7.643048408315447,-7.629855628644112,-7.616662848972776,-7.603470069301439,-7.590277289630105,-7.57708450995877,-7.563891730287431,-7.550698950616098,-7.537506170944761,-7.524313391273424,-7.511120611602088,-7.4979278319307525,-7.484735052259417,-7.4715422725880805,-7.458349492916746,-7.445156713245409,-7.431963933574074,-7.418725805821556,-7.405455284145264,-7.392184762468971,-7.378914240792678,-7.365643719116388],[-4.5590072885423005,-4.5691373588923705,-4.57926742924244,-4.5893974995925095,-4.599527569942579,-4.609657640292649,-4.619787710642718,-4.629917780992788,-4.640047851342857,-4.650177921692926,-4.660307992042997,-4.670438062393066,-4.680568132743135,-4.689660737547254,-4.69667842391943,-4.703696110291607,-4.710713796663783,-4.717731483035959,-4.7247491694081365,-4.731766855780313,-4.738784542152489,-4.745802228524666,-4.7528199148968415,-4.759837601269019,-4.766855287641195,-4.773872974013372,-4.780890660385548,-4.787908346757725,-4.794926033129901,-4.801943719502077,-4.808961405874253,-4.81597909224643,-4.822996778618607,-4.830014464990783,-4.83703215136296,-4.844049837735136,-4.851067524107313,-4.858085210479489,-4.865102896851666,-4.872120583223842,-4.879138269596019,-4.886155955968195,-4.893173642340372,-4.900191328712548,-4.9072090150847245,-4.914226701456901,-4.921244387829077,-4.928262074201254,-4.93527976057343,-4.942297446945606,-4.949315133317784,-4.956332819689959,-4.963350506062136,-4.970368192434313,-4.977385878806489,-4.984403565178665,-4.991421251550842,-4.9984389379230185,-5.005456624295195,-5.012474310667372,-5.019491997039548,-5.026509683411724,-5.033527369783902,-5.040545056156078,-5.047562742528254,-5.054580428900431,-5.061598115272607,-5.068615801644784,-5.07563348801696,-5.082651174389136,-5.0896688607613125,-5.096686547133489,-5.103704233505666,-5.110721919877842,-5.1177396062500184,-5.124757292622196,-5.131774978994371,-5.138792665366548,-5.145810351738724,-5.1528280381109015,-5.159845724483078,-5.166863410855254,-5.173881097227429,-5.1808987835996065,-5.1889427418522445,-5.197191954480977,-5.205441167109708,-5.2136903797384395,-5.221939592367171,-5.230188804995903,-5.238438017624635,-5.246687230253366,-5.254936442882098,-5.26318565551083,-5.271434868139561,-5.279684080768293,-5.287463722166344,-5.2928955303311955,-5.298327338496048,-5.3037591466609,-5.309190954825752,-5.314622762990604,-5.320054571155455,-5.325486379320307,-5.3309181874851586,-5.336349995650011,-5.341781803814863,-5.347213611979714,-5.352645420144566,-5.358077228309417,-5.3635090364742695,-5.368940844639122,-5.374372652803973,-5.379804460968826,-5.385236269133676,-5.390668077298528,-5.39609988546338,-5.401531693628232,-5.406963501793083,-5.412395309957935,-5.417827118122787,-5.423258926287639,-5.428690734452491,-5.4341225426173425,-5.439554350782194,-5.444986158947046,-5.450417967111898,-5.455849775276749,-5.461281583441601,-5.4667133916064525,-5.472145199771305,-5.477577007936157,-5.483008816101008,-5.48844062426586,-5.493872432430711,-5.499304240595563,-5.504736048760416,-5.510167856925267,-5.515599665090119,-5.52103147325497,-5.526463281419822,-5.531895089584674,-5.537326897749526,-5.542758705914378,-5.548190514079229,-5.553622322244081,-5.559054130408933,-5.564485938573784,-5.5699177467386365,-5.575349554903489,-5.58078136306834,-5.586213171233192,-5.591644979398044,-5.597076787562895,-5.602508595727747,-5.607940403892599,-5.613372212057451,-5.618804020222302,-5.624235828387154,-5.629667636552005,-5.635099444716857,-5.6405312528817095,-5.645963061046561,-5.651394869211413,-5.656826677376264,-5.662258485541116,-5.667690293705967,-5.67480871441848,-5.682770441404818,-5.690732168391159,-5.698693895377501,-5.70665562236384,-5.714617349350181,-5.722579076336521,-5.730540803322862,-5.738502530309201,-5.746464257295542,-5.754425984281882,-5.762387711268222,-5.770349438254563,-5.778311165240903,-5.786272892227243,-5.794234619213584,-5.802196346199924,-5.808885601672098,-5.814443779682198,-5.820001957692296,-5.825560135702395,-5.831118313712494,-5.836676491722593,-5.842234669732693,-5.847792847742792,-5.8533510257528905,-5.85890920376299,-5.864467381773089,-5.870025559783189,-5.875583737793288,-5.881141915803386,-5.886700093813486,-5.892258271823585,-5.897816449833685,-5.9033746278437835,-5.908932805853882,-5.914490983863982,-5.920049161874081,-5.92560733988418,-5.9311655178942795,-5.936723695904378,-5.942281873914477,-5.947840051924577,-5.953398229934676,-5.958956407944776,-5.964514585954875,-5.970072763964973,-5.975630941975074,-5.9811891199851726,-5.986747297995272,-5.992305476005371,-5.99786365401547,-6.00342183202557,-6.0089800100356685,-6.014538188045767,-6.020096366055867,-6.025654544065965,-6.031212722076065,-6.0367709000861645,-6.042329078096264,-6.047887256106363,-6.053445434116462,-6.059003612126562,-6.06456179013666,-6.070119968146759,-6.075678146156859,-6.081236324166959,-6.0867945021770575,-6.092352680187157,-6.097910858197256,-6.103469036207356,-6.109027214217455,-6.1145853922275535,-6.120143570237653,-6.125701748247751,-6.131259926257851,-6.136818104267951,-6.14237628227805,-6.147934460288148,-6.153492638298248,-6.159050816308348,-6.164608994318446,-6.170167172328545,-6.1767133391654525,-6.184247494829165,-6.191781650492879,-6.1993158061565925,-6.206849961820305,-6.21438411748402,-6.2219182731477325,-6.229452428811446,-6.23698658447516,-6.2445207401388725,-6.252054895802587,-6.2595890514663,-6.267123207130014,-6.274657362793727,-6.282191518457441,-6.289725674121154,-6.297259829784867,-6.3047939854485815,-6.312328141112294,-6.319862296776008,-6.3273964524397215,-6.334930608103436,-6.342464763767148,-6.3499989194308615,-6.357533075094576,-6.365067230758289,-6.3726013864220015,-6.380135542085716,-6.387669697749429,-6.395203853413143,-6.402738009076856,-6.4102721647405705,-6.417806320404283,-6.425340476067996,-6.4328746317317105,-6.440408787395423,-6.447942943059138,-6.4554770987228505,-6.463011254386565,-6.470545410050278,-6.478079565713991,-6.485613721377705,-6.493147877041418,-6.500682032705132,-6.508216188368846,-6.515750344032558,-6.523284499696272,-6.530818655359987,-6.5383528110236995,-6.545886966687412,-6.553421122351126,-6.5609552780148395,-6.568489433678552,-6.576023589342267,-6.58355774500598,-6.591091900669694,-6.598626056333408,-6.606160211997121,-6.613694367660834,-6.621228523324547,-6.628762678988261,-6.636296834651975,-6.6438309903156885,-6.651365145979402,-6.658899301643116,-6.666433457306829,-6.673967612970542,-6.681501768634256,-6.6890359242979684,-6.696570079961683,-6.704104235625397,-6.711638391289108,-6.719172546952823,-6.726706702616537,-6.736117964115646,-6.746534132911679,-6.756950301707712,-6.767366470503744,-6.777782639299776,-6.7881988080958084,-6.798614976891843,-6.809031145687874,-6.819447314483906,-6.829178508206531,-6.837539751782338,-6.845900995358145,-6.854262238933952,-6.86262348250976,-6.870984726085568,-6.879345969661376,-6.887707213237183,-6.896068456812991,-6.904429700388798,-6.912790943964607,-6.9211521875404145,-6.929513431116221,-6.937874674692029,-6.946235918267837,-6.954597161843644,-6.962958405419451,-6.971319648995259,-6.979680892571066,-6.988042136146874,-6.996403379722683,-7.00476462329849,-7.0131258668742955,-7.020921419724202,-7.028126409997787,-7.035331400271372,-7.042536390544959,-7.049741380818544,-7.056946371092129,-7.064151361365716,-7.071356351639303,-7.078561341912888,-7.0857663321864734,-7.092971322460061,-7.100176312733645,-7.107381303007232,-7.114586293280818,-7.121791283554403,-7.128996273827989,-7.136201264101575,-7.143406254375161,-7.150611244648746,-7.157816234922333,-7.165021225195919,-7.172226215469505,-7.17943120574309,-7.186636196016677,-7.193841186290262,-7.201046176563848,-7.208251166837435,-7.21545615711102,-7.222661147384606,-7.229866137658192,-7.237071127931777,-7.244276118205362,-7.251481108478949,-7.258686098752536,-7.2658910890261215,-7.273096079299707,-7.2803010695732935,-7.287506059846879,-7.2947110501204655,-7.301916040394051,-7.309121030667637,-7.316326020941222,-7.323531011214809,-7.330736001488395,-7.33794099176198,-7.345145982035566,-7.352350972309152,-7.359555962582738,-7.366760952856324,-7.373965943129909,-7.381170933403495,-7.388375923677081,-7.395580913950668,-7.402785904224253,-7.409990894497838,-7.417195884771425,-7.424400875045012,-7.431605865318597,-7.438810855592182,-7.446015845865769,-7.450596937604305,-7.442058536667606,-7.433520135730906,-7.424981734794206,-7.416443333857508,-7.4079049329208075,-7.399366531984108,-7.390828131047409,-7.382289730110708,-7.373751329174009,-7.365212928237311,-7.35667452730061,-7.34813612636391,-7.339597725427211,-7.3310593244905125,-7.322520923553812,-7.314602328251883,-7.307126453627285,-7.299650579002684,-7.292174704378083,-7.284698829753484,-7.277222955128883,-7.269747080504283,-7.262271205879685,-7.2547953312550835,-7.247319456630483,-7.239843582005882,-7.232367707381282,-7.224891832756682,-7.217415958132081,-7.209940083507483,-7.202464208882882,-7.194988334258282,-7.187512459633682,-7.180036585009082,-7.172560710384481,-7.165084835759881,-7.157608961135281,-7.150133086510681,-7.14265721188608,-7.13518133726148,-7.1277054626368805,-7.116894726735017,-7.103701947063682,-7.090509167392346,-7.07731638772101,-7.064123608049675,-7.0509308283783385,-7.037738048707002,-7.024545269035665,-7.011352489364331,-6.9981597096929935,-6.984966930021658,-6.971774150350322,-6.958581370678987,-6.945388591007649,-6.932195811336316,-6.919003031664979,-6.905810251993643,-6.892617472322305,-6.8794246926509715,-6.866231912979635,-6.8530391333082985,-6.839846353636964,-6.826653573965627,-6.813460794294292,-6.800268014622956,-6.787075234951621,-6.772656434311101,-6.75736190908852,-6.742067383865937,-6.726772858643353,-6.71147833342077,-6.696183808198189,-6.680889282975605,-6.665594757753022,-6.650300232530442,-6.635005707307857,-6.619711182085275,-6.6044166568626945,-6.589122131640112,-6.573827606417527,-6.558533081194944,-6.543238555972364],[-4.0796567768314755,-4.086674463203652,-4.093692149575828,-4.100709835948004,-4.1077275223201815,-4.114745208692358,-4.121762895064534,-4.12878058143671,-4.135798267808887,-4.142815954181064,-4.14983364055324,-4.156851326925416,-4.163869013297593,-4.1708866996697695,-4.177904386041946,-4.184922072414123,-4.191939758786299,-4.1989574451584755,-4.205975131530652,-4.212992817902828,-4.220010504275004,-4.227028190647181,-4.234045877019358,-4.241063563391535,-4.24808124976371,-4.255098936135887,-4.262116622508064,-4.26913430888024,-4.276151995252417,-4.283169681624592,-4.2901873679967695,-4.297205054368946,-4.304222740741122,-4.311240427113299,-4.318258113485475,-4.325275799857652,-4.332293486229828,-4.339311172602004,-4.346328858974182,-4.353346545346358,-4.360364231718534,-4.367381918090711,-4.374399604462887,-4.3814172908350635,-4.38843497720724,-4.395452663579416,-4.402470349951593,-4.409488036323769,-4.416505722695946,-4.423523409068123,-4.430541095440299,-4.437558781812475,-4.444576468184652,-4.451594154556828,-4.458611840929004,-4.465629527301181,-4.4726472136733575,-4.479664900045535,-4.486682586417711,-4.493700272789887,-4.500717959162063,-4.50773564553424,-4.514753331906417,-4.521771018278593,-4.528788704650769,-4.535806391022946,-4.542824077395122,-4.549841763767298,-4.556859450139475,-4.5638771365116515,-4.570894822883828,-4.577912509256004,-4.584930195628181,-4.591947882000357,-4.598965568372535,-4.605983254744711,-4.613000941116887,-4.620018627489063,-4.62703631386124,-4.634054000233417,-4.638947610821271,-4.642779189996883,-4.6466107691724945,-4.650442348348107,-4.655607451681417,-4.66103925984627,-4.666471068011121,-4.671902876175974,-4.677334684340825,-4.682766492505676,-4.688198300670528,-4.6936301088353805,-4.699061917000233,-4.704493725165084,-4.709925533329935,-4.715357341494788,-4.720789149659639,-4.726220957824491,-4.731652765989343,-4.737084574154194,-4.742516382319046,-4.747948190483898,-4.75337999864875,-4.758811806813602,-4.764243614978453,-4.769675423143305,-4.775107231308157,-4.780539039473008,-4.78597084763786,-4.791402655802712,-4.7968344639675635,-4.802266272132416,-4.807698080297267,-4.813129888462119,-4.81856169662697,-4.823993504791822,-4.829425312956674,-4.8348571211215265,-4.840288929286378,-4.84572073745123,-4.851152545616081,-4.856584353780933,-4.862016161945785,-4.867447970110637,-4.872879778275488,-4.87831158644034,-4.883743394605192,-4.889175202770044,-4.894607010934895,-4.9000388190997475,-4.905470627264599,-4.910902435429451,-4.916334243594302,-4.921766051759154,-4.927197859924005,-4.9326296680888575,-4.93806147625371,-4.943493284418562,-4.948925092583413,-4.954356900748265,-4.959788708913116,-4.965220517077968,-4.9706523252428205,-4.976084133407672,-4.981515941572524,-4.986947749737375,-4.992379557902227,-4.997811366067079,-5.0032431742319305,-5.008674982396783,-5.014106790561634,-5.019538598726486,-5.024970406891337,-5.030402215056189,-5.035834023221041,-5.041265831385893,-5.046697639550745,-5.052129447715596,-5.057561255880448,-5.062993064045299,-5.0684248722101515,-5.073856680375004,-5.079288488539856,-5.08329360364704,-5.085872033434175,-5.08845046322131,-5.0910288930084455,-5.095373104866215,-5.100600207759303,-5.105827310652389,-5.111054413545477,-5.116281516438565,-5.121508619331652,-5.12673572222474,-5.131962825117826,-5.137189928010915,-5.142417030904002,-5.1476441337970895,-5.152871236690177,-5.158098339583264,-5.163325442476351,-5.168552545369438,-5.173779648262525,-5.179006751155613,-5.184233854048701,-5.1894609569417876,-5.194688059834875,-5.199915162727963,-5.20514226562105,-5.2103693685141375,-5.215596471407226,-5.220823574300312,-5.2260506771934,-5.231277780086487,-5.236504882979575,-5.241731985872662,-5.246959088765749,-5.252186191658836,-5.257413294551925,-5.262640397445012,-5.267867500338099,-5.273094603231187,-5.2784541338505075,-5.284012311860607,-5.289570489870706,-5.295128667880805,-5.300686845890905,-5.306245023901003,-5.311803201911102,-5.317361379921202,-5.322919557931302,-5.328477735941401,-5.3340359139514995,-5.339594091961598,-5.345152269971698,-5.350710447981797,-5.356268625991897,-5.3618268040019945,-5.367384982012094,-5.372943160022194,-5.378501338032293,-5.3840595160423925,-5.389617694052491,-5.39517587206259,-5.40073405007269,-5.406292228082789,-5.4118504060928885,-5.417408584102987,-5.422966762113086,-5.428524940123186,-5.434083118133285,-5.439641296143384,-5.445199474153483,-5.450757652163583,-5.456315830173682,-5.4618740081837815,-5.46743218619388,-5.472990364203979,-5.478548542214079,-5.484106720224178,-5.4896648982342775,-5.495223076244376,-5.500781254254475,-5.506339432264575,-5.511897610274674,-5.517455788284773,-5.523013966294872,-5.528572144304971,-5.534130322315071,-5.53968850032517,-5.546234667162076,-5.5537688228257895,-5.561302978489502,-5.568837134153217,-5.57637128981693,-5.583905445480643,-5.591439601144357,-5.59897375680807,-5.606507912471784,-5.614042068135497,-5.621576223799211,-5.629110379462926,-5.636644535126638,-5.644178690790351,-5.651712846454065,-5.659247002117779,-5.666781157781492,-5.674315313445206,-5.6818494691089185,-5.689383624772632,-5.696917780436346,-5.704451936100059,-5.711986091763773,-5.719520247427486,-5.7270544030912,-5.734588558754913,-5.742122714418627,-5.749656870082341,-5.756638611920666,-5.763324413400382,-5.7700102148801,-5.776696016359818,-5.783381817839533,-5.790067619319251,-5.79675342079897,-5.803439222278687,-5.810125023758403,-5.816810825238121,-5.823496626717838,-5.8301824281975545,-5.836868229677273,-5.84355403115699,-5.850239832636706,-5.8569256341164255,-5.863611435596143,-5.870297237075859,-5.876983038555577,-5.883668840035295,-5.89035464151501,-5.897040442994728,-5.903726244474445,-5.910412045954162,-5.91709784743388,-5.923783648913597,-5.930469450393315,-5.9371552518730315,-5.943841053352749,-5.950526854832467,-5.957212656312183,-5.963898457791901,-5.970584259271619,-5.977270060751335,-5.983955862231053,-5.99064166371077,-5.997327465190486,-6.004013266670204,-6.010699068149922,-6.01738486962964,-6.024070671109356,-6.030756472589073,-6.03744227406879,-6.0441280755485085,-6.050813877028226,-6.057499678507943,-6.06418547998766,-6.070871281467378,-6.077557082947095,-6.0842428844268115,-6.090928685906528,-6.097614487386246,-6.104300288865963,-6.11098609034568,-6.117671891825398,-6.124125460695289,-6.1301145643455275,-6.136103667995765,-6.142092771646003,-6.14808187529624,-6.1540709789464785,-6.160060082596716,-6.166049186246955,-6.172038289897191,-6.1780273935474295,-6.184016497197668,-6.190005600847906,-6.195994704498143,-6.201983808148381,-6.207972911798619,-6.213962015448857,-6.219951119099094,-6.225940222749332,-6.2319293263995705,-6.237918430049809,-6.243907533700047,-6.249896637350285,-6.255885741000522,-6.261874844650761,-6.267863948300998,-6.273853051951236,-6.279842155601473,-6.285831259251712,-6.291820362901948,-6.297809466552188,-6.303798570202426,-6.309787673852663,-6.315776777502901,-6.321765881153139,-6.327754984803376,-6.3341732254781515,-6.341378215751738,-6.348583206025323,-6.355788196298908,-6.362993186572494,-6.370198176846079,-6.377403167119666,-6.384608157393252,-6.39181314766684,-6.399018137940425,-6.406223128214011,-6.413428118487596,-6.420633108761182,-6.427838099034767,-6.435043089308354,-6.4422480795819395,-6.449453069855525,-6.4566580601291115,-6.463863050402697,-6.4710680406762835,-6.478273030949869,-6.4854780212234555,-6.492683011497041,-6.499888001770627,-6.507092992044212,-6.514297982317798,-6.521502972591384,-6.528707962864971,-6.535912953138556,-6.543117943412142,-6.550322933685729,-6.557527923959315,-6.564732914232899,-6.571937904506485,-6.579142894780071,-6.586347885053658,-6.593552875327243,-6.60075786560083,-6.607962855874415,-6.615167846148001,-6.622372836421587,-6.629577826695174,-6.636782816968759,-6.643987807242345,-6.6511927975159315,-6.658397787789516,-6.665602778063102,-6.672807768336689,-6.677388860075225,-6.668850459138525,-6.660312058201826,-6.651773657265126,-6.643235256328428,-6.634696855391727,-6.626158454455028,-6.617620053518329,-6.6090816525816285,-6.600543251644929,-6.59200485070823,-6.58346644977153,-6.57492804883483,-6.566389647898131,-6.557851246961432,-6.549312846024732,-6.540774445088031,-6.532236044151334,-6.523697643214634,-6.515159242277933,-6.506620841341235,-6.498082440404534,-6.489544039467836,-6.481005638531137,-6.4724672375944365,-6.463928836657736,-6.4553904357210365,-6.446852034784337,-6.4383136338476366,-6.429775232910937,-6.421236831974239,-6.41269843103754,-6.404979059251117,-6.397503184626519,-6.390027310001918,-6.382551435377318,-6.375075560752717,-6.367599686128117,-6.3601238115035175,-6.352647936878916,-6.345172062254317,-6.337696187629716,-6.326885451727852,-6.3136926720565185,-6.300499892385181,-6.287307112713846,-6.274114333042511,-6.260921553371174,-6.247728773699837,-6.2345359940285014,-6.221343214357166,-6.20815043468583,-6.19412571100383,-6.17883118578125,-6.163536660558666,-6.148242135336083,-6.1329476101135025,-6.117653084890919,-6.102358559668335,-6.087064034445752,-6.071769509223172,-6.056474984000588,-6.041180458778005,-6.025885933555426,-6.010591408332841,-5.995296883110257,-5.9800023578876775,-5.964707832665093,-5.94941330744251,-5.9341187822199295,-5.918824256997345,-5.903529731774762,-5.88823520655218,-5.872940681329599,-5.857646156107015,-5.842351630884432,-5.827057105661851,-5.811762580439268,-5.7964680552166845,-5.7811735299941045,-5.765879004771521,-5.7505844795489365,-5.735289954326353,-5.719995429103774],[-3.59908680682496,-3.6061044931971367,-3.613122179569313,-3.6201398659414887,-3.6271575523136654,-3.634175238685842,-3.6411929250580184,-3.648210611430195,-3.655228297802372,-3.6622459841745476,-3.6692636705467248,-3.676281356918901,-3.6832990432910773,-3.690316729663254,-3.6973344160354302,-3.704352102407607,-3.711369788779783,-3.7183874751519594,-3.7254051615241366,-3.732422847896313,-3.739440534268489,-3.7464582206406654,-3.7534759070128416,-3.7604935933850188,-3.767511279757195,-3.7745289661293713,-3.7815466525015475,-3.788564338873724,-3.7955820252459014,-3.802599711618077,-3.8096173979902535,-3.8166350843624306,-3.8236527707346064,-3.8306704571067836,-3.8376881434789594,-3.8447058298511365,-3.8517235162233128,-3.858741202595489,-3.865758888967666,-3.8727765753398415,-3.8797942617120187,-3.886811948084195,-3.8938296344563716,-3.9008473208285483,-3.907865007200724,-3.914882693572901,-3.921900379945077,-3.928918066317254,-3.93593575268943,-3.942953439061607,-3.949971125433783,-3.9569888118059597,-3.964006498178136,-3.9710241845503123,-3.978041870922489,-3.985059557294665,-3.992077243666842,-3.9990949300390186,-4.006112616411195,-4.013130302783371,-4.020147989155547,-4.0271656755277245,-4.034183361899901,-4.040670027823158,-4.044501606998771,-4.048333186174382,-4.0521647653499935,-4.055996344525606,-4.059827923701218,-4.063659502876829,-4.067491082052442,-4.071322661228053,-4.0751542404036645,-4.078985819579277,-4.082817398754888,-4.0866489779305,-4.090480557106112,-4.094312136281724,-4.0981437154573355,-4.101975294632948,-4.105806873808559,-4.1096384529841705,-4.113470032159783,-4.117301611335394,-4.122466714668707,-4.127898522833558,-4.13333033099841,-4.138762139163261,-4.144193947328113,-4.1496257554929645,-4.155057563657817,-4.160489371822669,-4.165921179987521,-4.171352988152372,-4.176784796317224,-4.182216604482075,-4.1876484126469276,-4.193080220811779,-4.198512028976632,-4.203943837141483,-4.209375645306335,-4.214807453471186,-4.2202392616360385,-4.22567106980089,-4.231102877965742,-4.236534686130594,-4.241966494295445,-4.247398302460296,-4.2528301106251485,-4.258261918790001,-4.263693726954852,-4.269125535119704,-4.274557343284555,-4.279989151449408,-4.285420959614259,-4.290852767779111,-4.296284575943963,-4.301716384108815,-4.307148192273666,-4.312580000438518,-4.31801180860337,-4.3234436167682215,-4.328875424933074,-4.334307233097925,-4.339739041262777,-4.345170849427628,-4.35060265759248,-4.356034465757332,-4.361466273922184,-4.366898082087036,-4.372329890251887,-4.377761698416739,-4.383193506581591,-4.3886253147464425,-4.394057122911295,-4.399488931076146,-4.404920739240998,-4.41035254740585,-4.415784355570701,-4.421216163735553,-4.4266479719004055,-4.432079780065257,-4.437511588230109,-4.44294339639496,-4.448375204559812,-4.453807012724663,-4.459238818576419,-4.4618172483635545,-4.464395678150689,-4.466974107937824,-4.469552537724959,-4.472130967512094,-4.474709397299229,-4.477287827086363,-4.479866256873499,-4.482444686660634,-4.485023116447769,-4.487601546234903,-4.490179976022039,-4.492758405809174,-4.495336835596309,-4.497915265383443,-4.5004936951705785,-4.503072124957714,-4.505650554744848,-4.508228984531984,-4.510807414319118,-4.5151516261768885,-4.520378729069976,-4.5256058319630625,-4.530832934856151,-4.5360600377492375,-4.541287140642326,-4.546514243535413,-4.5517413464285,-4.556968449321588,-4.562195552214675,-4.567422655107763,-4.57264975800085,-4.577876860893937,-4.583103963787025,-4.588331066680112,-4.5935581695732,-4.598785272466287,-4.604012375359374,-4.609239478252462,-4.61446658114555,-4.619693684038637,-4.624920786931725,-4.63014788982481,-4.635374992717899,-4.640602095610985,-4.645829198504074,-4.651056301397161,-4.656283404290248,-4.661510507183336,-4.666737610076423,-4.67196471296951,-4.6771918158625985,-4.682418918755685,-4.6876460216487725,-4.69287312454186,-4.6981002274349475,-4.703327330328035,-4.708554433221122,-4.713781536114209,-4.719008639007297,-4.724235741900384,-4.7294628447934715,-4.734689947686559,-4.739917050579647,-4.745144153472734,-4.7503712563658205,-4.755598359258909,-4.760825462151996,-4.766052565045084,-4.771279667938171,-4.776506770831259,-4.781733873724346,-4.786960976617433,-4.792188079510521,-4.797415182403608,-4.802642285296695,-4.807869388189783,-4.81309649108287,-4.818323593975958,-4.823550696869045,-4.828777799762133,-4.83400490265522,-4.839232005548308,-4.844459108441395,-4.849686211334482,-4.854913314227569,-4.860140417120657,-4.865367520013744,-4.8705946229068315,-4.875821725799919,-4.880557262038678,-4.88290518168592,-4.885253101333161,-4.887601020980402,-4.889948940627643,-4.892296860274884,-4.8946447799221255,-4.896992699569367,-4.899340619216607,-4.901688538863849,-4.904036458511091,-4.906384378158331,-4.908732297805573,-4.912369035482507,-4.917294591189133,-4.92222014689576,-4.927145702602386,-4.932071258309014,-4.9369968140156395,-4.941922369722266,-4.9468479254288935,-4.95177348113552,-4.956699036842147,-4.961624592548773,-4.9665501482554,-4.971475703962026,-4.976401259668653,-4.981326815375279,-4.986252371081906,-4.991177926788533,-4.99610348249516,-5.001029038201786,-5.005954593908412,-5.010880149615039,-5.015805705321666,-5.020731261028292,-5.025656816734919,-5.030582372441547,-5.0355079281481725,-5.0404334838548,-5.0453590395614265,-5.051287744967742,-5.0579735464474584,-5.064659347927177,-5.071345149406894,-5.07803095088661,-5.084716752366329,-5.091402553846046,-5.098088355325762,-5.10477415680548,-5.111459958285197,-5.118145759764914,-5.124831561244632,-5.131517362724349,-5.138203164204066,-5.144888965683783,-5.1515747671635,-5.158260568643218,-5.164946370122935,-5.171632171602652,-5.17831797308237,-5.185003774562087,-5.191689576041805,-5.198375377521522,-5.205061179001239,-5.211746980480956,-5.218432781960674,-5.225118583440391,-5.231804384920108,-5.238490186399826,-5.245175987879543,-5.25186178935926,-5.258547590838977,-5.265233392318695,-5.271919193798412,-5.278604995278129,-5.285290796757845,-5.2919765982375635,-5.29866239971728,-5.305348201196998,-5.312034002676715,-5.318719804156432,-5.325405605636149,-5.332091407115867,-5.338777208595585,-5.345463010075301,-5.352148811555019,-5.358834613034736,-5.365520414514453,-5.37220621599417,-5.378892017473888,-5.385577818953605,-5.392263620433322,-5.39894942191304,-5.405635223392757,-5.412321024872474,-5.4187745937423655,-5.424763697392603,-5.430752801042841,-5.436741904693079,-5.442731008343317,-5.448720111993554,-5.454709215643793,-5.46069831929403,-5.466687422944268,-5.4726765265945065,-5.478665630244745,-5.484654733894983,-5.490643837545219,-5.4966329411954575,-5.502622044845696,-5.508611148495934,-5.514600252146171,-5.520589355796409,-5.526578459446647,-5.532567563096885,-5.538556666747123,-5.544545770397361,-5.5505348740475995,-5.556523977697837,-5.562513081348075,-5.568502184998312,-5.5744912886485505,-5.580480392298788,-5.586469495949025,-5.592458599599263,-5.598447703249502,-5.60443680689974,-5.610425910549978,-5.616415014200215,-5.6224041178504525,-5.628393221500691,-5.634382325150929,-5.640371428801167,-5.646360532451405,-5.652349636101643,-5.658338739751881,-5.664327843402119,-5.670316947052357,-5.676306050702594,-5.682295154352833,-5.688284258003071,-5.694273361653308,-5.700262465303545,-5.706251568953784,-5.712240672604022,-5.71822977625426,-5.724218879904498,-5.730207983554735,-5.736197087204974,-5.742186190855211,-5.748175294505448,-5.754164398155687,-5.760153501805926,-5.766142605456162,-5.7721317091064,-5.778120812756638,-5.784109916406876,-5.790099020057114,-5.796088123707352,-5.802077227357589,-5.8080663310078275,-5.814055434658067,-5.820044538308303,-5.826033641958541,-5.83202274560878,-5.838011849259018,-5.844000952909255,-5.849990056559494,-5.855979160209731,-5.861968263859969,-5.867957367510208,-5.872673182710573,-5.877048938285678,-5.881424693860786,-5.885800449435891,-5.890176205010997,-5.894551960586104,-5.898927716161211,-5.901087969845889,-5.892170714078431,-5.883253458310973,-5.8745610810536855,-5.865884989709667,-5.857208898365647,-5.848532807021625,-5.839856715677607,-5.831180624333587,-5.822504532989566,-5.813828441645548,-5.805152350301527,-5.796476258957507,-5.7878001676134865,-5.779124076269467,-5.770447984925447,-5.761771893581427,-5.753095802237407,-5.744419710893387,-5.735743619549367,-5.727067528205348,-5.718391436861327,-5.709715345517306,-5.701039254173288,-5.692363162829269,-5.683687071485247,-5.675010980141227,-5.666334888797207,-5.657658797453188,-5.648982706109167,-5.640306614765148,-5.631630523421128,-5.622954432077107,-5.6142783407330885,-5.605602249389068,-5.596926158045047,-5.588250066701027,-5.579573975357008,-5.570897884012989,-5.562221792668968,-5.553545701324948,-5.544869609980928,-5.532259266174214,-5.516838742037009,-5.501418217899801,-5.485997693762592,-5.470577169625385,-5.455156645488177,-5.439736121350968,-5.424315597213761,-5.408895073076554,-5.393474548939347,-5.378054024802138,-5.362633500664932,-5.3472129765277225,-5.3317924523905145,-5.316371928253309,-5.300951404116101,-5.285530879978893,-5.270110355841684,-5.254689831704479,-5.23926930756727,-5.223848783430061,-5.208428259292855,-5.193007735155648,-5.177587211018438,-5.162166686881233,-5.146746162744025,-5.131325638606816,-5.11590511446961,-5.100484590332401,-5.085064066195193,-5.069643542057985,-5.054223017920779,-5.038802493783571,-5.023381969646362,-5.007961445509156,-4.9925409213719485,-4.9771203972347395,-4.961699873097534,-4.946279348960325,-4.9307161242679545,-4.914686281664804,-4.898656439061656],[-3.1185168368184346,-3.125534523190611,-3.132552209562787,-3.139569895934964,-3.1465875823071405,-3.153605268679317,-3.160622955051493,-3.1676406414236697,-3.1746583277958464,-3.1816760141680227,-3.1886937005401994,-3.195711386912375,-3.202729073284552,-3.2097467596567286,-3.2167644460289053,-3.223782132401082,-3.2307998187732583,-3.2378175051454345,-3.244835191517611,-3.251852877889788,-3.2588705642619638,-3.2658882506341405,-3.2729059370063167,-3.2799236233784934,-3.2869413097506697,-3.2939589961228464,-3.3009766824950226,-3.307994368867199,-3.315012055239376,-3.3220297416115523,-3.3290474279837285,-3.3360651143559052,-3.343082800728081,-3.350100487100258,-3.3571181734724345,-3.3641358598446107,-3.3711535462167874,-3.378171232588964,-3.3851889189611404,-3.392206605333316,-3.399224291705493,-3.40624197807767,-3.4132596644498463,-3.420277350822023,-3.427295037194199,-3.434312723566375,-3.441330409938552,-3.446224024000648,-3.45005560317626,-3.453887182351872,-3.4577187615274836,-3.461550340703096,-3.4653819198787073,-3.469213499054319,-3.4730450782299314,-3.4768766574055423,-3.4807082365811546,-3.4845398157567664,-3.488371394932378,-3.49220297410799,-3.496034553283602,-3.4998661324592137,-3.503697711634825,-3.507529290810437,-3.511360869986049,-3.5151924491616606,-3.5190240283372725,-3.5228556075128843,-3.526687186688496,-3.530518765864108,-3.5343503450397202,-3.5381819242153316,-3.5420135033909435,-3.5458450825665553,-3.549676661742167,-3.553508240917779,-3.5573398200933903,-3.5611713992690026,-3.5650029784446144,-3.5688345576202263,-3.5726661367958377,-3.576497715971449,-3.5803292951470613,-3.584160874322673,-3.589325977655985,-3.594757785820837,-3.6001895939856885,-3.60562140215054,-3.6110532103153923,-3.616485018480244,-3.6219168266450956,-3.6273486348099473,-3.6327804429747994,-3.638212251139651,-3.6436440593045027,-3.6490758674693544,-3.6545076756342065,-3.659939483799058,-3.66537129196391,-3.6708031001287615,-3.6762349082936137,-3.6816667164584653,-3.687098524623317,-3.692530332788169,-3.6979621409530203,-3.703393949117872,-3.708825757282724,-3.7142575654475753,-3.7196893736124275,-3.725121181777279,-3.730552989942131,-3.735984798106983,-3.741416606271834,-3.7468484144366863,-3.752280222601538,-3.7577120307663896,-3.7631438389312417,-3.768575647096093,-3.774007455260945,-3.779439263425797,-3.7848710715906484,-3.7903028797555005,-3.795734687920352,-3.801166496085204,-3.8065983042500555,-3.812030112414907,-3.8174619205797593,-3.822893728744611,-3.8283255369094626,-3.8337573450743143,-3.8377624632929224,-3.8403408930800573,-3.842919322867192,-3.845497752654327,-3.8480761824414618,-3.850654612228597,-3.8532330420157317,-3.8558114718028667,-3.8583899015900016,-3.860968331377137,-3.8635467611642715,-3.8661251909514065,-3.8687036207385415,-3.871282050525677,-3.873860480312812,-3.8764389100999463,-3.8790173398870818,-3.8815957696742167,-3.8841741994613512,-3.8867526292484866,-3.8893310590356216,-3.8919094888227566,-3.8944879186098915,-3.897066348397026,-3.8996447781841614,-3.9022232079712964,-3.9048016377584314,-3.9073800675455663,-3.909958497332701,-3.9125369271198362,-3.915115356906971,-3.917693786694106,-3.9202722164812416,-3.922850646268376,-3.925429076055511,-3.928007505842646,-3.930585935629781,-3.9349301474875515,-3.9401572503806386,-3.945384353273726,-3.950611456166813,-3.9558385590599006,-3.961065661952988,-3.9662927648460755,-3.971519867739163,-3.9767469706322505,-3.981974073525337,-3.9872011764184254,-3.992428279311513,-3.9976553822046004,-4.002882485097688,-4.008109587990774,-4.013336690883862,-4.018563793776949,-4.023790896670037,-4.029017999563124,-4.034245102456212,-4.039472205349299,-4.044699308242387,-4.049926411135474,-4.055153514028562,-4.060380616921649,-4.065607719814737,-4.070834822707824,-4.076061925600911,-4.081289028493999,-4.086516131387086,-4.091743234280173,-4.096970337173261,-4.102197440066348,-4.107424542959435,-4.112651645852523,-4.1178787487456106,-4.123105851638698,-4.1283329545317855,-4.133560057424872,-4.1387871603179605,-4.144014263211047,-4.1492413661041345,-4.154468468997223,-4.1596955718903095,-4.164922674783397,-4.170149777676484,-4.175376880569572,-4.180603983462659,-4.185831086355747,-4.191058189248834,-4.196285292141921,-4.201512395035008,-4.204773228414041,-4.207121148061282,-4.2094690677085245,-4.211816987355765,-4.214164907003006,-4.216512826650247,-4.218860746297488,-4.221208665944729,-4.223556585591971,-4.225904505239212,-4.228252424886453,-4.230600344533694,-4.232948264180936,-4.235296183828177,-4.237644103475418,-4.239992023122659,-4.242339942769901,-4.244687862417141,-4.2470357820643825,-4.249383701711624,-4.251731621358865,-4.2540795410061065,-4.256427460653347,-4.258775380300588,-4.261123299947831,-4.263471219595071,-4.265819139242312,-4.268167058889554,-4.270514978536795,-4.2728628981840355,-4.275210817831277,-4.278847555508211,-4.283773111214838,-4.288698666921464,-4.2936242226280905,-4.298549778334717,-4.303475334041344,-4.30840088974797,-4.313326445454598,-4.318252001161224,-4.323177556867851,-4.328103112574477,-4.333028668281104,-4.3379542239877305,-4.342879779694357,-4.3478053354009845,-4.35273089110761,-4.357656446814237,-4.362582002520864,-4.367507558227491,-4.372433113934116,-4.377358669640744,-4.38228422534737,-4.387209781053997,-4.3921353367606235,-4.39706089246725,-4.4019864481738775,-4.406912003880503,-4.411837559587131,-4.416763115293757,-4.421688671000384,-4.426614226707009,-4.431539782413637,-4.436465338120263,-4.44139089382689,-4.446316449533517,-4.451242005240143,-4.45616756094677,-4.461093116653396,-4.466018672360023,-4.470944228066649,-4.475869783773276,-4.4807953394799025,-4.485720895186529,-4.490646450893156,-4.495572006599783,-4.500497562306409,-4.505423118013035,-4.510348673719663,-4.515274229426289,-4.520199785132915,-4.525125340839542,-4.530050896546169,-4.5349764522527956,-4.539902007959422,-4.544827563666049,-4.549753119372675,-4.554678675079302,-4.559604230785929,-4.564529786492555,-4.569455342199182,-4.574380897905809,-4.5793064536124355,-4.584232009319062,-4.589157565025689,-4.594083120732315,-4.599008676438942,-4.603934232145568,-4.608859787852195,-4.6137853435588205,-4.620054738683212,-4.62674054016293,-4.633426341642647,-4.640112143122364,-4.646797944602081,-4.653483746081799,-4.660169547561516,-4.666855349041233,-4.6735411505209505,-4.680226952000668,-4.686912753480385,-4.6935985549601025,-4.70028435643982,-4.706970157919537,-4.713423726789428,-4.719412830439666,-4.725401934089904,-4.731391037740141,-4.737380141390379,-4.743369245040617,-4.749358348690855,-4.755347452341094,-4.761336555991331,-4.767325659641569,-4.773314763291808,-4.779303866942045,-4.785292970592282,-4.79128207424252,-4.797271177892759,-4.803260281542997,-4.809249385193235,-4.815238488843471,-4.82122759249371,-4.827216696143948,-4.832240947256481,-4.836616702831588,-4.840992458406694,-4.845368213981801,-4.849743969556907,-4.854119725132014,-4.85849548070712,-4.862871236282226,-4.867246991857333,-4.87162274743244,-4.875998503007546,-4.880374258582652,-4.884750014157759,-4.889125769732864,-4.893501525307971,-4.897877280883078,-4.902253036458184,-4.90662879203329,-4.911004547608396,-4.915380303183504,-4.91975605875861,-4.924131814333716,-4.928507569908822,-4.93288332548393,-4.937259081059035,-4.941634836634142,-4.946010592209248,-4.950386347784354,-4.954762103359461,-4.959137858934567,-4.963513614509674,-4.96788937008478,-4.972265125659886,-4.976640881234994,-4.981016636810099,-4.985392392385206,-4.989768147960312,-4.994143903535419,-4.998519659110525,-5.002895414685632,-5.007271170260738,-5.011646925835844,-5.016022681410951,-5.020398436986057,-5.024774192561164,-5.02914994813627,-5.033525703711376,-5.037901459286482,-5.042277214861589,-5.046652970436696,-5.051028726011802,-5.055404481586909,-5.059780237162015,-5.064155992737122,-5.068531748312228,-5.072907503887334,-5.077283259462441,-5.081659015037547,-5.086034770612654,-5.09041052618776,-5.094786281762866,-5.0991620373379725,-5.10353779291308,-5.105698046597758,-5.0967807908303,-5.0878635350628425,-5.078946279295384,-5.070029023527928,-5.061111767760471,-5.0521945119930125,-5.043277256225556,-5.034360000458098,-5.02544274469064,-5.016525488923184,-5.007608233155726,-4.998690977388268,-4.98977372162081,-4.980856465853353,-4.971939210085896,-4.963021954318438,-4.9541046985509825,-4.945187442783524,-4.93640878696997,-4.927732695625951,-4.919056604281931,-4.91038051293791,-4.901704421593892,-4.893028330249871,-4.8843522389058505,-4.87567614756183,-4.867000056217811,-4.858323964873791,-4.84964787352977,-4.840971782185752,-4.832295690841731,-4.823619599497711,-4.814943508153691,-4.806267416809671,-4.797591325465651,-4.78891523412163,-4.780239142777612,-4.77156305143359,-4.7628869600895705,-4.7542108687455515,-4.745534777401532,-4.7329244335948175,-4.717503909457611,-4.702083385320403,-4.686662861183194,-4.671242337045989,-4.655821812908781,-4.640401288771573,-4.624980764634364,-4.609560240497158,-4.594139716359949,-4.578719192222741,-4.563298668085535,-4.547878143948326,-4.532457619811118,-4.5170370956739125,-4.5016165715367045,-4.4861960473994955,-4.470775523262287,-4.455354999125082,-4.439934474987873,-4.424513950850664,-4.40909342671346,-4.39367290257625,-4.377891689190529,-4.361861846587381,-4.3458320039842295,-4.32980216138108,-4.313772318777932,-4.297742476174781,-4.281712633571631,-4.26568279096848,-4.249652948365333,-4.233623105762183,-4.217593263159032,-4.201563420555884,-4.185533577952734,-4.169503735349584,-4.153473892746435,-4.137444050143285,-4.121414207540134,-4.105384364936984,-4.089354522333837],[-2.6379468668119186,-2.644964553184095,-2.651982239556271,-2.658999925928448,-2.6660176123006245,-2.6730352986728008,-2.680052985044977,-2.6870706714171537,-2.6940883577893304,-2.7011060441615067,-2.7081237305336834,-2.715141416905859,-2.722159103278036,-2.7291767896502126,-2.7361944760223893,-2.743212162394566,-2.7502298487667423,-2.7572475351389185,-2.764265221511095,-2.7712829078832715,-2.7783005942554477,-2.7853182806276244,-2.7923359669998002,-2.7993536533719774,-2.8063713397441536,-2.8133890261163303,-2.8204067124885066,-2.827424398860683,-2.8344420852328596,-2.841459771605036,-2.847946441002536,-2.851778020178148,-2.8556095993537602,-2.8594411785293716,-2.863272757704984,-2.8671043368805957,-2.870935916056207,-2.874767495231819,-2.878599074407431,-2.8824306535830426,-2.8862622327586545,-2.8900938119342663,-2.893925391109878,-2.89775697028549,-2.901588549461102,-2.905420128636713,-2.9092517078123254,-2.913083286987937,-2.9169148661635487,-2.9207464453391605,-2.9245780245147723,-2.9284096036903846,-2.9322411828659956,-2.9360727620416074,-2.9399043412172197,-2.943735920392831,-2.9475674995684433,-2.951399078744055,-2.9552306579196665,-2.959062237095279,-2.96289381627089,-2.9667253954465025,-2.9705569746221143,-2.974388553797726,-2.9782201329733375,-2.9820517121489494,-2.985883291324561,-2.989714870500173,-2.993546449675785,-2.9973780288513967,-3.0012096080270085,-3.00504118720262,-3.008872766378232,-3.012704345553844,-3.016535924729456,-3.0203675039050677,-3.0241990830806795,-3.028030662256291,-3.031862241431903,-3.0356938206075146,-3.039525399783127,-3.0433569789587382,-3.04718855813435,-3.051020137309962,-3.0561852406432735,-3.0616170488081256,-3.0670488569729772,-3.072480665137829,-3.077912473302681,-3.0833442814675323,-3.0887760896323844,-3.094207897797236,-3.0996397059620877,-3.10507151412694,-3.1105033222917915,-3.115935130456643,-3.1213669386214953,-3.1267987467863465,-3.1322305549511986,-3.1376623631160507,-3.143094171280902,-3.148525979445754,-3.1539577876106053,-3.1593895957754574,-3.1648214039403086,-3.1702532121051608,-3.175685020270013,-3.181116828434864,-3.186548636599716,-3.191980444764568,-3.1974122529294196,-3.2028440610942717,-3.208275869259123,-3.213707677423975,-3.216286108009436,-3.218864537796571,-3.221442967583706,-3.2240213973708407,-3.2265998271579757,-3.229178256945111,-3.231756686732246,-3.2343351165193805,-3.236913546306516,-3.239491976093651,-3.242070405880786,-3.244648835667921,-3.2472272654550562,-3.2498056952421908,-3.2523841250293257,-3.254962554816461,-3.2575409846035956,-3.2601194143907306,-3.2626978441778656,-3.2652762739650005,-3.2678547037521355,-3.2704331335392705,-3.2730115633264054,-3.2755899931135404,-3.2781684229006753,-3.2807468526878103,-3.2833252824749453,-3.2859037122620807,-3.2884821420492156,-3.29106057183635,-3.293639001623485,-3.2962174314106205,-3.2987958611977555,-3.30137429098489,-3.303952720772025,-3.3065311505591604,-3.3091095803462953,-3.3116880101334303,-3.314266439920565,-3.3168448697077,-3.3194232994948347,-3.3220017292819697,-3.3245801590691046,-3.32715858885624,-3.329737018643375,-3.33231544843051,-3.3348938782176445,-3.33747230800478,-3.340050737791915,-3.34262916757905,-3.345207597366185,-3.3477860271533197,-3.3503644569404547,-3.3547086687982253,-3.359935771691312,-3.3651628745843993,-3.370389977477487,-3.3756170803705743,-3.3808441832636618,-3.3860712861567492,-3.3912983890498367,-3.396525491942924,-3.4017525948360112,-3.406979697729099,-3.4122068006221857,-3.4174339035152737,-3.422661006408361,-3.427888109301448,-3.4331152121945356,-3.438342315087623,-3.443569417980711,-3.448796520873798,-3.4540236237668855,-3.459250726659973,-3.4644778295530605,-3.469704932446148,-3.474932035339235,-3.4801591382323225,-3.4853862411254095,-3.490613344018497,-3.4958404469115845,-3.5010675498046724,-3.50629465269776,-3.511521755590847,-3.5167488584839344,-3.521975961377022,-3.5266412751421754,-3.528989194789416,-3.5313371144366577,-3.5336850340838986,-3.53603295373114,-3.5383808733783813,-3.540728793025622,-3.543076712672863,-3.5454246323201044,-3.5477725519673458,-3.5501204716145867,-3.5524683912618285,-3.55481631090907,-3.5571642305563103,-3.5595121502035516,-3.561860069850793,-3.564207989498034,-3.566555909145275,-3.5689038287925166,-3.5712517484397575,-3.573599668086999,-3.57594758773424,-3.5782955073814806,-3.580643427028722,-3.5829913466759638,-3.5853392663232047,-3.587687185970447,-3.5900351056176873,-3.5923830252649287,-3.59473094491217,-3.597078864559411,-3.599426784206652,-3.6017747038538936,-3.6041226235011345,-3.606470543148376,-3.6088184627956164,-3.6111663824428586,-3.613514302090099,-3.6158622217373404,-3.6182101413845817,-3.6205580610318226,-3.6229059806790636,-3.625253900326305,-3.6276018199735462,-3.6299497396207876,-3.632297659268028,-3.63464557891527,-3.636993498562511,-3.639341418209752,-3.641689337856994,-3.6453260755339274,-3.650251631240554,-3.6551771869471805,-3.660102742653807,-3.665028298360434,-3.6699538540670607,-3.6748794097736868,-3.679804965480314,-3.6847305211869408,-3.6896560768935664,-3.694581632600194,-3.6995071883068205,-3.704432744013447,-3.7093582997200736,-3.7142838554267006,-3.719209411133327,-3.7241349668399533,-3.7290605225465807,-3.7339860782532073,-3.7389116339598334,-3.7438371896664604,-3.748762745373087,-3.753688301079713,-3.75861385678634,-3.7635394124929666,-3.768464968199593,-3.7733905239062198,-3.7783160796128468,-3.7832416353194733,-3.7881671910260994,-3.793092746732727,-3.7980183024393535,-3.8029438581459796,-3.8078694138526066,-3.812794969559233,-3.8177205252658597,-3.8226460809724863,-3.8275716366791133,-3.83249719238574,-3.8374227480923655,-3.8423483037989925,-3.8472738595056186,-3.852199415212245,-3.857124970918872,-3.862050526625499,-3.8669760823321253,-3.8719016380387523,-3.8768271937453793,-3.8817527494520054,-3.886678305158632,-3.891603860865259,-3.8965294165718856,-3.901454972278512,-3.9063805279851387,-3.9113060836917657,-3.916231639398392,-3.921157195105019,-3.926082750811646,-3.9310083065182715,-3.9351727518966313,-3.938107716898622,-3.9410426819006115,-3.9439776469026007,-3.946912611904591,-3.949847576906581,-3.9527825419085705,-3.9557175069105606,-3.9586524719125507,-3.96158743691454,-3.9645224019165304,-3.9674573669185205,-3.97039233192051,-3.9733272969225,-3.97626226192449,-3.9791972269264795,-3.98213219192847,-3.985067156930459,-3.988002121932449,-3.990937086934439,-3.993872051936429,-3.996807016938419,-3.999741981940409,-4.002676946942398,-4.00561400067269,-4.00855523185958,-4.011496463046472,-4.014437694233362,-4.017378925420254,-4.020320156607145,-4.023261387794036,-4.0262026189809275,-4.029143850167818,-4.03208508135471,-4.035026312541601,-4.037967543728492,-4.040908774915383,-4.043850006102274,-4.046791237289165,-4.049732468476057,-4.0526736996629475,-4.055614930849838,-4.05855616203673,-4.061497393223621,-4.064438624410513,-4.0673798555974034,-4.070321086784294,-4.073262317971185,-4.076203549158077,-4.079144780344968,-4.0820860115318585,-4.08502724271875,-4.087968473905642,-4.090909705092533,-4.093850936279424,-4.096792167466314,-4.099733398653206,-4.102674629840097,-4.105615861026989,-4.108557092213879,-4.111498323400771,-4.114439554587662,-4.117380785774552,-4.1203220169614445,-4.124366135510494,-4.128741891085601,-4.133117646660708,-4.137493402235814,-4.14186915781092,-4.146244913386026,-4.150620668961133,-4.154996424536239,-4.159372180111346,-4.163747935686453,-4.168123691261558,-4.172499446836665,-4.176875202411771,-4.181250957986878,-4.185626713561984,-4.19000246913709,-4.194378224712198,-4.198753980287303,-4.20312973586241,-4.207505491437516,-4.211881247012623,-4.216257002587729,-4.220632758162836,-4.225008513737942,-4.229384269313048,-4.233760024888155,-4.238135780463261,-4.242511536038367,-4.246887291613474,-4.25126304718858,-4.255638802763687,-4.260014558338793,-4.2643903139139,-4.268766069489006,-4.273141825064112,-4.277517580639219,-4.281893336214326,-4.286269091789431,-4.290644847364538,-4.295020602939645,-4.299396358514752,-4.303772114089857,-4.308147869664964,-4.3103081233496425,-4.301390867582185,-4.292473611814726,-4.283556356047269,-4.2746391002798125,-4.265721844512354,-4.256804588744897,-4.24788733297744,-4.2389700772099825,-4.230052821442524,-4.221135565675069,-4.212218309907611,-4.2033010541401525,-4.194383798372694,-4.185466542605238,-4.176549286837781,-4.1676320310703225,-4.158714775302866,-4.149797519535408,-4.140880263767951,-4.131963008000494,-4.123045752233036,-4.114128496465579,-4.1052112406981225,-4.096293984930664,-4.087376729163206,-4.078459473395748,-4.0695422176282925,-4.060624961860834,-4.051707706093375,-4.04279045032592,-4.0338731945584625,-4.024955938791004,-4.016038683023548,-4.00712142725609,-3.998256492886269,-3.989580401542249,-3.9809043101982304,-3.9722282188542097,-3.9635521275101895,-3.9548760361661706,-3.9461999448221503,-3.933589601015436,-3.9181690768782302,-3.9027485527410217,-3.887328028603814,-3.8719075044666083,-3.8564869803293993,-3.8410664561921903,-3.8250672541131174,-3.80903741150997,-3.7930075689068197,-3.7769777263036692,-3.7609478837005215,-3.744918041097371,-3.7288881984942206,-3.712858355891073,-3.6968285132879224,-3.680798670684772,-3.6647688280816215,-3.6487389854784738,-3.632709142875323,-3.616679300272173,-3.600649457669025,-3.5846196150658742,-3.5685897724627242,-3.5525599298595765,-3.536530087256425,-3.5205002446532756,-3.5044704020501283,-3.488440559446977,-3.472410716843827,-3.4563808742406765,-3.4403510316375288,-3.424321189034378,-3.4082913464312274,-3.39226150382808,-3.3762316612249297,-3.3602018186217792,-3.3441719760186315,-3.328142133415481,-3.3121122908123306,-3.29608244820918,-3.2800526056060324],[-2.1573768968053937,-2.1643945831775704,-2.171412269549746,-2.178429955921923,-2.1854476422940996,-2.192465328666276,-2.199483015038452,-2.206500701410629,-2.2135183877828055,-2.2205360741549818,-2.2275537605271585,-2.2345714468993347,-2.2415891332715114,-2.2486068196436877,-2.2535004371800262,-2.2573320163556385,-2.2611635955312495,-2.2649951747068617,-2.268826753882473,-2.2726583330580854,-2.276489912233697,-2.2803214914093086,-2.284153070584921,-2.2879846497605323,-2.291816228936144,-2.295647808111756,-2.299479387287368,-2.3033109664629796,-2.3071425456385914,-2.3109741248142033,-2.314805703989815,-2.318637283165427,-2.3224688623410388,-2.3263004415166506,-2.3301320206922624,-2.3339635998678743,-2.3377951790434857,-2.3416267582190975,-2.3454583373947093,-2.3492899165703216,-2.353121495745933,-2.356953074921545,-2.3607846540971567,-2.3646162332727685,-2.3684478124483803,-2.3722793916239917,-2.376110970799604,-2.379942549975216,-2.383774129150827,-2.3876057083264395,-2.3914372875020513,-2.395268866677663,-2.3991004458532745,-2.4029320250288864,-2.4067636042044986,-2.41059518338011,-2.4144267625557223,-2.4182583417313337,-2.4220899209069455,-2.4259215000825574,-2.4297530792581696,-2.433584658433781,-2.437416237609393,-2.4412478167850047,-2.4450793959606165,-2.4489109751362284,-2.4527425543118397,-2.456574133487452,-2.4604057126630634,-2.4642372918386757,-2.468068871014287,-2.471900450189899,-2.4757320293655107,-2.4795636085411226,-2.4833951877167344,-2.4872267668923462,-2.491058346067958,-2.49488992524357,-2.4987215044191817,-2.5025530835947936,-2.5063846627704054,-2.510216241946017,-2.514047821121629,-2.5178794002972404,-2.523044503630552,-2.528476311795404,-2.533908119960256,-2.5393399281251074,-2.5447717362899596,-2.550203544454811,-2.555635352619663,-2.5610671607845146,-2.5664989689493662,-2.5719307771142184,-2.57736258527907,-2.5827943934439217,-2.588226201608774,-2.592231322938804,-2.5948097527259395,-2.5973881825130745,-2.599966612300209,-2.6025450420873444,-2.605123471874479,-2.607701901661614,-2.610280331448749,-2.6128587612358842,-2.6154371910230187,-2.618015620810154,-2.620594050597289,-2.623172480384424,-2.6257509101715586,-2.628329339958694,-2.6309077697458285,-2.6334861995329635,-2.636064629320099,-2.638643059107234,-2.641221488894369,-2.6437999186815038,-2.6463783484686387,-2.6489567782557737,-2.6515352080429087,-2.6541136378300436,-2.6566920676171786,-2.6592704974043135,-2.6618489271914485,-2.6644273569785835,-2.667005786765719,-2.6695842165528534,-2.6721626463399883,-2.6747410761271238,-2.6773195059142583,-2.6798979357013932,-2.6824763654885286,-2.685054795275663,-2.6876332250627986,-2.690211654849933,-2.6927900846370685,-2.695368514424203,-2.6979469442113384,-2.700525373998473,-2.7031038037856083,-2.7056822335727433,-2.7082606633598783,-2.7108390931470128,-2.713417522934148,-2.715995952721283,-2.718574382508418,-2.721152812295553,-2.723731242082688,-2.726309671869823,-2.728888101656958,-2.7314665314440933,-2.734044961231228,-2.736623391018363,-2.739201820805498,-2.7417802505926328,-2.7443586803797677,-2.7469371101669027,-2.7495155399540376,-2.752093969741172,-2.7546723995283076,-2.7572508293154425,-2.7598292591025775,-2.762407688889713,-2.7649861186768474,-2.767564548463983,-2.7701429782511178,-2.7744871901088874,-2.779714293001975,-2.7849413958950624,-2.79016849878815,-2.795395601681237,-2.800622704574325,-2.8058498074674123,-2.8110769103604993,-2.816304013253587,-2.821531116146674,-2.8267582190397618,-2.831985321932849,-2.8372124248259363,-2.8424395277190238,-2.8476666306121112,-2.8508572415175375,-2.8532051611647793,-2.85555308081202,-2.8579010004592615,-2.8602489201065024,-2.862596839753744,-2.864944759400985,-2.8672926790482265,-2.869640598695468,-2.8719885183427083,-2.8743364379899496,-2.876684357637191,-2.879032277284432,-2.8813801969316737,-2.8837281165789146,-2.8860760362261555,-2.888423955873397,-2.890771875520638,-2.893119795167879,-2.8954677148151204,-2.8978156344623613,-2.9001635541096027,-2.902511473756844,-2.9048593934040854,-2.9072073130513263,-2.909555232698567,-2.911903152345809,-2.91425107199305,-2.9165989916402912,-2.9189469112875326,-2.9212948309347735,-2.923642750582015,-2.9259906702292557,-2.928338589876497,-2.9306865095237384,-2.9330344291709793,-2.9353823488182202,-2.9377302684654616,-2.9400781881127034,-2.9424261077599443,-2.9447740274071856,-2.947121947054427,-2.949469866701668,-2.9518177863489092,-2.95416570599615,-2.9565136256433915,-2.958861545290633,-2.9612094649378733,-2.963557384585115,-2.9659053042323564,-2.9682532238795973,-2.970601143526839,-2.9729490631740796,-2.975296982821321,-2.9776449024685623,-2.9799928221158036,-2.9823407417630445,-2.984688661410286,-2.9870365810575272,-2.9893845007047677,-2.991732420352009,-2.994080339999251,-2.9964282596464913,-2.9987761792937326,-3.0011240989409744,-3.0034720185882153,-3.0058199382354562,-3.008167857882698,-3.0118045955596315,-3.0167301512662585,-3.0216557069728847,-3.026581262679511,-3.0315068183861382,-3.036432374092765,-3.0413579297993913,-3.0462834855060184,-3.0512090412126454,-3.056134596919271,-3.061060152625898,-3.0659857083325246,-3.070911264039151,-3.075836819745778,-3.0807623754524047,-3.0856879311590313,-3.0906134868656574,-3.0955390425722844,-3.100464598278911,-3.1053901539855375,-3.1103157096921645,-3.115241265398791,-3.1189958882891906,-3.121930853291181,-3.1248658182931712,-3.127800783295161,-3.1307357482971505,-3.1336707132991406,-3.1366056783011307,-3.13954064330312,-3.14247560830511,-3.1454105733071,-3.1483455383090897,-3.1512805033110793,-3.1542154683130694,-3.15715043331506,-3.160085398317049,-3.1630203633190392,-3.1659553283210293,-3.168890293323019,-3.171825258325009,-3.174760223326999,-3.177695188328989,-3.180630153330979,-3.183565118332969,-3.186500083334958,-3.1894350483369482,-3.1923700133389383,-3.1953049783409284,-3.1982399433429176,-3.2011749083449077,-3.204109873346898,-3.2070448383488874,-3.2099798033508775,-3.2129147683528676,-3.2158497333548572,-3.2187846983568473,-3.221719663358837,-3.2246546283608275,-3.2275895933628167,-3.230524558364807,-3.233459523366797,-3.2363944883687865,-3.2393294533707766,-3.2422644183727662,-3.245199383374756,-3.248134348376746,-3.2510693133787356,-3.2540042783807257,-3.256939243382716,-3.259874208384706,-3.262809173386696,-3.265744138388685,-3.2686791033906752,-3.2716140683926653,-3.2745490333946545,-3.2774839983966446,-3.280418963398635,-3.283353928400625,-3.2862888934026144,-3.289223858404605,-3.2921588234065946,-3.2950937884085842,-3.298030842138875,-3.3009720733257657,-3.3039133045126565,-3.3068545356995482,-3.309795766886439,-3.3127369980733303,-3.3156782292602216,-3.3186194604471133,-3.321560691634004,-3.324501922820895,-3.3274431540077867,-3.3303843851946775,-3.3333256163815683,-3.3362668475684596,-3.3392080787553504,-3.3421493099422417,-3.3450905411291325,-3.3480317723160242,-3.350973003502915,-3.3539142346898063,-3.3568554658766976,-3.359796697063589,-3.36273792825048,-3.3656791594373714,-3.3686203906242618,-3.3715616218111526,-3.3745028529980443,-3.3774440841849356,-3.380385315371827,-3.383326546558718,-3.3862677777456094,-3.3892090089324998,-3.392150240119391,-3.3950914713062827,-3.398032702493174,-3.4009739336800644,-3.403915164866956,-3.4068563960538474,-3.4097976272407386,-3.41273885842763,-3.4156800896145203,-3.4186213208014116,-3.421562551988303,-3.424503783175194,-3.4274450143620854,-3.430386245548976,-3.433327476735868,-3.4362687079227587,-3.439209939109649,-3.4421511702965404,-3.445092401483432,-3.448033632670323,-3.450974863857214,-3.4539160950441055,-3.4568573262309963,-3.4597985574178876,-3.462739788604779,-3.46568101979167,-3.468622250978561,-3.471563482165452,-3.474504713352344,-3.4774459445392347,-3.480387175726126,-3.4833284069130173,-3.4862696380999076,-3.489210869286799,-3.49215210047369,-3.4950933316605814,-3.4980345628474727,-3.499164319126825,-3.5001342317509607,-3.5011041443750974,-3.5020740569992337,-3.5030439696233695,-3.5040138822475053,-3.504983794871641,-3.505953707495777,-3.5069236201199128,-3.5078935327440486,-3.508863445368185,-3.5098333579923207,-3.5108032706164565,-3.5117731832405927,-3.510979930608227,-3.501370851693359,-3.4917617727784904,-3.4821526938636223,-3.4725436149487554,-3.4630892620987237,-3.454007977278649,-3.444926692458576,-3.435845407638502,-3.426764122818427,-3.4176828379983544,-3.4086015531782796,-3.3995202683582053,-3.390438983538131,-3.3813576987180576,-3.3722764138979837,-3.363195129077909,-3.3541138442578355,-3.3450325594377617,-3.335951274617687,-3.326869989797614,-3.317788704977539,-3.3087074201574653,-3.299626135337392,-3.2905448505173176,-3.281463565697243,-3.2723822808771685,-3.2633009960570956,-3.254219711237021,-3.2451384264169465,-3.2360571415968735,-3.2269758567767988,-3.2178945719567245,-3.208813287136652,-3.199732002316577,-3.1906507174965024,-3.181569432676428,-3.172488147856355,-3.163406863036281,-3.154325578216206,-3.145244293396133,-3.1361630085760583,-3.123064206022643,-3.1070957479454164,-3.0911272898681865,-3.0751588317909566,-3.05919037371373,-3.043221915636501,-3.027253457559271,-3.011284999482041,-2.9953165414048146,-2.9793480833275847,-2.963379625250355,-2.947411167173129,-2.931442709095899,-2.9154742510186695,-2.8995057929414427,-2.883537334864213,-2.867568876786983,-2.8516004187097534,-2.835631960632527,-2.819663502555297,-2.8036950444780677,-2.787726586400841,-2.7717581283236115,-2.755789670246382,-2.7398212121691543,-2.7238527540919253,-2.707884296014696,-2.691915837937469,-2.675947379860239,-2.6599789217830097,-2.64401046370578,-2.6280420056285534,-2.6120735475513235,-2.5961050894740936,-2.5801366313968677,-2.5641681733196378,-2.548199715242408,-2.5360271462736494,-2.5244042442847388,-2.512781342295828,-2.5011584403069174,-2.4895355383180084],[-1.676677121976143,-1.6805087011517545,-1.6843402803273666,-1.6881718595029784,-1.69200343867859,-1.6958350178542019,-1.6996665970298137,-1.7034981762054255,-1.7073297553810372,-1.7111613345566492,-1.714992913732261,-1.7188244929078726,-1.7226560720834847,-1.7264876512590963,-1.7303192304347081,-1.73415080961032,-1.7379823887859316,-1.7418139679615436,-1.7456455471371553,-1.749477126312767,-1.753308705488379,-1.7571402846639907,-1.7609718638396026,-1.7648034430152144,-1.7686350221908262,-1.7724666013664379,-1.77629818054205,-1.7801297597176615,-1.7839613388932734,-1.787792918068885,-1.7916244972444968,-1.7954560764201088,-1.7992876555957205,-1.8031192347713323,-1.8069508139469441,-1.810782393122556,-1.8146139722981678,-1.8184455514737796,-1.8222771306493915,-1.8261087098250033,-1.8299402890006151,-1.8337718681762267,-1.8376034473518388,-1.8414350265274502,-1.845266605703062,-1.849098184878674,-1.8529297640542857,-1.856761343229898,-1.8605929224055093,-1.8644245015811212,-1.868256080756733,-1.8720876599323448,-1.8759192391079567,-1.8797508182835685,-1.8835823974591803,-1.8874139766347922,-1.8912455558104038,-1.8950771349860158,-1.8989087141616274,-1.9027402933372393,-1.9065718725128509,-1.910403451688463,-1.9142350308640748,-1.9180666100396864,-1.9218981892152982,-1.92572976839091,-1.9295613475665216,-1.9333929267421335,-1.9372245059177455,-1.9410560850933574,-1.944887664268969,-1.9487192434445806,-1.9525508226201926,-1.9563824017958045,-1.960213980971416,-1.9640455601470281,-1.9678771393226397,-1.9717087184982516,-1.9755402976738634,-1.9793718768494752,-1.9832034560250873,-1.983824186934027,-1.984444913881054,-1.9850656408280818,-1.9849108203923245,-1.9846008904800108,-1.984290960567697,-1.9859066073523342,-1.9884850371394693,-1.9910634669266039,-1.993641896713739,-1.996220326500874,-1.998798756288009,-2.001377186075144,-2.003955615862279,-2.006534045649414,-2.009112475436549,-2.0116909052236838,-2.014269335010819,-2.016847764797954,-2.0194261945850887,-2.022004624372224,-2.024583054159359,-2.027161483946494,-2.0297399137336285,-2.032318343520764,-2.0348967733078984,-2.0374752030950334,-2.040053632882169,-2.0426320626693037,-2.0452104924564383,-2.0477889222435737,-2.0503673520307086,-2.0529457818178436,-2.0555242116049786,-2.0581026413921135,-2.0606810711792485,-2.0632595009663834,-2.0658379307535184,-2.0684163605406534,-2.0709947903277883,-2.0735732201149233,-2.0761516499020582,-2.078730079689193,-2.081308509476328,-2.083886939263463,-2.086465369050598,-2.089043798837733,-2.0916222286248676,-2.094200658412003,-2.0967790881991384,-2.099357517986273,-2.1019359477734083,-2.104514377560543,-2.1070928073476782,-2.1096712371348127,-2.1122496669219477,-2.1148280967090827,-2.117406526496218,-2.119984956283353,-2.1225633860704876,-2.1251418158576225,-2.1277202456447575,-2.1302986754318924,-2.132877105219028,-2.1354555350061624,-2.1380339647932978,-2.1406123945804327,-2.1431908243675677,-2.1457692541547027,-2.1483476839418376,-2.1509261137289726,-2.1535045435161075,-2.1560829733032425,-2.1586614030903775,-2.1612398328775124,-2.1638182626646474,-2.1663966924517823,-2.1689751222389173,-2.1715535520260523,-2.1741319818131872,-2.1767104116003226,-2.179288841387457,-2.181867271174592,-2.184445700961727,-2.1870241307488625,-2.189602560535997,-2.1902850207508564,-2.190019496179578,-2.1897539716082997,-2.189488447037021,-2.191126435294563,-2.1934694231963983,-2.195812411098233,-2.1981553990000684,-2.200498386901903,-2.202841374803738,-2.205184362705573,-2.207527350607408,-2.2098703385092424,-2.212213326411077,-2.2145563143129126,-2.216899302214747,-2.2192422901165823,-2.2215852780184173,-2.223928265920252,-2.2262712538220866,-2.2286142417239216,-2.2309572296257567,-2.2333002175275913,-2.2356432054294264,-2.237986193331261,-2.240329181233096,-2.242672169134931,-2.245015157036766,-2.247358144938601,-2.2497011328404355,-2.252044120742271,-2.2543871086441056,-2.2567300965459403,-2.2590730844477753,-2.26141607234961,-2.263759060251445,-2.2661020481532796,-2.2684450360551147,-2.27078802395695,-2.2731310118587844,-2.2754739997606195,-2.2778169876624546,-2.280159975564289,-2.282502963466124,-2.284845951367959,-2.287188939269794,-2.2895319271716286,-2.2918749150734636,-2.2942179029752987,-2.2965608908771333,-2.2989038787789684,-2.3012468666808035,-2.303589854582638,-2.305932842484473,-2.308275830386308,-2.310618818288143,-2.312961806189978,-2.3153047940918126,-2.3176477819936476,-2.3199907698954823,-2.3223337577973173,-2.324676745699152,-2.327019733600987,-2.329362721502822,-2.3317057094046567,-2.334048697306492,-2.336391685208327,-2.3387346731101615,-2.3410776610119965,-2.343420648913831,-2.345763636815666,-2.348106624717501,-2.350449612619336,-2.352792600521171,-2.3551355884230056,-2.3574785763248407,-2.3598215642266753,-2.362164552128511,-2.3645075400303455,-2.36685052793218,-2.369193515834015,-2.37153650373585,-2.373879491637685,-2.376195087002773,-2.3784832898311152,-2.380771492659458,-2.3830596954878005,-2.3853478983161427,-2.3876361011444844,-2.389924303972827,-2.3922125068011697,-2.3945007096295123,-2.396788912457854,-2.3990771152861967,-2.401365318114539,-2.403653520942881,-2.4059417237712237,-2.4082299265995664,-2.410518129427908,-2.4128063322562503,-2.4150945350845934,-2.4173827379129356,-2.4196709407412778,-2.42195914356962,-2.424247346397962,-2.4265355492263048,-2.4288237520546474,-2.43111195488299,-2.433400157711332,-2.435688360539674,-2.4379765633680166,-2.4402647661963592,-2.442552969024701,-2.4448411718530436,-2.447129374681386,-2.4494175775097284,-2.4517057803380706,-2.4539939831664133,-2.4562821859947555,-2.4585703888230976,-2.4608585916514403,-2.463146794479782,-2.4654349973081247,-2.4677232001364677,-2.4700114029648095,-2.4722996057931517,-2.4745878086214943,-2.4768760114498365,-2.479164214278179,-2.481851889803134,-2.4847868548051237,-2.4877218198071134,-2.4906567848091035,-2.4935917498110935,-2.4965267148130836,-2.499461679815073,-2.502396644817063,-2.505331609819053,-2.508266574821043,-2.5112015398230327,-2.514136504825023,-2.5170714698270125,-2.520006434829002,-2.5229413998309926,-2.525876364832982,-2.528811329834972,-2.531746294836962,-2.534681259838952,-2.5376162248409417,-2.5405511898429314,-2.5434861548449215,-2.546421119846911,-2.549356084848901,-2.5522910498508913,-2.555226014852881,-2.5581609798548706,-2.561095944856861,-2.5640309098588507,-2.5669658748608404,-2.5699008398628305,-2.5728358048648206,-2.57577076986681,-2.5787057348688,-2.58164069987079,-2.58457566487278,-2.5875106298747697,-2.59044768360506,-2.593388914791951,-2.5963301459788424,-2.599271377165733,-2.6022126083526245,-2.6051538395395157,-2.6080950707264066,-2.6110363019132983,-2.613977533100189,-2.6169187642870804,-2.6198599954739716,-2.6228012266608625,-2.6257424578477537,-2.628683689034645,-2.631624920221536,-2.634566151408427,-2.6375073825953184,-2.640049022775638,-2.641018935399774,-2.64198884802391,-2.642958760648046,-2.643928673272182,-2.644898585896318,-2.645868498520454,-2.6468384111445897,-2.6478083237687255,-2.648778236392862,-2.6497481490169976,-2.6507180616411334,-2.6516879742652693,-2.652657886889405,-2.653627799513541,-2.6545977121376767,-2.6555676247618134,-2.656537537385949,-2.6575074500100846,-2.658477362634221,-2.6594472752583567,-2.6604171878824925,-2.6613871005066283,-2.6623570131307646,-2.6633269257549004,-2.6642968383790366,-2.6652667510031725,-2.6662366636273083,-2.667206576251444,-2.66817648887558,-2.669146401499716,-2.6701163141238515,-2.671086226747988,-2.6720561393721236,-2.6730260519962594,-2.6739959646203957,-2.6749658772445315,-2.6759357898686673,-2.6769057024928036,-2.6778756151169394,-2.678845527741075,-2.679815440365211,-2.6807853529893473,-2.681755265613483,-2.682725178237619,-2.683695090861755,-2.6846650034858905,-2.6856349161100264,-2.6866048287341626,-2.6875747413582984,-2.6885446539824343,-2.6895145666065705,-2.6904844792307063,-2.691454391854842,-2.6924243044789784,-2.693394217103114,-2.69436412972725,-2.6953340423513863,-2.6963039549755217,-2.697273867599658,-2.6982437802237937,-2.6992136928479296,-2.700183605472066,-2.7011535180962016,-2.7021234307203374,-2.7030933433444737,-2.7023000907121086,-2.69269101179724,-2.683081932882372,-2.6734728539675032,-2.6638637750526364,-2.6542546961377687,-2.6446456172229,-2.6350365383080336,-2.6254274593931655,-2.615818380478297,-2.6062093015634304,-2.5966002226485623,-2.5869911437336937,-2.5773820648188255,-2.5677729859039586,-2.5581639069890905,-2.5485548280742223,-2.5389457491593554,-2.529336670244487,-2.5197275913296187,-2.5101185124147523,-2.500509433499884,-2.4910857113096405,-2.4820044264895675,-2.4729231416694932,-2.4638418568494185,-2.4547605720293437,-2.445679287209271,-2.4365980023891964,-2.427516717569122,-2.418435432749049,-2.4093541479289744,-2.4002728631089,-2.391191578288827,-2.3821102934687524,-2.373029008648678,-2.3639477238286037,-2.3548664390085308,-2.345785154188456,-2.3367038693683817,-2.3276225845483083,-2.318541299728234,-2.3054424971748184,-2.2894740390975916,-2.273505581020362,-2.2575371229431322,-2.2415686648659054,-2.225600206788676,-2.2096317487114465,-2.1936632906342166,-2.1776948325569903,-2.161726374479761,-2.1457579164025304,-2.129789458325304,-2.1138210002480746,-2.0978525421708447,-2.0818840840936184,-2.0659156260163885,-2.049947167939159,-2.0339787098619295,-2.0180102517847027,-2.002041793707473,-1.9896170293249171,-1.9779941273360089,-1.966371225347098,-1.9547483233581873,-1.9431254213692783,-1.9315025193803677,-1.9198796173914567,-1.9082567154025478,-1.8966338134136373,-1.8850109114247264,-1.873388009435816,-1.861765107446907,-1.8501422054579963,-1.8385193034690859,-1.8268964014801767,-1.815273499491266,-1.8036505975023556,-1.7920276955134469,-1.780404793524536,-1.768781891535625,-1.7571589895467143,-1.7455360875578056],[-1.195430800254592,-1.1992623794302038,-1.2030939586058158,-1.2069255377814274,-1.2107571169570392,-1.214588696132651,-1.218420275308263,-1.2222518544838747,-1.2260834336594864,-1.2299150128350984,-1.2337465920107098,-1.2375781711863216,-1.2414097503619337,-1.2452413295375453,-1.2490729087131571,-1.252904487888769,-1.2567360670643808,-1.2605676462399924,-1.2643992254156045,-1.2682308045912163,-1.272062383766828,-1.2758939629424397,-1.2797255421180516,-1.2835571212936634,-1.2873887004692752,-1.2912202796448868,-1.2950518588204987,-1.2988834379961105,-1.3027150171717223,-1.3065465963473342,-1.310378175522946,-1.3142097546985578,-1.3180413338741697,-1.3218729130497815,-1.3257044922253933,-1.3295360714010052,-1.333367650576617,-1.3371992297522286,-1.3410308089278404,-1.3448623881034523,-1.348693967279064,-1.3525255464546757,-1.3563571256302878,-1.3601887048058994,-1.3640202839815112,-1.367851863157123,-1.3716834423327349,-1.375515021508347,-1.3793466006839585,-1.3831781798595704,-1.387009759035182,-1.390841338210794,-1.3946729173864059,-1.3985044965620175,-1.4023360757376295,-1.4061676549132411,-1.409999234088853,-1.413830813264465,-1.4176623924400766,-1.4214939716156882,-1.4253255507913,-1.4291571299669121,-1.4329887091425237,-1.4368202883181356,-1.4390464448115776,-1.439667171758605,-1.4402878987056322,-1.4409086256526595,-1.4415293525996868,-1.4421500795467144,-1.4427708064937417,-1.443391533440769,-1.4440122603877963,-1.4446329873348236,-1.445253714281851,-1.4458744412288784,-1.4464951681759057,-1.4471158951229328,-1.4477366220699606,-1.4483573490169876,-1.4489780759640152,-1.4495988029110425,-1.4502195298580698,-1.4508402568050973,-1.4506854363693402,-1.4503755064570265,-1.4500655765447128,-1.4497556466323993,-1.4494457167200856,-1.4491357868077719,-1.4488258568954582,-1.4485159269831445,-1.448205997070831,-1.4478960671585173,-1.4475861372462038,-1.44727620733389,-1.4469662774215766,-1.4466563475092626,-1.4463464175969492,-1.4460364876846354,-1.445726557772322,-1.4454166278600082,-1.4451066979476945,-1.445278164406028,-1.447856594193163,-1.4504350239802979,-1.4530134537674328,-1.4555918835545678,-1.458170313341703,-1.460748743128838,-1.4633271729159727,-1.4659056027031079,-1.4684840324902426,-1.4710624622773778,-1.4736408920645128,-1.4762193218516477,-1.478797751638783,-1.4813761814259174,-1.4839546112130526,-1.4865330410001878,-1.4891114707873225,-1.4916899005744577,-1.4942683303615927,-1.4968467601487276,-1.4994251899358626,-1.5020036197229976,-1.5045820495101325,-1.5071604792972675,-1.5097389090844024,-1.5123173388715374,-1.5148957686586724,-1.5174741984458073,-1.5200526282329423,-1.5226310580200773,-1.5252094878072122,-1.5277879175943472,-1.5303663473814821,-1.532944777168617,-1.5355232069557523,-1.5381016367428872,-1.5406800665300222,-1.543258496317157,-1.5458369261042921,-1.5484153558914269,-1.5509937856785623,-1.5535722154656968,-1.5561506452528322,-1.558729075039967,-1.561307504827102,-1.563885934614237,-1.566464364401372,-1.569042794188507,-1.5716212239756417,-1.5741996537627767,-1.5767780835499117,-1.5793565133370466,-1.5819349431241816,-1.5845133729113168,-1.5870918026984517,-1.5896702324855865,-1.5922486622727217,-1.5948270920598566,-1.5974055218469916,-1.5999839516341265,-1.6025623814212615,-1.6051408112083967,-1.6077192409955314,-1.6084017012103906,-1.6081361766391125,-1.6078706520678339,-1.6076051274965553,-1.607339602925277,-1.6070740783539983,-1.6068085537827197,-1.606543029211441,-1.606277504640163,-1.6060119800688841,-1.6057464554976058,-1.6054809309263274,-1.6052154063550486,-1.60494988178377,-1.6046843572124916,-1.604418832641213,-1.6041533080699344,-1.6038877834986558,-1.6036222589273774,-1.6033567343560988,-1.60309120978482,-1.602825685213542,-1.6025601606422635,-1.6022946360709849,-1.60259311595657,-1.6049361038584051,-1.60727909176024,-1.609622079662075,-1.61196506756391,-1.6143080554657447,-1.6166510433675798,-1.6189940312694144,-1.621337019171249,-1.6236800070730844,-1.6260229949749194,-1.6283659828767543,-1.6307089707785891,-1.6330519586804235,-1.6353949465822586,-1.6377379344840937,-1.6400809223859287,-1.6424239102877634,-1.6447668981895982,-1.6471098860914333,-1.649452873993268,-1.651795861895103,-1.6541388497969378,-1.6564818376987727,-1.6588248256006075,-1.6611678135024426,-1.6635108014042774,-1.6658537893061123,-1.6681967772079473,-1.670539765109782,-1.672882753011617,-1.6752257409134517,-1.6775687288152867,-1.6799117167171218,-1.6822547046189564,-1.6845976925207915,-1.6869406804226261,-1.6892836683244612,-1.691626656226296,-1.693969644128131,-1.6963126320299657,-1.6986556199318006,-1.7009986078336359,-1.7033415957354707,-1.7056845836373056,-1.7080275715391402,-1.7103705594409753,-1.7127135473428101,-1.715056535244645,-1.71739952314648,-1.7197425110483149,-1.7220854989501497,-1.7244284868519844,-1.7267714747538194,-1.729114462655654,-1.7314574505574893,-1.733800438459324,-1.736143426361159,-1.7384864142629939,-1.7408020096280823,-1.743090212456425,-1.7453784152847673,-1.7476666181131095,-1.7499548209414522,-1.7522430237697944,-1.7545312265981365,-1.756819429426479,-1.7591076322548214,-1.7613958350831636,-1.7636840379115062,-1.7659722407398486,-1.7682604435681908,-1.7705486463965328,-1.7728368492248756,-1.7751250520532178,-1.7774132548815598,-1.7797014577099024,-1.7819896605382446,-1.7842778633665872,-1.7865660661949294,-1.7888542690232718,-1.791142471851614,-1.7934306746799564,-1.7957188775082988,-1.7980070803366413,-1.8002952831649837,-1.802583485993326,-1.8048716888216683,-1.8071598916500105,-1.8094480944783529,-1.8117362973066955,-1.8140245001350375,-1.8163127029633799,-1.8186009057917225,-1.8208891086200645,-1.823177311448407,-1.8254655142767493,-1.8277537171050917,-1.8300419199334341,-1.8323301227617765,-1.834618325590119,-1.836906528418461,-1.8391947312468035,-1.841482934075146,-1.8437711369034882,-1.8460593397318303,-1.848347542560173,-1.8506357453885152,-1.8529239482168576,-1.8552121510452,-1.8575003538735422,-1.8597885567018846,-1.8620767595302268,-1.8643649623585694,-1.8666531651869114,-1.868941368015254,-1.8712295708435966,-1.8735177736719386,-1.875805976500281,-1.8780941793286234,-1.8803823821569658,-1.8826705849853078,-1.8849587878136502,-1.8872469906419924,-1.8895351934703348,-1.8918233962986772,-1.8940145272371822,-1.8931770771198972,-1.8923396270026125,-1.8915021768853268,-1.8906647267680416,-1.8898272766507567,-1.8889898265334717,-1.8881523764161867,-1.8873149262989017,-1.8864774761816165,-1.8856400260643316,-1.8848025759470466,-1.8839651258297616,-1.8831276757124766,-1.8822902255951914,-1.8814527754779062,-1.88072781938949,-1.8802278513588124,-1.8797278833281346,-1.8792279152974565,-1.8787279472667788,-1.8782279792361007,-1.8777280112054229,-1.8772280431747448,-1.8767280751440674,-1.8762281071133893,-1.8757281390827114,-1.8752281710520335,-1.8747282030213557,-1.8742282349906778,-1.8737282669599997,-1.8732282989293223,-1.872728330898644,-1.8722283628679666,-1.8717283948372883,-1.8712284268066104,-1.8707284587759325,-1.8702284907452547,-1.8697285227145768,-1.869228554683899,-1.868728586653221,-1.8682286186225432,-1.8677286505918653,-1.8672286825611872,-1.8667287145305096,-1.8662287464998315,-1.8657287784691536,-1.8652288104384758,-1.8647288424077977,-1.86422887437712,-1.863728906346442,-1.8632289383157645,-1.8627289702850862,-1.8622290022544088,-1.8617290342237305,-1.8612290661930526,-1.8607290981623748,-1.8602291301316967,-1.8597291621010186,-1.859229194070341,-1.858729226039663,-1.8585267363553406,-1.8594966489794764,-1.8604665616036122,-1.861436474227748,-1.8624063868518843,-1.8633762994760201,-1.864346212100156,-1.8653161247242922,-1.866286037348428,-1.8672559499725638,-1.8682258625967,-1.869195775220836,-1.8701656878449717,-1.8711356004691075,-1.8721055130932436,-1.8730754257173796,-1.8740453383415154,-1.8750152509656515,-1.8759851635897873,-1.876955076213923,-1.8779249888380591,-1.878894901462195,-1.879864814086331,-1.8808347267104666,-1.8818046393346028,-1.8827745519587387,-1.8837444645828745,-1.8847143772070107,-1.8856842898311466,-1.8866542024552824,-1.8876241150794184,-1.8885940277035544,-1.88956394032769,-1.8905338529518263,-1.8915037655759621,-1.892473678200098,-1.8934435908242337,-1.8944135034483698,-1.893620250816005,-1.8840111719011368,-1.8744020929862684,-1.8647930140714,-1.8551839351565333,-1.8455748562416652,-1.8359657773267968,-1.82635669841193,-1.8167476194970615,-1.8071385405821934,-1.797529461667327,-1.7879203827524586,-1.77831130383759,-1.7687022249227216,-1.7590931460078554,-1.749484067092987,-1.7398749881781184,-1.730265909263252,-1.7206568303483833,-1.7110477514335152,-1.7014386725186488,-1.6918295936037802,-1.682220514688912,-1.6726114357740456,-1.663002356859177,-1.6533932779443086,-1.6437841990294402,-1.6341751201145738,-1.6245660411997054,-1.614956962284837,-1.6053478833699704,-1.5957388044551022,-1.5861297255402338,-1.5765206466253672,-1.5669115677104988,-1.5573024887956306,-1.5476934098807622,-1.5380843309658956,-1.528475252051027,-1.5190821605205729,-1.5100008757005,-1.5009195908804256,-1.48782078832701,-1.471852330249783,-1.4558838721725536,-1.443206912376202,-1.4315840103872934,-1.4199611083983823,-1.408338206409472,-1.3967153044205611,-1.3850924024316522,-1.3734695004427413,-1.3618465984538306,-1.3502236964649221,-1.3386007944760112,-1.3269778924871005,-1.3153549904981918,-1.303732088509281,-1.2921091865203702,-1.2804862845314593,-1.2688633825425506,-1.2572404805536397,-1.245617578564729,-1.2339946765758203,-1.2223717745869096,-1.2107488725979987,-1.19912597060909,-1.1875030686201793,-1.1758801666312686,-1.1642572646423597,-1.152634362653449,-1.1410114606645383,-1.1293885586756276,-1.1177656566867187,-1.106142754697808,-1.094519852708897,-1.0828969507199884,-1.0712740487310777,-1.059651146742167,-1.048028244753258,-1.0364053427643474,-1.0247824407754367,-1.0131595387865258,-1.001536636797617],[-0.7141844785330318,-0.7180160577086437,-0.7218476368842554,-0.7256792160598673,-0.7295107952354789,-0.7333423744110908,-0.7371739535867028,-0.7410055327623144,-0.7448371119379262,-0.7486686911135382,-0.7525002702891499,-0.7563318494647617,-0.7601634286403736,-0.7639950078159853,-0.7678265869915972,-0.7716581661672091,-0.7754897453428207,-0.7793213245184325,-0.7831529036940443,-0.7869844828696562,-0.7908160620452678,-0.7946476412208798,-0.7984792203964914,-0.8023107995721033,-0.8061423787477152,-0.8099739579233269,-0.8138055370989388,-0.8176371162745506,-0.8214686954501624,-0.8253002746257742,-0.8291318538013859,-0.8329634329769977,-0.8367950121526095,-0.8406265913282214,-0.8444581705038332,-0.848289749679445,-0.8521213288550568,-0.8559529080306686,-0.8597844872062804,-0.8636160663818923,-0.8674476455575039,-0.8712792247331158,-0.8751108039087276,-0.8789423830843394,-0.8827739622599512,-0.8866055414355629,-0.8904371206111749,-0.8942686997867866,-0.8948894296361453,-0.8955101565831727,-0.8961308835302,-0.8967516104772273,-0.8973723374242547,-0.8979930643712821,-0.8986137913183094,-0.8992345182653367,-0.8998552452123642,-0.9004759721593916,-0.9010966991064189,-0.9017174260534462,-0.9023381530004736,-0.9029588799475009,-0.9035796068945283,-0.9042003338415556,-0.9048210607885829,-0.9054417877356103,-0.9060625146826377,-0.9066832416296651,-0.9073039685766924,-0.9079246955237197,-0.9085454224707471,-0.9091661494177744,-0.9097868763648018,-0.9104076033118291,-0.9110283302588564,-0.911649057205884,-0.9122697841529113,-0.9128905110999386,-0.9135112380469659,-0.9141319649939933,-0.9147526919410207,-0.915373418888048,-0.9159941458350753,-0.9166148727821026,-0.9164600523463459,-0.9161501224340323,-0.9158401925217186,-0.9155302626094048,-0.9152203326970912,-0.9149104027847776,-0.9146004728724639,-0.9142905429601502,-0.9139806130478365,-0.9136706831355229,-0.9133607532232093,-0.9130508233108956,-0.9127408933985819,-0.9124309634862683,-0.9121210335739547,-0.911811103661641,-0.9115011737493273,-0.9111912438370137,-0.9108813139247,-0.9105713840123864,-0.9102614541000726,-0.9099515241877589,-0.9096415942754453,-0.9093316643631317,-0.909021734450818,-0.9087118045385043,-0.9084018746261907,-0.9080919447138771,-0.9077820148015634,-0.9074720848892497,-0.9071621549769361,-0.9068522250646224,-0.9065422951523088,-0.9062323652399951,-0.9059224353276814,-0.9056125054153678,-0.9072281512468459,-0.9098065810339809,-0.9123850108211159,-0.914963440608251,-0.9175418703953858,-0.9201203001825208,-0.9226987299696559,-0.9252771597567907,-0.9278555895439256,-0.9304340193310607,-0.9330124491181956,-0.9355908789053307,-0.9381693086924655,-0.9407477384796006,-0.9433261682667355,-0.9459045980538705,-0.9484830278410055,-0.9510614576281404,-0.9536398874152756,-0.9562183172024106,-0.9587967469895453,-0.9613751767766803,-0.9639536065638152,-0.9665320363509502,-0.9691104661380854,-0.9716888959252203,-0.9742673257123553,-0.9768457554994903,-0.9794241852866252,-0.9820026150737603,-0.9845810448608953,-0.9871594746480302,-0.9897379044351652,-0.9923163342223,-0.9948947640094352,-0.99747319379657,-1.0000516235837051,-1.00263005337084,-1.0052084831579748,-1.0077869129451098,-1.010365342732245,-1.0129437725193797,-1.015522202306515,-1.0181006320936499,-1.0206790618807848,-1.0232574916679198,-1.0258359214550548,-1.026518381669914,-1.0262528570986356,-1.025987332527357,-1.0257218079560786,-1.0254562833848,-1.0251907588135216,-1.0249252342422426,-1.0246597096709644,-1.0243941850996858,-1.0241286605284072,-1.0238631359571286,-1.0235976113858503,-1.0233320868145717,-1.023066562243293,-1.022801037672015,-1.0225355131007363,-1.0222699885294577,-1.0220044639581793,-1.0217389393869007,-1.0214734148156221,-1.021207890244343,-1.020942365673065,-1.0206768411017864,-1.0204113165305078,-1.0201457919592294,-1.0198802673879508,-1.0196147428166722,-1.019349218245394,-1.0190836936741152,-1.0188181691028368,-1.018552644531558,-1.0182871199602799,-1.0180215953890013,-1.0177560708177222,-1.0174905462464443,-1.0172250216751655,-1.0169594971038871,-1.0166939725326085,-1.0164284479613297,-1.0161629233900513,-1.0158973988187727,-1.0156318742474943,-1.0153663496762158,-1.0151008251049372,-1.0148353005336588,-1.0164027845204,-1.0187457724222346,-1.0210887603240697,-1.0234317482259045,-1.0257747361277394,-1.0281177240295742,-1.0304607119314093,-1.032803699833244,-1.0351466877350788,-1.0374896756369139,-1.0398326635387487,-1.0421756514405836,-1.0445186393424186,-1.0468616272442537,-1.0492046151460883,-1.0515476030479234,-1.053890590949758,-1.0562335788515929,-1.058576566753428,-1.0609195546552628,-1.0632625425570976,-1.0656055304589327,-1.0679485183607675,-1.0702915062626022,-1.0726344941644372,-1.074977482066272,-1.077320469968107,-1.0796634578699418,-1.0820064457717768,-1.0843494336736117,-1.0866924215754465,-1.0890354094772816,-1.0913783973791162,-1.093721385280951,-1.096064373182786,-1.0984073610846208,-1.1007503489864559,-1.1030933368882907,-1.105408932253379,-1.1076971350817215,-1.109985337910064,-1.1122735407384061,-1.1145617435667488,-1.116849946395091,-1.1191381492234331,-1.1214263520517755,-1.1237145548801182,-1.1260027577084601,-1.1282909605368026,-1.1305791633651452,-1.1328673661934872,-1.1351555690218298,-1.137443771850172,-1.1397319746785144,-1.1420201775068566,-1.144308380335199,-1.1465965831635412,-1.1488847859918836,-1.1511729888202262,-1.1534611916485686,-1.1557493944769106,-1.158037597305253,-1.1603258001335957,-1.1626140029619378,-1.1649022057902803,-1.1671904086186227,-1.1694786114469649,-1.1717668142753073,-1.1740550171036495,-1.176343219931992,-1.178631422760334,-1.1809196255886765,-1.183207828417019,-1.185496031245361,-1.1877842340737035,-1.1900724369020461,-1.192360639730388,-1.1946488425587307,-1.1969370453870734,-1.1992252482154155,-1.2015134510437577,-1.2038016538721001,-1.2042066962233027,-1.2033692461060175,-1.2025317959887327,-1.2016943458714473,-1.200856895754162,-1.200019445636877,-1.1991819955195921,-1.198344545402307,-1.197507095285022,-1.196669645167737,-1.195832195050452,-1.1949947449331666,-1.1941572948158818,-1.1933198446985969,-1.1924823945813119,-1.1916449444640267,-1.1908074943467417,-1.1899700442294565,-1.1891325941121713,-1.1882951439948866,-1.1874576938776014,-1.1866202437603162,-1.1857827936430312,-1.184945343525746,-1.184107893408461,-1.183270443291176,-1.1824329931738906,-1.1815955430566056,-1.1807580929393207,-1.1799206428220357,-1.1790831927047505,-1.1782457425874655,-1.1774082924701805,-1.1765708423528956,-1.1757333922356104,-1.1748959421183254,-1.1740584920010402,-1.1732210418837554,-1.1723835917664702,-1.1716586356780545,-1.1711586676473764,-1.1706586996166988,-1.170158731586021,-1.169658763555343,-1.1691587955246652,-1.168658827493987,-1.1681588594633092,-1.1676588914326314,-1.1671589234019535,-1.1666589553712754,-1.1661589873405975,-1.1656590193099197,-1.1651590512792418,-1.1646590832485642,-1.1641591152178863,-1.1636591471872084,-1.1631591791565303,-1.1626592111258525,-1.1621592430951746,-1.1616592750644967,-1.1611593070338189,-1.160659339003141,-1.1601593709724631,-1.1596594029417853,-1.1591594349111074,-1.1586594668804295,-1.1581594988497517,-1.1576595308190736,-1.1571595627883957,-1.1566595947577176,-1.15615962672704,-1.1556596586963621,-1.155159690665684,-1.1546597226350062,-1.1541597546043285,-1.1536597865736504,-1.1531598185429728,-1.152659850512295,-1.1521598824816168,-1.151659914450939,-1.1511599464202609,-1.150659978389583,-1.1501600103589051,-1.149660042328227,-1.1491600742975494,-1.1486601062668713,-1.1481601382361937,-1.1476601702055158,-1.1471602021748377,-1.1466602341441599,-1.146160266113482,-1.1456602980828041,-1.1451603300521263,-1.1446603620214484,-1.1441603939907705,-1.1436604259600927,-1.1431604579294148,-1.1426604898987367,-1.142160521868059,-1.1416605538373812,-1.141160585806703,-1.1406606177760252,-1.1379636326652267,-1.1352198965551148,-1.1324761604450024,-1.1297324243348903,-1.1269886882247788,-1.1242449521146662,-1.121501216004554,-1.1187574798944422,-1.11601374378433,-1.113270007674218,-1.1105262715641062,-1.1077825354539939,-1.105038799343882,-1.1022950632337698,-1.0995513271236579,-1.0968075910135455,-1.0940638549034334,-1.0913201187933217,-1.0885763826832093,-1.0858326465730972,-1.0817289168297708,-1.07082521892037,-1.0599215210109691,-1.0490178231015683,-1.0381141251921693,-1.0272104272827685,-1.0163067293733676,-1.005403031463969,-0.9949824887187054,-0.9851329449923034,-0.9752834012659032,-0.9654338575395013,-0.9555843138130993,-0.9457347700866974,-0.9358852263602973,-0.9260356826338952,-0.9161861389074935,-0.9063365951810932,-0.8964870514546912,-0.8866375077282892,-0.8767879640018892,-0.8669384202754874,-0.8570888765490854,-0.8472393328226852,-0.8373897890962834,-0.8275402453698815,-0.8176907016434792,-0.8078411579170791,-0.7979916141906772,-0.7881420704642754,-0.7782925267378751,-0.7684429830114732,-0.7585934392850713,-0.7487438955586712,-0.7388943518322693,-0.7290448081058671,-0.7191952643794652,-0.7093457206530651,-0.6994961769266632,-0.6896466332002611,-0.679797089473861,-0.6699475457474591,-0.6595617294072459,-0.6487928612000269,-0.6380239929928058,-0.6272551247855847,-0.6164862565783659,-0.6057173883711445,-0.5949485201639234,-0.5841796519567025,-0.5734107837494833,-0.5626419155422622,-0.5518730473350412,-0.541104179127822,-0.5303353109206009,-0.5195664427133797,-0.5087975745061608,-0.4980287062989397,-0.4872598380917187,-0.47649096988449763,-0.4657221016772786,-0.4549532334700574,-0.44418436526283633,-0.4334154970556172,-0.4226466288483961,-0.4118777606411752,-0.401108892433956,-0.39034002422673497,-0.37957115601951374,-0.36880228781229474,-0.3580334196050737,-0.3472645513978526,-0.3364956831906315,-0.3257268149834124,-0.31495794677619127,-0.3041890785689702,-0.30080122568622697,-0.3004526306459371,-0.30010403560564725,-0.2997554405653575,-0.2994068455250678,-0.29905825048477813,-0.2987096554444884,-0.2983610604041987],[-0.23293815681148067,-0.23676973598709256,-0.24060131516270433,-0.24443289433831614,-0.24826447351392789,-0.2520960526895397,-0.25592763186515144,-0.2597592110407633,-0.2635907902163751,-0.26742236939198727,-0.2712539485675991,-0.2750855277432108,-0.27891710691882265,-0.28274868609443443,-0.28658026527004626,-0.2904118444456581,-0.2942434236212698,-0.2980750027968816,-0.3019065819724935,-0.30573816114810526,-0.309569740323717,-0.3134013194993288,-0.31723289867494064,-0.3210644778505525,-0.3248960570261643,-0.32872763620177603,-0.33255921537738786,-0.3363907945529997,-0.34022237372861147,-0.3440539529042233,-0.347885532079835,-0.3501116875136959,-0.35073241446072323,-0.3513531414077506,-0.3519738683547779,-0.3525945953018053,-0.3532153222488326,-0.35383604919586004,-0.3544567761428874,-0.3550775030899147,-0.35569823003694206,-0.3563189569839694,-0.35693968393099684,-0.35756041087802415,-0.3581811378250515,-0.3588018647720789,-0.35942259171910607,-0.3600433186661337,-0.360664045613161,-0.36128477256018815,-0.36190549950721573,-0.36252622645424293,-0.36314695340127046,-0.36376768034829776,-0.36438840729532496,-0.3650091342423525,-0.3656298611893797,-0.36625058813640726,-0.36687131508343457,-0.3674920420304617,-0.36811276897748935,-0.36873349592451643,-0.369354222871544,-0.3699749498185714,-0.37059567676559857,-0.37121640371262593,-0.3718371306596533,-0.3724578576066807,-0.373078584553708,-0.3736993115007354,-0.37432003844776274,-0.37494076539479004,-0.3755614923418174,-0.3761822192888448,-0.3768029462358722,-0.37742367318289954,-0.37804440012992685,-0.3786651270769542,-0.3792858540239816,-0.379906580971009,-0.3805273079180363,-0.38114803486506366,-0.381768761812091,-0.3823894887591183,-0.3822346683233615,-0.38192473841104785,-0.3816148084987342,-0.38130487858642054,-0.3809949486741069,-0.3806850187617933,-0.38037508884947957,-0.38006515893716586,-0.37975522902485226,-0.3794452991125386,-0.3791353692002249,-0.3788254392879111,-0.3785155093755977,-0.3782055794632838,-0.3778956495509704,-0.3775857196386567,-0.37727578972634296,-0.37696585981402925,-0.3766559299017156,-0.37634599998940194,-0.3760360700770883,-0.3757261401647746,-0.37541621025246097,-0.37510628034014737,-0.37479635042783366,-0.37448642051552,-0.37417649060320635,-0.37386656069089264,-0.37355663077857904,-0.3732467008662653,-0.3729367709539517,-0.372626841041638,-0.37231691112932425,-0.3720069812170106,-0.37169705130469716,-0.3713871213923833,-0.3710771914800698,-0.37076726156775597,-0.3704573316554423,-0.3701474017431289,-0.369837471830815,-0.36952754191850146,-0.36921761200618775,-0.36890768209387415,-0.3685977521815605,-0.3682878222692468,-0.3679778923569331,-0.36766796244461947,-0.3673580325323058,-0.36704810261999216,-0.3667381727076785,-0.3664282427953648,-0.36659970830053984,-0.3691781380876748,-0.3717565678748099,-0.37433499766194483,-0.37691342744907974,-0.3794918572362147,-0.38207028702334966,-0.3846487168104846,-0.3872271465976197,-0.38980557638475466,-0.3923840061718897,-0.39496243595902464,-0.39754086574615954,-0.4001192955332946,-0.4026977253204295,-0.40527615510756454,-0.4078545848946995,-0.4104330146818344,-0.41301144446896954,-0.41558987425610444,-0.41816830404323946,-0.4207467338303745,-0.42332516361750927,-0.42590359340464423,-0.4284820231917792,-0.4310604529789142,-0.4336388827660492,-0.4362173125531842,-0.43879574234031915,-0.44137417212745417,-0.443952601914589,-0.44463506212944837,-0.4443695375581699,-0.44410401298689123,-0.44383848841561274,-0.4435729638443342,-0.4433074392730559,-0.4430419147017774,-0.44277639013049885,-0.44251086555922026,-0.4422453409879417,-0.4419798164166631,-0.44171429184538463,-0.441448767274106,-0.4411832427028275,-0.4409177181315491,-0.44065219356027047,-0.440386668988992,-0.4401211444177135,-0.439855619846435,-0.4395900952751565,-0.43932457070387765,-0.4390590461325994,-0.43879352156132084,-0.43852799699004225,-0.4382624724187637,-0.43799694784748505,-0.43773142327620673,-0.43746589870492814,-0.43720037413364965,-0.4369348495623713,-0.4366693249910924,-0.4364038004198141,-0.4361382758485355,-0.4358727512772568,-0.4356072267059786,-0.4353417021346998,-0.43507617756342154,-0.4348106529921429,-0.4345451284208641,-0.4342796038495857,-0.43401407927830715,-0.43374855470702867,-0.43348303013575007,-0.4332175055644716,-0.43295198099319304,-0.43268645642191456,-0.432420931850636,-0.4321554072793574,-0.43188988270807893,-0.4316243581368003,-0.43135883356552196,-0.4310933089942433,-0.43082778442296477,-0.43056225985168617,-0.4302967352804077,-0.43003121070912914,-0.42976568613785054,-0.429500161566572,-0.42923463699529385,-0.4289691124240152,-0.42870358785273666,-0.42843806328145806,-0.4281725387101796,-0.427907014138901,-0.42764148956762243,-0.4278694651824066,-0.43021245308424155,-0.4325554409860765,-0.4348984288879115,-0.43724141678974626,-0.439584404691581,-0.44192739259341596,-0.4442703804952509,-0.4466133683970859,-0.4489563562989206,-0.45129934420075557,-0.45364233210259053,-0.4559853200044255,-0.4583283079062603,-0.46067129580809496,-0.4630142837099299,-0.4653572716117649,-0.46770025951359984,-0.47001585487868824,-0.4723040577070308,-0.474592260535373,-0.47688046336371526,-0.4791686661920578,-0.48145686902039997,-0.4837450718487422,-0.4860332746770848,-0.4883214775054272,-0.49060968033376917,-0.49289788316211175,-0.4951860859904543,-0.4974742888187964,-0.4997624916471387,-0.5020506944754812,-0.5043388973038235,-0.5066271001321657,-0.5089153029605081,-0.5112035057888503,-0.5134917086171928,-0.5152363153267219,-0.5143988652094368,-0.5135614150921519,-0.5127239649748668,-0.5118865148575815,-0.5110490647402967,-0.5102116146230116,-0.5093741645057264,-0.5085367143884415,-0.5076992642711564,-0.5068618141538713,-0.5060243640365861,-0.5051869139193012,-0.5043494638020162,-0.503512013684731,-0.5026745635674459,-0.5018371134501609,-0.5009996633328758,-0.5001622132155908,-0.49932476309830576,-0.49848731298102067,-0.49764986286373564,-0.4968124127464506,-0.4959749626291655,-0.4951375125118804,-0.49430006239459545,-0.49346261227731025,-0.4926251621600252,-0.49178771204274013,-0.4909502619254551,-0.49011281180817,-0.489275361690885,-0.48843791157359984,-0.48760046145631475,-0.4867630113390297,-0.4859255612217448,-0.4850881111044596,-0.4842506609871745,-0.4834132108698895,-0.48257576075260444,-0.4817383106353194,-0.4809008605180343,-0.4800634104007493,-0.47922596028346415,-0.4783885101661791,-0.4775510600488941,-0.476713609931609,-0.47587615981432385,-0.47503870969703893,-0.4742012595797538,-0.47336380946246875,-0.47252635934518367,-0.47168890922789863,-0.4708514591106135,-0.47001400899332846,-0.4691765588760434,-0.4683391087587583,-0.4675016586414733,-0.46666420852418833,-0.4658267584069032,-0.46498930828961793,-0.4641518581723329,-0.463314408055048,-0.4625894519666318,-0.462089483935954,-0.46158951590527614,-0.4610895478745982,-0.46058957984392035,-0.4600896118132426,-0.45958964378256467,-0.45908967575188675,-0.4585897077212087,-0.4580897396905308,-0.45758977165985293,-0.4570898036291752,-0.45658983559849725,-0.4560898675678194,-0.4555898995371415,-0.45415503290663883,-0.4514112967965266,-0.44866756068641456,-0.44592382457630264,-0.4431800884661904,-0.4404363523560782,-0.43769261624596617,-0.4349488801358543,-0.43220514402574206,-0.42946140791563003,-0.42671767180551806,-0.42397393569540587,-0.42123019958529384,-0.4184864634751819,-0.4157427273650697,-0.4129989912549574,-0.4102552551448458,-0.40751151903473354,-0.40476778292462123,-0.4020240468145093,-0.3992803107043973,-0.39653657459428515,-0.3937928384841731,-0.3910491023740612,-0.3883053662639489,-0.38556163015383693,-0.382817894043725,-0.38007415793361277,-0.3773304218235005,-0.3745866857133885,-0.37184294960327663,-0.3690992134931643,-0.36635547738305235,-0.36361174127294044,-0.36086800516282813,-0.3581242690527162,-0.3553805329426043,-0.35263679683249205,-0.3498930607223798,-0.3471493246122681,-0.3444055885021558,-0.3416618523920436,-0.3389181162819317,-0.3361743801718197,-0.3334306440617074,-0.3306869079515955,-0.32794317184148347,-0.3251994357313713,-0.3224556996212593,-0.31971196351114733,-0.3169682274010351,-0.3142244912909229,-0.31148075518081114,-0.3087370190706989,-0.3059932829605868,-0.3032495468504746,-0.3005058107403628,-0.2977620746302506,-0.29501833852013853,-0.29227460241002656,-0.2895308662999145,-0.2867871301898022,-0.28404339407969037,-0.2812996579695781,-0.2785559218594659,-0.275812185749354,-0.27306844963924204,-0.27032471352912973,-0.2662209837858032,-0.25531728587640234,-0.24441358796700163,-0.2335098900576008,-0.22260619214820204,-0.21170249423880116,-0.20079879632940023,-0.18989509842000163,-0.1789914005106008,-0.16808770260119998,-0.15718400469180116,-0.14628030678240023,-0.1353766088729994,-0.12447291096359858,-0.11356921305419976,-0.10266551514479894,-0.09176181723539822,-0.08085811932599962,-0.0699544214165988,-0.05905072350719798,-0.04814702559779904,-0.03724332768839822,-0.026339629778997398,-0.015435931869598352,-0.004532233960197751,0.006371463949203071,0.01633813460022324,0.026187678326623456,0.036037222053025286,0.0458867657794272,0.05573630950582739,0.06558585323222929,0.07543539695863136,0.08528494068503134,0.0951344844114334,0.1049840281378353,0.11483357186423715,0.12468311559063738,0.13453265931703923,0.14438220304344135,0.1542317467698413,0.16408129049624331,0.1744671068364566,0.18523597504367562,0.19600484325089684,0.20677371145811768,0.21754257966533697,0.22831144787255792,0.2390803160797791,0.2498491842870002,0.2606180524942192,0.27138692070144044,0.28215578890866133,0.2929246571158804,0.30369352532310157,0.3144623935303228,0.32523126173754163,0.3360001299447629,0.3438744908555914,0.3442230858958812,0.34457168093617085,0.34492027597646063,0.3452688710167504,0.34561746605704013,0.3459660610973299,0.3463146561376197,0.34666325117790936,0.347011846218199,0.34736044125848886,0.3477090362987786,0.3480576313390683,0.348406226379358,0.348754821419648,0.3491034164599376,0.3494520115002274,0.34980060654051714,0.35014920158080676,0.35049779662109654,0.35084639166138637,0.35119498670167604,0.351543581741966,0.3518921767822555,0.35224077182254526,0.3525893668628351],[0.24830816491007962,0.2444765857344678,0.240645006558856,0.23681342738324415,0.23298184820763246,0.2291502690320206,0.22531868985640882,0.22148711068079696,0.21765553150518518,0.21382395232957316,0.2099923731539613,0.20616079397834952,0.2023292148027377,0.1984976356271259,0.19466605645151414,0.19404532766173654,0.19342460071470924,0.19280387376768193,0.19218314682065463,0.1915624198736272,0.1909416929265999,0.1903209659795725,0.18970023903254518,0.18907951208551776,0.18845878513849035,0.18783805819146304,0.18721733124443574,0.18659660429740832,0.185975877350381,0.1853551504033537,0.1847344234563263,0.18411369650929887,0.18349296956227157,0.18287224261524426,0.18225151566821685,0.18163078872118954,0.18101006177416223,0.18038933482713482,0.1797686078801074,0.1791478809330801,0.1785271539860528,0.17790642703902537,0.17728570009199796,0.17666497314497065,0.17604424619794334,0.17542351925091615,0.1748027923038885,0.17418206535686132,0.173561338409834,0.17294061146280648,0.1723198845157793,0.17169915756875165,0.17107843062172456,0.17045770367469726,0.16983697672766962,0.16921624978064254,0.1685955228336149,0.1679747958865878,0.1673540689395605,0.16673334199253287,0.16611261504550578,0.16549188809847815,0.16487116115145106,0.16425043420442376,0.16362970725739628,0.16300898031036887,0.16238825336334156,0.16176752641631426,0.16114679946928684,0.16052607252225953,0.15990534557523212,0.1592846186282048,0.1586638916811775,0.1580431647341501,0.15742243778712273,0.1568017108400953,0.156180983893068,0.1555602569460406,0.15493952999901328,0.15431880305198586,0.15369807610495856,0.15307734915793114,0.15245662221090384,0.15183589526387642,0.1519907156996333,0.152300645611947,0.1526105755242606,0.15292050543657432,0.15323043534888792,0.15354036526120163,0.15385029517351523,0.15416022508582894,0.15447015499814254,0.15478008491045625,0.15509001482276957,0.15539994473508378,0.15570987464739688,0.1560198045597111,0.1563297344720242,0.1566396643843379,0.1569495942966519,0.1572595242089655,0.1575694541212792,0.15787938403359292,0.15818931394590652,0.15849924385822023,0.15880917377053383,0.15911910368284754,0.15942903359516114,0.15973896350747474,0.16004889341978845,0.16035882333210216,0.16066875324441576,0.16097868315672947,0.16128861306904307,0.16159854298135679,0.1619084728936706,0.1622184028059842,0.1625283327182977,0.16283826263061152,0.163148192542925,0.16345812245523894,0.16376805236755243,0.16407798227986592,0.16438791219217985,0.16469784210449334,0.16500777201680705,0.16531770192912065,0.16562763184143436,0.16593756175374808,0.16624749166606168,0.1665574215783754,0.166867351490689,0.1671772814030027,0.1674872113153164,0.16779714122763,0.1681070711399436,0.16841700105225732,0.16872693096457092,0.16903686087688463,0.16934679078919823,0.16965672070151194,0.16996665061382565,0.17027658052613925,0.17058651043845297,0.17089644035076657,0.17120637026308028,0.171516300175394,0.1718262300877076,0.1721361600000212,0.1724460899123349,0.1727560198246485,0.1730659497369622,0.17145030485864265,0.16887187507150753,0.16629344528437268,0.1637150154972377,0.16113658571010267,0.15855815592296776,0.15597972613583283,0.15340129634869773,0.15082286656156277,0.14824443677442778,0.14566600698729293,0.1430875772001579,0.1405091474130229,0.137930717625888,0.13724825741102864,0.13751378198230713,0.13777930655358578,0.13804483112486432,0.13831035569614286,0.13857588026742113,0.1388414048386996,0.1391069294099782,0.13937245398125675,0.13963797855253535,0.13990350312381394,0.14016902769509243,0.14043455226637103,0.14070007683764957,0.1409656014089281,0.14123112598020632,0.1414966505514852,0.14176217512276346,0.142027699694042,0.1422932242653206,0.14255874883659936,0.14282427340787768,0.14308979797915622,0.14335532255043482,0.14362084712171336,0.14388637169299218,0.14415189626427014,0.144417420835549,0.14468294540682727,0.1449484699781058,0.14521399454938463,0.14547951912066293,0.1457450436919415,0.14601056826322034,0.14627609283449844,0.14654161740577729,0.14680714197705552,0.1470726665483341,0.14733819111961294,0.1476037156908913,0.14786924026216985,0.14813476483344845,0.148400289404727,0.14866581397600553,0.14893133854728396,0.1491968631185625,0.14946238768984105,0.1497279122611196,0.14999343683239819,0.15025896140367673,0.15052448597495516,0.15079001054623364,0.15105553511751224,0.15132105968879078,0.15158658426006932,0.15185210883134792,0.15211763340262646,0.152383157973905,0.15264868254518324,0.1529142071164618,0.15317973168774035,0.15344525625901892,0.1537107808302975,0.15397630540157603,0.1542418299728546,0.15450735454413314,0.1547728791154117,0.15503840368669025,0.15530392825796846,0.15556945282924703,0.1558349774005256,0.15617213819501188,0.15708236012481067,0.15799258205460948,0.15890280398440823,0.15981302591420704,0.16072324784400582,0.16163346977380463,0.1625436917036034,0.1634539136334022,0.164364135563201,0.1652743574929998,0.1661845794227986,0.1681371633741296,0.1711321093469929,0.17412705531985592,0.17712200129271893,0.18011694726558225,0.1814054857913126,0.18224802564677464,0.1830905655022368,0.1839331053576989,0.18477564521316087,0.18561818506862302,0.1864607249240851,0.18730326477954717,0.18814580463500924,0.1889883444904714,0.1898308843459334,0.19067342420139544,0.1915159640568576,0.19235850391231968,0.19320104376778172,0.1940435836232438,0.19488612347870596,0.1957286633341679,0.19657120318963006,0.1974137430450922,0.19825628290055422,0.19909882275601629,0.1999413626114784,0.20078390246694042,0.2016264423224025,0.20246898217786466,0.2033115220333268,0.2041540618887887,0.20499660174425088,0.205839141599713,0.20668168145517504,0.20752422131063714,0.20836676116609926,0.2092093010215613,0.21005184087702333,0.21089438073248548,0.21173692058794752,0.21257946044340958,0.21342200029887168,0.21426454015433388,0.21510708000979578,0.21594961986525796,0.21679215972072005,0.21763469957618214,0.2184772394316442,0.21931977928710628,0.2201623191425683,0.22100485899803035,0.2218473988534925,0.22268993870895468,0.22353247856441666,0.22437501841987875,0.22521755827534085,0.22606009813080288,0.22690263798626498,0.22774517784172707,0.22858771769718914,0.22943025755265115,0.2302727974081133,0.23111533726357536,0.23195787711903743,0.23280041697449955,0.23364295682996164,0.23448549668542368,0.23532803654088577,0.23617057639634792,0.23701311625180999,0.237855656107272,0.23869819596273414,0.23954073581819615,0.24038327567365822,0.24122581552912034,0.24206835538458238,0.24291089524004447,0.24375343509550662,0.24459597495096871,0.2454385148064308,0.2462810546618928,0.24822138512599756,0.2523572968073864,0.25649320848877494,0.26062912017016404,0.26476503185155287,0.26890094353294147,0.2730368552143305,0.2771727668957197,0.2813086785771082,0.28544459025849733,0.2895805019398864,0.29371641362127493,0.29785232530266376,0.30198823698405286,0.3061241486654415,0.3102600603468303,0.3143959720282194,0.31853188370960817,0.3226677953909968,0.32680370707238593,0.33093961875377503,0.3350755304351638,0.3392114421165524,0.34334735379794146,0.3474832654793303,0.3516191771607191,0.35575508884210827,0.35989100052349676,0.3640269122048856,0.3681628238862745,0.3722987355676636,0.3764346472490522,0.3805705589304412,0.3847064706118304,0.38884238229321916,0.3929782939746077,0.39711420565599687,0.40125011733738547,0.40538602901877424,0.4095219407001633,0.4136578523815521,0.41779376406294094,0.42192967574433005,0.42606558742571893,0.43020149910710775,0.4343374107884963,0.43847332246988546,0.44260923415127423,0.446745145832663,0.45088105751405216,0.4550169691954407,0.45915288087682954,0.46287113621149123,0.4656148723216034,0.46835860843171506,0.4711023445418274,0.4738460806519395,0.4765898167620515,0.4793335528721635,0.48207728898227575,0.4848210250923878,0.4875647612024997,0.49030849731261195,0.4930522334227239,0.49579596953283583,0.4985397056429482,0.5012834417530604,0.504027177863172,0.5067709139732844,0.5095146500833965,0.5122583861935087,0.5150021223036205,0.5177458584137326,0.5204895945238448,0.5232333306339566,0.5259770667440687,0.5287208028541811,0.5314645389642928,0.5342082750744052,0.5369520111845173,0.5396957472946291,0.5424394834047412,0.5451832195148534,0.5492869492581799,0.5601906471675808,0.5710943450769816,0.5819980429863822,0.5929017408957813,0.6038054388051821,0.6147091367145829,0.6256128346239815,0.6365165325333824,0.6474202304427832,0.658323928352182,0.6692276262615829,0.6801313241709839,0.6910350220803845,0.7019387199897834,0.7128424178991842,0.7237461158085852,0.7346498137179835,0.7455535116273844,0.7564572095367853,0.7673609074461842,0.7782646053555851,0.7891683032649858,0.8000720011743848,0.8109756990837854,0.8218793969931862,0.8327830949025872,0.8436867928119858,0.8545904907213867,0.8654941886307873,0.8763978865401862,0.8873015844495872,0.898205282358988,0.9091089802683868,0.9200126781777874,0.9309163760871882,0.9420135487709741,0.9531628127445501,0.9643120767181279,0.975461340691706,0.9866106046652818,0.9977598686388596,1.001352546327443,0.9995476623838901,0.997742778440337,0.9959378944967835,0.9941330105532306,0.9923281266096772,0.9913389677197401,0.9916875627600299,0.9920361578003196,0.9923847528406092,0.9927333478808991,0.9930819429211888,0.9934305379614785,0.9937791330017683,0.994127728042058,0.9944763230823478,0.9948249181226375,0.9951735131629273,0.9955221082032171,0.9958707032435068,0.9962192982837965,0.9965678933240862,0.9969164883643761,0.9972650834046658,0.9976136784449554,0.9979622734852451,0.9983108685255351,0.9986594635658246,0.9990080586061145,0.9993566536464042,0.9997052486866941,1.0000538437269837,1.0004024387672736,1.0007510338075634,1.0010996288478529,1.0014482238881426,1.0017968189284325,1.0021454139687223,1.002494009009012,1.0028426040493017,1.0031911990895916,1.0035397941298811],[0.7294691186254569,0.7320553313840831,0.7346415441427091,0.7356242857371481,0.7350035587901208,0.7343828318430934,0.733762104896066,0.7331413779490387,0.7325206510020114,0.7318999240549839,0.7312791971079566,0.7306584701609292,0.7300377432139019,0.7294170162668745,0.7287962893198471,0.7281755623728198,0.7275548354257924,0.7269341084787652,0.7263133815317377,0.7256926545847104,0.725071927637683,0.7244512006906556,0.7238304737436284,0.723209746796601,0.7225890198495737,0.7219682929025463,0.7213475659555189,0.7207268390084915,0.7201061120614641,0.7194853851144369,0.7188646581674095,0.7182439312203821,0.7176232042733548,0.7170024773263275,0.7163817503793002,0.7157610234322728,0.7151402964852454,0.714519569538218,0.7138988425911907,0.7132781156441633,0.7126573886971359,0.7120366617501086,0.7114159348030813,0.7107952078560539,0.7101744809090266,0.7095537539619992,0.7089330270149719,0.7083123000679444,0.7076915731209171,0.7070708461738898,0.7064501192268624,0.7058293922798351,0.7052086653328076,0.7045879383857803,0.703967211438753,0.7033464844917257,0.7027257575446983,0.7021050305976708,0.7014843036506435,0.7008635767036162,0.7002428497565888,0.6996221228095616,0.6990013958625341,0.6983806689155068,0.6977599419684795,0.6971392150214522,0.6965184880744247,0.6958977611273973,0.69527703418037,0.6946563072333427,0.6940355802863153,0.693414853339288,0.6927941263922606,0.6921733994452333,0.691552672498206,0.6909319455511784,0.6903112186041512,0.6896904916571238,0.6890697647100965,0.6884490377630691,0.6878283108160417,0.6872075838690144,0.6865868569219871,0.6859661299749598,0.6861209504107165,0.6864308803230302,0.6867408102353438,0.6870507401476575,0.6873606700599711,0.6876705999722847,0.6879805298845985,0.6882904597969122,0.6886003897092259,0.6889103196215394,0.6892202495338531,0.6895301794461667,0.6898401093584805,0.6901500392707941,0.6904599691831078,0.6907698990954214,0.6910798290077351,0.6913897589200488,0.6916996888323624,0.692009618744676,0.6923195486569897,0.6926294785693035,0.6929394084816171,0.6932493383939307,0.6935592683062444,0.6938691982185581,0.6941791281308718,0.6944890580431854,0.694798987955499,0.6951089178678127,0.6954188477801263,0.6957287776924399,0.6960387076047536,0.6963486375170673,0.696658567429381,0.6969684973416946,0.6972784272540083,0.697588357166322,0.6978982870786357,0.6982082169909494,0.698518146903263,0.6988280768155766,0.6991380067278903,0.699447936640204,0.6997578665525176,0.7000677964648313,0.7003777263771449,0.7006876562894586,0.7009975862017723,0.7013075161140859,0.7016174460263996,0.7019273759387132,0.702237305851027,0.7025472357633404,0.7028571656756541,0.7031670955879679,0.7034770255002815,0.7037869554125952,0.7040968853249088,0.7044068152372225,0.7047167451495362,0.7050266750618498,0.7053366049741635,0.7056465348864771,0.7059564647987908,0.7062663947111044,0.7065763246234181,0.7068862545357317,0.7071961844480454,0.7075061143603592,0.7078160442726728,0.7081259741849865,0.7084359040973001,0.7087458340096138,0.7090557639219274,0.7093656938342411,0.7096756237465548,0.7099855536588684,0.7102954835711821,0.7106054134834956,0.7114026290308486,0.7146362799266859,0.7178699308225233,0.7209884629512414,0.7240494356963992,0.7271104084415577,0.7301713811867158,0.7314400602372194,0.7323502821670181,0.7332605040968169,0.7341707260266156,0.7350809479564144,0.7359911698862132,0.7369013918160121,0.7378116137458107,0.7387218356756098,0.7396320576054085,0.7405422795352072,0.7414525014650061,0.7423627233948049,0.7432729453246036,0.7441831672544025,0.7450933891842012,0.7460036111139999,0.7469138330437988,0.7478240549735975,0.7487342769033963,0.7496444988331952,0.750554720762994,0.7514649426927927,0.7523751646225916,0.7532853865523904,0.7541956084821893,0.755105830411988,0.7560160523417868,0.7569262742715855,0.7578364962013843,0.7587467181311831,0.7596569400609818,0.7605671619907807,0.7614773839205795,0.7623876058503782,0.7632978277801771,0.7642080497099758,0.7651182716397746,0.7660284935695736,0.7669387154993723,0.7678489374291712,0.7687591593589699,0.7696693812887685,0.7705796032185674,0.7714898251483662,0.772400047078165,0.7733102690079638,0.7742204909377627,0.7751307128675614,0.7760409347973602,0.776951156727159,0.7778613786569578,0.7787716005867565,0.7796818225165554,0.7805920444463541,0.7815022663761529,0.7824124883059517,0.7833227102357505,0.7842329321655492,0.785143154095348,0.7860533760251468,0.7869635979549455,0.7878738198847444,0.7887840418145432,0.789694263744342,0.7906044856741408,0.7915147076039396,0.7924249295337383,0.7933351514635372,0.7942453733933359,0.7951555953231347,0.7960658172529336,0.7969760391827324,0.7978862611125312,0.79879648304233,0.7997067049721288,0.8006169269019275,0.8015271488317264,0.8024373707615251,0.8043899547128561,0.8073849006857193,0.8103798466585825,0.8133747926314455,0.8163697386043088,0.8193646845771718,0.8223596305500348,0.8253545765228981,0.8283495224957615,0.8313444684686242,0.8343394144414875,0.8373343604143509,0.8403293063872139,0.8433242523600769,0.8463191983329402,0.8493141443058033,0.8523090902786663,0.8553040362515295,0.8582989822243926,0.8612939281972557,0.864288874170119,0.8672838201429823,0.8702787661158451,0.8732737120887083,0.8762686580615716,0.8792636040344347,0.8822585500072977,0.885253495980161,0.8882484419530241,0.8912433879258871,0.8942383338987504,0.8972332798716137,0.9002282258444764,0.9032231718173397,0.906218117790203,0.9092130637630661,0.9122080097359291,0.9152029557087924,0.9181979016816554,0.919893647004422,0.9207361868598841,0.9215787267153461,0.9224212665708081,0.9232638064262704,0.9241063462817326,0.9249488861371945,0.9257914259926566,0.9266339658481187,0.9274765057035808,0.9283190455590429,0.929161585414505,0.9300041252699671,0.930846665125429,0.9316892049808911,0.9325317448363534,0.9333742846918154,0.9342168245472774,0.9350593644027396,0.9359019042582016,0.9367444441136636,0.9375869839691259,0.9384295238245877,0.9392720636800499,0.9401146035355121,0.940957143390974,0.9417996832464361,0.9426422231018982,0.9434847629573603,0.9443273028128222,0.9451698426682844,0.9460123825237466,0.9468549223792087,0.9476974622346708,0.948540002090133,0.9493825419455948,0.9502250818010569,0.951067621656519,0.951910161511981,0.952752701367443,0.9535952412229052,0.9544377810783672,0.9552803209338294,0.9561228607892915,0.9580631912533962,0.9621991029347849,0.9663350146161737,0.9704709262975628,0.9746068379789515,0.9787427496603402,0.9828786613417292,0.9870145730231183,0.9911504847045068,0.995286396385896,0.9994223080672852,1.0035582197486737,1.0076941314300625,1.0118300431114513,1.0159659547928401,1.020101866474229,1.0242377781556182,1.0283736898370068,1.0325096015183954,1.0366455131997845,1.0407814248811738,1.0449173365625626,1.049053248243951,1.0531891599253402,1.0573250716067288,1.0614609832881177,1.065596894969507,1.0697328066508955,1.0738687183322844,1.0780046300136732,1.0821405416950622,1.0862764533764508,1.09041236505784,1.094548276739229,1.0986841884206178,1.1028201001020064,1.1069560117833954,1.111091923464784,1.1152278351461729,1.119363746827562,1.1234996585089507,1.1276355701903396,1.1317714818717288,1.1359073935531177,1.1400433052345065,1.1441792169158949,1.1483151285972841,1.152451040278673,1.1565869519600618,1.1607228636414506,1.1648587753228394,1.1689946870042283,1.1731305986856173,1.1772665103670064,1.1814024220483947,1.1855383337297838,1.1896742454111728,1.1942876916030047,1.2008877105013982,1.207487729399792,1.2140877482981856,1.2206877671965788,1.2272877860949727,1.2338878049933661,1.2404878238917596,1.2470878427901535,1.2536878616885474,1.2602878805869402,1.2668878994853343,1.273487918383728,1.2800879372821214,1.286687956180515,1.2932879750789086,1.2998879939773018,1.3064880128756955,1.3130880317740894,1.3196880506724833,1.326288069570876,1.33288808846927,1.339488107367664,1.3460881262660571,1.3526881451644506,1.3592881640628445,1.3668118250236903,1.3789536962968016,1.3910955675699133,1.4032374388430242,1.4153793101161336,1.427521181389245,1.4396630526623564,1.4518049239354658,1.463946795208577,1.4760886664816883,1.4882305377547975,1.4999699576287904,1.5111192216023683,1.522268485575946,1.533417749549522,1.5445670135230998,1.555716277496678,1.5668655414702535,1.5780148054438317,1.5891640694174096,1.6003133333909856,1.6114625973645635,1.6226118613381413,1.633761125311717,1.6449103892852952,1.656059653258873,1.6672089172324511,1.6783581812060269,1.689507445179605,1.7006567091531826,1.7118059731267588,1.7229552371003367,1.7341045010739145,1.7452537650474902,1.7564030290210684,1.767552292994646,1.7787015569682239,1.7898508209417998,1.8010000849153778,1.8121493488889557,1.8232986128625317,1.8344478768361094,1.8380405545246932,1.83623567058114,1.8344307866375869,1.8326259026940335,1.8308210187504803,1.8290161348069272,1.8272112508633735,1.8254063669198202,1.8236014829762675,1.8217965990327138,1.8199917150891602,1.8181868311456073,1.816381947202054,1.8145770632585008,1.8127721793149476,1.8109672953713942,1.809162411427841,1.8073575274842877,1.8055526435407345,1.8037477595971811,1.8019428756536278,1.8001379917100748,1.7983331077665214,1.796528223822968,1.7947233398794151,1.7929184559358617,1.7911135719923081,1.7893086880487554,1.7875038041052018,1.7856989201616484,1.7838940362180953,1.7701038488922443,1.7525540602598033,1.7350042716273624,1.7174544829949243,1.6999046943624831,1.6823549057300422,1.6648051170976044,1.6472553284651634,1.6297055398327225,1.6121557512002813,1.5946059625678435],[1.2101520114084798,1.212738224167106,1.2153244369257319,1.2179106496843581,1.2204968624429844,1.2230830752016104,1.2256692879602364,1.2282555007188627,1.2308417134774885,1.2334279262361147,1.2360141389947408,1.2386003517533668,1.241186564511993,1.243772777270619,1.2463589900292453,1.2489452027878714,1.2515314155464974,1.2541176283051234,1.2567038410637497,1.2592900530401607,1.2586693260931334,1.258048599146106,1.2574278721990788,1.2568071452520513,1.256186418305024,1.2555656913579967,1.2549449644109694,1.254324237463942,1.2537035105169145,1.2530827835698872,1.25246205662286,1.2518413296758324,1.2512206027288053,1.2505998757817778,1.2499791488347503,1.249358421887723,1.2487376949406956,1.2481169679936683,1.2474962410466408,1.2468755140996137,1.2462547871525862,1.245634060205559,1.2450133332585316,1.244392606311504,1.243771879364477,1.2431511524174494,1.2425304254704221,1.2419096985233948,1.2412889715763673,1.24066824462934,1.2400475176823127,1.2394267907352852,1.2388060637882579,1.2381853368412306,1.2375646098942032,1.236943882947176,1.2363231560001486,1.2357024290531213,1.2350817021060938,1.2344609751590665,1.2338402482120392,1.2332195212650117,1.2325987943179844,1.231978067370957,1.2313573404239297,1.2307366134769024,1.230115886529875,1.2294951595828476,1.2288744326358203,1.228253705688793,1.2276329787417657,1.2270122517947382,1.2263915248477109,1.2257707979006836,1.2251500709536562,1.2245293440066287,1.2239086170596014,1.223287890112574,1.2226671631655468,1.2220464362185195,1.2214257092714922,1.2208049823244647,1.2201842553774374,1.21956352843041,1.219718348866167,1.2200282787784804,1.2203382086907941,1.2206481386031078,1.2209580685154215,1.221267998427735,1.2215779283400487,1.2218878582523625,1.2221977881646762,1.2225077180769897,1.2228176479893036,1.223127577901617,1.2234375078139308,1.2237474377262445,1.224057367638558,1.224367297550872,1.2246772274631854,1.224987157375499,1.2252970872878128,1.2256070172001263,1.22591694711244,1.2262268770247537,1.2265368069370672,1.226846736849381,1.2271566667616947,1.2274665966740084,1.227776526586322,1.2280864564986356,1.2283963864109493,1.228706316323263,1.2290162462355767,1.2293261761478904,1.229636106060204,1.2299460359725176,1.2302559658848313,1.230565895797145,1.2308758257094585,1.2311857556217722,1.231495685534086,1.2318056154463997,1.2321155453587131,1.2324254752710269,1.2327354051833408,1.233045335095654,1.233355265007968,1.2336651949202815,1.2339751248325952,1.234285054744909,1.2345949846572224,1.2349049145695363,1.2352148444818498,1.2355247743941635,1.2358347043064772,1.2361446342187907,1.2364545641311044,1.2367644940434181,1.2370744239557319,1.2373843538680456,1.237694283780359,1.2380042136926728,1.2383141436049865,1.2386240735173002,1.238934003429614,1.2392439333419274,1.2415030098634565,1.2447366607592942,1.2479703116551315,1.251203962550969,1.254437613446806,1.2576712643426433,1.2609049152384808,1.264138566134318,1.2673722170301556,1.2706058679259928,1.27383951882183,1.2770731697176676,1.280306820613505,1.2835404715093424,1.2867741224051799,1.2900077733010171,1.2932414241968546,1.2964750750926919,1.2997087259885292,1.3028272581172473,1.3058882308624051,1.3089492036075636,1.3120101763527217,1.3150711490978797,1.3181321218430382,1.3211930945881962,1.3242540673333545,1.3273150400785125,1.3303760128236708,1.333436985568829,1.3364979583139873,1.3395589310591454,1.3426199038043034,1.3456808765494617,1.34874184929462,1.351802822039778,1.3548637947849365,1.3579247675300947,1.3609857402752528,1.3640467130204108,1.3671076857655688,1.370168658510727,1.3732296312558856,1.3762906040010432,1.3793515767462017,1.38241254949136,1.385473522236518,1.388534494981676,1.3904483998209278,1.3913586217507266,1.3922688436805255,1.3931790656103245,1.394089287540123,1.394999509469922,1.3959097313997206,1.3968199533295196,1.3977301752593183,1.3986403971891168,1.399550619118916,1.4004608410487147,1.4013710629785132,1.4022812849083124,1.4031915068381107,1.40410172876791,1.4050119506977086,1.4059221726275073,1.4068323945573062,1.407742616487105,1.408652838416904,1.4095630603467024,1.4104732822765014,1.4113835042063003,1.412293726136099,1.4132039480658978,1.4141141699956965,1.4150243919254952,1.4159346138552942,1.416844835785093,1.4177550577148916,1.4186652796446904,1.4195755015744895,1.420485723504288,1.421395945434087,1.4223061673638857,1.4232163892936844,1.4241266112234834,1.425036833153282,1.4259470550830808,1.4268572770128796,1.4277674989426783,1.4286777208724775,1.429587942802276,1.4304981647320751,1.4314083866618736,1.4323186085916724,1.4332288305214713,1.4341390524512698,1.4350492743810688,1.4359594963108677,1.4368697182406662,1.4377799401704652,1.438690162100264,1.440642746051595,1.4436376920244585,1.4466326379973211,1.4496275839701844,1.4526225299430475,1.4556174759159106,1.4586124218887737,1.4616073678616373,1.4646023138345003,1.467597259807363,1.470592205780226,1.4735871517530896,1.4765820977259527,1.4795770436988158,1.482571989671679,1.485566935644542,1.4885618816174049,1.4915568275902684,1.4945517735631313,1.4975467195359946,1.5005416655088577,1.5035366114817212,1.5065315574545841,1.5095265034274472,1.5125214494003103,1.5155163953731736,1.5185113413460363,1.5215062873188996,1.5245012332917627,1.527496179264626,1.530491125237489,1.5334860712103526,1.5364810171832153,1.5394759631560784,1.5424709091289417,1.545465855101805,1.548460801074668,1.5514557470475312,1.5544506930203943,1.5574456389932574,1.5604405849661207,1.5634355309389836,1.566430476911847,1.56942542288471,1.5724203688575733,1.575415314830436,1.5784102608032995,1.5814052067761628,1.5844001527490257,1.5873950987218888,1.590390044694752,1.5933849906676152,1.596379936640478,1.5993748826133416,1.6023698285862047,1.6053647745590676,1.6083597205319309,1.611354666504794,1.6143496124776573,1.6173445584505202,1.6203395044233837,1.6233344503962464,1.6263293963691094,1.6293243423419728,1.6323192883148359,1.6353142342876985,1.6383091802605623,1.6413041262334254,1.6442990722062882,1.6472940181791513,1.6502889641520149,1.6532839101248777,1.656278856097741,1.6583818082175452,1.6592243480730076,1.6600668879284695,1.6609094277839316,1.6617519676393935,1.6625945074948556,1.6634370473503177,1.6642795872057798,1.6651221270612417,1.665964666916704,1.6679049973808087,1.6720409090621973,1.676176820743586,1.6803127324249751,1.6844486441063637,1.6885845557877526,1.6927204674691416,1.696856379150531,1.700992290831919,1.7051282025133083,1.7092641141946974,1.7134000258760862,1.7175359375574748,1.7224645563342593,1.7290645752326523,1.7356645941310462,1.74226461302944,1.7488646319278334,1.7554646508262266,1.7620646697246205,1.7686646886230146,1.7752647075214076,1.7818647264198013,1.7884647453181952,1.7950647642165884,1.8016647831149817,1.808264802013376,1.8148648209117688,1.8214648398101625,1.8280648587085564,1.8346648776069503,1.841264896505343,1.847864915403737,1.8544649343021309,1.8610649532005241,1.8676649720989178,1.8742649909973115,1.880865009895705,1.8874650287940984,1.8940650476924923,1.9006650665908853,1.907265085489279,1.9138651043876729,1.9204651232860668,1.92706514218446,1.9336651610828535,1.9402651799812474,1.9468651988796408,1.9534652177780338,1.960065236676428,1.9666652555748216,1.9732652744732146,1.9798652933716085,1.9864653122700024,1.9930653311683955,1.9996653500667891,2.0062653689651833,2.0128653878635765,2.0194654067619697,2.026065425660364,2.032665444558757,2.0392654634571503,2.0458654823555444,2.0524655012539377,2.0590655201523314,2.065665539050725,2.072265557949119,2.0788655768475115,2.085465595745906,2.0920656146442997,2.098665633542693,2.1052656524410867,2.1118656713394803,2.1184656902378736,2.125065709136267,2.131665728034661,2.138265746933055,2.144865765831448,2.151465784729842,2.1580658036282356,2.164665822526629,2.171265841425022,2.1778658603234162,2.185389521284262,2.197531392557373,2.209673263830484,2.2218151351035957,2.233957006376705,2.2460988776498167,2.258240748922928,2.2703826201960373,2.2825244914691485,2.2946663627422597,2.306808234015369,2.3189501052884802,2.3310919765615914,2.343233847834703,2.355375719107812,2.3675175903809236,2.379659461654035,2.3918013329271446,2.4039432042002558,2.416085075473367,2.4282269467464763,2.4403688180195875,2.4525106892926987,2.464652560565808,2.4767944318389192,2.4889363031120313,2.501078174385142,2.513220045658252,2.525361916931363,2.537344717350449,2.548493981324025,2.5596432452976026,2.5707925092711807,2.581941773244756,2.593091037218334,2.6042403011919126,2.61538956516549,2.6265388291390663,2.6376880931126436,2.648837357086222,2.6599866210597978,2.6711358850333755,2.6747285627219592,2.672923678778406,2.6711187948348525,2.669313910891299,2.667509026947746,2.665704143004193,2.6638992590606394,2.662094375117086,2.660289491173533,2.6584846072299797,2.6566797232864263,2.6548748393428734,2.6529690133798405,2.6354192247474,2.6178694361149617,2.6003196474825208,2.58276985885008,2.565220070217639,2.5476702815852015,2.53012049295276,2.512570704320319,2.4950209156878813,2.47747112705544,2.4599213384229994,2.442371549790561,2.42482176115812,2.4072719725256793,2.3897221838932414,2.3721723952608005,2.354622606628359,2.337072817995918,2.3195230293634808,2.3019732407310394,2.284423452098599,2.2668736634661606,2.2493238748337196,2.2317740862012787,2.214224297568841,2.1966745089364,2.1791247203039585,2.1615749316715176,2.14402514303908],[1.6908349041915027,1.6934211169501288,1.6960073297087548,1.6985935424673808,1.701179755226007,1.703765967984633,1.7063521807432593,1.7089383935018854,1.7115246062605114,1.7141108190191376,1.7166970317777637,1.7192832445363897,1.721869457295016,1.724455670053642,1.727041882812268,1.7296280955708943,1.73221430832952,1.7348005210881463,1.7373867338467723,1.7399729466053984,1.7425591593640246,1.7451453721226506,1.7477315848812767,1.750317797639903,1.752904010398529,1.755490223157155,1.7580764359157808,1.7606626486744075,1.7632488614330333,1.7658350741916593,1.7684212869502858,1.7710074997089116,1.7735937124675376,1.7761799252261636,1.77876613798479,1.781352350743416,1.7823350933961462,1.7817143664491186,1.7810936395020913,1.780472912555064,1.7798521856080365,1.7792314586610092,1.7786107317139817,1.7779900047669543,1.777369277819927,1.7767485508728997,1.7761278239258724,1.7755070969788451,1.7748863700318178,1.7742656430847905,1.773644916137763,1.7730241891907357,1.7724034622437084,1.771782735296681,1.7711620083496538,1.7705412814026262,1.769920554455599,1.7692998275085716,1.7686791005615443,1.768058373614517,1.7674376466674895,1.7668169197204622,1.7661961927734349,1.7655754658264076,1.76495473887938,1.7643340119323527,1.7637132849853254,1.763092558038298,1.7624718310912706,1.7618511041442433,1.761230377197216,1.7606096502501887,1.7599889233031614,1.7593681963561338,1.7587474694091065,1.7581267424620792,1.757506015515052,1.7568852885680246,1.756264561620997,1.7556438346739698,1.7550231077269425,1.7544023807799152,1.7537816538328879,1.7531609268858603,1.753315747321617,1.7536256772339307,1.7539356071462444,1.7542455370585581,1.7545554669708716,1.7548653968831853,1.755175326795499,1.7554852567078127,1.7557951866201265,1.75610511653244,1.7564150464447539,1.7567249763570674,1.757034906269381,1.7573448361816946,1.7576547660940085,1.7579646960063222,1.7582746259186357,1.7585845558309494,1.758894485743263,1.7592044156555768,1.7595143455678903,1.759824275480204,1.7601342053925177,1.7604441353048315,1.7607540652171452,1.7610639951294584,1.7613739250417724,1.761683854954086,1.7619937848663996,1.7623037147787133,1.7626136446910268,1.7629235746033407,1.7632335045156542,1.763543434427968,1.7638533643402816,1.764163294252595,1.764473224164909,1.7647831540772225,1.7650930839895362,1.7654030139018497,1.7657129438141634,1.7660228737264771,1.7663328036387909,1.7666427335511046,1.766952663463418,1.767262593375732,1.7675725232880455,1.7683697398002274,1.7716033906960644,1.7748370415919017,1.7780706924877392,1.7813043433835765,1.7845379942794137,1.7877716451752512,1.7910052960710887,1.794238946966926,1.7974725978627633,1.8007062487586007,1.8039398996544382,1.8071735505502753,1.8104072014461128,1.8136408523419503,1.8168745032377878,1.820108154133625,1.8233418050294623,1.8265754559252998,1.8298091068211373,1.8330427577169746,1.8362764086128114,1.8395100595086489,1.8427437104044864,1.8459773613003236,1.8492110121961611,1.8524446630919984,1.855678313987836,1.8589119648836732,1.8621456157795107,1.865379266675348,1.8686129175711854,1.871846568467023,1.8750802193628602,1.8783138702586974,1.8815475211545347,1.8846660532832529,1.887727026028411,1.8907879987735692,1.8938489715187274,1.8969099442638855,1.8999709170090435,1.903031889754202,1.90609286249936,1.9091538352445183,1.9122148079896766,1.9152757807348346,1.918336753479993,1.9213977262251511,1.9244586989703094,1.9275196717154675,1.9305806444606257,1.9336416172057838,1.9367025899509418,1.9397635626961003,1.9428245354412583,1.9458855081864164,1.9489464809315746,1.9520074536767327,1.9550684264218907,1.958129399167049,1.9611903719122075,1.9642513446573657,1.9673123174025235,1.9703732901476823,1.97343426289284,1.9764952356379981,1.9795562083831568,1.9826171811283144,1.9856781538734727,1.988739126618631,1.9918000993637892,1.9948610721089475,1.9979220448541055,2.0009830175992636,2.004043990344422,2.00710496308958,2.010165935834738,2.013226908579896,2.016287881325055,2.0193488540702127,2.022409826815371,2.0254707995605292,2.028531772305687,2.0315927450508453,2.0346537177960036,2.037714690541162,2.0407756632863197,2.0438366360314784,2.046897608776636,2.0494567394046364,2.050366961334435,2.051277183264234,2.052187405194033,2.0530976271238317,2.0540078490536304,2.054918070983429,2.055828292913228,2.0567385148430266,2.0576487367728253,2.058558958702624,2.0594691806324237,2.060379402562222,2.061289624492021,2.0621998464218194,2.063110068351618,2.064020290281417,2.0649305122112156,2.0658407341410143,2.0667509560708135,2.067661178000612,2.0685713999304114,2.0694816218602097,2.070391843790009,2.071302065719807,2.072212287649606,2.073122509579405,2.0740327315092038,2.0749429534390025,2.076895537390334,2.079890483363197,2.0828854293360597,2.085880375308923,2.0888753212817863,2.091870267254649,2.094865213227512,2.0978601592003754,2.100855105173239,2.103850051146102,2.106844997118965,2.109839943091828,2.112834889064691,2.1158298350375544,2.1188247810104177,2.1218197269832806,2.124814672956144,2.127809618929007,2.13080456490187,2.133799510874733,2.1367944568475963,2.13978940282046,2.1427843487933225,2.145779294766186,2.148774240739049,2.1517691867119124,2.154764132684775,2.157759078657638,2.1607540246305015,2.163748970603365,2.1667439165762277,2.169738862549091,2.172733808521954,2.175728754494817,2.1787237004676805,2.181718646440544,2.1847135924134067,2.18770853838627,2.1907034843591324,2.1936984303319957,2.1966933763048595,2.1996883222777224,2.2026832682505857,2.2056782142234486,2.208673160196312,2.2116681061691743,2.2146630521420385,2.2176579981149014,2.2206529440877643,2.223647890060627,2.2266428360334904,2.2299484315288534,2.2345743100563125,2.2392001885837725,2.243826067111232,2.248451945638691,2.2530778241661515,2.257703702693611,2.2623295812210706,2.26695545974853,2.2715813382759897,2.2762072168034497,2.280833095330909,2.285458973858369,2.2900848523858284,2.294710730913288,2.2993366094407475,2.303962487968208,2.3085883664956666,2.3132142450231266,2.3178401235505866,2.322466002078046,2.327091880605505,2.3317177591329656,2.3363436376604247,2.3409695161878843,2.3455953947153443,2.350221273242804,2.354847151770263,2.359473030297723,2.364098908825183,2.3687247873526425,2.373350665880102,2.379054462451725,2.386914095111674,2.3947737277716232,2.402633360431573,2.4104929930915215,2.4183526257514707,2.4262122584114203,2.43407189107137,2.441931523731318,2.4497911563912678,2.4576507890512174,2.465510421711166,2.473370054371115,2.4812296870310644,2.489089319691013,2.4969489523509627,2.504808585010912,2.512668217670861,2.5205278503308097,2.5283874829907598,2.5362471156507094,2.544106748310658,2.5519663809706072,2.5598260136305564,2.5676856462905056,2.5755452789504547,2.583404911610404,2.5912645442703526,2.599124176930302,2.6069838095902518,2.614843442250201,2.6227030749101488,2.630562707570099,2.638422340230049,2.6462819728899976,2.6541416055499467,2.662001238209896,2.669860870869845,2.6777205035297937,2.6855801361897433,2.693439768849692,2.701299401509641,2.7091590341695904,2.7170186668295404,2.72487829948949,2.7327379321494383,2.740597564809388,2.748457197469337,2.756316830129286,2.7641764627892353,2.772036095449184,2.779895728109133,2.787755360769083,2.7956149934290324,2.8034746260889807,2.8113342587489303,2.81919389140888,2.8270535240688295,2.8349131567287778,2.8427727893887274,2.850632422048676,2.857843159717722,2.864443178616116,2.871043197514509,2.8776432164129027,2.8842432353112963,2.8908432542096905,2.8974432731080837,2.9040432920064774,2.910643310904871,2.9172433298032647,2.923843348701658,2.930443367600052,2.9370433864984453,2.9436434053968386,2.9502434242952322,2.956843443193627,2.963443462092019,2.970043480990413,2.976643499888807,2.9832435187872,2.9898435376855943,2.996443556583988,3.0039672175448335,3.0161090888179443,3.0282509600910554,3.040392831364168,3.052534702637277,3.064676573910388,3.0768184451834992,3.088960316456608,3.10110218772972,3.113244059002832,3.125385930275941,3.1375278015490515,3.1496696728221627,3.1618115440952748,3.1739534153683837,3.1860952866414953,3.198237157914607,3.210379029187716,3.222520900460827,3.230383276290199,3.2258352800857897,3.221287283881379,3.2167392876769685,3.2121912914725588,3.2076432952681486,3.2030952990637385,3.198547302859328,3.1939993066549186,3.189451310450508,3.1849033142460974,3.1803553180416873,3.175807321837277,3.171259325632867,3.1667113294284572,3.1621633332240466,3.157615337019636,3.153067340815226,3.148519344610816,3.143971348406406,3.1394233522019954,3.134875355997586,3.1303273597931756,3.125779363588765,3.1212313673843557,3.116683371179945,3.112135374975535,3.1075873787711252,3.103039382566715,3.0984913863623045,3.093943390157894,3.089395393953484,3.084847397749074,3.0802994015446634,3.075751405340254,3.0712034091358436,3.066655412931433,3.0621074167270237,3.0575594205226135,3.053011424318203,3.0484634281137923,3.043915431909383,3.039367435704972,3.034819439500562,3.030271443296152,3.0257234470917416,3.0093405188942355,2.9917907302617976,2.974240941629357,2.9566911529969158,2.939141364364478,2.921591575732037,2.904041787099596,2.8864919984671547,2.8689422098347173,2.8513924212022763,2.833842632569835,2.816292843937397,2.7987430553049566,2.781193266672515,2.7636434780400774,2.7460936894076364,2.728543900775195,2.710994112142754,2.6934443235103167],[2.1715177969745167,2.174104009733143,2.176690222491769,2.1792764352503946,2.181862648009021,2.184448860767647,2.187035073526273,2.189621286284899,2.1922074990435254,2.194793711802151,2.1973799245607775,2.1999661373194037,2.2025523500780295,2.2051385628366558,2.207724775595282,2.210310988353908,2.212897201112534,2.2154834138711603,2.218069626629786,2.2206558393884124,2.2232420521470386,2.2258282649056644,2.2284144776642902,2.231000690422917,2.2335869031815427,2.236173115940169,2.238759328698795,2.241345541457421,2.2439317542160473,2.246517966974673,2.2491041797332993,2.251690392491925,2.254276605250552,2.2568628180091777,2.2594490307678035,2.2620352435264297,2.264621456285056,2.267207669043682,2.269793881802308,2.2723800945609343,2.27496630731956,2.2775525200781863,2.2801387328368126,2.282724945595439,2.2853111583540646,2.287897371112691,2.2904835838713167,2.2930697966299434,2.295656009388569,2.298242222147195,2.3008284349058217,2.3034146476644475,2.3060008604230733,2.305380133752121,2.3047594068050934,2.304138679858066,2.303517952911039,2.3028972259640113,2.302276499016984,2.3016557720699566,2.301035045122929,2.300414318175902,2.2997935912288745,2.2991728642818474,2.29855213733482,2.297931410387793,2.2973106834407653,2.296689956493738,2.2960692295467107,2.295448502599683,2.294827775652656,2.2942070487056285,2.2935863217586014,2.292965594811574,2.2923448678645464,2.2917241409175193,2.2911034139704918,2.2904826870234647,2.289861960076437,2.2892412331294096,2.2886205061823826,2.287999779235355,2.287379052288328,2.2867583253413004,2.2869131457770573,2.2872230756893708,2.2875330056016847,2.287842935513998,2.2881528654263117,2.2884627953386256,2.288772725250939,2.289082655163253,2.289392585075566,2.28970251498788,2.290012444900194,2.2903223748125074,2.290632304724821,2.2909422346371344,2.2912521645494484,2.2915620944617623,2.291872024374076,2.2921819542863893,2.292491884198703,2.2928018141110167,2.2931117440233306,2.293421673935644,2.2937316038479576,2.294041533760271,2.294351463672585,2.294661393584899,2.294971323497212,2.295281253409526,2.2955911833218394,2.2959011132341534,2.2962110431464673,2.298470120632824,2.3017037715286612,2.3049374224244983,2.308171073320336,2.3114047242161737,2.3146383751120108,2.3178720260078483,2.3211056769036853,2.324339327799523,2.3275729786953603,2.3308066295911973,2.3340402804870353,2.3372739313828723,2.3405075822787094,2.3437412331745473,2.3469748840703843,2.350208534966222,2.3534421858620593,2.3566758367578964,2.359909487653734,2.363143138549571,2.3663767894454084,2.369610440341246,2.3728440912370834,2.376077742132921,2.379311393028758,2.382545043924595,2.385778694820433,2.38901234571627,2.3922459966121075,2.395479647507945,2.3987132984037824,2.40194694929962,2.405180600195457,2.4084142510912945,2.4116479019871315,2.4148815528829695,2.4181152037788065,2.4213488546746436,2.4245825055704815,2.4278161564663185,2.4310498073621556,2.4342834582579935,2.4375171091538306,2.4407507600496676,2.4439844109455056,2.4472180618413426,2.4504517127371805,2.4536853636330176,2.4569190145288546,2.460152665424692,2.4633863163205296,2.4665048484492478,2.4695658211944056,2.472626793939564,2.4756877666847217,2.4787487394298804,2.4818097121750387,2.4848706849201965,2.487931657665355,2.490992630410513,2.4940536031556713,2.4971145759008295,2.500175548645988,2.5032365213911456,2.5062974941363043,2.509358466881462,2.51241943962662,2.5154804123717787,2.518541385116937,2.521602357862095,2.524663330607253,2.527724303352411,2.530785276097569,2.5338462488427274,2.536907221587886,2.539968194333044,2.543029167078202,2.5460901398233604,2.5491511125685182,2.552212085313677,2.5552730580588348,2.558334030803993,2.5613950035491513,2.5644559762943095,2.5675169490394674,2.5705779217846256,2.5736388945297843,2.576699867274942,2.5797608400201,2.5828218127652587,2.5858827855104165,2.5889437582555743,2.592004731000733,2.595065703745891,2.598126676491049,2.6011876492362074,2.6042486219813656,2.6073095947265235,2.610370567471682,2.6134315402168404,2.6164925129619983,2.619553485707157,2.622614458452315,2.625675431197473,2.6287364039426313,2.6317973766877896,2.6348583494329474,2.6379193221781057,2.640980294923264,2.644041267668422,2.6471022404135804,2.650163213158738,2.6532241859038965,2.656285158649055,2.659346131394213,2.662407104139371,2.665468076884529,2.6685290496296874,2.6715900223748457,2.6746509951200044,2.677711967865162,2.6807729406103196,2.6838339133554783,2.6868948861006365,2.689955858845795,2.693016831590953,2.6960778043361113,2.699138777081269,2.702199749826428,2.705260722571586,2.708321695316744,2.709375300918132,2.7102855228479306,2.711195744777729,2.7131483287290603,2.716143274701923,2.7191382206747865,2.7221331666476494,2.7251281126205127,2.7281230585933756,2.731719896255384,2.736345774782844,2.740971653310304,2.745597531837763,2.750223410365223,2.7548492888926828,2.759475167420142,2.7641010459476014,2.768726924475062,2.773352803002521,2.7779786815299805,2.7826045600574405,2.7872304385849,2.791856317112359,2.796482195639819,2.801108074167279,2.8057339526947382,2.8103598312221982,2.8149857097496582,2.8196115882771173,2.8242374668045773,2.828863345332037,2.8334892238594964,2.838115102386956,2.842740980914416,2.847366859441876,2.8519927379693346,2.856618616496794,2.861244495024255,2.865870373551714,2.8704962520791737,2.8751221306066332,2.879748009134093,2.8843738876615523,2.888999766189012,2.8936256447164714,2.898251523243931,2.9028774017713914,2.9075032802988514,2.9121291588263105,2.91675503735377,2.9213809158812305,2.9260067944086896,2.9306326729361487,2.935258551463609,2.9398844299910687,2.9445103085185282,2.949136187045988,2.9537620655734473,2.958387944100907,2.9630138226283664,2.967639701155827,2.972265579683286,2.976891458210746,2.9815173367382055,2.986143215265665,2.9907690937931246,2.995394972320584,3.0000208508480437,3.0046467293755033,3.0092726079029632,3.0138984864304232,3.018524364957882,3.023150243485342,3.027776122012802,3.0324020005402614,3.037027879067721,3.0416537575951805,3.04627963612264,3.0509055146500996,3.055531393177559,3.0601572717050187,3.0647831502324783,3.0694090287599383,3.0740349072873987,3.078660785814858,3.0832866643423174,3.0889904609139407,3.09685009357389,3.104709726233839,3.1125693588937877,3.120428991553737,3.128288624213686,3.1361482568736356,3.144007889533585,3.151867522193534,3.159727154853483,3.1675867875134327,3.1754464201733814,3.183306052833331,3.19116568549328,3.199025318153229,3.206884950813178,3.214744583473127,3.222604216133077,3.2304638487930255,3.238323481452975,3.2461831141129247,3.254042746772874,3.2619023794328226,3.269762012092772,3.277621644752721,3.28548127741267,3.2933409100726196,3.301200542732569,3.309060175392518,3.3169198080524667,3.3247794407124167,3.3326390733723645,3.340498706032314,3.348358338692264,3.356217971352213,3.364077604012162,3.371937236672111,3.379796869332061,3.3876565019920095,3.3955161346519587,3.403375767311908,3.411235399971857,3.419095032631806,3.426954665291756,3.434814297951705,3.4426739306116536,3.4505335632716037,3.4583931959315524,3.466252828591501,3.4741124612514507,3.4819720939114,3.4898317265713485,3.4976913592312986,3.5074983088297147,3.518031866020869,3.528565423212025,3.539098980403182,3.549632537594337,3.5601660947854925,3.570699651976649,3.5812332091678045,3.5917667663589596,3.602300323550116,3.6128338807412717,3.623367437932427,3.633900995123583,3.64443455231474,3.6549681095058943,3.6655016666970512,3.6760352238882072,3.6865687810793624,3.6971023382705184,3.7076358954616744,3.7181694526528295,3.728703009843985,3.7392365670351415,3.7497701242262984,3.7603036814174526,3.770837238608609,3.781370795799765,3.7919043529909207,3.8024379101820758,3.8129714673732327,3.8237105422563307,3.835477205599149,3.8472438689419666,3.8590105322847843,3.8707771956276003,3.882543858970418,3.894310522313236,3.906077185656051,3.91784384899887,3.9296105123416876,3.941377175684503,3.9531438390273212,3.9649105023701385,3.9766771657129567,3.986676409219971,3.9821284130155603,3.9775804168111497,3.9730324206067404,3.96848442440233,3.9639364281979192,3.95938843199351,3.9548404357891,3.950292439584689,3.9457444433802795,3.9411964471758685,3.9366484509714583,3.932100454767048,3.9275524585626385,3.923004462358228,3.9184564661538177,3.9139084699494084,3.9093604737449974,3.9048124775405872,3.900264481336178,3.895716485131767,3.8911684889273572,3.8866204927229466,3.882072496518537,3.8775245003141268,3.872976504109716,3.868428507905306,3.863880511700896,3.8593325154964857,3.8547845192920764,3.850236523087666,3.8456885268832552,3.8411405306788455,3.836592534474435,3.832044538270025,3.8274965420656146,3.8229485458612045,3.8184005496567943,3.813852553452384,3.8093045572479745,3.804756561043564,3.8002085648391537,3.7956605686347444,3.7911125724303343,3.7865645762259232,3.782016580021513,3.777468583817103,3.7729205876126928,3.7683725914082826,3.7638245952038725,3.7592765989994623,3.754728602795052,3.7501806065906425,3.745632610386232,3.7410846141818217,3.734453201391635,3.69418955290264,3.6539259044136436,3.6136622559246483,3.5733986074356596,3.533134958946664,3.4928713104576676,3.4526076619686794,3.412344013479683,3.3720803649906874,3.3318167165016987,3.2915530680127034,3.251289419523707,3.2110257710347114,3.170762122545723],[2.652200689757539,2.6547869025161654,2.6573731152747913,2.6599593280334175,2.6625455407920438,2.6651317535506696,2.667717966309296,2.6703041790679216,2.672890391826548,2.6754766045851737,2.6780628173438004,2.680649030102426,2.683235242861052,2.6858214556196787,2.6884076683783045,2.690993881136931,2.6935800938955565,2.6961663066541828,2.698752519412809,2.7013387321714353,2.703924944930061,2.706511157688687,2.709097370447313,2.7116835832059394,2.714269795964565,2.716856008723192,2.7194422214818177,2.722028434240444,2.72461464699907,2.727200859757696,2.7297870725163222,2.732373285274948,2.7349594980335743,2.7375457107922,2.740131923550827,2.7427181363094526,2.7453043490680784,2.747890561826705,2.750476774585331,2.7530629873439567,2.755649200102583,2.758235412861209,2.760821625619835,2.7634078383784613,2.7659940511370875,2.7685802638957133,2.7711664766543396,2.773752689412966,2.7763389021715916,2.7789251149302174,2.781511327688844,2.78409754044747,2.786683753206096,2.7892699659647224,2.7918561787233482,2.7944423914819745,2.7970286042406007,2.799614816999227,2.802201029757853,2.8047872425164786,2.8073734552751053,2.809959668033731,2.812545880792357,2.815132093550983,2.8177183063096094,2.8203045190682356,2.8228907318268615,2.8254769445854877,2.828063157344114,2.8290459010551334,2.828425174108106,2.827804447161079,2.8271837202140513,2.8265629932670238,2.8259422663199967,2.825321539372969,2.824700812425942,2.8240800854789145,2.823459358531887,2.82283863158486,2.8222179046378324,2.8215971776908053,2.820976450743778,2.8203557237967503,2.820510544232507,2.820820474144821,2.8211304040571346,2.821440333969448,2.8217502638817615,2.8220601937940755,2.8223701237063894,2.822680053618703,2.8229899835310164,2.82329991344333,2.823609843355644,2.8239197732679577,2.824229703180271,2.8245396330925847,2.8253368505695944,2.828570501465432,2.831804152361269,2.8350378032571064,2.838271454152944,2.841505105048781,2.8447387559446184,2.847972406840456,2.8512060577362934,2.85443970863213,2.857673359527968,2.8609070104238055,2.8641406613196425,2.86737431221548,2.8706079631113175,2.8738416140071545,2.877075264902992,2.8803089157988295,2.883542566694667,2.8867762175905045,2.8900098684863416,2.893243519382179,2.8964771702780165,2.899710821173854,2.902944472069691,2.906178122965529,2.909411773861366,2.912645424757203,2.915879075653041,2.919112726548878,2.9223463774447156,2.925580028340553,2.9288136792363906,2.932047330132228,2.935280981028065,2.938514631923902,2.9417482828197397,2.944981933715577,2.9482155846114146,2.9514492355072517,2.954682886403089,2.9579165372989262,2.9611501881947637,2.964383839090601,2.9676174899864387,2.9708511408822758,2.9740847917781137,2.9773184426739507,2.9805520935697882,2.9837857444656253,2.9870193953614628,2.9902530462573003,2.9934866971531378,2.9967203480489752,2.999953998944812,3.0031876498406493,3.0064213007364873,3.0096549516323243,3.0128886025281614,3.016122253423999,3.0193559043198364,3.022589555215674,3.025823206111511,3.0290568570073484,3.032290507903186,3.0355241587990234,3.0387578096948604,3.041991460590698,3.0452251114865354,3.0483436436152536,3.0514046163604114,3.05446558910557,3.057526561850728,3.060587534595886,3.063648507341045,3.0667094800862027,3.069770452831361,3.072831425576519,3.075892398321677,3.0789533710668353,3.0820143438119936,3.085075316557152,3.0881362893023097,3.0911972620474684,3.094258234792626,3.0973192075377844,3.1003801802829427,3.103441153028101,3.106502125773259,3.1095630985184166,3.112624071263575,3.115685044008733,3.118746016753892,3.1218069894990492,3.1248679622442075,3.1279289349893666,3.1309899077345236,3.1340508804796827,3.137111853224841,3.140172825969999,3.1432337987151566,3.1462947714603153,3.149355744205473,3.1524167169506314,3.1554776896957897,3.1585386624409475,3.161599635186106,3.164660607931264,3.1677215806764223,3.1707825534215806,3.1738435261667384,3.177476630930455,3.1816818660607,3.185887101190945,3.1900923363211904,3.1942975714514352,3.19850280658168,3.202708041711925,3.2069132768421706,3.2111185119724155,3.215323747102661,3.2195289822329056,3.223734217363151,3.227939452493396,3.2321446876236406,3.236349922753886,3.240555157884131,3.244760393014376,3.2489656281446218,3.2531708632748666,3.257376098405112,3.261581333535357,3.2657865686656016,3.269991803795847,3.274197038926092,3.278402274056337,3.2826075091865823,3.2868127443168276,3.2910179794470724,3.2952232145773173,3.2994284497075625,3.3036336848378083,3.307838919968053,3.312044155098298,3.3162493902285433,3.3204546253587885,3.3246598604890334,3.3288650956192782,3.3330703307495235,3.3372755658797684,3.3414808010100137,3.345686036140259,3.3506073169638704,3.3562446434808493,3.3618819699978273,3.3675192965148053,3.373156623031784,3.378793949548762,3.384431276065741,3.3900686025827196,3.395705929099698,3.401343255616676,3.406980582133655,3.412617908650633,3.4182552351676114,3.4238925616845894,3.4295298882015683,3.4351672147185464,3.440804541235525,3.4464418677525037,3.4520791942694817,3.4577165207864597,3.4633538473034386,3.4689911738204176,3.4746285003373956,3.4802658268543745,3.4859031533713525,3.4915404798883305,3.497177806405309,3.5028151329222874,3.508452459439266,3.5140897859562434,3.5197271124732223,3.5253644389902012,3.5310017655071793,3.5366390920241573,3.542276418541136,3.547913745058115,3.5535510715750926,3.5591883980920715,3.56482572460905,3.570463051126028,3.576100377643007,3.581737704159985,3.587375030676963,3.593012357193942,3.5986496837109208,3.6042870102278988,3.6099243367448772,3.6155616632618557,3.6211989897788337,3.6268363162958126,3.6324736428127915,3.6381109693297695,3.6437482958467475,3.649385622363726,3.6550229488807044,3.660660275397682,3.6662976019146605,3.6719349284316394,3.6775722549486183,3.6832095814655963,3.6888469079825748,3.694484234499553,3.7001215610165317,3.7053309707828133,3.7099568493102733,3.714582727837733,3.7192086063651923,3.7238344848926523,3.728460363420112,3.733086241947571,3.7377121204750314,3.7423379990024905,3.74696387752995,3.7515897560574105,3.756215634584869,3.7608415131123287,3.765467391639789,3.7700932701672483,3.774719148694708,3.7793450272221674,3.783970905749628,3.7885967842770873,3.7932226628045465,3.7989264593761702,3.806786092036119,3.8146457246960677,3.8225053573560177,3.8303649900159664,3.838224622675915,3.846084255335865,3.8539438879958148,3.861803520655763,3.869663153315712,3.877522785975662,3.885382418635611,3.895857852843657,3.906391410034814,3.9169249672259694,3.927458524417124,3.937992081608281,3.9485256387994365,3.9590591959905916,3.969592753181748,3.980126310372904,3.9906598675640597,4.001193424755215,4.011726981946372,4.022260539137528,4.032794096328683,4.043327653519839,4.053861210710995,4.06439476790215,4.074928325093306,4.085461882284462,4.095995439475617,4.106528996666773,4.117062553857929,4.127596111049085,4.138129668240241,4.148663225431397,4.159196782622553,4.169730339813707,4.180263897004865,4.190797454196019,4.201331011387175,4.211864568578331,4.222398125769488,4.232931682960643,4.243465240151799,4.253998797342955,4.2645323545341105,4.275065911725266,4.285599468916422,4.296133026107578,4.306666583298734,4.31720014048989,4.3277336976810465,4.3382672548722,4.348800812063357,4.359334369254514,4.369867926445669,4.380401483636824,4.390935040827982,4.401468598019136,4.412002155210291,4.422535712401449,4.433069269592603,4.443602826783759,4.454136383974915,4.464669941166071,4.475203498357225,4.485737055548382,4.496270612739538,4.506804169930694,4.51733772712185,4.527871284313006,4.538404841504161,4.5489383986953165,4.559471955886473,4.57000551307763,4.5805390702687845,4.5910726274599405,4.6016061846510965,4.6121397418422525,4.622673299033408,4.6332068562245645,4.6439459311076625,4.65571259445048,4.667479257793298,4.679245921136116,4.691012584478932,4.70277924782175,4.714545911164567,4.726312574507383,4.738079237850202,4.7498459011930185,4.7616125645358345,4.773379227878653,4.78514589122147,4.796912554564288,4.808679217907104,4.820445881249922,4.832212544592739,4.843979207935556,4.855745871278374,4.867512534621191,4.879279197964006,4.891045861306825,4.902812524649644,4.914579187992459,4.926345851335276,4.938112514678094,4.949879178020911,4.961645841363727,4.973412504706546,4.985179168049363,4.996945831392179,5.008712494734997,5.020479158077816,5.0300705381918585,5.025522541987447,5.020974545783037,5.016426549578627,5.011878553374217,5.007330557169807,5.002782560965397,4.998234564760987,4.993686568556576,4.989138572352166,4.984590576147757,4.980042579943346,4.975494583738935,4.970946587534526,4.966398591330115,4.961850595125705,4.957302598921295,4.951564070661171,4.911300422172175,4.87103677368318,4.830773125194191,4.7905094767051954,4.750245828216199,4.709982179727211,4.669718531238216,4.629454882749219,4.589191234260223,4.548927585771236,4.508663937282239,4.4684002887932435,4.428136640304254,4.387872991815259,4.347609343326264,4.3073456948372755,4.267082046348278,4.226818397859283,4.186554749370295,4.146291100881299,4.106027452392303,4.065763803903307,4.025500155414319,3.9852365069253226,3.944972858436327,3.904709209947339,3.8644455614583424,3.824181912969347,3.7839182644803584,3.7436546159913626,3.7033909675023673,3.6631273190133706,3.622863670524383],[3.132652600620325,3.1352388133789506,3.1378250261375764,3.1404112388962027,3.142997451654829,3.145583664413455,3.148169877172081,3.150756089930707,3.1533423026893335,3.1559285154479593,3.158514728206586,3.1611009409652113,3.1636871537238376,3.1662733664824643,3.16885957924109,3.171445791999716,3.1740320047583417,3.1766182175169684,3.179204430275594,3.1817906430342204,3.1843768557928467,3.1869630685514725,3.1895492813100983,3.192135494068725,3.194721706827351,3.197307919585977,3.199894132344603,3.202480345103229,3.2050665578618553,3.207652770620481,3.2102389833791074,3.212825196137733,3.2154114088963595,3.2179976216549857,3.2205838344136115,3.2231700471722378,3.225756259930864,3.22834247268949,3.2309286854481165,3.233514898206742,3.236101110965368,3.2386873237239944,3.2412735364826206,3.2438597492412464,3.2464459619998727,3.249032174758499,3.2516183875171247,3.254204600275751,3.2567908130343772,3.259377025793003,3.2619632385516297,3.2645494513102555,3.2671356640688813,3.269721876827508,3.272308089586134,3.2748943023447596,3.2774805151033863,3.280066727862012,3.282652940620638,3.285239153379264,3.2878253661378904,3.2904115788965167,3.2929977916551425,3.2955840044137683,3.298170217172395,3.300756429931021,3.3033426426896466,3.3059288554482733,3.308515068206899,3.3111012809655254,3.313687493724151,3.3162737064827774,3.3188599192414037,3.3214461320000295,3.324032344758656,3.326618557517282,3.3292047702759078,3.3317909830345336,3.33437719579316,3.3369634085517865,3.3395496213104123,3.342135834069038,3.3468700994957112,3.3526783892454124,3.3588003129378365,3.364984963418806,3.368218615542514,3.3714522664383515,3.374685917334189,3.3779195682300265,3.3811532191258635,3.384386870021701,3.3876205209175385,3.3908541718133756,3.394087822709213,3.3973214736050505,3.400555124500888,3.403788775396725,3.4070224262925626,3.4102560771884,3.413489728084237,3.4167233789800746,3.4199570298759125,3.423190680771749,3.4264243316675866,3.429657982563424,3.4328916334592616,3.4361252843550987,3.4393589352509366,3.442592586146774,3.4458262370426107,3.449059887938448,3.4522935388342857,3.455527189730123,3.4587608406259607,3.461994491521798,3.4652281424176357,3.4684617933134727,3.4716954442093098,3.4749290951051472,3.4781627460009847,3.4813963968968222,3.4846300477926597,3.487863698688497,3.4910973495843347,3.4943310004801713,3.4975646513760092,3.5007983022718467,3.504031953167684,3.5072656040635213,3.5104992549593588,3.5137329058551963,3.5169665567510333,3.520200207646871,3.5234338585427083,3.5266675094385453,3.529901160334383,3.5331348112302203,3.536368462126058,3.5396021130218953,3.542835763917732,3.54606941481357,3.549303065709407,3.5525367166052444,3.555770367501082,3.559004018396919,3.562237669292757,3.5654713201885944,3.568704971084431,3.571938621980269,3.575172272876106,3.5784059237719434,3.5816395746677805,3.5848732255636175,3.588106876459455,3.5913405273552925,3.59457417825113,3.5978078291469675,3.601041480042805,3.6042751309386425,3.6075087818344795,3.610742432730317,3.6139760836261545,3.6172097345219916,3.620443385417829,3.6236770363136666,3.6269106872095036,3.631916503836616,3.6378084033293647,3.6437003028221135,3.6495922023148624,3.653797438582505,3.6580026737127502,3.6622079088429955,3.666413143973241,3.6706183791034857,3.6748236142337305,3.6790288493639762,3.683234084494221,3.687439319624466,3.691644554754711,3.6958497898849556,3.7000550250152013,3.704260260145446,3.708465495275691,3.7126707304059368,3.7168759655361816,3.721081200666427,3.725286435796672,3.729491670926917,3.733696906057162,3.7379021411874076,3.742107376317652,3.7463126114478977,3.750517846578142,3.754723081708388,3.7589283168386327,3.763133551968878,3.7673387870991233,3.771544022229368,3.775749257359613,3.779954492489858,3.7841597276201036,3.7883649627503493,3.7925701978805932,3.7967754330108385,3.800980668141084,3.805185903271329,3.8093911384015744,3.8135963735318192,3.817801608662064,3.8220068437923094,3.8262120789225547,3.8304173140527995,3.8346225491830443,3.8388277843132896,3.843033019443535,3.8472382545737798,3.8514434897040246,3.8556487248342695,3.859853959964515,3.86405919509476,3.8682644302250058,3.8724696653552506,3.8766749004854955,3.8808801356157403,3.885085370745985,3.889290605876231,3.893495841006476,3.897701076136721,3.9019063112669663,3.906111546397211,3.9103167815274564,3.9145220166577017,3.9187272517879466,3.9229324869181914,3.9271377220484367,3.931342957178682,3.935548192308927,3.9397534274391726,3.9439586625694174,3.9481638976996623,3.952369132829908,3.9565743679601524,3.960779603090398,3.9649848382206425,3.969190073350888,3.973395308481133,3.977600543611378,3.981805778741623,3.9867270595652347,3.992364386082213,3.998001712599191,4.0036390391161705,4.0092763656331485,4.014913692150127,4.0205510186671045,4.026188345184083,4.031825671701062,4.03746299821804,4.043100324735019,4.048737651251998,4.054374977768976,4.060012304285953,4.065649630802932,4.071286957319911,4.07692428383689,4.082561610353868,4.088198936870846,4.093836263387824,4.099473589904803,4.105110916421782,4.11074824293876,4.116385569455738,4.122022895972717,4.127660222489695,4.133297549006674,4.138934875523652,4.14457220204063,4.150209528557609,4.155846855074587,4.1614841815915655,4.1671215081085435,4.172758834625522,4.1783961611425005,4.1840334876594785,4.189670814176457,4.195308140693435,4.200945467210414,4.206582793727392,4.212220120244371,4.217857446761349,4.223494773278327,4.229132099795306,4.234769426312285,4.240406752829262,4.246044079346241,4.25168140586322,4.257318732380198,4.262956058897176,4.268593385414155,4.274230711931134,4.279868038448112,4.28550536496509,4.291142691482069,4.296780017999047,4.302417344516025,4.308054671033004,4.313691997549983,4.319329324066961,4.324966650583939,4.3306039771009175,4.336241303617896,4.341878630134874,4.349078156778685,4.357473437217189,4.365868717655694,4.374263998094198,4.382659278532701,4.391054558971206,4.39944983940971,4.407845119848214,4.416240400286718,4.424635680725222,4.433030961163727,4.441426241602231,4.449821522040736,4.458216802479239,4.466612082917743,4.475007363356248,4.4834026437947525,4.491797924233257,4.500193204671761,4.5096714771755755,4.521315733810009,4.532959990444443,4.544604247078878,4.556248503713311,4.567892760347745,4.579537016982179,4.591181273616614,4.602825530251048,4.614469786885481,4.626114043519917,4.63775830015435,4.649402556788784,4.661046813423218,4.6726910700576525,4.684335326692086,4.695979583326521,4.707623839960954,4.719268096595387,4.730912353229823,4.742556609864257,4.7542008664986914,4.765845123133125,4.77748937976756,4.789133636401994,4.800777893036427,4.812422149670862,4.824066406305295,4.835710662939729,4.847354919574164,4.858999176208599,4.870643432843032,4.882287689477466,4.8939319461119,4.905576202746334,4.917220459380768,4.928864716015203,4.940508972649637,4.95215322928407,4.963797485918505,4.975441742552938,4.9870859991873715,4.9987302558218065,5.010374512456241,5.022018769090675,5.033663025725109,5.045307282359543,5.056951538993977,5.0685957956284104,5.080240052262845,5.091884308897279,5.103528565531713,5.115172822166147,5.126817078800582,5.138461335435014,5.150105592069449,5.161749848703884,5.173394105338319,5.185038361972751,5.196682618607187,5.20832687524162,5.219971131876053,5.231615388510488,5.2432596451449225,5.254903901779355,5.266548158413791,5.278192415048226,5.289836671682658,5.301480928317092,5.313125184951527,5.3247694415859605,5.336413698220394,5.34805795485483,5.358640230355477,5.369173787546633,5.379707344737789,5.390240901928946,5.4007744591200995,5.411308016311256,5.421841573502412,5.432375130693568,5.4429086878847235,5.4534422450758795,5.464181319958978,5.475947983301796,5.487714646644614,5.499481309987432,5.5112479733302475,5.523014636673065,5.534781300015883,5.536906148947357,5.519747507463664,5.5025888659799715,5.485430224496282,5.468271583012591,5.451112941528898,5.433954300045205,5.416795658561515,5.399637017077822,5.382478375594129,5.3653197341104395,5.348161092626748,5.331002451143055,5.313843809659366,5.296685168175674,5.279526526691981,5.262367885208292,5.245209243724599,5.228050602240907,5.210891960757214,5.193733319273525,5.176574677789832,5.159416036306139,5.142257394822449,5.125098753338758,5.107940111855065,5.090781470371375,5.073622828887682,5.056464187403989,5.039305545920298,5.0221469044366085,5.004988262952915,4.987829621469223,4.970670979985535,4.953512338501842,4.9363536970181485,4.919195055534459,4.902036414050767,4.884877772567076,4.867719131083386,4.850560489599693,4.833401848116001,4.816243206632308,4.799084565148618,4.781925923664925,4.764767282181234,4.747608640697544,4.730449999213851,4.713291357730158,4.696132716246469,4.678974074762777,4.6618154332790835,4.644656791795391,4.627498150311702,4.61033950882801,4.5931808673443175,4.576022225860628,4.558863584376935,4.541704942893243,4.524546301409553,4.507387659925861,4.490229018442168,4.4730703769584785,4.455911735474786,4.438753093991093,4.421594452507401,4.404435811023712,4.3872771695400195,4.370118528056326,4.352959886572637,4.316547109436994,4.276283460947997,4.236019812459009,4.195756163970014,4.155492515481018,4.115228866992021,4.074965218503033],[3.6112566565723103,3.613842869330936,3.6164290820895624,3.6190152948481886,3.6216015076068144,3.6241877203654407,3.6267739331240665,3.6293601458826927,3.631946358641319,3.634532571399945,3.637118784158571,3.639704996917197,3.6422912096758235,3.6448774224344493,3.6474636351930756,3.650049847951702,3.6526360607103276,3.6552222734689535,3.65780848622758,3.660394698986206,3.6629809117448326,3.665567124503458,3.6681533372620843,3.6707395500207105,3.6733257627793368,3.6759119755379626,3.6784981882965884,3.681084401055214,3.683670613813841,3.6862568265724667,3.688843039331093,3.691429252089719,3.694015464848345,3.6966016776069717,3.6991878903655975,3.7017741031242233,3.70436031588285,3.706946528641476,3.7095327414001016,3.7121189541587274,3.714705166917354,3.71729137967598,3.719877592434606,3.7224638051932324,3.725050017951858,3.7276362307104844,3.7302224434691107,3.7328086562277365,3.7353948689863627,3.737981081744989,3.740567294503615,3.743153507262241,3.745739720020867,3.748325932779493,3.7509121455381194,3.753498358296745,3.7560845710553714,3.758670783813998,3.7612569965726235,3.7638432093312497,3.7664294220898764,3.7690156348485018,3.771601847607128,3.774188060365754,3.77677427312438,3.77989750058716,3.78570579033686,3.791514080086561,3.7973223698362615,3.8031306595859626,3.8089389493356633,3.814747239085364,3.8205555288350648,3.826363818584766,3.832172108334466,3.8379803980841674,3.8437886878338676,3.849596977583569,3.8554052673332695,3.86121355708297,3.8670218468326714,3.8728301365823716,3.8786384263320723,3.884446716081773,3.890568639774197,3.896753290255167,3.9029379407361353,3.9091225912171046,3.9153072416980734,3.9214918921790423,3.927676542660011,3.93386119314098,3.940045843621949,3.946230494102918,3.952415144583887,3.9585997950648557,3.9647844455458254,3.970969096026794,3.977153746507763,3.9833383969887315,3.989523047469701,3.9957076979506696,4.000416850353861,4.003650501249697,4.006884152145535,4.010117803041372,4.01335145393721,4.016585104833046,4.019818755728885,4.023052406624721,4.026286057520559,4.029519708416396,4.032753359312234,4.03598701020807,4.039220661103909,4.042454311999745,4.045687962895583,4.04892161379142,4.052155264687258,4.055388915583095,4.058622566478933,4.06185621737477,4.065089868270608,4.068323519166444,4.071557170062282,4.074790820958119,4.078024471853957,4.081258122749794,4.084491773645631,4.087725424541469,4.090959075437306,4.0941927263331435,4.097426377228981,4.1006600281248184,4.103893679020656,4.107127329916493,4.11036098081233,4.1135946317081675,4.116828282604006,4.1200619334998425,4.12329558439568,4.1265292352915175,4.129762886187355,4.1329965370831925,4.136230187979029,4.139463838874867,4.142697489770704,4.145931140666542,4.149164791562379,4.1523984424582165,4.155632093354054,4.1588657442498915,4.162099395145728,4.165333046041566,4.168566696937403,4.171800347833241,4.175033998729078,4.178267649624916,4.181501300520752,4.18473495141659,4.187968602312427,4.191202253208265,4.194435904104102,4.19766955499994,4.200903205895777,4.204136856791614,4.207370507687452,4.2123763243145635,4.218268223807312,4.224160123300061,4.23005202279281,4.235943922285559,4.241835821778308,4.247727721271057,4.253619620763805,4.259511520256554,4.265403419749303,4.271295319242053,4.277187218734801,4.28307911822755,4.2889710177203,4.294862917213049,4.300754816705797,4.306646716198546,4.312538615691295,4.318430515184044,4.324322414676793,4.330214314169542,4.3361062136622905,4.341998113155039,4.347890012647788,4.353781912140537,4.359673811633286,4.3655657111260355,4.3714576106187835,4.377349510111533,4.383241409604282,4.38913330909703,4.3950252085897805,4.4009171080825285,4.406809007575277,4.412700907068027,4.418592806560776,4.424484705351725,4.42868994048197,4.432895175612215,4.43710041074246,4.441305645872705,4.445510881002951,4.449716116133196,4.453921351263441,4.458126586393686,4.462331821523931,4.466537056654177,4.470742291784421,4.474947526914666,4.479152762044912,4.4833579971751565,4.487563232305401,4.491768467435646,4.495973702565893,4.500178937696137,4.504384172826382,4.508589407956627,4.512794643086872,4.516999878217117,4.521205113347363,4.525410348477608,4.529615583607852,4.533820818738098,4.538026053868343,4.542231288998588,4.546436524128833,4.550641759259078,4.554846994389323,4.559052229519568,4.563257464649813,4.567462699780059,4.5716679349103035,4.575873170040549,4.580078405170793,4.584283640301039,4.588488875431285,4.592694110561529,4.596899345691774,4.601104580822019,4.605309815952265,4.60951505108251,4.613720286212755,4.617925521343,4.622846802166611,4.62848412868359,4.634121455200568,4.639758781717546,4.645396108234525,4.651033434751504,4.656670761268482,4.66230808778546,4.667945414302439,4.673582740819417,4.679220067336395,4.684857393853374,4.690494720370353,4.69613204688733,4.70176937340431,4.707406699921288,4.713044026438266,4.718681352955244,4.724318679472223,4.729956005989202,4.735593332506179,4.741230659023158,4.746867985540137,4.7525053120571155,4.7581426385740935,4.7637799650910715,4.7694172916080495,4.775054618125029,4.780691944642006,4.786329271158985,4.791966597675963,4.797603924192942,4.80324125070992,4.808878577226899,4.814515903743877,4.820153230260856,4.825790556777834,4.831717178796639,4.840112459235143,4.848507739673647,4.856903020112152,4.865298300550656,4.87369358098916,4.882088861427665,4.890484141866169,4.898879422304672,4.907274702743177,4.915669983181681,4.924065263620186,4.932460544058689,4.940855824497194,4.949251104935698,4.957646385374201,4.966041665812707,4.9744369462512115,4.982832226689714,4.991227507128219,4.999622787566723,5.008018068005228,5.016413348443732,5.024808628882236,5.03320390932074,5.0415991897592445,5.049994470197749,5.058389750636253,5.066785031074757,5.075180311513261,5.0835755919517664,5.091970872390268,5.100366152828775,5.108761433267279,5.117156713705782,5.125551994144287,5.133947274582791,5.142342555021295,5.1507378354597995,5.159133115898304,5.167528396336808,5.1759236767753105,5.184318957213816,5.192714237652321,5.201109518090825,5.209504798529329,5.2189830710331435,5.230627327667577,5.242271584302011,5.253915840936446,5.265560097570879,5.277204354205313,5.288848610839748,5.3004928674741825,5.312137124108615,5.32378138074305,5.335425637377485,5.347069894011918,5.358714150646352,5.370358407280787,5.38200266391522,5.393646920549654,5.405291177184089,5.416935433818522,5.428579690452956,5.440223947087391,5.451868203721826,5.4635124603562595,5.475156716990694,5.486800973625128,5.498445230259561,5.510089486893995,5.52173374352843,5.533378000162863,5.5450222567972975,5.556666513431732,5.568310770066167,5.579955026700599,5.591599283335034,5.603243539969468,5.614887796603902,5.6265320532383365,5.638176309872771,5.649820566507205,5.661464823141638,5.673109079776072,5.684753336410506,5.69639759304494,5.708041849679375,5.719686106313809,5.731330362948243,5.742974619582677,5.754618876217111,5.766263132851545,5.777907389485979,5.791561579579508,5.806046797179219,5.820532014778929,5.835017232378641,5.849502449978353,5.863987667578062,5.878472885177773,5.892958102777485,5.907443320377196,5.921928537976907,5.936413755576618,5.950898973176328,5.965384190776039,5.97986940837575,5.994354625975461,6.0088398435751715,6.023325061174884,6.037810278774595,6.052295496374303,6.066780713974016,6.0812659315737285,6.095751149173438,6.110236366773148,6.12472158437286,6.139206801972571,6.153692019572281,6.168177237171992,6.182662454771704,6.197147672371414,6.211632889971125,6.226118107570837,6.2406033251705475,6.255088542770259,6.269573760369969,6.282951386629573,6.290791056188656,6.2986307257477385,6.306470395306821,6.314310064865902,6.3221497344249835,6.329989403984066,6.337829073543147,6.3456687431022285,6.353508412661311,6.361348082220392,6.369187751779474,6.377027421338555,6.384867090897638,6.3927067604567185,6.400546430015801,6.408386099574884,6.416225769133964,6.4106548856361325,6.3934962441524394,6.37633760266875,6.359178961185058,6.342020319701366,6.324861678217676,6.307703036733983,6.29054439525029,6.273385753766598,6.256227112282908,6.239068470799216,6.221909829315523,6.2047511878318335,6.187592546348141,6.170433904864449,6.15327526338076,6.136116621897067,6.118957980413374,6.101799338929682,6.084640697445993,6.0674820559623,6.0503234144786076,6.033164772994918,6.016006131511226,5.998847490027534,5.981688848543844,5.964530207060151,5.947371565576459,5.9302129240927695,5.913054282609076,5.895895641125384,5.878736999641691,5.861578358158002,5.844419716674309,5.827261075190616,5.810102433706927,5.792943792223235,5.775785150739543,5.758626509255853,5.74146786777216,5.724309226288469,5.707150584804776,5.689991943321086,5.672833301837393,5.655674660353701,5.638516018870012,5.621357377386319,5.604198735902627,5.556818631907743,5.491705270680413,5.426591909453084,5.361478548225767,5.296365186998438,5.231251825771109,5.1661384645437805,5.101025103316464,5.0359117420891355,4.970798380861807,4.90568501963449,4.8405716584071605,4.775458297179833,4.710344935952516,4.645231574725186,4.580118213497857,4.515004852270529,4.449891491043212],[4.0898607125242865,4.092446925282912,4.095033138041539,4.097619350800165,4.100205563558791,4.102791776317417,4.105377989076043,4.107964201834669,4.110550414593295,4.113136627351921,4.115722840110548,4.118309052869174,4.1208952656278,4.1234814783864255,4.126067691145052,4.128653903903678,4.131240116662304,4.1338263294209305,4.136412542179556,4.138998754938182,4.141584967696808,4.144171180455435,4.1467573932140604,4.149343605972687,4.151929818731313,4.154516031489939,4.1571022442485654,4.159688457007191,4.162274669765817,4.164860882524444,4.16744709528307,4.170033308041695,4.172619520800322,4.175205733558948,4.177791946317574,4.1803781590761995,4.182964371834826,4.185550584593452,4.188136797352079,4.190723010110704,4.19330922286933,4.195895435627957,4.198481648386582,4.201067861145209,4.203654073903834,4.20624028666246,4.208826499421087,4.211412712179713,4.213998924938339,4.2187331914282975,4.224541481177997,4.2303497709277,4.2361580606774,4.2419663504271,4.247774640176801,4.253582929926502,4.259391219676203,4.265199509425903,4.271007799175604,4.2768160889253055,4.282624378675006,4.288432668424707,4.294240958174407,4.3000492479241075,4.305857537673809,4.31166582742351,4.3174741171732105,4.323282406922911,4.329090696672613,4.3348989864223135,4.340707276172014,4.346515565921715,4.352323855671416,4.358132145421116,4.363940435170817,4.369748724920518,4.3755570146702185,4.381365304419919,4.387173594169621,4.392981883919321,4.398790173669022,4.404598463418722,4.410406753168424,4.416215042918124,4.4223369666105485,4.428521617091517,4.434706267572486,4.440890918053455,4.447075568534425,4.453260219015393,4.459444869496362,4.46562951997733,4.4718141704583,4.477998820939269,4.484183471420238,4.490368121901207,4.496552772382175,4.502737422863145,4.508922073344114,4.515106723825083,4.521291374306052,4.5274760247870205,4.533660675267989,4.539845325748959,4.546029976229927,4.552214626710896,4.5583992771918656,4.5645839276728335,4.570768578153803,4.576953228634772,4.583137879115741,4.589322529596711,4.5955071800776786,4.601691830558648,4.607876481039616,4.614061131520586,4.620245782001555,4.626430432482524,4.6326150829634924,4.635848736061032,4.639082386956869,4.642316037852707,4.6455496887485435,4.648783339644382,4.652016990540218,4.655250641436056,4.658484292331893,4.661717943227731,4.664951594123568,4.668185245019405,4.671418895915243,4.67465254681108,4.6778861977069175,4.681119848602755,4.6843534994985925,4.68758715039443,4.690820801290267,4.694054452186104,4.6972881030819424,4.700521753977779,4.7037554048736165,4.706989055769454,4.7102227066652915,4.713456357561128,4.7166900084569665,4.719923659352803,4.7231573102486415,4.726390961144478,4.729624612040316,4.732858262936153,4.73609191383199,4.739325564727828,4.742559215623665,4.745792866519502,4.74902651741534,4.752260168311177,4.755493819207015,4.758727470102852,4.761961120998689,4.765194771894526,4.768428422790364,4.771662073686201,4.774895724582039,4.778129375477876,4.781363026373714,4.784596677269551,4.787830328165388,4.7928361447925,4.798728044285248,4.804619943777997,4.8105118432707465,4.8164037427634945,4.822295642256245,4.828187541748994,4.834079441241742,4.8399713407344915,4.8458632402272395,4.851755139719989,4.857647039212738,4.863538938705486,4.869430838198236,4.8753227376909845,4.881214637183733,4.887106536676482,4.892998436169231,4.898890335661981,4.904782235154729,4.910674134647478,4.916566034140227,4.922457933632976,4.928349833125726,4.9342417326184735,4.940133632111222,4.946025531603972,4.95191743109672,4.95780933058947,4.9637012300822185,4.9695931295749665,4.975485029067716,4.981376928560465,4.987268828053214,4.993160727545963,4.9990526270387114,5.004944526531461,5.010836426024209,5.016728325516958,5.022620225009708,5.028512124502456,5.034404023995204,5.040295923487954,5.046187822980703,5.052079722473452,5.057971621966201,5.06386352145895,5.069755420951698,5.075647320444448,5.081539219937197,5.087431119429946,5.093323018922694,5.099214918415443,5.105106817908192,5.110998717400941,5.1168906168936905,5.122782516386439,5.128674415879187,5.134566315371937,5.140458214864686,5.146350114357435,5.152242013850183,5.158133913342932,5.164025812835681,5.16991771232843,5.17580961182118,5.181701511313928,5.187593410806677,5.193485310299426,5.199377207251178,5.203582442381423,5.207787677511668,5.2119929126419136,5.216198147772158,5.220403382902403,5.224608618032649,5.228813853162894,5.233019088293139,5.2372243234233835,5.241429558553629,5.245634793683875,5.249840028814118,5.254045263944364,5.258966544767976,5.264603871284955,5.270241197801933,5.2758785243189115,5.2815158508358895,5.287153177352868,5.2927905038698455,5.2984278303868235,5.304065156903803,5.309702483420781,5.31533980993776,5.322751481253084,5.3311467616915875,5.339542042130091,5.347937322568596,5.3563326030071,5.364727883445604,5.373123163884109,5.381518444322613,5.389913724761117,5.398309005199621,5.406704285638126,5.41509956607663,5.423494846515134,5.431890126953639,5.4402854073921425,5.448680687830647,5.457075968269151,5.465471248707655,5.473866529146159,5.482261809584664,5.490657090023168,5.499052370461672,5.507447650900176,5.515842931338681,5.524238211777185,5.532633492215688,5.541028772654194,5.5494240530926975,5.557819333531201,5.566214613969706,5.574609894408209,5.583005174846713,5.591400455285219,5.599795735723722,5.608191016162226,5.6165862966007305,5.624981577039236,5.6333768574777405,5.641772137916243,5.650167418354748,5.6585626987932525,5.666957979231756,5.675353259670261,5.683748540108765,5.692143820547269,5.700539100985773,5.708934381424278,5.717329661862782,5.725724942301286,5.734120222739791,5.742515503178295,5.750910783616798,5.759306064055302,5.7677013444938074,5.776096624932311,5.784491905370815,5.79288718580932,5.801282466247823,5.809677746686328,5.818073027124833,5.826468307563337,5.834863588001841,5.843258868440345,5.85165414887885,5.860049429317353,5.868444709755857,5.8768399901943615,5.885235270632865,5.893630551071371,5.902025831509874,5.91042111194838,5.9188163923868835,5.928294664890697,5.9399389215251315,5.951583178159566,5.963227434794001,5.974871691428434,5.986515948062867,5.998160204697302,6.009804461331737,6.0214487179661695,6.033092974600605,6.045964449836202,6.060449667435911,6.074934885035622,6.0894201026353345,6.103905320235045,6.118390537834754,6.132875755434467,6.147360973034178,6.161846190633888,6.1763314082336,6.190816625833311,6.2053018434330225,6.219787061032733,6.234272278632444,6.248757496232154,6.263242713831865,6.277727931431577,6.292213149031287,6.3066983666309975,6.32118358423071,6.33566880183042,6.35015401943013,6.3646392370298415,6.379124454629553,6.393609672229264,6.408094889828973,6.422580107428686,6.437065325028396,6.451550542628107,6.466035760227818,6.480520977827529,6.495006195427239,6.509491413026952,6.523976630626663,6.538461848226374,6.552947065826084,6.567432283425795,6.581917501025506,6.596402718625216,6.610887936224929,6.625373153824638,6.639858371424349,6.65434358902406,6.668828806623772,6.683314024223481,6.697799241823192,6.712284459422905,6.726769677022615,6.741254894622326,6.755740112222037,6.770225329821748,6.784710547421459,6.79919576502117,6.81368098262088,6.828166200220591,6.842651417820303,6.857136635420014,6.8716218530197235,6.886107070619435,6.900592288219147,6.915077505818856,6.9295627234185675,6.94404794101828,6.95853315861799,6.9730183762177,6.9875035938174115,7.001988811417123,7.016474029016833,7.030959246616544,7.045444464216256,7.059929681815967,7.074414899415676,7.088900117015389,7.102277743274993,7.110117412834075,7.117957082393158,7.12579675195224,7.133636421511321,7.141476091070403,7.149315760629484,7.157155430188566,7.164995099747649,7.17283476930673,7.180674438865811,7.188514108424894,7.196353777983976,7.204193447543058,7.212033117102139,7.21987278666122,7.227712456220304,7.2355521257793844,7.243391795338467,7.251231464897549,7.259071134456629,7.266910804015711,7.274750473574794,7.282590143133874,7.290429812692958,7.2982694822520395,7.306109151811121,7.313948821370201,7.321788490929284,7.329628160488366,7.337467830047448,7.345307499606529,7.353147169165612,7.360986838724693,7.3688265082837745,7.376666177842856,7.384505847401939,7.3923455169610195,7.380915638871682,7.363756997387989,7.346598355904299,7.329439714420607,7.312281072936915,7.295122431453225,7.277963789969532,7.26080514848584,7.224664461551346,7.159551100324018,7.094437739096689,7.029324377869361,6.964211016642045,6.899097655414716,6.8339842941873865,6.76887093296007,6.703757571732741,6.638644210505412,6.573530849278096,6.5084174880507675,6.443304126823438,6.378190765596109,6.3130774043687925,6.247964043141464,6.182850681914134,6.1177373206868175,6.05262395945949,5.987510598232161,5.922397237004844,5.857283875777515,5.792170514550186,5.727057153322869,5.66194379209554,5.596830430868212,5.531717069640884,5.466603708413567,5.401490347186238,5.33637698595891,5.271263624731592,5.206150263504263,5.141036902276935,5.075923541049617,5.01081017982229,4.94569681859496,4.880583457367631,4.815470096140315],[4.568464768476272,4.571050981234897,4.573637193993524,4.57622340675215,4.578809619510777,4.581395832269402,4.583982045028028,4.586568257786654,4.589154470545281,4.5917406833039065,4.594326896062533,4.596913108821159,4.599499321579785,4.6020855343384115,4.604671747097037,4.607257959855663,4.60984417261429,4.612430385372915,4.615016598131541,4.617602810890168,4.620189023648794,4.62277523640742,4.6253614491660455,4.627947661924672,4.630533874683298,4.633120087441925,4.6357063002005505,4.638292512959176,4.640878725717803,4.643464938476428,4.646051151235055,4.648637363993681,4.651760592519745,4.657568882269446,4.663377172019146,4.669185461768848,4.6749937515185485,4.680802041268249,4.686610331017951,4.692418620767651,4.698226910517352,4.704035200267052,4.709843490016753,4.715651779766454,4.721460069516154,4.727268359265856,4.7330766490155565,4.738884938765256,4.744693228514957,4.750501518264659,4.756309808014359,4.762118097764061,4.767926387513761,4.7737346772634615,4.779542967013162,4.785351256762863,4.7911595465125645,4.796967836262265,4.802776126011965,4.808584415761667,4.814392705511366,4.820200995261068,4.826009285010768,4.8318175747604695,4.83762586451017,4.843434154259871,4.849242444009572,4.855050733759272,4.860859023508974,4.866667313258674,4.872475603008375,4.878283892758075,4.884092182507777,4.8899004722574775,4.895708762007178,4.901517051756879,4.90732534150658,4.91313363125628,4.918941921005981,4.924750210755683,4.9305585005053825,4.936366790255083,4.942175080004784,4.9479833697544855,4.95410529344691,4.9602899439278785,4.966474594408847,4.972659244889816,4.978843895370785,4.985028545851754,4.991213196332723,4.997397846813692,5.003582497294661,5.00976714777563,5.015951798256599,5.022136448737568,5.028321099218537,5.034505749699505,5.040690400180475,5.046875050661443,5.053059701142413,5.0592443516233825,5.06542900210435,5.07161365258532,5.077798303066288,5.083982953547258,5.090167604028227,5.0963522545091955,5.102536904990164,5.108721555471133,5.114906205952102,5.121090856433072,5.12727550691404,5.133460157395009,5.139644807875978,5.145829458356947,5.152014108837916,5.158198759318886,5.1643834097998536,5.170568060280823,5.176752710761791,5.182937361242761,5.189122011723729,5.195306662204699,5.201491312685668,5.207675963166636,5.213860613647605,5.220045264128575,5.226229914609543,5.2324145650905125,5.2385992155714804,5.24478386605245,5.25096851653342,5.257153167014388,5.263337817495358,5.268046970872377,5.271280621768214,5.274514272664051,5.277747923559889,5.280981574455726,5.284215225351563,5.287448876247401,5.290682527143238,5.293916178039075,5.297149828934913,5.30038347983075,5.303617130726588,5.306850781622425,5.310084432518263,5.3133180834141,5.316551734309937,5.319785385205775,5.323019036101612,5.326252686997449,5.329486337893287,5.332719988789124,5.335953639684961,5.339187290580799,5.342420941476636,5.345654592372473,5.348888243268311,5.3521218941641475,5.355355545059986,5.3585891959558225,5.36182284685166,5.3650564977474975,5.368290148643335,5.373295965270447,5.379187864763195,5.385079764255946,5.390971663748694,5.396863563241443,5.402755462734193,5.40864736222694,5.41453926171969,5.420431161212438,5.426323060705187,5.432214960197937,5.438106859690684,5.443998759183435,5.449890658676183,5.4557825581689325,5.4616744576616805,5.46756635715443,5.473458256647179,5.479350156139928,5.485242055632677,5.4911339551254255,5.497025854618174,5.502917754110924,5.508809653603673,5.514701553096422,5.5205934525891704,5.526485352081919,5.532377251574668,5.538269151067418,5.544161050560166,5.550052950052914,5.555944849545664,5.561836749038412,5.567728648531161,5.573620548023911,5.579512447516659,5.585404347009408,5.591296246502157,5.597188145994905,5.603080045487656,5.608971944980404,5.6148638444731525,5.620755743965902,5.62664764345865,5.6325395429514,5.6384314424441495,5.6443233419368966,5.650215241429646,5.656107140922396,5.661999040415144,5.667890939907894,5.673782839400642,5.67967473889339,5.68556663838614,5.691458537878889,5.697350437371638,5.7032423368643865,5.709134236357135,5.715026135849884,5.720918035342634,5.726809934835382,5.732701834328131,5.73859373382088,5.744485633313629,5.752026103505505,5.759566575211201,5.767107046916896,5.77464751862259,5.782187990328286,5.789728462033981,5.7972689337396766,5.804809405445372,5.812349877151067,5.819890348856762,5.827430820562457,5.834971292268152,5.842511763973848,5.850052235679543,5.857592707385238,5.865133179090933,5.872673650796629,5.8802141225023234,5.887754594208019,5.89696297287286,5.907839258496846,5.918715544120831,5.929591829744815,5.940468115368802,5.951344400992786,5.962220686616771,5.973096972240756,5.983973257864743,5.994849543488726,6.005725829112712,6.016602114736698,6.027478400360684,6.038354685984668,6.049230971608654,6.060107257232638,6.070983542856624,6.0815710380193915,6.089963761992354,6.098356485965317,6.106749209938279,6.115141933911243,6.123534657884206,6.131927381857169,6.140320105830133,6.148712829803095,6.1571055537760575,6.1654982777490215,6.173891001721984,6.182283725694946,6.19067644966791,6.199069173640873,6.207461897613835,6.215854621586798,6.224247345559762,6.232640069532724,6.241032793505687,6.24942551747865,6.257818241451613,6.266210965424576,6.27460368939754,6.282996413370502,6.291389137343464,6.299781861316427,6.308174585289391,6.316567309262353,6.324960033235316,6.33335275720828,6.341745481181243,6.350138205154206,6.358530929127168,6.366923653100131,6.375316377073094,6.383709101046057,6.3921018250190205,6.400494548991983,6.408887272964946,6.41727999693791,6.425672720910873,6.434065444883835,6.442458168856799,6.450850892829761,6.459243616802723,6.467636340775687,6.47602906474865,6.484421788721614,6.492814512694576,6.50120723666754,6.509599960640502,6.517992684613464,6.526385408586428,6.53477813255939,6.543170856532353,6.5515635805053165,6.559956304478279,6.568349028451242,6.576741752424206,6.585134476397168,6.59352720037013,6.601919924343093,6.610312648316057,6.6187053722890195,6.627098096261983,6.637834767224247,6.653259332165106,6.668683897105966,6.6841084620468285,6.699533026987689,6.714957591928549,6.73038215686941,6.745806721810271,6.76123128675113,6.776655851691992,6.792080416632853,6.8075049815737145,6.822929546514574,6.838354111455436,6.853778676396296,6.869203241337155,6.884627806278018,6.900052371218878,6.915476936159738,6.9309015011006,6.946326066041461,6.961750630982322,6.9771751959231825,6.992599760864043,7.008024325804904,7.0234488907457635,7.038873455686625,7.054298020627485,7.0697225855683445,7.085147150509206,7.1005717154500685,7.115996280390927,7.131420845331789,7.14684541027265,7.16226997521351,7.177694540154371,7.193119105095233,7.208543670036093,7.223968234976953,7.239392799917814,7.254817364858676,7.270241929799534,7.285666494740395,7.301091059681258,7.316515624622118,7.331940189562978,7.34736475450384,7.362789319444699,7.37821388438556,7.393638449326422,7.409063014267281,7.424487579208142,7.4399121441490035,7.455336709089864,7.470761274030725,7.486185838971585,7.501610403912447,7.517034968853308,7.532459533794167,7.547884098735029,7.563308663675889,7.578733228616749,7.59415779355761,7.6095823584984705,7.625006923439331,7.640431488380193,7.655856053321055,7.671280618261913,7.686705183202775,7.702129748143637,7.717554313084496,7.7329788780253566,7.748403442966218,7.763828007907078,7.779252572847938,7.794677137788799,7.8101017027296615,7.82552626767052,7.840950832611382,7.856375397552244,7.871799962493103,7.887224527433964,7.904774274288597,7.919857133034911,7.909983979181711,7.877281936614643,7.844579894047573,7.811877851480511,7.7791758089134415,7.746473766346373,7.71377172377931,7.681069681212241,7.648367638645173,7.6156655960781094,7.582963553511041,7.5502615109439715,7.517559468376903,7.484857425809841,7.452155383242771,7.419453340675703,7.386751298108639,7.354049255541571,7.321347212974501,7.288645170407439,7.2559431278403705,7.223241085273301,7.190539042706239,7.157837000139169,7.125134957572101,7.092432915005032,7.05973087243797,7.0270288298709005,6.994326787303832,6.961624744736769,6.9289227021697,6.896220659602631,6.863518617035568,6.8308165744685,6.7981145319014304,6.765412489334361,6.7327104467673,6.700008404200231,6.667306361633162,6.634604319066099,6.601902276499031,6.569200233931961,6.536498191364897,6.503796148797829,6.47109410623076,6.438392063663697,6.405690021096628,6.37298797852956,6.340285935962491,6.307583893395428,6.2748818508283595,6.242179808261291,6.209477765694228,6.176775723127158,6.144073680560089,6.111371637993027,6.078669595425958,6.0459675528588885,6.01326551029182,5.980563467724758,5.947861425157688,5.91515938259062,5.882457340023557,5.849755297456488,5.817053254889419,5.784351212322356,5.751649169755288,5.718947127188219,5.686245084621156,5.653543042054087,5.620840999487019,5.588138956919948,5.555436914352887,5.5227348717858185,5.490032829218749,5.457330786651687,5.424628744084618,5.391926701517548,5.359224658950485,5.326522616383416,5.293820573816348,5.261118531249279,5.177799841788016],[5.0470688244282575,5.049655037186884,5.052241249945509,5.054827462704136,5.0574136754627625,5.059999888221388,5.062586100980014,5.065172313738641,5.067758526497267,5.0703447392558925,5.072930952014518,5.075517164773145,5.078103377531771,5.080689590290397,5.083275803049023,5.08586201580765,5.0905962833608935,5.096404573110594,5.102212862860295,5.108021152609996,5.113829442359696,5.119637732109398,5.125446021859099,5.1312543116087985,5.1370626013585,5.142870891108201,5.148679180857901,5.154487470607602,5.160295760357303,5.166104050107004,5.171912339856705,5.177720629606405,5.183528919356106,5.1893372091058065,5.195145498855508,5.200953788605209,5.20676207835491,5.212570368104609,5.218378657854311,5.224186947604012,5.229995237353712,5.235803527103413,5.241611816853114,5.2474201066028145,5.253228396352515,5.259036686102216,5.264844975851917,5.270653265601617,5.276461555351318,5.28226984510102,5.2880781348507195,5.293886424600421,5.299694714350121,5.305503004099823,5.311311293849524,5.317119583599224,5.322927873348926,5.328736163098625,5.334544452848326,5.340352742598027,5.3461610323477275,5.351969322097429,5.35777761184713,5.36358590159683,5.369394191346531,5.375202481096232,5.381010770845933,5.386819060595633,5.392627350345334,5.398435640095036,5.404243929844736,5.410052219594437,5.415860509344137,5.421668799093839,5.427477088843539,5.43328537859324,5.439093668342941,5.444901958092641,5.450710247842342,5.456518537592043,5.462326827341744,5.468135117091444,5.473943406841145,5.479751696590846,5.48587362028327,5.49205827076424,5.498242921245208,5.504427571726177,5.510612222207146,5.516796872688115,5.522981523169084,5.529166173650053,5.535350824131021,5.54153547461199,5.54772012509296,5.553904775573928,5.560089426054898,5.5662740765358665,5.572458727016836,5.578643377497805,5.584828027978774,5.591012678459743,5.5971973289407115,5.60338197942168,5.609566629902649,5.615751280383618,5.621935930864587,5.628120581345556,5.634305231826525,5.640489882307494,5.646674532788463,5.652859183269432,5.659043833750401,5.6652284842313705,5.671413134712338,5.677597785193308,5.683782435674277,5.689967086155246,5.696151736636215,5.7023363871171835,5.708521037598153,5.714705688079121,5.720890338560091,5.72707498904106,5.7332596395220286,5.739444290002997,5.745628940483966,5.751813590964935,5.757998241445904,5.764182891926874,5.770367542407842,5.776552192888812,5.78273684336978,5.788921493850749,5.795106144331719,5.8012907948126875,5.807475445293656,5.813660095774625,5.819844746255594,5.826029396736563,5.832214047217532,5.8383986976985005,5.844583348179469,5.850767998660438,5.856952649141408,5.863137299622377,5.869321950103346,5.875506600584314,5.881691251065283,5.887875901546252,5.894060552027221,5.900245202508191,5.90347885657956,5.906712507475397,5.909946158371235,5.9131798092670715,5.916413460162909,5.9196471110587465,5.922880761954584,5.9261144128504215,5.929348063746259,5.932581714642096,5.935815365537934,5.939049016433771,5.942282667329607,5.945516318225446,5.948749969121282,5.9537557857483945,5.959647685241144,5.965539584733893,5.971431484226642,5.977323383719391,5.9832152832121395,5.989107182704888,5.994999082197637,6.000890981690386,6.006782881183135,6.0126747806758845,6.018566680168633,6.024458579661383,6.030350479154132,6.036242378646881,6.042134278139629,6.048026177632377,6.053918077125126,6.059809976617875,6.065701876110625,6.071593775603373,6.077485675096122,6.08337757458887,6.089269474081621,6.09516137357437,6.1010532730671185,6.1069451725598665,6.112837072052616,6.118728971545365,6.124620871038113,6.130512771902762,6.138053243608457,6.145593715314151,6.153134187019846,6.160674658725542,6.168215130431237,6.175755602136933,6.183296073842628,6.190836545548324,6.198377017254019,6.205917488959713,6.213457960665409,6.220998432371104,6.2285389040767996,6.236079375782495,6.2436198474881905,6.251160319193885,6.258700790899581,6.266241262605276,6.273781734310972,6.281322206016667,6.288862677722362,6.296403149428057,6.303943621133753,6.311484092839448,6.319024564545143,6.326565036250837,6.334105507956533,6.341645979662228,6.349186451367924,6.356726923073619,6.364267394779315,6.37180786648501,6.379348338190704,6.3868888098964005,6.394429281602096,6.401969753307791,6.409510225013486,6.417050696719182,6.424591168424877,6.432131640130573,6.439672111836266,6.447212583541962,6.454753055247657,6.462293526953353,6.469833998659048,6.477374470364744,6.484914942070439,6.492455413776133,6.4999958854818285,6.507536357187524,6.5150768288932195,6.522617300598915,6.531825679263756,6.5427019648877405,6.553578250511726,6.564454536135711,6.575330821759696,6.586207107383681,6.597083393007666,6.607959678631653,6.618835964255638,6.629712249879622,6.640588535503607,6.651464821127593,6.662341106751579,6.673217392375563,6.684093677999549,6.694969963623533,6.70584624924752,6.716722534871505,6.727598820495491,6.738475106119475,6.7493513917434615,6.760227677367446,6.771103962991431,6.781980248615416,6.792856534239402,6.803732819863386,6.8146091054873725,6.825485391111358,6.836361676735343,6.847237962359328,6.858114247983313,6.8689905336073,6.8798668192312835,6.890743104855269,6.901619390479254,6.912495676103239,6.923371961727225,6.934248247351211,6.945124532975195,6.95600081859918,6.966877104223165,6.97775338984715,6.988629675471136,6.999505961095121,7.010382246719107,7.021258532343091,7.032134817967076,7.041278382107304,7.049671106080266,7.05806383005323,7.066456554026193,7.074849277999156,7.083242001972119,7.091634725945083,7.100027449918045,7.108420173891007,7.11681289786397,7.125205621836933,7.133598345809896,7.1419910697828595,7.150383793755822,7.158776517728786,7.167169241701748,7.175561965674712,7.183954689647674,7.192347413620637,7.2007401375936,7.209132861566563,7.217525585539525,7.225918309512489,7.234311033485452,7.242703757458415,7.251096481431378,7.259489205404341,7.267881929377303,7.276274653350267,7.284667377323229,7.2930601012961915,7.301452825269155,7.309845549242119,7.318238273215082,7.326630997188044,7.335023721161007,7.345760392123271,7.361184957064131,7.376609522004991,7.392034086945852,7.407458651886713,7.422883216827572,7.438307781768434,7.453732346709296,7.469156911650154,7.484581476591017,7.500006041531877,7.515430606472738,7.530855171413599,7.546279736354459,7.56170430129532,7.57712886623618,7.592553431177041,7.607977996117903,7.623402561058763,7.638827125999623,7.654251690940486,7.669676255881345,7.685100820822206,7.7005253857630676,7.715949950703928,7.731374515644788,7.746799080585649,7.762223645526509,7.777648210467369,7.793072775408231,7.808497340349093,7.823921905289952,7.839346470230813,7.854771035171675,7.870195600112535,7.885620165053394,7.901044729994257,7.916469294935117,7.931893859875977,7.947318424816839,7.962742989757699,7.978167554698559,7.99359211963942,8.009016684580281,8.024441249521141,8.040521847759289,8.058829260637001,8.07713667351471,8.09544408639242,8.11375149927013,8.13205891214784,8.150366325025551,8.168673737903262,8.186981150780973,8.20528856365868,8.223595976536393,8.241903389414103,8.260210802291812,8.278518215169523,8.296825628047234,8.315133040924945,8.333440453802654,8.351747866680366,8.370055279558075,8.388362692435784,8.406670105313497,8.424977518191207,8.443284931068916,8.461592343946627,8.479899756824338,8.498207169702049,8.516514582579758,8.53482199545747,8.55312940833518,8.571436821212888,8.5897442340906,8.608051646968311,8.626359059846019,8.644666472723731,8.662973885601442,8.681281298479151,8.699588711356862,8.717896124234572,8.732978982980887,8.731939071070233,8.730899159159582,8.729859247248928,8.728819335338276,8.727779423427624,8.726739511516971,8.725699599606319,8.724659687695667,8.723619775785014,8.72257986387436,8.721539951963708,8.720500040053055,8.719460128142403,8.71842021623175,8.717380304321097,8.716340392410444,8.715300480499792,8.71426056858914,8.713220656678487,8.712180744767835,8.711140832857183,8.689394330320658,8.656692287753597,8.623990245186526,8.59128820261946,8.55858616005239,8.525884117485328,8.49318207491826,8.460480032351189,8.427777989784126,8.395075947217057,8.362373904649989,8.329671862082925,8.296969819515857,8.264267776948788,8.23156573438172,8.198863691814656,8.166161649247588,8.13345960668052,8.100757564113456,8.068055521546388,8.035353478979317,8.002651436412256,7.969949393845186,7.937247351278118,7.904545308711055,7.871843266143985,7.839141223576917,7.806439181009848,7.773737138442786,7.741035095875716,7.708333053308648,7.675631010741585,7.642928968174516,7.6102269256074475,7.577524883040384,7.544822840473316,7.512120797906246,7.479418755339177,7.446716712772115,7.414014670205045,7.352078995464838,7.262355818929272,7.172632642393689,7.082909465858107,6.993186289322541,6.903463112786959,6.813739936251375,6.724016759715809,6.634293583180227,6.544570406644645,6.454847230109062,6.365124053573496,6.275400877037912,6.18567770050233,6.095954523966764,6.006231347431181,5.916508170895598,5.8267849943600325,5.73706181782445,5.647338641288867,5.557615464753285,5.467892288217719],[5.525455946748889,5.53452496245444,5.540876710413215,5.546685000162916,5.552493289912617,5.558301579662317,5.564109869412018,5.569918159161719,5.57572644891142,5.58153473866112,5.587343028410821,5.593151318160522,5.598959607910223,5.604767897659924,5.610576187409625,5.6163844771593245,5.622192766909026,5.628001056658726,5.633809346408428,5.639617636158128,5.645425925907829,5.651234215657531,5.65704250540723,5.662850795156931,5.668659084906632,5.674467374656333,5.680275664406033,5.686083954155735,5.691892243905436,5.697700533655136,5.703508823404836,5.709317113154538,5.715125402904238,5.720933692653939,5.72674198240364,5.732550272153341,5.738358561903041,5.744166851652742,5.749975141402444,5.755783431152143,5.761591720901845,5.767400010651545,5.773208300401246,5.779016590150947,5.784824879900648,5.790633169650349,5.796441459400049,5.80224974914975,5.808058038899451,5.813866328649152,5.819674618398852,5.825482908148554,5.831291197898254,5.837099487647954,5.842907777397656,5.848716067147357,5.854524356897058,5.860332646646758,5.866140936396458,5.871949226146159,5.87775751589586,5.883565805645562,5.8893740953952625,5.895182385144962,5.900990674894664,5.906798964644365,5.912607254394065,5.918415544143766,5.924223833893467,5.9300321236431675,5.935840413392869,5.941648703142569,5.9474569928922705,5.95326528264197,5.959073572391671,5.964881862141373,5.970690151891072,5.976498441640774,5.982306731390475,5.9881150211401755,5.993923310889876,5.999731600639576,6.005539890389278,6.011348180138978,6.0174701038314025,6.023654754312372,6.02983940479334,6.03602405527431,6.042208705755279,6.0483933562362475,6.054578006717216,6.060762657198185,6.066947307679155,6.073131958160125,6.079316608641093,6.085501259122062,6.09168590960303,6.097870560084,6.104055210564968,6.110239861045938,6.116424511526906,6.122609162007875,6.128793812488844,6.134978462969813,6.141163113450782,6.147347763931751,6.1535324144127195,6.159717064893688,6.165901715374658,6.172086365855627,6.178271016336596,6.1844556668175645,6.190640317298533,6.196824967779503,6.203009618260471,6.209194268741441,6.21537891922241,6.221563569703379,6.227748220184347,6.233932870665317,6.240117521146286,6.246302171627255,6.2524868221082235,6.258671472589192,6.264856123070162,6.271040773551129,6.277225424032099,6.283410074513068,6.2895947249940365,6.295779375475006,6.301964025955974,6.308148676436944,6.314333326917913,6.3205179773988815,6.32670262787985,6.332887278360819,6.339071928841789,6.345256579322758,6.351441229803727,6.357625880284695,6.363810530765664,6.369995181246633,6.376179831727602,6.382364482208571,6.3885491326895405,6.394733783170509,6.400918433651478,6.407103084132447,6.413287734613416,6.419472385094385,6.4256570355753535,6.431841686056323,6.438026336537292,6.444210987018261,6.45039563749923,6.456580287980199,6.462764938461167,6.468949588942137,6.475134239423105,6.481318889904075,6.487503540385044,6.4936881908660125,6.499872841346981,6.50605749182795,6.512242142308919,6.518426792789888,6.527075217879448,6.535946686728583,6.544683302109148,6.553419917489714,6.561782742239873,6.569323213945568,6.576863685651263,6.58440415735696,6.591944629062654,6.599485100768349,6.607025572474044,6.61456604417974,6.622106515885435,6.629646987591131,6.637187459296826,6.64472793100252,6.652268402708216,6.659808874413911,6.6673493461196065,6.674889817825302,6.682430289530997,6.689970761236693,6.697511232942388,6.705051704648082,6.712592176353779,6.720132648059473,6.727673119765168,6.735213591470863,6.742754063176559,6.750294534882254,6.75783500658795,6.765375478293644,6.772915949999339,6.780456421705035,6.787996893410731,6.795537365116426,6.803077836822121,6.810618308527817,6.818158780233512,6.825699251939206,6.833239723644903,6.840780195350598,6.848320667056293,6.855861138761988,6.863401610467683,6.870942082173379,6.878482553879073,6.886023025584768,6.893563497290463,6.901103968996159,6.908644440701854,6.91618491240755,6.923725384113245,6.93126585581894,6.938806327524635,6.946346799230331,6.9538872709360255,6.961427742641721,6.968968214347417,6.976508686053112,6.9840491577588075,6.991589629464502,6.999130101170198,7.006670572875892,7.014211044581588,7.021751516287282,7.029291987992978,7.036832459698674,7.044372931404369,7.051913403110064,7.05945387481576,7.066994346521454,7.074534818227151,7.082075289932845,7.089615761638542,7.0971562333442355,7.104696705049931,7.1122371767556265,7.119777648461322,7.127318120167017,7.134858591872712,7.142399063578408,7.149939535284103,7.157480006989798,7.166688385654638,7.177564671278624,7.188440956902609,7.199317242526593,7.21019352815058,7.221069813774564,7.231946099398549,7.242822385022536,7.2536986706465205,7.264574956270505,7.275451241894491,7.286327527518478,7.2972038131424615,7.308080098766447,7.318956384390432,7.329832670014417,7.340708955638402,7.351585241262388,7.362461526886373,7.373337812510359,7.384214098134343,7.39509038375833,7.405966669382314,7.416842955006299,7.427719240630285,7.43859552625427,7.449471811878255,7.460348097502241,7.471224383126226,7.482100668750212,7.492976954374196,7.5038532399981825,7.514729525622166,7.525605811246152,7.536482096870137,7.547358382494123,7.558234668118108,7.5691109537420935,7.579987239366078,7.590863524990064,7.601739810614049,7.612616096238034,7.623492381862019,7.6343686674860045,7.645244953109991,7.656121238733974,7.66699752435796,7.677873809981946,7.688750095605931,7.6996263812299155,7.710502666853903,7.721378952477886,7.732255238101872,7.7431315237258564,7.754007809349843,7.7648840949738265,7.775760380597813,7.786636666221799,7.797512951845783,7.808389237469768,7.819265523093755,7.830141808717739,7.841018094341725,7.851894379965709,7.862770665589695,7.873646951213679,7.884523236837666,7.895399522461651,7.906275808085635,7.917152093709621,7.928028379333607,7.938904664957591,7.949780950581577,7.960657236205562,7.9715335218295476,7.982409807453532,7.99259300222224,8.000985726195204,8.009378450168166,8.01777117414113,8.026163898114092,8.034556622087056,8.042949346060018,8.053686017022281,8.069110581963141,8.084535146904003,8.099959711844862,8.115384276785724,8.130808841726584,8.146233406667445,8.161657971608308,8.177082536549165,8.194576834107675,8.212884246985388,8.231191659863097,8.249499072740806,8.267806485618518,8.286113898496229,8.304421311373938,8.322728724251649,8.341036137129358,8.359343550007068,8.377650962884779,8.395958375762492,8.4142657886402,8.43257320151791,8.450880614395622,8.469188027273331,8.48749544015104,8.505802853028753,8.524110265906462,8.542417678784172,8.560725091661883,8.579032504539594,8.597339917417303,8.615647330295014,8.633954743172726,8.652262156050435,8.670569568928146,8.688876981805857,8.707184394683566,8.725491807561276,8.743799220438987,8.762106633316698,8.780414046194405,8.798721459072118,8.817028871949828,8.83533628482754,8.85364369770525,8.87195111058296,8.89025852346067,8.90856593633838,8.926873349216091,8.945180762093802,8.96348817497151,8.981795587849222,9.000103000726934,9.018410413604641,9.036717826482354,9.055025239360063,9.073332652237774,9.091640065115485,9.109947477993195,9.128254890870904,9.146562303748613,9.164869716626326,9.183177129504035,9.201484542381746,9.219791955259456,9.238099368137167,9.256406781014874,9.274714193892587,9.293021606770298,9.311329019648008,9.329636432525717,9.34794384540343,9.366251258281139,9.38455867115885,9.40286608403656,9.421173496914271,9.43948090979198,9.45778832266969,9.476095735547403,9.494403148425112,9.512710561302821,9.531017974180532,9.546100832926847,9.545060921016194,9.54402100910554,9.54298109719489,9.541941185284237,9.540901273373583,9.53986136146293,9.538821449552279,9.537781537641628,9.536741625730974,9.535701713820322,9.534661801909667,9.533621889999015,9.532581978088363,9.53154206617771,9.530502154267058,9.529462242356406,9.528422330445753,9.527382418535101,9.526342506624449,9.525302594713796,9.524262682803142,9.52322277089249,9.522182858981838,9.521142947071185,9.520103035160531,9.519063123249879,9.518023211339226,9.516983299428574,9.515943387517922,9.51490347560727,9.513863563696615,9.512823651785965,9.511783739875312,9.510743827964658,9.509703916054004,9.508664004143354,9.507624092232701,9.506584180322049,9.505544268411395,9.504504356500743,9.457582524085693,9.40696379593834,9.346911796070522,9.25718861953494,9.16746544299936,9.077742266463792,8.98801908992821,8.898295913392626,8.808572736857045,8.718849560321477,8.629126383785895,8.539403207250313,8.449680030714747,8.359956854179163,8.270233677643581,8.180510501108015,8.090787324572432,8.00106414803685,7.911340971501267,7.821617794965701,7.731894618430118,7.642171441894536,7.5524482653589695,7.462725088823388,7.373001912287805,7.283278735752237,7.193555559216655,7.103832382681073,7.014109206145507,6.924386029609924,6.834662853074342,6.744939676538759,6.655216500003193,6.565493323467609,6.475770146932026,6.38604697039646,6.2963237938608785,6.2066006173252966,6.11687744078973,6.027154264254147,5.937431087718565,5.847707911182981,5.757984734647415],[6.000991944576379,6.01006096028193,6.019129975987481,6.028198991693031,6.037268007398582,6.046337023104133,6.055406038809684,6.064475054515235,6.073544070220786,6.0826130859263365,6.091682101631887,6.100751117337438,6.109820133042989,6.11888914874854,6.127958164454091,6.137027180159642,6.1460961958651925,6.155165211570743,6.163147320729639,6.16895561047934,6.17476390022904,6.180572189978742,6.186380479728442,6.192188769478143,6.197997059227845,6.203805348977545,6.209613638727246,6.215421928476946,6.221230218226648,6.2270385079763475,6.232846797726049,6.238655087475749,6.2444633772254505,6.25027166697515,6.256079956724852,6.2618882464745536,6.267696536224253,6.273504825973955,6.279313115723655,6.285121405473356,6.290929695223056,6.296737984972758,6.302546274722458,6.308354564472159,6.314162854221859,6.31997114397156,6.325779433721261,6.331587723470961,6.337396013220662,6.3432043029703635,6.349012592720064,6.354820882469765,6.360629172219466,6.3664374619691655,6.372245751718868,6.378054041468568,6.383862331218269,6.389670620967969,6.39547891071767,6.4012872004673715,6.407095490217071,6.412903779966774,6.418712069716473,6.4245203594661735,6.430328649215875,6.436136938965577,6.4419452287152765,6.447753518464978,6.453561808214678,6.4593700979643796,6.465178387714081,6.470986677463781,6.476794967213483,6.482603256963182,6.488411546712884,6.494219836462584,6.500028126212285,6.505836415961985,6.511644705711687,6.517452995461387,6.523261285211088,6.529069574960788,6.53487786471049,6.5406861544601895,6.546808078152614,6.552992728633583,6.559177379114553,6.565362029595521,6.571546680076491,6.577731330557459,6.5839159810384285,6.590100631519397,6.596285282000366,6.602469932481336,6.608654582962304,6.614839233443273,6.621023883924242,6.627208534405211,6.63339318488618,6.639577835367149,6.645762485848118,6.6519471363290865,6.658131786810055,6.664316437291025,6.670501087771994,6.676685738252962,6.682870388733932,6.6890550392148995,6.695239689695869,6.701424340176839,6.707608990657807,6.713793641138777,6.719978291619745,6.726162942100714,6.732347592581682,6.738532243062652,6.744716893543621,6.75090154402459,6.757086194505559,6.763270844986527,6.769455495467497,6.775640145948465,6.781824796429434,6.788009446910404,6.794194097391372,6.800378747872342,6.80656339835331,6.81274804883428,6.818932699315248,6.825117349796217,6.831302000277185,6.837486650758155,6.843671301239125,6.849855951720093,6.8560406022010625,6.862225252682032,6.868409903163,6.87459455364397,6.880779204124938,6.8869638546059075,6.8931485050868755,6.899333155567845,6.905517806048813,6.911702456529783,6.917887107010753,6.9240717574917205,6.93025640797269,6.936441058453658,6.942625708934628,6.949795869759585,6.958937045545859,6.968078221332134,6.977219397118409,6.986360572904684,6.995501748690959,7.004642924477233,7.013784100263509,7.022925276049783,7.032066451836057,7.041207627622332,7.050348803408607,7.059489979194882,7.068631154981157,7.077772330767431,7.086913506553706,7.09605468233998,7.105195858126255,7.114067326975391,7.122803942355956,7.131540557736522,7.140277173117087,7.149013788497653,7.15775040387822,7.166487019258785,7.175223634639351,7.183960250019916,7.192696865400483,7.201433480781048,7.2101700961616135,7.2189067115421786,7.2276433269227445,7.2363799423033095,7.245116557683875,7.253853173064442,7.262589788445008,7.271326403825573,7.280063019206139,7.288799634586704,7.297536249967269,7.306272865347836,7.315009480728402,7.323746096108967,7.332482711489533,7.3412193268701,7.349955942250665,7.3586925576312305,7.367429173011796,7.3761657883923615,7.3849024037729265,7.393639019153492,7.402375634534058,7.411112249914624,7.41984886529519,7.428585480675755,7.437322096056322,7.446058711436887,7.454795326817451,7.463531942198018,7.472268557578583,7.481005172959149,7.489741788339715,7.498478403720282,7.5072150191008475,7.515951634481413,7.5246882498619785,7.5334248652425435,7.542161480623109,7.550898096003676,7.5585880905041405,7.566128562209835,7.573669033915531,7.581209505621226,7.588749977326922,7.596290449032616,7.603830920738312,7.611371392444006,7.618911864149703,7.626452335855397,7.633992807561094,7.641533279266788,7.649073750972483,7.656614222678178,7.664154694383873,7.671695166089569,7.679235637795264,7.68677610950096,7.694316581206655,7.70185705291235,7.709397524618046,7.716937996323741,7.724478468029437,7.732018939735131,7.739559411440826,7.747099883146522,7.754640354852217,7.762180826557913,7.769721298263607,7.777261769969304,7.784802241674997,7.792342713380693,7.801551092045534,7.812427377669519,7.823303663293505,7.834179948917489,7.845056234541476,7.85593252016546,7.866808805789445,7.877685091413431,7.888561377037416,7.8994376626614,7.910313948285387,7.921190233909373,7.932066519533357,7.942942805157342,7.953819090781328,7.964695376405313,7.975571662029298,7.986447947653284,7.9973242332772685,8.008200518901253,8.01907680452524,8.029953090149226,8.040829375773209,8.051705661397195,8.06258194702118,8.073458232645166,8.08433451826915,8.095210803893135,8.106087089517121,8.116963375141106,8.127839660765092,8.138715946389079,8.149592232013061,8.160468517637048,8.171344803261032,8.182221088885019,8.193097374509003,8.20397366013299,8.214849945756974,8.226043974104359,8.238153842572569,8.25026371104078,8.26237357950899,8.274483447977202,8.286593316445416,8.298703184913625,8.310813053381837,8.322922921850049,8.335032790318259,8.34714265878647,8.359252527254682,8.371362395722892,8.383472264191104,8.395582132659316,8.407692001127527,8.419801869595736,8.431911738063949,8.44402160653216,8.45613147500037,8.46824134346858,8.480351211936794,8.492461080405004,8.504570948873214,8.516680817341426,8.528790685809637,8.540900554277847,8.553010422746059,8.56512029121427,8.57723015968248,8.589340028150692,8.601449896618904,8.613559765087114,8.625669633555326,8.637779502023538,8.64988937049175,8.66199923895996,8.67410910742817,8.68621897589638,8.698328844364593,8.710438712832804,8.722548581301016,8.734658449769226,8.746768318237436,8.761189140729762,8.780231871270304,8.79927460181085,8.818317332351398,8.837360062891943,8.856402793432487,8.875445523973033,8.894488254513579,8.913530985054123,8.93257371559467,8.951616446135217,8.970659176675762,8.989701907216306,9.008744637756852,9.027787368297396,9.04683009883794,9.065872829378488,9.084915559919033,9.103958290459579,9.123001021000123,9.14204375154067,9.161086482081215,9.180129212621761,9.199171943162305,9.218214673702853,9.237257404243397,9.256300134783944,9.275342865324488,9.294385595865034,9.31342832640558,9.332471056946126,9.35151378748667,9.370556518027216,9.389599248567762,9.408641979108307,9.427684709648853,9.446727440189399,9.465770170729943,9.48481290127049,9.503855631811035,9.52289836235158,9.541941092892124,9.56098382343267,9.580026553973216,9.59906928451376,9.618112015054308,9.637154745594856,9.6561974761354,9.675240206675944,9.69428293721649,9.713325667757035,9.73236839829758,9.751411128838127,9.770453859378673,9.789496589919217,9.808539320459763,9.82758205100031,9.846624781540855,9.8656675120814,9.884710242621946,9.903752973162492,9.922795703703034,9.941838434243582,9.960881164784126,9.97992389532467,9.998966625865219,10.018009356405765,10.037052086946307,10.056094817486855,10.075137548027401,10.094180278567947,10.113223009108491,10.13226573964904,10.151308470189583,10.170351200730126,10.189393931270674,10.20843666181122,10.229817616957158,10.251567756245255,10.273317895533353,10.29506803482145,10.316818174109544,10.338568313397644,10.354119624134517,10.338676792115306,10.323233960096093,10.307791128076882,10.292348296057675,10.242395839387237,10.191777111239887,10.141158383092542,10.090539654945188,10.039920926797834,9.98930219865049,9.938683470503136,9.888064742355782,9.837446014208428,9.786827286061083,9.73620855791373,9.685589829766377,9.634971101619033,9.584352373471678,9.533733645324325,9.483114917176982,9.432496189029628,9.381877460882274,9.33125873273493,9.280640004587578,9.230021276440223,9.17940254829287,9.128783820145525,9.078165091998173,9.027546363850817,8.976927635703474,8.92630890755612,8.875690179408767,8.825071451261422,8.774452723114068,8.723833994966714,8.673215266819362,8.622596538672017,8.571977810524663,8.52135908237731,8.470740354229967,8.420121626082611,8.36950289793526,8.318884169787914,8.268265441640562,8.217646713493206,8.167027985345864,8.11640925719851,8.065790529051156,8.015171800903804,7.964553072756459,7.913934344609105,7.863315616461751,7.812696888314408,7.762078160167054,7.7114594320197,7.6608407038723545,7.610221975725002,7.559603247577648,7.508984519430295,7.458365791282951,7.407747063135598,7.357128334988244,7.3065096068409,7.255890878693546,7.205272150546192,7.154653422398848,7.104034694251495,7.053415966104142,7.002797237956797,6.952178509809444,6.90155978166209,6.850941053514736,6.800322325367392,6.749703597220039,6.699084869072685,6.648466140925341,6.597847412777987,6.547228684630634,6.485134483585859,6.372689298498307,6.2602441134107565,6.147798928323206,6.035353743235676],[6.476527942403858,6.485596958109409,6.494665973814961,6.503734989520511,6.512804005226061,6.521873020931613,6.530942036637163,6.540011052342715,6.549080068048266,6.558149083753816,6.567218099459367,6.576287115164917,6.585356130870468,6.59442514657602,6.603494162281571,6.612563177987122,6.6216321936926725,6.6307012093982225,6.639770225103773,6.648839240809324,6.657908256514875,6.666977272220426,6.676046287925978,6.6851153036315285,6.6941843193370785,6.70325333504263,6.712322350748181,6.721391366453732,6.730460382159283,6.739529397864834,6.7485984135703845,6.757667429275935,6.766736444981487,6.775805460687038,6.784874476392588,6.791226220795753,6.797034510545454,6.802842800295155,6.808651090044856,6.814459379794557,6.820267669544258,6.8260759592939575,6.831884249043659,6.83769253879336,6.8435008285430605,6.84930911829276,6.855117408042462,6.860925697792162,6.8667339875418625,6.872542277291565,6.878350567041264,6.884158856790966,6.889967146540666,6.895775436290366,6.901583726040069,6.907392015789768,6.913200305539471,6.91900859528917,6.9248168850388705,6.930625174788572,6.936433464538272,6.942241754287974,6.948050044037673,6.953858333787374,6.9596666235370765,6.965474913286777,6.971283203036478,6.977091492786179,6.982899782535879,6.988708072285581,6.994516362035281,7.000324651784982,7.006132941534682,7.011941231284384,7.017749521034084,7.023557810783785,7.029366100533485,7.035174390283187,7.0409826800328865,7.046790969782588,7.052599259532289,7.0584075492819895,7.06421583903169,7.070024128781391,7.076146052473815,7.082330702954785,7.088515353435753,7.0947000039167225,7.100884654397691,7.10706930487866,7.113253955359629,7.119438605840598,7.125623256321568,7.1318079068025355,7.1379925572835035,7.144177207764474,7.150361858245442,7.156546508726413,7.16273115920738,7.1689158096883485,7.175100460169319,7.181285110650288,7.187469761131257,7.193654411612226,7.1998390620931945,7.206023712574163,7.212208363055132,7.218393013536101,7.224577664017071,7.2307623144980395,7.236946964979008,7.243131615459977,7.249316265940946,7.255500916421915,7.261685566902884,7.267870217383853,7.274054867864823,7.280239518345791,7.286424168826759,7.292608819307729,7.298793469788697,7.304978120269666,7.311162770750636,7.317347421231604,7.323532071712574,7.329716722193543,7.3359013726745115,7.34208602315548,7.348270673636449,7.354455324117419,7.360639974598387,7.3668246250793565,7.373009275560325,7.381657697425986,7.390798873212261,7.399940048998536,7.409081224784811,7.418222400571086,7.42736357635736,7.436504752143635,7.44564592792991,7.454787103716184,7.463928279502459,7.473069455288733,7.482210631075008,7.4913518068612825,7.5004929826475575,7.5096341584338315,7.518775334220106,7.527916510006381,7.5370576857926554,7.54619886157893,7.555340037365205,7.56448121315148,7.573622388937755,7.582763564724029,7.591904740510303,7.601045916296579,7.610187092082852,7.619328267869128,7.628469443655403,7.637610619441678,7.646751795227953,7.655892971014227,7.665034146800502,7.674175322586776,7.683316498373051,7.692187967222187,7.700924582602752,7.709661197983317,7.718397813363883,7.727134428744448,7.735871044125015,7.744607659505581,7.753344274886146,7.762080890266711,7.770817505647278,7.779554121027844,7.78829073640841,7.797027351788975,7.80576396716954,7.814500582550107,7.823237197930672,7.831973813311238,7.8407104286918035,7.84944704407237,7.8581836594529335,7.8669202748335,7.875656890214067,7.884393505594631,7.893130120975198,7.901866736355764,7.910603351736329,7.919339967116894,7.92807658249746,7.936813197878027,7.945549813258591,7.954286428639158,7.963023044019723,7.9717596594002895,7.9804962747808545,7.989232890161421,7.997969505541986,8.006706120922551,8.015442736303116,8.024179351683683,8.032915967064248,8.041652582444813,8.05038919782538,8.059125813205945,8.067862428586512,8.076599043967077,8.085335659347642,8.094072274728209,8.102808890108774,8.11154550548934,8.120282120869906,8.129018736250472,8.137755351631037,8.146491967011602,8.155228582392168,8.163965197772734,8.1727018131533,8.181438428533866,8.190175043914431,8.198911659294998,8.207648274675563,8.216384890056128,8.225121505436695,8.23385812081726,8.242594736197825,8.251331351578392,8.260067966958957,8.268804582339524,8.277541197720089,8.286277813100654,8.29501442848122,8.303751043861785,8.31248765924235,8.321224274622917,8.329960890003482,8.338697505384049,8.348579540758513,8.359463811061985,8.370348081365456,8.38123235166893,8.392116621972402,8.403000892275875,8.413885162579348,8.424769432882819,8.436942868456777,8.450405469301222,8.463868070145667,8.47733067099011,8.490793271834555,8.504255872678998,8.517718473523441,8.531181074367886,8.544643675212331,8.558106276056773,8.57156887690122,8.585031477745664,8.598494078590107,8.61195667943455,8.625419280278996,8.638881881123439,8.652344481967882,8.665420594830685,8.677530463298897,8.689640331767107,8.701750200235319,8.713860068703532,8.72596993717174,8.738079805639952,8.750189674108164,8.762299542576375,8.774409411044585,8.786519279512797,8.798629147981007,8.810739016449219,8.82284888491743,8.834958753385642,8.84706862185385,8.859178490322062,8.871288358790276,8.883398227258485,8.895508095726697,8.907617964194909,8.919727832663119,8.93183770113133,8.94394756959954,8.956057438067752,8.968167306535962,8.980277175004176,8.992387043472387,9.004496911940597,9.016606780408807,9.02871664887702,9.04082651734523,9.052936385813442,9.065046254281654,9.077156122749864,9.089265991218076,9.101375859686286,9.113485728154497,9.12559559662271,9.13770546509092,9.149815333559133,9.161925202027343,9.174035070495552,9.186144938963764,9.198254807431976,9.210364675900188,9.2224745443684,9.23458441283661,9.24669428130482,9.258804149773031,9.270914018241243,9.28302388670945,9.295133755177662,9.307243623645876,9.319353492114086,9.331463360582298,9.34357322905051,9.35568309751872,9.36779296598693,9.379902834455141,9.392012702923353,9.404122571391564,9.416232439859776,9.428342308327986,9.4404521767962,9.452562045264408,9.466982867756734,9.486025598297278,9.505068328837824,9.524111059378368,9.543153789918913,9.562196520459459,9.581239251000005,9.600281981540553,9.619324712081093,9.638367442621641,9.657410173162187,9.676452903702733,9.695495634243278,9.714538364783824,9.733581095324368,9.752623825864914,9.77166655640546,9.790709286946004,9.80975201748655,9.828794748027097,9.847837478567644,9.866880209108189,9.885922939648733,9.904965670189279,9.924008400729825,9.94305113127037,9.962093861810915,9.98113659235146,10.000179322892004,10.019222053432552,10.038264783973098,10.057307514513642,10.076350245054188,10.095392975594734,10.114435706135279,10.133478436675825,10.15252116721637,10.171563897756915,10.190606628297461,10.209649358838007,10.228692089378551,10.247734819919096,10.267762071625317,10.289512210913415,10.31126235020151,10.333012489489606,10.354762628777705,10.3765127680658,10.398262907353896,10.420013046641994,10.44176318593009,10.463513325218186,10.485263464506286,10.507013603794384,10.528763743082475,10.550513882370574,10.572264021658672,10.594014160946768,10.615764300234863,10.63751443952296,10.659264578811054,10.681014718099153,10.702764857387251,10.724514996675346,10.74626513596344,10.76801527525154,10.789765414539637,10.811515553827732,10.83326569311583,10.855015832403929,10.876765971692024,10.898516110980118,10.920266250268217,10.942016389556313,10.96376652884441,10.985516668132506,11.007266807420605,11.029016946708698,11.050767085996796,11.072517225284894,11.09426736457299,11.116017503861086,11.137767643149182,11.15331895388606,11.137876121866848,11.122433289847635,11.106990457828424,11.091547625809216,11.076104793790005,11.06066196177079,11.045219129751583,11.029776297732372,11.014333465713161,10.998890633693954,10.983447801674739,10.968004969655528,10.952562137636317,10.937119305617108,10.921676473597898,10.906233641578686,10.890790809559476,10.875347977540265,10.859905145521054,10.844462313501845,10.829019481482632,10.813576649463421,10.798133817444214,10.782690985425003,10.767248153405792,10.737082128826419,10.686463400679076,10.635844672531721,10.585225944384367,10.534607216237024,10.48398848808967,10.433369759942316,10.382751031794971,10.332132303647619,10.281513575500265,10.23089484735291,10.180276119205567,10.129657391058213,10.079038662910861,10.028419934763516,9.977801206616162,9.927182478468808,9.876563750321463,9.82594502217411,9.775326294026758,9.724707565879413,9.674088837732059,9.623470109584707,9.572851381437353,9.522232653290008,9.471613925142654,9.420995196995301,9.370376468847956,9.319757740700602,9.26913901255325,9.218520284405905,9.167901556258553,9.071029989849077,8.958584804761527,8.846139619673997,8.733694434586447,8.621249249498895,8.508804064411365,8.396358879323815,8.283913694236265,8.171468509148733,8.059023324061185,7.946578138973633,7.834132953886103,7.721687768798552,7.609242583711001,7.4967973986234515,7.38435221353592,7.27190702844837,7.15946184336082,7.047016658273289,6.9345714731857395,6.822126288098188,6.7096811030106585,6.597235917923108,6.484790732835556,6.372345547748007,6.259900362660477],[6.952063940231346,6.961132955936897,6.970201971642448,6.979270987347999,6.98834000305355,6.997409018759101,7.006478034464652,7.015547050170203,7.024616065875753,7.0336850815813055,7.042754097286856,7.051823112992405,7.060892128697957,7.069961144403508,7.07903016010906,7.088099175814611,7.09716819152016,7.106237207225712,7.115306222931263,7.124375238636814,7.133444254342365,7.142513270047916,7.1515822857534666,7.160651301459017,7.169720317164568,7.178789332870119,7.18785834857567,7.19692736428122,7.205996379986772,7.2150653956923225,7.224134411397873,7.233203427103423,7.242272442808975,7.251341458514526,7.260410474220076,7.269479489925628,7.278548505631178,7.2876175213367285,7.296686537042279,7.30575555274783,7.314824568453382,7.323893584158932,7.332962599864483,7.342031615570034,7.351100631275585,7.360169646981136,7.369238662686687,7.378307678392238,7.38737669409779,7.3964457098033405,7.405514725508891,7.413496831112178,7.419305120861878,7.425113410611578,7.43092170036128,7.43672999011098,7.442538279860681,7.448346569610382,7.454154859360083,7.459963149109784,7.465771438859484,7.471579728609186,7.4773880183588854,7.483196308108586,7.489004597858288,7.4948128876079885,7.500621177357689,7.50642946710739,7.5122377568570915,7.518046046606791,7.523854336356493,7.529662626106193,7.535470915855894,7.541279205605594,7.547087495355295,7.552895785104996,7.558704074854696,7.564512364604397,7.570320654354099,7.5761289441037984,7.5819372338535,7.5877455236032,7.5935538133529015,7.599362103102601,7.605484026795027,7.611668677275996,7.617853327756965,7.624037978237933,7.6302226287189026,7.6364072791998705,7.64259192968084,7.648776580161809,7.654961230642778,7.661145881123747,7.667330531604716,7.673515182085684,7.679699832566653,7.685884483047623,7.692069133528592,7.698253784009561,7.70443843449053,7.710623084971499,7.716807735452468,7.722992385933438,7.729177036414406,7.735361686895375,7.741546337376343,7.747730987857311,7.753915638338281,7.76010028881925,7.7662849393002205,7.772469589781188,7.778654240262156,7.784838890743126,7.791023541224094,7.7972081917050655,7.804378349306123,7.8135195250923974,7.822660700878673,7.831801876664948,7.840943052451222,7.850084228237497,7.859225404023771,7.868366579810046,7.877507755596321,7.886648931382595,7.895790107168871,7.904931282955145,7.91407245874142,7.923213634527695,7.932354810313969,7.941495986100245,7.950637161886519,7.959778337672793,7.968919513459069,7.978060689245343,7.987201865031617,7.996343040817893,8.005484216604167,8.014625392390442,8.023766568176717,8.03290774396299,8.042048919749266,8.05119009553554,8.060331271321814,8.06947244710809,8.078613622894364,8.087754798680638,8.096895974466914,8.106037150253188,8.115178326039462,8.124319501825738,8.133460677612012,8.142601853398288,8.151743029184562,8.160884204970838,8.17002538075711,8.179166556543386,8.18830773232966,8.197448908115936,8.20659008390221,8.215731259688484,8.22487243547476,8.234013611261034,8.24315478704731,8.252295962833584,8.261437138619858,8.270308607468994,8.27904522284956,8.287781838230124,8.296518453610691,8.305255068991256,8.313991684371821,8.322728299752388,8.331464915132953,8.34020153051352,8.348938145894085,8.357674761274652,8.366411376655217,8.375147992035782,8.383884607416348,8.392621222796913,8.40135783817748,8.410094453558045,8.41883106893861,8.427567684319175,8.436304299699742,8.445040915080305,8.453777530460874,8.462514145841439,8.471250761222004,8.479987376602573,8.488723991983136,8.497460607363703,8.506197222744268,8.514933838124833,8.5236704535054,8.532407068885965,8.54114368426653,8.549880299647096,8.558616915027663,8.567353530408228,8.576090145788793,8.584826761169358,8.593563376549923,8.60229999193049,8.611036607311055,8.61977322269162,8.628509838072187,8.637246453452754,8.645983068833319,8.654719684213884,8.66345629959445,8.672192914975016,8.68092953035558,8.689666145736147,8.698402761116714,8.70892908992525,8.719813360228722,8.730697630532196,8.74158190083567,8.752466171139142,8.763350441442613,8.774234711746086,8.785118982049559,8.796003252353032,8.806887522656504,8.817771792959975,8.828656063263448,8.839540333566923,8.850424603870394,8.861308874173867,8.87219314447734,8.883077414780812,8.893961685084285,8.904845955387758,8.915730225691231,8.926614495994702,8.937498766298175,8.948383036601648,8.95926730690512,8.970151577208592,8.981035847512064,8.991920117815537,9.00280438811901,9.013688658422483,9.024572928725956,9.035457199029427,9.046341469332901,9.057225739636372,9.06939917521033,9.082861776054775,9.09632437689922,9.109786977743664,9.123249578588108,9.136712179432552,9.150174780276995,9.16363738112144,9.177099981965885,9.190562582810326,9.204025183654773,9.217487784499218,9.230950385343661,9.244412986188104,9.257875587032547,9.271338187876992,9.284800788721435,9.29826338956588,9.311725990410324,9.325188591254769,9.338651192099213,9.352113792943658,9.3655763937881,9.379038994632545,9.39250159547699,9.405964196321433,9.419426797165876,9.432889398010321,9.446351998854764,9.459814599699207,9.473277200543652,9.486739801388097,9.50020240223254,9.513665003076985,9.52712760392143,9.540590204765873,9.554052805610317,9.56751540645476,9.580978007299205,9.594440608143648,9.607903208988093,9.621365809832536,9.63482841067698,9.648291011521426,9.661753612365871,9.675216213210314,9.688678814054757,9.702141414899202,9.715604015743645,9.729066616588089,9.742529217432535,9.755991818276978,9.769454419121422,9.782917019965867,9.796379620810312,9.809842221654755,9.8233048224992,9.836767423343643,9.850230024188086,9.86369262503253,9.877155225876974,9.890617826721419,9.904080427565862,9.917543028410307,9.93100562925475,9.944468230099194,9.957930830943639,9.971393431788083,9.984856032632527,9.998318633476972,10.011781234321417,10.025147219141072,10.037257087609284,10.049366956077495,10.061476824545705,10.073586693013915,10.085696561482127,10.097806429950339,10.109916298418549,10.12202616688676,10.134136035354972,10.146245903823184,10.158355772291394,10.172776594783718,10.191819325324262,10.210862055864807,10.229904786405354,10.2489475169459,10.267990247486445,10.28703297802699,10.306075708567537,10.327456665581586,10.349206804869684,10.370956944157781,10.392707083445877,10.414457222733974,10.43620736202207,10.457957501310167,10.479707640598264,10.50145777988636,10.523207919174457,10.544958058462553,10.56670819775065,10.588458337038748,10.610208476326843,10.63195861561494,10.653708754903038,10.675458894191133,10.69720903347923,10.718959172767327,10.740709312055424,10.762459451343519,10.784209590631617,10.805959729919715,10.827709869207808,10.849460008495907,10.871210147784005,10.8929602870721,10.914710426360196,10.936460565648293,10.95821070493639,10.979960844224486,11.001710983512583,11.023461122800677,11.045211262088776,11.066961401376874,11.08871154066497,11.110461679953067,11.132211819241162,11.15396195852926,11.175712097817357,11.197462237105452,11.21921237639355,11.240962515681646,11.262712654969741,11.284462794257841,11.306212933545938,11.327963072834033,11.34971321212213,11.371463351410226,11.393213490698322,11.41496362998642,11.436713769274517,11.458463908562614,11.480214047850708,11.501964187138807,11.523714326426902,11.545464465714998,11.567214605003096,11.588964744291193,11.610714883579288,11.632465022867386,11.654215162155483,11.67596530144358,11.697715440731674,11.719465580019772,11.741215719307867,11.762965858595965,11.784715997884062,11.80646613717216,11.828216276460255,11.849966415748352,11.87171655503645,11.893466694324546,11.915216833612643,11.93696697290074,11.952518283637614,11.937075451618403,11.92163261959919,11.90618978757998,11.890746955560772,11.87530412354156,11.859861291522348,11.844418459503139,11.82897562748393,11.813532795464717,11.798089963445507,11.782647131426296,11.767204299407084,11.751761467387873,11.736318635368665,11.720875803349454,11.705432971330241,11.689990139311034,11.674547307291823,11.65910447527261,11.6436616432534,11.62821881123419,11.612775979214979,11.59733314719577,11.581890315176558,11.566447483157347,11.551004651138136,11.535561819118925,11.520118987099714,11.504676155080501,11.457231061167082,11.386927258636462,11.316623456105843,11.246319653575236,11.176015851044616,11.105712048513997,11.035408245983376,10.96510444345277,10.894800640922151,10.824496838391532,10.754193035860924,10.683889233330305,10.613585430799684,10.543281628269078,10.47297782573846,10.40267402320784,10.332370220677234,10.262066418146613,10.191762615615994,10.121458813085374,10.05115501055477,9.980851208024148,9.91054740549353,9.840243602962921,9.745357349624065,9.632912164536512,9.520466979448983,9.408021794361431,9.295576609273882,9.183131424186332,9.070686239098801,8.95824105401125,8.8457958689237,8.73335068383617,8.62090549874862,8.508460313661068,8.396015128573538,8.28356994348599,8.171124758398438,8.058679573310908,7.946234388223356,7.833789203135806,7.7213440180482555,7.608898832960724,7.496453647873175,7.384008462785624,7.271563277698094,7.1591180926105435,7.046672907522993,6.934227722435463,6.821782537347913,6.709337352260362,6.596892167172811,6.484446982085281],[7.427599938058826,7.436668953764378,7.445737969469928,7.454806985175479,7.463876000881029,7.47294501658658,7.482014032292131,7.491083047997682,7.500152063703233,7.509221079408785,7.518290095114335,7.527359110819885,7.536428126525437,7.545497142230988,7.55456615793654,7.56363517364209,7.57270418934764,7.581773205053191,7.590842220758742,7.599911236464293,7.608980252169844,7.618049267875395,7.627118283580945,7.636187299286497,7.645256314992047,7.654325330697598,7.663394346403149,7.6724633621087,7.681532377814251,7.690601393519802,7.6996704092253525,7.708739424930904,7.717808440636455,7.726877456342006,7.735946472047557,7.745015487753108,7.7540845034586585,7.763153519164209,7.77222253486976,7.781291550575311,7.790360566280862,7.799429581986413,7.808498597691964,7.8175676133975145,7.826636629103064,7.835705644808614,7.844774660514167,7.853843676219718,7.862912691925268,7.871981707630819,7.88105072333637,7.89011973904192,7.899188754747471,7.908257770453023,7.917326786158574,7.926395801864125,7.935464817569676,7.944533833275226,7.953602848980777,7.962671864686328,7.971740880391879,7.98080989609743,7.989878911802981,7.9989479275085325,8.008016943214082,8.017085958919633,8.026154974625184,8.035223990330735,8.041575731178291,8.047384020927993,8.053192310677693,8.059000600427394,8.064808890177094,8.070617179926796,8.076425469676495,8.082233759426197,8.088042049175897,8.093850338925598,8.0996586286753,8.105466918425,8.111275208174701,8.117083497924401,8.122891787674103,8.128700077423803,8.134822001116227,8.141006651597197,8.147191302078165,8.153375952559134,8.159560603040102,8.165745253521072,8.171929904002042,8.17811455448301,8.18429920496398,8.190483855444947,8.196668505925917,8.202853156406885,8.209037806887855,8.215222457368824,8.221407107849792,8.227591758330762,8.236240176972526,8.2453813527588,8.254522528545076,8.26366370433135,8.272804880117624,8.281946055903898,8.291087231690174,8.300228407476448,8.309369583262724,8.318510759048998,8.327651934835272,8.336793110621546,8.345934286407822,8.355075462194096,8.36421663798037,8.373357813766646,8.38249898955292,8.391640165339194,8.40078134112547,8.409922516911744,8.41906369269802,8.428204868484293,8.437346044270567,8.446487220056843,8.455628395843117,8.464769571629391,8.473910747415667,8.483051923201941,8.492193098988215,8.501334274774491,8.510475450560765,8.519616626347041,8.528757802133315,8.537898977919589,8.547040153705865,8.556181329492139,8.565322505278413,8.574463681064689,8.583604856850963,8.592746032637237,8.601887208423511,8.611028384209787,8.62016955999606,8.629310735782337,8.63845191156861,8.647593087354885,8.65673426314116,8.665875438927435,8.67501661471371,8.684157790499984,8.693298966286259,8.702440142072534,8.711581317858808,8.720722493645084,8.729863669431358,8.739004845217632,8.748146021003906,8.757287196790182,8.766428372576456,8.775569548362732,8.784710724149004,8.79385189993528,8.802993075721554,8.81213425150783,8.821275427294104,8.83041660308038,8.839557778866654,8.84842924771579,8.857165863096355,8.86590247847692,8.874639093857487,8.883375709238052,8.89211232461862,8.900848939999184,8.909585555379751,8.918322170760316,8.927058786140881,8.935795401521448,8.944532016902013,8.95326863228258,8.962005247663145,8.97074186304371,8.979478478424275,8.988215093804842,8.996951709185407,9.005688324565973,9.014424939946538,9.023161555327103,9.03189817070767,9.040634786088235,9.0493714014688,9.058394368788505,9.069278639091978,9.080162909395451,9.091047179698922,9.101931450002397,9.112815720305868,9.123699990609342,9.134584260912813,9.145468531216286,9.15635280151976,9.167237071823232,9.178121342126703,9.189005612430176,9.199889882733649,9.210774153037121,9.221658423340594,9.232542693644065,9.243426963947538,9.254311234251013,9.265195504554484,9.276079774857957,9.28696404516143,9.2978483154649,9.308732585768375,9.319616856071846,9.33050112637532,9.341385396678792,9.352269666982263,9.363153937285738,9.374038207589209,9.384922477892683,9.395806748196154,9.406691018499627,9.4175752888031,9.428459559106571,9.439343829410046,9.450228099713518,9.46111237001699,9.471996640320462,9.482880910623935,9.493765180927408,9.504649451230879,9.515533721534354,9.526417991837825,9.5373022621413,9.54818653244477,9.559070802748243,9.569955073051716,9.580839343355187,9.591723613658662,9.602607883962133,9.613492154265606,9.624376424569078,9.635260694872551,9.646144965176022,9.657029235479495,9.66791350578297,9.67879777608644,9.689682046389914,9.701855481963872,9.715318082808317,9.728780683652761,9.742243284497203,9.755705885341648,9.769168486186093,9.782631087030534,9.796093687874981,9.809556288719428,9.823018889563869,9.836481490408314,9.849944091252757,9.8634066920972,9.876869292941645,9.89033189378609,9.903794494630532,9.917257095474977,9.930719696319422,9.944182297163866,9.957644898008308,9.971107498852753,9.984570099697198,9.998032700541641,10.011495301386086,10.024957902230529,10.038420503074972,10.051883103919417,10.065345704763862,10.078808305608305,10.09227090645275,10.105733507297195,10.11919610814164,10.132658708986082,10.146121309830527,10.15958391067497,10.173046511519413,10.186509112363858,10.199971713208303,10.213434314052748,10.226896914897189,10.240359515741634,10.253822116586079,10.267284717430522,10.280747318274967,10.29420991911941,10.307672519963853,10.321135120808297,10.334597721652743,10.348060322497187,10.361522923341631,10.374985524186076,10.38844812503052,10.401910725874963,10.415373326719408,10.428835927563853,10.442298528408296,10.455761129252739,10.469223730097184,10.482686330941627,10.496427512486411,10.512211569719083,10.527995626951753,10.543779684184424,10.559563741417096,10.575347798649766,10.591131855882436,10.606915913115106,10.622699970347778,10.638484027580448,10.654268084813118,10.67005214204579,10.685836199278462,10.70162025651113,10.717404313743803,10.733188370976473,10.748972428209143,10.764756485441815,10.780540542674487,10.796324599907155,10.812108657139827,10.8278927143725,10.843676771605168,10.85946082883784,10.877402686203745,10.899660143836112,10.921917601468476,10.944175059100846,10.966432516733214,10.988689974365583,11.01094743199795,11.03320488963032,11.055462347262687,11.077719804895054,11.099977262527423,11.12223472015979,11.14449217779216,11.166749635424528,11.189007093056894,11.211264550689261,11.233522008321632,11.255779465953998,11.278036923586365,11.300294381218734,11.322551838851103,11.34480929648347,11.367066754115836,11.389324211748207,11.411581669380574,11.433839127012941,11.456096584645309,11.478354042277676,11.500611499910045,11.522868957542414,11.545126415174781,11.567383872807149,11.589641330439518,11.611898788071887,11.634156245704254,11.656413703336622,11.678671160968989,11.700928618601356,11.723186076233723,11.745443533866094,11.767700991498462,11.789958449130825,11.812215906763196,11.834473364395567,11.856730822027934,11.878988279660298,11.901245737292669,11.923503194925036,11.945760652557404,11.968018110189773,11.990275567822142,12.012533025454507,12.034790483086876,12.057047940719247,12.079305398351611,12.101562855983978,12.12382031361635,12.146077771248716,12.168335228881084,12.190592686513453,12.21285014414582,12.235107601778186,12.257365059410555,12.279622517042924,12.301879974675288,12.324137432307658,12.346394889940028,12.368652347572395,12.390909805204762,12.413167262837133,12.435424720469499,12.457682178101866,12.480958033818109,12.50543052053233,12.529903007246553,12.55437549396078,12.578847980675004,12.603320467389224,12.627792954103448,12.652265440817674,12.676737927531896,12.70121041424612,12.725682900960344,12.740215839792596,12.705051039215018,12.669886238637439,12.63472143805986,12.599556637482287,12.56439183690471,12.529227036327129,12.494062235749556,12.445929402325694,12.375625599795073,12.305321797264467,12.235017994733848,12.164714192203228,12.094410389672609,12.024106587142,11.953802784611383,11.883498982080763,11.813195179550156,11.742891377019538,11.672587574488917,11.60228377195831,11.53197996942769,11.461676166897071,11.391372364366465,11.321068561835844,11.250764759305223,11.180460956774606,11.110157154244,11.03985335171338,10.96954954918276,10.899245746652154,10.828941944121535,10.758638141590914,10.688334339060308,10.61803053652969,10.54772673399907,10.47742293146845,10.407119128937843,10.336815326407223,10.266511523876604,10.196207721345996,10.125903918815377,10.055600116284758,9.985296313754151,9.91499251122353,9.844688708692912,9.774384906162304,9.704081103631687,9.633777301101066,9.563473498570447,9.49316969603984,9.422865893509222,9.352562090978601,9.282258288447993,9.211954485917374,9.141650683386754,9.071346880856147,9.001043078325528,8.93073927579491,8.860435473264289,8.790131670733683,8.719827868203064,8.649524065672445,8.579220263141838,8.508916460611218,8.438612658080597,8.36830885554999,8.298005053019372,8.227701250488753,8.157397447958147,8.087093645427526,8.016789842896907,7.946486040366287,7.87618223783568,7.80587843530506,7.735574632774441,7.61578792719968,7.483445708003835,7.351103488807989,7.218761269612166,7.086419050416319,6.954076831220473,6.821734612024627,6.689392392828805],[7.90304362292272,7.913747046050547,7.922816061756097,7.931885077461649,7.9409540931672,7.950023108872751,7.959092124578301,7.9681611402838515,7.977230155989403,7.986299171694954,7.995368187400505,8.004437203106056,8.013506218811607,8.022575234517157,8.031644250222708,8.04071326592826,8.04978228163381,8.05885129733936,8.067920313044912,8.076989328750463,8.086058344456013,8.095127360161564,8.104196375867115,8.113265391572666,8.122334407278217,8.131403422983768,8.140472438689319,8.149541454394868,8.15861047010042,8.167679485805971,8.176748501511522,8.185817517217073,8.194886532922624,8.203955548628176,8.213024564333725,8.222093580039276,8.231162595744827,8.240231611450378,8.249300627155929,8.25836964286148,8.26743865856703,8.276507674272581,8.285576689978132,8.294645705683685,8.303714721389234,8.312783737094787,8.321852752800336,8.330921768505887,8.339990784211437,8.349059799916988,8.358128815622539,8.367197831328092,8.37626684703364,8.385335862739193,8.394404878444742,8.403473894150295,8.412542909855844,8.421611925561395,8.430680941266946,8.439749956972497,8.44881897267805,8.4578879883836,8.46695700408915,8.476026019794702,8.485095035500253,8.494164051205804,8.503233066911353,8.512302082616905,8.521371098322456,8.530440114028007,8.539509129733558,8.548578145439109,8.55764716114466,8.56671617685021,8.575785192555761,8.584854208261312,8.593923223966861,8.602992239672414,8.612061255377965,8.621130271083516,8.630199286789066,8.639268302494619,8.64833731820017,8.65740633390572,8.668003111553539,8.677144287339814,8.686285463126087,8.695426638912362,8.704567814698636,8.713708990484912,8.722850166271186,8.73199134205746,8.741132517843736,8.75027369363001,8.759414869416284,8.76855604520256,8.777697220988834,8.786838396775108,8.795979572561384,8.805120748347658,8.814261924133932,8.82340309992021,8.832544275706482,8.841685451492758,8.850826627279034,8.859967803065306,8.869108978851582,8.878250154637856,8.887391330424132,8.896532506210406,8.905673681996682,8.914814857782956,8.92395603356923,8.933097209355505,8.942238385141778,8.951379560928054,8.960520736714328,8.969661912500602,8.978803088286877,8.987944264073153,8.997085439859427,9.006226615645701,9.015367791431975,9.024508967218251,9.033650143004525,9.0427913187908,9.051932494577075,9.06107367036335,9.070214846149623,9.079356021935899,9.088497197722173,9.097638373508449,9.106779549294723,9.115920725080997,9.125061900867273,9.134203076653547,9.143344252439821,9.152485428226097,9.16162660401237,9.170767779798645,9.17990895558492,9.189050131371195,9.198191307157469,9.207332482943745,9.216473658730019,9.225614834516293,9.234756010302569,9.243897186088843,9.253038361875118,9.262179537661392,9.271320713447667,9.280461889233942,9.289603065020216,9.298744240806492,9.307885416592768,9.31702659237904,9.326167768165314,9.33530894395159,9.344450119737864,9.35359129552414,9.362732471310414,9.371873647096688,9.381014822882964,9.390155998669238,9.399297174455514,9.408438350241788,9.417579526028062,9.428338094006243,9.439905358080372,9.451396728865662,9.462280999169137,9.473165269472606,9.48404953977608,9.494933810079553,9.505818080383026,9.516702350686499,9.527586620989972,9.538470891293445,9.549355161596916,9.560239431900388,9.571123702203861,9.582007972507334,9.592892242810807,9.60377651311428,9.614660783417753,9.625545053721225,9.636429324024697,9.647313594328168,9.658197864631642,9.669082134935113,9.679966405238586,9.690850675542059,9.701734945845532,9.712619216149005,9.723503486452476,9.73438775675595,9.745272027059421,9.756156297362896,9.767040567666367,9.77792483796984,9.788809108273313,9.799693378576785,9.810577648880258,9.82146191918373,9.8323461894872,9.843230459790675,9.854114730094146,9.86499900039762,9.875883270701092,9.886767541004566,9.897651811308037,9.90853608161151,9.919420351914983,9.930304622218454,9.941188892521929,9.9520731628254,9.962957433128874,9.973841703432345,9.984725973735816,9.995610244039291,10.006494514342762,10.017378784646237,10.028263054949708,10.039147325253179,10.050031595556653,10.060915865860125,10.0718001361636,10.08268440646707,10.093568676770543,10.104452947074016,10.115337217377487,10.126221487680962,10.137105757984434,10.147990028287905,10.158874298591378,10.169758568894851,10.180642839198324,10.191527109501797,10.20241137980527,10.21329565010874,10.224179920412215,10.235064190715686,10.24594846101916,10.256832731322632,10.267717001626103,10.278601271929576,10.28948554223305,10.300369812536522,10.311254082839994,10.322138353143467,10.334311788717425,10.34777438956187,10.361236990406313,10.374699591250756,10.388162192095201,10.401624792939646,10.41508739378409,10.428549994628533,10.442012595472978,10.45547519631742,10.468937797161868,10.482400398006313,10.495862998850754,10.509325599695199,10.522788200539644,10.536250801384085,10.54971340222853,10.563176003072975,10.576638603917418,10.590101204761861,10.603563805606306,10.617026406450751,10.630489007295195,10.64395160813964,10.657414208984084,10.670876809828528,10.68433941067297,10.697802011517414,10.711264612361859,10.725841516120212,10.741625573352886,10.757409630585558,10.773193687818226,10.788977745050897,10.80476180228357,10.82054585951624,10.836329916748909,10.85211397398158,10.867898031214251,10.883682088446921,10.899466145679593,10.915250202912263,10.931034260144934,10.946818317377605,10.962602374610277,10.978386431842946,10.994170489075618,11.00995454630829,11.025738603540958,11.04152266077363,11.0573067180063,11.07309077523897,11.088874832471642,11.104658889704313,11.120442946936985,11.136227004169653,11.152011061402325,11.167795118634997,11.183579175867667,11.199363233100339,11.215147290333011,11.23093134756568,11.246715404798348,11.262499462031021,11.27828351926369,11.29406757649636,11.309851633729034,11.325635690961704,11.341419748194372,11.357203805427044,11.372987862659716,11.388771919892386,11.404555977125058,11.420340034357729,11.436124091590399,11.45190814882307,11.467692206055741,11.483476263288411,11.49926032052108,11.515044377753753,11.530828434986425,11.546612492219094,11.562396549451764,11.580338406817669,11.602595864450036,11.624853322082403,11.647110779714772,11.66936823734714,11.691625694979507,11.713883152611874,11.736140610244245,11.758398067876612,11.78065552550898,11.802912983141347,11.825170440773716,11.847427898406082,11.869685356038453,11.891942813670818,11.914200271303187,11.936457728935554,11.958715186567924,11.98097264420029,12.003230101832658,12.025487559465029,12.047745017097395,12.070002474729764,12.092259932362131,12.1145173899945,12.136774847626867,12.159032305259235,12.181289762891602,12.20354722052397,12.225804678156338,12.248062135788707,12.270319593421073,12.292577051053442,12.314834508685813,12.337091966318178,12.359349423950547,12.381606881582915,12.403864339215282,12.42612179684765,12.448767519415668,12.473240006129892,12.497712492844114,12.52218497955834,12.546657466272563,12.571129952986787,12.595602439701008,12.620074926415235,12.644547413129459,12.66901989984368,12.693492386557905,12.717964873272127,12.74243735998635,12.766909846700575,12.791382333414798,12.815854820129019,12.840327306843246,12.86479979355747,12.889272280271694,12.913744766985914,12.93821725370014,12.962689740414362,12.987162227128586,13.01163471384281,13.036107200557034,13.060579687271256,13.085052173985481,13.109524660699705,13.133997147413925,13.158469634128153,13.182942120842377,13.207414607556599,13.23188709427082,13.256359580985047,13.280832067699269,13.305304554413492,13.329777041127716,13.354249527841942,13.378722014556164,13.403194501270388,13.427666987984612,13.452139474698834,13.476611961413058,13.501084448127283,13.515617386959534,13.480452586381954,13.445287785804375,13.410122985226797,13.374958184649227,13.339793384071648,13.304628583494067,13.269463782916496,13.234298982338917,13.199134181761337,13.163969381183765,13.128804580606186,13.093639780028607,13.058474979451027,13.023310178873455,12.988145378295876,12.952980577718296,12.917815777140724,12.882650976563145,12.847486175985566,12.812321375407993,12.777156574830414,12.741991774252835,12.706826973675263,12.671662173097683,12.636497372520106,12.601332571942526,12.566167771364952,12.531002970787375,12.495838170209794,12.460673369632222,12.398108491478512,12.327804688947893,12.257500886417287,12.187197083886666,12.116893281356047,12.046589478825425,11.97628567629482,11.9059818737642,11.83567807123358,11.765374268702976,11.695070466172355,11.624766663641736,11.554462861111128,11.48415905858051,11.413855256049889,11.343551453519282,11.273247650988663,11.202943848458043,11.132640045927424,11.062336243396818,10.992032440866199,10.921728638335578,10.827421916668102,10.695079697472256,10.56273747827641,10.430395259080587,10.29805303988474,10.165710820688894,10.033368601493049,9.901026382297228,9.76868416310138,9.636341943905533,9.503999724709711,9.371657505513864,9.23931528631802,9.106973067122198,8.97463084792635,8.842288628730504,8.709946409534682,8.577604190338835,8.445261971142989,8.312919751947142,8.180577532751322,8.048235313555473,7.915893094359628,7.783550875163805,7.6512086559679595,7.518866436772113,7.386524217576291,7.254181998380444,7.121839779184598,6.989497559988752,6.85715534079293],[8.375533283698635,8.387871124144752,8.400208964590867,8.412546805036984,8.4248846454831,8.437222485929217,8.449560326375332,8.461898166821449,8.474236007267566,8.486573847713682,8.498911688159799,8.511249528605914,8.52358736905203,8.535925209498147,8.548263049944264,8.560600890390381,8.572938730836496,8.585276566873961,8.594345582579514,8.603414598285065,8.612483613990616,8.621552629696168,8.630621645401718,8.63969066110727,8.64875967681282,8.657828692518372,8.666897708223921,8.675966723929472,8.685035739635023,8.694104755340575,8.703173771046124,8.712242786751677,8.721311802457226,8.730380818162779,8.73944983386833,8.74851884957388,8.757587865279431,8.766656880984982,8.775725896690531,8.784794912396082,8.793863928101633,8.802932943807185,8.812001959512735,8.821070975218287,8.830139990923838,8.839209006629387,8.84827802233494,8.85734703804049,8.86641605374604,8.875485069451592,8.884554085157141,8.893623100862694,8.902692116568243,8.911761132273794,8.920830147979347,8.929899163684896,8.938968179390448,8.948037195095997,8.957106210801548,8.9661752265071,8.97524424221265,8.984313257918203,8.993382273623753,9.002451289329304,9.011520305034853,9.020589320740406,9.029658336445957,9.038727352151508,9.047796367857059,9.05686538356261,9.06593439926816,9.07500341497371,9.084072430679262,9.093141446384813,9.102210462090364,9.111279477795915,9.120348493501465,9.129417509207016,9.138486524912567,9.147555540618118,9.15662455632367,9.16569357202922,9.17476258773477,9.183831603440321,9.195406807521085,9.20748324927689,9.219559691032696,9.231636132788502,9.243712574544306,9.25578901630011,9.267865458055915,9.279941899811721,9.292018341567527,9.304094783323333,9.316171225079138,9.328247666834944,9.34032410859075,9.352400550346555,9.364476992102361,9.376553433858165,9.38862987561397,9.398260258436387,9.407401434222662,9.416542610008936,9.425683785795211,9.434824961581485,9.44396613736776,9.453107313154034,9.46224848894031,9.471389664726583,9.48053084051286,9.489672016299133,9.498813192085407,9.507954367871683,9.517095543657957,9.526236719444233,9.535377895230507,9.54451907101678,9.553660246803057,9.562801422589331,9.571942598375607,9.581083774161879,9.590224949948155,9.599366125734429,9.608507301520703,9.617648477306979,9.626789653093255,9.635930828879527,9.645072004665803,9.654213180452079,9.663354356238353,9.672495532024627,9.681636707810902,9.690777883597175,9.699919059383452,9.709060235169726,9.718201410956,9.727342586742274,9.73648376252855,9.745624938314824,9.754766114101098,9.763907289887374,9.773048465673648,9.782189641459922,9.791330817246198,9.800471993032472,9.809613168818748,9.818754344605022,9.827895520391296,9.83703669617757,9.846177871963846,9.85531904775012,9.864460223536396,9.87360139932267,9.882742575108946,9.89188375089522,9.901024926681494,9.91016610246777,9.919307278254042,9.928448454040318,9.937589629826592,9.946730805612868,9.955871981399142,9.965013157185417,9.974154332971692,9.983295508757966,9.992436684544241,10.003195252522419,10.014762516596548,10.026329780670679,10.03789704474481,10.04946430881894,10.061031572893071,10.072598836967199,10.084166101041331,10.095733365115462,10.107300629189591,10.118867893263724,10.130435157337853,10.142002421411984,10.153569685486115,10.165136949560244,10.176704213634375,10.188271477708504,10.199838741782635,10.211406005856766,10.222973269930895,10.234540534005026,10.246107798079157,10.257675062153286,10.269242326227419,10.280809590301548,10.292376854375679,10.30394411844981,10.315511382523939,10.327078646598071,10.3386459106722,10.35021317474633,10.36178043882046,10.373347702894591,10.384914966968722,10.396482231042853,10.408049495116982,10.419616759191111,10.431184023265242,10.442751287339373,10.454318551413504,10.465885815487635,10.477453079561764,10.489020343635897,10.500587607710026,10.512154871784157,10.523722135858286,10.535289399932417,10.546856664006548,10.558423928080675,10.569991192154808,10.581558456228938,10.593125720303068,10.604692984377198,10.616260248451328,10.62782751252546,10.63939477659959,10.65096204067372,10.662529304747851,10.67409656882198,10.685663832896111,10.697231096970242,10.708798361044373,10.7203656251185,10.731932889192635,10.743500153266762,10.755067417340893,10.766634681415022,10.778201945489155,10.789769209563286,10.801336473637415,10.812903737711546,10.824471001785678,10.836038265859807,10.847605529933936,10.859172794008067,10.870740058082196,10.882307322156327,10.893874586230458,10.905441850304587,10.917009114378718,10.92857637845285,10.94014364252698,10.952778989217196,10.96914207207775,10.986682113049147,11.00247647976308,11.018270846477014,11.03406521319095,11.049859579904883,11.065653946618818,11.081448313332752,11.097242680046687,11.113037046760619,11.128831413474554,11.14462578018849,11.160420146902421,11.176214513616355,11.19200888033029,11.20780043547675,11.22358449270942,11.23936854994209,11.255152607174763,11.270936664407431,11.286720721640105,11.302504778872777,11.318288836105445,11.334072893338115,11.349856950570786,11.365641007803458,11.381425065036128,11.397209122268798,11.41299317950147,11.428777236734138,11.444561293966812,11.460345351199482,11.476129408432152,11.491913465664823,11.507697522897494,11.523481580130166,11.539265637362835,11.555049694595507,11.570833751828175,11.586617809060847,11.602401866293519,11.618185923526188,11.63396998075886,11.649754037991531,11.665538095224203,11.681322152456872,11.697106209689544,11.712890266922214,11.728674324154884,11.744458381387556,11.760242438620226,11.776026495852896,11.791810553085567,11.807594610318239,11.823378667550909,11.839162724783579,11.85494678201625,11.870730839248923,11.886514896481593,11.902298953714263,11.918083010946935,11.933867068179602,11.949651125412275,11.965435182644946,11.981219239877616,11.997003297110286,12.012787354342958,12.028571411575628,12.044355468808298,12.06013952604097,12.075923583273642,12.091707640506312,12.107491697738983,12.123275754971655,12.139059812204325,12.154843869436993,12.170627926669667,12.186411983902337,12.202196041135005,12.21798009836768,12.233764155600351,12.24954821283302,12.265332270065691,12.283274127431595,12.305531585063962,12.327789042696327,12.350046500328698,12.372303957961064,12.394561415593433,12.416818873225802,12.441049491727453,12.465521978441673,12.489994465155899,12.514466951870125,12.538939438584348,12.56341192529857,12.587884412012794,12.612356898727018,12.636829385441239,12.661301872155464,12.685774358869688,12.71024684558391,12.734719332298134,12.759191819012361,12.783664305726584,12.808136792440806,12.832609279155031,12.857081765869253,12.881554252583475,12.906026739297701,12.930499226011925,12.954971712726147,12.979444199440373,13.003916686154597,13.028389172868815,13.05286165958304,13.077334146297266,13.10180663301149,13.126279119725712,13.150751606439938,13.17522409315416,13.199696579868382,13.224169066582608,13.24864155329683,13.273114040011052,13.297586526725278,13.322059013439501,13.346531500153725,13.371003986867947,13.395476473582171,13.419948960296395,13.444421447010617,13.468893933724843,13.493366420439065,13.517838907153287,13.542311393867514,13.566783880581738,13.591256367295959,13.615728854010184,13.640201340724408,13.664673827438632,13.689146314152854,13.713618800867078,13.7380912875813,13.762563774295522,13.78703626100975,13.811508747723972,13.835981234438194,13.86045372115242,13.884926207866643,13.909398694580863,13.933871181295089,13.958343668009315,13.982816154723537,14.00728864143776,14.031761128151985,14.056233614866205,14.08070610158043,14.105178588294656,14.12965107500888,14.154123561723102,14.178596048437324,14.20306853515155,14.227541021865774,14.252013508579996,14.276485995294221,14.291018934126473,14.255854133548894,14.220689332971315,14.185524532393737,14.150359731816165,14.115194931238584,14.080030130661006,14.044865330083434,14.009700529505857,13.974535728928275,13.939370928350703,13.904206127773124,13.869041327195545,13.833876526617965,13.798711726040393,13.763546925462814,13.728382124885234,13.693217324307664,13.658052523730086,13.622887723152505,13.587722922574933,13.530865888808613,13.439747062007523,13.34862823520645,13.257509408405356,13.166390581604265,13.075271754803175,12.9841529280021,12.89303410120101,12.80191527439992,12.710796447598844,12.619677620797752,12.528558793996663,12.437439967195589,12.346321140394497,12.255202313593404,12.164083486792315,12.072964659991241,11.981845833190151,11.89072700638906,11.799608179587985,11.708489352786893,11.617370525985802,11.526251699184728,11.435132872383637,11.344014045582547,11.252895218781472,11.16177639198038,11.07065756517929,10.9795387383782,10.888419911577126,10.797301084776034,10.706182257974943,10.615063431173867,10.523944604372776,10.432825777571686,10.341706950770611,10.250588123969521,10.159469297168428,10.068350470367339,9.977231643566265,9.886112816765174,9.794993989964082,9.671762672673838,9.539420453477991,9.407078234282144,9.274736015086322,9.142393795890476,9.010051576694629,8.877709357498807,8.74536713830296,8.613024919107115,8.480682699911267,8.348340480715446,8.2159982615196,8.083656042323753,7.951313823127931,7.818971603932084,7.6866293847362375,7.554287165540417,7.421944946344571,7.289602727148724,7.157260507952877,7.024918288757055],[8.848022944474543,8.860360784920658,8.872698625366773,8.885036465812892,8.897374306259007,8.909712146705125,8.92204998715124,8.934387827597355,8.946725668043474,8.959063508489589,8.971401348935705,8.983739189381822,8.996077029827937,9.008414870274056,9.02075271072017,9.033090551166287,9.045428391612404,9.05776623205852,9.070104072504638,9.082441912950753,9.09477975339687,9.107117593842986,9.119455434289101,9.13179327473522,9.144131115181334,9.156468955627451,9.168806796073568,9.181144636519683,9.1934824769658,9.205820317411916,9.218158157858033,9.23049599830415,9.242833838750265,9.255171679196382,9.265875103402921,9.274944119108472,9.284013134814023,9.293082150519574,9.302151166225125,9.311220181930675,9.320289197636225,9.329358213341777,9.338427229047328,9.347496244752879,9.35656526045843,9.36563427616398,9.374703291869531,9.383772307575082,9.392841323280631,9.401910338986184,9.410979354691735,9.420048370397286,9.429117386102837,9.438186401808386,9.447255417513938,9.45632443321949,9.465393448925042,9.47446246463059,9.48353148033614,9.492600496041693,9.501669511747242,9.510738527452794,9.519807543158345,9.528876558863896,9.537945574569447,9.547014590274998,9.556083605980549,9.565152621686101,9.57422163739165,9.583290653097201,9.592359668802752,9.601428684508303,9.610497700213854,9.619566715919404,9.628635731624955,9.637704747330506,9.646773763036057,9.655842778741608,9.664911794447159,9.67398081015271,9.683049825858262,9.692118841563813,9.701187857269362,9.710256872974915,9.721832077055677,9.733908518811482,9.745984960567288,9.758061402323094,9.7701378440789,9.782214285834703,9.794290727590509,9.806367169346315,9.818443611102118,9.830520052857924,9.84259649461373,9.854672936369536,9.866749378125341,9.878825819881147,9.890902261636953,9.902978703392758,9.915055145148564,9.92713158690437,9.939208028660175,9.95128447041598,9.963360912171783,9.975437353927589,9.987513795683395,9.9995902374392,10.011666679195006,10.023743120950812,10.035819562706617,10.047896004462423,10.059972446218229,10.072048887974034,10.08412532972984,10.096201771485644,10.108278213241448,10.119376229532946,10.128517405319222,10.137658581105498,10.146799756891774,10.155940932678046,10.16508210846432,10.174223284250596,10.18336446003687,10.192505635823146,10.201646811609422,10.210787987395694,10.21992916318197,10.229070338968246,10.238211514754518,10.247352690540794,10.25649386632707,10.265635042113342,10.274776217899618,10.283917393685892,10.293058569472167,10.302199745258442,10.311340921044717,10.320482096830991,10.329623272617265,10.33876444840354,10.347905624189815,10.35704679997609,10.366187975762365,10.37532915154864,10.384470327334913,10.393611503121189,10.402752678907463,10.411893854693737,10.421035030480013,10.430176206266287,10.439317382052561,10.448458557838835,10.457599733625113,10.466740909411385,10.47588208519766,10.485023260983935,10.494164436770209,10.503305612556485,10.512446788342759,10.521587964129035,10.530729139915309,10.539870315701585,10.549011491487859,10.558152667274133,10.567293843060407,10.578052411038586,10.589619675112717,10.601186939186848,10.612754203260975,10.624321467335108,10.635888731409239,10.64745599548337,10.659023259557499,10.67059052363163,10.68215778770576,10.693725051779891,10.70529231585402,10.71685957992815,10.728426844002282,10.739994108076413,10.751561372150542,10.763128636224673,10.774695900298802,10.786263164372933,10.797830428447064,10.809397692521193,10.820964956595324,10.832532220669455,10.844099484743586,10.855666748817715,10.867234012891846,10.878801276965977,10.890368541040107,10.901935805114238,10.913503069188366,10.925070333262498,10.936637597336627,10.948204861410757,10.959772125484887,10.97133938955902,10.98290665363315,10.99447391770728,11.00604118178141,11.01760844585554,11.029175709929671,11.040742974003802,11.052310238077931,11.063877502152062,11.075444766226191,11.087012030300324,11.098579294374453,11.110146558448584,11.121713822522715,11.133281086596844,11.144848350670976,11.156415614745105,11.167982878819235,11.179550142893365,11.191117406967496,11.202684671041627,11.214251935115756,11.225819199189887,11.237386463264016,11.24895372733815,11.260520991412278,11.272088255486409,11.28365551956054,11.29764376824254,11.311845632695828,11.32604749714912,11.340249361602408,11.354451226055696,11.368653090508987,11.382854954962276,11.397056819415564,11.411258683868853,11.425460548322143,11.439662412775432,11.453864277228723,11.468066141682009,11.482268006135298,11.496469870588589,11.510671735041878,11.524873599495166,11.539075463948453,11.553277328401744,11.567479192855032,11.581681057308323,11.598044140168877,11.616568441436701,11.635092742704522,11.653617043972345,11.67214134524017,11.690665646507991,11.709189947775814,11.727714249043638,11.74623855031146,11.764762851579281,11.783287152847105,11.801811454114928,11.820335755382752,11.838860056650574,11.857384357918395,11.87590865918622,11.89443296045404,11.912957261721864,11.931481562989687,11.950005864257509,11.968530165525332,11.987054466793158,12.005578768060976,12.0241030693288,12.042627370596623,12.061151671864446,12.07967597313227,12.096714596833799,12.112508963547734,12.128303330261666,12.144097696975603,12.159892063689536,12.175686430403468,12.191480797117404,12.207275163831337,12.223069530545272,12.238863897259206,12.254658263973141,12.270452630687075,12.286246997401006,12.302041364114944,12.317835730828875,12.333630097542812,12.349424464256746,12.36521883097068,12.381013197684613,12.396807564398546,12.412601931112482,12.428396297826415,12.444190664540349,12.459985031254284,12.47577939796822,12.491573764682153,12.507368131396088,12.523162498110022,12.538956864823954,12.554751231537889,12.570545598251824,12.58633996496576,12.602134331679691,12.617928698393627,12.633723065107558,12.649517431821494,12.665311798535429,12.68110616524936,12.696900531963296,12.712694898677231,12.728489265391165,12.744283632105098,12.760077998819034,12.775872365532967,12.791666732246902,12.807461098960836,12.823255465674771,12.839049832388705,12.854844199102638,12.870638565816572,12.886432932530505,12.902227299244439,12.918021665958374,12.93381603267231,12.949610399386243,12.965404766100177,12.984185323610182,13.008938262712324,13.033691201814467,13.05844414091661,13.083197080018753,13.107950019120894,13.132702958223042,13.157455897325185,13.182208836427325,13.20696177552947,13.231714714631615,13.256467653733756,13.281220592835899,13.305973531938044,13.330726471040187,13.355479410142326,13.380232349244473,13.404985288346616,13.429738227448755,13.454491166550902,13.479244105653047,13.503997044755188,13.528749983857331,13.553502922959476,13.578255862061617,13.603008801163758,13.627761740265903,13.652514679368046,13.67726761847019,13.702020557572334,13.726773496674479,13.751526435776617,13.776279374878762,13.801032313980905,13.825785253083048,13.85053819218519,13.875291131287337,13.900044070389479,13.92479700949162,13.949549948593766,13.974302887695906,13.999055826798049,14.023808765900194,14.048561705002337,14.07331464410448,14.098067583206621,14.12282052230877,14.14757346141091,14.172326400513054,14.197079339615197,14.22183227871734,14.246585217819481,14.271338156921626,14.29609109602377,14.320844035125909,14.345596974228055,14.370349913330202,14.395102852432341,14.419855791534484,14.444608730636629,14.46936166973877,14.494114608840913,14.518867547943056,14.5436204870452,14.568373426147343,14.593126365249486,14.617879304351632,14.642632243453772,14.668174769006587,14.694235353308095,14.720295937609599,14.746356521911103,14.772417106212608,14.798477690514112,14.824538274815618,14.850598859117124,14.876659443418628,14.90272002772013,14.928780612021637,14.954841196323144,14.980901780624649,15.006962364926151,15.033022949227657,15.044842992584535,14.985460331218302,14.92607766985207,14.866695008485836,14.807312347119613,14.747929685753382,14.688547024387145,14.629164363020925,14.56978170165469,14.510399040288458,14.451016378922237,14.391633717556003,14.319688770037391,14.2285699432363,14.137451116435226,14.046332289634133,13.955213462833044,13.86409463603197,13.772975809230878,13.681856982429787,13.590738155628713,13.499619328827622,13.40850050202653,13.317381675225455,13.226262848424366,13.135144021623274,13.044025194822185,12.95290636802111,12.861787541220018,12.770668714418928,12.679549887617853,12.588431060816761,12.497312234015672,12.406193407214596,12.315074580413505,12.223955753612413,12.132836926811324,12.041718100010248,11.950599273209159,11.859480446408067,11.768361619606992,11.6772427928059,11.586123966004811,11.495005139203737,11.403886312402644,11.312767485601555,11.221648658800481,11.13052983199939,11.039411005198298,10.948292178397207,10.857173351596131,10.766054524795042,10.67493569799395,10.583816871192877,10.492698044391785,10.401579217590694,10.31046039078962,10.219341563988529,10.12822273718744,10.037103910386346,9.945985083585274,9.854866256784181,9.763747429983091,9.672628603182016,9.581509776380926,9.490390949579833,9.399272122778761,9.308153295977668,9.217034469176578,9.125915642375503,9.034796815574413,8.94367798877332,8.807898483651439,8.658841351674443,8.50978421969742,8.360727087720397,8.2116699557434,8.062612823766376,7.9135556917893535,7.764498559812358,7.615441427835334,7.466384295858311,7.317327163881289,7.168270031904292],[9.320512605250457,9.332850445696574,9.345188286142688,9.357526126588805,9.369863967034924,9.382201807481039,9.394539647927155,9.406877488373272,9.419215328819389,9.431553169265504,9.44389100971162,9.456228850157737,9.468566690603852,9.480904531049969,9.493242371496088,9.505580211942203,9.51791805238832,9.530255892834436,9.542593733280553,9.554931573726668,9.567269414172785,9.579607254618901,9.591945095065016,9.604282935511133,9.616620775957248,9.628958616403366,9.641296456849483,9.653634297295598,9.665972137741715,9.678309978187832,9.690647818633948,9.702985659080065,9.71532349952618,9.727661339972297,9.739999180418414,9.75233702086453,9.764674861310645,9.77701270175676,9.789350542202879,9.801688382648994,9.81402622309511,9.826364063541227,9.838701903987344,9.85103974443346,9.863377584879576,9.875715425325692,9.88805326577181,9.900391106217926,9.912728946664041,9.925066787110158,9.937404624226337,9.946473639931888,9.955542655637439,9.96461167134299,9.97368068704854,9.982749702754091,9.991818718459642,10.000887734165193,10.009956749870744,10.019025765576295,10.028094781281846,10.037163796987397,10.04623281269295,10.055301828398498,10.06437084410405,10.0734398598096,10.082508875515149,10.091577891220702,10.100646906926253,10.109715922631803,10.118784938337354,10.127853954042905,10.136922969748456,10.145991985454009,10.15506100115956,10.164130016865109,10.17319903257066,10.18226804827621,10.191337063981761,10.200406079687312,10.209475095392863,10.218544111098415,10.227613126803965,10.236682142509517,10.248257346590279,10.260333788346085,10.27241023010189,10.284486671857694,10.296563113613502,10.308639555369306,10.320715997125111,10.332792438880917,10.34486888063672,10.356945322392527,10.369021764148332,10.381098205904138,10.393174647659944,10.40525108941575,10.417327531171555,10.42940397292736,10.441480414683166,10.453556856438972,10.465633298194776,10.477709739950582,10.489786181706387,10.501862623462193,10.513939065217999,10.526015506973803,10.538091948729608,10.550168390485414,10.56224483224122,10.574321273997024,10.58639771575283,10.598474157508635,10.61055059926444,10.622627041020246,10.63470348277605,10.646779924531856,10.658856366287662,10.670932808043467,10.683009249799273,10.695085691555079,10.707162133310883,10.71923857506669,10.731315016822494,10.7433914585783,10.755467900334105,10.76754434208991,10.779620783845715,10.79169722560152,10.803773667357326,10.815850109113132,10.827926550868938,10.840002992624743,10.849633376415795,10.858774552202071,10.867915727988345,10.87705690377462,10.886198079560895,10.89533925534717,10.904480431133443,10.913621606919719,10.922762782705993,10.931903958492267,10.941045134278543,10.950186310064819,10.959327485851091,10.968468661637367,10.97760983742364,10.986751013209915,10.99589218899619,11.005033364782465,11.01417454056874,11.023315716355015,11.03245689214129,11.041598067927564,11.050739243713839,11.059880419500113,11.069021595286388,11.078162771072662,11.087303946858938,11.096445122645212,11.105586298431486,11.114727474217762,11.123868650004036,11.133009825790312,11.142151001576584,11.152909569554765,11.164476833628894,11.176044097703025,11.187611361777154,11.199178625851285,11.210745889925416,11.222313153999545,11.233880418073678,11.245447682147807,11.257014946221938,11.268582210296069,11.280149474370198,11.291716738444329,11.30328400251846,11.31485126659259,11.32641853066672,11.33798579474085,11.349553058814982,11.361120322889112,11.372687586963242,11.384254851037372,11.395822115111503,11.407389379185632,11.418956643259763,11.430523907333892,11.442091171408023,11.453658435482154,11.465225699556285,11.476792963630416,11.488360227704545,11.499927491778676,11.511494755852807,11.523062019926936,11.534629284001067,11.546196548075198,11.557763812149329,11.569331076223458,11.580898340297587,11.592465604371718,11.604032868445849,11.61560013251998,11.62830668281461,11.6425085472679,11.656710411721189,11.67091227617448,11.685114140627766,11.699316005081055,11.713517869534346,11.727719733987634,11.741921598440925,11.75612346289421,11.7703253273475,11.784527191800791,11.798729056254079,11.81293092070737,11.827132785160659,11.841334649613946,11.855536514067236,11.869738378520525,11.883940242973816,11.898142107427105,11.912343971880393,11.926545836333682,11.94074770078697,11.954949565240259,11.969151429693548,11.983353294146838,11.997555158600129,12.011757023053416,12.025958887506704,12.040160751959995,12.054362616413282,12.068564480866574,12.082766345319861,12.09696820977315,12.11117007422644,12.125371938679729,12.139573803133018,12.153775667586306,12.167977532039597,12.182179396492884,12.196381260946175,12.210583125399463,12.226946208260019,12.245470509527841,12.263994810795666,12.282519112063486,12.30104341333131,12.319567714599133,12.338092015866955,12.35661631713478,12.375140618402602,12.393664919670424,12.412189220938245,12.43071352220607,12.449237823473894,12.467762124741714,12.486286426009539,12.50481072727736,12.523335028545183,12.541859329813008,12.560383631080828,12.578907932348649,12.597432233616473,12.615956534884297,12.63448083615212,12.653005137419942,12.671529438687765,12.690053739955587,12.708578041223412,12.727102342491232,12.745626643759055,12.764150945026877,12.782675246294701,12.801199547562524,12.819723848830346,12.838248150098169,12.856772451365993,12.875296752633815,12.893821053901636,12.91234535516946,12.930869656437281,12.949393957705105,12.967918258972928,12.98644256024075,13.00496686150857,13.023491162776395,13.042015464044221,13.06053976531204,13.079064066579864,13.097588367847687,13.116112669115509,13.13463697038333,13.153161271651157,13.171685572918978,13.190209874186799,13.206747080618467,13.2225414473324,13.238335814046334,13.254130180760267,13.269924547474202,13.285718914188134,13.301513280902071,13.317307647616005,13.333102014329938,13.348896381043872,13.364690747757807,13.380485114471739,13.396279481185672,13.412073847899608,13.427868214613543,13.443662581327475,13.459456948041414,13.475251314755345,13.49104568146928,13.506840048183214,13.522634414897148,13.538428781611083,13.554223148325015,13.57001751503895,13.585811881752885,13.601606248466819,13.617400615180753,13.633194981894688,13.64898934860862,13.664783715322555,13.68356427283256,13.708317211934702,13.733070151036845,13.757823090138992,13.782576029241133,13.807328968343274,13.832081907445417,13.856834846547564,13.881587785649703,13.906340724751846,13.931093663853993,13.955846602956136,13.980599542058279,14.005352481160422,14.030105420262563,14.054858359364706,14.079611298466851,14.104364237568992,14.129117176671135,14.15387011577328,14.178623054875425,14.203375993977566,14.22812893307971,14.252881872181852,14.277634811283995,14.302387750386137,14.327140689488283,14.351893628590425,14.376646567692568,14.401399506794712,14.426152445896856,14.450905384998997,14.47565832410114,14.500411263203286,14.525164202305426,14.549917141407569,14.574670080509714,14.600351946372006,14.626412530673509,14.652473114975017,14.678533699276521,14.704594283578022,14.73065486787953,14.756715452181034,14.78277603648254,14.808836620784044,14.834897205085547,14.860957789387054,14.887018373688559,14.913078957990063,14.939139542291567,14.965200126593071,14.99126071089458,15.017321295196085,15.043381879497586,15.069442463799092,15.095503048100596,15.121563632402102,15.147624216703607,15.173684801005113,15.199745385306617,15.225805969608121,15.251866553909625,15.277927138211131,15.303987722512634,15.330048306814138,15.356108891115646,15.382169475417149,15.408230059718653,15.434290644020159,15.460351228321667,15.486411812623167,15.512472396924675,15.53853298122618,15.56459356552768,15.59065414982919,15.616714734130694,15.642775318432195,15.668835902733703,15.694896487035207,15.720957071336711,15.747017655638219,15.773078239939721,15.7848982832966,15.725515621930368,15.666132960564134,15.606750299197904,15.547367637831679,15.487984976465448,15.428602315099212,15.36921965373299,15.309836992366755,15.250454331000523,15.191071669634301,15.131689008268065,15.072306346901833,15.0129236855356,14.953541024169377,14.894158362803143,14.83477570143691,14.77539304007069,14.716010378704457,14.656627717338221,14.597245055972,14.537862394605767,14.478479733239533,14.41909707187331,14.359714410507076,14.300331749140845,14.24094908777461,14.181566426408388,14.122183765042156,14.06280110367592,14.003418442309698,13.944035780943466,13.884653119577232,13.82527045821101,13.765887796844778,13.706505135478542,13.625634398958807,13.534515572157732,13.443396745356642,13.35227791855555,13.261159091754477,13.170040264953386,13.078921438152294,12.987802611351219,12.89668378455013,12.805564957749038,12.714446130947962,12.623327304146873,12.503842933613468,12.354785801636444,12.20572866965945,12.056671537682426,11.907614405705402,11.758557273728407,11.609500141751381,11.460443009774359,11.311385877797365,11.162328745820341,11.013271613843319,10.864214481866295,10.7151573498893,10.566100217912275,10.417043085935251,10.267985953958256,10.118928821981232,9.969871690004208,9.820814558027212,9.67175742605019,9.522700294073166,9.373643162096172,9.224586030119148,9.075528898142124,8.9264717661651,8.777414634188105,8.628357502211083,8.479300370234059,8.330243238257063,8.18118610628004,8.032128974303017,7.88307184232602,7.734014710348996,7.584957578371974,7.43590044639495,7.286843314417954],[9.793002266026365,9.805340106472482,9.817677946918597,9.830015787364712,9.842353627810828,9.854691468256947,9.867029308703062,9.879367149149179,9.891704989595295,9.904042830041412,9.916380670487527,9.928718510933644,9.94105635137976,9.953394191825877,9.965732032271994,9.978069872718109,9.990407713164226,10.002745553610342,10.01508339405646,10.027421234502576,10.039759074948691,10.052096915394808,10.064434755840924,10.07677259628704,10.089110436733158,10.101448277179273,10.11378611762539,10.126123958071506,10.138461798517621,10.150799638963738,10.163137479409855,10.17547531985597,10.187813160302088,10.200151000748203,10.212488841194318,10.224826681640437,10.237164522086552,10.249502362532668,10.261840202978785,10.2741780434249,10.286515883871017,10.298853724317134,10.31119156476325,10.323529405209367,10.335867245655482,10.3482050861016,10.360542926547716,10.372880766993832,10.385218607439949,10.397556447886064,10.409894288332183,10.422232128778298,10.434569969224414,10.446907809670531,10.459245650116648,10.471583490562763,10.48392133100888,10.496259171454996,10.508597011901111,10.520934852347228,10.533272692793345,10.545610533239461,10.557948373685578,10.570286214131693,10.58262405457781,10.594961895023927,10.607299735470043,10.618003160755293,10.627072176460844,10.636141192166395,10.645210207871946,10.654279223577497,10.663348239283048,10.6724172549886,10.681486270694151,10.6905552863997,10.699624302105251,10.708693317810802,10.717762333516353,10.726831349221904,10.735900364927454,10.744969380633007,10.754038396338558,10.763107412044109,10.774682616124872,10.786759057880676,10.798835499636482,10.810911941392288,10.822988383148093,10.835064824903899,10.847141266659705,10.859217708415509,10.871294150171314,10.88337059192712,10.895447033682926,10.90752347543873,10.919599917194535,10.931676358950341,10.943752800706147,10.955829242461952,10.967905684217758,10.979982125973564,10.99205856772937,11.004135009485173,11.016211451240979,11.028287892996785,11.04036433475259,11.052440776508394,11.064517218264202,11.076593660020006,11.088670101775811,11.100746543531617,11.112822985287421,11.124899427043228,11.136975868799032,11.149052310554838,11.161128752310642,11.173205194066448,11.185281635822255,11.197358077578059,11.209434519333866,11.22151096108967,11.233587402845476,11.245663844601282,11.257740286357087,11.269816728112891,11.281893169868697,11.293969611624503,11.306046053380308,11.318122495136114,11.330198936891918,11.342275378647726,11.35435182040353,11.366428262159335,11.37850470391514,11.390581145670946,11.40265758742675,11.414734029182556,11.426810470938362,11.438886912694167,11.450963354449973,11.463039796205779,11.475116237961583,11.487192679717388,11.499269121473196,11.511345563228998,11.523422004984806,11.535498446740611,11.547574888496415,11.55965133025222,11.570749347512358,11.579890523298632,11.589031699084908,11.598172874871182,11.607314050657457,11.616455226443732,11.625596402230006,11.634737578016281,11.643878753802555,11.653019929588831,11.662161105375105,11.67130228116138,11.680443456947653,11.68958463273393,11.698725808520203,11.707866984306479,11.717008160092751,11.727766728070932,11.739333992145061,11.750901256219192,11.762468520293321,11.774035784367452,11.785603048441583,11.797170312515714,11.808737576589843,11.820304840663976,11.831872104738105,11.843439368812236,11.855006632886365,11.866573896960496,11.878141161034627,11.889708425108756,11.901275689182887,11.912842953257018,11.924410217331147,11.93597748140528,11.947544745479409,11.95911200955354,11.973171461839957,11.987373326293246,12.001575190746536,12.015777055199825,12.029978919653114,12.044180784106404,12.058382648559691,12.072584513012982,12.086786377466272,12.100988241919561,12.11519010637285,12.129391970826138,12.143593835279427,12.157795699732716,12.171997564186004,12.186199428639295,12.200401293092582,12.21460315754587,12.228805021999161,12.243006886452449,12.257208750905738,12.271410615359027,12.285612479812318,12.29981434426561,12.314016208718897,12.328218073172184,12.342419937625476,12.356621802078761,12.370823666532054,12.385025530985342,12.39922739543863,12.41342925989192,12.427631124345208,12.441832988798499,12.456034853251786,12.470236717705074,12.484438582158365,12.498640446611653,12.512842311064944,12.527044175518233,12.54124603997152,12.555447904424812,12.569649768878099,12.583851633331388,12.598053497784678,12.612255362237967,12.626457226691254,12.640659091144546,12.654860955597833,12.669062820051124,12.683264684504412,12.697466548957701,12.71166841341099,12.72587027786428,12.740072142317569,12.754274006770856,12.768475871224148,12.782677735677435,12.796879600130724,12.811081464584014,12.825283329037305,12.839485193490592,12.855848276351148,12.87437257761897,12.892896878886793,12.911421180154615,12.92994548142244,12.94846978269026,12.966994083958083,12.985518385225907,13.004042686493731,13.022566987761552,13.041091289029374,13.0596155902972,13.078139891565023,13.096664192832844,13.115188494100668,13.133712795368488,13.152237096636311,13.170761397904135,13.189285699171958,13.207810000439778,13.2263343017076,13.244858602975427,13.263382904243247,13.281907205511068,13.300431506778896,13.318955808046717,13.337480109314537,13.356004410582361,13.374528711850184,13.393053013118006,13.411577314385829,13.430101615653655,13.448625916921472,13.4671502181893,13.48567451945712,13.504198820724945,13.522723121992765,13.54124742326059,13.559771724528412,13.578296025796234,13.596820327064057,13.61534462833188,13.6338689295997,13.652393230867524,13.670917532135348,13.68944183340317,13.707966134670993,13.726490435938816,13.745014737206636,13.76353903847446,13.782063339742287,13.800587641010106,13.819111942277928,13.837636243545752,13.856160544813577,13.874684846081397,13.893209147349218,13.911733448617042,13.930257749884865,13.94878205115269,13.967306352420511,13.985830653688332,14.004354954956154,14.022879256223979,14.041403557491803,14.059927858759623,14.078452160027448,14.096976461295272,14.115500762563093,14.134025063830915,14.15254936509874,14.17107366636656,14.189597967634382,14.208122268902207,14.226646570170027,14.245170871437852,14.263695172705676,14.282219473973496,14.300743775241319,14.316779564403117,14.332573931117052,14.348368297830985,14.364162664544919,14.382943222054925,14.407696161157068,14.432449100259209,14.457202039361354,14.481954978463497,14.50670791756564,14.532529123737405,14.558589708038914,14.584650292340415,14.610710876641921,14.636771460943427,14.662832045244931,14.688892629546435,14.714953213847942,14.741013798149446,14.76707438245095,14.793134966752456,14.819195551053959,14.845256135355463,14.87131671965697,14.897377303958477,14.92343788825998,14.949498472561483,14.975559056862991,15.001619641164492,15.027680225465998,15.053740809767504,15.079801394069008,15.105861978370513,15.131922562672019,15.157983146973525,15.184043731275025,15.210104315576531,15.236164899878037,15.262225484179543,15.288286068481046,15.31434665278255,15.340407237084056,15.36646782138556,15.392528405687063,15.41858898998857,15.444649574290075,15.47071015859158,15.496770742893087,15.52283132719459,15.548891911496094,15.5749524957976,15.601013080099104,15.627073664400607,15.653134248702115,15.679194833003617,15.705255417305121,15.73131600160663,15.757376585908133,15.783437170209634,15.809497754511142,15.835558338812648,15.861618923114152,15.887679507415655,15.913740091717163,15.939800676018665,15.965861260320171,15.991921844621677,16.01798242892318,16.044043013224684,16.07010359752619,16.096164181827696,16.122224766129197,16.148285350430704,16.174345934732212,16.200406519033717,16.226467103335217,16.252527687636725,16.27858827193823,16.304648856239734,16.330709440541238,16.356770024842746,16.382830609144246,16.408891193445754,16.43495177774726,16.461012362048763,16.487072946350267,16.513133530651775,16.524953574008652,16.46557091264242,16.406188251276184,16.346805589909952,16.28742292854373,16.228040267177498,16.168657605811262,16.10927494444504,16.049892283078808,15.990509621712572,15.93112696034635,15.871744298980115,15.812361637613884,15.75297897624765,15.652059852550158,15.539651787209444,15.427243721868729,15.314835656528036,15.202427591187321,15.090019525846607,14.977611460505914,14.8652033951652,14.752795329824487,14.640387264483792,14.527979199143077,14.415571133802363,14.30316306846165,14.190755003120957,14.078346937780244,13.965938872439528,13.853530807098835,13.74112274175812,13.628714676417408,13.516306611076715,13.403898545735998,13.291490480395284,13.17908241505457,13.066674349713878,12.954266284373166,12.84185821903245,12.729450153691756,12.617042088351043,12.504634023010329,12.392225957669634,12.279817892328921,12.167409826988207,12.055001761647514,11.942593696306798,11.830185630966085,11.717777565625372,11.605369500284677,11.492961434943963,11.380553369603248,11.268145304262555,11.15573723892184,11.043329173581128,10.930921108240433,10.81851304289972,10.706104977559006,10.593696912218292,10.481288846877598,10.368880781536884,10.256472716196171,10.144064650855476,10.031656585514764,9.919248520174047,9.806840454833354,9.69443238949264,9.582024324151927,9.469616258811232,9.343159312632807,9.194102180655783,9.04504504867876,8.895987916701765,8.746930784724743,8.597873652747719,8.448816520770722,8.2997593887937,8.150702256816675,8.00164512483968,7.852587992862657,7.703530860885633,7.55447372890861,7.405416596931614],[10.26549192680228,10.277829767248397,10.290167607694512,10.302505448140629,10.314843288586745,10.327181129032862,10.339518969478977,10.351856809925094,10.36419465037121,10.376532490817327,10.388870331263442,10.401208171709559,10.413546012155676,10.425883852601793,10.43822169304791,10.450559533494024,10.462897373940143,10.475235214386258,10.487573054832374,10.499910895278491,10.512248735724606,10.524586576170723,10.53692441661684,10.549262257062956,10.561600097509071,10.573937937955188,10.586275778401305,10.598613618847422,10.610951459293538,10.623289299739655,10.63562714018577,10.647964980631889,10.660302821078004,10.672640661524118,10.684978501970235,10.697316342416352,10.709654182862469,10.721992023308584,10.734329863754702,10.746667704200815,10.759005544646934,10.77134338509305,10.783681225539167,10.796019065985282,10.8083569064314,10.820694746877516,10.83303258732363,10.845370427769748,10.857708268215864,10.87004610866198,10.882383949108098,10.894721789554213,10.907059630000331,10.919397470446446,10.931735310892563,10.94407315133868,10.956410991784795,10.968748832230911,10.981086672677028,10.993424513123145,11.005762353569262,11.018100194015377,11.030438034461493,11.04277587490761,11.055113715353725,11.067451555799844,11.079789396245959,11.092127236692075,11.10446507713819,11.116802917584307,11.129140758030424,11.14147859847654,11.153816438922657,11.166154279368774,11.178492119814889,11.190829960261006,11.203167800707122,11.21550564115324,11.227843481599354,11.240181322045471,11.252519162491588,11.264857002937704,11.277194843383821,11.289532681578711,11.301107885659475,11.313184327415279,11.325260769171084,11.33733721092689,11.349413652682696,11.3614900944385,11.373566536194307,11.385642977950111,11.397719419705917,11.409795861461722,11.421872303217528,11.433948744973334,11.44602518672914,11.458101628484943,11.47017807024075,11.482254511996555,11.49433095375236,11.506407395508164,11.518483837263972,11.530560279019776,11.542636720775581,11.554713162531387,11.566789604287193,11.578866046042997,11.590942487798804,11.603018929554608,11.615095371310414,11.627171813066218,11.639248254822023,11.651324696577829,11.663401138333635,11.67547758008944,11.687554021845246,11.699630463601052,11.711706905356857,11.723783347112661,11.735859788868469,11.747936230624273,11.760012672380077,11.772089114135884,11.784165555891688,11.796241997647494,11.8083184394033,11.820394881159105,11.83247132291491,11.844547764670716,11.85662420642652,11.868700648182328,11.880777089938132,11.892853531693937,11.904929973449743,11.917006415205547,11.929082856961353,11.941159298717158,11.953235740472964,11.96531218222877,11.977388623984575,11.989465065740381,12.001541507496185,12.01361794925199,12.025694391007798,12.0377708327636,12.049847274519406,12.061923716275214,12.074000158031017,12.086076599786823,12.098153041542629,12.110229483298435,12.12230592505424,12.134382366810044,12.14645880856585,12.158535250321655,12.170611692077461,12.182688133833265,12.19476457558907,12.206841017344876,12.218917459100682,12.230993900856488,12.243070342612294,12.255146784368097,12.267223226123903,12.27929966787971,12.291376109635515,12.303834376412029,12.318036240865318,12.332238105318607,12.346439969771897,12.360641834225184,12.374843698678474,12.389045563131761,12.403247427585052,12.417449292038341,12.431651156491629,12.44585302094492,12.460054885398208,12.474256749851497,12.488458614304786,12.502660478758076,12.516862343211363,12.531064207664654,12.545266072117943,12.559467936571231,12.573669801024522,12.58787166547781,12.602073529931099,12.616275394384388,12.630477258837677,12.644679123290965,12.658880987744256,12.673082852197544,12.687284716650833,12.701486581104124,12.715688445557412,12.7298903100107,12.74409217446399,12.758294038917278,12.772495903370569,12.786697767823858,12.800899632277146,12.815101496730435,12.829303361183724,12.843505225637013,12.857707090090301,12.871908954543592,12.88611081899688,12.90031268345017,12.914514547903458,12.92871641235675,12.942918276810035,12.957120141263324,12.971322005716615,12.985523870169903,12.999725734623194,13.013927599076482,13.028129463529769,13.04233132798306,13.056533192436348,13.070735056889639,13.084936921342928,13.099138785796216,13.113340650249507,13.127542514702794,13.141744379156085,13.155946243609375,13.170148108062662,13.184349972515951,13.19855183696924,13.21275370142253,13.22695556587582,13.241157430329109,13.255359294782396,13.269561159235687,13.283763023688975,13.297964888142264,13.312166752595552,13.326368617048843,13.340570481502132,13.35477234595542,13.368974210408709,13.383176074862,13.39737793931529,13.411579803768575,13.425781668221864,13.439983532675155,13.454185397128445,13.468387261581734,13.484750344442288,13.503274645710112,13.521798946977935,13.540323248245757,13.55884754951358,13.577371850781404,13.595896152049225,13.614420453317049,13.632944754584871,13.651469055852692,13.669993357120516,13.68851765838834,13.707041959656161,13.725566260923983,13.744090562191808,13.762614863459628,13.781139164727453,13.799663465995277,13.818501955546195,13.837864097938162,13.857226240330133,13.876588382722103,13.895950525114067,13.915312667506038,13.93467480989801,13.954036952289977,13.973399094681945,13.992761237073914,14.012123379465883,14.031485521857851,14.05084766424982,14.070209806641792,14.08957194903376,14.108934091425727,14.128296233817697,14.147658376209666,14.167020518601635,14.186382660993605,14.205744803385574,14.225106945777538,14.244469088169511,14.263831230561475,14.283193372953445,14.302555515345414,14.321917657737387,14.341279800129353,14.360641942521323,14.380004084913292,14.399366227305261,14.418728369697229,14.4380905120892,14.457452654481166,14.476814796873136,14.496176939265105,14.515539081657074,14.53490122404904,14.554263366441011,14.573625508832983,14.59298765122495,14.612349793616918,14.63171193600889,14.651074078400855,14.670436220792824,14.689798363184794,14.709160505576762,14.728522647968731,14.7478847903607,14.76724693275267,14.786609075144638,14.805971217536607,14.825333359928578,14.844695502320544,14.864057644712513,14.883419787104483,14.902781929496452,14.92214407188842,14.94150621428039,14.960868356672359,14.980230499064326,14.999592641456296,15.018954783848267,15.038316926240235,15.057679068632202,15.079305583305118,15.105460842539909,15.131616101774704,15.1577713610095,15.183926620244295,15.210081879479088,15.236237138713886,15.262392397948682,15.288547657183475,15.31470291641827,15.340858175653068,15.36701343488786,15.393168694122657,15.419323953357452,15.445479212592248,15.471634471827043,15.49778973106184,15.523944990296634,15.550100249531429,15.576255508766225,15.602410768001022,15.628566027235816,15.65472128647061,15.680876545705406,15.7070318049402,15.733187064174995,15.75934232340979,15.785497582644584,15.81165284187938,15.837808101114177,15.863963360348972,15.890118619583765,15.916273878818561,15.94242913805336,15.968584397288154,15.994739656522947,16.020894915757744,16.04705017499254,16.073205434227333,16.099360693462128,16.125515952696922,16.151671211931717,16.17782647116651,16.20398173040131,16.230136989636105,16.2562922488709,16.282447508105694,16.30860276734049,16.334758026575287,16.360913285810078,16.387068545044876,16.41322380427967,16.439379063514465,16.465534322749264,16.491689581984055,16.517844841218853,16.544000100453648,16.570155359688442,16.596310618923237,16.62246587815803,16.648621137392823,16.67477639662762,16.700931655862416,16.727086915097214,16.7532057760936,16.77925975284128,16.805313729588956,16.83136770633663,16.8574216830843,16.883475659831976,16.909529636579652,16.935583613327324,16.961637590075,16.987691566822676,17.013745543570348,17.039799520318024,17.0658534970657,17.09190747381337,17.117961450561044,17.14401542730872,17.170069404056395,17.196123380804064,17.222177357551743,17.22941332494557,17.14255924557019,17.05570516619481,16.96885108681943,16.88199700744407,16.79514292806869,16.708288848693307,16.621434769317947,16.534580689942565,16.447726610567184,16.360872531191823,16.274018451816442,16.187164372441064,16.100310293065682,16.01345621369032,15.92660213431494,15.839635981703843,15.727227916363152,15.614819851022439,15.502411785681725,15.39000372034103,15.277595655000315,15.1651875896596,15.052779524318908,14.940371458978195,14.827963393637482,14.715555328296766,14.603147262956071,14.490739197615358,14.378331132274646,14.26592306693395,14.153515001593236,14.041106936252522,13.928698870911829,13.816290805571114,13.703882740230402,13.591474674889689,13.479066609548994,13.366658544208281,13.254250478867565,13.141842413526872,13.029434348186157,12.917026282845443,12.80461821750475,12.692210152164035,12.579802086823321,12.467394021482626,12.354985956141913,12.2425778908012,12.130169825460486,12.017761760119793,11.905353694779079,11.792945629438364,11.680537564097671,11.568129498756957,11.455721433416244,11.34331336807555,11.230905302734836,11.118497237394122,11.006089172053407,10.893681106712712,10.781273041372,10.668864976031285,10.556456910690592,10.444048845349878,10.331640780009163,10.21923271466847,10.098672252476455,9.936027864173795,9.773383475871167,9.610739087568508,9.44809469926585,9.28545031096319,9.122805922660561,8.960161534357905,8.797517146055245,8.634872757752618,8.472228369449958,8.309583981147298,8.146939592844669,7.98429520454201,7.8216508162393525,7.659006427936693,7.496362039634065],[10.735983080895231,10.751511698601773,10.767040316308314,10.782568934014856,10.798097551721396,10.813626169427938,10.829154787134478,10.84468340484102,10.860212022547561,10.875740640254103,10.891269257960644,10.906797875667186,10.922326493373726,10.937855111080266,10.953383728786807,10.96891234649335,10.98444096419989,10.997842395395152,11.010180235841268,11.022518076287385,11.0348559167335,11.047193757179617,11.059531597625734,11.07186943807185,11.084207278517967,11.096545118964082,11.108882959410199,11.121220799856316,11.133558640302432,11.145896480748547,11.158234321194664,11.17057216164078,11.182910002086897,11.195247842533014,11.20758568297913,11.219923523425246,11.232261363871363,11.24459920431748,11.256937044763596,11.269274885209711,11.281612725655828,11.293950566101945,11.30628840654806,11.318626246994176,11.330964087440293,11.343301927886408,11.355639768332527,11.367977608778643,11.380315449224758,11.392653289670875,11.40499113011699,11.417328970563108,11.429666811009223,11.44200465145534,11.454342491901457,11.466680332347572,11.479018172793689,11.491356013239805,11.503693853685922,11.516031694132039,11.528369534578156,11.54070737502427,11.553045215470387,11.565383055916502,11.57772089636262,11.590058736808736,11.602396577254853,11.61473441770097,11.627072258147084,11.639410098593201,11.651747939039318,11.664085779485434,11.676423619931551,11.688761460377666,11.701099300823783,11.7134371412699,11.725774981716015,11.738112822162133,11.75045066260825,11.762788503054365,11.775126343500482,11.787464183946598,11.799802024392715,11.812139864838832,11.824259873043022,11.836336314798826,11.848412756554632,11.860489198310436,11.872565640066243,11.884642081822047,11.896718523577853,11.908794965333659,11.920871407089464,11.93294784884527,11.945024290601076,11.95710073235688,11.969177174112687,11.981253615868491,11.993330057624297,12.005406499380102,12.017482941135906,12.029559382891712,12.041635824647518,12.053712266403323,12.065788708159129,12.077865149914935,12.08994159167074,12.102018033426544,12.114094475182352,12.126170916938154,12.138247358693961,12.150323800449765,12.162400242205571,12.174476683961377,12.186553125717182,12.198629567472988,12.210706009228792,12.222782450984598,12.234858892740405,12.246935334496207,12.259011776252017,12.27108821800782,12.283164659763624,12.295241101519432,12.307317543275236,12.319393985031041,12.331470426786847,12.343546868542651,12.355623310298459,12.367699752054264,12.379776193810066,12.391852635565874,12.40392907732168,12.416005519077483,12.428081960833289,12.440158402589095,12.4522348443449,12.464311286100706,12.476387727856512,12.488464169612316,12.500540611368121,12.512617053123929,12.524693494879733,12.536769936635539,12.548846378391344,12.560922820147148,12.572999261902954,12.585075703658761,12.597152145414563,12.60922858717037,12.621305028926177,12.636264129922242,12.651223232427943,12.666182334933646,12.681141437439349,12.696100539945053,12.711059642450756,12.726018744956459,12.74097784746216,12.755936949967863,12.770896052473569,12.785855154979272,12.800814257484975,12.815773359990676,12.830732462496378,12.845691565002083,12.860650667507786,12.877040784697016,12.894146409228009,12.911252033759002,12.928357658289995,12.94546328282099,12.962568907351983,12.979674531882974,12.996780156413969,13.013885780944962,13.030991405475955,13.048097030006948,13.065202654537941,13.082308279068936,13.099413903599928,13.11651952813092,13.133625152661915,13.150730777192909,13.167836401723902,13.183954718578862,13.198168950780703,13.21238318298254,13.22659741518438,13.24081164738622,13.255025879588061,13.2692401117899,13.283454343991737,13.297668576193578,13.311882808395415,13.326097040597258,13.340311272799095,13.354525505000934,13.368739737202775,13.382953969404614,13.397168201606451,13.411382433808292,13.425596666010133,13.439810898211972,13.454025130413813,13.468239362615648,13.482453594817489,13.49666782701933,13.510882059221167,13.525096291423008,13.539310523624847,13.553524755826686,13.567738988028527,13.581953220230364,13.596167452432205,13.610381684634046,13.624595916835883,13.638810149037726,13.653024381239561,13.667238613441402,13.681452845643243,13.695667077845082,13.70988131004692,13.72409554224876,13.738309774450599,13.752524006652438,13.766738238854279,13.780952471056116,13.795166703257955,13.809380935459796,13.823595167661637,13.837809399863474,13.852023632065315,13.866237864267156,13.880452096468993,13.894666328670834,13.90888056087267,13.923094793074512,13.937309025276353,13.95152325747819,13.96573748968003,13.979951721881868,13.994165954083709,14.00838018628555,14.022594418487387,14.036808650689226,14.051022882891067,14.065237115092906,14.079451347294746,14.093665579496584,14.111276205904403,14.132283226518197,14.15329024713199,14.174297267745784,14.19530428835958,14.216311308973374,14.237318329587168,14.258325350200963,14.27933237081476,14.300339391428553,14.321346412042347,14.342353432656143,14.363360453269935,14.384367473883731,14.405374494497526,14.42638151511132,14.447388535725112,14.468395556338908,14.489402576952703,14.510409597566497,14.531416618180291,14.552423638794089,14.57343065940788,14.594437680021677,14.615444700635472,14.636451721249264,14.657458741863058,14.678465762476854,14.699472783090648,14.72047980370444,14.741486824318237,14.762493844932035,14.783500865545825,14.804077971324606,14.823440113716577,14.842802256108543,14.86216439850051,14.881526540892482,14.90088868328445,14.920250825676419,14.939612968068388,14.958975110460358,14.978337252852324,14.997699395244297,15.017061537636266,15.036423680028232,15.055785822420201,15.075147964812171,15.09451010720414,15.11387224959611,15.13323439198808,15.152596534380045,15.171958676772014,15.191320819163986,15.210682961555953,15.230045103947921,15.249407246339889,15.268769388731862,15.288131531123828,15.307493673515797,15.326855815907766,15.346217958299736,15.365580100691702,15.384942243083675,15.40430438547564,15.42366652786761,15.44302867025958,15.462390812651552,15.481752955043516,15.501115097435488,15.520477239827457,15.539839382219427,15.559201524611392,15.578563667003365,15.597925809395331,15.617287951787299,15.636650094179267,15.656012236571236,15.675374378963207,15.694736521355175,15.714098663747144,15.733460806139114,15.752822948531083,15.774449463203995,15.800604722438788,15.826759981673584,15.85291524090838,15.879070500143174,15.90522575937797,15.931381018612765,15.957536277847561,15.983691537082354,16.009846796317152,16.036002055551947,16.06215731478674,16.088312574021536,16.11446783325633,16.140623092491126,16.16677835172592,16.19293361096072,16.219088870195513,16.245244129430308,16.271399388665102,16.2975546478999,16.323709907134692,16.349865166369487,16.376020425604285,16.40217568483908,16.428330944073874,16.454486203308672,16.480641462543463,16.506796721778258,16.532951981013053,16.55910724024785,16.585262499482642,16.611417758717444,16.637573017952235,16.66372748608943,16.689781462837104,16.715835439584776,16.74188941633245,16.767943393080124,16.7939973698278,16.820051346575475,16.846105323323144,16.872159300070823,16.8982132768185,16.92426725356617,16.950321230313847,16.97637520706152,17.00242918380919,17.028483160556867,17.054537137304543,17.080591114052215,17.10664509079989,17.132699067547566,17.15875304429524,17.18480702104291,17.210860997790586,17.236914974538266,17.262968951285934,17.28902292803361,17.315076904781286,17.341130881528958,17.36718485827663,17.393238835024306,17.41929281177198,17.445346788519654,17.47140076526733,17.497454742015005,17.523508718762677,17.549562695510353,17.57561667225803,17.6016706490057,17.627724625753377,17.65377860250105,17.67983257924872,17.705886555996397,17.731940532744073,17.757994509491752,17.784048486239417,17.810102462987096,17.836156439734772,17.862210416482444,17.888264393230116,17.914318369977792,17.92155433737162,17.83470025799624,17.74784617862086,17.660992099245483,17.57413801987012,17.487283940494738,17.400429861119356,17.313575781743996,17.226721702368614,17.139867622993236,17.053013543617872,16.966159464242494,16.879305384867113,16.792451305491735,16.705597226116367,16.61874314674099,16.53188906736561,16.445034987990248,16.35818090861487,16.27132682923949,16.184472749864124,16.097618670488746,16.010764591113364,15.923910511738,15.837056432362623,15.750202352987243,15.663348273611863,15.5764941942365,15.48964011486112,15.402786035485741,15.315931956110377,15.229077876734998,15.142223797359616,15.055369717984254,14.968515638608874,14.881661559233493,14.794807479858116,14.70795340048275,14.621099321107371,14.534245241731993,14.447391162356627,14.359584474347471,14.240676412206675,14.078032023904045,13.915387635601386,13.75274324729873,13.5900988589961,13.42745447069344,13.264810082390785,13.102165694088123,12.939521305785496,12.776876917482836,12.614232529180178,12.451588140877549,12.28894375257489,12.12629936427223,11.9636549759696,11.801010587666944,11.638366199364285,11.475721811061629,11.313077422758997,11.15043303445634,10.98778864615368,10.82514425785105,10.662499869548395,10.499855481245733,10.337211092943107,10.174566704640446,10.011922316337788,9.849277928035157,9.686633539732501,9.523989151429841,9.361344763127184,9.198700374824554,9.036055986521895,8.873411598219239,8.710767209916607,8.548122821613951,8.38547843331129,8.222834045008662,8.060189656706003,7.897545268403347,7.734900880100686,7.572256491798058],[11.206453841977936,11.221982459684476,11.237511077391016,11.25303969509756,11.2685683128041,11.284096930510643,11.299625548217183,11.315154165923722,11.330682783630266,11.346211401336806,11.361740019043348,11.377268636749887,11.392797254456429,11.40832587216297,11.423854489869512,11.439383107576054,11.454911725282596,11.470440342989136,11.485968960695676,11.501497578402219,11.517026196108759,11.5325548138153,11.548083431521842,11.563612049228384,11.579140666934924,11.594669284641466,11.610197902348006,11.625726520054547,11.641255137761089,11.65678375546763,11.672312373174172,11.687840990880712,11.703369608587256,11.718366428939206,11.730704269385322,11.743042109831439,11.755379950277556,11.767717790723673,11.780055631169787,11.792393471615904,11.804731312062021,11.817069152508136,11.829406992954254,11.84174483340037,11.854082673846484,11.866420514292603,11.878758354738718,11.891096195184836,11.903434035630951,11.915771876077068,11.928109716523185,11.9404475569693,11.952785397415415,11.965123237861533,11.977461078307648,11.989798918753765,12.002136759199882,12.014474599646,12.026812440092115,12.039150280538232,12.051488120984349,12.063825961430464,12.07616380187658,12.088501642322697,12.100839482768812,12.11317732321493,12.125515163661044,12.137853004107162,12.150190844553277,12.162528684999394,12.174866525445513,12.187204365891628,12.199542206337744,12.21188004678386,12.224217887229976,12.236555727676093,12.24889356812221,12.261231408568326,12.273569249014441,12.285907089460558,12.298244929906673,12.310582770352791,12.322920610798906,12.335258451245023,12.347378459449214,12.35945490120502,12.371531342960825,12.38360778471663,12.395684226472437,12.40776066822824,12.419837109984044,12.431913551739852,12.443989993495656,12.456066435251461,12.468142877007267,12.480219318763073,12.492295760518878,12.504372202274684,12.51644864403049,12.528525085786296,12.5406015275421,12.552677969297907,12.564754411053713,12.576830852809517,12.588907294565322,12.600983736321126,12.613060178076932,12.625136619832737,12.637213061588543,12.649289503344349,12.661365945100153,12.673442386855958,12.685518828611764,12.69759527036757,12.709671712123377,12.721748153879181,12.733824595634985,12.74590103739079,12.757977479146598,12.7700539209024,12.782130362658208,12.794206804414014,12.806283246169818,12.818359687925625,12.830436129681429,12.842512571437235,12.854589013193038,12.866665454948844,12.878741896704652,12.890818338460456,12.902894780216261,12.914971221972067,12.92704766372787,12.939124105483678,12.952641876580433,12.967600979086136,12.982560081591838,12.997519184097541,13.012478286603244,13.027437389108949,13.04239649161465,13.057355594120354,13.072314696626057,13.087273799131758,13.102232901637462,13.117192004143165,13.13215110664887,13.147110209154572,13.162069311660275,13.177028414165978,13.19198751667168,13.206946619177385,13.221905721683084,13.236864824188789,13.251823926694492,13.266783029200194,13.281742131705897,13.2967012342116,13.311660336717303,13.326619439223007,13.34157854172871,13.356537644234413,13.371496746740117,13.38645584924582,13.401414951751523,13.416374054257226,13.431333156762928,13.447723273952159,13.464828898483152,13.481934523014147,13.499040147545138,13.51614577207613,13.533251396607126,13.550357021138117,13.567462645669112,13.584568270200103,13.6016738947311,13.618779519262091,13.635885143793086,13.652990768324077,13.670096392855072,13.687202017386065,13.704307641917056,13.72141326644805,13.738518890979046,13.755624515510036,13.772730140041029,13.789835764572022,13.806941389103017,13.824047013634011,13.841152638165003,13.858258262695996,13.875363887226992,13.892469511757984,13.909575136288975,13.92668076081997,13.943786385350965,13.960892009881956,13.977997634412947,13.995103258943942,14.012208883474937,14.029314508005928,14.046420132536923,14.063525757067918,14.078233637883166,14.092447870085005,14.106662102286846,14.120876334488685,14.135090566690522,14.149304798892363,14.163519031094204,14.177733263296041,14.191947495497882,14.206161727699719,14.22037595990156,14.2345901921034,14.248804424305238,14.263018656507079,14.277232888708916,14.291447120910757,14.305661353112598,14.319875585314437,14.334089817516276,14.348304049718115,14.362518281919954,14.376732514121795,14.390946746323634,14.405160978525473,14.419375210727312,14.43358944292915,14.447803675130992,14.46201790733283,14.47623213953467,14.49044637173651,14.504660603938348,14.518874836140188,14.533089068342028,14.547303300543867,14.561517532745706,14.575731764947545,14.589945997149385,14.604160229351223,14.618374461553064,14.632588693754903,14.646802925956742,14.661017158158582,14.67523139036042,14.68944562256226,14.703659854764101,14.717874086965939,14.735484713373756,14.756491733987552,14.777498754601346,14.79850577521514,14.819512795828935,14.840519816442729,14.861526837056523,14.882533857670317,14.903540878284113,14.924547898897906,14.9455549195117,14.966561940125498,14.987568960739292,15.008575981353085,15.02958300196688,15.050590022580673,15.071597043194469,15.092604063808263,15.113611084422057,15.134618105035852,15.155625125649646,15.176632146263444,15.197639166877234,15.21864618749103,15.239653208104826,15.260660228718619,15.281667249332411,15.302674269946209,15.323681290560003,15.344688311173798,15.365695331787592,15.386702352401388,15.40770937301518,15.428716393628978,15.449723414242772,15.470730434856565,15.491737455470359,15.512744476084155,15.533751496697949,15.55475851731174,15.575765537925538,15.596772558539332,15.617779579153122,15.63878659976692,15.659793620380716,15.680800640994509,15.701807661608303,15.7228146822221,15.743821702835895,15.764828723449687,15.785835744063482,15.806842764677276,15.82784978529107,15.848856805904866,15.869863826518662,15.890870847132454,15.911877867746249,15.932884888360045,15.953891908973839,15.974898929587631,15.995905950201426,16.01691297081522,16.037919991429014,16.058927012042812,16.079934032656602,16.100941053270397,16.12194807388419,16.14295509449799,16.163962115111783,16.184969135725574,16.20597615633937,16.226983176953166,16.24799019756696,16.268997218180758,16.290004238794552,16.311011259408343,16.331793974078163,16.35115611647013,16.3705182588621,16.389880401254068,16.409242543646037,16.428604686038007,16.447966828429973,16.469593343102886,16.49574860233768,16.521903861572476,16.54805912080727,16.574214380042065,16.600303172832938,16.626357149580613,16.65241112632829,16.67846510307596,16.704519079823637,16.73057305657131,16.756627033318985,16.78268101006666,16.808734986814333,16.83478896356201,16.86084294030968,16.886896917057356,16.91295089380503,16.939004870552704,16.965058847300376,16.991112824048052,17.017166800795728,17.0432207775434,17.069274754291076,17.09532873103875,17.121382707786424,17.1474366845341,17.173490661281775,17.199544638029444,17.22559861477712,17.251652591524795,17.277706568272468,17.303760545020143,17.32981452176782,17.355868498515495,17.381922475263167,17.40797645201084,17.43403042875852,17.460084405506187,17.486138382253863,17.512192359001535,17.53824633574921,17.564300312496886,17.590354289244562,17.616408265992234,17.64246224273991,17.668516219487582,17.69457019623526,17.720624172982934,17.746678149730606,17.77273212647828,17.798786103225954,17.82484007997363,17.850894056721305,17.876948033468977,17.903002010216653,17.929055986964325,17.955109963712,17.981163940459673,18.00721791720735,18.03327189395502,18.059325870702697,18.085379847450373,18.111433824198045,18.137487800945717,18.163541777693393,18.18959575444107,18.21564973118874,18.241703707936416,18.267757684684092,18.293811661431768,18.31986563817944,18.345919614927112,18.371973591674788,18.39802756842246,18.424081545170136,18.45013552191781,18.476189498665487,18.50224347541316,18.528297452160835,18.554351428908504,18.580405405656183,18.606459382403855,18.613695349797684,18.52684127042231,18.439987191046928,18.353133111671546,18.266279032296183,18.179424952920805,18.092570873545423,18.001828136698883,17.86831017622432,17.73479221574976,17.60127425527522,17.46775629480066,17.3342383343261,17.20072037385154,17.067202413377,16.933684452902437,16.800166492427877,16.66664853195334,16.533130571478775,16.399612611004216,16.26609465052968,16.132576690055117,15.999058729580554,15.865540769106017,15.732022808631454,15.598504848156892,15.46498688768233,15.331468927207794,15.197950966733233,15.06443300625867,14.930915045784133,14.797397085309571,14.66387912483501,14.530361164360473,14.396843203885911,14.263325243411348,14.129807282936786,13.99628932246225,13.862771361987688,13.729253401513127,13.595735441038588,13.462217480564025,13.328699520089462,13.195181559614927,13.061663599140365,12.928145638665804,12.794627678191267,12.661109717716704,12.527591757242142,12.39407379676758,12.260555836293042,12.12703787581848,11.993519915343919,11.86000195486938,11.72648399439482,11.592966033920257,11.459448073445719,11.32593011297116,11.192412152496596,11.058894192022034,10.9253762315475,10.791858271072934,10.658340310598373,10.524822350123836,10.391304389649273,10.257786429174713,10.124268468700176,9.990750508225615,9.857232547751051,9.723714587276515,9.590196626801951,9.45667866632739,9.323160705852828,9.189642745378292,9.056124784903728,8.922606824429167,8.7866616620806,8.624017273777941,8.461372885475285,8.298728497172656,8.136084108869998,7.973439720567338,7.810795332264679,7.648150943962051],[11.676924603060638,11.692453220767181,11.70798183847372,11.72351045618026,11.739039073886804,11.754567691593344,11.770096309299884,11.785624927006427,11.801153544712967,11.81668216241951,11.83221078012605,11.84773939783259,11.863268015539132,11.878796633245674,11.894325250952216,11.909853868658757,11.925382486365297,11.94091110407184,11.95643972177838,11.971968339484922,11.987496957191464,12.003025574898004,12.018554192604544,12.034082810311087,12.049611428017627,12.065140045724169,12.08066866343071,12.09619728113725,12.111725898843794,12.127254516550334,12.142783134256877,12.158311751963415,12.173840369669957,12.189368987376499,12.20489760508304,12.220426222789582,12.235954840496122,12.251483458202665,12.267012075909204,12.282540693615747,12.298069311322287,12.31359792902883,12.32912654673537,12.34465516444191,12.360183782148452,12.375712399854992,12.391241017561535,12.406769635268075,12.422298252974617,12.437826870681159,12.451228302929376,12.463566143375491,12.47590398382161,12.488241824267725,12.500579664713841,12.512917505159958,12.525255345606073,12.537593186052192,12.549931026498307,12.562268866944423,12.57460670739054,12.586944547836655,12.599282388282772,12.611620228728889,12.623958069175004,12.636295909621122,12.648633750067237,12.660971590513354,12.673309430959469,12.685647271405585,12.697985111851704,12.710322952297819,12.722660792743936,12.73499863319005,12.747336473636167,12.759674314082284,12.7720121545284,12.784349994974518,12.796687835420634,12.80902567586675,12.821363516312866,12.833701356758983,12.8460391972051,12.858377037651216,12.870497045855405,12.88257348761121,12.894649929367016,12.906726371122822,12.918802812878628,12.930879254634432,12.94295569639024,12.955032138146043,12.967108579901849,12.979185021657653,12.99126146341346,13.003337905169264,13.01541434692507,13.027490788680876,13.039567230436681,13.051643672192487,13.063720113948293,13.075796555704096,13.087872997459904,13.09994943921571,13.112025880971512,13.12410232272732,13.136178764483125,13.148255206238929,13.160331647994736,13.17240808975054,13.184484531506346,13.19656097326215,13.208637415017957,13.220713856773763,13.232790298529567,13.244866740285374,13.256943182041178,13.269019623796982,13.283978725744326,13.298937828250033,13.313896930755735,13.328856033261438,13.34381513576714,13.358774238272842,13.373733340778548,13.388692443284251,13.403651545789954,13.418610648295656,13.433569750801357,13.448528853307064,13.463487955812765,13.47844705831847,13.49340616082417,13.508365263329871,13.523324365835578,13.538283468341278,13.553242570846981,13.568201673352686,13.583160775858389,13.598119878364091,13.613078980869792,13.628038083375497,13.6429971858812,13.657956288386902,13.672915390892607,13.687874493398308,13.702833595904014,13.717792698409717,13.732751800915418,13.747710903421122,13.762670005926823,13.777629108432528,13.792588210938229,13.807547313443932,13.822506415949636,13.837465518455339,13.852424620961042,13.867383723466745,13.882342825972447,13.89730192847815,13.912261030983853,13.927220133489556,13.94217923599526,13.957138338500961,13.972097441006664,13.987056543512368,14.002015646018071,14.018405763207301,14.035511387738294,14.052617012269287,14.06972263680028,14.086828261331272,14.103933885862267,14.12103951039326,14.138145134924255,14.155250759455248,14.17235638398624,14.189462008517234,14.206567633048227,14.223673257579222,14.240778882110213,14.257884506641206,14.2749901311722,14.292095755703194,14.309201380234185,14.32630700476518,14.343412629296173,14.360518253827166,14.37762387835816,14.394729502889152,14.411835127420147,14.428940751951139,14.446046376482133,14.463152001013125,14.48025762554412,14.497363250075113,14.514468874606106,14.531574499137097,14.548680123668092,14.565785748199087,14.582891372730078,14.599996997261073,14.617102621792066,14.634208246323059,14.651313870854052,14.668419495385045,14.68552511991604,14.70263074444703,14.719736368978024,14.73684199350902,14.75394761804001,14.771053242571005,14.788158867101998,14.805264491632991,14.822370116163984,14.839475740694978,14.856581365225972,14.873686989756965,14.890792614287957,14.907898238818948,14.925003863349945,14.94210948788094,14.958298324985629,14.972512557187468,14.986726789389309,15.00094102159115,15.015155253792988,15.029369485994826,15.043583718196667,15.057797950398506,15.072012182600345,15.086226414802185,15.100440647004024,15.114654879205862,15.128869111407704,15.143083343609543,15.15729757581138,15.17151180801322,15.185726040215062,15.1999402724169,15.21415450461874,15.22836873682058,15.242582969022418,15.25679720122426,15.271011433426098,15.285225665627937,15.299439897829775,15.313654130031615,15.327868362233456,15.342082594435293,15.359693220843113,15.380700241456907,15.401707262070701,15.422714282684494,15.44372130329829,15.464728323912084,15.485735344525878,15.506742365139672,15.527749385753467,15.54875640636726,15.569763426981057,15.590770447594853,15.611777468208647,15.632784488822438,15.653791509436235,15.67479853005003,15.695805550663824,15.716812571277618,15.737819591891412,15.758826612505207,15.779833633119003,15.800840653732797,15.82184767434659,15.842854694960383,15.863861715574181,15.884868736187975,15.905875756801768,15.926882777415564,15.947889798029358,15.968896818643152,15.989903839256947,16.01091085987074,16.031917880484535,16.05292490109833,16.073931921712127,16.094938942325918,16.115945962939712,16.13695298355351,16.157960004167304,16.178967024781095,16.199974045394892,16.220981066008687,16.241988086622477,16.26299510723627,16.284002127850073,16.305009148463864,16.326016169077658,16.347023189691456,16.36803021030525,16.38903723091904,16.410044251532838,16.43105127214663,16.452058292760427,16.473448200519442,16.49631747019588,16.51918673987231,16.542056009548748,16.564925279225186,16.58779454890162,16.610663818578058,16.633533088254495,16.656402357930933,16.679271627607367,16.7021408972838,16.72501016696024,16.747879436636673,16.77074870631311,16.793617975989548,16.816487245665982,16.839356515342423,16.86222578501886,16.885095054695295,16.907964324371733,16.930833594048167,16.953702863724605,16.97657213340104,16.999441403077476,17.02231067275391,17.045179942430348,17.068049212106786,17.090918481783223,17.11378775145966,17.136657021136095,17.15991754494375,17.183960577013842,17.20800360908393,17.23204664115402,17.25608967322411,17.280132705294204,17.304175737364297,17.328218769434386,17.352261801504476,17.37630483357457,17.40034786564466,17.42439089771475,17.44843392978484,17.472476961854934,17.496519993925023,17.520563025995116,17.54460605806521,17.568649090135303,17.59269212220539,17.61673515427548,17.640778186345575,17.66482121841566,17.688864250485757,17.712907282555847,17.73719278136182,17.763278703623566,17.78936462588532,17.81545054814707,17.841536470408812,17.86762239267056,17.893708314932315,17.919794237194058,17.94588015945581,17.97196608171756,17.998052003979307,18.024137926241057,18.050223848502803,18.076309770764553,18.102395693026303,18.128481615288052,18.1545675375498,18.180653459811552,18.206739382073298,18.23282530433505,18.258911226596794,18.284997148858544,18.311083071120294,18.33716899338204,18.363254915643793,18.389340837905543,18.41542676016729,18.44151268242904,18.467598604690785,18.493684526952535,18.519770449214285,18.545856371476034,18.571942293737784,18.598028215999534,18.62411413826128,18.65020006052303,18.67628598278478,18.702371905046526,18.72845782730828,18.754543749570022,18.780629671831772,18.806715594093518,18.83280151635527,18.858887438617018,18.884973360878767,18.911059283140517,18.937145205402267,18.963231127664013,18.989317049925763,19.015402972187513,19.04148889444926,19.067574816711012,19.09366073897276,19.119746661234505,19.145832583496254,19.171918505758008,19.198004428019754,19.224090350281504,19.250176272543253,19.25256151576324,19.136443363774458,19.020325211785675,18.904207059796885,18.788088907808124,18.67197075581934,18.555852603830555,18.43973445184179,18.323616299853008,18.20749814786422,18.09137999587546,17.975261843886674,17.859143691897888,17.743025539909105,17.626907387920344,17.510789235931554,17.394671083942775,17.27855293195401,17.162434779965224,17.04631662797644,16.930198475987677,16.81190535262343,16.678387392148867,16.544869431674332,16.41135147119977,16.277833510725205,16.144315550250646,16.01079758977611,15.877279629301547,15.743761668826986,15.610243708352447,15.476725747877888,15.343207787403324,15.209689826928786,15.076171866454224,14.942653905979661,14.809135945505101,14.675617985030563,14.542100024556001,14.40858206408144,14.275064103606903,14.14154614313234,14.008028182657778,13.874510222183241,13.74099226170868,13.607474301234118,13.47395634075958,13.340438380285018,13.206920419810455,13.073402459335894,12.939884498861357,12.806366538386795,12.672848577912234,12.539330617437695,12.405812656963134,12.272294696488572,12.138776736014034,12.005258775539472,11.87174081506491,11.738222854590347,11.604704894115812,11.471186933641249,11.336006788739137,11.162596659806734,10.9891865308743,10.815776401941863,10.642366273009458,10.468956144077023,10.295546015144586,10.122135886212181,9.948725757279743,9.775315628347307,9.601905499414872,9.428495370482468,9.255085241550033,9.081675112617596,8.908264983685191,8.734854854752754,8.561444725820317,8.388034596887914,8.214624467955478,8.04121433902304,7.867804210090604,7.6943940811582],[12.147395364143334,12.162923981849874,12.178452599556415,12.193981217262957,12.209509834969499,12.225038452676039,12.240567070382578,12.25609568808912,12.271624305795664,12.287152923502203,12.302681541208745,12.318210158915285,12.333738776621828,12.349267394328368,12.36479601203491,12.380324629741452,12.395853247447992,12.411381865154535,12.426910482861075,12.442439100567617,12.457967718274158,12.473496335980698,12.48902495368724,12.50455357139378,12.520082189100322,12.535610806806863,12.551139424513405,12.566668042219945,12.582196659926487,12.597725277633028,12.61325389533957,12.628782513046112,12.644311130752651,12.659839748459193,12.675368366165735,12.690896983872276,12.706425601578815,12.721954219285358,12.737482836991898,12.753011454698441,12.768540072404981,12.784068690111525,12.799597307818065,12.815125925524605,12.830654543231146,12.846183160937686,12.86171177864423,12.87724039635077,12.892769014057311,12.908297631763853,12.923826249470395,12.939354867176935,12.954883484883476,12.970412102590016,12.985940720296558,13.0014693380031,13.016997955709641,13.032526573416183,13.048055191122724,13.063583808829264,13.079112426535806,13.094641044242348,13.11016966194889,13.12569827965543,13.141226897361971,13.156755515068513,13.17175233647342,13.184090176919536,13.196428017365653,13.208765857811768,13.221103698257885,13.233441538704001,13.245779379150118,13.258117219596235,13.27045506004235,13.282792900488467,13.295130740934583,13.3074685813807,13.319806421826815,13.332144262272932,13.344482102719049,13.356819943165165,13.369157783611282,13.381495624057397,13.39361563226159,13.405692074017393,13.417768515773199,13.429844957529005,13.441921399284809,13.453997841040614,13.46607428279642,13.478150724552226,13.490227166308031,13.502303608063835,13.514380049819643,13.526456491575447,13.538532933331252,13.550609375087058,13.562685816842865,13.57476225859867,13.586838700354475,13.60035647240251,13.615315574908212,13.630274677413915,13.645233779919618,13.66019288242532,13.675151984931025,13.690111087436726,13.70507018994243,13.720029292448134,13.734988394953836,13.749947497459539,13.764906599965244,13.779865702470946,13.794824804976649,13.809783907482352,13.824743009988055,13.839702112493757,13.85466121499946,13.869620317505163,13.884579420010866,13.899538522516568,13.914497625022271,13.929456727527974,13.944415830033677,13.959374932539381,13.974334035045084,13.989293137550789,14.004252240056488,14.019211342562194,14.034170445067895,14.0491295475736,14.064088650079302,14.079047752585002,14.094006855090708,14.108965957596409,14.123925060102113,14.138884162607816,14.153843265113519,14.168802367619223,14.183761470124924,14.198720572630627,14.21367967513633,14.228638777642033,14.243597880147737,14.25855698265344,14.273516085159143,14.288475187664847,14.30343429017055,14.318393392676253,14.333352495181956,14.348311597687658,14.363270700193361,14.378229802699062,14.393188905204767,14.40814800771047,14.423107110216172,14.438066212721875,14.453025315227578,14.46798441773328,14.482943520238983,14.497902622744688,14.512861725250392,14.527820827756093,14.542779930261796,14.557739032767499,14.572698135273203,14.589088252462433,14.606193876993425,14.62329950152442,14.640405126055413,14.657510750586406,14.6746163751174,14.691721999648394,14.708827624179385,14.72593324871038,14.743038873241371,14.760144497772364,14.777250122303359,14.794355746834352,14.811461371365343,14.828566995896338,14.845672620427331,14.862778244958324,14.87988386948932,14.896989494020312,14.914095118551305,14.931200743082297,14.948306367613291,14.965411992144286,14.982517616675278,14.999623241206269,15.016728865737264,15.033834490268257,15.05094011479925,15.068045739330245,15.085151363861236,15.10225698839223,15.119362612923222,15.136468237454217,15.15357386198521,15.170679486516203,15.187785111047198,15.20489073557819,15.221996360109184,15.239101984640175,15.25620760917117,15.273313233702162,15.290418858233156,15.307524482764151,15.324630107295143,15.341735731826137,15.35884135635713,15.375946980888124,15.393052605419115,15.41015822995011,15.427263854481104,15.444369479012096,15.461475103543089,15.478580728074082,15.495686352605073,15.512791977136072,15.529897601667063,15.547003226198054,15.564108850729047,15.581214475260042,15.598320099791035,15.615425724322028,15.632531348853021,15.649636973384016,15.666742597915007,15.683848222446,15.700953846976995,15.718059471507988,15.73516509603898,15.752270720569976,15.76937634510097,15.78648196963196,15.803587594162952,15.820693218693947,15.837798843224942,15.852577244289922,15.866791476491759,15.881005708693602,15.89521994089544,15.90943417309728,15.923648405299117,15.93786263750096,15.952076869702799,15.966291101904638,15.983901728312455,16.00490874892625,16.025915769540042,16.046922790153836,16.06792981076763,16.088936831381428,16.10994385199522,16.130950872609016,16.15195789322281,16.172964913836605,16.1939719344504,16.214978955064197,16.235985975677988,16.256992996291782,16.278000016905576,16.29900703751937,16.320014058133165,16.34102107874696,16.363281195175496,16.386150464851934,16.40901973452837,16.43188900420481,16.454758273881243,16.477627543557677,16.50049681323412,16.523366082910552,16.54623535258699,16.569104622263428,16.59197389193986,16.614843161616296,16.637712431292737,16.660581700969175,16.68345097064561,16.706320240322043,16.72918950999848,16.75205877967492,16.774928049351352,16.79779731902779,16.820666588704228,16.843535858380662,16.8664051280571,16.889274397733534,16.91214366740997,16.935012937086405,16.957882206762847,16.98075147643928,17.00362074611572,17.026490015792156,17.04935928546859,17.072228555145028,17.095097824821465,17.1179670944979,17.140836364174337,17.16370563385077,17.186574903527212,17.209444173203646,17.23231344288008,17.25518271255652,17.278051982232956,17.30092125190939,17.323790521585828,17.346659791262265,17.3695290609387,17.392398330615137,17.41526760029157,17.43813686996801,17.461006139644446,17.48387540932088,17.50674467899732,17.529613948673756,17.55248321835019,17.575352488026624,17.598221757703065,17.6210910273795,17.643960297055937,17.66682956673237,17.689698836408812,17.712568106085246,17.73543737576168,17.758306645438118,17.781175915114556,17.80404518479099,17.826914454467428,17.850174978275085,17.874218010345174,17.898261042415264,17.922304074485353,17.946347106555447,17.970390138625536,17.99443317069563,18.018476202765722,18.04251923483581,18.0665622669059,18.090605298975994,18.114648331046084,18.138691363116173,18.16273439518627,18.18677742725636,18.21082045932645,18.234863491396542,18.25890652346663,18.28294955553672,18.306992587606814,18.33103561967691,18.355078651746997,18.37912168381709,18.403164715887183,18.42720774795727,18.451250780027358,18.475293812097455,18.499336844167544,18.523379876237634,18.547422908307727,18.57146594037782,18.595508972447906,18.619552004518,18.643595036588092,18.66763806865818,18.691681100728275,18.715724132798364,18.739767164868457,18.763810196938547,18.78785322900864,18.81189626107873,18.835939293148822,18.859982325218912,18.884025357289,18.908068389359094,18.932111421429187,18.956154453499273,18.980197485569366,19.00424051763946,19.02828354970955,19.052326581779642,19.07636961384973,19.10041264591982,19.125208865805387,19.151294788067133,19.177380710328883,19.203466632590633,19.22955255485238,19.255638477114125,19.28172439937588,19.307810321637625,19.333896243899375,19.359982166161124,19.386068088422874,19.41215401068462,19.43823993294637,19.46432585520812,19.490411777469863,19.516497699731616,19.542583621993366,19.568669544255112,19.59475546651686,19.620841388778615,19.64692731104036,19.673013233302107,19.699099155563857,19.725185077825607,19.751271000087357,19.777356922349107,19.803442844610853,19.829528766872603,19.85561468913435,19.881700611396102,19.884085854616092,19.767967702627306,19.65184955063852,19.53573139864974,19.419613246660973,19.30349509467219,19.187376942683404,19.071258790694642,18.955140638705856,18.839022486717074,18.72290433472831,18.606786182739523,18.49066803075074,18.374549878761954,18.258431726773193,18.142313574784403,18.026195422795624,17.91007727080686,17.793959118818073,17.67784096682929,17.561722814840525,17.445604662851743,17.329486510862957,17.21336835887419,17.09725020688541,16.981132054896623,16.86501390290784,16.748895750919075,16.63277759893029,16.516659446941507,16.400541294952745,16.28442314296396,16.168304990975173,16.05218683898641,15.936068686997626,15.789829503032806,15.636005939247251,15.482182375461727,15.328358811676173,15.174535247890619,15.020711684105093,14.86688812031954,14.713064556533988,14.55924099274846,14.405417428962908,14.251593865177353,14.097770301391828,13.943946737606273,13.790123173820719,13.629095378053481,13.455685249121078,13.282275120188643,13.108864991256205,12.935454862323802,12.762044733391365,12.58863460445893,12.415224475526525,12.241814346594088,12.068404217661652,11.894994088729216,11.721583959796812,11.548173830864375,11.37476370193194,11.201353572999535,11.027943444067098,10.854533315134663,10.681123186202258,10.507713057269822,10.334302928337385,10.16089279940498,9.987482670472545,9.814072541540106,9.640662412607671,9.467252283675267,9.293842154742832,9.120432025810395,8.94702189687799,8.773611767945553,8.600201639013118,8.426791510080713,8.253381381148277,8.079971252215842,7.906561123283404,7.733150994351],[12.617866125226037,12.633394742932579,12.64892336063912,12.66445197834566,12.679980596052202,12.695509213758744,12.711037831465283,12.726566449171825,12.742095066878367,12.757623684584908,12.77315230229145,12.78868091999799,12.80420953770453,12.819738155411073,12.835266773117613,12.850795390824155,12.866324008530697,12.881852626237237,12.89738124394378,12.91290986165032,12.92843847935686,12.943967097063402,12.959495714769943,12.975024332476485,12.990552950183025,13.006081567889568,13.02161018559611,13.03713880330265,13.052667421009193,13.068196038715733,13.083724656422273,13.099253274128817,13.114781891835356,13.130310509541898,13.14583912724844,13.16136774495498,13.176896362661521,13.192424980368063,13.207953598074605,13.223482215781143,13.239010833487686,13.254539451194228,13.270068068900768,13.28559668660731,13.30112530431385,13.316653922020393,13.332182539726933,13.347711157433475,13.363239775140016,13.378768392846556,13.394297010553098,13.40982562825964,13.425354245966181,13.440882863672721,13.456411481379263,13.471940099085803,13.487468716792346,13.502997334498886,13.518525952205428,13.53405456991197,13.549583187618511,13.565111805325053,13.580640423031594,13.596169040738133,13.611697658444676,13.627226276151216,13.642754893857758,13.6582835115643,13.673812129270841,13.689340746977381,13.704869364683923,13.720397982390462,13.735926600097004,13.751455217803546,13.766983835510088,13.78251245321663,13.79804107092317,13.81356968862971,13.829098306336252,13.844626924042794,13.860155541749336,13.875684159455876,13.891212777162417,13.90461421046359,13.9167342190607,13.931693321566405,13.946652424072107,13.96161152657781,13.976570629083513,13.991529731589216,14.00648883409492,14.021447936600623,14.036407039106326,14.051366141612029,14.066325244117731,14.081284346623434,14.096243449129137,14.11120255163484,14.126161654140542,14.141120756646245,14.15607985915195,14.171038961657652,14.185998064163355,14.200957166669058,14.21591626917476,14.230875371680462,14.245834474186168,14.260793576691869,14.275752679197574,14.290711781703276,14.305670884208979,14.320629986714682,14.335589089220385,14.350548191726087,14.36550729423179,14.380466396737493,14.395425499243197,14.410384601748898,14.425343704254601,14.440302806760304,14.455261909266008,14.470221011771713,14.485180114277416,14.500139216783118,14.515098319288821,14.530057421794524,14.545016524300229,14.559975626805931,14.574934729311632,14.589893831817337,14.604852934323038,14.619812036828742,14.634771139334447,14.649730241840146,14.66468934434585,14.679648446851555,14.694607549357258,14.70956665186296,14.724525754368663,14.739484856874366,14.754443959380069,14.769403061885772,14.784362164391474,14.799321266897177,14.81428036940288,14.829239471908584,14.844198574414287,14.85915767691999,14.874116779425691,14.889075881931396,14.9040349844371,14.918994086942803,14.933953189448504,14.948912291954205,14.96387139445991,14.978830496965614,14.993789599471317,15.00874870197702,15.02370780448272,15.038666906988425,15.053626009494128,15.06858511199983,15.083544214505533,15.098503317011238,15.11346241951694,15.128421522022643,15.143380624528346,15.159770741717576,15.17687636624857,15.193981990779562,15.211087615310555,15.228193239841548,15.245298864372542,15.262404488903535,15.279510113434528,15.296930273959882,15.314350434568274,15.331770595176666,15.349190755785056,15.366610916393448,15.384031077001838,15.401451237610232,15.41887139821862,15.436291558827012,15.453711719435404,15.471131880043796,15.488552040652186,15.505972201260578,15.523392361868968,15.540812522477362,15.558232683085752,15.575652843694144,15.593073004302532,15.610493164910926,15.627913325519316,15.64533348612771,15.662753646736098,15.68017380734449,15.697593967952882,15.715014128561272,15.732434289169666,15.749854449778054,15.767274610386448,15.784694770994838,15.80211493160323,15.819535092211622,15.836955252820012,15.854375413428404,15.871795574036794,15.889215734645186,15.906635895253578,15.92405605586197,15.941476216470358,15.958896377078752,15.976316537687143,15.993736698295532,16.011156858903927,16.028577019512316,16.045997180120708,16.0634173407291,16.080837501337488,16.098257661945883,16.11567782255427,16.13309798316266,16.150518143771055,16.167938304379447,16.18535846498784,16.20277862559623,16.22019878620462,16.237618946813015,16.255039107421403,16.27245926802979,16.289879428638187,16.307299589246576,16.32471974985497,16.34213991046336,16.35956007107175,16.376980231680143,16.394400392288535,16.411820552896923,16.42924071350532,16.446660874113707,16.4640810347221,16.48150119533049,16.498921355938883,16.51634151654727,16.533761677155663,16.551181837764055,16.568601998372447,16.586022158980835,16.607628859892376,16.633422101107072,16.65921534232176,16.68500858353645,16.710801824751144,16.736595065965833,16.762388307180526,16.78818154839522,16.81397478960991,16.839768030824597,16.86556127203929,16.891179868955938,16.91409157252825,16.937003276100562,16.959914979672874,16.982826683245182,17.005738386817495,17.02865009038981,17.05156179396212,17.074473497534427,17.097385201106743,17.120296904679055,17.143208608251364,17.166120311823676,17.18903201539599,17.2119437189683,17.234855422540612,17.257767126112928,17.280678829685236,17.303590533257548,17.32650223682986,17.349413940402176,17.37232564397448,17.395237347546793,17.418149051119105,17.441060754691417,17.46397245826373,17.48688416183604,17.50979586540835,17.532707568980662,17.555619272552978,17.578530976125286,17.6014426796976,17.62435438326991,17.647266086842226,17.670177790414535,17.693089493986847,17.716001197559162,17.73891290113147,17.76182460470378,17.784736308276095,17.807648011848404,17.830559715420716,17.853471418993028,17.876383122565343,17.899294826137652,17.922206529709964,17.945118233282276,17.968029936854588,17.9909416404269,18.013853343999212,18.036765047571524,18.059676751143833,18.082588454716145,18.105500158288457,18.128394303299352,18.151263572975793,18.17413284265223,18.19700211232866,18.219871382005103,18.24274065168154,18.265609921357974,18.28847919103441,18.311348460710846,18.334217730387284,18.357087000063718,18.37995626974016,18.40282553941659,18.425694809093027,18.448564078769465,18.471433348445903,18.49430261812234,18.517171887798774,18.54043241160643,18.56447544367652,18.58851847574661,18.612561507816704,18.636604539886793,18.660647571956883,18.68469060402698,18.70873363609707,18.732776668167155,18.75681970023725,18.78086273230734,18.80490576437743,18.828948796447524,18.852991828517613,18.877034860587706,18.901077892657796,18.92512092472789,18.949163956797978,18.97320698886807,18.99725002093816,19.021293053008257,19.045336085078343,19.069379117148436,19.093422149218526,19.117465181288615,19.14150821335871,19.1655512454288,19.18959427749889,19.21363730956898,19.237680341639074,19.261723373709163,19.285766405779256,19.309809437849346,19.333852469919435,19.35789550198953,19.38193853405962,19.40598156612971,19.4300245981998,19.454067630269897,19.478110662339986,19.502153694410076,19.526196726480165,19.55023975855026,19.57428279062035,19.59832582269044,19.62236885476053,19.646411886830624,19.670454918900713,19.694497950970803,19.718540983040896,19.742584015110985,19.766627047181075,19.79067007925117,19.81471311132126,19.83875614339135,19.862799175461443,19.886842207531537,19.910885239601626,19.934928271671716,19.95897130374181,19.9830143358119,20.00705736788199,20.03110039995208,20.05514343202217,20.079186464092263,20.103229496162356,20.127272528232446,20.151315560302535,20.17535859237263,20.19940162444272,20.22344465651281,20.2474876885829,20.271530720652994,20.295573752723083,20.319616784793173,20.343659816863266,20.367702848933362,20.391745881003445,20.415788913073538,20.43983194514363,20.463874977213724,20.487918009283813,20.51322495024896,20.515610193468955,20.399492041480165,20.263979426853606,20.110155863068048,19.956332299282526,19.802508735496968,19.64868517171142,19.49486160792589,19.34103804414034,19.187214480354783,19.03339091656926,18.879567352783706,18.72574378899815,18.571920225212597,18.418096661427075,18.264273097641517,18.110449533855967,17.95662597007044,17.802802406284886,17.648978842499332,17.495155278713806,17.341331714928252,17.187508151142698,17.033684587357172,16.879861023571618,16.726037459786067,16.572213896000513,16.418390332214987,16.264566768429432,16.110743204643878,15.956919640858354,15.8030960770728,15.649272513287245,15.495448949501721,15.341625385716167,15.187801821930613,15.03397825814506,14.880154694359536,14.726331130573982,14.572507566788428,14.418684003002902,14.264860439217347,14.111036875431795,13.957213311646269,13.803389747860715,13.649566184075162,13.495742620289636,13.341919056504084,13.18809549271853,13.034271928932975,12.880448365147451,12.726624801361897,12.572801237576343,12.418977673790817,12.265154110005263,12.11133054621971,11.957506982434184,11.80368341864863,11.649859854863077,11.496036291077523,11.342212727291999,11.188389163506445,11.034565599720892,10.880742035935366,10.726918472149812,10.573094908364258,10.419271344578732,10.26544778079318,10.111624217007627,9.957800653222101,9.803977089436547,9.650153525650992,9.49632996186544,9.342506398079916,9.188682834294362,9.034859270508807,8.881035706723281,8.727212142937727,8.573388579152173,8.419565015366649,8.265741451581095,8.11191788779554,7.945318036476206,7.771907907543802],[13.087781753877364,13.103310371583905,13.118838989290445,13.134367606996987,13.149896224703529,13.16542484241007,13.180953460116612,13.196482077823152,13.212010695529694,13.227539313236235,13.243067930942777,13.258596548649317,13.274125166355859,13.2896537840624,13.305182401768942,13.320711019475482,13.336239637182022,13.351768254888565,13.367296872595105,13.382825490301649,13.398354108008188,13.41388272571473,13.42941134342127,13.444939961127812,13.460468578834352,13.475997196540895,13.491525814247435,13.507054431953975,13.522583049660518,13.53811166736706,13.553640285073602,13.569168902780142,13.584697520486682,13.600226138193225,13.615754755899765,13.631283373606307,13.646811991312848,13.662340609019388,13.677869226725932,13.693397844432472,13.708926462139013,13.724455079845555,13.739983697552095,13.755512315258636,13.771040932965178,13.786569550671718,13.80209816837826,13.817626786084801,13.833155403791341,13.848684021497883,13.864212639204425,13.879741256910966,13.895269874617508,13.910798492324048,13.926327110030588,13.94185572773713,13.957384345443671,13.972912963150213,13.988441580856755,14.003970198563296,14.019498816269838,14.03502743397638,14.050556051682921,14.06608466938946,14.081613287096001,14.097141904802543,14.112670522509084,14.128199140215626,14.145227770250528,14.163756410805961,14.18228505136139,14.20081369191682,14.21934233247225,14.23787097302768,14.256399613583111,14.274928254138542,14.293456894693971,14.3119855352494,14.330514175804833,14.349042816360264,14.367571456915693,14.386100097471124,14.404628738026554,14.423157378581985,14.441044230723676,14.458802725182625,14.476561219641571,14.494319714100518,14.512078208559466,14.529836703018411,14.547595197477358,14.565353691936306,14.583112186395253,14.6008706808542,14.618629175313146,14.636387669772093,14.65414616423104,14.671904658689986,14.689663153148935,14.70695508312581,14.721914185631512,14.736873288137215,14.751832390642917,14.766791493148622,14.781750595654323,14.796709698160026,14.81166880066573,14.826627903171433,14.841587005677138,14.856546108182838,14.871505210688541,14.886464313194244,14.901423415699949,14.916382518205651,14.931341620711354,14.946300723217057,14.96125982572276,14.976218928228462,14.991178030734165,15.006137133239868,15.021096235745572,15.036055338251275,15.051014440756978,15.06597354326268,15.080932645768383,15.095891748274088,15.110850850779793,15.125809953285495,15.140769055791196,15.1557281582969,15.170687260802604,15.185646363308306,15.200605465814009,15.21556456831971,15.230523670825413,15.245482773331116,15.260441875836818,15.275400978342521,15.290360080848226,15.305319183353928,15.32027828585963,15.335237388365336,15.350196490871038,15.36515559337674,15.380114695882444,15.395073798388147,15.41003290089385,15.424992003399552,15.439951105905255,15.454910208410958,15.469869310916662,15.484828413422365,15.499787515928066,15.514746618433767,15.529705720939472,15.544664823445176,15.559623925950879,15.574583028456582,15.589542130962284,15.604501233467987,15.619460335973692,15.634419438479394,15.649378540985097,15.6643376434908,15.679296745996503,15.694255848502205,15.709214951007908,15.727393142234757,15.747180877822178,15.766968613409597,15.786756348997018,15.80654408458444,15.826331820171859,15.84611955575928,15.865907291346701,15.885695026934119,15.905482762521538,15.925270498108961,15.94505823369638,15.9648459692838,15.984633704871221,16.004421440458643,16.02420917604606,16.04399691163348,16.063784647220903,16.08357238280832,16.10336011839574,16.123147853983163,16.14182143760441,16.1592415982128,16.176661758821194,16.194081919429586,16.211502080037974,16.22892224064637,16.246342401254758,16.263762561863153,16.28118272247154,16.29860288307993,16.316023043688325,16.333443204296714,16.350863364905106,16.368283525513498,16.385703686121886,16.40312384673028,16.42054400733867,16.437964167947065,16.455384328555454,16.472804489163845,16.490224649772237,16.507644810380626,16.52506497098902,16.54248513159741,16.5599052922058,16.577325452814193,16.594745613422585,16.612165774030974,16.62958593463937,16.647006095247757,16.664426255856146,16.68184641646454,16.699266577072933,16.716686737681325,16.734106898289713,16.751527058898105,16.7689472195065,16.786367380114886,16.80378754072328,16.821207701331673,16.83862786194006,16.856048022548453,16.873468183156845,16.890888343765234,16.90830850437363,16.925728664982017,16.94314882559041,16.9605689861988,16.977989146807193,16.995409307415585,17.012829468023977,17.03024962863237,17.047669789240757,17.06508994984915,17.08251011045754,17.099930271065933,17.117350431674325,17.134770592282713,17.152190752891105,17.169610913499497,17.18703107410789,17.204451234716277,17.226057935627818,17.25185117684251,17.277644418057204,17.303437659271893,17.32923090048659,17.355024141701275,17.380817382915964,17.40661062413066,17.43240386534535,17.45819710656004,17.483990347774732,17.50978358898942,17.535576830204118,17.561370071418807,17.587163312633496,17.61295655384819,17.63874979506288,17.66454303627757,17.690336277492264,17.71612951870695,17.741922759921643,17.767716001136336,17.79350924235103,17.819302483565718,17.84509572478041,17.8708889659951,17.896682207209793,17.922475448424485,17.94826868963917,17.974061930853864,17.999855172068557,18.02564841328325,18.051441654497935,18.07723489571263,18.102853495280293,18.125765198852605,18.148676902424913,18.171588605997226,18.194500309569538,18.217412013141846,18.240323716714162,18.263235420286474,18.286147123858782,18.309058827431095,18.33197053100341,18.35488223457572,18.37779393814803,18.400705641720343,18.423617345292655,18.446529048864967,18.46944075243728,18.49235245600959,18.515264159581903,18.538175863154216,18.561087566726528,18.583999270298836,18.606910973871152,18.62982267744346,18.652734381015776,18.675646084588085,18.698557788160397,18.72146949173271,18.74438119530502,18.76729289887733,18.79020460244964,18.813116306021954,18.836028009594266,18.858939713166578,18.881851416738886,18.904763120311202,18.927674823883514,18.950586527455823,18.973498231028135,18.996409934600447,19.01932163817276,19.04223334174507,19.065145045317383,19.08805674888969,19.110968452462004,19.13388015603432,19.15679185960663,19.17970356317894,19.202615266751252,19.224473787681134,19.244225943326143,19.263978098971158,19.28373025461617,19.303482410261186,19.323234565906198,19.342986721551213,19.36273887719623,19.38249103284124,19.402243188486256,19.42199534413127,19.441747499776284,19.461499655421292,19.481251811066308,19.50100396671132,19.520756122356335,19.540508278001347,19.560260433646363,19.58001258929138,19.59976474493639,19.619516900581406,19.639269056226418,19.659021211871433,19.67877336751645,19.69852552316146,19.71827767880647,19.739590012784426,19.763495345161644,19.787400677538862,19.811306009916077,19.835211342293295,19.85911667467051,19.883022007047728,19.906927339424946,19.93083267180216,19.95473800417938,19.978643336556594,20.002548668933812,20.02645400131103,20.050359333688245,20.074264666065464,20.09816999844268,20.122075330819897,20.145980663197115,20.169885995574333,20.193791327951548,20.217696660328766,20.241601992705984,20.2655073250832,20.289412657460417,20.313317989837632,20.337223322214847,20.361128654592065,20.385033986969287,20.4089393193465,20.432844651723716,20.456749984100934,20.48065531647815,20.504560648855367,20.528465981232586,20.552371313609804,20.57627664598702,20.600181978364237,20.62408731074145,20.647992643118666,20.671897975495884,20.695803307873106,20.719708640250317,20.743613972627536,20.767519305004754,20.791424637381972,20.815329969759187,20.839235302136405,20.86314063451362,20.887045966890835,20.910951299268053,20.93485663164527,20.958761964022486,20.982667296399704,21.006572628776922,21.030477961154137,21.05438329353135,21.07828862590857,21.07392786935342,20.92823666813642,20.782545466919423,20.636854265702425,20.491163064485455,20.345471863268457,20.199780662051463,20.05408946083449,19.908398259617492,19.762707058400498,19.617015857183528,19.471324655966534,19.325633454749536,19.179942253532538,19.034251052315568,18.88855985109857,18.742868649881572,18.597177448664603,18.451486247447605,18.305795046230607,18.16010384501364,18.014412643796643,17.868721442579645,17.723030241362675,17.577339040145677,17.43164783892868,17.285956637711685,17.134803994796616,16.980980431011062,16.827156867225508,16.673333303439982,16.519509739654428,16.365686175868873,16.211862612083348,16.058039048297797,15.90421548451224,15.750391920726688,15.596568356941162,15.442744793155608,15.288921229370056,15.13509766558453,14.981274101798975,14.827450538013423,14.673626974227897,14.519803410442345,14.36597984665679,14.212156282871264,14.05833271908571,13.904509155300156,13.750685591514603,13.596862027729077,13.443038463943523,13.28921490015797,13.135391336372445,12.98156777258689,12.827744208801338,12.673920645015812,12.506278980689597,12.324545575304592,12.142812169919587,11.961078764534616,11.779345359149612,11.597611953764607,11.415878548379636,11.234145142994633,11.052411737609628,10.870678332224657,10.688944926839651,10.507211521454646,10.325478116069675,10.143744710684672,9.962011305299667,9.780277899914662,9.59854449452969,9.416811089144687,9.235077683759684,9.05334427837471,8.871610872989706,8.689877467604703,8.508144062219731,8.326410656834726,8.144677251449721,7.962943846064717,7.781210440679747],[13.557667854213282,13.573196471919822,13.588725089626363,13.604253707332903,13.619782325039445,13.635310942745988,13.650839560452527,13.666368178159068,13.681896795865612,13.697425413572152,13.712954031278695,13.728482648985235,13.744011266691775,13.759539884398318,13.775068502104858,13.790597119811398,13.80612573751794,13.821654355224481,13.837182972931025,13.852711590637565,13.868240208344105,13.883768826050645,13.899297443757186,13.914826061463728,13.93035467917027,13.945883296876811,13.961411914583353,13.976940532289895,13.992469149996435,14.007997767702978,14.023526385409518,14.03905500311606,14.0545836208226,14.070112238529141,14.085640856235683,14.101169473942223,14.116698091648766,14.132226709355304,14.14775532706185,14.163283944768388,14.178812562474931,14.194341180181471,14.209869797888013,14.225398415594555,14.240927033301093,14.256455651007636,14.271984268714176,14.28751288642072,14.30304150412726,14.318570121833801,14.334098739540343,14.349627358645808,14.368155999201237,14.386684639756666,14.405213280312099,14.423741920867528,14.442270561422959,14.46079920197839,14.479327842533817,14.49785648308925,14.516385123644678,14.534913764200109,14.553442404755542,14.57197104531097,14.590499685866401,14.60902832642183,14.62755696697726,14.646085607532692,14.664614248088121,14.683142888643552,14.70167152919898,14.72020016975441,14.73872881030984,14.757257450865273,14.775786091420702,14.794314731976133,14.812843372531562,14.831372013086993,14.849900653642424,14.868429294197854,14.886957934753283,14.905486575308714,14.924015215864143,14.942543856419574,14.960430708561269,14.978189203020216,14.995947697479162,15.01370619193811,15.031464686397056,15.049223180856002,15.066981675314949,15.084740169773898,15.102498664232844,15.120257158691793,15.138015653150736,15.155774147609684,15.173532642068633,15.191291136527578,15.209049630986526,15.226808125445471,15.244566619904418,15.262325114363367,15.280083608822313,15.297842103281258,15.315600597740206,15.333359092199153,15.351117586658102,15.368876081117048,15.386634575575993,15.40439307003494,15.422151564493888,15.439910058952833,15.45766855341178,15.475427047870728,15.493185542329675,15.510944036788622,15.526836271250776,15.541795373756475,15.556754476262181,15.571713578767884,15.586672681273587,15.60163178377929,15.616590886284992,15.631549988790695,15.646509091296398,15.661468193802103,15.676427296307805,15.691386398813508,15.706345501319209,15.721304603824914,15.736263706330616,15.751222808836319,15.766181911342022,15.781141013847725,15.79610011635343,15.811059218859132,15.826018321364835,15.840977423870537,15.85593652637624,15.870895628881943,15.885854731387646,15.900813833893348,15.915772936399051,15.930732038904754,15.945691141410457,15.96065024391616,15.975609346421866,15.990568448927569,16.00552755143327,16.020486653938974,16.035445756444677,16.05040485895038,16.06536396145608,16.080323063961785,16.095282166467488,16.11024126897319,16.125200371478893,16.140159473984596,16.1551185764903,16.170077678996,16.185036781501704,16.19999588400741,16.214954986513114,16.229914089018813,16.244873191524515,16.259832294030222,16.274791396535925,16.292969587762773,16.31275732335019,16.33254505893761,16.352332794525033,16.372120530112454,16.391908265699872,16.411696001287293,16.431483736874714,16.451271472462132,16.471059208049553,16.490846943636974,16.510634679224395,16.530422414811817,16.550210150399238,16.569997885986655,16.589785621574073,16.609573357161494,16.629361092748915,16.649148828336337,16.668936563923758,16.68872429951118,16.708512035098597,16.728299770686018,16.74808750627344,16.767875241860857,16.787662977448278,16.8074507130357,16.82723844862312,16.84702618421054,16.86681391979796,16.88660165538538,16.9063893909728,16.926177126560223,16.945964862147644,16.96575259773506,16.985540333322483,17.005328068909904,17.025115804497325,17.044903540084743,17.064691275672164,17.08447901125958,17.104266746847003,17.124054482434424,17.14349404672447,17.160914207332866,17.178334367941254,17.195754528549646,17.213174689158038,17.230594849766426,17.24801501037482,17.26543517098321,17.282855331591602,17.300275492199994,17.317695652808386,17.335115813416778,17.352535974025166,17.36995613463356,17.38737629524195,17.40479645585034,17.422216616458734,17.43963677706713,17.457056937675514,17.47447709828391,17.491897258892298,17.50931741950069,17.52673758010908,17.544157740717473,17.56157790132586,17.578998061934257,17.596418222542646,17.613838383151037,17.63125854375943,17.648678704367825,17.666098864976213,17.6835190255846,17.700939186192993,17.718359346801385,17.735779507409777,17.753199668018166,17.770619828626558,17.78803998923495,17.80546014984334,17.822880310451733,17.844487011363274,17.870280252577967,17.896073493792656,17.92186673500735,17.947659976222038,17.973453217436727,17.99924645865142,18.025039699866113,18.050832941080806,18.07662618229549,18.102419423510188,18.128212664724877,18.15400590593957,18.17979914715426,18.205592388368952,18.23138562958364,18.257178870798334,18.282972112013027,18.308765353227717,18.334558594442406,18.3603518356571,18.38614507687179,18.411938318086477,18.43773155930117,18.463524800515863,18.489318041730556,18.515111282945245,18.540904524159938,18.56669776537463,18.59249100658932,18.61828424780401,18.644077489018702,18.66987073023339,18.695663971448084,18.721457212662777,18.747250453877466,18.773043695092156,18.798836936306852,18.82463017752154,18.85042341873623,18.876216659950924,18.902009901165613,18.927803142380306,18.953596383595,18.97938962480969,19.005182866024377,19.03097610723907,19.056769348453763,19.082562589668456,19.10835583088314,19.134149072097834,19.159942313312527,19.18573555452722,19.211528795741906,19.237322036956602,19.26311527817129,19.288908519385984,19.31452712160466,19.337438825176967,19.360350528749283,19.383262232321595,19.406173935893904,19.429085639466216,19.45199734303853,19.47490904661084,19.497820750183152,19.520732453755464,19.543644157327776,19.56655586090008,19.589467564472397,19.612379268044712,19.635290971617025,19.658202675189333,19.681114378761645,19.704026082333957,19.726937785906266,19.74984948947858,19.77276119305089,19.795672896623202,19.818584600195514,19.84149630376783,19.86440800734014,19.88731971091245,19.90917823184233,19.928930387487345,19.948682543132357,19.96843469877737,19.988186854422388,20.007939010067396,20.02769116571241,20.047443321357427,20.067195477002436,20.08694763264745,20.106699788292467,20.12645194393748,20.14620409958249,20.165956255227506,20.18570841087252,20.205460566517534,20.22521272216255,20.24496487780756,20.264717033452577,20.284469189097585,20.3042213447426,20.323973500387616,20.34372565603263,20.363477811677644,20.383229967322656,20.40298212296767,20.422734278612687,20.442486434257695,20.46223858990271,20.481990745547726,20.50174290119274,20.52149505683775,20.541247212482766,20.56099936812778,20.58075152377279,20.60050367941781,20.62025583506282,20.640007990707833,20.65976014635285,20.67951230199786,20.699264457642876,20.719016613287884,20.7387687689329,20.758520924577915,20.77827308022293,20.798025235867946,20.81777739151296,20.83752954715797,20.857281702802982,20.877033858447998,20.89678601409301,20.916538169738025,20.93629032538304,20.956042481028057,20.975794636673065,20.99554679231808,21.01636470317508,21.040270035552293,21.064175367929508,21.088080700306726,21.111986032683944,21.13589136506116,21.15979669743838,21.183702029815592,21.20760736219281,21.23151269457003,21.255418026947247,21.279323359324458,21.303228691701676,21.327134024078898,21.351039356456113,21.374944688833327,21.398850021210546,21.42275535358776,21.44666068596498,21.470566018342197,21.49447135071941,21.518376683096626,21.542282015473845,21.566187347851063,21.59009268022828,21.613998012605496,21.637903344982718,21.63354258842756,21.48785138721056,21.342160185993563,21.19646898477657,21.0507777835596,20.9050865823426,20.759395381125604,20.613704179908638,20.468012978691632,20.32232177747464,20.176630576257672,20.030939375040674,19.885248173823676,19.739556972606678,19.59386577138971,19.44817457017271,19.302483368955713,19.156792167738743,19.011100966521745,18.86540976530475,18.71971856408778,18.57402736287078,18.428336161653785,18.282644960436812,18.136953759219818,17.991262558002823,17.845571356785825,17.699880155568856,17.536890893875075,17.364162387448694,17.19143388102234,17.01870537459596,16.84597686816958,16.673248361743227,16.500519855316846,16.327791348890464,16.155062842464083,15.98233433603773,15.80960582961135,15.636877323184965,15.464148816758616,15.291420310332233,15.11869180390585,14.945963297479501,14.773234791053119,14.600506284626736,14.427777778200387,14.255049271774006,14.082320765347623,13.90959225892124,13.736863752494891,13.564135246068508,13.391406739642125,13.218678233215776,13.045949726789393,12.87322122036301,12.695748197153488,12.514014791768485,12.33228138638348,12.150547980998477,11.968814575613505,11.787081170228502,11.605347764843495,11.423614359458524,11.24188095407352,11.060147548688516,10.878414143303544,10.69668073791854,10.514947332533534,10.333213927148565,10.151480521763558,9.969747116378555,9.788013710993551,9.606280305608578,9.424546900223575,9.24281349483857,9.061080089453599,8.879346684068594,8.69761327868359,8.51587987329862,8.334146467913614,8.152413062528609,7.970679657143606,7.7889462517586345],[14.02755395454919,14.04308257225573,14.05861118996227,14.074139807668814,14.089668425375354,14.105197043081894,14.120725660788436,14.136254278494977,14.151782896201519,14.16731151390806,14.182840131614602,14.198368749321144,14.213897367027682,14.229425984734227,14.244954602440767,14.260483220147307,14.276011837853849,14.29154045556039,14.307069073266932,14.322597690973474,14.338126308680014,14.353654926386554,14.369183544093096,14.384712161799637,14.400240779506177,14.41576939721272,14.431298014919262,14.446826632625802,14.462355250332344,14.477883868038885,14.493412485745425,14.508941103451967,14.524469721158507,14.53999833886505,14.555526956571592,14.572555587596504,14.591084228151935,14.609612868707362,14.628141509262797,14.646670149818224,14.665198790373655,14.683727430929084,14.702256071484513,14.720784712039944,14.739313352595374,14.757841993150805,14.776370633706234,14.794899274261665,14.813427914817094,14.831956555372525,14.850485195927956,14.869013836483386,14.887542477038817,14.906071117594248,14.924599758149677,14.943128398705106,14.961657039260539,14.980185679815968,14.998714320371395,15.017242960926827,15.035771601482256,15.054300242037687,15.07282888259312,15.091357523148549,15.10988616370398,15.128414804259409,15.146943444814838,15.16547208537027,15.1840007259257,15.20252936648113,15.22105800703656,15.239586647591992,15.258115288147419,15.276643928702851,15.29517256925828,15.313701209813711,15.33222985036914,15.350758490924571,15.369287131480002,15.387815772035433,15.406344412590862,15.424873053146293,15.443401693701723,15.461930334257152,15.479817186398847,15.497575680857796,15.515334175316742,15.533092669775689,15.550851164234635,15.56860965869358,15.586368153152529,15.604126647611476,15.621885142070424,15.639643636529371,15.657402130988316,15.675160625447262,15.692919119906211,15.710677614365157,15.728436108824106,15.74619460328305,15.763953097741998,15.781711592200946,15.799470086659891,15.817228581118837,15.834987075577784,15.852745570036733,15.87050406449568,15.888262558954626,15.906021053413575,15.92377954787252,15.941538042331466,15.959296536790415,15.97705503124936,15.994813525708306,16.012572020167255,16.0303305146262,16.04808900908515,16.065847503544095,16.083605998003044,16.10136449246199,16.119122986920935,16.13688148137988,16.15463997583883,16.172398470297775,16.190156964756724,16.20791545921567,16.22567395367462,16.243432448133564,16.26119094259251,16.27894943705146,16.296707931510404,16.314466425969353,16.331758356870026,16.34671745937573,16.36167656188143,16.376635664387134,16.391594766892837,16.40655386939854,16.421512971904242,16.43647207440995,16.451431176915648,16.466390279421354,16.481349381927053,16.49630848443276,16.51126758693846,16.526226689444165,16.541185791949868,16.55614489445557,16.571103996961273,16.586063099466976,16.60102220197268,16.61598130447838,16.630940406984084,16.645899509489787,16.660858611995494,16.675817714501193,16.6907768170069,16.7057359195126,16.720695022018305,16.735654124524004,16.75061322702971,16.76557232953541,16.780531432041116,16.795490534546815,16.81044963705252,16.825408739558224,16.840367842063927,16.85854603329077,16.878333768878193,16.898121504465614,16.917909240053035,16.937696975640456,16.957484711227877,16.9772724468153,16.997060182402716,17.016847917990138,17.036635653577555,17.05642338916498,17.076211124752398,17.09599886033982,17.11578659592724,17.13557433151466,17.155362067102082,17.1751498026895,17.194937538276918,17.214725273864342,17.23451300945176,17.25430074503918,17.274088480626602,17.29387621621402,17.31366395180144,17.333451687388862,17.353239422976284,17.3730271585637,17.392814894151122,17.412602629738544,17.432390365325965,17.452178100913386,17.471965836500807,17.491753572088225,17.511541307675646,17.531329043263064,17.551116778850485,17.570904514437906,17.590692250025327,17.61047998561275,17.63026772120017,17.650055456787587,17.669843192375005,17.689630927962426,17.709418663549847,17.72920639913727,17.74899413472469,17.768781870312107,17.78856960589953,17.80835734148695,17.82814507707437,17.84793281266179,17.86772054824921,17.887508283836627,17.907296019424052,17.92708375501147,17.94687149059889,17.966659226186312,17.98644696177373,18.006234697361155,18.026022432948572,18.045810168535997,18.065597904123415,18.085385639710836,18.105173375298254,18.124961110885675,18.144748846473096,18.162586816452915,18.180006977061304,18.1974271376697,18.214847298278087,18.23226745888648,18.24968761949487,18.267107780103263,18.28452794071165,18.301948101320047,18.319368261928435,18.336788422536827,18.35420858314522,18.371628743753607,18.389048904362,18.40646906497039,18.423889225578783,18.441309386187175,18.462916087098716,18.48870932831341,18.514502569528098,18.54029581074279,18.56608905195748,18.59188229317217,18.617675534386862,18.643468775601555,18.669262016816248,18.695055258030937,18.72084849924563,18.74664174046032,18.772434981675012,18.7982282228897,18.824021464104394,18.849814705319083,18.875607946533773,18.90140118774847,18.92719442896316,18.952987670177848,18.97878091139254,19.004574152607233,19.03036739382192,19.056160635036612,19.081953876251305,19.107747117465998,19.133540358680687,19.15933359989538,19.185126841110073,19.21092008232476,19.23671332353945,19.262506564754144,19.288299805968833,19.314093047183526,19.33988628839822,19.365679529612912,19.391472770827598,19.41726601204229,19.443059253256983,19.468852494471676,19.49464573568637,19.520438976901055,19.546232218115748,19.57202545933044,19.597818700545133,19.62361194175982,19.64940518297451,19.675198424189205,19.700991665403894,19.726784906618587,19.752578147833276,19.77837138904797,19.80416463026266,19.829957871477355,19.855751112692044,19.881544353906733,19.907337595121422,19.933130836336115,19.958924077550808,19.984717318765497,20.01051055998019,20.03630380119488,20.062097042409572,20.087890283624265,20.113683524838954,20.139476766053644,20.16527000726834,20.19106324848303,20.21685648969772,20.24264973091241,20.2684429721271,20.294236213341797,20.320029454556483,20.345822695771176,20.37161593698587,20.397409178200558,20.423202419415247,20.44899566062994,20.47478890184463,20.500582143059326,20.526200747929014,20.549112451501326,20.572024155073635,20.593882676003517,20.613634831648525,20.63338698729354,20.653139142938556,20.67289129858357,20.69264345422858,20.712395609873596,20.73214776551861,20.75189992116362,20.771652076808635,20.79140423245365,20.811156388098663,20.830908543743675,20.850660699388694,20.870412855033706,20.890165010678718,20.909917166323734,20.929669321968746,20.949421477613758,20.969173633258777,20.988925788903785,21.0086779445488,21.028430100193813,21.048182255838828,21.06793441148384,21.087686567128856,21.10743872277387,21.127190878418883,21.1469430340639,21.16669518970891,21.186447345353926,21.206199500998935,21.22595165664395,21.245703812288966,21.265455967933974,21.28520812357899,21.30496027922401,21.32471243486902,21.34446459051403,21.364216746159048,21.38396890180406,21.403721057449076,21.423473213094084,21.4432253687391,21.462977524384115,21.482549180308357,21.501759860377728,21.520970540447095,21.540181220516466,21.559391900585837,21.578602580655208,21.597813260724575,21.617023940793946,21.636234620863316,21.655445300932683,21.674655981002054,21.693866661071425,21.713077341140796,21.732288021210167,21.751498701279534,21.7707093813489,21.78992006141827,21.809130741487643,21.828341421557013,21.84755210162638,21.86676278169575,21.885973461765122,21.905184141834493,21.92439482190386,21.94360550197323,21.9628161820426,21.98202686211197,22.001237542181343,22.02044822225071,22.039658902320078,22.05886958238945,22.07808026245882,22.097290942528186,22.116501622597557,22.135712302666928,22.1549229827363,22.17413366280567,22.193344342875037,22.180312913937403,22.006070939964758,21.83182896599211,21.657866824564664,21.48513831813831,21.31240981171193,21.139681305285546,20.9669527988592,20.79422429243282,20.621495786006435,20.448767279580085,20.276038773153704,20.10331026672732,19.93058176030094,19.75785325387459,19.585124747448205,19.412396241021824,19.23966773459547,19.06693922816909,18.89421072174271,18.721482215316357,18.548753708889976,18.376025202463595,18.203296696037242,18.03056818961086,17.85783968318448,17.685111176758095,17.512382670331746,17.339654163905365,17.166925657478984,16.99419715105263,16.82146864462625,16.64874013819987,16.476011631773517,16.30328312534714,16.130554618920755,15.957826112494374,15.785097606068025,15.612369099641642,15.439640593215259,15.266912086788906,15.094183580362525,14.921455073936144,14.748726567509792,14.57599806108341,14.403269554657028,14.230541048230677,14.057812541804298,13.885084035377915,13.712355528951534,13.539627022525181,13.3668985160988,13.194170009672417,13.021441503246066,12.848712996819685,12.675984490393303,12.503255983966952,12.33052747754057,12.15779897111419,11.985070464687809,11.812341958261458,11.639613451835075,11.466884945408694,11.294156438982343,11.12142793255596,10.94869942612958,10.775970919703228,10.603242413276845,10.430513906850464,10.257785400424115,10.08505689399773,9.91232838757135,9.739599881144967,9.566871374718616,9.394142868292235,9.221414361865852,9.048685855439501,8.87595734901312,8.703228842586737,8.530500336160388,8.357771829734006,8.170133872127927,7.982219094476834,7.794304316825775],[14.497440054885107,14.512968672591647,14.528497290298189,14.54402590800473,14.55955452571127,14.575083143417812,14.590611761124352,14.606140378830894,14.621668996537435,14.637197614243977,14.652726231950519,14.66825484965706,14.6837834673636,14.699312085070142,14.714840702776684,14.730369320483225,14.745897938189765,14.761426555896307,14.776955175991777,14.795483816547208,14.814012457102638,14.832541097658073,14.8510697382135,14.86959837876893,14.888127019324362,14.906655659879792,14.925184300435221,14.94371294099065,14.962241581546081,14.980770222101512,14.999298862656943,15.017827503212372,15.036356143767803,15.054884784323232,15.073413424878664,15.091942065434093,15.110470705989524,15.128999346544955,15.147527987100386,15.166056627655815,15.184585268211244,15.203113908766676,15.221642549322105,15.240171189877536,15.258699830432967,15.277228470988394,15.295757111543825,15.314285752099256,15.332814392654686,15.351343033210116,15.369871673765548,15.388400314320977,15.406928954876406,15.425457595431837,15.443986235987268,15.462514876542699,15.48104351709813,15.49957215765356,15.51810079820899,15.536629438764418,15.555158079319849,15.57368671987528,15.59221536043071,15.61074400098614,15.629272641541569,15.647801282097,15.666329922652428,15.684858563207861,15.70338720376329,15.72191584431872,15.74044448487415,15.75897312542958,15.777501765985011,15.796030406540442,15.814559047095871,15.833087687651304,15.851616328206733,15.870144968762162,15.888673609317593,15.907202249873023,15.925730890428454,15.944259530983883,15.962788171539314,15.981316812094743,15.999203664236438,16.016962158695385,16.03472065315433,16.05247914761328,16.070237642072225,16.08799613653117,16.105754630990116,16.123513125449065,16.141271619908014,16.15903011436696,16.176788608825905,16.194547103284854,16.2123055977438,16.23006409220275,16.247822586661695,16.26558108112064,16.28333957557959,16.301098070038535,16.31885656449748,16.336615058956426,16.354373553415375,16.37213204787432,16.38989054233327,16.407649036792215,16.425407531251164,16.44316602571011,16.460924520169055,16.478683014628004,16.49644150908695,16.5142000035459,16.531958498004844,16.54971699246379,16.56747548692274,16.585233981381684,16.60299247584063,16.62075097029958,16.638509464758524,16.656267959217473,16.67402645367642,16.691784948135364,16.709543442594317,16.727301937053262,16.745060431512208,16.762818925971153,16.7805774204301,16.798335914889048,16.816094409347997,16.833852903806942,16.851611398265888,16.869369892724833,16.88712838718378,16.904886881642724,16.922645376101677,16.940403870560623,16.958162365019568,16.975920859478514,16.99367935393746,17.01143784839641,17.029196342855357,17.046954837314303,17.06471333177325,17.082471826232197,17.100230320691146,17.117988815150092,17.135747309609037,17.151639544994993,17.16659864750069,17.181557750006398,17.196516852512097,17.2114759550178,17.226435057523503,17.241394160029206,17.25635326253491,17.271312365040615,17.286271467546314,17.30123057005202,17.316189672557723,17.331148775063426,17.34610787756913,17.36106698007483,17.376026082580534,17.390985185086237,17.40594428759194,17.42412247881879,17.44391021440621,17.46369794999363,17.483485685581048,17.50327342116847,17.52306115675589,17.54284889234331,17.562636627930733,17.58242436351815,17.60221209910557,17.621999834692993,17.641787570280414,17.66157530586783,17.681363041455253,17.70115077704267,17.72093851263009,17.740726248217513,17.760513983804934,17.780301719392355,17.800089454979776,17.819877190567194,17.83966492615462,17.859452661742036,17.879240397329458,17.899028132916875,17.918815868504296,17.938603604091718,17.95839133967914,17.978179075266556,17.997966810853974,18.017754546441395,18.03754228202882,18.057330017616238,18.07711775320366,18.09690548879108,18.1166932243785,18.136480959965922,18.15626869555334,18.17605643114076,18.19584416672818,18.2156319023156,18.23541963790302,18.255207373490443,18.27499510907786,18.294782844665285,18.314570580252706,18.334358315840124,18.354146051427545,18.373933787014966,18.393721522602384,18.413509258189805,18.433296993777226,18.453084729364644,18.472872464952065,18.492660200539486,18.512447936126907,18.532235671714325,18.552023407301746,18.571811142889167,18.59159887847659,18.611386614064006,18.63117434965143,18.65096208523885,18.67074982082627,18.690537556413688,18.71032529200111,18.73011302758853,18.74990076317595,18.769688498763372,18.78996219836753,18.81047887664241,18.830995554917294,18.851512233192175,18.87202891146706,18.89254558974194,18.91306226801682,18.933578946291703,18.954095624566584,18.974612302841468,18.99512898111635,19.015645659391232,19.036162337666116,19.056679015940997,19.081003209958663,19.109134919719107,19.13726662947956,19.165398339240003,19.193530049000458,19.2216617587609,19.24979346852135,19.277925178281794,19.305159963990686,19.331427473129636,19.357694982268587,19.38396249140754,19.410230000546495,19.43649750968544,19.462765018824395,19.489032527963346,19.515300037102296,19.54156754624125,19.5678350553802,19.594102564519147,19.6203700736581,19.64663758279706,19.672905091936002,19.699172601074956,19.72544011021391,19.751707619352864,19.77797512849181,19.80424263763076,19.830510146769715,19.85677765590866,19.88304516504762,19.909312674186573,19.935580183325516,19.96184769246447,19.98811520160342,20.014382710742375,20.04065021988132,20.066917729020275,20.093185238159226,20.119452747298176,20.14572025643713,20.17198776557608,20.198255274715034,20.224522783853985,20.25079029299294,20.277057802131885,20.303325311270836,20.32959282040979,20.35586032954874,20.382127838687687,20.408395347826648,20.434662856965595,20.460930366104545,20.487197875243503,20.51346538438245,20.539732893521396,20.56600040266035,20.592267911799304,20.618535420938258,20.644802930077205,20.67107043921616,20.697337948355113,20.72360545749406,20.749872966633014,20.776140475771964,20.802407984910914,20.828675494049868,20.854943003188822,20.88121051232777,20.907478021466723,20.933745530605677,20.960013039744624,20.986280548883578,21.012548058022524,21.03881556716148,21.065083076300425,21.09135058543938,21.117618094578333,21.14388560371728,21.170153112856234,21.196420621995188,21.222688131134134,21.24895564027309,21.270771168121517,21.2836827333889,21.29659429865628,21.30950586392367,21.322417429191052,21.335328994458433,21.348240559725816,21.3611521249932,21.374063690260584,21.386975255527968,21.399886820795352,21.412798386062736,21.42570995133012,21.4386215165975,21.451533081864884,21.464444647132268,21.477356212399652,21.490267777667036,21.503179342934416,21.516090908201804,21.529002473469188,21.541914038736568,21.554825604003952,21.56773716927134,21.58064873453872,21.593560299806104,21.606471865073487,21.619383430340868,21.635182080278476,21.65439276034784,21.673603440417214,21.69281412048658,21.71202480055595,21.731235480625323,21.750446160694693,21.769656840764057,21.78886752083343,21.808078200902806,21.82728888097217,21.84649956104154,21.86571024111091,21.884920921180278,21.904131601249652,21.92334228131902,21.94255296138839,21.961763641457758,21.980974321527132,22.000185001596495,22.01939568166587,22.03860636173524,22.057817041804604,22.07702772187398,22.09623840194335,22.115449082012717,22.134659762082087,22.153870442151458,22.17308112222083,22.192291802290192,22.211502482359567,22.230713162428938,22.2499238424983,22.269134522567676,22.288345202637046,22.307555882706414,22.326766562775788,22.345977242845155,22.365187922914522,22.38439860298389,22.403609283053264,22.42281996312263,22.442030643192002,22.461241323261373,22.480452003330743,22.499662683400107,22.518873363469478,22.538084043538852,22.55729472360822,22.576505403677587,22.595716083746957,22.614926763816328,22.6341374438857,22.653348123955066,22.672558804024437,22.659527375086803,22.485285401114155,22.311043427141513,22.136801453168868,21.96255947919626,21.78831750522361,21.61407553125097,21.439833557278355,21.26559158330571,21.091349609333065,20.917107635360452,20.742865661387807,20.568623687415162,20.39438171344252,20.220139739469907,20.045897765497262,19.871655791524617,19.697413817552007,19.523171843579362,19.348929869606717,19.174687895634104,19.00044592166146,18.826203947688814,18.651961973716205,18.477719999743556,18.30347802577091,18.12923605179827,17.954994077825656,17.78075210385301,17.60651012988037,17.432268155907757,17.25802618193511,17.08378420796247,16.910354148685244,16.73762564225886,16.564897135832474,16.392168629406093,16.219440122979744,16.04671161655336,15.873983110126979,15.70125460370063,15.528526097274247,15.355797590847864,15.183069084421515,15.010340577995132,14.83761207156875,14.6648835651424,14.492155058716019,14.319426552289638,14.146698045863257,13.973969539436904,13.79167054259452,13.603755764943426,13.415840987292366,13.227926209641272,13.040011431990179,12.852096654339121,12.664181876688028,12.476267099036935,12.28835232138584,12.100437543734781,11.912522766083686,11.724607988432593,11.536693210781534,11.348778433130443,11.160863655479346,10.97294887782829,10.785034100177196,10.597119322526101,10.409204544875042,10.221289767223947,10.033374989572856,9.845460211921761,9.657545434270704,9.469630656619609,9.281715878968516,9.093801101317457,8.905886323666364,8.71797154601527,8.530056768364211,8.342141990713117,8.154227213062024,7.966312435410929,7.7783976577598715],[14.967326155221023,14.982854772927565,14.999883404942485,15.018412045497914,15.036940686053345,15.055469326608776,15.073997967164207,15.092526607719636,15.111055248275067,15.129583888830497,15.148112529385928,15.166641169941357,15.185169810496788,15.203698451052219,15.222227091607648,15.240755732163079,15.259284372718508,15.277813013273938,15.29634165382937,15.314870294384798,15.333398934940229,15.35192757549566,15.370456216051089,15.38898485660652,15.407513497161949,15.426042137717381,15.444570778272812,15.46309941882824,15.481628059383672,15.500156699939101,15.518685340494532,15.537213981049963,15.55574262160539,15.574271262160822,15.592799902716251,15.611328543271682,15.629857183827113,15.64838582438254,15.666914464937975,15.685443105493402,15.703971746048833,15.722500386604263,15.741029027159694,15.759557667715125,15.778086308270554,15.796614948825983,15.815143589381416,15.833672229936846,15.852200870492275,15.870729511047703,15.889258151603135,15.907786792158568,15.926315432713995,15.944844073269426,15.963372713824855,15.981901354380287,16.000429994935715,16.018958635491146,16.037487276046576,16.056015916602007,16.074544557157438,16.09307319771287,16.1116018382683,16.13013047882373,16.148659119379158,16.167187759934592,16.18571640049002,16.20424504104545,16.22277368160088,16.24130232215631,16.259830962711742,16.27835960326717,16.2968882438226,16.31541688437803,16.333945524933462,16.352474165488893,16.37100280604432,16.38953144659975,16.40806008715518,16.426588727710612,16.445117368266043,16.463646008821474,16.482174649376905,16.500703289932336,16.518590142074025,16.536348636532974,16.55410713099192,16.57186562545087,16.589624119909814,16.607382614368763,16.62514110882771,16.642899603286654,16.660658097745603,16.67841659220455,16.696175086663498,16.713933581122443,16.73169207558139,16.749450570040338,16.767209064499283,16.784967558958233,16.802726053417178,16.820484547876124,16.838243042335073,16.856001536794018,16.873760031252964,16.89151852571191,16.909277020170858,16.927035514629807,16.944794009088753,16.9625525035477,16.980310998006647,16.998069492465593,17.015827986924542,17.033586481383487,17.051344975842433,17.069103470301382,17.086861964760327,17.104620459219277,17.122378953678222,17.140137448137168,17.157895942596117,17.175654437055062,17.19341293151401,17.211171425972957,17.228929920431902,17.246688414890848,17.264446909349797,17.282205403808742,17.29996389826769,17.317722392726637,17.335480887185582,17.353239381644528,17.370997876103477,17.388756370562426,17.40651486502137,17.424273359480317,17.442031853939266,17.45979034839821,17.47754884285716,17.495307337316106,17.51306583177505,17.530824326234,17.548582820692946,17.56634131515189,17.58409980961084,17.601858304069786,17.61961679852873,17.63737529298768,17.655133787446626,17.672892281905575,17.69065077636452,17.708409270823466,17.726167765282415,17.74392625974136,17.76168475420031,17.779443248659256,17.7972017431182,17.81496023757715,17.832718732036096,17.85047722649504,17.86823572095399,17.885994215412936,17.90375270987188,17.92151120433083,17.93926969878978,17.95656163061425,17.971520733119952,17.989698924346804,18.009486659934222,18.029274395521643,18.049062131109064,18.068849866696485,18.088637602283903,18.109093538020986,18.129610216295866,18.15012689457075,18.17064357284563,18.191160251120515,18.21167692939539,18.232193607670276,18.252710285945156,18.273226964220044,18.293743642494924,18.314260320769808,18.334776999044685,18.355293677319573,18.37581035559445,18.396327033869333,18.416843712144217,18.437360390419094,18.457877068693982,18.478393746968862,18.498910425243743,18.519427103518623,18.539943781793507,18.560460460068388,18.580977138343272,18.601493816618156,18.622010494893036,18.642527173167917,18.6630438514428,18.68356052971768,18.70407720799256,18.72459388626745,18.745110564542326,18.76562724281721,18.78614392109209,18.80666059936697,18.827177277641855,18.84769395591674,18.86821063419162,18.888727312466504,18.909243990741388,18.929760669016265,18.950277347291145,18.97079402556603,18.99131070384091,19.011827382115793,19.032344060390677,19.052860738665558,19.07337741694044,19.09389409521532,19.114410773490203,19.134927451765087,19.155444130039967,19.175960808314848,19.196477486589732,19.216994164864612,19.237510843139496,19.258027521414377,19.278544199689257,19.29906087796414,19.31957755623902,19.340094234513906,19.36061091278879,19.38112759106367,19.40164426933855,19.42216094761343,19.442677625888315,19.463194304163196,19.48371098243808,19.50422766071296,19.524744338987844,19.545261017262725,19.56577769553761,19.58629437381249,19.60681105208737,19.627327730362254,19.647844408637134,19.668361086912018,19.69268528092968,19.720816990690132,19.74894870045058,19.777080410211024,19.805212119971475,19.833343829731923,19.861475539492368,19.88960724925282,19.91773895901327,19.94587066877372,19.974002378534163,20.00213408829461,20.030265798055062,20.05839750781551,20.086529217575958,20.114660927336402,20.142792637096854,20.170924346857298,20.19905605661775,20.227187766378194,20.255319476138645,20.283451185899096,20.31158289565954,20.339714605419985,20.367846315180437,20.395978024940884,20.424109734701332,20.452241444461784,20.48037315422223,20.508504863982672,20.536636573743124,20.564768283503575,20.59289999326402,20.62103170302447,20.649163412784915,20.677295122545367,20.705426832305815,20.733558542066262,20.76169025182671,20.78982196158716,20.817953671347603,20.846085381108054,20.874217090868502,20.90234880062895,20.929214261747248,20.9554817708862,20.98174928002515,21.008016789164103,21.034284298303053,21.060551807442003,21.086819316580954,21.113086825719904,21.139354334858858,21.16562184399781,21.191889353136762,21.21815686227571,21.24442437141466,21.270691880553617,21.296959389692567,21.323226898831518,21.349494407970468,21.37576191710942,21.40202942624837,21.428296935387323,21.454564444526273,21.480831953665223,21.507099462804177,21.53336697194313,21.559634481082078,21.585901990221032,21.612169499359986,21.638437008498936,21.664704517637887,21.690972026776837,21.717239535915787,21.743507045054738,21.769774554193692,21.796042063332642,21.822309572471593,21.848577081610543,21.874844590749497,21.901112099888447,21.927379609027398,21.949195136875826,21.96210670214321,21.975018267410594,21.987929832677978,22.00084139794536,22.01375296321274,22.026664528480126,22.03957609374751,22.052487659014893,22.065399224282277,22.07831078954966,22.091222354817045,22.10413392008443,22.117045485351813,22.129957050619197,22.142868615886577,22.155780181153965,22.168691746421345,22.18160331168873,22.194514876956116,22.207426442223497,22.22033800749088,22.23324957275826,22.24616113802565,22.25907270329303,22.271984268560416,22.284895833827797,22.29780739909518,22.310718964362565,22.32363052962995,22.336542094897332,22.349453660164713,22.3623652254321,22.37527679069948,22.388188355966868,22.40109992123425,22.414011486501632,22.426923051769016,22.439834617036396,22.452746182303784,22.465657747571168,22.478569312838548,22.491480878105932,22.50439244337332,22.5173040086407,22.53021557390808,22.543127139175468,22.556038704442848,22.568950269710232,22.581861834977616,22.594773400245,22.607684965512384,22.62059653077977,22.63350809604715,22.646419661314532,22.65933122658192,22.672242791849303,22.685154357116684,22.698065922384068,22.710977487651455,22.729138303647705,22.748348983717076,22.767559663786443,22.786770343855814,22.80598102392518,22.82519170399455,22.844402384063926,22.863613064133293,22.882823744202664,22.90203442427203,22.921245104341402,22.94045578441077,22.95966646448014,22.978877144549507,22.99808782461888,23.017298504688252,23.03650918475762,23.05571986482699,23.074930544896358,23.09414122496573,23.113351905035096,23.132562585104466,23.151773265173837,23.138741836236203,22.96449986226356,22.79025788829091,22.61601591431827,22.44177394034566,22.26753196637301,22.09328999240037,21.91904801842776,21.74480604445511,21.57056407048247,21.396322096509856,21.222080122537207,21.047838148564566,20.873596174591917,20.699354200619304,20.525112226646662,20.350870252674017,20.176628278701408,20.002386304728766,19.828144330756118,19.653902356783505,19.479660382810863,19.29535432602767,19.105665148986212,18.915975971944725,18.72628679490323,18.536597617861744,18.346908440820286,18.1572192637788,17.967530086737305,17.777840909695854,17.58815173265436,17.398462555612873,17.208773378571415,17.019084201529928,16.829395024488438,16.639705847446947,16.45001667040549,16.260327493364,16.070638316322512,15.880949139281055,15.691259962239565,15.501570785198075,15.311881608156618,15.122192431115128,14.932503254073637,14.742814077032182,14.553124899990694,14.363435722949204,14.173746545907713,13.984057368866257,13.794368191824766,13.604679014783276,13.414989837741823,13.225300660700333,13.035611483658842,12.845922306617386,12.656233129575895,12.466543952534408,12.276854775492918,12.087165598451461,11.897476421409971,11.70870132936669,11.52078655171563,11.33287177406454,11.144956996413445,10.957042218762385,10.76912744111129,10.581212663460198,10.393297885809138,10.205383108158046,10.01746833050695,9.82955355285586,9.6416387752048,9.453723997553706,9.265809219902613,9.077894442251552,8.88997966460046,8.702064886949366,8.514150109298306,8.326235331647215,8.13832055399612,7.9504057763450255,7.762490998693966],[15.43682106070483,15.455349701260259,15.47387834181569,15.492406982371119,15.510935622926551,15.52946426348198,15.547992904037411,15.56652154459284,15.585050185148273,15.603578825703702,15.62210746625913,15.640636106814561,15.659164747369992,15.677693387925423,15.69622202848085,15.714750669036281,15.733279309591712,15.751807950147143,15.770336590702573,15.788865231258004,15.807393871813433,15.825922512368864,15.844451152924293,15.862979793479726,15.881508434035155,15.900037074590585,15.918565715146014,15.937094355701444,15.955622996256876,15.974151636812307,15.992680277367738,16.011208917923167,16.029737558478594,16.04826619903403,16.066794839589456,16.085323480144886,16.103852120700317,16.122380761255748,16.14090940181118,16.159438042366606,16.177966682922037,16.196495323477468,16.2150239640329,16.23355260458833,16.252081245143756,16.270609885699187,16.289138526254618,16.30766716681005,16.32619580736548,16.344724447920907,16.36325308847634,16.38178172903177,16.4003103695872,16.41883901014263,16.43736765069806,16.45589629125349,16.474424931808922,16.49295357236435,16.51148221291978,16.53001085347521,16.548539494030642,16.567068134586073,16.585596775141504,16.60412541569693,16.62265405625236,16.641182696807792,16.659711337363223,16.678239977918654,16.69676861847408,16.717596284766906,16.73888375461596,16.76017122446501,16.78145869431407,16.802746164163125,16.824033634012178,16.845321103861234,16.866608573710288,16.88789604355934,16.909183513408397,16.93047098325745,16.951758453106507,16.97304592295556,16.994333392804617,17.01562086265367,17.036213792178582,17.05666781363867,17.077121835098755,17.09757585655884,17.11802987801893,17.138483899479017,17.158937920939103,17.17939194239919,17.199845963859275,17.22029998531936,17.240754006779447,17.261208028239533,17.28166204969962,17.302116071159706,17.322570092619795,17.340777842874537,17.358536337333486,17.376294831792432,17.39405332625138,17.411811820710327,17.429570315169272,17.44732880962822,17.465087304087167,17.482845798546116,17.50060429300506,17.518362787464007,17.536121281922956,17.5538797763819,17.57163827084085,17.589396765299796,17.60715525975874,17.624913754217687,17.642672248676636,17.660430743135585,17.67818923759453,17.695947732053476,17.71370622651242,17.73146472097137,17.74922321543032,17.766981709889265,17.78474020434821,17.80249869880716,17.82025719326611,17.838015687725054,17.855774182184,17.873532676642945,17.891291171101894,17.90904966556084,17.92680816001979,17.944566654478734,17.96232514893768,17.980083643396625,17.997842137855574,18.015600632314523,18.03335912677347,18.051117621232414,18.068876115691364,18.08663461015031,18.104393104609258,18.1221515990682,18.13991009352715,18.157668587986095,18.175427082445044,18.193185576903993,18.21094407136294,18.228702565821884,18.24646106028083,18.26421955473978,18.281978049198724,18.29973654365767,18.317495038116615,18.335253532575564,18.353012027034513,18.37077052149346,18.388529015952404,18.406287510411353,18.4240460048703,18.441804499329248,18.459562993788193,18.47732148824714,18.495079982706088,18.512838477165033,18.53059697162398,18.55143289743855,18.573807538930925,18.596182180423305,18.618556821915682,18.640931463408062,18.663306104900443,18.68568074639282,18.7080553878852,18.730430029377576,18.752804670869953,18.775179312362333,18.79755395385471,18.81992859534709,18.842303236839467,18.864677878331847,18.887052519824223,18.9094271613166,18.93180180280898,18.95417644430136,18.976551085793737,18.998925727286117,19.021300368778494,19.04367501027087,19.066049651763255,19.08842429325563,19.110592496214753,19.131109174489637,19.151625852764518,19.1721425310394,19.192659209314282,19.213175887589163,19.23369256586404,19.254209244138927,19.274725922413808,19.29524260068869,19.315759278963576,19.336275957238456,19.356792635513337,19.377309313788217,19.3978259920631,19.418342670337978,19.438859348612866,19.459376026887746,19.479892705162626,19.500409383437507,19.520926061712395,19.541442739987275,19.561959418262155,19.58247609653704,19.60299277481192,19.623509453086804,19.644026131361684,19.664542809636565,19.68505948791145,19.70557616618633,19.72609284446121,19.746609522736094,19.767126201010978,19.78764287928586,19.808159557560742,19.828676235835623,19.849192914110507,19.869709592385387,19.89022627066027,19.910742948935148,19.931259627210032,19.951776305484913,19.972292983759793,19.992809662034677,20.01332634030956,20.033843018584445,20.054359696859326,20.07487637513421,20.09539305340909,20.11590973168397,20.13642640995885,20.156943088233735,20.177459766508616,20.1979764447835,20.21849312305838,20.23900980133326,20.259526479608144,20.280043157883025,20.30436735190069,20.332499061661142,20.360630771421587,20.388762481182034,20.416894190942486,20.445025900702937,20.47315761046338,20.50128932022383,20.529421029984277,20.55755273974472,20.58568444950517,20.61381615926562,20.641947869026065,20.670079578786517,20.698211288546965,20.726342998307416,20.754474708067857,20.78260641782831,20.810738127588756,20.838869837349208,20.867001547109652,20.895133256870103,20.923264966630548,20.951396676391,20.97952838615145,21.007660095911895,21.03579180567234,21.06392351543279,21.09205522519324,21.120186934953686,21.148318644714138,21.176450354474586,21.20458206423503,21.232713773995478,21.26084548375593,21.288977193516374,21.317108903276825,21.345240613037273,21.37337232279772,21.401504032558165,21.429635742318617,21.45776745207906,21.485899161839512,21.514030871599964,21.542162581360408,21.570294291120856,21.598426000881304,21.626557710641755,21.6546894204022,21.682821130162647,21.710952839923095,21.739084549683547,21.76721625944399,21.795347969204443,21.82347967896489,21.851611388725335,21.879743098485786,21.907874808246238,21.936006518006685,21.96413822776713,21.992269937527578,22.020401647288026,22.048533357048473,22.076665066808925,22.104796776569373,22.132928486329817,22.161060196090265,22.18919190585072,22.217323615611164,22.245455325371612,22.27358703513206,22.301718744892504,22.329850454652952,22.357982164413404,22.38611387417385,22.414245583934296,22.44237729369475,22.470509003455195,22.49864071321564,22.526772422976094,22.5532685595038,22.57953606864275,22.605803577781696,22.627619105630124,22.640530670897512,22.65344223616489,22.666353801432273,22.67926536669966,22.692176931967044,22.705088497234424,22.71800006250181,22.730911627769192,22.743823193036576,22.75673475830396,22.769646323571344,22.78255788883873,22.795469454106108,22.808381019373492,22.82129258464088,22.83420414990826,22.847115715175647,22.860027280443028,22.872938845710408,22.885850410977795,22.89876197624518,22.911673541512563,22.924585106779947,22.93646913370817,22.94817772925842,22.959886324808664,22.97159492035891,22.983303515909157,22.995012111459403,23.006720707009652,23.0184293025599,23.030137898110144,23.04184649366039,23.053555089210633,23.065263684760883,23.076972280311132,23.08868087586137,23.100389471411624,23.11209806696187,23.123806662512116,23.135515258062362,23.147223853612612,23.158932449162858,23.1706410447131,23.18234964026335,23.194058235813596,23.205766831363842,23.217475426914092,23.229184022464338,23.240892618014584,23.25260121356483,23.264309809115076,23.276018404665322,23.28772700021557,23.299435595765814,23.311144191316064,23.32285278686631,23.334561382416556,23.346269977966806,23.357978573517048,23.369687169067294,23.381395764617544,23.393104360167793,23.404812955718036,23.416521551268282,23.42823014681853,23.439938742368778,23.451647337919024,23.46335593346927,23.475064529019516,23.486773124569766,23.49848172012001,23.510190315670258,23.5218989112205,23.53360750677075,23.545316102321,23.557024697871242,23.568733293421488,23.580441888971738,23.59215048452198,23.60385908007223,23.615567675622476,23.59188067369925,23.391215684408674,23.190550695118098,22.989885705827522,22.78922071653698,22.588555727246405,22.38789073795583,22.18722574866529,21.988847363232573,21.799158186191082,21.609469009149628,21.419779832108137,21.230090655066647,21.040401478025156,20.850712300983698,20.661023123942208,20.471333946900717,20.281644769859263,20.091955592817772,19.902266415776282,19.71257723873483,19.522888061693344,19.33319888465185,19.143509707610395,18.953820530568905,18.764131353527414,18.574442176485924,18.38475299944447,18.19506382240298,18.00537464536149,17.815685468320034,17.62599629127854,17.436307114237053,17.246617937195598,17.056928760154108,16.867239583112617,16.677550406071127,16.487861229029672,16.298172051988182,16.10848287494669,15.918793697905237,15.729104520863746,15.539415343822256,15.349726166780801,15.16003698973931,14.97034781269782,14.780658635656364,14.590969458614875,14.401280281573385,14.211591104531895,14.02190192749044,13.83221275044895,13.642523573407459,13.452834396366004,13.263145219324514,13.073456042283023,12.883766865241569,12.694077688200078,12.504388511158588,12.314699334117098,12.125010157075643,11.935320980034152,11.745631802992662,11.555942625951207,11.366253448909717,11.176564271868227,10.98687509482677,10.79718591778528,10.607496740743793,10.417807563702336,10.228118386660846,10.038429209619355,9.848740032577865,9.659050855536409,9.469361678494918,9.279672501453428,9.08758242810474,8.89538797360346,8.703193519102182,8.510999064600938,8.318804610099658,8.126610155598378,7.934415701097098,7.742221246595854],[15.90627684673144,15.924805487286871,15.943334127842302,15.961862768397731,15.980391408953164,15.998920049508591,16.017448690064022,16.035977330619453,16.054505971174883,16.073034611730314,16.091563252285745,16.110091892841172,16.128620533396603,16.147149173952034,16.165677814507465,16.184206455062895,16.202735095618326,16.221263736173754,16.239792376729184,16.258321017284615,16.276849657840046,16.295378298395477,16.313906938950904,16.33243557950634,16.350964220061766,16.369492860617196,16.38802150117263,16.406550141728054,16.42507878228349,16.443607422838916,16.462136063394347,16.480664703949778,16.49919334450521,16.51772198506064,16.53625062561607,16.5547792661715,16.57330790672693,16.59183654728236,16.610365187837793,16.62889382839322,16.64742246894865,16.665951109504082,16.68447975005951,16.70300839061494,16.72153703117037,16.7400656717258,16.758594312281232,16.777122952836663,16.79565159339209,16.81418023394752,16.832708874502952,16.851237515058383,16.87068576520023,16.891973235049285,16.913260704898338,16.934548174747395,16.955835644596448,16.977123114445504,16.998410584294554,17.01969805414361,17.040985523992667,17.06227299384172,17.083560463690777,17.10484793353983,17.126135403388886,17.14742287323794,17.168710343086993,17.18999781293605,17.211285282785102,17.232572752634155,17.253860222483212,17.275147692332265,17.296435162181318,17.317722632030375,17.33901010187943,17.360297571728484,17.381585041577537,17.402872511426594,17.424159981275647,17.4454474511247,17.466734920973757,17.48802239082281,17.509309860671866,17.53059733052092,17.551190260045836,17.57164428150592,17.592098302966008,17.612552324426094,17.63300634588618,17.653460367346266,17.673914388806352,17.69436841026644,17.714822431726525,17.735276453186614,17.755730474646697,17.776184496106787,17.796638517566873,17.81709253902696,17.837546560487045,17.85800058194713,17.878454603407217,17.898908624867303,17.91936264632739,17.939816667787476,17.96027068924756,17.980724710707648,18.001178732167734,18.02163275362782,18.04208677508791,18.062540796547992,18.082994818008082,18.103448839468168,18.123902860928254,18.14435688238834,18.164810903848426,18.184366416134097,18.202124910593042,18.219883405051988,18.237641899510937,18.255400393969886,18.27315888842883,18.290917382887777,18.308675877346722,18.32643437180567,18.34419286626462,18.361951360723566,18.379709855182515,18.39746834964146,18.415226844100403,18.432985338559355,18.4507438330183,18.468502327477246,18.486260821936195,18.504019316395137,18.521777810854086,18.539536305313035,18.55729479977198,18.575053294230926,18.592811788689872,18.61057028314882,18.62832877760777,18.646087272066715,18.66384576652566,18.681604260984606,18.699362755443556,18.7171212499025,18.73487974436145,18.752638238820396,18.77039673327934,18.788155227738294,18.80591372219724,18.823672216656185,18.84143071111513,18.859189205574076,18.87694770003302,18.89470619449197,18.912464688950916,18.930223183409865,18.94798167786881,18.965740172327756,18.983498666786705,19.001257161245654,19.0190156557046,19.036774150163545,19.05453264462249,19.07229113908144,19.09004963354039,19.110885559354955,19.13326020084733,19.155634842339712,19.178009483832092,19.20038412532447,19.22275876681685,19.245133408309226,19.267508049801606,19.289882691293982,19.31225733278636,19.33463197427874,19.35700661577112,19.379381257263496,19.401755898755873,19.424130540248253,19.44650518174063,19.46887982323301,19.491254464725387,19.513629106217767,19.536003747710144,19.558378389202524,19.5807530306949,19.60312767218728,19.625502313679657,19.647876955172034,19.670251596664414,19.69262623815679,19.71500087964917,19.737375521141548,19.759750162633928,19.78212480412631,19.804499445618685,19.826874087111065,19.849248728603445,19.871623370095822,19.8939980115882,19.916372653080575,19.938747294572956,19.961121936065336,19.983496577557716,20.00587121905009,20.02824586054247,20.05062050203485,20.072995143527226,20.095369785019606,20.117744426511983,20.14011906800436,20.16249370949674,20.184868350989113,20.207242992481497,20.229617633973874,20.25199227546625,20.274366916958634,20.29674155845101,20.31725823715735,20.337774915432234,20.358291593707115,20.378808271982,20.39932495025688,20.419841628531763,20.440358306806644,20.460874985081524,20.48139166335641,20.50190834163129,20.522425019906173,20.542941698181053,20.563458376455934,20.583975054730818,20.6044917330057,20.625008411280582,20.645525089555463,20.666041767830347,20.686558446105227,20.707075124380108,20.72759180265499,20.748108480929872,20.768625159204756,20.789141837479637,20.80965851575452,20.8301751940294,20.85069187230428,20.871208550579166,20.891725228854046,20.916049422871712,20.944181132632163,20.972312842392608,21.000444552153056,21.028576261913507,21.05670797167395,21.0848396814344,21.112971391194847,21.141103100955302,21.169234810715743,21.197366520476194,21.225498230236646,21.253629939997094,21.281761649757538,21.30989335951799,21.338025069278437,21.36615677903888,21.394288488799333,21.42242019855978,21.45055190832023,21.478683618080673,21.506815327841124,21.53494703760157,21.56307874736202,21.591210457122468,21.619342166882916,21.647473876643364,21.67560558640381,21.70373729616426,21.731869005924707,21.76000071568516,21.788132425445607,21.816264135206048,21.8443958449665,21.87252755472695,21.900659264487395,21.928790974247846,21.956922684008294,21.985054393768742,22.013186103529186,22.041317813289638,22.069449523050082,22.097581232810533,22.125712942570978,22.153844652331433,22.18303036822302,22.21256217715069,22.242093986078366,22.271625795006038,22.301157603933703,22.33068941286138,22.36022122178905,22.38975303071672,22.41928483964439,22.448816648572066,22.47834845749973,22.507880266427403,22.53741207535508,22.56694388428275,22.596475693210422,22.62600750213809,22.655539311065763,22.68507111999343,22.714602928921103,22.744134737848775,22.773666546776447,22.80319835570412,22.83273016463179,22.862261973559463,22.891793782487134,22.921325591414806,22.950857400342475,22.980389209270147,23.009921018197822,23.039452827125487,23.06898463605316,23.098516444980834,23.128048253908503,23.157580062836175,23.187111871763847,23.21664368069152,23.24617548961919,23.27570729854686,23.29651148724208,23.299860435472397,23.303209383702715,23.306558331933033,23.30990728016335,23.313256228393673,23.31660517662399,23.319954124854313,23.323303073084627,23.32665202131495,23.330000969545267,23.333349917775585,23.336698866005904,23.340047814236225,23.343396762466543,23.34674571069686,23.350094658927183,23.3534436071575,23.35679255538782,23.360141503618138,23.363490451848456,23.366839400078774,23.370188348309092,23.37353729653941,23.37688624476973,23.38023519300005,23.383584141230365,23.386933089460687,23.390282037691005,23.393630985921323,23.399815363746285,23.411523959296527,23.423232554846777,23.434941150397027,23.446649745947273,23.458358341497515,23.47006693704776,23.481775532598014,23.493484128148253,23.505192723698503,23.516901319248753,23.528609914798995,23.54031851034924,23.55202710589949,23.56373570144974,23.575444296999983,23.58715289255023,23.59886148810048,23.61057008365072,23.622278679200967,23.63398727475122,23.645695870301466,23.657404465851712,23.669113061401955,23.680821656952205,23.69253025250245,23.7042388480527,23.715947443602943,23.727656039153192,23.73936463470344,23.751073230253684,23.762781825803934,23.77449042135418,23.786199016904423,23.797907612454672,23.809616208004922,23.821324803555164,23.833033399105414,23.84474199465566,23.856450590205906,23.868159185756152,23.879867781306398,23.891576376856648,23.90328497240689,23.91499356795714,23.926702163507386,23.938410759057632,23.950119354607878,23.96182795015812,23.97353654570837,23.985245141258616,23.996953736808862,24.008662332359112,23.984975330435887,23.784310341145307,23.583645351854727,23.382980362564155,23.182315373273617,22.981650383983038,22.780985394692458,22.58032040540192,22.379655416111348,22.178990426820768,21.97832543753023,21.77766044823965,21.57699545894907,21.376330469658498,21.175665480367954,20.97500049107738,20.7743355017868,20.573670512496264,20.373005523205688,20.17234053391511,19.971675544624567,19.771010555333994,19.570345566043414,19.369680576752874,19.1690155874623,18.96835059817172,18.767685608881145,18.567020619590604,18.366355630300028,18.16569064100945,17.96502565171891,17.764360662428334,17.563695673137758,17.363030683847217,17.16236569455664,16.96170070526606,16.76103571597549,16.560370726684948,16.35970573739437,16.159040748103795,15.964778288793418,15.775089111751928,15.585399934710438,15.395710757668983,15.204560162575387,15.012365708074107,14.820171253572862,14.627976799071583,14.435782344570303,14.243587890069024,14.05139343556778,13.859198981066498,13.667004526565218,13.474810072063974,13.282615617562694,13.090421163061416,12.89822670856017,12.706032254058892,12.51383779955761,12.32164334505633,12.129448890555087,11.937254436053808,11.745059981552528,11.552865527051283,11.360671072550002,11.168476618048723,10.976282163547479,10.784087709046197,10.591893254544917,10.399698800043673,10.207504345542395,10.015309891041115,9.823115436539835,9.63092098203859,9.43872652753731,9.24653207303603,9.054337618534786,8.862143164033506,8.669948709532227,8.477754255030982,8.285559800529702,8.093365346028422,7.901170891527143,7.708976437025899],[16.375732632758044,16.394261273313475,16.412789913868906,16.431318554424337,16.449847194979764,16.4683758355352,16.486904476090626,16.505433116646053,16.523961757201487,16.542490397756914,16.561019038312345,16.579547678867776,16.598076319423207,16.616604959978638,16.63513360053407,16.6536622410895,16.672190881644926,16.69071952220036,16.709248162755788,16.72777680331122,16.74630544386665,16.764834084422077,16.783362724977508,16.80189136553294,16.82042000608837,16.8389486466438,16.85747728719923,16.87600592775466,16.894534568310092,16.91306320886552,16.931591849420954,16.95012048997638,16.968649130531812,16.987177771087243,17.00570641164267,17.0242350521981,17.0450627154826,17.066350185331654,17.08763765518071,17.108925125029764,17.13021259487882,17.151500064727877,17.172787534576926,17.194075004425983,17.215362474275036,17.23664994412409,17.257937413973146,17.279224883822202,17.300512353671255,17.32179982352031,17.343087293369365,17.364374763218418,17.385662233067475,17.406949702916528,17.428237172765584,17.449524642614637,17.47081211246369,17.492099582312747,17.5133870521618,17.534674522010853,17.55596199185991,17.577249461708966,17.59853693155802,17.619824401407072,17.64111187125613,17.662399341105182,17.683686810954235,17.70497428080329,17.726261750652345,17.747549220501398,17.768836690350454,17.790124160199507,17.811411630048564,17.832699099897617,17.853986569746674,17.875274039595727,17.896561509444783,17.917848979293836,17.93913644914289,17.960423918991943,17.981711388841,18.002998858690056,18.024286328539112,18.045573798388165,18.066166727913075,18.086620749373168,18.10707477083325,18.127528792293337,18.147982813753423,18.168436835213512,18.188890856673595,18.209344878133685,18.229798899593767,18.250252921053857,18.270706942513943,18.291160963974026,18.311614985434115,18.332069006894198,18.352523028354288,18.372977049814374,18.393431071274456,18.413885092734546,18.434339114194636,18.454793135654718,18.475247157114804,18.49570117857489,18.516155200034977,18.536609221495063,18.55706324295515,18.577517264415235,18.597971285875325,18.618425307335407,18.638879328795493,18.659333350255583,18.67978737171567,18.70024139317576,18.72069541463584,18.741149436095924,18.761603457556014,18.7820574790161,18.802511500476186,18.822965521936275,18.843419543396358,18.863873564856448,18.88432758631653,18.90478160777662,18.925235629236706,18.945689650696792,18.96614367215688,18.986597693616964,19.00705171507705,19.02750573653714,19.045713483852587,19.063471978311533,19.081230472770482,19.09898896722943,19.116747461688377,19.134505956147322,19.15226445060627,19.170022945065217,19.187781439524166,19.20553993398311,19.223298428442057,19.241056922901002,19.258815417359955,19.2765739118189,19.294332406277846,19.31209090073679,19.329849395195737,19.347607889654686,19.365366384113635,19.38312487857258,19.400883373031526,19.41864186749047,19.436400361949417,19.454158856408366,19.471917350867315,19.48967584532626,19.507434339785206,19.52519283424415,19.5429513287031,19.56070982316205,19.578468317620995,19.59622681207994,19.61398530653889,19.631743800997835,19.649502295456784,19.67033822127135,19.692712862763727,19.715087504256108,19.737462145748488,19.759836787240864,19.78221142873324,19.80458607022562,19.826960711718,19.84933535321038,19.871709994702755,19.89408463619513,19.916459277687515,19.938833919179892,19.96120856067227,19.983583202164645,20.00595784365703,20.028332485149406,20.050707126641782,20.073081768134166,20.09545640962654,20.117831051118916,20.140205692611296,20.162580334103673,20.184954975596053,20.207329617088433,20.22970425858081,20.25207890007319,20.274453541565567,20.296828183057947,20.319202824550324,20.341577466042704,20.36395210753508,20.38632674902746,20.408701390519838,20.431076032012218,20.453450673504594,20.47582531499697,20.498199956489348,20.52057459798173,20.542949239474112,20.56532388096649,20.587698522458865,20.610073163951242,20.632447805443622,20.654822446936,20.67719708842838,20.699571729920756,20.721946371413136,20.744321012905512,20.766695654397893,20.78907029589027,20.811444937382646,20.83381957887503,20.856194220367406,20.878568861859787,20.900943503352163,20.923318144844536,20.945692786336917,20.968067427829297,20.990442069321677,21.012816710814054,21.035191352306434,21.057565993798814,21.07994063529119,21.102315276783564,21.124689918275944,21.147064559768324,21.169439201260705,21.19181384275308,21.214188484245458,21.236563125737838,21.25893776723022,21.281312408722595,21.303687050214975,21.326061691707356,21.34843633319973,21.37081097469211,21.393185616184486,21.415560257676866,21.437934899169242,21.46030954066162,21.482684182154,21.503407299825056,21.527731493842722,21.55586320360317,21.584545512985535,21.6140773219132,21.643609130840876,21.673140939768547,21.702672748696216,21.73220455762389,21.76173636655156,21.79126817547923,21.820799984406904,21.85033179333458,21.87986360226225,21.90939541118992,21.93892722011759,21.968459029045263,21.997990837972935,22.027522646900604,22.057054455828272,22.086586264755944,22.116118073683616,22.14564988261129,22.175181691538956,22.20471350046663,22.234245309394304,22.263777118321975,22.293308927249647,22.322840736177316,22.352372545104988,22.38190435403266,22.41143616296033,22.440967971888004,22.470499780815672,22.500031589743344,22.529563398671016,22.559095207598688,22.58862701652636,22.61815882545403,22.647690634381703,22.67722244330937,22.706754252237047,22.736286061164716,22.765817870092384,22.79534967902006,22.824881487947728,22.8544132968754,22.883945105803072,22.913476914730747,22.943008723658412,22.972540532586088,23.00207234151376,23.03160415044143,23.0611359593691,23.090667768296772,23.120199577224447,23.149731386152116,23.179263195079784,23.20879500400746,23.23832681293513,23.2678586218628,23.297390430790475,23.326922239718144,23.356454048645816,23.385985857573488,23.41551766650116,23.445049475428828,23.474581284356503,23.504113093284175,23.533644902211844,23.563176711139516,23.592708520067188,23.622240328994856,23.651772137922528,23.6813039468502,23.71083575577787,23.74036756470554,23.769899373633216,23.799431182560884,23.828962991488556,23.85849480041623,23.888026609343903,23.91755841827157,23.94709022719924,23.967894415894463,23.97124336412478,23.9745923123551,23.977941260585418,23.981290208815736,23.984639157046058,23.987988105276372,23.991337053506694,23.994686001737012,23.998034949967327,24.001383898197652,24.00473284642797,24.00808179465829,24.011430742888606,24.014779691118925,24.018128639349243,24.02147758757956,24.024826535809883,24.028175484040197,24.03152443227052,24.034873380500837,24.038222328731155,24.041571276961477,24.044920225191795,24.048269173422113,24.05161812165243,24.05496706988275,24.05831601811307,24.06166496634339,24.06501391457371,24.06836286280403,24.071711811034348,24.075060759264666,24.07840970749498,24.081758655725302,24.08510760395562,24.08845655218594,24.091805500416257,24.095154448646575,24.098503396876893,24.10185234510721,24.10520129333753,24.108550241567848,24.11189918979817,24.115248138028488,24.118597086258806,24.121946034489127,24.125294982719442,24.128643930949764,24.131992879180082,24.1353418274104,24.138690775640722,24.142039723871036,24.145388672101358,24.148737620331673,24.15208656856199,24.155435516792316,24.158784465022634,24.162133413252953,24.16548236148327,24.16883130971359,24.172180257943907,24.175529206174225,24.179293673641055,24.1910022691913,24.202710864741547,24.21441946029179,24.22612805584204,24.237836651392286,24.24954524694253,24.261253842492778,24.272962438043024,24.28467103359327,24.296379629143516,24.308088224693762,24.319796820244008,24.331505415794254,24.343214011344504,24.354922606894753,24.366631202445,24.378339797995242,24.39004839354549,24.401756989095738,24.378069987172513,24.177404997881936,23.976740008591356,23.776075019300784,23.575410030010243,23.374745040719663,23.174080051429083,22.97341506213855,22.772750072847973,22.572085083557397,22.371420094266853,22.17075510497628,21.9700901156857,21.769425126395124,21.568760137104583,21.368095147814007,21.16743015852343,20.963222856606222,20.75892916571345,20.554635474820675,20.35034178392794,20.14604809303517,19.941754402142394,19.73746071124966,19.533167020356885,19.328873329464113,19.12457963857134,18.920285947678607,18.715992256785835,18.51169856589306,18.307404875000326,18.10311118410755,17.89881749321478,17.694523802322045,17.49023011142927,17.285936420536498,17.081642729643722,16.877349038750992,16.673055347858217,16.468761656965444,16.264467966072708,16.060174275179936,15.855880584287164,15.651586893394427,15.447293202501655,15.24299951160888,15.038705820716146,14.834412129823374,14.6301184389306,14.425824748037826,14.221531057145091,14.017237366252319,13.812943675359547,13.60864998446681,13.404356293574038,13.200062602681266,12.99576891178853,12.791475220895759,12.587181530002985,12.38288783911021,12.178594148217474,11.974300457324702,11.77000676643193,11.565713075539193,11.361419384646421,11.157125693753649,10.952832002860912,10.750842899476243,10.558648444974963,10.366453990473719,10.17425953597244,9.98206508147116,9.789870626969881,9.597676172468637,9.405481717967357,9.213287263466077,9.021092808964832,8.828898354463552,8.636703899962274,8.444509445461028,8.252314990959748,8.060120536458466,7.867926081957188,7.675731627455944],[16.84518841878466,16.86371705934009,16.882245699895517,16.900774340450948,16.91930298100638,16.93783162156181,16.956360262117236,16.974888902672667,16.993417543228098,17.01194618378353,17.03047482433896,17.049003464894387,17.06753210544982,17.086060746005252,17.10458938656068,17.12311802711611,17.141646667671537,17.16017530822697,17.178703948782402,17.198152195915924,17.21943966576498,17.240727135614033,17.262014605463087,17.283302075312143,17.3045895451612,17.32587701501025,17.347164484859306,17.368451954708362,17.38973942455742,17.41102689440647,17.432314364255525,17.453601834104578,17.47488930395363,17.496176773802688,17.517464243651744,17.538751713500798,17.56003918334985,17.581326653198907,17.602614123047964,17.623901592897013,17.64518906274607,17.666476532595127,17.68776400244418,17.709051472293233,17.73033894214229,17.751626411991342,17.7729138818404,17.794201351689452,17.81548882153851,17.83677629138756,17.858063761236615,17.87935123108567,17.900638700934728,17.92192617078378,17.943213640632834,17.964501110481887,17.985788580330944,18.007076050179997,18.028363520029053,18.049650989878106,18.07093845972716,18.092225929576216,18.113513399425273,18.134800869274322,18.15608833912338,18.17737580897243,18.19866327882149,18.21995074867054,18.241238218519598,18.26252568836865,18.283813158217708,18.30510062806676,18.326388097915817,18.34767556776487,18.368963037613927,18.39025050746298,18.411537977312033,18.43282544716109,18.454112917010143,18.475400386859196,18.496687856708252,18.517975326557305,18.539262796406362,18.560550266255415,18.58114319578033,18.601597217240418,18.622051238700504,18.64250526016059,18.662959281620676,18.683413303080762,18.703867324540848,18.724321346000934,18.74477536746102,18.765229388921107,18.785683410381193,18.80613743184128,18.82659145330137,18.84704547476145,18.86749949622154,18.887953517681623,18.908407539141713,18.9288615606018,18.949315582061885,18.96976960352197,18.990223624982058,19.010677646442144,19.03113166790223,19.051585689362316,19.072039710822402,19.092493732282488,19.112947753742574,19.133401775202664,19.153855796662747,19.174309818122836,19.194763839582922,19.21521786104301,19.235671882503095,19.25612590396318,19.276579925423267,19.297033946883353,19.317487968343443,19.337941989803525,19.358396011263615,19.378850032723697,19.399304054183787,19.419758075643873,19.44021209710396,19.460666118564045,19.48112014002413,19.501574161484218,19.522028182944304,19.542482204404394,19.562936225864476,19.583390247324566,19.60384426878465,19.624298290244734,19.64475231170482,19.665206333164907,19.685660354624996,19.706114376085083,19.726568397545165,19.747022419005255,19.76747644046534,19.787930461925427,19.808384483385513,19.8288385048456,19.849292526305685,19.86974654776577,19.889302057112143,19.907060551571092,19.924819046030038,19.942577540488983,19.960336034947932,19.978094529406878,19.995853023865827,20.013611518324772,20.031370012783718,20.049128507242667,20.066887001701613,20.08464549616056,20.102403990619507,20.120162485078453,20.1379209795374,20.155679473996347,20.173437968455296,20.19119646291424,20.208954957373187,20.229790883187757,20.252165524680137,20.274540166172514,20.296914807664894,20.31928944915727,20.34166409064965,20.364038732142028,20.386413373634404,20.408788015126785,20.43116265661916,20.45353729811154,20.475911939603918,20.4982865810963,20.52066122258868,20.543035864081055,20.565410505573432,20.58778514706581,20.610159788558192,20.63253443005057,20.654909071542946,20.67728371303533,20.699658354527703,20.722032996020083,20.74440763751246,20.766782279004836,20.78915692049722,20.811531561989597,20.833906203481973,20.856280844974357,20.878655486466734,20.901030127959107,20.923404769451487,20.945779410943864,20.968154052436248,20.99052869392862,21.012903335421,21.035277976913378,21.057652618405758,21.080027259898134,21.102401901390515,21.12477654288289,21.14715118437527,21.169525825867648,21.19190046736003,21.214275108852405,21.237178392718548,21.2606690626234,21.284159732528245,21.307650402433097,21.33114107233795,21.354631742242795,21.378122412147647,21.401613082052496,21.425103751957344,21.448594421862197,21.472085091767045,21.495575761671894,21.519066431576743,21.54255710148159,21.566047771386444,21.589538441291293,21.61302911119614,21.63651978110099,21.660010451005842,21.683501120910687,21.706991790815543,21.73048246072039,21.75397313062524,21.777463800530086,21.800954470434938,21.824445140339783,21.847935810244635,21.871426480149488,21.894917150054336,21.918407819959185,21.941898489864034,21.965389159768883,21.988879829673735,22.012370499578584,22.035861169483436,22.059351839388285,22.082842509293133,22.106333179197986,22.13326146078547,22.163627354055592,22.193993247325714,22.224359140595833,22.25472503386596,22.285090927136082,22.315456820406204,22.34582271367633,22.376188606946457,22.406554500216572,22.4369203934867,22.467286286756824,22.497652180026947,22.52801807329707,22.55838396656719,22.588749859837314,22.619115753107437,22.64948164637756,22.67984753964768,22.710213432917804,22.74057932618793,22.770945219458056,22.801311112728175,22.8316770059983,22.86204289926842,22.892408792538546,22.92277468580867,22.95314057907879,22.983506472348914,23.013872365619036,23.04423825888916,23.074604152159285,23.104970045429404,23.135335938699527,23.165701831969656,23.19606772523978,23.226433618509898,23.256799511780024,23.287165405050146,23.317531298320265,23.34789719159039,23.378263084860514,23.408628978130633,23.43899487140076,23.46936076467088,23.499726657941004,23.530092551211126,23.560458444481252,23.590824337751375,23.621190231021494,23.651556124291623,23.681922017561742,23.71228791083186,23.74265380410199,23.773019697372114,23.80338559064223,23.83375148391236,23.86411737718248,23.894483270452604,23.924849163722726,23.955215056992852,23.98558095026297,24.015946843533094,24.04631273680322,24.07667863007334,24.107044523343465,24.137410416613587,24.167776309883713,24.198142203153832,24.22850809642396,24.25887398969408,24.289239882964203,24.319605776234326,24.34997166950445,24.380337562774574,24.410703456044693,24.44106934931482,24.470814111213283,24.500345920140948,24.529877729068623,24.559409537996295,24.588941346923967,24.618473155851635,24.639277344546855,24.642626292777177,24.645975241007495,24.649324189237813,24.65267313746813,24.65602208569845,24.65937103392877,24.66271998215909,24.666068930389407,24.669417878619726,24.672766826850044,24.676115775080362,24.679464723310684,24.682813671541002,24.684808267063534,24.686028919799714,24.687249572535887,24.688470225272066,24.689690878008243,24.690911530744415,24.692132183480595,24.693352836216768,24.69457348895295,24.695794141689127,24.697014794425304,24.69823544716148,24.69945609989766,24.700676752633836,24.70189740537001,24.703118058106188,24.704338710842364,24.705559363578544,24.706780016314717,24.708000669050897,24.709221321787073,24.71044197452325,24.71166262725943,24.7128832799956,24.71410393273178,24.71532458546796,24.716545238204134,24.71776589094031,24.71898654367649,24.720207196412666,24.721427849148846,24.72264850188502,24.723869154621198,24.725089807357374,24.72631046009355,24.727531112829723,24.728751765565907,24.729972418302083,24.731193071038263,24.732413723774435,24.73363437651061,24.734855029246795,24.736075681982967,24.73729633471914,24.73851698745532,24.739737640191496,24.74095829292768,24.742178945663852,24.743399598400025,24.74462025113621,24.745840903872384,24.747061556608564,24.748282209344737,24.749502862080917,24.750723514817093,24.75194416755327,24.753164820289445,24.75438547302562,24.7556061257618,24.756826778497974,24.758047431234154,24.75926808397033,24.760488736706506,24.761709389442686,24.762930042178862,24.76415069491504,24.765371347651215,24.766592000387394,24.767812653123567,24.7314788147,24.5073725204777,24.283266226255392,24.05915993203309,23.83505363781083,23.610947343588528,23.38684104936622,23.162734755143962,22.93862846092166,22.714522166699357,22.490415872477094,22.26630957825479,22.04220328403249,21.818096989810183,21.604309712974977,21.40001602208221,21.195722331189437,20.9914286402967,20.787134949403928,20.582841258511156,20.378547567618416,20.174253876725647,19.969960185832875,19.765666494940135,19.561372804047366,19.35707911315459,19.152785422261818,18.94849173136908,18.74419804047631,18.539904349583537,18.3356106586908,18.13131696779803,17.927023276905253,17.72272958601252,17.518435895119747,17.314142204226975,17.1098485133342,16.905554822441466,16.701261131548694,16.496967440655922,16.292673749763185,16.088380058870413,15.88408636797764,15.679792677084905,15.47549898619213,15.27120529529936,15.066911604406625,14.862617913513851,14.658324222621077,14.454030531728304,14.24973684083557,14.045443149942797,13.841149459050024,13.63685576815729,13.432562077264514,13.228268386371743,13.023974695479009,12.819681004586233,12.615387313693462,12.411093622800689,12.206799931907955,12.00250624101518,11.798212550122408,11.593918859229673,11.389625168336899,11.185331477444127,10.98103778655139,10.776744095658618,10.572450404765846,10.36815671387311,10.169995024371232,9.975196010547853,9.780396996724473,9.58559798290113,9.39079896907775,9.195999955254372,9.001200941431026,8.806401927607645,8.611602913784267,8.416803899960923,8.222004886137544,8.027205872314163,7.832406858490783,7.637607844667439],[17.31464420481126,17.33317284536669,17.35170148592212,17.372529146198296,17.39381661604735,17.415104085896402,17.43639155574546,17.457679025594512,17.478966495443565,17.50025396529262,17.521541435141675,17.54282890499073,17.564116374839784,17.58540384468884,17.606691314537894,17.62797878438695,17.649266254236004,17.670553724085057,17.691841193934113,17.713128663783166,17.734416133632223,17.755703603481276,17.77699107333033,17.798278543179386,17.81956601302844,17.840853482877492,17.86214095272655,17.883428422575605,17.90471589242466,17.92600336227371,17.947290832122768,17.96857830197182,17.989865771820874,18.01115324166993,18.032440711518987,18.05372818136804,18.075015651217093,18.09630312106615,18.117590590915206,18.138878060764256,18.160165530613313,18.18145300046237,18.202740470311422,18.224027940160475,18.245315410009532,18.266602879858585,18.28789034970764,18.309177819556695,18.33046528940575,18.351752759254804,18.373040229103857,18.394327698952914,18.41561516880197,18.436902638651024,18.458190108500077,18.47947757834913,18.500765048198186,18.52205251804724,18.543339987896296,18.56462745774535,18.585914927594402,18.60720239744346,18.628489867292515,18.64977733714157,18.67106480699062,18.692352276839678,18.71363974668873,18.734927216537784,18.75621468638684,18.777502156235894,18.79878962608495,18.820077095934003,18.84136456578306,18.862652035632113,18.88393950548117,18.905226975330223,18.926514445179276,18.947801915028332,18.969089384877385,18.99037685472644,19.011664324575495,19.032951794424548,19.054239264273605,19.075526734122658,19.096119663647574,19.11657368510766,19.137027706567746,19.157481728027832,19.17793574948792,19.198389770948005,19.21884379240809,19.239297813868177,19.259751835328263,19.28020585678835,19.300659878248435,19.32111389970852,19.34156792116861,19.362021942628694,19.382475964088783,19.402929985548866,19.423384007008956,19.44383802846904,19.464292049929128,19.484746071389214,19.5052000928493,19.525654114309386,19.546108135769472,19.56656215722956,19.587016178689645,19.60747020014973,19.627924221609817,19.648378243069907,19.66883226452999,19.68928628599008,19.709740307450165,19.73019432891025,19.750648350370337,19.771102371830423,19.79155639329051,19.812010414750596,19.832464436210685,19.852918457670768,19.873372479130857,19.89382650059094,19.91428052205103,19.934734543511116,19.955188564971202,19.975642586431288,19.996096607891374,20.01655062935146,20.037004650811546,20.057458672271636,20.07791269373172,20.098366715191805,20.11882073665189,20.139274758111977,20.159728779572063,20.18018280103215,20.20063682249224,20.221090843952325,20.241544865412408,20.261998886872497,20.282452908332584,20.30290692979267,20.323360951252756,20.343814972712842,20.364268994172928,20.384723015633014,20.4051770370931,20.425631058553186,20.446085080013273,20.46653910147336,20.48699312293345,20.50744714439353,20.52790116585362,20.548355187313707,20.568809208773793,20.58926323023388,20.609717251693965,20.63017127315405,20.650625294614137,20.671079316074223,20.69153333753431,20.711987358994396,20.732441380454482,20.750649124830638,20.768407619289587,20.789243545104153,20.81161818659653,20.83399282808891,20.856367469581286,20.878742111073663,20.901586654725158,20.925077324630006,20.94856799453486,20.972058664439707,20.995549334344556,21.019040004249405,21.042530674154253,21.066021344059102,21.089512013963954,21.1130026838688,21.136493353773652,21.1599840236785,21.18347469358335,21.2069653634882,21.230456033393054,21.2539467032979,21.277437373202748,21.3009280431076,21.32441871301245,21.347909382917297,21.371400052822146,21.394890722727,21.418381392631847,21.441872062536696,21.465362732441548,21.488853402346393,21.512344072251246,21.53583474215609,21.559325412060943,21.58281608196579,21.606306751870644,21.629797421775493,21.65328809168034,21.67677876158519,21.70026943149004,21.723760101394888,21.74725077129974,21.77074144120459,21.79423211110944,21.81772278101429,21.84121345091914,21.864704120823987,21.88819479072884,21.911685460633684,21.935176130538537,21.958666800443385,21.982157470348234,22.005648140253083,22.029138810157935,22.052629480062784,22.076120149967632,22.09961081987248,22.123101489777333,22.146592159682182,22.17008282958703,22.19357349949188,22.21706416939673,22.24055483930158,22.264045509206433,22.287536179111278,22.31102684901613,22.334517518920975,22.358008188825828,22.381498858730676,22.404989528635525,22.428480198540377,22.451970868445226,22.475461538350075,22.498952208254924,22.52244287815978,22.545933548064625,22.569424217969473,22.592914887874322,22.616405557779174,22.639896227684023,22.66338689758887,22.68687756749372,22.71036823739857,22.737296518986057,22.767662412256183,22.798028305526305,22.828394198796428,22.85876009206655,22.889125985336673,22.91949187860679,22.949857771876918,22.980223665147044,23.010589558417163,23.04095545168729,23.07132134495741,23.101687238227534,23.132053131497656,23.162419024767782,23.1927849180379,23.223150811308024,23.25351670457815,23.283882597848272,23.314248491118395,23.34461438438852,23.374980277658644,23.405346170928762,23.43571206419889,23.46607795746901,23.496443850739134,23.526809744009256,23.55717563727938,23.5875415305495,23.617907423819624,23.64827331708975,23.678639210359876,23.70900510362999,23.739370996900114,23.769736890170243,23.800102783440362,23.83046867671049,23.86083456998061,23.89120046325073,23.921566356520856,23.95193224979098,23.9822981430611,24.01266403633122,24.043029929601346,24.073395822871476,24.10376171614159,24.134127609411713,24.16449350268184,24.194859395951962,24.225225289222085,24.25559118249221,24.28595707576233,24.316322969032452,24.346688862302578,24.377054755572704,24.40742064884282,24.43778654211295,24.468152435383068,24.498518328653194,24.528884221923313,24.561429248315765,24.594115374575633,24.626801500835498,24.65948762709537,24.692173753355235,24.7248598796151,24.75754600587497,24.79023213213484,24.8229182583947,24.855604384654573,24.88829051091444,24.920976637174306,24.95366276343417,24.986348889694042,25.019035015953907,25.051721142213776,25.084407268473644,25.117093394733512,25.149779520993373,25.182465647253245,25.215151773513117,25.24783789977298,25.28052402603285,25.29931348903841,25.290309625535393,25.281305762032368,25.27230189852935,25.263298035026327,25.254294171523302,25.24529030802028,25.236286444517255,25.227282581014233,25.21827871751121,25.209274854008186,25.200270990505164,25.19126712700214,25.182263263499117,25.173259399996095,25.16425553649307,25.155251672990047,25.146247809487026,25.137243945984004,25.128240082480982,25.119236218977957,25.110232355474935,25.101228491971913,25.092224628468887,25.083220764965866,25.074216901462844,25.065213037959822,25.056209174456797,25.04720531095377,25.038201447450753,25.02919758394773,25.020193720444702,25.011189856941684,25.012252753459617,25.013473406195796,25.01469405893197,25.01591471166815,25.017135364404325,25.0183560171405,25.019576669876677,25.020797322612857,25.02201797534903,25.023238628085213,25.024459280821386,25.025679933557566,25.026900586293742,25.028121239029918,25.029341891766094,25.03056254450227,25.031783197238447,25.033003849974627,25.034224502710803,25.035445155446983,25.03666580818316,25.03788646091933,25.03910711365551,25.040327766391687,25.041548419127864,25.042769071864043,25.04398972460022,25.045210377336396,25.046431030072572,25.04765168280875,25.04887233554493,25.050092988281104,25.05131364101728,25.05253429375346,25.053754946489637,25.054975599225816,25.05619625196199,25.057416904698165,25.058637557434345,25.059858210170525,25.061078862906697,25.062299515642877,25.06352016837905,25.06474082111523,25.06596147385141,25.067182126587582,25.068402779323762,25.069623432059934,25.070844084796114,25.072064737532287,25.03573089910872,24.81162460488642,24.587518310664112,24.363412016441814,24.13930572221955,23.915199427997248,23.69109313377494,23.466986839552682,23.24288054533038,23.018774251108077,22.794667956885814,22.57056166266351,22.346455368441205,22.122349074218903,21.898242779996643,21.67413648577434,21.450030191552038,21.22592389732978,21.001817603107476,20.777711308885173,20.553605014662907,20.329498720440604,20.1053924262183,19.88128613199604,19.65717983777374,19.433073543551433,19.20896724932913,18.984860955106868,18.760754660884565,18.536648366662263,18.312542072440003,18.088435778217697,17.864329483995395,17.64022318977313,17.416116895550832,17.192010601328526,16.967904307106224,16.744451050940448,16.528181195573445,16.31191134020644,16.095641484839476,15.87937162947247,15.663101774105463,15.446831918738496,15.23056206337149,15.014292208004486,14.799811585363527,14.605012571540147,14.410213557716768,14.215414543893386,14.020615530070042,13.825816516246663,13.631017502423283,13.43621848859994,13.24141947477656,13.046620460953182,12.851821447129836,12.657022433306457,12.462223419483077,12.267424405659696,12.072625391836354,11.877826378012973,11.683027364189593,11.48822835036625,11.293429336542872,11.09863032271949,10.903831308896146,10.709032295072767,10.514233281249385,10.319434267426043,10.124635253602662,9.929836239779284,9.735037225955905,9.54023821213256,9.34543919830918,9.150640184485802,8.955841170662456,8.761042156839077,8.566243143015697,8.371444129192353,8.176645115368974,7.981846101545594,7.787047087722215,7.592248073898871],[17.782815300343746,17.8041027701928,17.825390240041852,17.84667770989091,17.86796517973996,17.889252649589018,17.91054011943807,17.931827589287124,17.95311505913618,17.974402528985237,17.99568999883429,18.016977468683343,18.0382649385324,18.059552408381457,18.08083987823051,18.102127348079563,18.123414817928616,18.144702287777672,18.165989757626726,18.187277227475782,18.20856469732484,18.229852167173892,18.251139637022945,18.272427106872,18.29371457672105,18.315002046570108,18.336289516419164,18.357576986268217,18.378864456117274,18.400151925966327,18.42143939581538,18.442726865664437,18.46401433551349,18.485301805362546,18.5065892752116,18.527876745060652,18.54916421490971,18.570451684758766,18.591739154607822,18.61302662445687,18.634314094305928,18.65560156415498,18.676889034004038,18.69817650385309,18.719463973702148,18.7407514435512,18.762038913400254,18.783326383249307,18.80461385309836,18.825901322947416,18.847188792796473,18.868476262645526,18.88976373249458,18.911051202343636,18.93233867219269,18.953626142041745,18.9749136118908,18.996201081739855,19.017488551588908,19.038776021437965,19.060063491287018,19.081350961136074,19.102638430985127,19.12392590083418,19.145213370683237,19.166500840532294,19.187788310381347,19.2090757802304,19.230363250079456,19.25207311643147,19.27589499006161,19.299716863691746,19.323538737321883,19.34736061095202,19.37118248458216,19.3950043582123,19.418826231842438,19.442648105472575,19.466469979102712,19.490291852732852,19.51411372636299,19.537935599993126,19.561757473623267,19.585579347253404,19.608744259461755,19.63177777938575,19.654811299309742,19.677844819233734,19.70087833915773,19.723911859081724,19.746945379005716,19.769978898929708,19.793012418853703,19.816045938777695,19.839079458701686,19.862112978625678,19.885146498549677,19.90818001847367,19.92992378496505,19.950377806425138,19.970831827885224,19.99128584934531,20.011739870805396,20.032193892265482,20.052647913725565,20.073101935185655,20.09355595664574,20.114009978105827,20.134463999565916,20.154918021026003,20.17537204248609,20.195826063946175,20.21628008540626,20.236734106866347,20.257188128326433,20.27764214978652,20.298096171246605,20.31855019270669,20.339004214166778,20.359458235626864,20.37991225708695,20.400366278547036,20.420820300007122,20.44127432146721,20.461728342927294,20.482182364387384,20.50263638584747,20.523090407307556,20.543544428767643,20.56399845022773,20.584452471687815,20.6049064931479,20.625360514607987,20.645814536068073,20.66626855752816,20.686722578988245,20.70717660044833,20.727630621908418,20.748084643368504,20.76853866482859,20.78899268628868,20.809446707748762,20.829900729208852,20.850354750668934,20.870808772129024,20.89126279358911,20.911716815049196,20.932170836509286,20.95262485796937,20.97307887942946,20.99353290088954,21.013986922349627,21.034440943809717,21.054894965269803,21.07534898672989,21.095803008189975,21.116257029650058,21.136711051110147,21.15716507257023,21.17761909403032,21.198073115490406,21.21852713695049,21.238981158410578,21.259435179870664,21.27988920133075,21.300343222790836,21.320797244250922,21.344183537653517,21.369035967027358,21.393888396401202,21.418740825775046,21.443593255148883,21.468445684522727,21.493298113896568,21.518150543270412,21.543002972644253,21.567855402018097,21.59270783139194,21.61756026076578,21.642412690139622,21.667265119513466,21.692117548887307,21.71696997826115,21.74182240763499,21.766674837008836,21.791527266382676,21.816379695756517,21.84123212513036,21.866084554504205,21.890936983878042,21.915789413251886,21.94064184262573,21.96549427199957,21.990346701373415,22.015199130747256,22.0400515601211,22.064903989494937,22.08975641886878,22.114608848242625,22.139461277616466,22.163360470261544,22.18685114016639,22.21034181007124,22.233832479976094,22.25732314988094,22.28081381978579,22.30430448969064,22.32779515959549,22.35128582950034,22.374776499405193,22.39826716931004,22.42175783921489,22.445248509119736,22.46873917902459,22.492229848929433,22.515720518834286,22.539211188739134,22.562701858643987,22.586192528548835,22.609683198453684,22.633173868358533,22.656664538263385,22.680155208168234,22.703645878073083,22.72713654797793,22.75062721788278,22.774117887787632,22.79760855769248,22.82109922759733,22.844589897502175,22.868080567407027,22.891571237311876,22.915061907216725,22.938552577121577,22.962043247026426,22.98553391693128,23.009024586836127,23.03251525674098,23.056005926645827,23.079496596550676,23.102987266455525,23.126477936360374,23.149968606265226,23.17345927617007,23.196949946074923,23.22044061597977,23.24393128588462,23.267421955789473,23.29091262569432,23.31440329559917,23.341331577186658,23.37169747045678,23.402063363726903,23.432429256997025,23.462795150267148,23.49316104353727,23.523526936807396,23.55389283007752,23.58425872334764,23.61462461661776,23.644990509887887,23.675356403158013,23.70572229642813,23.736088189698254,23.76645408296838,23.796819976238503,23.827185869508625,23.85755176277875,23.88791765604887,23.918283549318993,23.948649442589115,23.979015335859245,24.00938122912936,24.039747122399486,24.070113015669612,24.100478908939735,24.130844802209857,24.16121069547998,24.191576588750102,24.22194248202022,24.252308375290347,24.282674268560477,24.313040161830596,24.34340605510072,24.37512018704584,24.40780631330571,24.440492439565574,24.473178565825442,24.50586469208531,24.53855081834518,24.571236944605047,24.603923070864912,24.636609197124777,24.669295323384645,24.70198144964452,24.734667575904382,24.76735370216425,24.800039828424122,24.832725954683987,24.865412080943855,24.898098207203724,24.930784333463592,24.963470459723453,24.996156585983325,25.028842712243193,25.061528838503058,25.094214964762926,25.126901091022795,25.159587217282663,25.192273343542528,25.2249594698024,25.257645596062265,25.29033172232213,25.323017848581998,25.355703974841866,25.38839010110173,25.4210762273616,25.45376235362147,25.486448479881332,25.5191346061412,25.551820732401072,25.584506858660937,25.617192984920806,25.64987911118067,25.68256523744054,25.715251363700403,25.747937489960275,25.78062361622014,25.81330974248001,25.845995868739877,25.878681994999745,25.911368121259613,25.944054247519475,25.962843710525046,25.953839847022024,25.944835983519,25.935832120015974,25.926828256512955,25.917824393009933,25.90882052950691,25.899816666003886,25.89081280250086,25.88180893899784,25.872805075494817,25.86380121199179,25.854797348488773,25.845793484985748,25.836789621482726,25.827785757979704,25.81878189447668,25.809778030973657,25.800774167470635,25.791770303967617,25.78276644046459,25.773762576961566,25.76475871345854,25.755754849955515,25.746750986452497,25.73774712294947,25.728743259446453,25.719739395943428,25.710735532440406,25.701731668937384,25.692727805434355,25.683723941931337,25.674720078428315,25.66571621492529,25.656712351422264,25.647708487919246,25.63870462441622,25.629700760913195,25.620696897410177,25.61169303390715,25.602689170404133,25.593685306901108,25.584681443398082,25.57567757989506,25.566673716392035,25.557669852889013,25.54866598938599,25.53966212588297,25.53065826237995,25.521654398876926,25.5126505353739,25.503646671870875,25.494642808367853,25.48563894486483,25.476635081361813,25.467631217858788,25.458627354355762,25.44962349085274,25.44061962734972,25.431615763846693,25.422611900343675,25.413608036840653,25.404604173337624,25.395600309834606,25.38659644633158,25.377592582828555,25.368588719325533,25.359584855822515,25.35922768363454,25.360448336370712,25.361668989106892,25.36288964184307,25.36411029457925,25.36533094731542,25.366551600051597,25.367772252787777,25.368992905523957,25.370213558260133,25.37143421099631,25.37265486373249,25.37387551646866,25.375096169204845,25.376316821941014,25.339982983517444,25.115876689295142,24.89177039507284,24.66766410085054,24.443557806628274,24.21945151240597,23.99534521818367,23.77123892396141,23.547132629739107,23.323026335516804,23.098920041294544,22.874813747072235,22.656390623348763,22.440120767981757,22.223850912614793,22.007581057247787,21.79131120188078,21.575041346513814,21.358771491146808,21.1425016357798,20.926231780412838,20.709961925045832,20.493692069678826,20.27742221431186,20.061152358944856,19.84488250357785,19.628612648210847,19.412342792843877,19.19607293747687,18.979803082109864,18.7635332267429,18.547263371375895,18.33099351600889,18.114723660641925,17.89845380527492,17.682183949907913,17.465914094540906,17.249644239173943,17.033374383806937,16.817104528439934,16.600834673072967,16.38456481770596,16.168294962338955,15.95202510697199,15.735755251604981,15.519485396237979,15.303215540871014,15.086945685504007,14.870675830137001,14.654405974769997,14.43813611940303,14.221866264036024,14.005596408669017,13.789326553302054,13.573056697935048,13.356786842568042,13.140516987201078,12.924247131834068,12.707977276467064,12.491707421100058,12.275437565733094,12.05916771036609,11.842897854999084,11.626627999632117,11.410358144265112,11.194088288898106,10.97781843353114,10.761548578164136,10.54527872279713,10.329008867430165,10.112739012063159,9.896469156696153,9.689677455187335,9.49487844136399,9.30007942754061,9.10528041371723,8.910481399893886,8.715682386070506,8.520883372247127,8.326084358423783,8.131285344600403,7.936486330777023,7.7416873169536435,7.5468883031303],[18.25079219829314,18.272079668142197,18.29336713799125,18.314654607840307,18.33594207768936,18.357229547538417,18.37851701738747,18.399804487236523,18.42109195708558,18.442379426934636,18.463666896783685,18.484954366632742,18.5062418364818,18.52752930633085,18.548816776179905,18.57010424602896,18.591391715878014,18.61267918572707,18.633966655576124,18.65525412542518,18.676541595274234,18.697829065123287,18.719116534972343,18.7404040048214,18.76169147467045,18.782978944519506,18.804266414368563,18.825553884217616,18.846841354066672,18.868128823915725,18.88941629376478,18.910703763613835,18.931991233462888,18.953278703311945,18.974566173160998,18.99585364301005,19.017141112859107,19.03842858270816,19.05971605255722,19.08100352240627,19.102290992255323,19.123578462104376,19.144865931953433,19.166153401802486,19.187440871651546,19.2087283415006,19.230015811349652,19.251303281198705,19.27259075104776,19.293878220896815,19.315165690745868,19.336453160594925,19.357740630443978,19.38071769910471,19.40453957273485,19.42836144636499,19.452183319995125,19.476005193625266,19.499827067255403,19.523648940885543,19.54747081451568,19.57129268814582,19.595114561775958,19.618936435406095,19.642758309036232,19.666580182666372,19.69040205629651,19.71422392992665,19.738045803556787,19.761867677186927,19.785689550817064,19.8095114244472,19.833333298077342,19.85715517170748,19.88097704533762,19.904798918967757,19.928620792597894,19.952442666228034,19.97626453985817,20.00008641348831,20.02390828711845,20.047730160748586,20.071552034378726,20.095373908008863,20.118538820217214,20.14157234014121,20.1646058600652,20.187639379989193,20.210672899913188,20.23370641983718,20.256739939761175,20.279773459685167,20.302806979609162,20.325840499533154,20.34887401945715,20.37190753938114,20.394941059305133,20.417974579229128,20.441008099153123,20.46404161907711,20.487075139001107,20.5101086589251,20.533142178849094,20.55617569877309,20.57920921869708,20.602242738621072,20.625276258545068,20.648309778469056,20.671343298393055,20.694376818317046,20.71741033824104,20.740443858165033,20.763477378089025,20.78651089801302,20.80954441416197,20.829998435622056,20.850452457082145,20.870906478542228,20.891360500002314,20.911814521462404,20.932268542922493,20.95272256438258,20.97317658584266,20.993630607302748,21.014084628762834,21.03453865022292,21.05499267168301,21.075446693143093,21.095900714603182,21.11635473606327,21.136808757523355,21.15726277898344,21.177716800443527,21.198170821903613,21.2186248433637,21.239078864823785,21.25953288628387,21.279986907743957,21.300440929204044,21.320894950664133,21.341348972124216,21.361802993584305,21.38225701504439,21.402711036504478,21.423165057964564,21.44361907942465,21.464073100884736,21.484527122344822,21.504981143804905,21.525435165264994,21.54588918672508,21.566343208185167,21.586797229645253,21.60725125110534,21.62770527256543,21.64815929402551,21.6686133154856,21.689067336945683,21.709521358405773,21.729975379865856,21.750429401325945,21.770883422786028,21.791337444246118,21.8117914657062,21.83224548716629,21.852699508626376,21.873153530086462,21.896539823489057,21.921392252862894,21.94624468223674,21.97109711161058,21.995949540984427,22.020801970358264,22.045654399732108,22.070506829105952,22.09535925847979,22.120211687853633,22.145064117227477,22.16991654660132,22.194768975975165,22.219621405349006,22.244473834722843,22.269326264096687,22.29417869347053,22.319031122844372,22.343883552218216,22.368735981592057,22.393588410965897,22.41844084033974,22.443293269713585,22.46814569908743,22.49299812846127,22.51785055783511,22.542702987208955,22.567555416582795,22.592407845956636,22.61726027533048,22.642112704704317,22.666965134078165,22.691817563452005,22.71666999282585,22.741522422199694,22.76637485157353,22.791227280947375,22.816079710321215,22.84093213969506,22.8657845690689,22.890636998442744,22.915489427816585,22.940341857190425,22.96519428656427,22.990046715938114,23.014899145311958,23.0397515746858,23.06460400405964,23.089456433433483,23.114308862807327,23.139161292181164,23.16401372155501,23.18886615092885,23.213718580302693,23.238571009676534,23.263423439050378,23.288275868424215,23.313128297798063,23.337980727171907,23.362833156545744,23.387685585919584,23.41253801529343,23.437390444667273,23.462242874041117,23.487095303414957,23.511947732788798,23.536800162162642,23.561652591536483,23.586505020910327,23.611357450284167,23.63620987965801,23.660040984846425,23.683531654751274,23.707022324656123,23.730512994560975,23.754003664465824,23.777494334370672,23.800985004275525,23.824475674180373,23.847966344085222,23.871457013990074,23.894947683894923,23.918438353799772,23.945366635387256,23.97573252865738,24.006098421927504,24.036464315197623,24.06683020846775,24.097196101737875,24.127561995007994,24.15792788827812,24.18881112577592,24.221497252035782,24.254183378295657,24.286869504555526,24.319555630815387,24.35224175707526,24.384927883335124,24.417614009594992,24.450300135854857,24.48298626211473,24.51567238837459,24.54835851463446,24.581044640894326,24.6137307671542,24.64641689341406,24.67910301967393,24.711789145933803,24.744475272193664,24.77716139845353,24.8098475247134,24.842533650973266,24.875219777233134,24.907905903493003,24.94059202975287,24.973278156012736,25.005964282272608,25.038650408532476,25.07133653479234,25.104022661052205,25.136708787312074,25.169394913571942,25.20208103983181,25.23476716609168,25.26745329235154,25.30013941861141,25.332825544871277,25.365511671131152,25.398197797391013,25.43088392365088,25.46357004991075,25.49625617617062,25.528942302430483,25.561628428690355,25.59431455495022,25.627000681210085,25.659686807469953,25.69237293372982,25.72505905998969,25.757745186249558,25.790431312509426,25.823117438769287,25.85580356502916,25.88848969128903,25.921175817548892,25.95386194380876,25.98654807006863,26.019234196328497,26.05192032258836,26.084606448848227,26.117292575108102,26.149978701367964,26.182664827627832,26.2153509538877,26.24803708014757,26.280723206407437,26.3134093326673,26.346095458927174,26.378781585187035,26.411467711446903,26.44415383770677,26.47683996396664,26.509526090226505,26.542212216486373,26.57489834274624,26.607584469006106,26.626373932011678,26.617370068508652,26.60836620500563,26.59936234150261,26.590358477999587,26.58135461449656,26.57235075099354,26.563346887490518,26.553595690456913,26.5412879606039,26.52898023075089,26.51667250089788,26.50436477104487,26.492057041191856,26.479749311338846,26.467441581485836,26.455133851632823,26.44282612177981,26.430518391926803,26.41821066207379,26.405902932220776,26.39359520236777,26.381287472514757,26.368979742661747,26.356672012808737,26.344364282955723,26.332056553102714,26.319748823249704,26.30744109339669,26.295133363543677,26.28282563369067,26.270517903837657,26.258210173984644,26.245902444131637,26.233594714278624,26.221286984425614,26.2089792545726,26.19667152471959,26.184363794866584,26.17205606501357,26.159748335160558,26.14744060530755,26.135132875454538,26.122825145601524,26.110517415748518,26.098209685895505,26.08590195604249,26.07359422618948,26.06128649633647,26.048978766483458,26.036671036630448,26.02436330677744,26.012055576924425,25.99974784707141,25.987440117218405,25.97513238736539,25.96282465751238,25.950516927659372,25.93820919780636,25.92590146795335,25.91359373810034,25.901286008247325,25.88897827839432,25.876670548541306,25.864362818688292,25.852055088835282,25.839747358982276,25.827439629129262,25.81513189927625,25.802824169423236,25.790516439570226,25.77820870971722,25.765900979864206,25.753593250011196,25.741285520158186,25.728977790305173,25.716670060452163,25.70436233059915,25.69205460074614,25.67974687089313,25.667439141040116,25.655131411187106,25.642823681334093,25.59190381338423,25.34792325495009,25.103942696515944,24.8599621380818,24.615981579647702,24.372001021213563,24.128020462779418,23.884039904345318,23.64005934591118,23.396078787477038,23.15209822904294,22.908117670608796,22.664137112174654,22.42015655374051,22.176175995306416,21.932195436872274,21.688214878438128,21.444234320004032,21.20025376156989,20.956273203135744,20.712292644701648,20.494868245071018,20.278598389704012,20.06232853433705,19.846058678970042,19.629788823603036,19.41351896823603,19.197249112869066,18.980979257502057,18.764709402135054,18.548439546768087,18.332169691401084,18.115899836034078,17.89962998066711,17.683360125300105,17.4670902699331,17.250820414566093,17.03455055919913,16.818280703832123,16.602010848465117,16.385740993098153,16.169471137731147,15.953201282364141,15.736931426997177,15.520661571630171,15.304391716263165,15.0881218608962,14.871852005529194,14.65558215016219,14.439312294795183,14.223042439428216,14.00677258406121,13.790502728694205,13.57423287332724,13.357963017960236,13.14169316259323,12.925423307226264,12.709153451859258,12.492883596492252,12.276613741125246,12.06034388575828,11.844074030391276,11.62780417502427,11.415772271753777,11.219844827343115,11.023917382932453,10.827989938521828,10.632062494111167,10.436135049700503,10.240207605289879,10.044280160879216,9.848352716468554,9.652425272057894,9.456497827647269,9.260570383236606,9.064642938825944,8.86871549441532,8.672788050004657,8.476860605593995,8.280933161183372,8.08500571677271,7.889078272362048,7.693150827951386,7.49722338354076],[18.718769096242532,18.740056566091585,18.76134403594064,18.782631505789695,18.80391897563875,18.825206445487805,18.846493915336858,18.867781385185914,18.889068855034967,18.91035632488402,18.931643794733077,18.95293126458213,18.974218734431183,18.99550620428024,19.016793674129296,19.03808114397835,19.059368613827402,19.08065608367646,19.101943553525512,19.12323102337457,19.14451849322362,19.16580596307268,19.18709343292173,19.208380902770788,19.22966837261984,19.250955842468894,19.27224331231795,19.293530782167004,19.31481825201606,19.336105721865113,19.357393191714166,19.378680661563223,19.399968131412276,19.421255601261333,19.442543071110386,19.46383054095944,19.485540408147806,19.509362281777946,19.533184155408087,19.557006029038224,19.580827902668357,19.6046497762985,19.62847164992864,19.652293523558775,19.676115397188912,19.699937270819053,19.72375914444919,19.747581018079327,19.771402891709464,19.795224765339608,19.819046638969745,19.842868512599885,19.86669038623002,19.89051225986016,19.9143341334903,19.938156007120433,19.961977880750574,19.985799754380714,20.00962162801085,20.033443501640992,20.05726537527113,20.081087248901266,20.104909122531403,20.128730996161543,20.152552869791684,20.17637474342182,20.200196617051958,20.2240184906821,20.247840364312232,20.271662237942373,20.295484111572513,20.31930598520265,20.34312785883279,20.366949732462928,20.390771606093068,20.4145934797232,20.438415353353342,20.462237226983483,20.48605910061362,20.509880974243757,20.533702847873897,20.557524721504034,20.58134659513417,20.60516846876431,20.628333380972663,20.651366900896654,20.674400420820646,20.69743394074464,20.720467460668637,20.74350098059263,20.76653450051662,20.789568020440612,20.81260154036461,20.835635060288602,20.858668580212594,20.881702100136586,20.90473562006058,20.927769139984573,20.950802659908568,20.97383617983256,20.996869699756555,21.01990321968055,21.042936739604542,21.065970259528534,21.089003779452526,21.11203729937652,21.135070819300516,21.158104339224508,21.181137859148503,21.20417137907249,21.227204898996487,21.250238418920482,21.273271938844474,21.29630545876847,21.31933897869246,21.342372498616452,21.365406018540448,21.38843953846444,21.411473058388435,21.434506578312423,21.45754009823642,21.480573618160413,21.503607138084405,21.5266406580084,21.549674177932392,21.572707697856387,21.59574121778038,21.618774737704374,21.641808257628366,21.66484177755236,21.687875297476353,21.70961906481897,21.730073086279056,21.750527107739142,21.770981129199225,21.791435150659314,21.8118891721194,21.832343193579486,21.852797215039573,21.873251236499662,21.893705257959745,21.914159279419835,21.93461330087992,21.955067322340003,21.975521343800093,21.99597536526018,22.01642938672026,22.03688340818035,22.057337429640434,22.077791451100524,22.09824547256061,22.118699494020696,22.139153515480785,22.159607536940868,22.180061558400958,22.200515579861044,22.22096960132113,22.241423622781216,22.261877644241302,22.282331665701385,22.302785687161474,22.323239708621557,22.343693730081647,22.36414775154173,22.38460177300182,22.4050557944619,22.42550981592199,22.448896109324583,22.473748538698423,22.498600968072267,22.52345339744611,22.548305826819952,22.573158256193793,22.598010685567637,22.622863114941477,22.647715544315318,22.672567973689162,22.697420403063006,22.722272832436847,22.74712526181069,22.77197769118453,22.796830120558376,22.821682549932216,22.846534979306057,22.8713874086799,22.896239838053745,22.92109226742759,22.945944696801426,22.970797126175274,22.99564955554911,23.020501984922955,23.045354414296796,23.070206843670636,23.095059273044484,23.119911702418324,23.14476413179217,23.16961656116601,23.194468990539846,23.21932141991369,23.24417384928753,23.269026278661375,23.29387870803522,23.31873113740906,23.343583566782904,23.368435996156748,23.393288425530585,23.41814085490443,23.44299328427827,23.467845713652117,23.492698143025954,23.5175505723998,23.54240300177364,23.567255431147487,23.592107860521324,23.616960289895168,23.641812719269012,23.666665148642853,23.691517578016693,23.716370007390534,23.74122243676438,23.76607486613822,23.790927295512063,23.815779724885903,23.840632154259744,23.86548458363359,23.890337013007432,23.915189442381273,23.940041871755113,23.96489430112896,23.9897467305028,24.01499722909525,24.04132821389738,24.067659198699506,24.09399018350163,24.120321168303757,24.146652153105887,24.17298313790801,24.199314122710135,24.22564510751226,24.251976092314386,24.278307077116512,24.304638061918634,24.330969046720764,24.35730003152289,24.383631016325015,24.40996200112714,24.436292985929263,24.462623970731393,24.48895495553352,24.515285940335644,24.545749974452683,24.580347057884644,24.614944141316602,24.649541224748557,24.684138308180515,24.71873539161247,24.753332475044427,24.787929558476385,24.822526641908343,24.857123725340294,24.891720808772256,24.926317892204214,24.960914975636168,24.995512059068126,25.03010914250008,25.064706225932042,25.099303309363997,25.133900392795958,25.168497476227913,25.20309455965987,25.23769164309183,25.270788007883382,25.303446667444558,25.336105327005743,25.36876398656693,25.401422646128108,25.434081305689286,25.466739965250476,25.499398624811658,25.532057284372836,25.564715943934022,25.597374603495204,25.630033263056383,25.66269192261757,25.69535058217875,25.728009241739933,25.76066790130111,25.793326560862297,25.82598522042348,25.858643879984662,25.891302539545844,25.923961199107026,25.95661985866821,25.98927851822939,26.021937177790576,26.054595837351755,26.08725449691294,26.119913156474123,26.152571816035305,26.18523047559649,26.21788913515767,26.25054779471885,26.283206454280034,26.315865113841216,26.348523773402405,26.38118243296358,26.413841092524766,26.44649975208595,26.479158411647127,26.511817071208313,26.5444757307695,26.577134390330674,26.60979304989186,26.64245170945304,26.675110369014224,26.707769028575406,26.74042768813659,26.773086347697777,26.805745007258952,26.838403666820135,26.87106232638132,26.9037209859425,26.936379645503685,26.96903830506487,27.001696964626046,27.034355624187235,27.067014283748414,27.099672943309596,27.132331602870778,27.16499026243196,27.197648921993146,27.230307581554325,27.262966241115507,27.276702087315925,27.252592306794824,27.22848252627372,27.204372745752615,27.180262965231513,27.156153184710412,27.132043404189304,27.107933623668202,27.0838238431471,27.059714062626,27.035604282104895,27.01149450158379,26.987384721062693,26.963274940541588,26.939165160020487,26.915055379499382,26.890945598978284,26.86683581845718,26.842726037936075,26.818616257414973,26.79450647689387,26.770396696372767,26.746286915851666,26.722177135330558,26.69806735480946,26.673957574288355,26.64984779376725,26.62573801324615,26.601628232725048,26.577518452203947,26.553408671682842,26.52929889116174,26.505189110640636,26.48107933011953,26.456969549598433,26.437025189122966,26.424717459269957,26.412409729416943,26.400101999563933,26.387794269710923,26.37548653985791,26.363178810004904,26.35087108015189,26.338563350298877,26.32625562044587,26.313947890592857,26.301640160739844,26.289332430886834,26.277024701033824,26.26471697118081,26.252409241327804,26.240101511474787,26.227793781621777,26.215486051768767,26.203178321915757,26.190870592062744,26.178562862209738,26.166255132356724,26.15394740250371,26.1416396726507,26.12933194279769,26.117024212944678,26.10471648309167,26.092408753238658,26.080101023385648,26.067793293532638,26.055485563679625,26.04317783382661,26.030870103973605,26.01856237412059,26.006254644267578,25.99394691441457,25.981639184561555,25.96933145470855,25.95702372485554,25.944715995002525,25.932408265149512,25.920100535296502,25.907792805443492,25.895485075590482,25.883177345737472,25.87086961588446,25.85856188603145,25.80764201808158,25.56366145964744,25.319680901213296,25.075700342779157,24.831719784345058,24.587739225910916,24.34375866747677,24.099778109042674,23.855797550608536,23.61181699217439,23.367836433740294,23.12385587530615,22.879875316872006,22.635894758437864,22.391914200003768,22.147933641569626,21.903953083135484,21.659972524701384,21.415991966267242,21.172011407833097,20.928030849399,20.68405029096486,20.440069732530716,20.19608917409662,19.952108615662475,19.708128057228336,19.464147498794194,19.220166940360095,18.97618638192595,18.73220582349181,18.48822526505771,18.24424470662357,18.012479094045858,17.786998873189702,17.561518652333504,17.336038431477302,17.110558210621104,16.885077989764945,16.659597768908746,16.434117548052548,16.20863732719639,15.98315710634019,15.75767688548399,15.53219666462783,15.306716443771633,15.081236222915432,14.855756002059275,14.630275781203075,14.404795560346875,14.179315339490676,13.953835118634519,13.728354897778319,13.517840538960403,13.321913094549778,13.125985650139114,12.930058205728455,12.734130761317829,12.538203316907168,12.342275872496508,12.146348428085844,11.950420983675219,11.754493539264557,11.558566094853894,11.36263865044327,11.166711206032607,10.970783761621945,10.77485631721132,10.57892887280066,10.383001428389997,10.18707398397937,9.99114653956871,9.795219095158046,9.599291650747386,9.40336420633676,9.2074367619261,9.011509317515438,8.815581873104811,8.619654428694151,8.423726984283489,8.227799539872864,8.031872095462202,7.835944651051539,7.640017206640878,7.444089762230252],[19.18674599419193,19.208033464040984,19.229320933890037,19.250608403739093,19.271895873588146,19.2931833434372,19.314470813286256,19.33575828313531,19.357045752984362,19.37833322283342,19.399620692682475,19.42090816253153,19.442195632380585,19.463483102229638,19.48477057207869,19.506058041927748,19.5273455117768,19.548632981625857,19.56992045147491,19.591207921323967,19.61418499082105,19.63800686445119,19.66182873808133,19.685650611711466,19.709472485341603,19.733294358971744,19.757116232601884,19.780938106232018,19.80475997986216,19.828581853492295,19.852403727122432,19.87622560075257,19.900047474382713,19.92386934801285,19.947691221642987,19.971513095273128,19.995334968903265,20.019156842533405,20.042978716163542,20.06680058979368,20.09062246342382,20.114444337053957,20.138266210684094,20.162088084314234,20.18590995794437,20.20973183157451,20.23355370520465,20.257375578834786,20.281197452464923,20.305019326095064,20.3288411997252,20.352663073355345,20.376484946985478,20.400306820615615,20.424128694245756,20.447950567875893,20.471772441506033,20.49559431513617,20.519416188766307,20.543238062396448,20.567059936026585,20.59088180965672,20.614703683286862,20.638525556916996,20.66234743054714,20.68616930417728,20.709991177807417,20.733813051437554,20.75763492506769,20.781456798697832,20.805278672327972,20.82910054595811,20.852922419588246,20.876744293218387,20.90056616684852,20.924388040478664,20.9482099141088,20.972031787738935,20.99585366136908,21.019675534999216,21.043497408629356,21.06731928225949,21.091141155889627,21.11496302951977,21.138127941728115,21.16116146165211,21.184194981576105,21.207228501500097,21.230262021424092,21.253295541348084,21.276329061272076,21.29936258119607,21.322396101120063,21.345429621044055,21.368463140968053,21.391496660892045,21.414530180816037,21.43756370074003,21.460597220664024,21.48363074058802,21.50666426051201,21.529697780436003,21.552731300359998,21.575764820283993,21.598798340207985,21.621831860131977,21.64486538005597,21.667898899979964,21.69093241990396,21.71396593982795,21.736999459751942,21.760032979675938,21.78306649959993,21.806100019523925,21.829133539447916,21.852167059371908,21.875200579295903,21.8982340992199,21.92126761914389,21.944301139067882,21.967334658991874,21.990368178915872,22.01340169883986,22.036435218763856,22.059468738687848,22.082502258611843,22.105535778535835,22.12856929845983,22.15160281838382,22.174636338307817,22.197669858231812,22.220703378155804,22.243736898079796,22.266770418003787,22.289803937927783,22.312837457851778,22.335870977775766,22.358904497699765,22.381938017623753,22.404971537547752,22.428005057471744,22.451038577395735,22.47407209731973,22.49710561724372,22.520139137167718,22.543172657091713,22.5662061770157,22.58923969401589,22.609693715475977,22.630147736936063,22.65060175839615,22.671055779856236,22.691509801316325,22.711963822776408,22.732417844236497,22.752871865696584,22.77332588715667,22.793779908616756,22.814233930076842,22.834687951536928,22.855141972997014,22.8755959944571,22.896050015917186,22.916504037377273,22.93695805883736,22.957412080297445,22.97786610175753,23.001252395160122,23.026104824533967,23.050957253907804,23.07580968328165,23.10066211265549,23.125514542029336,23.150366971403173,23.17521940077702,23.20007183015086,23.224924259524705,23.249776688898546,23.27462911827239,23.299481547646227,23.32433397702007,23.349186406393912,23.37403883576776,23.398891265141597,23.42374369451544,23.448596123889285,23.473448553263122,23.498300982636966,23.523153412010807,23.548005841384654,23.572858270758495,23.59771070013234,23.622563129506176,23.64741555888002,23.67226798825386,23.6971204176277,23.72197284700155,23.746825276375386,23.771677705749234,23.79653013512307,23.82138256449691,23.846917401103354,23.873248385905484,23.899579370707606,23.925910355509732,23.952241340311858,23.978572325113984,24.00490330991611,24.031234294718235,24.05756527952036,24.083896264322487,24.110227249124613,24.136558233926742,24.162889218728864,24.189220203530986,24.215551188333116,24.24188217313524,24.268213157937367,24.294544142739493,24.32087512754162,24.347206112343745,24.37353709714587,24.399868081947997,24.426199066750122,24.452530051552248,24.478861036354374,24.5051920211565,24.531523005958626,24.55785399076075,24.584184975562877,24.610515960365007,24.63684694516713,24.663177929969255,24.68950891477138,24.715839899573506,24.742170884375632,24.768501869177758,24.794832853979884,24.82116383878201,24.847494823584135,24.87382580838626,24.900156793188387,24.926487777990513,24.95281876279264,24.979149747594764,25.00548073239689,25.031811717199012,25.058142702001142,25.084473686803264,25.110804671605393,25.14126870572243,25.175865789154393,25.21046287258635,25.245059956018306,25.279657039450264,25.314254122882218,25.34885120631418,25.383448289746134,25.418045373178096,25.452642456610047,25.487239540042005,25.521836623473966,25.55643370690592,25.591030790337875,25.625627873769837,25.66022495720179,25.694822040633746,25.729419124065707,25.76401620749766,25.798613290929616,25.833210374361578,25.867807457793536,25.902404541225486,25.937001624657448,25.971598708089406,26.006195791521364,26.04079287495332,26.07538995838528,26.10998704181723,26.14458412524919,26.17918120868115,26.213778292113105,26.24837537554506,26.282972458977017,26.317569542408975,26.35216662584093,26.38676370927289,26.42136079270485,26.455957876136807,26.490554959568758,26.525152043000716,26.559749126432678,26.59434620986463,26.628943293296587,26.663540376728548,26.698137460160495,26.732734543592457,26.76733162702442,26.801928710456373,26.836525793888327,26.87112287732029,26.905391678392476,26.93805033795366,26.97070899751484,27.00336765707603,27.036026316637205,27.068684976198387,27.101343635759573,27.13400229532075,27.166660954881937,27.199319614443123,27.2319782740043,27.26463693356548,27.297295593126666,27.32995425268785,27.362612912249027,27.395271571810213,27.4279302313714,27.460588890932573,27.49324755049376,27.52590621005495,27.558564869616127,27.591223529177306,27.62388218873849,27.656540848299674,27.689199507860856,27.72185816742204,27.75451682698322,27.7871754865444,27.819834146105585,27.85249280566677,27.88515146522795,27.917810124789135,27.931545970989546,27.90743619046845,27.883326409947344,27.85921662942624,27.835106848905138,27.810997068384037,27.786887287862932,27.76277750734183,27.73866772682073,27.714557946299625,27.69044816577852,27.66633838525742,27.642228604736317,27.61811882421521,27.594009043694108,27.569899263173006,27.545789482651905,27.521679702130804,27.497569921609703,27.473460141088594,27.44935036056749,27.42524058004639,27.40113079952529,27.37702101900419,27.352911238483085,27.32880145796198,27.304691677440875,27.280581896919774,27.256472116398673,27.23236233587757,27.208252555356466,27.184142774835365,27.16003299431426,27.135923213793156,27.111813433272054,27.087703652750953,27.06359387222985,27.039484091708747,27.015374311187646,26.99126453066654,26.967154750145436,26.943044969624335,26.918935189103234,26.89482540858213,26.870715628061028,26.846605847539923,26.822496067018818,26.798386286497717,26.774276505976616,26.750166725455514,26.72605694493441,26.70194716441331,26.677837383892204,26.653727603371102,26.62961782285,26.605508042328893,26.58139826180779,26.557288481286694,26.53317870076559,26.509068920244484,26.484959139723383,26.46084935920228,26.436739578681177,26.412629798160072,26.388520017638974,26.36441023711787,26.34030045659676,26.316190676075667,26.29208089555456,26.267971115033458,26.243861334512353,26.21975155399125,26.197377389258914,26.185069659405904,26.172761929552895,26.16045419969988,26.148146469846868,26.13583873999386,26.123531010140848,26.111223280287838,26.09891555043483,26.086607820581815,26.074300090728805,26.023380222778936,25.779399664344798,25.535419105910652,25.29143854747651,25.047457989042414,24.803477430608275,24.55949687217413,24.315516313740034,24.08979888152348,23.86431866066728,23.63883843981112,23.413358218954922,23.18787799809872,22.962397777242526,22.736917556386366,22.511437335530164,22.28595711467397,22.06047689381781,21.834996672961612,21.60951645210541,21.38403623124925,21.158556010393053,20.933075789536858,20.707595568680695,20.4821153478245,20.2566351269683,20.031154906112096,19.80567468525594,19.58019446439974,19.35471424354354,19.12923402268738,18.903753801831183,18.678273580974984,18.45279336011883,18.227313139262627,18.00183291840643,17.77635269755023,17.55087247669407,17.32539225583787,17.099912034981674,16.874431814125515,16.648951593269317,16.423471372413115,16.19799115155696,15.97251093070076,15.747030709844559,15.521550488988401,15.296070268132201,15.070590047276001,14.845109826419803,14.619629605563643,14.394149384707445,14.168669163851245,13.943188942995087,13.71770872213889,13.492228501282689,13.266748280426533,13.041268059570331,12.815787838714133,12.590307617857935,12.364827397001775,12.139347176145577,11.913866955289375,11.68838673443322,11.46290651357702,11.237426292720821,11.011946071864664,10.786465851008463,10.560985630152263,10.335505409296106,10.110025188439906,9.884544967583706,9.659064746727505,9.433584525871348,9.20810430501515,8.98262408415895,8.762448251794304,8.56652080738364,8.37059336297298,8.174665918562356,7.978738474151694,7.782811029741032,7.58688358533037,7.390956140919744],[19.65472289214132,19.67601036199037,19.697297831839425,19.719007699864147,19.742829573494284,19.76665144712442,19.79047332075456,19.814295194384698,19.83811706801484,19.861938941644976,19.885760815275116,19.909582688905253,19.933404562535394,19.95722643616553,19.98104830979567,20.004870183425805,20.028692057055945,20.052513930686082,20.076335804316223,20.10015767794636,20.123979551576497,20.147801425206637,20.171623298836774,20.195445172466915,20.219267046097052,20.243088919727192,20.26691079335733,20.290732666987466,20.314554540617607,20.338376414247744,20.36219828787788,20.38602016150802,20.40984203513816,20.4336639087683,20.457485782398436,20.481307656028577,20.50512952965871,20.52895140328885,20.55277327691899,20.576595150549128,20.600417024179265,20.624238897809406,20.648060771439543,20.67188264506968,20.69570451869982,20.719526392329957,20.7433482659601,20.767170139590235,20.79099201322037,20.814813886850516,20.83863576048065,20.86245763411079,20.886279507740927,20.910101381371064,20.933923255001204,20.95774512863134,20.98156700226148,21.00538887589162,21.029210749521756,21.053032623151896,21.076854496782033,21.100676370412174,21.12449824404231,21.148320117672448,21.17214199130259,21.195963864932725,21.219785738562866,21.243607612193003,21.267429485823143,21.29125135945328,21.315073233083417,21.338895106713558,21.362716980343695,21.386538853973832,21.410360727603972,21.434182601234113,21.45800447486425,21.481826348494387,21.505648222124524,21.529470095754665,21.5532919693848,21.57711384301494,21.60093571664508,21.62475759027522,21.647922502483567,21.670956022407562,21.693989542331554,21.717023062255546,21.74005658217954,21.763090102103533,21.786123622027528,21.80915714195152,21.832190661875515,21.855224181799507,21.8782577017235,21.901291221647497,21.92432474157149,21.947358261495484,21.970391781419472,21.993425301343464,22.01645882126746,22.039492341191455,22.062525861115446,22.08555938103944,22.108592900963433,22.13162642088743,22.15465994081142,22.177693460735412,22.200726980659407,22.2237605005834,22.246794020507394,22.269827540431386,22.292861060355378,22.315894580279373,22.33892810020337,22.36196162012736,22.384995140051355,22.408028659975347,22.43106217989934,22.454095699823334,22.477129219747326,22.50016273967132,22.52319625959531,22.546229779519308,22.5692632994433,22.59229681936729,22.615330339291287,22.63836385921528,22.661397379139274,22.684430899063265,22.707464418987257,22.730497938911252,22.753531458835244,22.77656497875924,22.79959849868323,22.822632018607226,22.845665538531218,22.868699058455213,22.891732578379205,22.914766098303197,22.937799618227192,22.960833138151187,22.98386665807518,23.00690017799917,23.029933697923166,23.05296721784716,23.076000737771153,23.099034257695145,23.122067777619137,23.145101297543132,23.168134817467127,23.19116833739112,23.21420185731511,23.237235377239102,23.260268897163098,23.283302417087093,23.306335937011085,23.32936945693508,23.352402976859068,23.375436496783063,23.398470016707055,23.421503536631054,23.444537056555045,23.467570576479037,23.489314344672884,23.50976836613297,23.530222387593057,23.55360868099565,23.578461110369492,23.603313539743336,23.628165969117177,23.653018398491017,23.678837573111444,23.70516855791357,23.731499542715696,23.757830527517818,23.78416151231995,23.810492497122077,23.8368234819242,23.863154466726325,23.88948545152845,23.91581643633058,23.942147421132702,23.968478405934828,23.994809390736954,24.021140375539083,24.04747136034121,24.07380234514333,24.100133329945457,24.126464314747583,24.15279529954971,24.179126284351835,24.20545726915396,24.231788253956086,24.258119238758212,24.28445022356034,24.310781208362464,24.33711219316459,24.363443177966715,24.389774162768845,24.416105147570967,24.442436132373093,24.46876711717522,24.49509810197734,24.52142908677947,24.547760071581596,24.574091056383722,24.600422041185844,24.626753025987973,24.6530840107901,24.679414995592225,24.70574598039435,24.732076965196477,24.7584079499986,24.78473893480073,24.811069919602854,24.83740090440498,24.863731889207106,24.89006287400923,24.916393858811354,24.942724843613483,24.969055828415613,24.99538681321773,25.021717798019857,25.048048782821986,25.074379767624116,25.100710752426238,25.127041737228364,25.153372722030486,25.179703706832612,25.20603469163474,25.23236567643687,25.25869666123899,25.285027646041115,25.311358630843245,25.337689615645367,25.3640206004475,25.390351585249622,25.416682570051748,25.443013554853874,25.469344539656,25.495675524458125,25.522006509260247,25.548337494062377,25.574668478864503,25.600999463666632,25.627330448468754,25.653661433270884,25.679992418073006,25.70632340287513,25.736787436992174,25.77138452042413,25.80598160385609,25.840578687288044,25.875175770720002,25.90977285415196,25.944369937583915,25.978967021015873,26.01356410444783,26.048161187879785,26.082758271311743,26.117355354743705,26.15195243817566,26.186549521607613,26.22114660503957,26.255743688471533,26.290340771903487,26.324937855335442,26.3595349387674,26.394132022199358,26.428729105631312,26.463326189063274,26.497923272495225,26.532520355927186,26.567117439359144,26.601714522791102,26.636311606223057,26.670908689655015,26.705505773086973,26.740102856518927,26.774699939950885,26.809297023382847,26.843894106814794,26.87849119024676,26.913088273678717,26.94768535711067,26.98228244054263,27.016879523974588,27.05147660740654,27.086073690838496,27.120670774270454,27.155267857702412,27.189864941134367,27.22446202456633,27.259059107998283,27.293656191430237,27.328253274862192,27.362850358294157,27.397447441726108,27.43204452515807,27.466641608590027,27.50123869202198,27.535835775453936,27.570432858885898,27.605029942317856,27.63962702574981,27.67422410918177,27.708821192613723,27.74341827604568,27.77801535947764,27.812612442909597,27.84720952634155,27.88180660977351,27.916403693205467,27.95100077663742,27.98559786006938,28.02019494350134,28.0547920269333,28.08938911036525,28.123986193797208,28.158583277229166,28.193180360661124,28.22777744409308,28.262374527525036,28.29697161095699,28.33156869438895,28.366165777820907,28.400762861252865,28.435359944684823,28.46995702811678,28.504554111548735,28.539151194980697,28.572654008462745,28.58638985466316,28.56228007414206,28.538170293620954,28.514060513099853,28.48995073257875,28.461879230726293,28.4330706789968,28.404262127267305,28.375453575537815,28.346645023808318,28.317836472078827,28.289027920349337,28.260219368619843,28.23141081689035,28.202602265160856,28.173793713431362,28.144985161701868,28.116176609972378,28.087368058242888,28.05855950651339,28.029750954783896,28.000942403054403,27.972133851324912,27.94332529959542,27.914516747865928,27.885708196136434,27.856899644406937,27.828091092677447,27.799282540947956,27.77047398921846,27.74166543748896,27.712856885759475,27.68404833402998,27.655239782300487,27.626431230570997,27.5976226788415,27.568814127112006,27.540005575382516,27.511197023653022,27.482388471923528,27.453579920194038,27.424771368464544,27.39596281673505,27.367154265005556,27.338345713276066,27.309537161546572,27.28072860981708,27.251920058087585,27.223111506358094,27.1943029546286,27.165494402899107,27.136685851169617,27.107877299440123,27.07906874771063,27.05026019598114,27.02145164425164,26.992643092522147,26.963834540792654,26.935025989063163,26.90621743733367,26.877408885604176,26.848600333874685,26.81979178214519,26.790983230415698,26.762174678686208,26.73336612695671,26.704557575227216,26.67574902349773,26.646940471768232,26.61813192003874,26.58932336830924,26.560514816579754,26.53170626485026,26.502897713120767,26.474089161391273,26.44528060966178,26.416472057932285,26.3876635062028,26.3588549544733,26.330046402743807,26.301237851014314,26.27242929928482,26.24362074755533,26.17628628670594,25.916322280257024,25.656358273808117,25.396394267359202,25.136430260910345,24.87646625446143,24.616502248012523,24.356538241563662,24.09657423511475,23.836610228665837,23.576646222216976,23.316682215768065,23.056718209319154,22.796754202870247,22.536790196421382,22.276826189972475,22.01686218352356,21.7568981770747,21.496934170625785,21.236970164176878,20.977006157728017,20.717042151279106,20.45707814483019,20.19711413838133,19.937150131932423,19.67718612548351,19.4172221190346,19.157258112585737,18.90771120268395,18.68223098182775,18.456750760971588,18.23127054011539,18.00579031925919,17.78031009840303,17.554829877546837,17.32934965669064,17.103869435834437,16.878389214978277,16.65290899412208,16.42742877326588,16.201948552409725,15.976468331553523,15.750988110697325,15.525507889841167,15.300027668984967,15.074547448128767,14.84906722727261,14.62358700641641,14.398106785560207,14.172626564704009,13.947146343847852,13.721666122991653,13.496185902135451,13.270705681279294,13.045225460423094,12.819745239566894,12.619974706248044,12.424231110797464,12.228487515346888,12.03274391989631,11.837000324445768,11.641256728995192,11.445513133544614,11.249769538094071,11.054025942643493,10.858282347192915,10.662538751742373,10.466795156291798,10.271051560841219,10.075307965390678,9.879564369940098,9.683820774489522,9.488077179038944,9.292333583588404,9.096589988137826,8.900846392687248,8.705102797236707,8.509359201786129,8.313615606335551,8.11787201088501,7.922128415434432,7.726384819983853,7.530641224533276,7.334897629082734],[20.119699886153942,20.145913095280633,20.172126304407325,20.198339513534016,20.224552722660707,20.2507659317874,20.27697914091409,20.30319235004078,20.329405559167476,20.355618768294168,20.38183197742086,20.40804518654755,20.43425839567424,20.460471604800933,20.485887700174057,20.50970957380419,20.53353144743433,20.55735332106447,20.58117519469461,20.604997068324746,20.628818941954886,20.652640815585027,20.676462689215164,20.700284562845304,20.724106436475438,20.74792831010558,20.771750183735715,20.795572057365852,20.819393930995993,20.843215804626134,20.867037678256267,20.890859551886408,20.914681425516545,20.938503299146685,20.962325172776822,20.986147046406963,21.0099689200371,21.03379079366724,21.057612667297377,21.081434540927518,21.105256414557655,21.12907828818779,21.152900161817932,21.17672203544807,21.200543909078206,21.224365782708347,21.248187656338487,21.27200952996862,21.29583140359876,21.319653277228902,21.343475150859035,21.367297024489176,21.391118898119316,21.414940771749453,21.43876264537959,21.46258451900973,21.486406392639868,21.51022826627001,21.534050139900145,21.55787201353028,21.581693887160423,21.60551576079056,21.6293376344207,21.653159508050837,21.676981381680974,21.700803255311115,21.724625128941252,21.74844700257139,21.77226887620153,21.796090749831666,21.819912623461807,21.843734497091944,21.86755637072208,21.891378244352218,21.91520011798236,21.939021991612496,21.962843865242636,21.986665738872773,22.010487612502914,22.034309486133047,22.058131359763188,22.081953233393325,22.105775107023465,22.129596980653606,22.15480774046049,22.18029627750273,22.205784814544963,22.231273351587205,22.256761888629438,22.282250425671673,22.307738962713913,22.33322749975615,22.358716036798388,22.384204573840623,22.409693110882863,22.4351816479251,22.460670184967338,22.48574955051732,22.50878307044131,22.531816590365302,22.554850110289294,22.57788363021329,22.60091715013728,22.623950670061273,22.646984189985268,22.67001770990926,22.693051229833255,22.716084749757243,22.739118269681242,22.762151789605234,22.785185309529226,22.80821882945322,22.831252349377213,22.854285869301208,22.8773193892252,22.900352909149195,22.92338642907319,22.946419948997182,22.969453468921174,22.992486988845165,23.015520508769164,23.038554028693156,23.061587548617148,23.08462106854114,23.107654588465135,23.130688108389126,23.15372162831312,23.176755148237113,23.199788668161105,23.2228221880851,23.245855708009096,23.268889227933087,23.29192274785708,23.31495626778107,23.337989787705066,23.361023307629058,23.384056827553053,23.407090347477045,23.43012386740104,23.45315738732503,23.476190907249027,23.49922442717302,23.522257947097014,23.545291467021006,23.568324986945,23.591358506868993,23.614392026792984,23.63742554671698,23.66045906664097,23.683492586564967,23.706526106488955,23.729559626412954,23.752593146336945,23.775626666260937,23.798660186184936,23.821693706108924,23.84472722603292,23.867760745956907,23.890794265880903,23.9138277858049,23.93686130572889,23.959894825652885,23.982928345576877,24.005961865500872,24.028995385424867,24.052028905348855,24.07506242527285,24.100878870830066,24.12808677920389,24.155294687577722,24.182502595951547,24.209710504325372,24.2369184126992,24.26412632107302,24.291334229446853,24.318542137820682,24.345750046194503,24.372957954568335,24.40016586294216,24.427373771315988,24.454581679689813,24.48178958806364,24.508997496437466,24.536205404811295,24.56341331318512,24.590621221558948,24.617829129932773,24.645037038306597,24.67224494668043,24.69945285505425,24.72666076342808,24.753868671801907,24.781076580175732,24.80828448854956,24.835492396923385,24.862700305297214,24.889908213671042,24.917116122044867,24.944324030418695,24.971531938792516,24.99873984716634,25.025947755540173,25.053155663913998,25.080363572287826,25.10757148066165,25.13477938903548,25.161987297409304,25.189195205783133,25.216403114156957,25.243611022530786,25.27081893090461,25.29802683927844,25.325234747652267,25.352442656026092,25.37965056439992,25.406588650872607,25.43291963567473,25.45925062047686,25.48558160527898,25.51191259008111,25.538243574883236,25.56457455968536,25.590905544487484,25.617236529289613,25.643567514091735,25.66989849889386,25.69622948369599,25.722560468498116,25.74889145330024,25.775222438102368,25.80155342290449,25.827884407706616,25.854215392508745,25.880546377310868,25.906877362112997,25.933208346915123,25.95953933171725,25.98587031651937,26.012201301321497,26.038532286123623,26.064863270925752,26.091194255727878,26.11752524053,26.14385622533213,26.17018721013425,26.19651819493638,26.222849179738507,26.24918016454063,26.275511149342755,26.301842134144884,26.332306168261923,26.366903251693884,26.40150033512584,26.436097418557793,26.47069450198975,26.505291585421705,26.539888668853663,26.57448575228562,26.60908283571758,26.64367991914953,26.678277002581492,26.71287408601345,26.747471169445408,26.782068252877362,26.81666533630932,26.851262419741282,26.885859503173236,26.920456586605194,26.955053670037152,26.989650753469107,27.02424783690107,27.058844920333026,27.093442003764977,27.128039087196935,27.162636170628897,27.19723325406085,27.231830337492806,27.266427420924764,27.30102450435672,27.335621587788676,27.370218671220634,27.404815754652596,27.440002991907804,27.475531202885907,27.51105941386401,27.54658762484211,27.58211583582021,27.61764404679832,27.65317225777642,27.68870046875452,27.724228679732622,27.759756890710722,27.795285101688822,27.830813312666926,27.866341523645033,27.90186973462313,27.937397945601234,27.972926156579337,28.00845436755744,28.04398257853554,28.07951078951364,28.11503900049175,28.150567211469845,28.18609542244795,28.221623633426052,28.25715184440415,28.292680055382252,28.328208266360356,28.363736477338456,28.39926468831656,28.434792899294663,28.470321110272764,28.505849321250864,28.54137753222897,28.57690574320707,28.61243395418517,28.647962165163275,28.68349037614137,28.719018587119475,28.75454679809758,28.790075009075686,28.82560322005378,28.861131431031882,28.896659642009986,28.932187852988086,28.967716063966186,29.003244274944294,29.038772485922394,29.074300696900494,29.109828907878594,29.1453571188567,29.1808853298348,29.2164135408129,29.226154365934605,29.184320419343543,29.142486472752477,29.10065252616141,29.058818579570342,29.01698463297928,28.975150686388208,28.933316739797142,28.89148279320608,28.849648846615015,28.807814900023946,28.76598095343288,28.72414700684181,28.682313060250745,28.64047911365968,28.598645167068614,28.556811220477545,28.51497727388648,28.473143327295418,28.43130938070435,28.389475434113283,28.34764148752221,28.305807540931152,28.26397359434008,28.22213964774902,28.180305701157955,28.138471754566886,28.096637807975817,28.05480386138475,28.012969914793686,27.971135968202617,27.929302021611555,27.887468075020482,27.845634128429417,27.80380018183835,27.761966235247286,27.720132288656217,27.678298342065155,27.64157505464887,27.612766502919378,27.583957951189888,27.555149399460394,27.5263408477309,27.497532296001403,27.468723744271912,27.439915192542422,27.41110664081293,27.382298089083434,27.353489537353944,27.324680985624447,27.295872433894957,27.267063882165466,27.23825533043597,27.20944677870648,27.18063822697699,27.15182967524749,27.123021123518,27.094212571788503,27.065404020059013,27.03659546832952,27.007786916600026,26.978978364870535,26.95016981314104,26.921361261411548,26.892552709682057,26.86374415795256,26.834935606223066,26.806127054493576,26.777318502764082,26.748509951034585,26.719701399305094,26.6908928475756,26.662084295846107,26.633275744116617,26.604467192387123,26.57565864065763,26.546850088928135,26.518041537198645,26.48923298546915,26.460424433739654,26.431615882010163,26.402807330280673,26.373998778551176,26.306664317701788,26.046700311252874,25.786736304803963,25.526772298355056,25.266808291906187,25.006844285457284,24.746880279008366,24.486916272559508,24.226952266110594,23.966988259661687,23.707024253212822,23.44706024676391,23.187096240315,22.92713223386609,22.667168227417232,22.40720422096832,22.147240214519407,21.887276208070546,21.62731220162164,21.367348195172724,21.107384188723863,20.847420182274952,20.58745617582604,20.32749216937718,20.06752816292827,19.80756415647936,19.547600150030448,19.307080953509477,19.075172286831766,18.843263620154055,18.611354953476386,18.379446286798682,18.14753762012097,17.915628953443303,17.683720286765595,17.451811620087884,17.219902953410177,16.98799428673251,16.7560856200548,16.52417695337709,16.292268286699425,16.060359620021714,15.828450953344003,15.596542286666338,15.364633619988629,15.13272495331092,14.900816286633251,14.668907619955544,14.436998953277834,14.205090286600125,13.973181619922457,13.741272953244748,13.509364286567038,13.277455619889372,13.045546953211662,12.813638286533953,12.581729619856285,12.36694797151186,12.171204376061283,11.975460780610707,11.779717185160166,11.583973589709586,11.38822999425901,11.192486398808466,10.99674280335789,10.800999207907312,10.60525561245677,10.409512017006193,10.213768421555615,10.018024826105075,9.822281230654497,9.626537635203917,9.43079403975334,9.2350504443028,9.03930684885222,8.843563253401644,8.647819657951104,8.452076062500524,8.256332467049948,8.060588871599407,7.864845276148827,7.669101680698249,7.473358085247672,7.277614489797131],[20.584054948613446,20.610268157740137,20.63648136686683,20.66269457599352,20.68890778512021,20.715120994246902,20.741334203373594,20.767547412500285,20.793760621626976,20.819973830753668,20.84618703988036,20.87240024900705,20.89861345813374,20.924826667260437,20.951039876387128,20.977253085513823,21.00346629464051,21.029679503767202,21.055892712893893,21.082105922020588,21.108319131147276,21.13453234027397,21.16074554940066,21.186958758527354,21.213171967654045,21.239385176780736,21.265598385907424,21.29181159503412,21.31802480416081,21.3442380132875,21.370451222414193,21.394671650433605,21.418493524063745,21.442315397693882,21.46613727132402,21.489959144954163,21.513781018584297,21.537602892214437,21.561424765844578,21.585246639474715,21.609068513104848,21.632890386734992,21.65671226036513,21.680534133995266,21.704356007625407,21.728177881255544,21.75199975488568,21.77582162851582,21.79964350214596,21.823465375776095,21.847287249406236,21.871109123036376,21.89493099666651,21.91875287029665,21.942574743926787,21.966396617556928,21.990218491187065,22.014040364817205,22.037862238447342,22.061684112077483,22.08550598570762,22.109327859337757,22.133149732967894,22.156971606598034,22.180793480228175,22.204615353858316,22.22843722748845,22.25225910111859,22.276080974748727,22.299902848378863,22.323724722009004,22.34754659563914,22.37136846926928,22.39519034289942,22.41901221652956,22.442834090159693,22.466655963789833,22.490477837419974,22.51429971105011,22.538121584680248,22.561943458310388,22.585765331940525,22.609587205570662,22.633409079200803,22.658619839007688,22.684108376049927,22.709596913092163,22.7350854501344,22.760573987176638,22.786062524218877,22.811551061261113,22.83703959830335,22.86252813534559,22.888016672387828,22.913505209430063,22.9389937464723,22.96448228351454,22.989970820556774,23.015459357599013,23.04094789464125,23.066436431683485,23.091924968725724,23.117413505767963,23.1429020428102,23.168390579852435,23.19387911689467,23.21936765393691,23.244856190979146,23.270344728021385,23.29583326506362,23.321321802105857,23.346810339148096,23.37229887619033,23.39778741323257,23.421639270628503,23.444672790552495,23.467706310476487,23.490739830400482,23.513773350324477,23.53680687024847,23.559840390172464,23.582873910096456,23.605907430020448,23.628940949944443,23.651974469868435,23.675007989792427,23.69804150971642,23.721075029640417,23.74410854956441,23.7671420694884,23.790175589412392,23.813209109336388,23.836242629260383,23.859276149184378,23.882309669108366,23.905343189032358,23.928376708956357,23.95141022888035,23.97444374880434,23.997477268728336,24.020510788652327,24.043544308576323,24.066577828500314,24.089611348424306,24.1126448683483,24.135678388272293,24.158711908196288,24.18174542812028,24.20477894804427,24.227812467968267,24.250845987892262,24.273879507816254,24.29691302774025,24.31994654766424,24.342980067588233,24.366013587512228,24.389047107436223,24.412080627360215,24.43511414728421,24.4581476672082,24.481181187132197,24.50421470705619,24.52724822698018,24.550281746904172,24.573315266828168,24.596348786752163,24.619382306676155,24.64519875223337,24.672406660607194,24.699614568981023,24.72682247735485,24.754030385728676,24.7812382941025,24.80844620247633,24.835654110850157,24.862862019223982,24.890069927597807,24.91727783597164,24.944485744345464,24.97169365271929,24.998901561093117,25.02610946946694,25.05331737784077,25.080525286214595,25.107733194588423,25.13494110296225,25.162149011336076,25.1893569197099,25.216564828083733,25.243772736457558,25.270980644831383,25.29818855320521,25.325396461579036,25.352604369952864,25.37981227832669,25.40702018670052,25.434228095074346,25.461436003448167,25.488643911822,25.515851820195824,25.54305972856965,25.570267636943477,25.5974755453173,25.62468345369113,25.65189136206496,25.679099270438783,25.706307178812608,25.733515087186433,25.76072299556026,25.78793090393409,25.815138812307918,25.842346720681746,25.86955462905557,25.896762537429392,25.92397044580322,25.951178354177046,25.978386262550874,26.005594170924706,26.032802079298527,26.06000998767236,26.087217896046184,26.114425804420012,26.141633712793837,26.168841621167665,26.19604952954149,26.223257437915315,26.250465346289143,26.277673254662968,26.304881163036796,26.332089071410625,26.35929697978445,26.386504888158274,26.413712796532103,26.44092070490593,26.468128613279756,26.495336521653584,26.52254443002741,26.549752338401237,26.576960246775062,26.60416815514889,26.631376063522715,26.660019099577315,26.68904851309493,26.718077926612537,26.74710734013015,26.776136753647762,26.805166167165368,26.834195580682977,26.86322499420059,26.892254407718198,26.92503912087996,26.96157913368587,26.998119146491778,27.034659159297686,27.071199172103594,27.107739184909505,27.144279197715417,27.180819210521324,27.217359223327236,27.253899236133144,27.29043924893905,27.326979261744963,27.36351927455087,27.400059287356783,27.43659930016269,27.4731393129686,27.50967932577451,27.54621933858042,27.582759351386326,27.619299364192234,27.655839376998145,27.69237938980406,27.728919402609964,27.765459415415876,27.80106545960946,27.83659367058756,27.872121881565658,27.907650092543765,27.943178303521865,27.978706514499965,28.01423472547807,28.049762936456176,28.08529114743427,28.120819358412376,28.156347569390476,28.191875780368576,28.227403991346684,28.262932202324784,28.298460413302884,28.333988624280984,28.36951683525909,28.40504504623719,28.44057325721529,28.476101468193395,28.5116296791715,28.5471578901496,28.582686101127702,28.618214312105806,28.653742523083906,28.689270734062006,28.72479894504011,28.760327156018214,28.795855366996314,28.831383577974417,28.86691178895252,28.902439999930618,28.93796821090872,28.97349642188683,29.00902463286493,29.044552843843025,29.080081054821132,29.11560926579923,29.151137476777333,29.186665687755436,29.222193898733536,29.257722109711636,29.293250320689737,29.328778531667844,29.36430674264594,29.399834953624044,29.435363164602148,29.470891375580248,29.50641958655835,29.541947797536455,29.577476008514555,29.613004219492655,29.64853243047076,29.68406064144886,29.71958885242696,29.755117063405066,29.790645274383166,29.826173485361267,29.861701696339367,29.871442521461077,29.82960857487001,29.787774628278946,29.745940681687877,29.70410673509681,29.662272788505746,29.620438841914677,29.578604895323608,29.53677094873255,29.494937002141477,29.45310305555041,29.41126910895935,29.369435162368283,29.32760121577721,29.285767269186145,29.243933322595083,29.202099376004014,29.16026542941295,29.118431482821883,29.076597536230818,29.034763589639745,28.992929643048683,28.95109569645762,28.90926174986655,28.867427803275486,28.82559385668442,28.78375991009335,28.74192596350229,28.70009201691122,28.65825807032015,28.616424123729082,28.574590177138024,28.532756230546955,28.490922283955886,28.44908833736482,28.40725439077376,28.36542044418269,28.323586497591627,28.281752551000558,28.23991860440949,28.198084657818427,28.156250711227358,28.11441676463629,28.072582818045223,28.030748871454158,27.988914924863096,27.94708097827202,27.90524703168096,27.863413085089896,27.821579138498826,27.77974519190776,27.7379112453167,27.69607729872563,27.65424335213456,27.6124094055435,27.57057545895243,27.52874151236136,27.486907565770295,27.445073619179233,27.403239672588164,27.3614057259971,27.319571779406033,27.277737832814964,27.235903886223895,27.194069939632836,27.152235993041764,27.110402046450698,27.068568099859633,27.026734153268567,26.9849002066775,26.943066260086432,26.90123231349537,26.8593983669043,26.81756442031324,26.77573047372217,26.733896527131105,26.692062580540032,26.650228633948974,26.619611016464997,26.590802464735503,26.56199391300601,26.53318536127652,26.504376809547022,26.43704234869763,26.17707834224872,25.91711433579981,25.657150329350902,25.420565745331743,25.188657078654035,24.956748411976324,24.724839745298656,24.492931078620945,24.261022411943234,24.02911374526557,23.79720507858786,23.565296411910154,23.333387745232443,23.101479078554775,22.869570411877067,22.63766174519936,22.40575307852169,22.17384441184398,21.941935745166273,21.710027078488608,21.478118411810897,21.246209745133186,21.01430107845552,20.78239241177781,20.550483745100102,20.31857507842239,20.086666411744726,19.854757745067015,19.622849078389308,19.39094041171164,19.15903174503393,18.927123078356217,18.695214411678553,18.463305745000845,18.231397078323138,17.999488411645423,17.767579744967758,17.53567107829005,17.30376241161234,17.071853744934675,16.839945078256964,16.608036411579256,16.376127744901588,16.144219078223877,15.912310411546168,15.680401744868501,15.448493078190793,15.216584411513084,14.984675744835373,14.752767078157706,14.520858411479995,14.288949744802288,14.057041078124621,13.82513241144691,13.593223744769201,13.361315078091534,13.129406411413825,12.897497744736118,12.665589078058407,12.433680411380742,12.20177174470303,11.969863078025321,11.737954411347655,11.506045744669946,11.274137077992236,11.04222841131457,10.81031974463686,10.578411077959153,10.346502411281485,10.114593744603775,9.882685077926066,9.650776411248357,9.418867744570688,9.186959077892979,8.95505041121527,8.723141744537603,8.491233077859894,8.259324411182186,8.02741574450452,7.807562136863225,7.611818541412648,7.4160749459620705,7.220331350511528],[21.048410011072953,21.074623220199648,21.10083642932634,21.12704963845303,21.15326284757972,21.179476056706417,21.205689265833108,21.231902474959803,21.258115684086484,21.28432889321318,21.31054210233987,21.33675531146656,21.362968520593256,21.389181729719947,21.415394938846642,21.44160814797333,21.46782135710002,21.494034566226716,21.520247775353404,21.5464609844801,21.57267419360679,21.598887402733478,21.625100611860173,21.65131382098686,21.677527030113556,21.703740239240247,21.729953448366935,21.75616665749363,21.782379866620317,21.808593075747012,21.834806284873707,21.861019494000395,21.88723270312709,21.913445912253778,21.939659121380473,21.96587233050716,21.992085539633855,22.018298748760547,22.044511957887238,22.070725167013933,22.09693837614062,22.123151585267312,22.149364794394003,22.175578003520695,22.201791212647386,22.228004421774077,22.25421763090077,22.27963372706303,22.30345560069317,22.327277474323306,22.351099347953447,22.374921221583584,22.39874309521372,22.422564968843858,22.446386842474,22.47020871610414,22.494030589734276,22.517852463364417,22.541674336994554,22.565496210624694,22.58931808425483,22.613139957884968,22.636961831515105,22.660783705145242,22.684605578775383,22.708427452405523,22.732249326035657,22.7560711996658,22.779893073295938,22.803714946926075,22.827536820556215,22.851358694186352,22.875180567816493,22.89900244144663,22.922824315076767,22.946646188706907,22.97046806233704,22.99428993596718,23.018111809597322,23.04193368322746,23.065755556857596,23.089577430487736,23.113399304117877,23.13722117774801,23.1624319375549,23.187920474597135,23.21340901163937,23.238897548681614,23.26438608572385,23.289874622766085,23.31536315980832,23.34085169685056,23.3663402338928,23.391828770935035,23.41731730797727,23.44280584501951,23.46829438206175,23.493782919103985,23.51927145614622,23.54475999318846,23.570248530230696,23.595737067272935,23.62122560431517,23.646714141357407,23.672202678399643,23.697691215441882,23.72317975248412,23.748668289526357,23.774156826568593,23.79964536361083,23.825133900653068,23.850622437695307,23.876110974737543,23.90159951177978,23.927088048822018,23.952576585864257,23.978065122906493,24.00355365994873,24.029042196990968,24.054530734033204,24.080019271075443,24.10550780811768,24.130996345159915,24.156484882202154,24.181973419244393,24.20746195628663,24.232950493328865,24.2584390303711,24.283927567413336,24.30941610445558,24.33449547081571,24.357528990739702,24.380562510663694,24.403596030587686,24.426629550511684,24.449663070435676,24.472696590359668,24.49573011028366,24.518763630207655,24.541797150131647,24.564830670055642,24.587864189979634,24.61089770990363,24.63393122982762,24.656964749751616,24.679998269675608,24.7030317895996,24.726065309523594,24.749098829447586,24.77213234937158,24.795165869295573,24.81819938921957,24.84123290914356,24.864266429067552,24.887299948991547,24.91033346891554,24.933366988839534,24.95640050876353,24.979434028687518,25.002467548611516,25.025501068535505,25.048534588459503,25.07156810838349,25.094601628307487,25.11763514823148,25.140668668155474,25.163702188079466,25.18951863363668,25.21672654201051,25.243934450384337,25.271142358758162,25.298350267131987,25.32555817550582,25.352766083879644,25.379973992253472,25.4071819006273,25.43438980900112,25.46159771737495,25.488805625748775,25.516013534122607,25.54322144249643,25.570429350870256,25.59763725924408,25.62484516761791,25.652053075991738,25.679260984365563,25.706468892739387,25.733676801113212,25.760884709487044,25.78809261786087,25.8153005262347,25.842508434608522,25.869716342982347,25.896924251356175,25.924132159730004,25.95134006810383,25.97854797647766,26.00575588485148,26.032963793225314,26.060171701599135,26.08737960997296,26.114587518346788,26.141795426720613,26.169003335094445,26.19621124346827,26.223419151842094,26.250627060215923,26.277834968589747,26.305042876963576,26.3322507853374,26.359458693711233,26.386666602085057,26.413874510458886,26.441082418832707,26.468290327206535,26.49549823558036,26.52270614395419,26.549914052328017,26.578557087544727,26.60758650106234,26.636615914579945,26.665645328097558,26.69467474161517,26.723704155132772,26.752733568650388,26.781762982167997,26.81079239568561,26.839821809203215,26.86885122272082,26.897880636238437,26.926910049756046,26.95593946327365,26.984968876791267,27.013998290308876,27.043027703826485,27.072057117344098,27.101086530861707,27.130115944379316,27.159145357896925,27.188174771414538,27.217204184932147,27.246233598449756,27.275263011967365,27.304292425484974,27.333321839002586,27.362351252520195,27.391380666037804,27.42041007955541,27.449439493073022,27.478468906590635,27.511253619752395,27.547793632558307,27.584333645364215,27.620873658170122,27.657413670976034,27.69395368378194,27.730493696587853,27.76703370939376,27.803573722199673,27.840113735005577,27.87665374781149,27.913193760617396,27.949733773423308,27.98627378622922,28.02281379903513,28.059353811841035,28.095893824646943,28.132433837452854,28.168973850258766,28.205513863064674,28.24205387587058,28.278593888676497,28.315133901482398,28.351673914288313,28.388213927094224,28.424753939900135,28.461293952706036,28.49783396551195,28.53437397831786,28.570913991123767,28.60745400392968,28.64399401673559,28.68053402954149,28.717074042347406,28.753614055153314,28.790154067959225,28.826694080765137,28.863234093571045,28.899774106376952,28.936314119182864,28.97285413198877,29.009394144794676,29.04593415760059,29.082474170406503,29.119014183212414,29.155554196018315,29.19209420882423,29.22863422163014,29.265174234436053,29.301714247241957,29.33825426004787,29.374794272853773,29.411334285659684,29.447874298465592,29.484414311271504,29.52095432407741,29.557494336883323,29.59403434968923,29.630574362495146,29.667114375301054,29.703654388106962,29.74019440091287,29.77673441371878,29.813274426524686,29.8498144393306,29.88635445213651,29.922894464942416,29.959434477748328,29.995974490554236,30.032514503360147,30.069054516166055,30.105594528971963,30.142134541777875,30.178674554583786,30.21521456738969,30.251754580195602,30.28829459300151,30.32483460580742,30.36137461861333,30.39791463141924,30.434454644225152,30.470994657031063,30.50698985186585,30.516730676987553,30.474896730396487,30.430711972870093,30.382609151606076,30.334506330342077,30.286403509078074,30.238300687814057,30.19019786655005,30.14209504528605,30.093992224022035,30.045889402758032,29.997786581494022,29.949683760230023,29.90158093896601,29.853478117702004,29.805375296438,29.75727247517399,29.70916965390999,29.66106683264598,29.612964011381973,29.564861190117966,29.516758368853957,29.468655547589954,29.420552726325944,29.372449905061938,29.32434708379793,29.276244262533925,29.22814144126992,29.180038620005913,29.131935798741907,29.083832977477897,29.035730156213894,28.987627334949888,28.939524513685875,28.891421692421872,28.84331887115787,28.79521604989386,28.74711322862985,28.699010407365847,28.650907586101837,28.602804764837835,28.55470194357383,28.506599122309815,28.45849630104581,28.410393479781803,28.362290658517797,28.31418783725379,28.266085015989788,28.217982194725778,28.169879373461768,28.121776552197765,28.073673730933763,28.02557090966975,27.977468088405743,27.92936526714174,27.88126244587773,27.83315962461372,27.78505680334972,27.736953982085716,27.688851160821706,27.640748339557703,27.592645518293693,27.544542697029684,27.49643987576568,27.44833705450168,27.400234233237665,27.35213141197366,27.304028590709656,27.255925769445646,27.207822948181636,27.159720126917627,27.111617305653624,27.063514484389618,27.015411663125608,26.967308841861605,26.9192060205976,26.87110319933359,26.823000378069587,26.774897556805577,26.726794735541567,26.678691914277564,26.63058909301356,26.58248627174955,26.497072495469332,26.22510394410802,25.95313539274671,25.681166841385398,25.409198290024136,25.137229738662825,24.865261187301513,24.59329263594025,24.32132408457894,24.04935553321763,23.777386981856367,23.505418430495055,23.233449879133744,22.961481327772432,22.689512776411174,22.417544225049863,22.145575673688555,21.873607122327293,21.60163857096598,21.32967001960467,21.05770146824341,20.785732916882097,20.513764365520785,20.241795814159524,19.969827262798216,19.6978587114369,19.42589016007559,19.153921608714327,18.881953057353016,18.609984505991708,18.338015954630446,18.066047403269135,17.794078851907823,17.52211030054656,17.250141749185254,16.978173197823942,16.706204646462627,16.44440272474851,16.212494058070803,15.980585391393092,15.748676724715423,15.516768058037714,15.284859391360005,15.052950724682336,14.821042058004627,14.58913339132692,14.357224724649251,14.159580434598716,13.96520610307683,13.770831771554947,13.5764574400331,13.382083108511214,13.187708776989329,12.99333444546748,12.798960113945597,12.604585782423712,12.410211450901866,12.21583711937998,12.021462787858095,11.827088456336211,11.632714124814363,11.438339793292478,11.243965461770594,11.049591130248745,10.855216798726861,10.660842467204976,10.466468135683128,10.272093804161244,10.077719472639359,9.883345141117509,9.688970809595624,9.49459647807374,9.300222146551857,9.105847815030007,8.911473483508123,8.71709915198624,8.52272482046439,8.328350488942506,8.133976157420621,7.939601825898773,7.745227494376889,7.550853162855003,7.356478831333119,7.162104499811271],[21.512765073532467,21.53897828265916,21.56519149178585,21.59140470091254,21.617617910039232,21.643831119165924,21.670044328292615,21.696257537419307,21.722470746546,21.748683955672693,21.77489716479938,21.801110373926072,21.827323583052763,21.853536792179458,21.87975000130615,21.905963210432844,21.932176419559532,21.958389628686223,21.984602837812915,22.01081604693961,22.037029256066297,22.063242465192992,22.08945567431968,22.115668883446375,22.141882092573066,22.168095301699758,22.194308510826446,22.22052171995314,22.24673492907983,22.272948138206523,22.299161347333214,22.325374556459906,22.351587765586597,22.37780097471329,22.404014183839983,22.43022739296667,22.456440602093366,22.482653811220054,22.50886702034675,22.53508022947344,22.56129343860013,22.587506647726823,22.613719856853514,22.63993306598021,22.666146275106897,22.69235948423359,22.71857269336028,22.744785902486974,22.770999111613666,22.797212320740357,22.823425529867052,22.849638738993736,22.87585194812043,22.902065157247122,22.92827836637381,22.95449157550051,22.980704784627196,23.00691799375389,23.03313120288058,23.05934441200727,23.085557621133965,23.111770830260653,23.137984039387348,23.16419724851404,23.18841767732259,23.21223955095273,23.236061424582868,23.259883298213005,23.283705171843145,23.307527045473286,23.331348919103423,23.355170792733563,23.378992666363697,23.402814539993837,23.426636413623974,23.450458287254115,23.474280160884252,23.498102034514392,23.52192390814453,23.545745781774666,23.569567655404807,23.593389529034944,23.617211402665085,23.64103327629522,23.666244036102107,23.69173257314435,23.717221110186586,23.74270964722882,23.768198184271057,23.793686721313293,23.819175258355536,23.84466379539777,23.870152332440007,23.895640869482243,23.921129406524486,23.946617943566714,23.972106480608957,23.997595017651193,24.023083554693436,24.04857209173567,24.074060628777907,24.099549165820143,24.125037702862386,24.15052623990462,24.176014776946857,24.201503313989093,24.22699185103133,24.252480388073565,24.277968925115808,24.303457462158043,24.32894599920028,24.354434536242515,24.37992307328475,24.405411610326993,24.43090014736923,24.456388684411465,24.4818772214537,24.507365758495936,24.53285429553818,24.55834283258041,24.58383136962265,24.60931990666489,24.634808443707126,24.660296980749365,24.685785517791597,24.711274054833837,24.73676259187608,24.762251128918315,24.78773966596055,24.813228203002787,24.838716740045022,24.864205277087258,24.8896938141295,24.915182351171737,24.940670888213972,24.96615942525621,24.99164796229845,25.017136499340687,25.042625036382923,25.06811357342516,25.093602110467394,25.119090647509637,25.144579184551873,25.17006772159411,25.195556258636344,25.221044795678587,25.246533332720816,25.27038519092691,25.2934187108509,25.316452230774896,25.339485750698884,25.362519270622883,25.385552790546875,25.408586310470866,25.43161983039486,25.454653350318853,25.477686870242845,25.500720390166844,25.523753910090832,25.546787430014827,25.56982094993882,25.592854469862814,25.61588798978681,25.6389215097108,25.661955029634793,25.68498854955879,25.708022069482777,25.73383851504,25.76104642341382,25.78825433178765,25.815462240161477,25.8426701485353,25.86987805690913,25.897085965282958,25.924293873656783,25.95150178203061,25.978709690404436,26.005917598778264,26.033125507152093,26.060333415525918,26.087541323899746,26.11474923227357,26.1419571406474,26.169165049021224,26.196372957395052,26.223580865768877,26.250788774142702,26.277996682516527,26.305204590890355,26.33241249926418,26.35962040763801,26.386828316011837,26.41403622438566,26.441244132759493,26.468452041133315,26.497095075512135,26.526124489029748,26.555153902547353,26.584183316064966,26.613212729582575,26.642242143100184,26.671271556617796,26.700300970135405,26.729330383653014,26.75835979717062,26.787389210688232,26.816418624205845,26.84544803772345,26.874477451241063,26.903506864758675,26.93253627827628,26.961565691793897,26.990595105311503,27.01962451882911,27.048653932346724,27.077683345864333,27.106712759381946,27.135742172899555,27.16477158641716,27.193800999934776,27.22283041345238,27.251859826969994,27.280889240487603,27.30991865400521,27.338948067522825,27.367977481040434,27.397006894558046,27.426036308075652,27.455065721593265,27.484095135110874,27.513124548628483,27.542153962146095,27.5711833756637,27.600212789181313,27.629242202698922,27.65827161621653,27.687301029734144,27.71633044325175,27.745359856769362,27.774389270286974,27.803418683804583,27.83244809732219,27.861477510839798,27.89050692435741,27.919536337875023,27.94856575139263,27.97759516491024,28.00662457842785,28.03565399194546,28.06468340546307,28.097468118624832,28.134008131430743,28.170548144236648,28.20708815704256,28.24362816984847,28.28016818265438,28.316708195460286,28.353248208266198,28.389788221072106,28.426328233878014,28.462868246683925,28.499408259489837,28.535948272295744,28.572488285101652,28.609028297907564,28.64556831071347,28.68210832351938,28.71864833632529,28.7551883491312,28.79172836193711,28.82826837474302,28.864808387548926,28.901348400354838,28.937888413160746,28.974428425966657,29.010968438772565,29.047508451578473,29.084048464384388,29.120588477190296,29.157128489996204,29.19366850280211,29.230208515608027,29.26674852841393,29.303288541219843,29.33982855402575,29.37636856683166,29.412908579637573,29.44944859244348,29.48598860524939,29.5225286180553,29.55906863086121,29.595608643667116,29.63214865647302,29.668688669278936,29.705228682084847,29.74176869489075,29.778308707696663,29.814848720502578,29.851388733308486,29.887928746114394,29.924468758920302,29.961008771726213,29.99754878453212,30.034088797338033,30.070628810143944,30.108706872007744,30.14691310561153,30.185119339215312,30.223325572819096,30.261531806422877,30.299738040026657,30.337944273630445,30.37615050723422,30.414356740838002,30.45256297444179,30.49076920804557,30.52897544164935,30.56718167525314,30.605387908856915,30.643594142460703,30.681800376064487,30.720006609668268,30.758212843272048,30.796419076875832,30.834625310479616,30.872831544083397,30.911037777687177,30.949244011290965,30.98745024489474,31.025656478498526,31.06386271210231,31.102068945706094,31.140275179309878,31.145092544884623,31.083132174401328,31.02117180391803,30.95921143343473,30.897251062951433,30.83529069246814,30.77333032198484,30.711369951501542,30.64940958101825,30.58744921053495,30.52548884005165,30.463528469568352,30.40156809908506,30.339607728601763,30.27764735811846,30.215686987635166,30.153726617151868,30.091766246668573,30.02980587618528,29.96784550570198,29.905885135218675,29.843924764735384,29.78196439425209,29.720004023768787,29.658043653285493,29.596083282802198,29.5341229123189,29.4721625418356,29.410202171352307,29.34824180086901,29.286281430385706,29.224321059902415,29.162360689419113,29.100400318935815,29.03843994845252,28.97647957796923,28.914519207485927,28.852558837002633,28.790598466519338,28.728638096036036,28.666677725552738,28.605230608557484,28.55712778729348,28.509024966029468,28.460922144765462,28.41281932350146,28.364716502237453,28.316613680973443,28.26851085970944,28.220408038445434,28.172305217181428,28.124202395917422,28.076099574653412,28.027996753389402,27.9798939321254,27.931791110861393,27.88368828959738,27.835585468333377,27.787482647069375,27.739379825805365,27.69127700454136,27.643174183277353,27.595071362013343,27.54696854074934,27.498865719485334,27.450762898221324,27.402660076957314,27.354557255693315,27.306454434429305,27.258351613165296,27.21024879190129,27.162145970637283,27.114043149373277,27.06594032810927,27.017837506845268,26.96973468558126,26.92163186431725,26.873529043053246,26.82542622178924,26.777323400525233,26.729220579261224,26.681117757997217,26.63301493673321,26.54760116045299,26.27563260909168,26.00366405773037,25.73169550636906,25.459726955007795,25.187758403646487,24.915789852285172,24.643821300923914,24.371852749562606,24.09988419820129,23.82791564684003,23.555947095478718,23.28397854411741,23.012009992756095,22.740041441394833,22.468072890033522,22.196104338672214,21.924135787310956,21.652167235949644,21.380198684588333,21.10823013322707,20.836261581865756,20.573656911732236,20.33801731928002,20.10237772682777,19.866738134375513,19.63109854192326,19.395458949471053,19.159819357018797,18.924179764566542,18.68854017211433,18.452900579662078,18.217260987209823,17.981621394757614,17.74598180230536,17.510342209853107,17.274702617400852,17.039063024948643,16.803423432496388,16.567783840044136,16.332144247591923,16.096504655139668,15.860865062687415,15.625225470235202,15.389585877782949,15.153946285330697,14.918306692878485,14.682667100426233,14.447027507973978,14.211387915521724,13.975748323069514,13.74010873061726,13.504469138165005,13.268829545712796,13.03318995326054,12.797550360808287,12.561910768356077,12.326271175903823,12.090631583451568,11.854991990999315,11.619352398547104,11.383712806094849,11.18557979247745,10.991205460955603,10.796831129433716,10.602456797911833,10.408082466389985,10.213708134868101,10.019333803346216,9.824959471824368,9.630585140302482,9.436210808780599,9.241836477258712,9.047462145736866,8.85308781421498,8.658713482693095,8.464339151171247,8.269964819649363,8.075590488127478,7.88121615660563,7.686841825083745,7.492467493561861,7.298093162039976,7.103718830518128],[21.977120135991967,22.00333334511866,22.02954655424535,22.05575976337204,22.081972972498733,22.108186181625424,22.134399390752115,22.160612599878807,22.1868258090055,22.213039018132193,22.239252227258884,22.265465436385576,22.291678645512263,22.317891854638958,22.34410506376565,22.37031827289234,22.396531482019036,22.422744691145724,22.448957900272415,22.475171109399106,22.5013843185258,22.527597527652492,22.553810736779184,22.580023945905875,22.606237155032566,22.632450364159258,22.65866357328595,22.684876782412644,22.711089991539335,22.737303200666027,22.763516409792715,22.78972961891941,22.8159428280461,22.842156037172792,22.868369246299483,22.894582455426175,22.920795664552866,22.947008873679557,22.973222082806252,22.99943529193294,23.025648501059635,23.051861710186323,23.078074919313018,23.104288128439705,23.1305013375664,23.15671454669309,23.182927755819783,23.209140964946478,23.235354174073166,23.261567383199857,23.28778059232655,23.313993801453236,23.34020701057993,23.366420219706626,23.392633428833314,23.41884663796001,23.445059847086696,23.47127305621339,23.49748626534008,23.523699474466774,23.54991268359347,23.576125892720157,23.60233910184685,23.628552310973543,23.65476552010023,23.680978729226926,23.707191938353613,23.733405147480305,23.759618356607,23.785831565733687,23.812044774860382,23.838257983987074,23.864471193113765,23.890684402240456,23.916897611367148,23.943110820493843,23.96932402962053,23.99553723874722,24.021750447873913,24.047963657000608,24.073379753952008,24.097201627582145,24.121023501212285,24.144845374842422,24.17005613464931,24.195544671691547,24.221033208733786,24.246521745776025,24.272010282818258,24.297498819860497,24.322987356902736,24.348475893944972,24.373964430987208,24.399452968029447,24.424941505071683,24.45043004211392,24.475918579156154,24.501407116198394,24.526895653240633,24.55238419028287,24.577872727325108,24.603361264367347,24.628849801409583,24.65433833845182,24.679826875494054,24.705315412536294,24.730803949578533,24.75629248662077,24.781781023663005,24.80726956070524,24.83275809774748,24.85824663478972,24.883735171831955,24.909223708874194,24.93471224591643,24.96020078295867,24.9856893200009,25.011177857043137,25.036666394085376,25.062154931127615,25.08764346816985,25.113132005212087,25.138620542254323,25.164109079296562,25.1895976163388,25.21508615338104,25.240574690423276,25.266063227465512,25.291551764507748,25.31704030154999,25.342528838592226,25.368017375634462,25.393505912676698,25.418994449718937,25.444482986761173,25.469971523803412,25.495460060845648,25.520948597887884,25.546437134930123,25.571925671972362,25.597414209014598,25.622902746056834,25.648391283099073,25.67387982014131,25.69936835718355,25.724856894225784,25.75034543126802,25.77583396831026,25.8013225053525,25.826811042394734,25.85229957943697,25.87778811647921,25.903276653521445,25.92876519056368,25.95425372760592,25.979742264648156,26.00523080169039,26.03071933873263,26.05620787577487,26.081696412817106,26.10718494985934,26.13267348690158,26.158162023943817,26.183241391114105,26.206274911038097,26.229308430962092,26.25234195088608,26.278158396443303,26.305366304817127,26.332574213190952,26.359782121564784,26.3869900299386,26.415633063479536,26.44466247699714,26.473691890514754,26.502721304032363,26.531750717549972,26.56078013106758,26.589809544585194,26.6188389581028,26.647868371620408,26.676897785138024,26.70592719865563,26.73495661217324,26.76398602569085,26.79301543920846,26.822044852726073,26.851074266243685,26.88010367976129,26.909133093278896,26.938162506796512,26.96719192031412,26.996221333831727,27.025250747349343,27.05428016086695,27.08330957438456,27.11233898790217,27.14136840141978,27.170397814937388,27.199427228455,27.22845664197261,27.25748605549022,27.286515469007828,27.31554488252544,27.34457429604305,27.37360370956066,27.40263312307827,27.431662536595876,27.46069195011349,27.4897213636311,27.51875077714871,27.547780190666323,27.57680960418393,27.605839017701534,27.634868431219147,27.66389784473676,27.69292725825437,27.721956671771977,27.750986085289586,27.7800154988072,27.809044912324808,27.83807432584242,27.867103739360026,27.896133152877635,27.92516256639525,27.954191979912856,27.98322139343047,28.01225080694808,28.041280220465683,28.070309633983296,28.099339047500905,28.128368461018518,28.157397874536127,28.186427288053736,28.215456701571348,28.244486115088957,28.27351552860657,28.30254494212418,28.331574355641784,28.360603769159397,28.389633182677006,28.418662596194615,28.447692009712227,28.476721423229836,28.505750836747445,28.534780250265054,28.563809663782664,28.592839077300276,28.621868490817885,28.650897904335498,28.683682617497254,28.720222630303166,28.756762643109074,28.793302655914985,28.829842668720893,28.866382681526805,28.902922694332712,28.93946270713862,28.976002719944532,29.01254273275044,29.04908274555635,29.08562275836226,29.12216277116817,29.15870278397408,29.195242796779986,29.231782809585894,29.268322822391806,29.304862835197714,29.341402848003625,29.377942860809533,29.414482873615444,29.451022886421356,29.487562899227264,29.52410291203317,29.560642924839083,29.597375193467933,29.635581427071717,29.6737876606755,29.71199389427928,29.750200127883062,29.78840636148685,29.82661259509063,29.86481882869441,29.90302506229819,29.941231295901982,29.979437529505763,30.01764376310954,30.055849996713327,30.094056230317108,30.132262463920892,30.170468697524672,30.208674931128456,30.246881164732237,30.285087398336024,30.323293631939805,30.361499865543585,30.39970609914737,30.437912332751154,30.476118566354934,30.514324799958715,30.552531033562502,30.590737267166286,30.628943500770063,30.667149734373844,30.705355967977635,30.743562201581412,30.781768435185192,30.819974668788984,30.85818090239276,30.89638713599654,30.93459336960033,30.97279960320411,31.011005836807886,31.049212070411677,31.087418304015454,31.125624537619238,31.163830771223022,31.202037004826806,31.240243238430583,31.278449472034367,31.316655705638155,31.354861939241935,31.393068172845716,31.431274406449504,31.46948064005328,31.507686873657065,31.545893107260852,31.58409934086463,31.622305574468413,31.660511808072194,31.69871804167598,31.736924275279762,31.775130508883542,31.779947874458287,31.717987503974996,31.656027133491698,31.5940667630084,31.532106392525105,31.47014602204181,31.40818565155851,31.346225281075206,31.28426491059192,31.22230454010862,31.16034416962532,31.09838379914202,31.03642342865873,30.974463058175427,30.912502687692136,30.850542317208834,30.788581946725536,30.72662157624224,30.664661205758946,30.602700835275648,30.540740464792343,30.47878009430905,30.416819723825757,30.354859353342455,30.292898982859157,30.230938612375866,30.168978241892564,30.107017871409273,30.04505750092597,29.983097130442676,29.92113675995937,29.859176389476083,29.797216018992785,29.735255648509483,29.67329527802619,29.61133490754289,29.549374537059595,29.487414166576297,29.425453796093002,29.3634934256097,29.301533055126406,29.23957268464311,29.17761231415981,29.11565194367651,29.053691573193213,28.991731202709918,28.929770832226616,28.867810461743325,28.80585009126003,28.74388972077673,28.681929350293437,28.619968979810135,28.558008609326837,28.496048238843535,28.434087868360244,28.372127497876946,28.310167127393647,28.248206756910353,28.186246386427054,28.124286015943756,28.06232564546046,28.000365274977167,27.938404904493865,27.87644453401057,27.814484163527275,27.752523793043974,27.690563422560675,27.628603052077388,27.566642681594086,27.504682311110784,27.44272194062749,27.380761570144195,27.318801199660896,27.256840829177598,27.194880458694303,27.132920088211005,27.070959717727703,27.008999347244416,26.94703897676111,26.885078606277812,26.823118235794517,26.761157865311223,26.699197494827924,26.596265544436243,26.353214478911312,26.117574886459057,25.881935294006805,25.646295701554592,25.41065610910234,25.17501651665009,24.939376924197873,24.703737331745625,24.46809773929337,24.232458146841157,23.996818554388902,23.76117896193665,23.525539369484395,23.289899777032183,23.054260184579928,22.818620592127676,22.582980999675467,22.34734140722321,22.111701814770957,21.876062222318748,21.640422629866492,21.40478303741424,21.169143444962028,20.933503852509773,20.69786426005752,20.46222466760527,20.22658507515306,19.990945482700806,19.75530589024855,19.51966629779634,19.284026705344086,19.04838711289183,18.812747520439622,18.577107927987367,18.34146833553511,18.10582874308286,17.87018915063065,17.634549558178396,17.39890996572614,17.16327037327393,16.92763078082168,16.69199118836942,16.456351595917212,16.220712003464957,15.985072411012705,15.749432818560493,15.51379322610824,15.278153633655986,15.04251404120373,14.806874448751522,14.571234856299267,14.335595263847011,14.099955671394802,13.864316078942547,13.628676486490296,13.393036894038083,13.157397301585831,12.921757709133576,12.686118116681321,12.450478524229112,12.214838931776857,11.979199339324603,11.743559746872393,11.507920154420137,11.272280561967886,11.036640969515673,10.801001377063422,10.565361784611166,10.329722192158957,10.094082599706702,9.858443007254447,9.622803414802194,9.387163822349983,9.15152422989773,8.915884637445476,8.680245044993265,8.44460545254101,8.208965860088757,7.973326267636547,7.737686675184293,7.502047082732039,7.266407490279785,7.045342719295057],[22.43633495345867,22.464918756944183,22.4935025604297,22.522086363915218,22.55067016740073,22.579253970886246,22.60783777437176,22.636421577857273,22.66500538134279,22.69358918482831,22.722172988313822,22.750756791799336,22.77934059528485,22.807924398770364,22.834137607948076,22.86035081707477,22.886564026201462,22.91277723532815,22.938990444454845,22.965203653581536,22.991416862708228,23.01763007183492,23.04384328096161,23.0700564900883,23.096269699214993,23.122482908341684,23.148696117468376,23.174909326595067,23.20112253572176,23.227335744848453,23.253548953975145,23.279762163101836,23.305975372228524,23.33218858135522,23.35840179048191,23.3846149996086,23.410828208735293,23.437041417861984,23.463254626988675,23.489467836115367,23.515681045242058,23.54189425436875,23.568107463495444,23.594320672622136,23.620533881748823,23.646747090875515,23.67296030000221,23.699173509128897,23.725386718255592,23.751599927382287,23.777813136508975,23.80402634563567,23.830239554762358,23.856452763889045,23.88266597301574,23.90887918214243,23.935092391269126,23.961305600395818,23.987518809522506,24.0137320186492,24.03994522777589,24.066158436902583,24.092371646029275,24.118584855155966,24.144798064282657,24.17101127340935,24.19722448253604,24.22343769166273,24.249650900789426,24.275864109916114,24.302077319042805,24.3282905281695,24.35450373729619,24.380716946422883,24.406930155549574,24.43314336467627,24.459356573802957,24.485569782929648,24.511782992056343,24.537996201183034,24.564209410309726,24.590422619436413,24.61663582856311,24.6428490376898,24.668458353412777,24.693946890455017,24.719435427497253,24.744923964539492,24.770412501581724,24.795901038623963,24.821389575666203,24.846878112708435,24.872366649750674,24.897855186792917,24.923343723835146,24.94883226087739,24.974320797919624,24.99980933496186,25.025297872004103,25.05078640904634,25.076274946088574,25.10176348313081,25.12725202017305,25.15274055721529,25.178229094257524,25.20371763129976,25.229206168341996,25.25469470538423,25.280183242426475,25.30567177946871,25.331160316510946,25.35664885355318,25.38213739059542,25.40762592763766,25.433114464679896,25.458603001722132,25.484091538764375,25.50958007580661,25.53506861284884,25.560557149891082,25.586045686933318,25.61153422397556,25.637022761017796,25.662511298060032,25.687999835102268,25.713488372144504,25.738976909186743,25.76446544622898,25.789953983271218,25.815442520313454,25.84093105735569,25.86641959439793,25.891908131440168,25.917396668482404,25.94288520552464,25.96837374256688,25.993862279609118,26.01935081665135,26.04483935369359,26.07032789073583,26.09581642777806,26.1213049648203,26.14679350186254,26.172282038904775,26.197770575947015,26.22325911298925,26.248747650031486,26.274236187073726,26.29972472411596,26.3252132611582,26.350701798200436,26.376190335242672,26.40167887228491,26.427167409327147,26.454209074780223,26.482027304363502,26.509845533946788,26.53766376353007,26.565481993113345,26.59330022269663,26.62111845227991,26.648936681863194,26.67675491144648,26.70457314102976,26.73239137061304,26.76020960019632,26.7880278297796,26.816921388090872,26.84635261076612,26.875783833441375,26.90521505611663,26.934646278791885,26.964077501467138,26.993508724142394,27.022939946817644,27.0523711694929,27.081802392168157,27.111233614843407,27.140664837518663,27.170096060193917,27.19952728286917,27.228958505544423,27.258389728219676,27.287820950894933,27.317252173570186,27.34668339624544,27.376114618920692,27.405545841595945,27.434977064271198,27.464408286946455,27.493839509621708,27.52327073229696,27.552701954972218,27.582133177647467,27.611564400322724,27.640995622997977,27.67042684567323,27.699858068348483,27.72928929102374,27.75872051369899,27.788151736374246,27.817582959049496,27.84701418172475,27.87644540440001,27.90587662707526,27.935307849750515,27.964739072425772,27.994170295101025,28.023601517776278,28.053032740451528,28.082463963126784,28.11189518580204,28.141326408477287,28.170757631152547,28.200188853827797,28.229620076503053,28.25905129917831,28.28848252185356,28.317913744528816,28.34734496720407,28.376776189879322,28.40620741255458,28.435638635229832,28.465069857905082,28.49450108058034,28.523932303255595,28.55336352593085,28.582794748606098,28.612225971281354,28.641657193956608,28.671088416631864,28.700519639307117,28.729950861982367,28.759382084657624,28.78881330733288,28.81824453000813,28.847675752683383,28.87710697535864,28.906538198033893,28.935969420709146,28.965400643384402,28.994831866059656,29.024263088734905,29.05369431141016,29.083125534085415,29.11255675676067,29.141987979435925,29.171419202111178,29.202943101394297,29.234520658997486,29.27031193833637,29.310316939410942,29.350321940485514,29.390301855044367,29.428525702947628,29.466749550850885,29.504973398754146,29.543197246657403,29.581421094560667,29.61964494246392,29.657868790367182,29.696092638270443,29.734316486173697,29.772540334076954,29.81076418198021,29.848988029883472,29.887211877786733,29.925435725689987,29.963659573593247,30.001883421496505,30.040107269399762,30.078331117303023,30.116554965206277,30.15477881310954,30.193002661012798,30.23122650891606,30.269450356819313,30.307674204722574,30.345898052625834,30.384121900529088,30.42234574843235,30.46056959633561,30.498793444238864,30.537017292142124,30.575241140045385,30.613464987948642,30.6516888358519,30.68991268375516,30.72813653165842,30.76636037956167,30.80458422746493,30.842808075368193,30.88103192327145,30.919255771174708,30.95747961907797,30.995703466981222,31.033927314884487,31.072151162787748,31.110375010691,31.14859885859426,31.186822706497516,31.225046554400777,31.26327040230403,31.30149425020729,31.339718098110556,31.37794194601381,31.416165793917074,31.454389641820327,31.49261348972358,31.530837337626842,31.569061185530103,31.60728503343336,31.645508881336617,31.68373272923988,31.72195657714314,31.760180425046393,31.798404272949654,31.836628120852914,31.874851968756168,31.913075816659425,31.95129966456269,31.989523512465944,32.027747360369204,32.06597120827246,32.104195056175726,32.14241890407898,32.18064275198224,32.218866599885494,32.25709044778875,32.29531429569201,32.33353814359527,32.37176199149853,32.409985838457224,32.412842498112944,32.34292374076297,32.27300498341299,32.20308622606301,32.133167468713026,32.06324871136305,31.993329954013063,31.923411196663082,31.85349243931311,31.78357368196313,31.713654924613145,31.643736167263167,31.57381740991319,31.503898652563205,31.433979895213227,31.36406113786325,31.294142380513264,31.224223623163287,31.154304865813316,31.08438610846333,31.014467351113346,30.944548593763372,30.87462983641339,30.80471107906341,30.73479232171343,30.664873564363454,30.59495480701347,30.525036049663495,30.455117292313517,30.385198534963532,30.31527977761355,30.24536102026358,30.17544226291359,30.10552350556361,30.035604748213633,29.965685990863655,29.895767233513673,29.8258484761637,29.755929718813718,29.686010961463737,29.61609220411376,29.54617344676378,29.4762546894138,29.40633593206381,29.336417174713837,29.266498417363856,29.196579660013875,29.126660902663897,29.056742145313923,28.986823387963938,28.91690463061396,28.846985873263982,28.777067115914,28.70714835856402,28.637229601214045,28.567310843864064,28.49739208651408,28.427473329164105,28.357554571814127,28.28763581446414,28.21771705711416,28.147798299764187,28.077879542414202,28.00796078506422,27.938042027714246,27.868123270364265,27.798204513014284,27.72828575566431,27.658366998314328,27.588448240964343,27.518529483614365,27.448610726264384,27.378691968914403,27.308773211564425,27.23885445421445,27.168935696864466,27.099016939514485,27.02909818216451,26.959179424814526,26.88926066746454,26.819341910114566,26.749423152764592,26.679504395414604,26.574554007464783,26.29444546651568,26.014336925566578,25.734228384617474,25.454119843668423,25.17401130271932,24.89390276177022,24.613794220821166,24.333685679872065,24.05357713892296,23.773468597973913,23.49336005702481,23.213251516075708,22.933142975126604,22.65303443417755,22.372925893228448,22.092817352279347,21.812708811330296,21.532600270381195,21.25249172943209,20.972383188483043,20.69227464753394,20.412166106584834,20.132057565635783,19.851949024686682,19.57184048373758,19.29173194278848,19.011623401839422,18.73151486089032,18.45140631994122,18.17129777899217,17.89118923804307,17.611080697093964,17.330972156144913,17.050863615195812,16.770755074246708,16.490646533297607,16.210537992348556,15.930429451399451,15.664740661563593,15.427891370385371,15.1910420792071,14.954192788028832,14.717343496850608,14.48049420567234,14.281090094289741,14.089175020349131,13.897259946408484,13.70534487246784,13.513429798527195,13.321514724586585,13.129599650645941,12.937684576705298,12.745769502764688,12.553854428824042,12.361939354883399,12.170024280942789,11.978109207002143,11.786194133061498,11.594279059120854,11.402363985180244,11.210448911239599,11.018533837298957,10.826618763358347,10.634703689417702,10.442788615477056,10.250873541536446,10.0589584675958,9.867043393655157,9.675128319714549,9.483213245773904,9.291298171833258,9.099383097892613,8.907468023952003,8.715552950011359,8.523637876070714,8.331722802130104,8.13980772818946,7.947892654248815,7.755977580308205,7.564062506367561,7.372147432426916,7.180232358486271,6.988317284545662],[22.894165858757475,22.92274966224299,22.951333465728506,22.97991726921402,23.008501072699538,23.037084876185048,23.065668679670566,23.09425248315608,23.122836286641594,23.15142009012711,23.180003893612625,23.208587697098142,23.237171500583656,23.26575530406917,23.294339107554688,23.3229229110402,23.351506714525716,23.38009051801123,23.408674321496747,23.43725812498226,23.46584192846778,23.49442573195329,23.523009535438806,23.55159333892432,23.580177142409838,23.60876094589535,23.637344749380865,23.665928552866383,23.694512356351893,23.72309615983741,23.75049466658568,23.776707875712372,23.802921084839063,23.829134293965758,23.855347503092446,23.88156071221914,23.90777392134583,23.933987130472524,23.96020033959921,23.986413548725906,24.012626757852594,24.03883996697929,24.06505317610598,24.09126638523267,24.11747959435936,24.143692803486054,24.16990601261275,24.196119221739437,24.222332430866125,24.248545639992823,24.27475884911951,24.300972058246206,24.327185267372897,24.353398476499585,24.37961168562628,24.405824894752968,24.432038103879663,24.45825131300635,24.484464522133045,24.51067773125974,24.536890940386428,24.563104149513123,24.58931735863981,24.615530567766502,24.641743776893193,24.667956986019888,24.694170195146576,24.72038340427327,24.746596613399962,24.772809822526654,24.79902303165335,24.825236240780036,24.85144944990673,24.87766265903342,24.903875868160114,24.9300890772868,24.956302286413496,24.982515495540188,25.00872870466688,25.034941913793567,25.061155122920262,25.087368332046953,25.113581541173644,25.13979475030034,25.165404066023314,25.190892603065553,25.21638114010779,25.241869677150028,25.267358214192264,25.2928467512345,25.318335288276735,25.343823825318978,25.369312362361214,25.39480089940345,25.420289436445685,25.445777973487928,25.47126651053016,25.496755047572403,25.522243584614635,25.54773212165687,25.573220658699114,25.59870919574135,25.624197732783585,25.64968626982583,25.675174806868064,25.7006633439103,25.726151880952536,25.75164041799477,25.777128955037014,25.80261749207925,25.828106029121486,25.85359456616372,25.879083103205957,25.9045716402482,25.930060177290436,25.95554871433267,25.98103725137491,26.006525788417147,26.03201432545938,26.05750286250162,26.082991399543854,26.108479936586097,26.133968473628332,26.159457010670568,26.184945547712807,26.210434084755043,26.23592262179728,26.261411158839515,26.286899695881758,26.312388232923993,26.33787676996623,26.363365307008465,26.388853844050708,26.414342381092943,26.43983091813518,26.465319455177415,26.49080799221965,26.5166848117866,26.544503041369886,26.572321270953164,26.600139500536446,26.627957730119732,26.65577595970301,26.683594189286293,26.711412418869575,26.739230648452857,26.76704887803614,26.79486710761942,26.822685337202703,26.85050356678599,26.87832179636927,26.90614002595255,26.933958255535835,26.961776485119113,26.9895947147024,27.017412944285677,27.04523117386896,27.073049403452245,27.100867633035524,27.128685862618806,27.15650409220209,27.184322321785373,27.212140551368655,27.239958780951934,27.267777010535216,27.295595240118498,27.32341346970178,27.352307028013044,27.381738250688297,27.41116947336355,27.440600696038807,27.47003191871406,27.499463141389313,27.52889436406457,27.558325586739823,27.587756809415076,27.61718803209033,27.646619254765586,27.67605047744084,27.705481700116092,27.73491292279135,27.764344145466602,27.79377536814185,27.823206590817108,27.852637813492365,27.882069036167614,27.911500258842867,27.940931481518124,27.970362704193377,27.99979392686863,28.029225149543883,28.058656372219133,28.08808759489439,28.117518817569646,28.146950040244896,28.176381262920156,28.20581248559541,28.235243708270666,28.264674930945915,28.294106153621172,28.32353737629642,28.352968598971675,28.382399821646928,28.411831044322184,28.441262266997438,28.47069348967269,28.500124712347947,28.529555935023197,28.558987157698454,28.588418380373707,28.61784960304896,28.647280825724213,28.676712048399466,28.706143271074723,28.73557449374998,28.76500571642523,28.794436939100486,28.823868161775735,28.85329938445099,28.882730607126245,28.9121618298015,28.941593052476755,28.971024275152004,29.00045549782726,29.029886720502518,29.059317943177767,29.088749165853024,29.118180388528273,29.14761161120353,29.179081852520717,29.210659410123906,29.242236967727102,29.273814525330298,29.305392082933494,29.336969640536687,29.368547198139883,29.400124755743075,29.431702313346268,29.46327987094946,29.494857428552653,29.526434986155845,29.55801254375904,29.589590101362234,29.62116765896543,29.652745216568626,29.684322774171818,29.71590033177501,29.747477889378207,29.7790554469814,29.81063300458459,29.846424283923476,29.88642928499805,29.92643428607262,29.96643928714719,30.00644428822177,30.04644928929634,30.086454290370913,30.126459291445485,30.16646429252006,30.206469293594626,30.246474294669202,30.286479295743774,30.32648429681835,30.366489297892922,30.406494298967495,30.446499300042067,30.48650430111664,30.52650930219121,30.56651430326578,30.606519304340356,30.64652430541493,30.686529306489504,30.726534307564073,30.766539308638645,30.806544309713225,30.846549310787797,30.886554311862366,30.92655931293694,30.966564314011514,31.006569315086082,31.046060040829204,31.084283888732458,31.12250773663571,31.160731584538976,31.198955432442233,31.237179280345494,31.27540312824875,31.313626976152012,31.35185082405527,31.390074671958526,31.42829851986179,31.46652236776504,31.5047462156683,31.542970063571563,31.58119391147482,31.619417759378074,31.657641607281334,31.695865455184595,31.734089303087853,31.772313150991117,31.81053699889437,31.848760846797624,31.886984694700878,31.925208542604146,31.963432390507403,32.00165623841066,32.03988008631392,32.07810393421718,32.116327782120436,32.1545516300237,32.19277547792696,32.23099932583021,32.26922317373347,32.30744702163673,32.34567086953999,32.38389471744324,32.42211856534651,32.46034241324976,32.498566261153016,32.536790109056284,32.575013956959545,32.6132378048628,32.65146165276605,32.68968550066932,32.727909348572574,32.76613319647583,32.80435704437909,32.84258089228235,32.8808047401856,32.919028588088864,32.95725243599213,32.995476283895385,33.03370013179864,33.0311144097849,32.94690954793719,32.86270468608948,32.77849982424176,32.69429496239405,32.610090100546344,32.52588523869862,32.44168037685091,32.35747551500321,32.27327065315549,32.189065791307776,32.10486092946006,32.02065606761236,31.93645120576464,31.85224634391693,31.768041482069222,31.6838366202215,31.599631758373793,31.515426896526083,31.431222034678367,31.34701717283065,31.26281231098294,31.178607449135228,31.09440258728751,31.010197725439806,30.925992863592096,30.841788001744384,30.757583139896667,30.673378278048958,30.589173416201245,30.504968554353532,30.420763692505826,30.336558830658113,30.252353968810393,30.16814910696268,30.083944245114974,29.999739383267258,29.91553452141955,29.831329659571843,29.74712479772412,29.66291993587641,29.578715074028704,29.494510212180987,29.41030535033327,29.326100488485558,29.2447868803924,29.174868123042415,29.10494936569244,29.035030608342463,28.96511185099248,28.8951930936425,28.825274336292523,28.75535557894254,28.685436821592553,28.615518064242586,28.5455993068926,28.475680549542616,28.405761792192642,28.33584303484266,28.26592427749268,28.196005520142705,28.126086762792724,28.056168005442743,27.98624924809277,27.916330490742787,27.846411733392806,27.776492976042817,27.70657421869285,27.63665546134287,27.56673670399288,27.496817946642903,27.426899189292925,27.356980431942944,27.287061674592966,27.217142917242988,27.147224159893007,27.077305402543022,27.00738664519305,26.93746788784307,26.86754913049308,26.797630373143107,26.72771161579313,26.657792858443145,26.55284247049332,26.27273392954422,25.992625388595116,25.712516847646015,25.432408306696964,25.152299765747863,24.872191224798758,24.59208268384971,24.311974142900603,24.031865601951502,23.75175706100245,23.471648520053346,23.19153997910425,22.911431438155148,22.63132289720609,22.351214356256992,22.071105815307885,21.790997274358837,21.528913431124362,21.292064139946092,21.055214848767868,20.8183655575896,20.58151626641133,20.344666975233107,20.10781768405484,19.870968392876573,19.634119101698303,19.39726981052008,19.160420519341812,18.923571228163542,18.686721936985318,18.449872645807048,18.21302335462878,17.976174063450557,17.73932477227229,17.502475481094024,17.265626189915757,17.02877689873753,16.791927607559263,16.555078316380992,16.31822902520277,16.081379734024498,15.844530442846231,15.607681151668007,15.370831860489739,15.13398256931147,14.897133278133246,14.66028398695498,14.423434695776713,14.186585404598443,13.949736113420219,13.71288682224195,13.476037531063682,13.239188239885458,13.00233894870719,12.76548965752892,12.528640366350697,12.29179107517243,12.054941783994163,11.818092492815895,11.581243201637669,11.344393910459402,11.107544619281134,10.870695328102908,10.63384603692464,10.396996745746371,10.193848106787053,10.001933032846408,9.810017958905762,9.618102884965154,9.426187811024509,9.234272737083863,9.04235766314322,8.85044258920261,8.658527515261966,8.46661244132132,8.27469736738071,8.082782293440067,7.890867219499422,7.698952145558812,7.507037071618168,7.315121997677522,7.123206923736877,6.931291849796269],[23.351996764056288,23.380580567541802,23.40916437102732,23.437748174512834,23.46633197799835,23.49491578148386,23.52349958496938,23.552083388454893,23.580667191940407,23.609250995425928,23.637834798911438,23.666418602396956,23.69500240588247,23.723586209367983,23.7521700128535,23.78075381633901,23.80933761982453,23.837921423310043,23.86650522679556,23.895089030281074,23.92367283376659,23.952256637252102,23.98084044073762,24.009424244223133,24.038008047708647,24.066591851194165,24.09517565467968,24.123759458165193,24.152343261650707,24.180927065136224,24.209510868621738,24.238094672107255,24.26667847559277,24.295262279078287,24.323846082563797,24.352429886049315,24.38101368953483,24.409597493020343,24.43818129650586,24.466765099991374,24.495348903476888,24.523932706962405,24.55251651044792,24.581100313933433,24.60968411741895,24.638267920904468,24.66685172438998,24.693064934349984,24.71927814347667,24.745491352603374,24.771704561730058,24.797917770856756,24.824130979983444,24.85034418911013,24.87655739823683,24.902770607363514,24.928983816490213,24.955197025616897,24.981410234743592,25.007623443870287,25.033836652996975,25.06004986212367,25.086263071250357,25.112476280377045,25.138689489503744,25.164902698630435,25.191115907757126,25.217329116883818,25.243542326010513,25.2697555351372,25.295968744263895,25.322181953390583,25.348395162517278,25.37460837164397,25.40082158077066,25.427034789897352,25.453247999024043,25.479461208150738,25.505674417277426,25.531887626404117,25.55810083553081,25.584314044657503,25.61052725378419,25.636740462910886,25.66234977863386,25.687838315676103,25.71332685271834,25.738815389760575,25.76430392680281,25.78979246384505,25.815281000887286,25.840769537929525,25.86625807497176,25.891746612014,25.91723514905624,25.942723686098468,25.96821222314071,25.993700760182946,26.01918929722519,26.044677834267425,26.07016637130966,26.095654908351896,26.121143445394132,26.146631982436375,26.17212051947861,26.197609056520847,26.223097593563082,26.248586130605318,26.27407466764756,26.299563204689797,26.325051741732032,26.350540278774268,26.376028815816504,26.401517352858747,26.427005889900983,26.45249442694322,26.477982963985454,26.50347150102769,26.528960038069933,26.554448575112165,26.579937112154404,26.606978778376273,26.634797007959556,26.662615237542838,26.690433467126123,26.7182516967094,26.746069926292684,26.773888155875966,26.801706385459248,26.82952461504253,26.857342844625812,26.885161074209094,26.912979303792376,26.940797533375658,26.96861576295894,26.996433992542222,27.024252222125504,27.052070451708786,27.07988868129207,27.10770691087535,27.135525140458633,27.163343370041915,27.191161599625197,27.21897982920848,27.24679805879176,27.274616288375043,27.302434517958325,27.330252747541607,27.35807097712489,27.385889206708175,27.413707436291457,27.441525665874735,27.469343895458017,27.4971621250413,27.524980354624585,27.552798584207867,27.580616813791146,27.608435043374428,27.636253272957706,27.664071502540992,27.691889732124274,27.719707961707556,27.747526191290838,27.77534442087412,27.803162650457406,27.830980880040684,27.858799109623966,27.887692667935234,27.917123890610483,27.94655511328574,27.975986335960997,28.005417558636246,28.034848781311503,28.064280003986756,28.09371122666201,28.123142449337266,28.152573672012515,28.182004894687772,28.211436117363025,28.240867340038278,28.270298562713535,28.299729785388784,28.32916100806404,28.358592230739294,28.388023453414547,28.417454676089804,28.446885898765057,28.476317121440307,28.50574834411556,28.535179566790816,28.56461078946607,28.594042012141326,28.62347323481658,28.652904457491836,28.68233568016709,28.711766902842342,28.74119812551759,28.770629348192845,28.8000605708681,28.829491793543355,28.85892301621861,28.888354238893864,28.917785461569117,28.94721668424437,28.976647906919624,29.00607912959488,29.03551035227013,29.064941574945383,29.094372797620636,29.123804020295893,29.155220603647148,29.186798161250344,29.218375718853533,29.24995327645673,29.281530834059925,29.313108391663118,29.344685949266314,29.376263506869506,29.4078410644727,29.439418622075895,29.470996179679084,29.502573737282283,29.534151294885476,29.565728852488668,29.597306410091868,29.628883967695057,29.660461525298253,29.692039082901445,29.723616640504634,29.755194198107834,29.786771755711023,29.818349313314222,29.849926870917415,29.881504428520607,29.9130819861238,29.944659543726992,29.976237101330188,30.007814658933384,30.039392216536573,30.07096977413977,30.10254733174296,30.134124889346154,30.165702446949354,30.197280004552546,30.22885756215574,30.26043511975893,30.292012677362123,30.32359023496532,30.355167792568515,30.386745350171708,30.42253662951059,30.462541630585164,30.502546631659733,30.54255163273431,30.582556633808885,30.622561634883454,30.662566635958022,30.702571637032598,30.742576638107177,30.782581639181743,30.82258664025632,30.86259164133089,30.902596642405463,30.94260164348004,30.98260664455461,31.02261164562918,31.062616646703752,31.102621647778328,31.142626648852897,31.182631649927472,31.22263665100205,31.262641652076624,31.302646653151186,31.34265165422576,31.382656655300337,31.422661656374906,31.462666657449482,31.50267165852405,31.542676659598627,31.582681660673195,31.622686661747775,31.662691662822347,31.70269666389692,31.74270166497149,31.782706666046064,31.82271166712064,31.86271666819521,31.90272166926978,31.942726670344353,31.98273167141893,32.022736672493494,32.06274167356807,32.102746674642646,32.14275167571722,32.1827566767918,32.222761677866366,32.262766678940935,32.30277168001551,32.342776681090086,32.382781682164655,32.422786683239224,32.4627916843138,32.50279668538837,32.542801686462944,32.58280668753752,32.62281168861209,32.66281668968666,32.701818226614044,32.740042074517305,32.77826592242056,32.81648977032382,32.85471361822707,32.892937466130334,32.931161314033595,32.96938516193685,33.00760900984011,33.04583285774337,33.08405670564663,33.122280553549885,33.160504401453146,33.19872824935641,33.23695209725966,33.27517594516292,33.31339979306618,33.351623640969436,33.38984748887269,33.42807133677596,33.46629518467922,33.504519032582465,33.54274288048573,33.58096672838899,33.619190576292254,33.6574144241955,33.65482870218176,33.57062384033405,33.48641897848634,33.40221411663862,33.318009254790915,33.233804392943206,33.14959953109549,33.06539466924777,32.981189807400064,32.896984945552354,32.81278008370464,32.72857522185693,32.64437036000922,32.5601654981615,32.47596063631379,32.391755774466084,32.30755091261837,32.22334605077066,32.13914118892295,32.05493632707523,31.970731465227512,31.886526603379806,31.802321741532097,31.71811687968438,31.633912017836668,31.549707155988962,31.465502294141242,31.381297432293536,31.297092570445827,31.212887708598107,31.128682846750394,31.04447798490269,30.96027312305497,30.87606826120726,30.79186339935955,30.70765853751184,30.623453675664123,30.539248813816414,30.4550439519687,30.37083909012098,30.28663422827328,30.20242936642557,30.11822450457785,30.034019642730136,29.949814780882427,29.865609919034714,29.781405057187,29.697200195339292,29.61299533349158,29.528790471643863,29.444585609796153,29.36038074794844,29.27617588610073,29.19197102425301,29.10776616240531,29.02356130055759,28.939356438709876,28.855151576862166,28.770946715014453,28.68674185316674,28.602536991319027,28.51833212947132,28.4341272676236,28.349922405775896,28.265717543928183,28.18151268208047,28.09730782023275,28.013102958385055,27.928898096537335,27.844693234689615,27.760488372841905,27.676283510994203,27.585253306623425,27.49136889548116,27.397484484338893,27.303600073196616,27.209715662054343,27.115831250912088,27.02194683976981,26.928062428627538,26.83417801748527,26.74029360634301,26.646409195200732,26.52072273686926,26.23602604259168,25.951329348314097,25.666632654036523,25.381935959758994,25.097239265481413,24.812542571203828,24.527845876926307,24.24314918264873,23.998325314418732,23.76147602324051,23.524626732062238,23.28777744088397,23.050928149705705,22.81407885852748,22.577229567349214,22.34038027617094,22.10353098499272,21.866681693814453,21.629832402636186,21.39298311145796,21.156133820279692,20.91928452910142,20.682435237923194,20.445585946744934,20.208736655566664,19.971887364388394,19.73503807321017,19.498188782031903,19.261339490853636,19.02449019967541,18.78764090849714,18.550791617318872,18.313942326140648,18.07709303496238,17.84024374378411,17.60339445260584,17.366545161427617,17.12969587024935,16.892846579071083,16.65599728789286,16.419147996714592,16.182298705536322,15.945449414358098,15.70860012317983,15.471750832001561,15.234901540823337,14.99805224964507,14.761202958466804,14.524353667288533,14.28750437611031,14.050655084932043,13.813805793753772,13.576956502575548,13.340107211397282,13.103257920219013,12.866408629040787,12.629559337862519,12.392710046684254,12.155860755505985,11.91901146432776,11.682162173149493,11.445312881971223,11.208463590792999,10.97161429961473,10.734765008436463,10.497915717258238,10.26106642607997,10.024217134901704,9.78736784372348,9.55051855254521,9.313669261366941,9.076819970188673,8.83997067901045,8.60312138783218,8.382397789490387,8.193925546888304,8.005453304286188,7.816981061684072,7.628508819081991,7.4400365764798755,7.2515643338777585,7.063092091275643,6.874619848673562],[23.809827669355094,23.838411472840605,23.86699527632612,23.89557907981164,23.92416288329715,23.952746686782667,23.98133049026818,24.0099142937537,24.038498097239213,24.067081900724727,24.095665704210244,24.124249507695755,24.152833311181276,24.181417114666786,24.210000918152303,24.238584721637817,24.26716852512333,24.29575232860885,24.32433613209436,24.35291993557988,24.38150373906539,24.410087542550908,24.438671346036422,24.46725514952194,24.495838953007453,24.524422756492967,24.553006559978485,24.581590363463995,24.610174166949513,24.638757970435027,24.66734177392054,24.695925577406058,24.724509380891575,24.75309318437709,24.781676987862603,24.810260791348117,24.83884459483363,24.86742839831915,24.896012201804663,24.924596005290176,24.953179808775694,24.981763612261208,25.010347415746722,25.03893121923224,25.067515022717753,25.096098826203267,25.124682629688785,25.153266433174302,25.181850236659812,25.210434040145326,25.239017843630847,25.267601647116358,25.296185450601875,25.32476925408739,25.353353057572903,25.38193686105842,25.410520664543935,25.439104468029452,25.467688271514966,25.496272075000476,25.524855878485994,25.553439681971508,25.582023485457025,25.609421992987585,25.63563520211428,25.661848411240975,25.688061620367662,25.714274829494357,25.74048803862105,25.76670124774774,25.79291445687443,25.819127666001123,25.845340875127814,25.871554084254505,25.8977672933812,25.923980502507888,25.950193711634583,25.97640692076127,26.002620129887966,26.028833339014657,26.05504654814135,26.08125975726804,26.10747296639473,26.133686175521422,26.1592954912444,26.18478402828664,26.210272565328875,26.235761102371114,26.26124963941335,26.286738176455586,26.312226713497825,26.337715250540064,26.363203787582297,26.388692324624536,26.41418086166678,26.439669398709007,26.46515793575125,26.490646472793483,26.51613500983573,26.541623546877965,26.567112083920197,26.592600620962436,26.618089158004672,26.64357769504691,26.669454515382654,26.69727274496594,26.72509097454922,26.7529092041325,26.780727433715786,26.808545663299068,26.83636389288235,26.864182122465632,26.892000352048914,26.919818581632196,26.947636811215478,26.975455040798764,27.00327327038204,27.03109149996532,27.058909729548606,27.08672795913189,27.114546188715174,27.142364418298452,27.17018264788173,27.198000877465017,27.2258191070483,27.25363733663158,27.281455566214863,27.309273795798145,27.337092025381427,27.36491025496471,27.392728484547987,27.42054671413127,27.44836494371455,27.476183173297837,27.504001402881123,27.5318196324644,27.55963786204768,27.587456091630965,27.61527432121425,27.64309255079753,27.670910780380808,27.69872900996409,27.726547239547372,27.754365469130654,27.782183698713936,27.81000192829722,27.8378201578805,27.865638387463783,27.893456617047065,27.92127484663035,27.94909307621363,27.97691130579691,28.004729535380196,28.032547764963475,28.06036599454676,28.088184224130043,28.11600245371332,28.143820683296607,28.171638912879885,28.199457142463167,28.22727537204645,28.25509360162973,28.282911831213013,28.310730060796296,28.338548290379578,28.36636651996286,28.39418474954614,28.42307830785741,28.452509530532666,28.481940753207915,28.51137197588317,28.540803198558425,28.57023442123368,28.599665643908935,28.629096866584188,28.658528089259438,28.68795931193469,28.71739053460995,28.7468217572852,28.776252979960454,28.80568420263571,28.83511542531096,28.864546647986216,28.893977870661473,28.923409093336723,28.95284031601198,28.982271538687236,29.01170276136248,29.04113398403774,29.070565206712992,29.09999642938824,29.13135935477357,29.162936912376765,29.194514469979957,29.22609202758315,29.257669585186342,29.289247142789538,29.320824700392734,29.352402257995927,29.38397981559912,29.415557373202315,29.447134930805504,29.478712488408704,29.510290046011896,29.54186760361509,29.573445161218284,29.60502271882148,29.63660027642467,29.668177834027865,29.699755391631058,29.731332949234254,29.762910506837446,29.794488064440635,29.826065622043835,29.857643179647027,29.88922073725022,29.920798294853416,29.952375852456605,29.983953410059797,30.015530967662997,30.04710852526619,30.078686082869385,30.110263640472574,30.141841198075767,30.173418755678966,30.20499631328216,30.23657387088536,30.268151428488547,30.299728986091736,30.331306543694936,30.36288410129813,30.39446165890132,30.42603921650452,30.457616774107713,30.489194331710905,30.5207718893141,30.55234944691729,30.583927004520486,30.61550456212368,30.64708211972687,30.678659677330067,30.710237234933256,30.741814792536456,30.773392350139652,30.804969907742844,30.836547465346037,30.86812502294923,30.89970258055242,30.931280138155618,30.96285769575881,30.998648975097687,31.038653976172267,31.07865897724684,31.118663978321415,31.158668979395987,31.19867398047056,31.238678981545128,31.278683982619704,31.31868898369428,31.35869398476885,31.398698985843424,31.438703986917997,31.47870898799257,31.518713989067138,31.558718990141713,31.598723991216282,31.638728992290854,31.678733993365434,31.718738994440006,31.75874399551457,31.798748996589147,31.838753997663723,31.87875899873829,31.918763999812867,31.958769000887443,31.998774001962015,32.03877900303658,32.07878400411116,32.11878900518573,32.1587940062603,32.19879900733488,32.238804008409446,32.27880900948402,32.3188140105586,32.35881901163317,32.39882401270774,32.43882901378231,32.478834014856886,32.518839015931455,32.558844017006024,32.5988490180806,32.638854019155175,32.678859020229744,32.71886402130432,32.7588690223789,32.798874023453465,32.83887902452804,32.878884025602616,32.918889026677185,32.958894027751754,32.99889902882633,33.038904029900905,33.07890903097548,33.11891403205005,33.15891903312462,33.198924034199194,33.23892903527377,33.278934036348346,33.318939037422915,33.35894403849749,33.39894903957206,33.43895404064663,33.478959041721204,33.51896404279578,33.55896904387035,33.598974044944924,33.63897904601949,33.678984047094076,33.71898904816864,33.75899404924321,33.79899905031779,33.83900405139236,33.879009052466934,33.9190140535415,33.95901905461608,33.99902405569065,34.03902905676522,34.07903405783979,34.11903905891437,34.15904405998894,34.19904906106352,34.23905406213809,34.279394600397076,34.270345625002385,34.16833980283493,34.074455391692666,33.98057098055039,33.886686569408134,33.792802158265864,33.69891774712359,33.60503333598131,33.511148924839055,33.41726451369678,33.32338010255451,33.22949569141224,33.13561128026998,33.0417268691277,32.94784245798543,32.85395804684317,32.76007363570089,32.66618922455863,32.572304813416366,32.47842040227409,32.38453599113182,32.29065157998955,32.19676716884728,32.10288275770501,32.00899834656275,31.91511393542048,31.821229524278206,31.72734511313594,31.633460701993673,31.5395762908514,31.445691879709127,31.351807468566868,31.25792305742459,31.164038646282314,31.070154235140052,30.976269823997786,30.882385412855513,30.78850100171325,30.694616590570984,30.600732179428707,30.50684776828644,30.412963357144182,30.319078946001902,30.225194534859625,30.131310123717363,30.037425712575093,29.943541301432823,29.849656890290557,29.75577247914829,29.661888068006014,29.568003656863752,29.474119245721486,29.380234834579213,29.286350423436936,29.19246601229468,29.098581601152404,29.004697190010134,28.910812778867864,28.816928367725595,28.723043956583325,28.629159545441055,28.535275134298793,28.441390723156516,28.347506312014254,28.253621900871984,28.159737489729714,28.065853078587438,27.971968667445182,27.878084256302905,27.784199845160636,27.690315434018366,27.596431022876104,27.502546611733827,27.408662200591564,27.3147777894493,27.220893378307025,27.12700896716475,27.033124556022493,26.93924014488022,26.845355733737943,26.751471322595677,26.657586911453414,26.563702500311138,26.43801604197966,26.15331934770208,25.868622653424502,25.583925959146924,25.299229264869396,25.01453257059182,24.729835876314237,24.445139182036712,24.160442487759134,23.87574579348155,23.591049099204024,23.306352404926443,23.021655710648865,22.736959016371284,22.45226232209376,22.16756562781618,21.882868933538596,21.598172239261075,21.313475544983493,21.028778850705912,20.744082156428384,20.459385462150806,20.174688767873228,19.8899920735957,19.60529537931812,19.32059868504054,19.035901990762962,18.751205296485434,18.466508602207853,18.181811907930275,17.89711521365275,17.61241851937517,17.32772182509759,17.043025130820062,16.76005902512838,16.52416603817811,16.28827305122783,16.052380064277596,15.816487077327318,15.58059409037704,15.344701103426809,15.10880811647653,14.872915129526254,14.637022142576019,14.40112915562574,14.165236168675465,13.929343181725232,13.693450194774952,13.457557207824676,13.227886129805658,13.039413887203578,12.85094164460146,12.662469401999344,12.473997159397262,12.285524916795147,12.097052674193034,11.90858043159095,11.720108188988833,11.531635946386718,11.343163703784601,11.154691461182521,10.966219218580404,10.777746975978287,10.589274733376206,10.40080249077409,10.212330248171973,10.023858005569894,9.835385762967778,9.646913520365661,9.45844127776358,9.269969035161463,9.081496792559346,8.89302454995723,8.70455230735515,8.516080064753034,8.327607822150918,8.139135579548837,7.95066333694672,7.762191094344605,7.573718851742523,7.385246609140407,7.196774366538291,7.008302123936174,6.819829881334092],[24.267658574653908,24.29624237813942,24.324826181624935,24.35340998511045,24.381993788595963,24.41057759208148,24.439161395566998,24.467745199052512,24.496329002538026,24.52491280602354,24.553496609509057,24.58208041299457,24.610664216480085,24.6392480199656,24.667831823451113,24.69641562693663,24.724999430422148,24.753583233907662,24.782167037393176,24.81075084087869,24.839334644364207,24.86791844784972,24.896502251335235,24.92508605482075,24.953669858306263,24.98225366179178,25.010837465277298,25.039421268762812,25.068005072248326,25.096588875733836,25.125172679219354,25.15375648270487,25.182340286190385,25.2109240896759,25.239507893161413,25.268091696646927,25.296675500132444,25.325259303617962,25.35384310710348,25.38242691058899,25.411010714074504,25.43959451756002,25.468178321045535,25.496762124531053,25.525345928016566,25.55392973150208,25.582513534987598,25.61109733847311,25.639681141958626,25.668264945444143,25.696848748929657,25.72543255241517,25.75401635590069,25.7826001593862,25.811183962871716,25.839767766357234,25.868351569842744,25.89693537332826,25.925519176813776,25.954102980299293,25.982686783784807,26.01127058727032,26.03985439075584,26.068438194241352,26.09702199772687,26.12560580121238,26.154189604697894,26.18277340818341,26.211357211668926,26.239941015154443,26.268524818639957,26.29710862212547,26.32569242561099,26.3542762290965,26.382860032582016,26.41144383606753,26.440027639553048,26.46861144303856,26.49719524652408,26.525779050009593,26.5519922607519,26.578205469878586,26.60441867900528,26.630631888131973,26.65624120385495,26.68172974089719,26.707218277939422,26.73270681498166,26.759748481972334,26.787566711555616,26.815384941138895,26.84320317072218,26.87102140030546,26.898839629888744,26.926657859472027,26.954476089055305,26.98229431863859,27.01011254822187,27.037930777805155,27.065749007388433,27.093567236971715,27.121385466555,27.14920369613828,27.177021925721565,27.204840155304844,27.23265838488813,27.260476614471408,27.28829484405469,27.316113073637972,27.343931303221254,27.371749532804536,27.399567762387818,27.4273859919711,27.455204221554382,27.483022451137664,27.510840680720946,27.53865891030423,27.56647713988751,27.594295369470792,27.622113599054074,27.649931828637357,27.67775005822064,27.705568287803917,27.733386517387203,27.761204746970485,27.789022976553767,27.81684120613705,27.84465943572033,27.872477665303613,27.900295894886895,27.928114124470177,27.95593235405346,27.98375058363674,28.011568813220023,28.039387042803305,28.067205272386587,28.09502350196987,28.12284173155315,28.150659961136434,28.178478190719716,28.206296420302994,28.23411464988628,28.26193287946956,28.28975110905284,28.317569338636122,28.345387568219405,28.37320579780269,28.401024027385972,28.428842256969254,28.456660486552536,28.48447871613582,28.512296945719097,28.540115175302383,28.567933404885665,28.595751634468947,28.62356986405223,28.651388093635507,28.679206323218793,28.70702455280207,28.734842782385357,28.76266101196864,28.79047924155192,28.818297471135203,28.84611570071848,28.873933930301767,28.901752159885046,28.929570389468328,28.958463947779595,28.98789517045485,29.017326393130105,29.046757615805355,29.07618883848061,29.107498105900003,29.139075663503196,29.170653221106388,29.202230778709584,29.233808336312777,29.265385893915973,29.296963451519165,29.328541009122354,29.360118566725554,29.391696124328746,29.42327368193194,29.454851239535135,29.486428797138327,29.518006354741523,29.549583912344715,29.581161469947908,29.612739027551104,29.644316585154296,29.675894142757492,29.707471700360685,29.739049257963877,29.77062681556707,29.802204373170262,29.833781930773455,29.865359488376654,29.896937045979847,29.92851460358304,29.960092161186232,29.991669718789428,30.023247276392624,30.054824833995816,30.08640239159901,30.1179799492022,30.149557506805397,30.181135064408593,30.212712622011786,30.24429017961498,30.27586773721817,30.307445294821363,30.339022852424563,30.370600410027755,30.402177967630948,30.43375552523414,30.465333082837333,30.496910640440532,30.52848819804372,30.56006575564691,30.59164331325011,30.623220870853302,30.6547984284565,30.686375986059694,30.717953543662887,30.749531101266086,30.78110865886927,30.81268621647247,30.844263774075664,30.875841331678853,30.90741888928205,30.93899644688524,30.970574004488434,31.00215156209163,31.033729119694826,31.065306677298018,31.096884234901214,31.128461792504407,31.160039350107603,31.19161690771079,31.223194465313988,31.25477202291718,31.286349580520373,31.317927138123565,31.34950469572676,31.38108225332996,31.41265981093315,31.444237368536346,31.475814926139538,31.507392483742734,31.538970041345923,31.574761320684807,31.61476632175938,31.654771322833955,31.694776323908524,31.734781324983096,31.774786326057676,31.814791327132244,31.854796328206817,31.894801329281393,31.93480633035596,31.974945543488694,32.015458639746626,32.05597173600456,32.09648483226249,32.13699792852043,32.177511024778354,32.21802412103629,32.25853721729422,32.29905031355215,32.33956340981008,32.38007650606802,32.42058960232596,32.461102698583886,32.501615794841825,32.54212889109976,32.58264198735769,32.62315508361562,32.663668179873554,32.70418127613148,32.74469437238942,32.78520746864735,32.82572056490528,32.866233661163214,32.906746757421146,32.947259853679085,32.98777294993701,33.02828604619495,33.06879914245289,33.109312238710814,33.14982533496875,33.19033843122668,33.23085152748461,33.27136462374254,33.31187772000048,33.35239081625841,33.392903912516346,33.43341700877428,33.47393010503221,33.51444320129014,33.554956297548074,33.59546939380601,33.63598249006394,33.67649558632187,33.71700868257981,33.75752177883774,33.798034875095674,33.838547971353606,33.879061067611545,33.91957416386947,33.96008726012741,34.000600356385334,34.04111345264327,34.0816265489012,34.12213964515914,34.16265274141707,34.203165837675,34.243678933932934,34.284192030190866,34.3247051264488,34.36521822270673,34.40573131896466,34.4462444152226,34.48675751148053,34.527270607738465,34.56778370399639,34.60829680025432,34.64880989651226,34.6893229927702,34.729836089028126,34.770349185286065,34.810862281544,34.85137537780193,34.89188847405986,34.882839498665156,34.774666379965225,34.6664932612653,34.558320142565364,34.45014702386544,34.34197390516552,34.23380078646557,34.12562766776564,34.01745454906572,33.90928143036579,33.80110831166585,33.692935192965926,33.584762074265996,33.47658895556606,33.368415836866134,33.260242718166204,33.152069599466266,33.04389648076634,32.93572336206642,32.82755024336648,32.71937712466654,32.61120400596661,32.50303088726669,32.39485776856675,32.28668464986683,32.178511531166905,32.07033841246697,31.962165293767036,31.853992175067113,31.745819056367175,31.637645937667237,31.52947281896732,31.421299700267383,31.313126581567452,31.204953462867522,31.0967803441676,30.98860722546766,30.88043410676773,30.772260988067806,30.66408786936787,30.55591475066794,30.447741631968015,30.339568513268077,30.231395394568143,30.123222275868223,30.015049157168292,29.906876038468354,29.798702919768427,29.6905298010685,29.582356682368562,29.485296961974154,29.391412550831888,29.29752813968961,29.203643728547338,29.10975931740508,29.01587490626281,28.921990495120536,28.82810608397827,28.734221672835996,28.64033726169373,28.54645285055146,28.452568439409195,28.35868402826692,28.26479961712466,28.170915205982393,28.077030794840116,27.983146383697843,27.889261972555584,27.79537756141331,27.701493150271034,27.60760873912877,27.513724327986505,27.419839916844232,27.325955505701963,27.232071094559696,27.138186683417423,27.04430227227515,26.950417861132895,26.856533449990618,26.762649038848345,26.668764627706082,26.574880216563812,26.480995805421536,26.355309347090063,26.070612652812486,25.785915958534908,25.501219264257326,25.216522569979798,24.93182587570222,24.64712918142464,24.362432487147114,24.077735792869532,23.793039098591954,23.508342404314426,23.223645710036845,22.938949015759263,22.654252321481685,22.380372063721044,22.144479076770768,21.908586089820496,21.67269310287026,21.436800115919986,21.200907128969707,20.96501414201947,20.729121155069194,20.493228168118915,20.25733518116868,20.021442194218405,19.78554920726813,19.54965622031785,19.313763233367613,19.07787024641734,18.841977259467065,18.60608427251683,18.37019128556655,18.134298298616272,17.89840531166604,17.662512324715763,17.426619337765484,17.190726350815208,16.954833363864974,16.7189403769147,16.48304738996442,16.247154403014186,16.01126141606391,15.775368429113632,15.539475442163397,15.303582455213117,15.067689468262843,14.83179648131261,14.595903494362332,14.360010507412055,14.124117520461779,13.888224533511545,13.652331546561266,13.41643855961099,13.180545572660755,12.944652585710479,12.7087595987602,12.472866611809968,12.23697362485969,12.001080637909412,11.765187650959135,11.529294664008901,11.293401677058625,11.057508690108346,10.821615703158113,10.585722716207837,10.349829729257557,10.113936742307324,9.878043755357048,9.64215076840677,9.406257781456537,9.215179067821994,9.026706825219875,8.838234582617762,8.64976234001568,8.461290097413565,8.27281785481145,8.084345612209367,7.89587336960725,7.707401127005135,7.518928884403055,7.330456641800938,7.1419843991988206,6.953512156596705,6.765039913994624],[24.71931972548138,24.75029443398891,24.78126914249643,24.81224385100396,24.84321855951149,24.87419326801902,24.905167976526545,24.93614268503407,24.967117393541603,24.998092102049135,25.02906681055666,25.06004151906419,25.091016227571718,25.12039700142186,25.148980804907374,25.177564608392892,25.206148411878402,25.234732215363916,25.263316018849434,25.291899822334948,25.32048362582046,25.34906742930598,25.377651232791493,25.40623503627701,25.434818839762524,25.46340264324804,25.491986446733552,25.520570250219066,25.549154053704584,25.577737857190098,25.60632166067561,25.634905464161125,25.663489267646643,25.692073071132157,25.720656874617674,25.74924067810319,25.777824481588702,25.80640828507422,25.834992088559737,25.863575892045247,25.89215969553076,25.920743499016275,25.949327302501793,25.97791110598731,26.00649490947282,26.035078712958338,26.063662516443852,26.092246319929366,26.120830123414883,26.149413926900397,26.17799773038591,26.20658153387143,26.235165337356946,26.263749140842457,26.292332944327974,26.320916747813484,26.349500551299002,26.37808435478452,26.40666815827003,26.43525196175555,26.463835765241065,26.492419568726582,26.521003372212093,26.549587175697607,26.578170979183124,26.60675478266864,26.635338586154155,26.66392238963967,26.692506193125183,26.7210899966107,26.749673800096218,26.77825760358173,26.806841407067242,26.83542521055276,26.864009014038274,26.89259281752379,26.9211766210093,26.94976042449482,26.978344227980337,27.006928031465847,27.035511834951365,27.06409563843688,27.092679441922396,27.12126324540791,27.14920907064156,27.177027300224847,27.204845529808125,27.232663759391407,27.26048198897469,27.28830021855797,27.316118448141253,27.343936677724535,27.371754907307817,27.3995731368911,27.427391366474385,27.455209596057664,27.48302782564095,27.51084605522423,27.538664284807513,27.566482514390795,27.594300743974074,27.62211897355736,27.64993720314064,27.677755432723924,27.705573662307206,27.733391891890484,27.761210121473766,27.78902835105705,27.816846580640334,27.844664810223613,27.872483039806898,27.900301269390177,27.92811949897346,27.95593772855674,27.983755958140023,28.01157418772331,28.039392417306587,28.06721064688987,28.095028876473158,28.122847106056433,28.150665335639722,28.178483565222997,28.20630179480628,28.23412002438957,28.261938253972843,28.289756483556125,28.31757471313941,28.345392942722693,28.37321117230597,28.401029401889257,28.428847631472536,28.45666586105582,28.484484090639103,28.512302320222386,28.540120549805664,28.567938779388946,28.59575700897223,28.623575238555514,28.651393468138796,28.67921169772208,28.70702992730536,28.734848156888642,28.762666386471924,28.790484616055206,28.818302845638488,28.84612107522177,28.87393930480505,28.901757534388334,28.929575763971616,28.9573939935549,28.98521222313818,29.013030452721463,29.040848682304745,29.068666911888023,29.096485143336118,29.126506279703733,29.156527416071356,29.186548552438975,29.216569688806594,29.246590825174216,29.276611961541835,29.306633097909454,29.336654234277077,29.366675370644696,29.396696507012315,29.426717643379938,29.456738779747557,29.489115041740327,29.522668866545672,29.556222691351014,29.58977651615636,29.623330340961697,29.656884165767046,29.690437990572388,29.723991815377733,29.757545640183075,29.79109946498842,29.824653289793766,29.858207114599107,29.891760939404453,29.925314764209794,29.95886858901514,29.99095556389032,30.022518661021913,30.0540817581535,30.0856448552851,30.117207952416685,30.14877104954828,30.180334146679876,30.211897243811464,30.24346034094306,30.27502343807465,30.306586535206243,30.33814963233783,30.369712729469423,30.401275826601015,30.432838923732607,30.464402020864203,30.49596511799579,30.527528215127383,30.55909131225898,30.59065440939057,30.622217506522162,30.653780603653757,30.685343700785346,30.71690679791694,30.74846989504853,30.780032992180125,30.811596089311713,30.84315918644331,30.874722283574897,30.906285380706493,30.937848477838088,30.969411574969676,31.00097467210127,31.03253776923286,31.064100866364452,31.095663963496044,31.12722706062764,31.158790157759228,31.190353254890816,31.221916352022415,31.253479449154007,31.285042546285602,31.31660564341719,31.348168740548786,31.37973183768037,31.41129493481197,31.442858031943558,31.47442112907515,31.505984226206746,31.537547323338337,31.56911042046993,31.60067351760152,31.632236614733113,31.663799711864705,31.695362808996297,31.72692590612789,31.758489003259477,31.790052100391073,31.821615197522668,31.853178294654256,31.884741391785848,31.91630448891744,31.947867586049032,31.979430683180624,32.01099378031222,32.04255687744381,32.0741199745754,32.10568307170699,32.142239038479595,32.1837878748932,32.22533671130681,32.266885547720406,32.30843438413402,32.34998322054762,32.391532056961225,32.433080893374836,32.47462972978845,32.51617856620204,32.557727402615654,32.599276239029265,32.64082507544287,32.68237391185647,32.723922748270084,32.76547158468369,32.80702042109729,32.8485692575109,32.8901180939245,32.93166693033811,32.973215766751714,33.014764603165325,33.05631343957893,33.09786227599253,33.139411112406144,33.18095994881975,33.22250878523335,33.26405762164696,33.305606458060566,33.34715529447417,33.388704130887774,33.430252967301385,33.47180180371499,33.51335064012859,33.554899476542204,33.59644831295581,33.63799714936941,33.67954598578302,33.72109482219662,33.762319208631524,33.80283230488946,33.84334540114739,33.88385849740531,33.92437159366325,33.96488468992119,34.00539778617912,34.045910882437056,34.08642397869498,34.12693707495291,34.167450171210845,34.207963267468784,34.248476363726716,34.28898945998465,34.32950255624258,34.37001565250051,34.410528748758445,34.45104184501638,34.491554941274316,34.53206803753224,34.57258113379018,34.613094230048105,34.653607326306044,34.69412042256397,34.73463351882191,34.77514661507984,34.81565971133777,34.85617280759571,34.896685903853644,34.93719900011157,34.9777120963695,35.01822519262744,35.05873828888537,35.099251385143305,35.13976448140124,35.18027757765917,35.2207906739171,35.26130377017503,35.30181686643297,35.342329962690904,35.382843058948836,35.423356155206775,35.4638692514647,35.50438234772263,35.49533337232793,35.387160253628,35.27898713492808,35.17081401622814,35.06264089752821,34.95446777882829,34.84629466012835,34.73812154142841,34.629948422728496,34.521775304028566,34.41360218532862,34.305429066628705,34.19725594792877,34.089082829228836,33.980909710528906,33.87273659182898,33.764563473129044,33.65639035442912,33.54821723572919,33.44004411702925,33.331870998329315,33.22369787962939,33.11552476092946,33.00735164222953,32.8991785235296,32.791005404829676,32.68283228612974,32.574659167429814,32.466486048729884,32.35831293002995,32.25013981133001,32.14196669263009,32.033793573930154,31.925620455230224,31.817447336530293,31.70927421783037,31.60110109913043,31.49292798043051,31.384754861730578,31.276581743030643,31.168408624330716,31.06023550563079,30.952062386930855,30.843889268230917,30.73571614953099,30.627543030831063,30.519369912131125,30.411196793431202,30.30302367473127,30.194850556031334,30.086677437331414,29.978504318631487,29.87033119993155,29.76215808123161,29.653984962531695,29.545811843831757,29.43763872513182,29.329465606431896,29.221292487731965,29.113119369032034,29.004946250332107,28.89677313163218,28.788600012932243,28.675918728432812,28.556377268066967,28.436835807701122,28.31729434733527,28.19775288696944,28.078211426603588,27.95866996623774,27.839128505871898,27.71958704550606,27.600045585140208,27.48050412477437,27.36096266440853,27.24142120404268,27.12187974367683,27.002338283310998,26.882796822945146,26.7632553625793,26.643713902213456,26.524172441847615,26.404630981481766,26.257309153579957,25.971085487998224,25.68486182241649,25.39863815683476,25.112414491253084,24.826190825671347,24.539967160089613,24.253743494507937,23.967519828926203,23.681296163344467,23.395072497762786,23.108848832181053,22.82262516659932,22.536401501017586,22.25017783543591,21.963954169854176,21.677730504272443,21.391506838690766,21.105283173109033,20.86100152951094,20.625108542560703,20.389215555610427,20.15332256866015,19.917429581709914,19.681536594759635,19.445643607809362,19.209750620859086,18.973857633908853,18.737964646958574,18.502071660008294,18.26617867305806,18.030285686107785,17.794392699157505,17.558499712207272,17.322606725256996,17.08671373830672,16.85082075135644,16.61492776440621,16.37903477745593,16.143141790505656,15.907248803555419,15.671355816605143,15.435462829654865,15.19956984270463,14.963676855754352,14.727783868804075,14.491890881853843,14.255997894903565,14.02010490795329,13.78421192100301,13.548318934052777,13.3124259471025,13.076532960152223,12.840639973201988,12.604746986251712,12.368853999301434,12.132961012351199,11.897068025400923,11.661175038450645,11.425282051500368,11.189389064550134,10.953496077599858,10.717603090649579,10.481710103699346,10.24581711674907,10.027144570951567,9.842912260167447,9.658679949383291,9.474447638599138,9.290215327815018,9.105983017030862,8.921750706246709,8.737518395462555,8.553286084678433,8.36905377389428,8.184821463110124,8.000589152326004,7.81635684154185,7.632124530757695,7.447892219973575,7.26365990918942,7.079427598405266,6.89519528762111,6.710962976836989],[25.168896500282255,25.199871208789784,25.23084591729731,25.261820625804837,25.292795334312366,25.323770042819895,25.354744751327424,25.38571945983495,25.41669416834248,25.44766887685001,25.47864358535754,25.50961829386506,25.54059300237259,25.57156771088012,25.60254241938765,25.63351712789518,25.664491836402703,25.695466544910232,25.72644125341776,25.75741596192529,25.78839067043282,25.819365378940347,25.850340087447872,25.881314795955404,25.91228950446293,25.943264212970462,25.97423892147799,26.005213629985512,26.036188338493044,26.06676456524869,26.095348368734204,26.123932172219718,26.152515975705235,26.18109977919075,26.209683582676263,26.23826738616178,26.266851189647294,26.295434993132808,26.324018796618326,26.352602600103843,26.381186403589354,26.40977020707487,26.43835401056038,26.466937814045902,26.495521617531413,26.524105421016927,26.552689224502444,26.581273027987958,26.609856831473476,26.63844063495899,26.667024438444503,26.69560824193002,26.724192045415535,26.75277584890105,26.781359652386563,26.80994345587208,26.838527259357594,26.86711106284311,26.895694866328625,26.92427866981414,26.952862473299653,26.98144627678517,27.01003008027069,27.0386138837562,27.067197687241716,27.09578149072723,27.124365294212744,27.15294909769826,27.181532901183775,27.21011670466929,27.238700508154807,27.26728431164032,27.295868115125835,27.324451918611352,27.353035722096866,27.38161952558238,27.410203329067897,27.43878713255341,27.467370936038925,27.495954739524443,27.524538543009953,27.55312234649547,27.581706149980985,27.610289953466502,27.63823577870015,27.66605400828343,27.693872237866714,27.72169046745,27.749508697033278,27.77732692661656,27.805145156199846,27.832963385783124,27.860781615366413,27.888599844949688,27.916418074532977,27.944236304116256,27.97205453369954,27.999872763282816,28.027690992866106,28.055509222449388,28.08332745203267,28.111145681615948,28.138963911199234,28.166782140782512,28.19460037036579,28.222418599949076,28.25023682953236,28.278055059115644,28.305873288698923,28.3336915182822,28.361509747865487,28.389327977448772,28.417146207032054,28.444964436615333,28.47278266619861,28.500600895781897,28.528419125365176,28.556237354948458,28.584055584531747,28.61187381411502,28.63969204369831,28.667510273281593,28.69532850286487,28.723146732448157,28.750964962031432,28.778783191614718,28.806601421198,28.83441965078128,28.862237880364564,28.890056109947846,28.917874339531128,28.94569256911441,28.973510798697692,29.001329028280974,29.029147257864256,29.056965487447535,29.08478371703082,29.112601946614106,29.14152163181784,29.17154276818546,29.20156390455308,29.2315850409207,29.26160617728832,29.29162731365594,29.32164845002356,29.351669586391182,29.3816907227588,29.41171185912642,29.441732995494043,29.471754131861662,29.50177526822928,29.531796404596907,29.56181754096452,29.59183867733214,29.621859813699764,29.65188095006738,29.681902086435006,29.71192322280262,29.74194435917024,29.771965495537863,29.801986631905482,29.8320077682731,29.862028904640727,29.892050041008343,29.922071177375962,29.952092313743584,29.982113450111203,30.01448971210398,30.04804353690932,30.081597361714664,30.115151186520006,30.148705011325355,30.182258836130693,30.215812660936038,30.24936648574138,30.28292031054673,30.316474135352067,30.350027960157412,30.383581784962754,30.4171356097681,30.450689434573444,30.484243259378786,30.51779708418413,30.55135090898947,30.58490473379482,30.61845855860016,30.652012383405506,30.685566208210847,30.71912003301619,30.75267385782153,30.78622768262688,30.819781507432225,30.853335332237563,30.88688915704291,30.920442981848247,30.953996806653596,30.987550631458937,31.021104456264286,31.054658281069624,31.08821210587497,31.121765930680308,31.155319755485657,31.1873543431881,31.218917440319693,31.25048053745128,31.282043634582877,31.313606731714465,31.34516982884606,31.376732925977656,31.40829602310924,31.43985912024084,31.471422217372428,31.502985314504024,31.534548411635615,31.5661115087672,31.597674605898796,31.62923770303039,31.660800800161983,31.69236389729357,31.723926994425163,31.75549009155676,31.787053188688354,31.81861628581994,31.85017938295153,31.881742480083126,31.91330557721472,31.944868674346317,31.976431771477902,32.007994868609494,32.03955796574108,32.07112106287268,32.10268416000427,32.13424725713586,32.16581035426746,32.19737345139905,32.22893654853064,32.26049964566223,32.292062742793824,32.32362583992541,32.355188937057015,32.3867520341886,32.41831513132019,32.44987822845178,32.481441325583376,32.51300442271497,32.54456751984656,32.57613061697815,32.60769371410974,32.63925681124134,32.670819908372934,32.70737587514552,32.74892471155914,32.790473547972745,32.83202238438635,32.87357122079995,32.91512005721356,32.95666889362717,32.99821773004078,33.03976656645438,33.08131540286798,33.12286423928159,33.1644130756952,33.205961912108805,33.24751074852241,33.28905958493601,33.33060842134962,33.37215725776323,33.41370609417683,33.45525493059044,33.496803767004046,33.53835260341765,33.57990143983126,33.62145027624486,33.66299911265847,33.70454794907208,33.74609678548568,33.78764562189929,33.8291944583129,33.870743294726495,33.912292131140106,33.95384096755372,33.99538980396733,34.036938640380924,34.078487476794535,34.12003631320814,34.16158514962174,34.20313398603535,34.24468282244896,34.28623165886256,34.327780495276166,34.36932933168978,34.41087816810338,34.452427004516984,34.493975840930595,34.5355246773442,34.577073513757796,34.61862235017141,34.66017118658502,34.70172002299862,34.743268859412225,34.784817695825836,34.82636653223944,34.867915368653044,34.909464205066655,34.951013041480266,34.99256187789386,35.03411071430747,35.07565955072108,35.11720838713468,35.158757223548285,35.200306059961896,35.2418548963755,35.283403732789104,35.324952569202715,35.36650140561632,35.40805024202992,35.44959907844353,35.491147914857144,35.532696751270734,35.574245587684345,35.615794424097956,35.65734326051157,35.698892096925164,35.740440933338775,35.78198976975238,35.82353860616598,35.86508744257959,35.906636278993204,35.94818511540681,35.98973395182042,36.031282788234016,36.07283162464762,36.11505152419771,36.098984666463,35.965539020558886,35.83659934681271,35.71705788644687,35.59751642608103,35.477974965715184,35.35843350534933,35.23889204498349,35.119350584617656,34.999809124251804,34.88026766388595,34.76072620352011,34.64118474315427,34.52164328278842,34.40210182242258,34.28256036205674,34.16301890169089,34.04347744132505,33.92393598095921,33.80439452059336,33.68485306022751,33.565311599861666,33.445770139495835,33.32622867912998,33.20668721876414,33.0871457583983,32.96760429803245,32.84806283766662,32.72852137730077,32.60897991693492,32.48943845656907,32.36989699620324,32.250355535837386,32.13081407547154,32.0112726151057,31.89173115473986,31.77218969437401,31.65264823400817,31.53310677364233,31.413565313276482,31.294023852910637,31.1744823925448,31.05494093217895,30.9353994718131,30.81585801144726,30.696316551081416,30.576775090715568,30.45723363034973,30.33769216998389,30.218150709618037,30.0986092492522,29.979067788886354,29.85952632852051,29.739984868154657,29.62044340778883,29.500901947422975,29.38136048705713,29.261819026691285,29.14227756632545,29.022736105959595,28.903194645593757,28.783653185227916,28.664111724862067,28.54457026449623,28.425028804130392,28.30548734376454,28.185945883398688,28.06640442303286,27.946862962667005,27.82732150230116,27.707780041935315,27.588238581569478,27.468697121203625,27.34915566083779,27.22961420047195,27.110072740106098,26.990531279740246,26.870989819374422,26.75144835900857,26.63190689864272,26.51236543827688,26.39282397791104,26.27328251754519,26.125960689643378,25.839737024061645,25.553513358479908,25.26728969289818,24.9810660273165,24.694842361734764,24.408618696153034,24.122395030571354,23.83617136498962,23.549947699407888,23.263724033826207,22.977500368244478,22.69127670266274,22.405053037081007,22.118829371499327,21.832605705917597,21.546382040335864,21.260158374754184,20.97393470917245,20.687711043590717,20.401487378009037,20.115263712427307,19.82904004684557,19.54281638126389,19.256592715682157,18.970369050100423,18.684145384518693,18.39792171893701,18.11169805335528,17.825474387773546,17.558010519717683,17.324819090426857,17.09162766113603,16.858436231845246,16.62524480255442,16.392053373263597,16.15886194397277,15.925670514681988,15.692479085391163,15.459287656100335,15.226096226809554,14.992904797518728,14.759713368227901,14.526521938937119,14.293330509646292,14.060139080355468,13.826947651064685,13.593756221773859,13.360564792483032,13.127373363192207,12.894181933901427,12.660990504610599,12.427799075319774,12.194607646028992,12.001216228872448,11.816983918088292,11.632751607304172,11.448519296520017,11.264286985735861,11.080054674951711,10.89582236416759,10.711590053383434,10.527357742599278,10.343125431815158,10.158893121031005,9.97466081024685,9.79042849946273,9.606196188678574,9.42196387789442,9.2377315671103,9.053499256326145,8.869266945541991,8.685034634757837,8.500802323973716,8.31657001318956,8.132337702405406,7.9481053916212865,7.763873080837131,7.579640770052977,7.395408459268857,7.211176148484702,7.026943837700547,6.842711526916393,6.658479216132272],[25.618473275083137,25.64944798359067,25.68042269209819,25.71139740060572,25.742372109113248,25.773346817620777,25.804321526128305,25.835296234635834,25.866270943143363,25.89724565165089,25.92822036015842,25.95919506866595,25.990169777173477,26.021144485681006,26.052119194188535,26.083093902696064,26.11406861120359,26.145043319711117,26.176018028218646,26.206992736726175,26.2379674452337,26.26894215374123,26.299916862248757,26.330891570756286,26.361866279263815,26.392840987771343,26.423815696278872,26.454790404786394,26.48576511329393,26.516739821801455,26.547714530308983,26.578689238816516,26.609663947324037,26.640638655831566,26.671613364339095,26.702588072846623,26.733562781354152,26.76453748986168,26.79551219836921,26.826486906876735,26.857461615384263,26.888436323891792,26.91941103239932,26.950385740906853,26.981360449414378,27.012335157921903,27.041715932561043,27.070299736046557,27.09888353953207,27.12746734301759,27.1560511465031,27.18463494998862,27.21321875347413,27.241802556959648,27.270386360445162,27.298970163930676,27.327553967416193,27.356137770901707,27.384721574387225,27.413305377872735,27.441889181358256,27.470472984843767,27.499056788329284,27.527640591814798,27.556224395300312,27.58480819878583,27.61339200227134,27.64197580575686,27.67055960924237,27.69914341272789,27.727727216213403,27.75631101969892,27.784894823184434,27.813478626669948,27.842062430155465,27.870646233640983,27.899230037126493,27.927813840612007,27.95639764409752,27.98498144758304,28.013565251068556,28.04214905455407,28.070732858039584,28.099316661525098,28.127262486758752,28.155080716342034,28.182898945925317,28.2107171755086,28.23853540509188,28.266353634675163,28.294171864258445,28.321990093841727,28.34980832342501,28.37762655300829,28.405444782591573,28.433263012174855,28.461081241758137,28.48889947134142,28.516717700924705,28.544535930507983,28.572354160091265,28.600172389674547,28.627990619257833,28.65580884884111,28.683627078424394,28.711445308007676,28.739263537590958,28.76708176717424,28.794899996757522,28.822718226340804,28.850536455924086,28.878354685507368,28.90617291509065,28.933991144673932,28.961809374257214,28.989627603840496,29.017445833423775,29.045264063007057,29.073082292590346,29.100900522173625,29.128718751756907,29.15653698393196,29.186558120299576,29.216579256667195,29.24660039303482,29.27662152940244,29.306642665770063,29.336663802137682,29.366684938505294,29.396706074872924,29.426727211240543,29.456748347608162,29.486769483975785,29.516790620343397,29.54681175671102,29.57683289307864,29.606854029446257,29.636875165813883,29.666896302181502,29.69691743854912,29.726938574916744,29.75695971128436,29.786980847651982,29.817001984019605,29.847023120387224,29.877044256754843,29.907065393122465,29.937086529490085,29.967107665857704,29.997128802225326,30.027149938592945,30.057171074960564,30.08719221132818,30.117213347695802,30.147234484063425,30.177255620431044,30.207276756798663,30.237297893166286,30.267319029533905,30.297340165901524,30.327361302269146,30.357382438636765,30.387403575004384,30.417424711372007,30.447445847739623,30.47746698410725,30.507488120474868,30.539864382467638,30.573418207272976,30.60697203207832,30.640525856883666,30.67407968168901,30.707633506494357,30.741187331299695,30.77474115610504,30.80829498091039,30.841848805715724,30.875402630521073,30.908956455326415,30.942510280131764,30.976064104937105,31.009617929742447,31.04317175454779,31.076725579353138,31.11027940415848,31.14383322896382,31.177387053769166,31.210940878574508,31.24449470337985,31.278048528185195,31.311602352990533,31.345156177795882,31.378710002601224,31.41226382740657,31.445817652211915,31.479371477017256,31.512925301822595,31.54647912662794,31.580032951433285,31.613586776238627,31.647140601043972,31.680694425849314,31.714248250654656,31.747802075460005,31.781355900265343,31.814909725070688,31.848463549876033,31.882017374681375,31.91557119948672,31.949125024292062,31.98267884909741,32.01623267390275,32.049786498708094,32.08334032351344,32.11689414831878,32.15044797312413,32.184001797929476,32.217555622734814,32.25110944754015,32.284663272345504,32.31821709715084,32.35177092195619,32.38375312248589,32.41531621961748,32.446879316749076,32.47844241388067,32.51000551101226,32.54156860814385,32.57313170527544,32.60469480240703,32.63625789953863,32.66782099667022,32.69938409380181,32.730947190933406,32.762510288064995,32.79407338519659,32.82563648232818,32.85719957945977,32.88876267659136,32.92032577372296,32.951888870854546,32.98345196798614,33.01501506511773,33.046578162249325,33.078141259380914,33.10970435651251,33.141267453644105,33.17283055077569,33.20439364790729,33.23595674503888,33.27251271181147,33.314061548225084,33.35561038463869,33.39715922105229,33.4387080574659,33.480256893879506,33.52180573029311,33.56335456670672,33.60490340312033,33.64645223953393,33.68800107594754,33.72954991236114,33.77109874877475,33.81264758518836,33.85419642160196,33.895745258015566,33.93729409442917,33.97884293084278,34.020391767256385,34.06194060366999,34.1034894400836,34.14503827649721,34.18658711291081,34.22813594932442,34.26968478573802,34.31123362215163,34.35278245856524,34.39433129497884,34.43588013139245,34.47742896780605,34.518977804219666,34.56052664063327,34.602075477046874,34.643624313460485,34.68517314987409,34.72672198628769,34.7682708227013,34.80981965911491,34.851368495528504,34.892917331942115,34.934466168355726,34.97601500476932,35.01756384118293,35.05911267759654,35.10066151401015,35.142210350423746,35.18375918683736,35.22530802325096,35.26740329792255,35.31002583427257,35.352648370622596,35.39527090697262,35.437893443322636,35.480515979672674,35.5231385160227,35.565761052372714,35.608383588722745,35.65100612507277,35.693628661422785,35.736251197772816,35.77887373412284,35.82149627047286,35.86411880682289,35.90674134317291,35.949363879522934,35.99198641587296,36.03460895222298,36.07723148857301,36.11985402492303,36.16247656127305,36.20509909762308,36.2477216339731,36.290344170323124,36.33296670667315,36.37558924302317,36.4182117793732,36.460834315723226,36.50345685207325,36.546079388423266,36.5887019247733,36.63132446112333,36.673946997473344,36.71656953382337,36.70050267608866,36.56705703018455,36.43361138428044,36.300165738376315,36.166720092472204,36.03327444656809,35.89982880066397,35.76638315475985,35.63293750885575,35.49949186295163,35.3660462170475,35.232600571143394,35.099154925239276,34.96570927933516,34.83226363343105,34.69881798752694,34.56537234162281,34.4319266957187,34.29848104981458,34.165035403910466,34.03158975800634,33.89814411210223,33.76469846619812,33.631252820293994,33.497807174389884,33.36436152848577,33.230915882581655,33.09747023667754,32.964024590773434,32.83057894486931,32.697133298965184,32.56368765306109,32.43024200715696,32.29679636125284,32.16335071534873,32.02990506944462,31.89645942354049,31.76301377763638,31.62956813173227,31.496122485828145,31.36267683992403,31.22923119401992,31.0957855481158,30.962339902211674,30.828894256307564,30.695448610403453,30.562002964499328,30.428557318595217,30.295111672691107,30.161666026786982,30.02822038088287,29.894774734978764,29.76132908907464,29.627883443170514,29.494437797266414,29.3695534834864,29.250012023120544,29.130470562754702,29.010929102388864,28.891387642023016,28.771846181657175,28.652304721291337,28.53276326092548,28.413221800559647,28.293680340193806,28.174138879827957,28.0545974194621,27.935055959096275,27.815514498730426,27.69597303836457,27.576431577998733,27.456890117632895,27.337348657267043,27.2178071969012,27.098265736535364,26.978724276169515,26.859182815803663,26.739641355437836,26.62009989507198,26.500558434706132,26.381016974340294,26.261475513974453,26.1419340536086,25.994612225706796,25.70838856012506,25.422164894543325,25.135941228961595,24.849717563379915,24.563493897798182,24.27727023221645,23.99104656663477,23.70482290105304,23.418599235471305,23.132375569889625,22.884122348379677,22.65093091908885,22.417739489798024,22.184548060507243,21.951356631216417,21.71816520192559,21.484973772634806,21.25178234334398,21.018590914053153,20.785399484762372,20.552208055471546,20.31901662618072,20.085825196889935,19.85263376759911,19.619442338308286,19.386250909017463,19.15305947972668,18.919868050435852,18.686676621145025,18.45348519185425,18.22029376256342,17.987102333272592,17.75391090398181,17.520719474690985,17.28752804540016,17.05433661610933,16.82114518681855,16.587953757527725,16.354762328236898,16.121570898946118,15.88837946965529,15.655188040364465,15.421996611073682,15.188805181782858,14.955613752492031,14.722422323201249,14.489230893910424,14.256039464619597,14.022848035328773,13.789656606037987,13.556465176747162,13.323273747456337,13.090082318165553,12.856890888874727,12.623699459583904,12.390508030293121,12.157316601002295,11.92412517171147,11.690933742420643,11.457742313129861,11.224550883839036,10.99135945454821,10.758168025257426,10.524976595966601,10.291785166675776,10.058593737384992,9.825402308094167,9.592210878803343,9.359019449512559,9.125828020221732,8.892636590930907,8.659445161640082,8.448318563268996,8.264086252484843,8.079853941700689,7.895621630916567,7.711389320132412,7.527157009348258,7.342924698564137,7.158692387779983,6.974460076995829,6.790227766211674,6.6059954554275535],[26.068050049884015,26.099024758391543,26.12999946689907,26.160974175406597,26.191948883914126,26.222923592421655,26.25389830092918,26.28487300943671,26.315847717944237,26.346822426451766,26.377797134959295,26.408771843466823,26.43974655197435,26.47072126048188,26.501695968989406,26.532670677496935,26.563645386004463,26.594620094511992,26.62559480301952,26.65656951152705,26.687544220034578,26.718518928542107,26.74949363704963,26.78046834555716,26.811443054064686,26.842417762572218,26.873392471079747,26.90436717958727,26.9353418880948,26.96631659660233,26.997291305109858,27.028266013617387,27.059240722124912,27.090215430632444,27.121190139139973,27.1521648476475,27.18313955615503,27.214114264662552,27.245088973170084,27.27606368167761,27.307038390185138,27.338013098692667,27.368987807200195,27.399962515707724,27.430937224215253,27.46191193272278,27.49288664123031,27.52386134973784,27.554836058245364,27.585810766752893,27.61678547526042,27.64776018376795,27.67873489227548,27.709709600783007,27.740684309290533,27.77165901779806,27.80263372630559,27.83360843481312,27.864583143320647,27.895557851828176,27.9265325603357,27.95750726884323,27.988083496387876,28.016667299873387,28.045251103358904,28.073834906844418,28.102418710329935,28.13100251381545,28.159586317300967,28.18817012078648,28.216753924272,28.245337727757512,28.273921531243023,28.30250533472854,28.331089138214054,28.35967294169957,28.388256745185085,28.4168405486706,28.445424352156117,28.474008155641634,28.502591959127145,28.53117576261266,28.559759566098176,28.58834336958369,28.61628919481734,28.644107424400627,28.671925653983905,28.69974388356719,28.72756211315047,28.75538034273375,28.783198572317037,28.811016801900315,28.8388350314836,28.86665326106688,28.894471490650165,28.922289720233447,28.950107949816733,28.97792617940001,29.005744408983293,29.033562638566575,29.061380868149858,29.08919909773314,29.117017327316425,29.144835556899704,29.172653786482986,29.20157347241368,29.231594608781304,29.261615745148923,29.291636881516542,29.321658017884165,29.351679154251784,29.381700290619406,29.411721426987025,29.441742563354644,29.471763699722267,29.501784836089886,29.531805972457505,29.561827108825128,29.591848245192747,29.621869381560366,29.65189051792799,29.681911654295607,29.711932790663226,29.741953927030846,29.771975063398468,29.801996199766087,29.83201733613371,29.86203847250133,29.892059608868948,29.92208074523657,29.95210188160419,29.98212301797181,30.01214415433943,30.042165290707047,30.07218642707467,30.10220756344229,30.132228699809907,30.16224983617753,30.192270972545153,30.222292108912768,30.25231324528039,30.28233438164801,30.31235551801563,30.34237665438325,30.37239779075087,30.40241892711849,30.432440063486112,30.46246119985373,30.49248233622135,30.522503472588973,30.552524608956592,30.582545745324218,30.612566881691833,30.642588018059453,30.672609154427075,30.70263029079469,30.73265142716231,30.762672563529932,30.792693699897555,30.82271483626517,30.852735972632793,30.882757109000416,30.912778245368038,30.942799381735654,30.972820518103276,31.0028416544709,31.032862790838514,31.065239052831288,31.098792877636626,31.13234670244197,31.165900527247317,31.19945435205266,31.233008176858004,31.266562001663345,31.30011582646869,31.333669651274036,31.367223476079374,31.400777300884723,31.434331125690065,31.46788495049541,31.501438775300752,31.534992600106097,31.56854642491144,31.602100249716784,31.635654074522122,31.66920789932747,31.702761724132813,31.73631554893816,31.769869373743497,31.803423198548845,31.836977023354187,31.87053084815953,31.90408467296487,31.93763849777022,31.97119232257556,32.0047461473809,32.038299972186245,32.07185379699159,32.105407621796935,32.13896144660228,32.17251527140762,32.206069096212964,32.23962292101831,32.27317674582365,32.306730570629,32.34028439543434,32.37383822023968,32.40739204504502,32.44094586985037,32.47449969465571,32.50805351946106,32.5416073442664,32.57516116907175,32.608714993877086,32.64226881868243,32.67582264348778,32.70937646829312,32.74293029309846,32.776484117903806,32.81003794270915,32.843591767514496,32.877145592319835,32.91069941712518,32.944253241930525,32.97780706673586,33.01136089154121,33.044914716346554,33.0784685411519,33.11202236595724,33.14557619076258,33.17913001556792,33.212683840373266,33.24623766517861,33.279791489983964,33.313345314789295,33.34689913959465,33.380452964399986,33.41400678920533,33.447560614010676,33.481114438816014,33.51466826362136,33.548222088426705,33.580151901783665,33.61171499891526,33.643278096046856,33.67484119317844,33.70640429031004,33.73796738744163,33.769530484573224,33.80109358170481,33.837649548477415,33.87919838489102,33.92074722130462,33.96229605771823,34.00384489413184,34.04539373054544,34.086942566959046,34.12849140337266,34.17004023978626,34.211589076199864,34.253137912613475,34.294686749027086,34.33623558544068,34.37778442185429,34.41975507164738,34.4623776079974,34.50500014434742,34.54762268069745,34.590245217047475,34.6328677533975,34.67549028974753,34.71811282609755,34.76073536244757,34.8033578987976,34.845980435147624,34.88860297149765,34.931225507847664,34.973848044197695,35.01647058054772,35.05909311689774,35.101715653247766,35.14433818959779,35.18696072594781,35.22958326229784,35.27220579864787,35.314828334997884,35.35745087134791,35.40007340769793,35.442695944047955,35.48531848039798,35.527941016748,35.570563553098026,35.61318608944805,35.65580862579808,35.698431162148104,35.74105369849813,35.78367623484815,35.826298771198175,35.8689213075482,35.91154384389822,35.95416638024825,35.99678891659827,36.03941145294829,36.082033989298324,36.12465652564835,36.167279061998364,36.209901598348395,36.25252413469842,36.29514667104844,36.337769207398466,36.38039174374849,36.42301428009851,36.46563681644854,36.50825935279856,36.550881889148584,36.59350442549861,36.63612696184863,36.67874949819866,36.72137203454868,36.7639945708987,36.806617107248734,36.84923964359876,36.891862179948774,36.934484716298805,36.97710725264883,37.01972978899885,37.06235232534887,37.1049748616989,37.14759739804892,37.190219934398954,37.23284247074898,37.275465007099,37.318087543449025,37.30202068571431,37.1685750398102,37.03512939390609,36.90168374800197,36.768238102097854,36.63479245619375,36.50134681028962,36.3679011643855,36.2344555184814,36.10100987257728,35.967564226673154,35.834118580769044,35.70067293486493,35.56722728896081,35.4337816430567,35.30033599715259,35.16689035124846,35.03344470534435,34.89999905944024,34.766553413536116,34.633107767632,34.49966212172788,34.36621647582377,34.23277082991965,34.09932518401554,33.96587953811142,33.832433892207305,33.698988246303195,33.565542600399084,33.43209695449496,33.298651308590834,33.16520566268674,33.03176001678261,32.89831437087849,32.76486872497438,32.63142307907027,32.49797743316614,32.36453178726203,32.23108614135792,32.097640495453795,31.964194849549685,31.83074920364557,31.69730355774145,31.563857911837324,31.430412265933217,31.296966620029107,31.16352097412498,31.03007532822087,30.89662968231676,30.76318403641264,30.629738390508525,30.496292744604414,30.36284709870029,30.229401452796164,30.095955806892064,29.962510160987943,29.823109601926287,29.67667148308475,29.530233364243223,29.38379524540168,29.237357126560145,29.09091900771861,28.944480888877067,28.798042770035536,28.651604651194006,28.505166532352455,28.358728413510914,28.212290294669398,28.06585217582785,27.919414056986305,27.772975938144768,27.62653781930324,27.48009970046169,27.333661581620163,27.187223462778633,27.040785343937085,26.894347225095537,26.74790910625402,26.601470987412476,26.45503286857093,26.308594749729398,26.162156630887864,26.01571851204632,25.84614413267436,25.560888450650175,25.27563276862599,24.9903770866018,24.705121404577664,24.41986572255348,24.134610040529296,23.84935435850516,23.56409867648097,23.278842994456785,22.993587312432652,22.708331630408466,22.423075948384277,22.137820266360087,21.852564584335955,21.56730890231177,21.28205322028758,20.996797538263447,20.711541856239258,20.426286174215072,20.14103049219094,19.855774810166753,19.570519128142564,19.28526344611843,19.000007764094242,18.714752082070056,18.42949640004587,18.144240718021734,17.85898503599755,17.57372935397336,17.288473671949227,17.00321798992504,16.768786763538017,16.535595334247233,16.302403904956407,16.06921247566558,15.836021046374753,15.602829617083973,15.369638187793146,15.13644675850232,14.903255329211536,14.670063899920711,14.436872470629886,14.203681041339102,13.970489612048278,13.737298182757453,13.50410675346667,13.270915324175846,13.03772389488502,12.804532465594194,12.571341036303409,12.338149607012584,12.115209299492738,11.935835325923188,11.756461352353607,11.577087378784025,11.397713405214475,11.218339431644893,11.038965458075308,10.859591484505728,10.680217510936178,10.500843537366595,10.321469563797011,10.142095590227463,9.962721616657879,9.783347643088298,9.603973669518746,9.424599695949166,9.245225722379582,9.065851748810033,8.88647777524045,8.707103801670868,8.527729828101284,8.348355854531734,8.168981880962153,7.989607907392571,7.810233933823021,7.630859960253439,7.451485986683856,7.272112013114307,7.092738039544725,6.9133640659751405,6.733990092405557,6.554616118836009],[26.517626824684896,26.548601533192425,26.579576241699954,26.610550950207482,26.641525658715008,26.672500367222536,26.703475075730065,26.734449784237594,26.76542449274512,26.796399201252648,26.827373909760176,26.858348618267705,26.889323326775234,26.920298035282766,26.95127274379029,26.98224745229782,27.013222160805345,27.044196869312877,27.075171577820406,27.106146286327935,27.137120994835463,27.168095703342992,27.199070411850514,27.230045120358046,27.26101982886557,27.2919945373731,27.32296924588063,27.353943954388154,27.384918662895686,27.415893371403214,27.446868079910743,27.477842788418272,27.508817496925797,27.53979220543333,27.570766913940854,27.601741622448383,27.632716330955912,27.663691039463433,27.69466574797097,27.72564045647849,27.756615164986023,27.787589873493552,27.81856458200108,27.84953929050861,27.880513999016138,27.911488707523663,27.94246341603119,27.97343812453872,28.004412833046246,28.035387541553774,28.066362250061303,28.09733695856883,28.12831166707636,28.15928637558389,28.190261084091418,28.221235792598947,28.252210501106475,28.283185209614004,28.314159918121533,28.34513462662906,28.376109335136587,28.407084043644115,28.438058752151644,28.469033460659173,28.5000081691667,28.53098287767423,28.561957586181755,28.592932294689284,28.623907003196813,28.65488171170434,28.68585642021187,28.7168311287194,28.747805837226927,28.778780545734453,28.809755254241985,28.840729962749514,28.87170467125704,28.902679379764567,28.933654088272096,28.963034863700234,28.991618667185744,29.020202470671258,29.048786274156775,29.07737007764229,29.105315902875944,29.133134132459226,29.160952362042508,29.18877059162579,29.2165888245278,29.24660996089542,29.276631097263042,29.30665223363066,29.33667336999828,29.366694506365903,29.39671564273352,29.42673677910114,29.456757915468764,29.486779051836383,29.516800188204,29.54682132457162,29.57684246093924,29.606863597306862,29.63688473367448,29.666905870042104,29.696927006409723,29.726948142777342,29.75696927914496,29.786990415512584,29.817011551880203,29.847032688247822,29.877053824615444,29.907074960983064,29.937096097350683,29.967117233718305,29.997138370085924,30.027159506453543,30.057180642821166,30.087201779188785,30.117222915556404,30.147244051924027,30.177265188291646,30.207286324659265,30.237307461026887,30.267328597394506,30.297349733762125,30.327370870129748,30.35739200649737,30.387413142864986,30.417434279232605,30.44745541560023,30.47747655196785,30.50749768833547,30.53751882470309,30.567539961070707,30.59756109743833,30.627582233805946,30.657603370173568,30.68762450654119,30.717645642908806,30.74766677927643,30.777687915644048,30.807709052011667,30.83773018837929,30.86775132474691,30.897772461114535,30.92779359748215,30.957814733849773,30.987835870217395,31.01785700658501,31.047878142952634,31.077899279320253,31.10792041568787,31.137941552055487,31.16796268842311,31.197983824790732,31.228004961158348,31.25802609752597,31.288047233893593,31.31806837026121,31.34808950662883,31.378110642996454,31.40813177936407,31.438152915731695,31.46817405209931,31.498195188466937,31.528216324834553,31.55823746120217,31.590613723194945,31.624167548000287,31.657721372805632,31.691275197610977,31.72482902241632,31.75838284722166,31.791936672027006,31.82549049683235,31.859044321637693,31.892598146443035,31.926151971248384,31.959705796053722,31.993259620859067,32.02681344566441,32.060367270469754,32.09392109527509,32.127474920080445,32.16102874488578,32.194582569691136,32.228136394496474,32.26169021930181,32.295244044107164,32.3287978689125,32.36235169371784,32.39590551852319,32.42945934332853,32.46301316813388,32.49656699293922,32.53037798778274,32.564225718293486,32.59807344880423,32.631921179314965,32.6657689098257,32.699616640336444,32.73346437084719,32.76731210135793,32.80115983186867,32.8350075623794,32.868855292890146,32.90270302340089,32.936550753911625,32.97039848442237,33.004246214933104,33.038093945443855,33.071941675954584,33.10578940646533,33.13963713697607,33.173484867486806,33.20733259799755,33.24118032850829,33.27502805901903,33.30887578952977,33.34272352004051,33.37657125055125,33.410418981061994,33.44426671157273,33.47811444208347,33.51196217259421,33.54580990310495,33.579657633615696,33.61350536412643,33.64735309463717,33.68120082514791,33.715048555658655,33.7488962861694,33.782744016680134,33.81659174719087,33.85043947770161,33.884287208212356,33.91813493872309,33.951982669233836,33.98583039974458,34.019678130255315,34.05352586076606,34.087373591276794,34.12122132178754,34.15506905229828,34.18891678280902,34.22276451331976,34.256612243830496,34.29045997434123,34.324307704851975,34.35815543536272,34.39721925399123,34.441499160737514,34.48577906748379,34.530058974230066,34.57433888097635,34.61861878772263,34.66289869446891,34.70717860121519,34.75145850796147,34.79573841470775,34.84001832145403,34.884298228200315,34.9285781349466,34.972858041692874,35.01609399196784,35.05878310472748,35.10147221748712,35.14416133024676,35.1868504430064,35.22953955576604,35.272228668525685,35.31491778128533,35.35760689404496,35.40029600680461,35.44298511956425,35.48567423232389,35.528363345083534,35.571052457843166,35.61374157060281,35.656430683362444,35.69911979612209,35.74180890888174,35.78449802164137,35.827187134401015,35.869876247160654,35.91256535992029,35.95525447267994,35.99794358543958,36.04063269819922,36.08332181095885,36.126010923718496,36.168700036478135,36.211389149237775,36.25407826199742,36.29676737475707,36.3394564875167,36.382145600276345,36.424834713035985,36.467523825795624,36.51021293855526,36.55290205131491,36.59559116407455,36.63828027683419,36.680969389593834,36.72365850235347,36.766347615113105,36.80903672787275,36.85172584063239,36.89441495339203,36.937104066151676,36.979793178911315,37.022482291670954,37.06517140443059,37.10786051719023,37.15054962994988,37.19323874270951,37.23592785546916,37.2786169682288,37.321306080988435,37.363995193748075,37.40668430650772,37.44937341926736,37.492062532027,37.534751644786645,37.57744075754628,37.620129870305924,37.66281898306556,37.705508095825195,37.74819720858485,37.79088632134449,37.83357543410413,37.87626454686377,37.918953659623405,37.89419522844842,37.73454170940424,37.574888190360056,37.41543493024209,37.268996811400555,37.122558692559025,36.97612057371748,36.829682454875936,36.68324433603442,36.536806217192876,36.39036809835133,36.2439299795098,36.09749186066826,35.95105374182672,35.80461562298519,35.65817750414365,35.51173938530211,35.36530126646058,35.21886314761904,35.0724250287775,34.92598690993596,34.77954879109442,34.6331106722529,34.486672553411346,34.340234434569815,34.193796315728285,34.047358196886734,33.9009200780452,33.754481959203666,33.60804384036213,33.461605721520584,33.315167602679054,33.16872948383752,33.02229136499598,32.87585324615444,32.729415127312905,32.58297700847137,32.43653888962983,32.2901007707883,32.143662651946755,31.997224533105218,31.85078641426369,31.70434829542214,31.5579101765806,31.41147205773907,31.26503393889754,31.118595820055987,30.972157701214456,30.825719582372926,30.679281463531378,30.532843344689848,30.386405225848314,30.239967107006773,30.093528988165218,29.947090869323706,29.800652750482165,29.654214631640613,29.507776512799087,29.361338393957553,29.214900275116,29.068462156274478,28.922024037432944,28.775585918591396,28.629147799749866,28.48270968090833,28.336271562066788,28.18983344322524,28.04339532438372,27.896957205542183,27.75051908670063,27.6040809678591,27.45764284901757,27.311204730176023,27.164766611334493,27.018328492492962,26.87189037365141,26.725452254809866,26.57901413596835,26.432576017126802,26.28613789828526,26.139699779443724,25.993261660602197,25.846823541760653,25.677249162388694,25.391993480364505,25.10673779834032,24.82148211631613,24.536226434291994,24.250970752267808,23.96571507024362,23.68045938821949,23.3952037061953,23.109948024171114,22.824692342146978,22.539436660122792,22.254180978098603,21.968925296074417,21.683669614050288,21.3984139320261,21.11315825000191,20.827902567977777,20.542646885953587,20.2573912039294,19.97213552190527,19.68687983988108,19.401624157856894,19.11636847583276,18.831112793808572,18.545857111784386,18.261296255728126,17.978125044122073,17.694953832515978,17.41178262090987,17.128611409303822,16.845440197697723,16.56226898609162,16.27909777448557,15.995926562879468,15.712755351273367,15.429584139667265,15.146412928061217,14.863241716455114,14.580070504849012,14.29689929324296,14.013728081636858,13.793614873821666,13.618543097285709,13.443471320749719,13.268399544213732,13.093327767677776,12.918255991141784,12.743184214605797,12.568112438069807,12.393040661533849,12.21796888499786,12.04289710846187,11.867825331925912,11.692753555389924,11.517681778853934,11.34261000231798,11.167538225781989,10.98888129020132,10.80950731663174,10.630133343062191,10.450759369492607,10.271385395923025,10.092011422353474,9.912637448783892,9.73326347521431,9.55388950164476,9.374515528075177,9.195141554505595,9.015767580936044,8.836393607366462,8.65701963379688,8.477645660227298,8.298271686657747,8.118897713088165,7.939523739518583,7.760149765949032,7.58077579237945,7.401401818809868,7.222027845240318,7.042653871670736,6.863279898101153,6.68390592453157,6.50453195096202],[26.960883552105926,26.99424663387441,27.0276097156429,27.060972797411385,27.09433587917987,27.127698960948354,27.16106204271684,27.194425124485324,27.227788206253813,27.261151288022294,27.294514369790782,27.327877451559267,27.36044441170027,27.3914191202078,27.42239382871533,27.453368537222858,27.484343245730383,27.515317954237915,27.54629266274544,27.577267371252972,27.6082420797605,27.63921678826803,27.67019149677555,27.70116620528308,27.73214091379061,27.763115622298137,27.794090330805663,27.82506503931319,27.85603974782072,27.887014456328252,27.91798916483578,27.948963873343306,27.979938581850835,28.010913290358367,28.041887998865892,28.07286270737342,28.10383741588095,28.13481212438848,28.165786832896007,28.196761541403532,28.22773624991106,28.25871095841859,28.28968566692612,28.320660375433647,28.351635083941172,28.3826097924487,28.41358450095623,28.44455920946376,28.475533917971283,28.506508626478812,28.53748333498634,28.56845804349387,28.5994327520014,28.630407460508927,28.661382169016456,28.692356877523984,28.723331586031513,28.75430629453904,28.78528100304657,28.8162557115541,28.847230420061624,28.878205128569153,28.90917983707668,28.94015454558421,28.97112925409174,29.002103962599268,29.033078671106793,29.06405337961432,29.09502808812185,29.12600279662938,29.156977505136908,29.187952213644436,29.218926922151965,29.249901630659494,29.280876339167023,29.31185104767455,29.342825756182076,29.373800464689605,29.404775173197134,29.435749881704663,29.46672459021219,29.497699298719716,29.528674007227245,29.559648715734774,29.589828780792377,29.61984991716,29.64987105352762,29.67989218989524,29.70991332626286,29.73993446263048,29.769955598998102,29.79997673536572,29.82999787173334,29.860019008100963,29.89004014446858,29.9200612808362,29.950082417203824,29.980103553571443,30.01012468993906,30.04014582630668,30.0701669626743,30.100188099041922,30.13020923540954,30.160230371777164,30.190251508144783,30.220272644512402,30.25029378088002,30.280314917247644,30.310336053615263,30.340357189982882,30.370378326350504,30.400399462718124,30.430420599085743,30.460441735453365,30.490462871820984,30.520484008188603,30.550505144556226,30.580526280923845,30.610547417291464,30.640568553659087,30.670589690026706,30.700610826394325,30.730631962761944,30.760653099129563,30.790674235497185,30.820695371864804,30.850716508232427,30.880737644600046,30.910758780967665,30.940779917335284,30.970801053702907,31.00082219007053,31.030843326438145,31.060864462805768,31.09088559917339,31.120906735541006,31.150927871908628,31.180949008276247,31.210970144643866,31.24099128101149,31.271012417379108,31.301033553746727,31.33105469011435,31.36107582648197,31.391096962849588,31.42111809921721,31.45113923558483,31.48116037195245,31.511181508320067,31.541202644687687,31.57122378105531,31.60124491742293,31.631266053790547,31.66128719015817,31.691308326525792,31.72202124426228,31.754117717456126,31.78621419064997,31.818310663843818,31.850407137037664,31.88250361023151,31.914600083425356,31.9466965566192,31.978793029813048,32.010889503006894,32.04298597620074,32.075082449394586,32.10940751616088,32.14484687971339,32.180286243265904,32.215725606818424,32.25116497037094,32.28660433392345,32.32204369747596,32.357483061028475,32.392922424580995,32.42836178813351,32.46380115168603,32.49924051523853,32.53467987879105,32.570119242343566,32.60555860589608,32.6409979694486,32.67643733300111,32.71131192660661,32.745159657117355,32.77900738762809,32.81285511813883,32.84670284864957,32.880550579160314,32.91439830967105,32.94824604018179,32.98209377069253,33.01594150120327,33.04978923171401,33.08363696222475,33.11748469273549,33.15133242324623,33.185180153756974,33.21902788426771,33.25287561477845,33.28672334528919,33.32057107579993,33.354418806310676,33.38826653682142,33.422114267332155,33.45596199784289,33.489809728353634,33.52365745886437,33.557505189375114,33.59135291988585,33.62520065039659,33.659048380907336,33.69289611141807,33.726743841928815,33.76059157243955,33.7944393029503,33.82828703346104,33.86213476397178,33.895982494482524,33.92983022499325,33.963677955504,33.99752568601474,34.03137341652548,34.065221147036226,34.09906887754696,34.1329166080577,34.16676433856844,34.20061206907918,34.23445979958992,34.268307530100664,34.3021552606114,34.33600299112214,34.36985072163288,34.40369845214362,34.437546182654366,34.4713939131651,34.505241643675845,34.53908937418658,34.572937104697324,34.60678483520807,34.6406325657188,34.67448029622955,34.70832802674028,34.742175757251026,34.77602348776177,34.809871218272505,34.84371894878325,34.877566679293984,34.91141440980473,34.950478228433234,34.994758135179524,35.03903804192579,35.083317948672075,35.12759785541836,35.17187776216464,35.216157668910924,35.26043757565721,35.30471748240348,35.34899738914976,35.39327729589604,35.437557202642324,35.4818371093886,35.52611701613488,35.570396922881166,35.61467682962744,35.658956736373725,35.70323664312001,35.74751654986628,35.791796456612566,35.83607636335885,35.88035627010513,35.92463617685141,35.96891608359769,36.013195990343974,36.05747589709024,36.101755803836525,36.14603571058281,36.19031561732909,36.23459552407537,36.27887543082166,36.32315533756793,36.36743524431421,36.41171515106049,36.455995057806774,36.50027496455306,36.54455487129933,36.588834778045616,36.631623315554506,36.674312428314146,36.717001541073785,36.759690653833424,36.80237976659307,36.84506887935271,36.887757992112356,36.93044710487199,36.973136217631634,37.01582533039127,37.05851444315091,37.10120355591055,37.1438926686702,37.18658178142984,37.229270894189476,37.271960006949115,37.31464911970876,37.35733823246839,37.40002734522804,37.442716457987686,37.48540557074732,37.528094683506964,37.5707837962666,37.61347290902624,37.65616202178588,37.69885113454552,37.74154024730516,37.7842293600648,37.826918472824445,37.869607585584085,37.912296698343724,37.95498581110336,37.99767492386301,38.04036403662265,38.08305314938229,38.125742262141934,38.168431374901566,38.21112048766121,38.25380960042086,38.29649871318049,38.33918782594013,38.38187693869977,38.424566051459415,38.46725516421906,38.50994427697869,38.485185845803706,38.32553232675952,38.165878807715345,38.006225288671146,37.84657176962696,37.686918250582785,37.52726473153859,37.36761121249439,37.207957693450226,37.04830417440603,36.88865065536183,36.728997136317645,36.56934361727347,36.40969009822927,36.250036579185085,36.09038306014091,35.93072954109671,35.771076022052526,35.61142250300834,35.45176898396415,35.29211546491995,35.13246194587577,34.97280842683159,34.81315490778739,34.65350138874321,34.493847869699024,34.334194350654826,34.17454083161065,34.014887312566465,33.855233793522274,33.695580274478075,33.535926755433906,33.37627323638971,33.21661971734551,33.05696619830133,32.89731267925715,32.73765916021295,32.578005641168765,32.41835212212459,32.25869860308039,32.099045084036206,31.939391564992025,31.77973804594783,31.620084526903632,31.460431007859448,31.300777488815264,31.14112396977107,30.98147045072689,30.821816931682704,30.662163412638513,30.50250989359433,30.34285637455015,30.18320285550595,30.023549336461755,29.86389581741759,29.70424229837339,29.544588779329196,29.384935260285015,29.22528174124083,29.065628222196633,28.905974703152456,28.75312906714727,28.606690948305726,28.460252829464196,28.313814710622665,28.16737659178112,28.020938472939577,27.874500354098053,27.728062235256512,27.581624116414964,27.43518599757343,27.2887478787319,27.142309759890352,26.995871641048822,26.849433522207292,26.70299540336574,26.556557284524203,26.41011916568268,26.263681046841135,26.11724292799959,25.970804809158057,25.824366690316527,25.67792857147498,25.508354192103024,25.223098510078838,24.93784282805465,24.65258714603046,24.367331464006327,24.08207578198214,23.79682009995795,23.51156441793382,23.228260376064267,22.945089164458167,22.661917952852118,22.37874674124601,22.095575529639913,21.812404318033813,21.529233106427764,21.246061894821658,20.962890683215555,20.679719471609506,20.396548260003406,20.113377048397304,19.83020583679125,19.54703462518515,19.26386341357905,18.980692201973,18.6975209903669,18.414349778760798,18.131178567154695,17.848007355548646,17.564836143942543,17.28166493233644,16.998493720730394,16.715322509124288,16.43215129751819,16.14898008591214,15.865808874306035,15.582637662699932,15.299466451093831,15.016295239487782,14.73312402788168,14.449952816275578,14.166781604669527,13.883610393063426,13.663497185248232,13.488425408712274,13.313353632176288,13.138281855640301,12.963210079104343,12.788138302568353,12.613066526032362,12.437994749496372,12.262922972960418,12.087851196424428,11.912779419888437,11.737707643352483,11.562635866816493,11.387564090280502,11.212492313744546,11.037420537208558,10.862348760672567,10.687276984136577,10.512205207600623,10.337133431064633,10.162061654528642,9.986989877992688,9.811918101456698,9.636846324920707,9.46177454838475,9.286702771848761,9.111630995312773,8.936559218776814,8.761487442240826,8.586415665704838,8.411343889168847,8.236272112632891,8.061200336096901,7.886128559560912,7.710065598075046,7.530691624505463,7.351317650935881,7.171943677366332,6.9925697037967485,6.813195730227166,6.633821756657583,6.454447783088034],[27.40152197537514,27.434885057143624,27.46824813891211,27.501611220680594,27.53497430244908,27.568337384217564,27.60170046598605,27.635063547754534,27.66842662952302,27.701789711291507,27.735152793059992,27.768515874828477,27.801878956596962,27.835242038365447,27.868605120133935,27.90196820190242,27.935331283670905,27.96869436543939,28.002057447207875,28.03542052897636,28.068783610744845,28.10214669251333,28.135509774281815,28.168872856050303,28.202235937818784,28.235599019587273,28.268962101355758,28.302325183124243,28.33568826489273,28.367061037101067,28.3980357456086,28.429010454116128,28.459985162623656,28.490959871131185,28.52193457963871,28.55290928814624,28.583883996653768,28.614858705161296,28.645833413668825,28.676808122176354,28.707782830683882,28.738757539191404,28.76973224769894,28.800706956206465,28.831681664713994,28.862656373221526,28.89363108172905,28.924605790236583,28.95558049874411,28.986555207251634,29.017529915759166,29.048504624266688,29.079479332774223,29.11045404128175,29.141428749789274,29.172403458296806,29.20337816680433,29.234352875311863,29.26532758381939,29.296302292326914,29.327277000834446,29.35825170934197,29.389226417849503,29.42020112635703,29.451175834864557,29.482150543372086,29.513125251879615,29.544099960387143,29.575074668894672,29.6060493774022,29.63702408590973,29.667998794417255,29.698973502924783,29.729948211432312,29.76092291993984,29.79189762844737,29.822872336954894,29.853847045462423,29.884821753969952,29.91579646247748,29.94677117098501,29.977745879492538,30.008720588000063,30.039695296507595,30.069875361565195,30.099896497932818,30.129917634300437,30.159938770668056,30.18995990703568,30.219981043403298,30.250002179770917,30.28002331613854,30.31004445250616,30.34006558887378,30.3700867252414,30.40010786160902,30.43012899797664,30.46015013434426,30.490171270711883,30.5201924070795,30.55021354344712,30.58023467981474,30.61025581618236,30.640276952549982,30.6702980889176,30.70031922528522,30.730340361652843,30.760361498020462,30.79038263438808,30.820403770755703,30.85042490712332,30.88044604349094,30.910467179858564,30.940488316226183,30.970509452593802,31.00053058896142,31.030551725329044,31.060572861696663,31.090593998064282,31.120615134431905,31.150636270799524,31.180657407167146,31.210678543534762,31.240699679902384,31.270720816270003,31.300741952637622,31.330763089005245,31.360784225372868,31.390805361740483,31.420826498108106,31.45084763447573,31.480868770843347,31.510889907210966,31.54091104357859,31.570932179946205,31.60095331631382,31.63097445268145,31.660995589049065,31.691016725416688,31.72276731043478,31.754863783628625,31.786960256822468,31.819056730016317,31.85115320321016,31.88324967640401,31.915346149597855,31.947442622791705,31.97953909598555,32.01163556917939,32.04373204237324,32.07582851556709,32.10792498876093,32.140021461954774,32.17211793514862,32.20421440834247,32.23631088153631,32.268407354730165,32.30050382792401,32.33260030111786,32.3646967743117,32.39679324750555,32.428889720699395,32.46098619389324,32.49308266708709,32.52517914028094,32.55727561347478,32.589372086668625,32.623697153434925,32.65913651698743,32.69457588053995,32.73001524409246,32.765454607644976,32.800893971197496,32.83633333475,32.87177269830252,32.907212061855034,32.94265142540755,32.97809078896007,33.01353015251257,33.04896951606509,33.08440887961761,33.119848243170125,33.15528760672264,33.19072697027515,33.22616633382766,33.261605697380176,33.297045060932696,33.3324844244852,33.36792378803772,33.403363151590234,33.43880251514275,33.47424187869527,33.50968124224778,33.54512060580029,33.580559969352805,33.61599933290532,33.65143869645783,33.68687806001034,33.72231742356287,33.757756787115376,33.79319615066789,33.82863551422041,33.86407487777292,33.899514241325434,33.93495360487795,33.97039296843046,34.00583233198297,34.04127169553549,34.076711059088005,34.11076416381713,34.14461189432787,34.17845962483862,34.21230735534935,34.246155085860096,34.28000281637084,34.313850546881575,34.34769827739232,34.38154600790306,34.4153937384138,34.44924146892454,34.48308919943528,34.51693692994601,34.550784660456756,34.5846323909675,34.61848012147824,34.65232785198898,34.686175582499715,34.72002331301046,34.7538710435212,34.78771877403194,34.82156650454268,34.85541423505342,34.88926196556416,34.923109696074896,34.95695742658564,34.99080515709638,35.02465288760712,35.05850061811786,35.092348348628605,35.12619607913934,35.160043809650084,35.19389154016082,35.22773927067156,35.261587001182306,35.29543473169305,35.329282462203786,35.36313019271452,35.396977923225265,35.430825653736,35.464673384246744,35.50373720287526,35.54801710962154,35.592297016367816,35.63657692311409,35.680856829860375,35.72513673660666,35.76941664335294,35.81369655009922,35.8579764568455,35.902256363591775,35.94653627033806,35.99081617708434,36.035096083830624,36.07937599057691,36.12365589732318,36.167935804069465,36.21221571081574,36.256495617562024,36.3007755243083,36.34505543105458,36.389335337800865,36.43361524454715,36.477895151293424,36.52217505803971,36.56645496478599,36.610734871532266,36.65501477827855,36.69929468502483,36.74357459177111,36.78785449851739,36.83213440526367,36.876414312009956,36.920694218756225,36.96497412550251,37.00925403224879,37.05353393899507,37.09781384574135,37.14209375248763,37.186373659233915,37.23065356598019,37.274933472726474,37.31921337947275,37.36349328621903,37.407773192965315,37.4520530997116,37.496333006457874,37.54061291320416,37.58489281995044,37.629172726696716,37.67345263344299,37.717732540189274,37.76201244693555,37.80629235368183,37.85057226042812,37.894852167174406,37.939132073920675,37.98341198066696,38.02769188741324,38.07197179415952,38.1162517009058,38.16053160765208,38.204463526381545,38.247152639141184,38.28984175190082,38.33253086466046,38.3752199774201,38.41790909017974,38.46059820293939,38.503287315699026,38.545976428458665,38.58866554121831,38.63135465397795,38.67404376673758,38.716732879497236,38.75942199225687,38.80211110501651,38.844800217776154,38.88748933053579,38.93017844329544,38.97286755605507,39.01555666881472,39.058245781574364,39.100934894333996,39.076176463159,38.916522944114824,38.75686942507065,38.59721590602645,38.437562386982265,38.27790886793808,38.11825534889389,37.958601829849684,37.79894831080553,37.63929479176133,37.47964127271713,37.31998775367295,37.16033423462876,37.000680715584565,36.841027196540395,36.68137367749621,36.52172015845201,36.36206663940782,36.202413120363644,36.042759601319446,35.88310608227525,35.72345256323107,35.56379904418689,35.40414552514268,35.24449200609851,35.08483848705433,34.92518496801013,34.765531448965945,34.60587792992176,34.44622441087756,34.28657089183337,34.1269173727892,33.96726385374501,33.80761033470081,33.64795681565663,33.48830329661244,33.328649777568245,33.16899625852407,33.00934273947989,32.84968922043569,32.69003570139151,32.530382182347324,32.370728663303126,32.21107514425893,32.05142162521474,31.891768106170574,31.732114587126375,31.57246106808219,31.412807549038007,31.25315402999381,31.089002076548816,30.914815217299807,30.740628358050785,30.56644149880176,30.392254639552768,30.21806778030375,30.04388092105473,29.869694061805717,29.695507202556712,29.52132034330769,29.347133484058677,29.172946624809672,28.99875976556065,28.824572906311644,28.650386047062632,28.476199187813613,28.302012328564594,28.1278254693156,27.953638610066577,27.779451750817557,27.60526489156855,27.43107803231954,27.256891173070517,27.08270431382151,26.9085174545725,26.73433059532348,26.56014373607446,26.385956876825464,26.21177001757644,26.037583158327422,25.863396299078413,25.689209439829405,25.515022580580382,25.32281249267558,25.040486261491683,24.75816003030779,24.47583379912389,24.193507567940046,23.91118133675615,23.628855105572256,23.346528874388405,23.064202643204514,22.781876412020615,22.499550180836767,22.217223949652873,21.934897718468974,21.65257148728508,21.370245256101235,21.087919024917337,20.80559279373344,20.523266562549598,20.2409403313657,19.9586141001818,19.676287868997957,19.39396163781406,19.111635406630164,18.82930917544632,18.54698294426242,18.26465671307853,17.98233048189463,17.700004250710784,17.41767801952689,17.13535178834299,16.853025557159146,16.570699325975248,16.288373094791353,16.00604686360751,15.72372063242361,15.441394401239714,15.159068170055818,14.876741938871973,14.594415707688075,14.312089476504179,14.030157981440102,13.751367708850578,13.536493402127205,13.367008785496058,13.19298113719918,13.018953488902305,12.84492584060546,12.670898192308584,12.496870544011706,12.32284289571483,12.148815247417986,11.97478759912111,11.800759950824233,11.626732302527387,11.45270465423051,11.278677005933636,11.104649357636792,10.930621709339912,10.756594061043039,10.582566412746162,10.408538764449318,10.23451111615244,10.060483467855562,9.88645581955872,9.712428171261843,9.538400522964965,9.36437287466812,9.190345226371246,9.016317578074368,8.842289929777522,8.668262281480647,8.49423463318377,8.320206984886894,8.146179336590048,7.972151688293172,7.798124039996296,7.62409639169945,7.450068743402575,7.276041095105699,7.102013446808854,6.927985798511977,6.7539581502151,6.579930501918224,6.405902853621379],[27.84216039864434,27.875523480412827,27.90888656218131,27.942249643949793,27.975612725718282,28.00897580748677,28.042338889255255,28.07570197102374,28.109065052792225,28.14242813456071,28.175791216329195,28.20915429809768,28.242517379866165,28.27588046163465,28.309243543403138,28.342606625171623,28.375969706940108,28.409332788708593,28.442695870477078,28.476058952245566,28.50942203401405,28.542785115782536,28.576148197551017,28.609511279319506,28.64287436108799,28.676237442856475,28.70960052462496,28.742963606393445,28.776326688161934,28.809689769930415,28.843052851698907,28.87641593346739,28.909779015235873,28.94314209700436,28.976505178772843,29.00986826054133,29.043231342309813,29.076594424078305,29.109957505846786,29.143320587615275,29.176683669383756,29.21004675115224,29.24340983292073,29.276772914689214,29.3101359964577,29.34270295399434,29.37367766250187,29.404652371009398,29.435627079516927,29.466601788024455,29.497576496531984,29.528551205039513,29.55952591354704,29.59050062205457,29.62147533056209,29.65245003906962,29.68342474757715,29.714399456084678,29.74537416459221,29.776348873099735,29.807323581607267,29.838298290114793,29.869272998622325,29.90024770712985,29.93122241563738,29.962197124144907,29.993171832652433,30.02414654115996,30.05512124966749,30.08609595817502,30.117070666682547,30.148045375190073,30.1790200836976,30.20999479220513,30.24096950071266,30.271944209220187,30.302918917727716,30.333893626235245,30.364868334742773,30.395843043250302,30.42681775175783,30.457792460265356,30.488767168772885,30.519741877280413,30.549921942338013,30.57994307870564,30.60996421507326,30.639985351440878,30.6700064878085,30.700027624176116,30.73004876054374,30.76006989691136,30.79009103327898,30.820112169646602,30.850133306014218,30.88015444238184,30.91017557874946,30.940196715117082,30.9702178514847,31.00023898785232,31.030260124219943,31.06028126058756,31.09030239695518,31.120323533322804,31.15034466969042,31.18036580605804,31.210386942425664,31.24040807879328,31.270429215160906,31.30045035152852,31.33047148789614,31.360492624263763,31.390513760631386,31.420534896999,31.450556033366624,31.480577169734246,31.510598306101862,31.540619442469485,31.570640578837107,31.600661715204723,31.630682851572345,31.660703987939968,31.69141690341343,31.723513376607276,31.755609849801125,31.787706322994964,31.819802796188817,31.851899269382663,31.88399574257651,31.916092215770355,31.9481886889642,31.980285162158047,32.01238163535189,32.04447810854574,32.076574581739585,32.10867105493343,32.140767528127284,32.17286400132113,32.20496047451498,32.23705694770882,32.26915342090267,32.301249894096514,32.33334636729036,32.36544284048421,32.39753931367805,32.4296357868719,32.461732260065745,32.49382873325959,32.52592520645344,32.55802167964728,32.59011815284113,32.622214626034975,32.65431109922882,32.68640757242267,32.71850404561652,32.75060051881036,32.782696992004205,32.81479346519806,32.846889938391904,32.87898641158574,32.91108288477959,32.943179357973435,32.97527583116728,33.00737230436113,33.03946877755497,33.07156525074882,33.103661723942665,33.137986790708965,33.17342615426148,33.20886551781399,33.2443048813665,33.279744244919016,33.315183608471536,33.35062297202405,33.38606233557656,33.42150169912908,33.456941062681594,33.49238042623411,33.52781978978662,33.56325915333913,33.598698516891645,33.634137880444165,33.66957724399668,33.70501660754919,33.74045597110171,33.77589533465422,33.811334698206736,33.84677406175924,33.88221342531176,33.917652788864274,33.95309215241679,33.988531515969306,34.02397087952182,34.05941024307433,34.094849606626845,34.130288970179365,34.16572833373188,34.20116769728439,34.2366070608369,34.272046424389416,34.30748578794193,34.34292515149445,34.378364515046954,34.41380387859948,34.449243242151994,34.4846826057045,34.52012196925702,34.55556133280953,34.591000696362045,34.62644005991456,34.66187942346707,34.69731878701958,34.7327581505721,34.76819751412462,34.803636877677135,34.83907624122965,34.87451560478216,34.909954968334674,34.94539433188719,34.9808336954397,35.01627305899222,35.05171242254473,35.08715178609724,35.12259114964976,35.15803051320228,35.19346987675479,35.2289092403073,35.264348603859816,35.29978796741233,35.33522733096484,35.37066669451736,35.406106058069874,35.441545421622386,35.47636867051692,35.51021640102766,35.5440641315384,35.57791186204914,35.61175959255988,35.64560732307062,35.679455053581364,35.7133027840921,35.74715051460284,35.78099824511358,35.814845975624316,35.848693706135066,35.8825414366458,35.916389167156545,35.95023689766728,35.984084628178024,36.01793235868876,36.056996177317274,36.10127608406356,36.14555599080983,36.189835897556115,36.2341158043024,36.278395711048674,36.32267561779496,36.36695552454124,36.41123543128752,36.4555153380338,36.49979524478008,36.544075151526364,36.58835505827264,36.632634965018916,36.6769148717652,36.72119477851148,36.76547468525776,36.80975459200404,36.85403449875032,36.898314405496606,36.94259431224289,36.98687421898917,37.03115412573545,37.07543403248172,37.11971393922801,37.16399384597428,37.208273752720565,37.252553659466855,37.296833566213124,37.34111347295941,37.38539337970568,37.42967328645197,37.47395319319825,37.51823309994453,37.56251300669081,37.60679291343709,37.651072820183366,37.69535272692965,37.73963263367593,37.78391254042221,37.8281924471685,37.872472353914766,37.91675226066105,37.96103216740733,38.005312074153615,38.04959198089989,38.093871887646166,38.13815179439245,38.18243170113873,38.22671160788501,38.27099151463129,38.315271421377574,38.35955132812385,38.40383123487014,38.44811114161642,38.49239104836269,38.536670955108974,38.58095086185526,38.62523076860154,38.669510675347816,38.7137905820941,38.75807048884038,38.80235039558666,38.84663030233294,38.89091020907922,38.9351901158255,38.97947002257178,39.023749929318065,39.06802983606433,39.112309742810616,39.1565896495569,39.200869556303175,39.245149463049465,39.28942936979575,39.333709276542024,39.378172065874864,39.422708011535136,39.467243957195414,39.51177990285568,39.55631584851595,39.60085179417623,39.6453877398365,39.68992368549677,39.65745218845668,39.47096580601592,39.284479423575156,39.09799304113438,38.911506658693625,38.730486805416874,38.55629994616785,38.38211308691882,38.20792622766983,38.03373936842081,37.859552509171785,37.68536564992278,37.511178790673775,37.33699193142475,37.16280507217574,36.98861821292673,36.81443135367771,36.64024449442871,36.4660576351797,36.291870775930676,36.11768391668165,35.94349705743265,35.76931019818364,35.59512333893461,35.42093647968561,35.246749620436596,35.072562761187584,34.89837590193857,34.72418904268957,34.55000218344054,34.37581532419152,34.20162846494253,34.02744160569351,33.85325474644448,33.67906788719548,33.50488102794647,33.33069416869745,33.15650730944844,32.982320450199424,32.808133590950405,32.6339467317014,32.459759872452395,32.28557301320337,32.11138615395435,31.937199294705337,31.763012435456336,31.588825576207313,31.414638716958308,31.240451857709296,31.066264998460273,30.89207813921127,30.71789127996226,30.543704420713237,30.369517561464214,30.195330702215223,30.021143842966197,29.846956983717178,29.672770124468173,29.498583265219168,29.324396405970138,29.150209546721133,28.976022687472128,28.801835828223105,28.6276489689741,28.453462109725088,28.27927525047607,28.105088391227046,27.930901531978055,27.756714672729032,27.582527813480013,27.408340954230994,27.234154094981996,27.059967235732966,26.885780376483964,26.71159351723496,26.537406657985933,26.363219798736907,26.189032939487916,26.0148460802389,25.840659220989874,25.66647236174087,25.49228550249186,25.318098643242838,25.125888555338033,24.843562324154135,24.56123609297024,24.278909861786342,23.996583630602498,23.7142573994186,23.43193116823471,23.14960493705086,22.867278705866966,22.584952474683064,22.302626243499223,22.020300012315328,21.737973781131426,21.455647549947532,21.17332131876369,20.890995087579793,20.608668856395894,20.32634262521205,20.044016394028155,19.761690162844253,19.47936393166041,19.197037700476514,18.91475594363123,18.635965671041763,18.357175398452235,18.078385125862717,17.79959485327319,17.52080458068372,17.2420143080942,16.963224035504673,16.684433762915205,16.40564349032568,16.12685321773616,15.848062945146687,15.569272672557164,15.29048239996764,15.011692127378119,14.732901854788647,14.454111582199126,14.175321309609602,13.89653103702013,13.617740764430607,13.402866457707233,13.23364641231684,13.064426366926414,12.89520632153599,12.725986276145598,12.556766230755173,12.387546185364744,12.218326139974321,12.049106094583927,11.879886049193502,11.710666003803077,11.54144595841268,11.372225913022255,11.20300586763183,11.033785822241436,10.864565776851013,10.695345731460586,10.526125686070161,10.356905640679766,10.186944796877894,10.012917148581016,9.838889500284171,9.664861851987297,9.49083420369042,9.316806555393574,9.142778907096698,8.968751258799822,8.794723610502977,8.6206959622061,8.446668313909225,8.272640665612348,8.098613017315504,7.924585369018625,7.7505577207217495,7.576530072424905,7.402502424128029,7.228474775831151,7.054447127534306,6.880419479237432,6.706391830940553,6.532364182643677,6.358336534346833],[28.28279882191354,28.316161903682026,28.34952498545051,28.382888067218996,28.416251148987484,28.44961423075597,28.48297731252445,28.51634039429294,28.549703476061428,28.583066557829913,28.616429639598397,28.64979272136688,28.683155803135364,28.716518884903852,28.749881966672337,28.783245048440826,28.81660813020931,28.849971211977795,28.88333429374628,28.916697375514765,28.95006045728325,28.983423539051735,29.01678662082022,29.050149702588705,29.083512784357193,29.116875866125675,29.150238947894163,29.183602029662648,29.216965111431133,29.25032819319962,29.283691274968106,29.31705435673659,29.350417438505076,29.38378052027356,29.417143602042046,29.45050668381053,29.483869765579016,29.517232847347504,29.55059592911599,29.583959010884474,29.61732209265296,29.650685174421444,29.68404825618993,29.717411337958413,29.7507744197269,29.784137501495383,29.81750058326387,29.850863665032357,29.884226746800838,29.917589828569326,29.95095291033781,29.984315992106296,30.01767907387478,30.05104215564327,30.084405237411755,30.11776831918024,30.151131400948724,30.184494482717213,30.217857564485694,30.251220646254183,30.284583728022668,30.317946809791152,30.349319579395132,30.380294287902657,30.411268996410186,30.442243704917715,30.473218413425244,30.504193121932772,30.535167830440297,30.566142538947826,30.597117247455355,30.628091955962883,30.659066664470412,30.690041372977937,30.721016081485473,30.751990789992995,30.782965498500527,30.813940207008056,30.844914915515584,30.87588962402311,30.906864332530642,30.937839041038167,30.968813749545696,30.999788458053224,31.029968523110824,31.05998965947845,31.09001079584607,31.120031932213685,31.15005306858131,31.180074204948927,31.210095341316546,31.24011647768417,31.270137614051787,31.300158750419413,31.33017988678703,31.360201023154648,31.39022215952227,31.42024329588989,31.45026443225751,31.48028556862513,31.51030670499275,31.540327841360373,31.570348977727992,31.60037011409561,31.630391250463234,31.660412386830853,31.692162969585922,31.72425944277977,31.756355915973614,31.78845238916746,31.820548862361306,31.852645335555152,31.884741808749,31.91683828194285,31.948934755136698,31.981031228330544,32.01312770152438,32.04522417471823,32.077320647912074,32.10941712110592,32.141513594299774,32.17361006749362,32.205706540687466,32.23780301388131,32.26989948707516,32.301995960269004,32.33409243346285,32.366188906656696,32.398285379850535,32.430381853044395,32.462478326238234,32.49457479943209,32.526671272625926,32.55876774581977,32.59086421901362,32.622960692207464,32.65505716540131,32.68715363859516,32.71925011178901,32.751346584982855,32.7834430581767,32.81553953137055,32.84763600456439,32.87973247775824,32.911828950952085,32.94392542414593,32.97602189733978,33.00811837053362,33.04021484372747,33.072311316921315,33.10440779011516,33.13650426330901,33.16860073650285,33.2006972096967,33.232793682890545,33.26489015608439,33.29698662927824,33.32908310247208,33.36117957566593,33.393276048859775,33.42537252205362,33.45746899524747,33.48956546844132,33.52166194163516,33.55375841482901,33.58585488802286,33.617951361216704,33.652276427983,33.68771579153551,33.72315515508802,33.758594518640535,33.79403388219305,33.82947324574557,33.864912609298074,33.90035197285059,33.935791336403106,33.97123069995562,34.00667006350814,34.04210942706065,34.077548790613164,34.11298815416568,34.14842751771819,34.18386688127071,34.21930624482322,34.254745608375735,34.290184971928255,34.32562433548077,34.361063699033274,34.39650306258579,34.431942426138306,34.46738178969082,34.50282115324334,34.538260516795845,34.573699880348364,34.60913924390088,34.6445786074534,34.68001797100591,34.71545733455842,34.750896698110935,34.78633606166345,34.82177542521596,34.85721478876848,34.89265415232099,34.928093515873506,34.96353287942602,34.99897224297853,35.03441160653105,35.069850970083564,35.10529033363608,35.14072969718859,35.17616906074111,35.211608424293615,35.247047787846135,35.28248715139865,35.31792651495117,35.35336587850367,35.38880524205619,35.4242446056087,35.459683969161226,35.49512333271373,35.53056269626625,35.56600205981876,35.60144142337128,35.63688078692379,35.67232015047631,35.707759514028815,35.743198877581335,35.77863824113384,35.81407760468636,35.84951696823887,35.88495633179139,35.9203956953439,35.95583505889642,35.99127442244893,36.02681765357795,36.062776354704496,36.09873505583104,36.13469375695759,36.17065245808413,36.206611159210674,36.24256986033722,36.27852856146376,36.314487262590305,36.35044596371686,36.3864046648434,36.422363365969936,36.45832206709648,36.49428076822303,36.53023946934957,36.56619817047612,36.60698379851269,36.65259635345927,36.69820890840586,36.74382146335243,36.78943401829903,36.83504657324561,36.8806591281922,36.926271683138786,36.97188423808537,37.01749679303195,37.06310934797854,37.108721902925126,37.15342840159795,37.19796434725823,37.2425002929185,37.28703623857877,37.33157218423904,37.376108129899315,37.42064407555959,37.46518002121986,37.50971596688014,37.55425191254041,37.59878785820068,37.64332380386095,37.68785974952123,37.732395695181495,37.77693164084177,37.82146758650204,37.86600353216232,37.91053947782258,37.95507542348287,37.99961136914314,38.04414731480341,38.08868326046368,38.133219206123954,38.177755151784226,38.2222910974445,38.26682704310477,38.31136298876505,38.35589893442531,38.40043488008559,38.44497082574586,38.489506771406134,38.534042717066406,38.578578662726684,38.623114608386956,38.66765055404723,38.7121864997075,38.75672244536777,38.80125839102804,38.845794336688314,38.890330282348586,38.93486622800886,38.979402173669136,39.023938119329415,39.06847406498967,39.11301001064995,39.15754595631023,39.2020819019705,39.246617847630766,39.291153793291045,39.33568973895132,39.38022568461159,39.42476163027186,39.46929757593213,39.5138335215924,39.558369467252675,39.60290541291295,39.64744135857322,39.69197730423349,39.736513249893775,39.78104919555405,39.82558514121432,39.87012108687459,39.91465703253486,39.959192978195134,40.003728923855405,40.04826486951568,40.09280081517595,40.13733676083623,40.1818727064965,40.22640865215677,40.27094459781705,40.23847310077694,40.05198671833619,39.865500335895426,39.67901395345465,39.492527571013895,39.30604118857313,39.119554806132356,38.93306842369158,38.74658204125083,38.560095658810056,38.37360927636928,38.187122893928525,38.00063651148776,37.81415012904699,37.62766374660623,37.44117736416547,37.25469098172469,37.06820459928393,36.881718216843176,36.695231834402406,36.50874545196162,36.32225906952087,36.135772687080106,35.94928630463933,35.76279992219857,35.576313539757805,35.38982715731703,35.20334077487627,35.01685439243551,34.83036800999473,34.64388162755396,34.45739524511322,34.27090886267244,34.084422480231666,33.897936097790904,33.71144971535015,33.52496333290937,33.33847695046861,33.15199056802785,32.96550418558707,32.77901780314632,32.592531420705555,32.40604503826478,32.219558655824,32.03307227338324,31.846585890942478,31.66009950850171,31.47361312606094,31.287126743620185,31.10064036117941,30.91415397873865,30.72766759629789,30.541181213857115,30.354694831416335,30.168208448975594,29.98172206653482,29.795235684094038,29.608749301653283,29.422262919212525,29.235776536771745,29.049290154330983,28.862803771890228,28.67631738944945,28.48983100700869,28.30334462456793,28.116858242127154,27.930371859686378,27.743885477245637,27.559790735391488,27.385603876142465,27.21141701689346,27.03723015764445,26.86304329839543,26.68885643914642,26.514669579897415,26.34048272064839,26.166295861399373,25.99210900215038,25.817922142901356,25.643735283652333,25.469548424403325,25.29536156515432,25.121174705905293,24.928964618000496,24.646638386816594,24.364312155632696,24.0819859244488,23.799659693264957,23.520563633232896,23.24177336064337,22.9629830880539,22.684192815464375,22.405402542874853,22.12661227028538,21.84782199769586,21.56903172510634,21.290241452516817,21.011451179927345,20.73266090733782,20.4538706347483,20.175080362158827,19.896290089569305,19.61749981697978,19.33870954439031,19.059919271800787,18.781128999211262,18.502338726621794,18.22354845403227,17.944758181442747,17.665967908853222,17.38717763626375,17.108387363674233,16.829597091084707,16.550806818495236,16.27201654590571,15.993226273316191,15.714436000726721,15.435645728137196,15.156855455547673,14.87806518295815,14.59927491036868,14.320484637779154,14.041694365189633,13.762904092600163,13.484113820010638,13.269239513287266,13.100019467896871,12.930799422506446,12.761579377116021,12.592359331725628,12.423139286335203,12.253919240944777,12.084699195554354,11.915479150163957,11.746259104773532,11.577039059383106,11.407819013992711,11.238598968602288,11.06937892321186,10.900158877821468,10.730938832431043,10.561718787040617,10.392498741650192,10.223278696259799,10.054058650869372,9.884838605478947,9.715618560088553,9.546398514698126,9.377178469307703,9.207958423917308,9.038738378526883,8.869518333136456,8.700298287746062,8.531078242355637,8.361858196965212,8.192638151574787,8.023418106184392,7.8541980607939665,7.6849780154035425,7.515757970013148,7.346537924622723,7.177317879232297,7.006880808259763,6.832853159962886,6.658825511666008,6.484797863369133,6.310770215072289],[28.72343724518275,28.756800326951236,28.790163408719717,28.823526490488202,28.85688957225669,28.89025265402518,28.92361573579366,28.956978817562145,28.990341899330634,29.02370498109912,29.057068062867604,29.09043114463609,29.123794226404573,29.157157308173062,29.190520389941547,29.22388347171003,29.257246553478517,29.290609635247,29.323972717015486,29.357335798783975,29.390698880552456,29.42406196232094,29.457425044089426,29.490788125857915,29.524151207626396,29.55751428939488,29.590877371163373,29.624240452931858,29.657603534700343,29.690966616468828,29.724329698237312,29.757692780005797,29.791055861774282,29.824418943542767,29.857782025311252,29.891145107079737,29.924508188848225,29.95787127061671,29.9912343523852,30.024597434153684,30.05796051592217,30.09132359769065,30.12468667945914,30.158049761227623,30.191412842996105,30.224775924764593,30.258139006533078,30.291502088301563,30.324865170070048,30.358228251838533,30.39159133360702,30.424954415375502,30.45831749714399,30.491680578912476,30.525043660680964,30.558406742449446,30.591769824217934,30.62513290598642,30.658495987754904,30.69185906952339,30.725222151291874,30.758585233060362,30.791948314828844,30.82531139659733,30.858674478365817,30.8920375601343,30.925400641902783,30.95876372367127,30.992126805439753,31.025489887208245,31.058852968976726,31.092216050745208,31.1255791325137,31.15894221428218,31.19230529605067,31.225668377819158,31.259031459587643,31.292394541356124,31.324961496288402,31.35593620479593,31.38691091330346,31.417885621810985,31.448860330318514,31.479835038826042,31.510015103883646,31.54003624025127,31.570057376618887,31.600078512986506,31.63009964935413,31.660812562564576,31.692909035758422,31.72500550895227,31.757101982146114,31.789198455339964,31.821294928533803,31.853391401727652,31.8854878749215,31.917584348115344,31.94968082130919,31.981777294503036,32.01387376769688,32.045970240890725,32.07806671408458,32.110163187278424,32.14225966047227,32.174356133666116,32.20645260685996,32.23854908005381,32.27064555324766,32.30274202644151,32.33483849963535,32.3669349728292,32.399031446023045,32.43112791921689,32.46322439241074,32.49532086560458,32.52741733879843,32.559513811992275,32.59161028518612,32.62370675837997,32.65580323157381,32.68789970476766,32.719996177961505,32.75209265115535,32.7841891243492,32.816285597543036,32.84838207073689,32.880478543930735,32.91257501712459,32.94467149031843,32.97676796351227,33.00886443670612,33.040960909899965,33.07305738309381,33.10515385628766,33.1372503294815,33.16934680267535,33.201443275869195,33.23353974906304,33.26563622225689,33.29773269545073,33.32982916864458,33.361925641838425,33.39402211503227,33.426118588226124,33.45821506141997,33.49031153461382,33.52240800780766,33.55450448100151,33.586600954195355,33.6186974273892,33.65079390058305,33.68289037377689,33.71498684697074,33.747083320164585,33.77917979335843,33.81127626655228,33.84337273974613,33.87546921293997,33.90756568613382,33.93966215932767,33.971758632521514,34.00385510571536,34.035951578909206,34.06804805210305,34.1001445252969,34.132240998490744,34.16656606525704,34.20200542880955,34.23744479236206,34.27288415591458,34.30832351946709,34.34376288301961,34.37920224657211,34.41464161012464,34.450080973677146,34.485520337229666,34.520959700782186,34.55639906433469,34.591838427887204,34.627277791439724,34.66271715499223,34.69815651854475,34.73359588209727,34.769450714299104,34.80540941542564,34.8413681165522,34.87732681767874,34.91328551880529,34.94924421993183,34.985202921058374,35.02116162218492,35.05712032331146,35.093079024438005,35.129037725564544,35.16499642669109,35.200955127817636,35.23691382894418,35.27287253007073,35.308831231197274,35.34478993232382,35.38074863345037,35.41670733457691,35.45266603570345,35.48862473682999,35.52458343795654,35.56054213908308,35.59650084020963,35.632459541336175,35.66841824246272,35.70437694358927,35.74033564471581,35.77629434584235,35.81225304696889,35.84821174809544,35.88417044922198,35.92012915034853,35.956087851475075,35.992046552601614,36.02800525372817,36.06396395485471,36.09992265598125,36.13588135710779,36.17184005823434,36.207798759360884,36.24375746048743,36.279716161613976,36.31567486274052,36.35163356386706,36.38759226499361,36.42355096612015,36.45950966724669,36.49546836837324,36.531427069499784,36.56738577062633,36.60334447175288,36.63930317287942,36.67526187400596,36.71122057513251,36.747179276259054,36.7831379773856,36.81909667851214,36.85505537963869,36.89101408076523,36.92697278189177,36.96293148301832,36.99889018414487,37.03484888527141,37.070807586397954,37.1067662875245,37.14755191556107,37.193164470507654,37.23877702545423,37.28438958040082,37.33000213534741,37.375614690293986,37.42122724524057,37.46683980018716,37.51245235513375,37.55806491008033,37.60367746502692,37.649290019973506,37.694902574920086,37.74051512986667,37.786127684813266,37.831740239759846,37.87735279470643,37.92296534965301,37.9685779045996,38.014190459546185,38.05980301449277,38.10541556943936,38.151028124385945,38.19664067933253,38.24225323427912,38.2878657892257,38.333478344172285,38.37909089911887,38.42470345406545,38.47031600901204,38.515928563958624,38.56154111890521,38.60715367385179,38.652766228798384,38.69837878374497,38.74399133869156,38.78960389363813,38.835216448584724,38.880829003531304,38.92644155847789,38.97205411342448,39.017666668371064,39.06327922331764,39.10889177826424,39.154504333210824,39.2001168881574,39.24572944310399,39.29134199805058,39.336954552997156,39.38227930334832,39.4268152490086,39.47135119466887,39.51588714032914,39.56042308598941,39.604959031649685,39.649494977309956,39.69403092297023,39.73856686863051,39.783102814290785,39.82763875995105,39.87217470561133,39.91671065127159,39.96124659693187,40.005782542592144,40.05031848825241,40.09485443391269,40.13939037957295,40.18392632523323,40.2284622708935,40.27299821655377,40.31753416221406,40.362070107874324,40.406606053534595,40.45114199919487,40.49567794485513,40.54021389051542,40.58474983617568,40.62928578183596,40.67382172749623,40.718357673156504,40.76289361881678,40.80742956447705,40.851965510137326,40.81949401309723,40.633007630656465,40.4465212482157,40.26003486577493,40.07354848333417,39.88706210089341,39.70057571845263,39.51408933601186,39.327602953571116,39.14111657113034,38.95463018868956,38.7681438062488,38.581657423808046,38.39517104136727,38.20868465892651,38.02219827648575,37.83571189404498,37.649225511604214,37.46273912916345,37.27625274672268,37.0897663642819,36.90327998184114,36.71679359940038,36.530307216959606,36.34382083451885,36.15733445207809,35.97084806963731,35.78436168719655,35.597875304755796,35.41138892231501,35.224902539874236,35.0384161574335,34.85192977499272,34.66544339255194,34.47895701011119,34.292470627670426,34.10598424522965,33.91949786278889,33.73301148034813,33.546525097907356,33.360038715466594,33.17355233302583,32.987065950585055,32.80057956814428,32.61409318570352,32.42382164900813,32.22135345003103,32.01888525105395,31.816417052076865,31.613948853099764,31.411480654122684,31.209012455145597,31.006544256168496,30.804076057191395,30.60160785821433,30.39913965923723,30.196671460260127,29.994203261283044,29.79173506230596,29.58926686332886,29.386798664351772,29.184330465374693,28.98186226639759,28.77939406742051,28.576925868443425,28.374457669466324,28.17198947048922,27.969521271512157,27.767053072535056,27.564584873557955,27.362116674580875,27.15964847560379,26.957180276626683,26.754712077649607,26.552243878672524,26.34977567969542,26.147307480718318,25.944839281741253,25.742371082764148,25.539902883787054,25.337434684809967,25.134966485832884,24.93249828685578,24.717456236091834,24.439544926393452,24.161633616695077,23.883722306996695,23.605810997298367,23.32789968759998,23.049988377901602,22.772077068203274,22.49416575850489,22.216254448806513,21.93834313910818,21.660431829409802,21.38252051971142,21.104609210013038,20.826697900314713,20.548786590616327,20.27087528091795,19.992963971219616,19.715052661521238,19.43714135182286,19.159230042124527,18.881318732426145,18.603407422727766,18.325496113029434,18.047584803331056,17.769673493632673,17.49176218393429,17.213850874235966,16.935939564537584,16.658028254839202,16.38011694514087,16.10220563544249,15.824294325744109,15.54638301604578,15.2684717063474,14.99056039664902,14.713466515839666,14.440246572292912,14.167026628746113,13.893806685199309,13.620586741652556,13.347366798105751,13.138442283353015,12.975443074881765,12.812443866410486,12.649444657939206,12.486445449467956,12.323446240996676,12.155201295094296,11.986916312345322,11.818631329596382,11.650346346847408,11.482061364098437,11.313776381349495,11.145491398600521,10.97720641585155,10.808921433102608,10.640636450353634,10.472351467604662,10.304066484855689,10.135781502106749,9.967496519357777,9.799211536608805,9.630926553859862,9.46264157111089,9.294356588361916,9.126071605612974,8.957786622864003,8.78950164011503,8.621216657366089,8.452931674617115,8.284646691868144,8.11636170911917,7.948076726370229,7.779791743621257,7.611506760872285,7.443221778123343,7.274936795374369,7.1066518126253975,6.938366829876456,6.770081847127484,6.601796864378511,6.433511881629539,6.265226898880597],[29.158073369302286,29.19143645107077,29.224799532839253,29.258162614607738,29.291525696376226,29.32488877814471,29.358251859913196,29.39161494168168,29.424978023450166,29.45834110521865,29.49170418698714,29.525067268755624,29.55843035052411,29.591793432292597,29.625156514061082,29.658519595829567,29.69188267759805,29.725245759366537,29.758608841135022,29.79197192290351,29.82533500467199,29.858698086440477,29.89206116820896,29.92542424997745,29.95878733174593,29.992150413514416,30.025513495282908,30.058876577051386,30.092239658819878,30.125602740588363,30.158965822356848,30.192328904125333,30.22569198589381,30.259055067662306,30.292418149430787,30.325781231199272,30.35914431296776,30.392507394736242,30.425870476504734,30.459233558273212,30.492596640041704,30.52595972181018,30.559322803578674,30.592685885347155,30.626048967115636,30.65941204888413,30.69277513065261,30.726138212421098,30.759501294189583,30.792864375958064,30.826227457726553,30.859590539495038,30.892953621263526,30.92631670303201,30.9596797848005,30.99304286656898,31.02640594833747,31.059769030105954,31.093132111874436,31.126495193642924,31.15985827541141,31.193221357179898,31.22658443894838,31.259947520716864,31.293310602485352,31.326673684253834,31.36003676602232,31.393399847790807,31.42676292955929,31.46012601132778,31.49348909309626,31.526852174864743,31.560215256633235,31.595519280555838,31.631211495936935,31.666903711318035,31.70259592669913,31.73828814208023,31.77398035746133,31.809672572842427,31.845364788223524,31.88105700360462,31.916749218985718,31.952441434366815,31.986757875065976,32.02079916082876,32.054840446591534,32.08888173235431,32.122923018117085,32.15696430387986,32.191005589642636,32.22504687540542,32.259088161168194,32.29312944693097,32.327170732693745,32.359591339209004,32.39168781240285,32.423784285596696,32.45588075879054,32.48797723198439,32.520073705178234,32.55217017837208,32.584266651565926,32.61636312475978,32.64845959795362,32.68055607114747,32.71265254434132,32.74474901753516,32.77684549072901,32.808941963922855,32.8410384371167,32.87313491031055,32.90523138350439,32.93732785669824,32.969424329892085,33.00152080308593,33.03361727627978,33.06571374947362,33.09781022266747,33.129906695861315,33.16200316905516,33.19409964224901,33.22619611544285,33.25829258863671,33.29038906183055,33.3224855350244,33.354582008218244,33.38667848141209,33.41877495460594,33.45087142779978,33.48296790099363,33.515064374187475,33.54716084738132,33.57925732057517,33.61135379376901,33.64345026696286,33.675546740156705,33.70764321335055,33.7397396865444,33.77183615973824,33.80393263293209,33.836029106125935,33.86812557931978,33.90022205251363,33.93231852570747,33.96441499890132,33.99651147209517,34.02860794528902,34.06070441848286,34.09280089167671,34.124897364870556,34.1569938380644,34.18909031125825,34.221186784452094,34.25328325764594,34.28537973083978,34.31747620403363,34.34957267722748,34.381669150421324,34.41376562361517,34.445862096809016,34.47795857000286,34.510055043196715,34.542151516390554,34.57424798958441,34.60634446277825,34.6384409359721,34.67392198863929,34.71109533104317,34.74826867344704,34.78544201585092,34.822615358254794,34.85978870065867,34.896962043062544,34.93413538546642,34.971308727870294,35.00848207027417,35.045655412678045,35.08282875508191,35.12000209748579,35.15717543988966,35.19434878229354,35.23152212469741,35.26869546710129,35.30586880950516,35.34304215190903,35.380215494312914,35.41738883671678,35.453853635853655,35.489812336980194,35.52577103810674,35.561729739233286,35.59768844035983,35.63364714148638,35.669605842612924,35.70556454373946,35.74152324486601,35.77748194599255,35.813440647119094,35.84939934824564,35.885358049372186,35.92131675049873,35.95727545162528,35.99323415275182,36.02919285387836,36.0651515550049,36.10111025613145,36.137068957257995,36.17302765838454,36.20898635951109,36.24494506063763,36.28090376176418,36.316862462890725,36.35282116401726,36.3887798651438,36.42473856627035,36.460697267396895,36.49665596852344,36.53261466964999,36.568573370776534,36.60453207190308,36.640490773029626,36.676449474156165,36.71240817528271,36.74836687640925,36.7843255775358,36.82028427866234,36.85624297978889,36.892201680915434,36.92816038204198,36.96411908316853,37.000077784295065,37.03603648542161,37.07199518654816,37.1079538876747,37.14391258880124,37.17987128992779,37.215829991054335,37.251788692180874,37.28774739330742,37.323706094433966,37.35966479556052,37.39562349668706,37.431582197813604,37.46754089894015,37.50349960006669,37.539458301193235,37.575417002319774,37.61137570344632,37.64733440457287,37.68812003260943,37.73373258755602,37.779345142502606,37.82495769744919,37.87057025239577,37.91618280734236,37.96179536228894,38.00740791723553,38.05302047218212,38.0986330271287,38.144245582075285,38.18985813702187,38.23547069196846,38.281083246915045,38.32669580186163,38.37230835680821,38.4179209117548,38.46353346670138,38.509146021647965,38.55475857659456,38.600371131541145,38.645983686487725,38.69159624143431,38.7372087963809,38.782821351327485,38.828433906274064,38.87404646122065,38.91965901616724,38.965271571113824,39.01088412606041,39.05649668100699,39.102109235953584,39.147721790900164,39.19333434584675,39.23894690079334,39.284559455739924,39.33017201068651,39.3757845656331,39.42139712057968,39.467009675526256,39.51262223047285,39.55823478541943,39.603847340366016,39.6494598953126,39.69507245025919,39.740685005205776,39.78629756015236,39.83191011509894,39.87752267004553,39.923135224992116,39.9687477799387,40.01436033488528,40.05997288983187,40.105585444778455,40.15119799972505,40.19681055467162,40.242423109618215,40.2880356645648,40.33364821951139,40.37926077445796,40.424873329404555,40.47048588435114,40.51609843929772,40.56171099424431,40.607323549190895,40.65293610413747,40.69854865908406,40.74416121403065,40.78977376897723,40.835386323923814,40.8809988788704,40.92661143381699,40.97222398876357,41.01783654371016,41.06344909865675,41.109061653603334,41.15467420854992,41.2002867634965,41.24589931844309,41.29170115281364,41.338087277082344,41.38447340135105,41.43085952561975,41.39055278170214,41.17686030141199,40.963167821121836,40.74947534083166,40.53578286054151,40.32209038025135,40.10839789996118,39.90059466058658,39.69812646160952,39.49565826263242,39.29319006365531,39.09072186467823,38.88825366570115,38.68578546672404,38.48331726774696,38.280849068769875,38.07838086979278,37.875912670815694,37.67344447183861,37.47097627286151,37.26850807388441,37.066039874907325,36.863571675930245,36.661103476953144,36.45863527797606,36.25616707899898,36.05369888002187,35.85123068104478,35.64876248206771,35.44629428309061,35.2438260841135,35.04135788513644,34.83888968615934,34.63642148718223,34.43395328820515,34.23148508922807,34.02901689025097,33.826548691273885,33.624080492296805,33.4216122933197,33.21914409434261,33.01667589536554,32.814207696388436,32.61173949741133,32.40927129843425,32.20680309945717,32.00433490048006,31.80186670150298,31.599398502525897,31.396930303548796,31.19446210457171,30.99199390559463,30.789525706617532,30.587057507640424,30.384589308663365,30.18212110968626,29.97965291070916,29.777184711732083,29.574716512754993,29.372248313777888,29.169780114800812,28.96731191582373,28.764843716846624,28.56237551786954,28.35990731889246,28.157439119915356,27.95497092093826,27.75250272196119,27.550034522984088,27.347566324006984,27.145098125029904,26.94262992605282,26.74016172707572,26.537693528098632,26.335225329121553,26.13275713014445,25.930288931167347,25.727820732190285,25.52535253321318,25.322884334236083,25.120416135259003,24.917947936281916,24.71547973730481,24.500437686540867,24.222526376842488,23.944615067144106,23.666703757445728,23.3887924477474,23.110881138049017,22.832969828350635,22.555058518652302,22.277147208953927,21.999235899255545,21.721324589557213,21.443413279858834,21.165501970160456,20.887590660462074,20.60967935076374,20.33176804106536,20.05385673136698,19.775945421668652,19.49803411197027,19.222113073508073,18.94889312996132,18.675673186414514,18.402453242867715,18.12923329932096,17.85601335577416,17.582793412227357,17.30957346868055,17.036353525133798,16.763133581586995,16.489913638040193,16.216693694493443,15.94347375094664,15.670253807399838,15.397033863853085,15.123813920306283,14.850593976759479,14.577374033212678,14.304154089665925,14.030934146119122,13.75771420257232,13.484494259025567,13.211274315478764,13.002349800726027,12.839350592254778,12.676351383783496,12.513352175312217,12.350352966840966,12.187353758369689,12.024354549898407,11.861355341427128,11.698356132955878,11.535356924484596,11.372357716013317,11.209358507542067,11.046359299070788,10.883360090599508,10.72036088212826,10.55736167365698,10.394362465185697,10.231363256714417,10.068364048243168,9.90536483977189,9.742365631300608,9.579366422829358,9.416367214358077,9.249443712936916,9.081158730187974,8.912873747439,8.744588764690029,8.576303781941089,8.408018799192114,8.239733816443142,8.07144883369417,7.903163850945228,7.7348788681962555,7.566593885447283,7.398308902698342,7.230023919949369,7.061738937200397,6.893453954451456,6.725168971702483,6.55688398895351,6.3885990062045375,6.220314023455597],[29.589708342870324,29.623071424638802,29.65643450640729,29.68979758817577,29.72316066994426,29.75652375171275,29.789886833481226,29.82324991524972,29.856612997018203,29.889976078786685,29.923339160555173,29.956702242323658,29.990065324092146,30.02342840586063,30.056791487629113,30.0901545693976,30.123517651166082,30.156880732934567,30.19024381470306,30.223606896471544,30.25696997824003,30.29033306000851,30.323696141776995,30.357059223545484,30.39042230531397,30.423785387082454,30.45714846885094,30.490511550619424,30.52387463238791,30.557237714156397,30.590600795924882,30.623963877693367,30.65732695946185,30.690690041230337,30.72405312299882,30.75741620476731,30.79077928653579,30.82414236830428,30.857505450072768,30.89086853184125,30.924231613609734,30.957594695378223,30.990957777146704,31.024320858915196,31.057683940683678,31.09104702245216,31.12441010422065,31.157773185989132,31.191136267757614,31.224499349526106,31.257862431294587,31.291225513063075,31.324588594831557,31.35795167660005,31.39131475836853,31.42467784013702,31.458817297637623,31.494509513018716,31.53020172839981,31.565893943780914,31.601586159162007,31.63727837454311,31.672970589924205,31.7086628053053,31.7443550206864,31.780047236067503,31.8157394514486,31.851431666829697,31.887123882210794,31.92281609759189,31.958508312972988,31.99420052835409,32.02989274373518,32.06558495911628,32.10127717449738,32.13696938987848,32.17266160525958,32.20835382064067,32.24404603602177,32.27973825140287,32.315430466783965,32.35112268216506,32.38681489754616,32.422507112927256,32.45682355362642,32.490864839389204,32.52490612515197,32.558947410914755,32.59298869667753,32.627029982440305,32.66107126820308,32.695112553965856,32.72915383972864,32.763195125491414,32.79723641125419,32.831277697016965,32.86531898277974,32.899360268542516,32.9334015543053,32.967442840068074,33.00148412583085,33.035525411593625,33.0695666973564,33.10360798311918,33.13764926888196,33.17169055464473,33.20573184040751,33.239773126170284,33.27381441193306,33.30785569769584,33.34189698345862,33.37528999657924,33.40738646977309,33.43948294296693,33.47157941616078,33.503675889354625,33.53577236254847,33.56786883574232,33.59996530893616,33.63206178213001,33.664158255323855,33.6962547285177,33.72835120171155,33.76044767490539,33.792544148099246,33.824640621293085,33.85673709448693,33.88883356768078,33.92093004087463,33.953026514068476,33.98512298726232,34.01721946045617,34.049315933650014,34.08141240684385,34.113508880037706,34.14560535323155,34.1777018264254,34.209798299619244,34.24189477281309,34.273991246006936,34.30608771920078,34.33818419239463,34.370280665588474,34.40237713878232,34.43447361197617,34.46657008517002,34.498666558363865,34.53076303155771,34.56285950475156,34.5949559779454,34.62705245113925,34.659148924333095,34.69124539752694,34.72334187072079,34.75543834391463,34.78753481710848,34.819631290302326,34.85172776349617,34.88382423669002,34.91592070988386,34.94801718307771,34.980113656271556,35.0122101294654,35.04430660265925,35.076403075853094,35.10849954904694,35.140596022240786,35.17607707490799,35.213250417311855,35.25042375971573,35.28759710211961,35.32477044452348,35.361943786927355,35.39911712933123,35.436290471735106,35.47346381413898,35.510637156542856,35.54781049894673,35.584983841350606,35.62215718375448,35.65933052615836,35.69650386856223,35.73367721096611,35.77085055336998,35.80802389577385,35.845197238177725,35.88237058058161,35.91954392298547,35.95671726538935,35.99389060779322,36.0310639501971,36.06823729260097,36.105410635004844,36.14258397740872,36.179757319812595,36.21693066221647,36.254104004620345,36.29127734702422,36.328450689428095,36.36562403183197,36.40279737423584,36.43997071663972,36.47714405904359,36.51431740144747,36.551490743851346,36.588664086255214,36.62583742865909,36.663010771062964,36.70018411346684,36.737357455870715,36.77453079827459,36.811704140678465,36.84887748308234,36.88605082548621,36.92322416789008,36.96039751029396,36.997570852697834,37.03474419510171,37.071917537505584,37.10909087990946,37.14510018895146,37.181058890078,37.21701759120455,37.25297629233109,37.28893499345764,37.324893694584176,37.36085239571072,37.39681109683727,37.432769797963815,37.46872849909035,37.5046872002169,37.540645901343446,37.57660460246999,37.61256330359654,37.648522004723084,37.68448070584962,37.72043940697617,37.756398108102715,37.79235680922926,37.82831551035581,37.864274211482346,37.90023291260889,37.93619161373543,37.972150314861985,38.00810901598852,38.04406771711507,38.080026418241616,38.115985119368155,38.1519438204947,38.18790252162125,38.22868814965781,38.2743007046044,38.31991325955099,38.365525814497566,38.41113836944416,38.45675092439074,38.50236347933732,38.54797603428391,38.59358858923049,38.63920114417708,38.68481369912367,38.73042625407026,38.77603880901684,38.821651363963426,38.86726391891001,38.9128764738566,38.95848902880318,39.004101583749765,39.04971413869635,39.09532669364293,39.140939248589525,39.18655180353611,39.232164358482684,39.27777691342928,39.323389468375865,39.36900202332245,39.41461457826903,39.46022713321562,39.505839688162204,39.55145224310879,39.59706479805538,39.642677353001964,39.688289907948544,39.73390246289513,39.77951501784172,39.825127572788304,39.870740127734884,39.91635268268148,39.961965237628064,40.00805510146796,40.05444122573667,40.10082735000538,40.14721347427409,40.19359959854279,40.239985722811504,40.286371847080204,40.33275797134892,40.379144095617626,40.425530219886326,40.471916344155034,40.51830246842374,40.56468859269245,40.61107471696115,40.657460841229856,40.70384696549857,40.75023308976727,40.796619214035985,40.843005338304685,40.88939146257339,40.9357775868421,40.9821637111108,41.02854983537951,41.074935959648215,41.12132208391693,41.16770820818563,41.21409433245433,41.260480456723045,41.30686658099175,41.35325270526045,41.39963882952916,41.446024953797874,41.492411078066574,41.538797202335275,41.58518332660398,41.631569450872696,41.6779555751414,41.724341699410104,41.77072782367881,41.81711394794752,41.863500072216226,41.90988619648493,41.95627232075364,42.00265844502234,41.96235170110474,41.74865922081458,41.534966740524425,41.321274260234254,41.1075817799441,40.89388929965394,40.68019681936377,40.466504339073595,40.25281185878346,40.03911937849329,39.82542689820312,39.61173441791296,39.39804193762281,39.18434945733263,38.97065697704248,38.756964496752325,38.543272016462154,38.329579536172,38.11588705588184,37.90219457559167,37.688502095301494,37.47480961501134,37.26111713472118,37.04742465443101,36.833732174140856,36.6200396938507,36.40634721356053,36.19265473327037,35.978962252980224,35.76526977269005,35.55157729239988,35.337884812109735,35.124192331819565,34.910499851529394,34.69680737123924,34.48311489094908,34.26942241065891,34.055729930368756,33.84203745007861,33.62834496978843,33.41465248949827,33.20096000920812,32.98726752891795,32.77357504862777,32.55988256833761,32.346190088047464,32.13249760775729,31.918805127467134,31.705112647176986,31.49142016688681,31.277727686596652,31.0640352063065,30.85034272601633,30.63665024572615,30.422957765436013,30.20926528514584,29.995572804855666,29.781880324565513,29.56818784427536,29.354495363985194,29.140802883695034,28.92711040340488,28.713417923114708,28.499725442824552,28.286032962534396,28.072340482244222,27.85864800195405,27.644955521663917,27.431263041373743,27.217570561083566,27.003878080793413,26.790185600503257,26.576493120213087,26.362800639922934,26.149108159632778,25.935415679342604,25.721723199052434,25.510802182639313,25.30833398366221,25.105865784685108,24.903397585708028,24.700929386730945,24.49846118775384,24.283419136989895,24.005507827291517,23.730759631176475,23.457539687629673,23.18431974408292,22.911099800536114,22.637879856989315,22.364659913442562,22.091439969895756,21.818220026348953,21.545000082802204,21.271780139255398,20.998560195708595,20.725340252161793,20.452120308615044,20.178900365068237,19.90568042152144,19.632460477974686,19.35924053442788,19.086020590881077,18.812800647334328,18.539580703787525,18.266360760240723,17.99314081669397,17.719920873147167,17.446700929600365,17.173480986053562,16.900261042506806,16.627041098960007,16.3538211554132,16.08060121186645,15.807381268319649,15.534161324772846,15.260941381226095,14.987721437679294,14.714501494132488,14.441281550585686,14.168061607038933,13.89484166349213,13.621621719945328,13.348401776398575,13.075181832851772,12.866257318099034,12.703258109627782,12.540258901156506,12.377259692685227,12.214260484213977,12.051261275742695,11.888262067271416,11.725262858800136,11.562263650328887,11.399264441857607,11.236265233386327,11.073266024915076,10.910266816443798,10.747267607972518,10.584268399501266,10.421269191029985,10.258269982558707,10.095270774087426,9.932271565616176,9.769272357144896,9.606273148673617,9.443273940202367,9.280274731731087,9.117275523259808,8.954276314788558,8.791277106317278,8.628277897845997,8.465278689374747,8.302279480903467,8.139280272432188,7.976281063960907,7.813281855489658,7.650282647018377,7.487283438547097,7.324284230075848,7.161285021604568,6.998285813133289,6.835286604662038,6.672287396190757,6.50928818771948,6.343686130779536,6.175401148030594],[30.021343316438344,30.054706398206832,30.088069479975317,30.121432561743802,30.154795643512287,30.188158725280772,30.221521807049257,30.25488488881774,30.288247970586227,30.321611052354715,30.3549741341232,30.38833721589168,30.421700297660166,30.45506337942866,30.488426461197143,30.521789542965628,30.555152624734113,30.588515706502598,30.621878788271083,30.655241870039568,30.688604951808053,30.721968033576537,30.75533111534502,30.78869419711351,30.822057278881992,30.855420360650477,30.88878344241897,30.92214652418745,30.95550960595594,30.98887268772442,31.02223576949291,31.055598851261394,31.088961933029875,31.122325014798363,31.155688096566845,31.189051178335337,31.222414260103818,31.255777341872307,31.28914042364079,31.322503505409276,31.357807530100487,31.39349974548159,31.42919196086269,31.464884176243785,31.500576391624882,31.536268607005976,31.57196082238708,31.607653037768173,31.64334525314927,31.67903746853037,31.714729683911465,31.750421899292565,31.786114114673662,31.82180633005476,31.85749854543586,31.893190760816953,31.928882976198054,31.96457519157915,32.00026740696025,32.03595962234135,32.07165183772244,32.107344053103546,32.143036268484636,32.17872848386574,32.214420699246844,32.250112914627934,32.28580513000904,32.32149734539013,32.35718956077123,32.39288177615232,32.428573991533426,32.464266206914516,32.49995842229562,32.53565063767672,32.571342853057814,32.60703506843891,32.64272728382001,32.678419499201105,32.71411171458221,32.749803929963306,32.7854961453444,32.8211883607255,32.8568805761066,32.892572791487694,32.92688923218686,32.960930517949635,32.99497180371241,33.029013089475185,33.06305437523797,33.09709566100074,33.13113694676352,33.165178232526294,33.19921951828907,33.23326080405185,33.26730208981463,33.3013433755774,33.33538466134018,33.369425947102954,33.40346723286574,33.437508518628505,33.47154980439129,33.50559109015406,33.53963237591684,33.573673661679614,33.60771494744239,33.64175623320517,33.67579751896795,33.70983880473072,33.743880090493505,33.77792137625627,33.81196266201905,33.84600394778183,33.88004523354461,33.91408651930738,33.94812780507016,33.98216909083293,34.016210376595716,34.050251662358484,34.084292948121266,34.11833423388404,34.15237551964682,34.18641680540959,34.220458091172375,34.254499376935144,34.28854066269792,34.3225819484607,34.35662323422348,34.39066451998625,34.42308512714331,34.45518160033715,34.487278073530995,34.51937454672485,34.551471019918694,34.58356749311253,34.615663966306386,34.64776043950023,34.67985691269408,34.711953385887924,34.74404985908177,34.776146332275616,34.80824280546946,34.84033927866331,34.872435751857154,34.904532225051,34.936628698244846,34.96872517143869,35.00082164463254,35.032918117826384,35.06501459102023,35.09711106421408,35.12920753740793,35.16130401060177,35.193400483795614,35.22549695698946,35.25759343018331,35.28968990337716,35.321786376571005,35.35388284976485,35.3859793229587,35.41807579615254,35.45017226934639,35.482268742540235,35.51436521573408,35.54646168892793,35.57855816212177,35.61065463531562,35.642751108509465,35.678232161176666,35.71540550358054,35.75257884598442,35.78975218838829,35.82692553079216,35.86409887319604,35.90127221559992,35.93844555800379,35.97561890040766,36.012792242811535,36.04996558521541,36.08713892761929,36.12431227002316,36.16148561242703,36.19865895483091,36.235832297234786,36.27300563963866,36.31017898204253,36.347352324446405,36.38452566685028,36.421699009254155,36.45887235165803,36.496045694061905,36.53321903646578,36.570392378869656,36.607565721273524,36.644739063677406,36.68191240608128,36.719085748485156,36.75625909088903,36.7934324332929,36.830605775696775,36.86777911810065,36.904952460504525,36.9421258029084,36.979299145312275,37.01647248771615,37.053645830120026,37.090819172523894,37.12799251492777,37.165165857331644,37.20233919973552,37.239512542139394,37.27668588454327,37.313859226947145,37.35103256935102,37.388205911754895,37.42537925415877,37.46255259656264,37.49972593896652,37.53689928137039,37.57407262377426,37.61124596617814,37.648419308582014,37.68559265098589,37.722765993389764,37.75993933579364,37.797112678197514,37.83428602060139,37.871459363005265,37.90863270540913,37.94580604781301,37.98297939021688,38.02015273262076,38.05732607502463,38.09449941742851,38.131672759832384,38.16884610223626,38.206019444640134,38.243192787044,38.28036612944788,38.31753947185175,38.35471281425563,38.39188615665951,38.42905949906338,38.46623284146725,38.50340618387113,38.540579526275,38.57775286867887,38.61492621108275,38.65209955348662,38.6892728958905,38.72700429465196,38.769392631865564,38.81627377183648,38.86315491180739,38.90995354719711,38.95633967146582,39.00272579573453,39.049111920003234,39.09549804427194,39.14188416854065,39.18827029280936,39.23465641707806,39.28104254134677,39.32742866561547,39.37381478988418,39.420200914152886,39.466587038421586,39.512973162690294,39.559359286959,39.60574541122771,39.65213153549641,39.69851765976512,39.74490378403383,39.79128990830253,39.837676032571245,39.88406215683995,39.93044828110865,39.97683440537736,40.02322052964607,40.069606653914775,40.11599277818348,40.16237890245219,40.2087650267209,40.2551511509896,40.301537275258305,40.34792339952702,40.39430952379572,40.44069564806443,40.487081772333134,40.53346789660184,40.57985402087054,40.626240145139256,40.67262626940796,40.719012393676664,40.76539851794537,40.81178464221408,40.858170766482786,40.90455689075149,40.9509430150202,40.99732913928891,41.043715263557615,41.09010138782632,41.13648751209503,41.18287363636373,41.229259760632445,41.27564588490115,41.322032009169845,41.36841813343856,41.41480425770727,41.461190381975975,41.507576506244675,41.55396263051338,41.60034875478209,41.6467348790508,41.693121003319504,41.73950712758821,41.78589325185691,41.83227937612562,41.878665500394334,41.925051624663034,41.97143774893174,42.017823873200456,42.064209997469156,42.11059612173786,42.156982246006564,42.20336837027527,42.24975449454398,42.296140618812686,42.34252674308139,42.38891286735009,42.4352989916188,42.481685115887515,42.52807124015622,42.57445736442492,42.53415062050732,42.32045814021716,42.10676565992701,41.893073179636836,41.67938069934668,41.465688219056524,41.251995738766354,41.038303258476176,40.82461077818604,40.610918297895864,40.397225817605694,40.18353333731554,39.96984085702539,39.75614837673521,39.54245589644506,39.32876341615491,39.11507093586473,38.90137845557457,38.687685975284424,38.47399349499425,38.26030101470407,38.04660853441391,37.83291605412376,37.619223573833594,37.405531093543445,37.19183861325328,36.97814613296311,36.764453652672955,36.550761172382806,36.33706869209263,36.12337621180245,35.90968373151232,35.69599125122214,35.482298770931976,35.26860629064182,35.054913810351664,34.841221330061494,34.62752884977134,34.41383636948118,34.200143889191004,33.986451408900855,33.76507586476927,33.53404358298414,33.30301130119901,33.07197901941389,32.84094673762878,32.609914455843644,32.37888217405853,32.14784989227342,31.916817610488284,31.68578532870317,31.454753046918057,31.223720765132924,30.992688483347788,30.761656201562698,30.53062391977756,30.299591637992428,30.068559356207313,29.8375270744222,29.60649479263706,29.37546251085195,29.144430229066835,28.913397947281705,28.68236566549659,28.45133338371148,28.22030110192634,27.989268820141206,27.758236538356112,27.527204256570975,27.296171974785842,27.065139693000727,26.834107411215612,26.60307512943048,26.372042847645368,26.141010565860253,25.909978284075116,25.678946002289983,25.447913720504893,25.216881438719756,24.98584915693462,24.75481687514951,24.523784593364393,24.29275231157926,24.0548217039955,23.782399467418337,23.509977230841184,23.23755499426403,22.965132757686927,22.692710521109774,22.420288284532617,22.147866047955517,21.875443811378364,21.603021574801208,21.330599338224104,21.05817710164695,20.785754865069794,20.513332628492645,20.240910391915538,19.96848815533838,19.696065918761228,19.423643682184125,19.15122144560697,18.878799209029815,18.606376972452715,18.333954735875558,18.061532499298405,17.7891102627213,17.516688026144145,17.24426578956699,16.97184355298984,16.699421316412735,16.426999079835582,16.154576843258425,15.882154606681322,15.609732370104167,15.337310133527014,15.070195981948434,14.803350898419463,14.53650581489049,14.269660731361517,14.002815647832598,13.735970564303624,13.469125480774652,13.20228039724573,12.935435313716757,12.732985077888442,12.576531161846315,12.42007724580416,12.263623329762005,12.107169413719877,11.950715497677724,11.79426158163557,11.637807665593414,11.481353749551289,11.323663485541466,11.161456742119043,10.999249998696648,10.837043255274224,10.674836511851801,10.512629768429406,10.350423025006984,10.188216281584559,10.026009538162135,9.863802794739742,9.701596051317319,9.539389307894893,9.3771825644725,9.214975821050077,9.052769077627653,8.890562334205258,8.728355590782835,8.56614884736041,8.403942103938016,8.241735360515593,8.079528617093167,7.917321873670745,7.755115130248351,7.592908386825927,7.430701643403504,7.268494899981109,7.106288156558684,6.944081413136261,6.7818746697138685,6.619667926291443,6.457461182869019,6.2952544394465955,6.133047696024201],[30.452978290006378,30.486341371774863,30.519704453543348,30.553067535311833,30.586430617080318,30.619793698848802,30.653156780617287,30.686519862385776,30.71988294415426,30.75324602592275,30.786609107691234,30.819972189459715,30.8533352712282,30.88669835299669,30.920061434765174,30.953424516533662,30.986787598302147,31.02015068007063,31.053513761839117,31.0868768436076,31.120239925376087,31.15360300714457,31.186966088913053,31.221105547182276,31.256797762563373,31.29248997794447,31.328182193325567,31.363874408706664,31.39956662408776,31.43525883946886,31.47095105484996,31.506643270231056,31.542335485612153,31.57802770099325,31.613719916374347,31.649412131755447,31.685104347136544,31.72079656251764,31.75648877789874,31.792180993279835,31.827873208660932,31.863565424042033,31.89925763942313,31.93494985480423,31.970642070185328,32.006334285566425,32.04202650094753,32.07771871632862,32.113410931709716,32.14910314709082,32.18479536247192,32.220487577853014,32.25617979323411,32.2918720086152,32.327564223996305,32.3632564393774,32.398948654758506,32.434640870139596,32.47033308552069,32.5060253009018,32.54171751628289,32.57740973166399,32.61310194704509,32.648794162426185,32.68448637780728,32.72017859318838,32.755870808569476,32.79156302395058,32.82725523933168,32.862947454712774,32.89863967009387,32.93433188547497,32.970024100856065,33.00571631623716,33.04140853161826,33.077100746999356,33.11279296238045,33.14848517776156,33.18417739314265,33.21986960852375,33.25556182390485,33.291254039285946,33.32694625466705,33.36263847004814,33.396954910747304,33.43099619651008,33.46503748227286,33.49907876803564,33.53312005379841,33.56716133956119,33.601202625323964,33.63524391108675,33.669285196849515,33.7033264826123,33.73736776837507,33.77140905413785,33.80545033990063,33.8394916256634,33.87353291142618,33.90757419718896,33.94161548295173,33.97565676871451,34.00969805447728,34.043739340240066,34.077780626002834,34.11182191176562,34.14586319752839,34.17990448329117,34.21394576905394,34.24798705481672,34.2820283405795,34.316069626342276,34.35011091210505,34.384152197867834,34.4181934836306,34.452234769393385,34.48627605515616,34.520317340918936,34.55435862668171,34.58839991244449,34.62244119820726,34.656482483970045,34.69052376973282,34.724565055495596,34.75860634125837,34.79264762702115,34.82668891278392,34.860730198546705,34.89477148430948,34.928812770072255,34.96285405583503,34.99689534159781,35.03093662736058,35.064977913123364,35.09901919888614,35.133060484648915,35.1671017704117,35.20114305617447,35.23518434193725,35.269225627700024,35.3032669134628,35.337308199225575,35.37134948498835,35.40539077075113,35.43878378451353,35.47088025770738,35.50297673090123,35.53507320409507,35.567169677288916,35.59926615048277,35.631362623676615,35.66345909687046,35.69555557006431,35.72765204325815,35.759748516452,35.791844989645845,35.82394146283969,35.85603793603354,35.88813440922738,35.92023088242123,35.952327355615076,35.98442382880892,36.01652030200277,36.048616775196614,36.08071324839046,36.112809721584306,36.14490619477815,36.18038724744535,36.21756058984923,36.2547339322531,36.29190727465698,36.32908061706085,36.36625395946473,36.403427301868604,36.44060064427248,36.47777398667635,36.51494732908022,36.5521206714841,36.58929401388798,36.62646735629185,36.66364069869572,36.7008140410996,36.73798738350347,36.77516072590735,36.81233406831122,36.8495074107151,36.88668075311897,36.92385409552284,36.96102743792672,36.99820078033059,37.03537412273447,37.07254746513834,37.10972080754222,37.14689414994609,37.18406749234997,37.22124083475385,37.25841417715772,37.295587519561586,37.33276086196547,37.369934204369336,37.407107546773204,37.44428088917709,37.48145423158096,37.51862757398484,37.55580091638871,37.59297425879259,37.63014760119646,37.66732094360033,37.70449428600421,37.74166762840808,37.77884097081196,37.81601431321583,37.853187655619706,37.89036099802358,37.927731301007995,37.96562683546428,38.003522369920574,38.04141790437686,38.07931343883314,38.11720897328943,38.15510450774572,38.19300004220201,38.2308955766583,38.268791111114574,38.30668664557086,38.344582180027146,38.382477714483436,38.42037324893972,38.458268783396,38.49616431785229,38.53405985230858,38.57195538676487,38.60985092122115,38.647746455677435,38.685641990133725,38.72353752459001,38.7614330590463,38.79932859350259,38.83722412795887,38.87511966241515,38.91301519687144,38.95091073132773,38.988806265784014,39.0267018002403,39.064597334696586,39.10249286915287,39.14038840360915,39.17828393806545,39.21617947252173,39.25407500697802,39.296463344191615,39.34334448416253,39.39022562413344,39.43710676410435,39.48398790407526,39.53086904404617,39.577750184017084,39.624631323988,39.671512463958905,39.71839360392981,39.765274743900726,39.81215588387164,39.85903702384255,39.90591816381346,39.952799303784374,39.99968044375528,40.046561583726195,40.09344272369711,40.140323863668016,40.18720500363893,40.234086143609844,40.28096728358076,40.32784842355166,40.37472956352257,40.421610703493485,40.4684918434644,40.5153729834353,40.56225412340622,40.609135263377134,40.65601640334803,40.702897543318954,40.749778683289875,40.79665982326077,40.84354096323168,40.8904221032026,40.9373032431735,40.98418438314442,41.03106552311533,41.07794666308624,41.12482780305716,41.171708943028065,41.21859008299898,41.265471222969886,41.3123523629408,41.359233502911714,41.40611464288261,41.45299578285353,41.49987692282444,41.54675806279536,41.59363920276627,41.64052034273718,41.68740148270808,41.734282622679,41.78116376264991,41.828044902620825,41.874926042591724,41.92180718256264,41.96868832253356,42.015569462504466,42.06245060247538,42.109331742446294,42.1562128824172,42.20309402238811,42.24997516235903,42.29685630232993,42.343737442300835,42.39061858227176,42.43749972224267,42.48438086221358,42.53126200218449,42.578143142155405,42.62502428212631,42.671905422097225,42.71878656206813,42.76566770203904,42.81254884200996,42.85942998198087,42.90631112195178,42.953192261922695,43.0000734018936,43.04728032719584,43.095627499521335,43.14397467184685,43.095847250190765,42.85477064057161,42.61369403095246,42.37261742133328,42.13154081171413,41.89046420209498,41.649387592475804,41.408310982856634,41.167234373237505,40.927413302267,40.69638102048186,40.46534873869674,40.23431645691163,40.003284175126495,39.77225189334138,39.54121961155627,39.31018732977114,39.07915504798602,38.84812276620091,38.61709048441577,38.386058202630636,38.155025920845524,37.92399363906041,37.69296135727528,37.46192907549016,37.23089679370505,36.99986451191991,36.7688322301348,36.53779994834969,36.306767666564554,36.07573538477942,35.84470310299432,35.61367082120919,35.38263853942406,35.151606257638946,34.92057397585383,34.689541694068694,34.458509412283576,34.22747713049847,33.99644484871334,33.76541256692822,33.5343802851431,33.30334800335797,33.072315721572835,32.84128343978772,32.61025115800261,32.37921887621747,32.14818659443236,31.91715431264725,31.686122030862116,31.455089749077004,31.224057467291885,30.993025185506752,30.761992903721616,30.530960621936526,30.29992834015139,30.068896058366253,29.837863776581138,29.606831494796026,29.375799213010893,29.14476693122578,28.913734649440666,28.68270236765553,28.45167008587042,28.220637804085307,27.98960552230017,27.758573240515034,27.52754095872994,27.29650867694481,27.06547639515967,26.83444411337456,26.603411831589447,26.37237954980431,26.141347268019196,25.910314986234084,25.67928270444895,25.44825042266381,25.21721814087872,24.986185859093588,24.755153577308455,24.524121295523337,24.293089013738225,24.062056731953092,23.824126124369325,23.55170388779217,23.279281651215015,23.006859414637862,22.73443717806076,22.462014941483602,22.18959270490645,21.917170468329346,21.644748231752192,21.37232599517504,21.099903758597936,20.82748152202078,20.555059285443626,20.282637048866473,20.01021481228937,19.737792575712213,19.468697063220983,19.201851979692062,18.935006896163088,18.668161812634118,18.401316729105197,18.134471645576223,17.867626562047253,17.60078147851833,17.333936394989358,17.067091311460388,16.800246227931414,16.533401144402493,16.26655606087352,15.999710977344549,15.732865893815628,15.466020810286654,15.199175726757684,14.93233064322876,14.665485559699789,14.398640476170817,14.131795392641845,13.864950309112924,13.59810522558395,13.33126014205498,13.064415058526057,12.797569974997085,12.595119739168767,12.438665823126643,12.282211907084486,12.125757991042333,11.969304075000206,11.812850158958051,11.656396242915898,11.499942326873743,11.343488410831617,11.187034494789463,11.030580578747308,10.874126662705184,10.717672746663025,10.561218830620872,10.404764914578745,10.24831099853659,10.091857082494437,9.93540316645228,9.778949250410156,9.622495334368,9.466041418325846,9.30958750228372,9.153133586241566,8.99667967019941,8.840225754157286,8.683771838115131,8.52403780245161,8.361831059029216,8.199624315606792,8.037417572184369,7.875210828761945,7.71300408533955,7.550797341917128,7.388590598494703,7.226383855072309,7.064177111649886,6.901970368227461,6.739763624805068,6.577556881382645,6.415350137960219,6.253143394537796,6.090936651115402],[30.884613263574412,30.917976345342897,30.95133942711138,30.984702508879867,31.01806559064835,31.05142867241684,31.084791754185325,31.120095779645155,31.15578799502625,31.19148021040735,31.22717242578845,31.262864641169546,31.298556856550647,31.334249071931744,31.36994128731284,31.405633502693938,31.44132571807504,31.477017933456136,31.512710148837233,31.54840236421833,31.584094579599427,31.619786794980524,31.65547901036162,31.69117122574272,31.726863441123818,31.762555656504915,31.798247871886012,31.83394008726711,31.869632302648206,31.905324518029307,31.941016733410404,31.9767089487915,32.0124011641726,32.0480933795537,32.083785594934795,32.11947781031589,32.15517002569699,32.19086224107809,32.22655445645918,32.26224667184028,32.29793888722138,32.33363110260248,32.36932331798357,32.405015533364676,32.44070774874577,32.47639996412687,32.512092179507974,32.547784394889064,32.58347661027016,32.61916882565126,32.654861041032355,32.69055325641345,32.72624547179455,32.761937687175646,32.79762990255675,32.83332211793785,32.869014333318944,32.90470654870004,32.94039876408114,32.97609097946224,33.01178319484333,33.047475410224436,33.083167625605526,33.11885984098663,33.15455205636773,33.190244271748824,33.22593648712992,33.26162870251102,33.297320917892115,33.33301313327321,33.368705348654316,33.404397564035406,33.44008977941651,33.47578199479761,33.511474210178704,33.5471664255598,33.5828586409409,33.618550856322,33.6542430717031,33.6899352870842,33.725627502465294,33.76131971784639,33.79701193322749,33.832704148608585,33.86702058930775,33.901061875070525,33.9351031608333,33.969144446596076,34.00318573235885,34.037227018121634,34.07126830388441,34.105309589647185,34.13935087540996,34.173392161172735,34.20743344693551,34.241474732698286,34.27551601846107,34.309557304223844,34.34359858998663,34.377639875749395,34.41168116151218,34.44572244727495,34.47976373303773,34.51380501880051,34.54784630456328,34.58188759032606,34.61592887608884,34.64997016185161,34.68401144761439,34.718052733377164,34.75209401913994,34.786135304902714,34.82017659066549,34.85421787642827,34.88825916219105,34.92230044795383,34.9563417337166,34.990383019479374,35.02442430524216,35.05846559100493,35.09250687676771,35.12654816253048,35.160589448293265,35.194630734056034,35.228672019818816,35.26271330558159,35.29675459134437,35.33079587710714,35.364837162869925,35.3988784486327,35.432919734395476,35.46696102015825,35.50100230592103,35.5350435916838,35.569084877446585,35.60312616320935,35.637167448972136,35.67120873473491,35.70525002049769,35.73929130626047,35.77333259202324,35.80737387778602,35.841415163548795,35.87545644931157,35.90949773507435,35.94353902083713,35.977580306599904,36.01162159236268,36.045662878125455,36.07970416388824,36.113745449651006,36.14778673541379,36.181828021176564,36.21586930693933,36.249910592702115,36.28395187846489,36.317993164227666,36.35203444999044,36.38607573575322,36.42011702151599,36.45415830727877,36.48657891507761,36.51867538827146,36.55077186146531,36.58286833465915,36.614964807853,36.647061281046845,36.68254233371404,36.719715676117914,36.7568890185218,36.79406236092567,36.83123570332954,36.86840904573342,36.9055823881373,36.94275573054117,36.97992907294505,37.017102415348916,37.05427575775279,37.091449100156666,37.12862244256054,37.16635384182032,37.2042493762766,37.24214491073289,37.28004044518918,37.31793597964546,37.35583151410175,37.393727048558034,37.431622583014324,37.46951811747061,37.50741365192689,37.54530918638318,37.58320472083947,37.62110025529575,37.65899578975204,37.69689132420832,37.73478685866461,37.772682393120895,37.810577927577185,37.84847346203347,37.88636899648976,37.92426453094604,37.96216006540233,38.00005559985861,38.0379511343149,38.075846668771185,38.113742203227474,38.15163773768376,38.18953327214005,38.22742880659633,38.26532434105262,38.3032198755089,38.34111540996519,38.37901094442147,38.41690647887776,38.45480201333405,38.492697547790335,38.530593082246625,38.56848861670291,38.60638415115919,38.64427968561548,38.68217522007176,38.72007075452805,38.75796628898434,38.795861823440625,38.833757357896914,38.8716528923532,38.90954842680948,38.94744396126577,38.98533949572205,39.02323503017835,39.061130564634624,39.09902609909091,39.1369216335472,39.174817168003486,39.21271270245977,39.250608236916065,39.28850377137235,39.32639930582863,39.36429484028492,39.4021903747412,39.44008590919749,39.477981443653775,39.51587697811006,39.55377251256635,39.59166804702264,39.62956358147892,39.6674591159352,39.7053546503915,39.74325018484778,39.781145719304064,39.82353405651766,39.87041519648858,39.917296336459486,39.96417747643039,40.01105861640131,40.05793975637222,40.10482089634313,40.15170203631405,40.198583176284956,40.24546431625586,40.292345456226776,40.33922659619769,40.3861077361686,40.43298887613951,40.479870016110425,40.52675115608133,40.57363229605224,40.62051343602316,40.66739457599407,40.71427571596497,40.761156855935894,40.8080379959068,40.85491913587771,40.90180027584862,40.948681415819536,40.99556255579044,41.04244369576135,41.08932483573227,41.13620597570318,41.183087115674084,41.229968255645005,41.27684939561592,41.32373053558682,41.37061167555773,41.41749281552865,41.46437395549956,41.51125509547047,41.55813623544138,41.60501737541229,41.6518985153832,41.698779655354116,41.74566079532502,41.79254193529594,41.83942307526685,41.886304215237764,41.933185355208664,41.98006649517958,42.02694763515049,42.073828775121406,42.12070991509232,42.16759105506323,42.21447219503413,42.26135333500505,42.30823447497596,42.355115614946875,42.402035083994186,42.450382256319685,42.4987294286452,42.547076600970705,42.595423773296204,42.64377094562171,42.69211811794721,42.74046529027272,42.78881246259822,42.83715963492372,42.88550680724923,42.933853979574735,42.98220115190025,43.030548324225734,43.078895496551254,43.12724266887676,43.17558984120225,43.22393701352776,43.272284185853266,43.32063135817877,43.36897853050427,43.417325702829785,43.465672875155285,43.514020047480784,43.56236721980629,43.6107143921318,43.6590615644573,43.7074087367828,43.65928131512673,43.41820470550758,43.17712809588842,42.93605148626925,42.6949748766501,42.453898267030944,42.212821657411766,41.971745047792595,41.73066843817347,41.489591828554296,41.24851521893512,41.00743860931597,40.76636199969681,40.52528539007764,40.284208780458485,40.04313217083934,39.802055561220165,39.560978951601015,39.31990234198186,39.07882573236269,38.83774912274352,38.59667251312436,38.35559590350521,38.11451929388603,37.873442684266884,37.63236607464773,37.39128946502856,37.15021285540941,36.90913624579026,36.66805963617108,36.4269830265519,36.18590641693278,35.94482980731361,35.70375319769443,35.462676588075276,35.221599978456126,34.98052336883695,34.7394467592178,34.49837014959865,34.25729353997947,34.01621693036032,33.775140320741166,33.534063711121995,33.292987101502824,33.05191049188367,32.81083388226452,32.56975727264534,32.32868066302619,32.08760405340704,31.846527443787867,31.605450834168714,31.364374224549564,31.12329761493039,30.88222100531122,30.641144395692088,30.40006778607291,30.158991176453736,29.917914566834583,29.676837957215433,29.435761347596262,29.19468473797711,28.953608128357956,28.712531518738782,28.47145490911963,28.230378299500483,27.98930168988131,27.74822508026213,27.507148470643003,27.266071861023825,27.02499525140465,26.7839186417855,26.542842032166348,26.301765422547177,26.060688812928028,25.81961220330887,25.578535593689697,25.337458984070526,25.096382374451395,24.85530576483222,24.614229155213046,24.373152545593893,24.11437889879318,23.85468864949326,23.59391281981639,23.3277090882545,23.061505356692614,22.79530162513073,22.529097893568892,22.262894162007004,21.996690430445117,21.73048669888328,21.464282967321395,21.198079235759508,20.93187550419767,20.665057142146118,20.398212058617148,20.131366975088177,19.864521891559253,19.597676808030283,19.33083172450131,19.063986640972388,18.797141557443414,18.530296473914444,18.263451390385523,17.99660630685655,17.72976122332758,17.462916139798654,17.196071056269684,16.929225972740714,16.66238088921174,16.39553580568282,16.12869072215385,15.861845638624875,15.595000555095954,15.328155471566982,15.06131038803801,14.794465304509087,14.527620220980117,14.260775137451143,13.993930053922172,13.727084970393248,13.460239886864278,13.193394803335305,12.926549719806385,12.65970463627741,12.457254400449095,12.300800484406968,12.144346568364814,11.98789265232266,11.831438736280534,11.674984820238379,11.518530904196224,11.362076988154067,11.205623072111944,11.049169156069787,10.892715240027634,10.736261323985508,10.579807407943354,10.423353491901198,10.266899575859071,10.110445659816918,9.953991743774763,9.797537827732608,9.641083911690483,9.484629995648328,9.328176079606173,9.171722163564047,9.015268247521892,8.858814331479739,8.70236041543761,8.545906499395457,8.389452583353302,8.232998667311175,8.076544751269022,7.920090835226866,7.763636919184712,7.607313054749027,7.451483393524933,7.295653732300838,7.139824071076772,6.983994409852677,6.828164748628583,6.672335087404518,6.516505426180423,6.360675764956327,6.204846103732233,6.049016442508168],[31.31088768432102,31.34876975814438,31.386651831967736,31.424533905791098,31.462415979614455,31.500298053437813,31.53818012726117,31.57606220108453,31.613944274907887,31.651826348731248,31.689708422554602,31.72613059018424,31.761822805565338,31.797515020946435,31.83320723632753,31.86889945170863,31.90459166708973,31.940283882470826,31.975976097851923,32.011668313233024,32.047360528614114,32.08305274399521,32.11874495937631,32.15443717475741,32.19012939013851,32.225821605519606,32.2615138209007,32.2972060362818,32.3328982516629,32.368590467043994,32.40428268242509,32.439974897806195,32.475667113187285,32.51135932856839,32.54705154394948,32.58274375933058,32.61843597471168,32.65412819009278,32.689820405473874,32.72551262085497,32.761204836236075,32.79689705161717,32.83258926699827,32.868281482379366,32.90397369776046,32.93966591314156,32.975358128522664,33.01105034390376,33.04674255928485,33.082434774665956,33.118126990047045,33.15381920542815,33.189511420809254,33.225203636190344,33.26089585157144,33.29658806695254,33.332280282333635,33.36797249771474,33.403664713095836,33.439356928476926,33.47504914385803,33.51074135923913,33.546433574620224,33.58212579000133,33.61781800538242,33.65351022076352,33.68920243614461,33.724894651525716,33.76058686690681,33.79627908228791,33.83197129766901,33.867663513050104,33.9033557284312,33.9390479438123,33.974740159193395,34.0104323745745,34.04612458995559,34.081816805336686,34.11750902071779,34.15320123609889,34.188893451479984,34.22458566686108,34.26027788224218,34.295970097623275,34.33028653832244,34.364327824085215,34.39836910984799,34.43241039561077,34.46645168137355,34.500492967136324,34.5345342528991,34.568575538661875,34.60261682442466,34.636658110187426,34.67069939595021,34.704740681712984,34.73878196747576,34.77282325323854,34.80686453900132,34.84090582476409,34.87494711052687,34.908988396289644,34.94302968205242,34.977070967815195,35.01111225357797,35.045153539340745,35.07919482510353,35.1132361108663,35.14727739662908,35.181318682391854,35.21535996815463,35.24940125391741,35.28344253968018,35.31748382544296,35.351525111205746,35.385566396968514,35.41960768273129,35.453648968494065,35.48769025425685,35.521731540019616,35.5557728257824,35.58981411154518,35.62385539730795,35.65789668307073,35.69193796883351,35.72597925459628,35.76002054035906,35.79406182612183,35.828103111884616,35.86214439764739,35.89618568341016,35.93022696917295,35.96426825493572,35.99830954069849,36.032350826461276,36.06639211222405,36.10043339798682,36.1344746837496,36.168515969512384,36.20255725527515,36.23659854103793,36.27063982680071,36.304681112563486,36.338722398326254,36.372763684089044,36.40680496985181,36.44084625561459,36.47488754137737,36.508928827140146,36.54297011290293,36.5770113986657,36.61105268442847,36.645093970191255,36.67913525595403,36.713176541716805,36.74721782747959,36.78125911324236,36.81710957418776,36.85296003560041,36.88881049701306,36.92466095842571,36.960511419838355,36.996361881251005,37.03221234266365,37.0680628040763,37.10391326548895,37.13976372690159,37.1775451518249,37.21629205850354,37.25503896518219,37.29378587186083,37.332532778539466,37.37127968521811,37.41002659189675,37.44877349857539,37.487520405254045,37.52626731193268,37.56501421861132,37.60376112528996,37.6425080319686,37.68125493864724,37.72000184532588,37.75874875200452,37.79749565868316,37.83624256536181,37.87498947204045,37.913736378719086,37.95248328539773,37.99123019207637,38.02997709875501,38.06872400543366,38.1074709121123,38.14621781879094,38.184964725469584,38.22371163214822,38.26185757099066,38.29975310544694,38.33764863990322,38.37554417435951,38.413439708815794,38.45133524327208,38.489230777728366,38.527126312184656,38.56502184664094,38.60291738109723,38.64081291555351,38.6787084500098,38.71660398446609,38.75449951892237,38.792395053378655,38.830290587834945,38.868186122291235,38.90608165674752,38.9439771912038,38.98187272566009,39.01976826011637,39.05766379457266,39.095559329028944,39.13345486348523,39.171350397941524,39.209245932397806,39.247141466854096,39.285037001310386,39.322932535766654,39.36082807022295,39.39872360467923,39.43661913913552,39.47451467359181,39.512410208048095,39.550305742504385,39.58820127696066,39.62609681141696,39.66399234587324,39.70188788032953,39.73978341478581,39.7776789492421,39.815574483698384,39.85347001815467,39.891365552610964,39.929261087067246,39.96715662152353,40.00505215597982,40.04294769043611,40.08084322489239,40.11873875934867,40.15663429380496,40.194529828261246,40.232425362717535,40.27032089717382,40.30821643163011,40.35060476884371,40.397485908814616,40.44436704878553,40.49124818875644,40.53812932872735,40.58501046869826,40.63189160866917,40.678772748640085,40.725653888611006,40.7725350285819,40.81941616855282,40.866297308523734,40.91317844849465,40.96005958846555,41.00694072843646,41.053821868407375,41.10070300837828,41.147584148349196,41.1944652883201,41.241346428291024,41.28822756826193,41.335108708232845,41.38198984820375,41.428870988174666,41.47575212814557,41.522633268116486,41.5695144080874,41.61639554805831,41.66327668802922,41.71015782800013,41.75703896797105,41.80513701311803,41.85348418544353,41.901831357769034,41.95017853009455,41.99852570242005,42.04687287474555,42.09522004707105,42.14356721939656,42.191914391722065,42.24026156404757,42.28860873637307,42.33695590869857,42.385303081024084,42.4336502533496,42.48199742567509,42.5303445980006,42.5786917703261,42.62703894265161,42.67538611497711,42.723733287302615,42.77208045962812,42.82042763195362,42.86877480427913,42.91712197660464,42.96546914893014,43.013816321255646,43.06216349358115,43.11051066590665,43.15885783823215,43.20720501055766,43.255552182883164,43.30389935520867,43.35224652753418,43.400593699859684,43.448940872185176,43.49728804451068,43.545635216836196,43.593982389161695,43.6423295614872,43.69067673381271,43.739023906138215,43.787371078463714,43.83571825078922,43.88406542311473,43.932412595440226,43.98075976776573,44.02910694009123,44.07745411241673,44.125801284742245,44.17414845706775,44.22249562939325,44.27084280171876,44.22271538006268,43.981638770443524,43.740562160824375,43.4994855512052,43.25840894158605,43.01733233196689,42.77625572234772,42.53517911272855,42.29410250310942,42.05302589349024,41.81194928387107,41.570872674251916,41.329796064632774,41.08871945501359,40.84764284539445,40.60656623577529,40.36548962615612,40.12441301653696,39.88333640691781,39.642259797298635,39.401183187679464,39.16010657806031,38.919029968441166,38.67795335882198,38.43687674920284,38.19580013958368,37.95472352996451,37.713646920345354,37.472570310726205,37.23149370110703,36.990417091487856,36.74934048186873,36.50826387224956,36.26718726263039,36.02611065301123,35.78503404339207,35.5439574337729,35.301470731726766,35.041780482426866,34.782090233126944,34.52239998382704,34.26270973452715,34.00301948522722,33.74332923592729,33.4836389866274,33.22394873732749,32.96425848802757,32.704568238727674,32.44487798942777,32.185187740127844,31.925497490827944,31.665807241528046,31.406116992228124,31.146426742928195,30.886736493628323,30.627046244328398,30.367355995028475,30.107665745728575,29.847975496428674,29.58828524712875,29.328594997828848,29.06890474852895,28.80921449922902,28.54952424992912,28.28983400062922,28.030143751329305,27.770453502029376,27.5107632527295,27.251073003429575,26.991382754129653,26.73169250482975,26.47200225552985,26.21231200622993,25.952621756930025,25.692931507630124,25.433241258330202,25.173551009030277,24.913860759730404,24.654170510430475,24.394480261130553,24.134790011830653,23.875099762530752,23.61540951323083,23.354633683553956,23.08842995199207,22.82222622043019,22.5560224888683,22.289818757306463,22.023615025744576,21.75741129418269,21.49120756262085,21.225003831058963,20.95880009949708,20.692596367935245,20.426392636373354,20.160188904811466,19.893985173249582,19.627781441687745,19.361577710125857,19.09537397856397,18.829170247002136,18.56296651544025,18.29676278387836,18.030559052316526,17.76435532075464,17.49815158919275,17.231947857630914,16.965744126069026,16.699540394507142,16.433336662945255,16.167132931383417,15.900929199821528,15.637669451930948,15.377687629106756,15.117705806282512,14.857723983458273,14.59774216063408,14.337760337809836,14.077778514985596,13.817796692161354,13.557814869337161,13.29783304651292,13.037851223688676,12.777869400864484,12.517887578040245,12.3222913985147,12.172684964202523,12.023078529890318,11.873472095578116,11.723865661265936,11.574259226953732,11.424652792641526,11.275046358329323,11.125439924017146,10.975833489704941,10.826227055392737,10.67662062108056,10.527014186768357,10.373091928442943,10.217262267218876,10.06143260599478,9.905602944770687,9.749773283546592,9.593943622322527,9.43811396109843,9.282284299874338,9.126454638650271,8.970624977426176,8.814795316202082,8.658965654978015,8.503135993753922,8.347306332529826,8.191476671305761,8.035647010081666,7.879817348857573,7.723987687633477,7.568158026409411,7.412328365185316,7.256498703961222,7.100669042737156,6.944839381513061,6.789009720288966,6.633180059064902,6.477350397840807,6.321520736616712,6.165691075392617,6.009861414168551],[31.733963065181143,31.771845139004505,31.80972721282786,31.84760928665122,31.885491360474578,31.923373434297936,31.961255508121297,31.999137581944655,32.03701965576801,32.074901729591375,32.11278380341473,32.15066587723809,32.188547951061445,32.226430024884806,32.26431209870816,32.30219417253152,32.340076246354876,32.37795832017824,32.41584039400159,32.45372246782495,32.491604541648314,32.52948661547167,32.56736868929503,32.60525076311839,32.643132836941746,32.68101491076511,32.71889698458846,32.75641408180055,32.79210629718165,32.82779851256275,32.86349072794385,32.899182943324945,32.93487515870604,32.97056737408714,33.006259589468236,33.04195180484933,33.07764402023043,33.11333623561153,33.14902845099263,33.18472066637372,33.22041288175482,33.25610509713592,33.29179731251702,33.327489527898116,33.36318174327921,33.39887395866031,33.43456617404141,33.47025838942251,33.5059506048036,33.541642820184705,33.577335035565795,33.6130272509469,33.648719466328,33.68441168170909,33.72010389709019,33.75579611247129,33.791488327852385,33.82718054323348,33.862872758614586,33.89856497399568,33.93425718937678,33.96994940475788,34.005641620138974,34.04133383552007,34.077026050901175,34.11271826628227,34.14841048166336,34.184102697044466,34.219794912425556,34.25548712780666,34.291179343187764,34.326871558568854,34.36256377394996,34.39825598933105,34.43394820471215,34.46964042009324,34.505332635474346,34.54102485085544,34.57671706623654,34.61240928161764,34.648101496998734,34.68379371237983,34.71948592776093,34.755178143142025,34.78949458384119,34.823535869603965,34.85757715536674,34.89161844112952,34.92565972689229,34.95970101265507,34.99374229841785,35.027783584180625,35.0618248699434,35.095866155706176,35.12990744146896,35.16394872723173,35.19799001299451,35.232031298757285,35.26607258452007,35.30011387028284,35.33415515604562,35.368196441808394,35.40223772757117,35.436279013333944,35.47032029909672,35.5043615848595,35.53840287062228,35.57244415638505,35.60648544214783,35.640526727910604,35.67456801367338,35.70860929943616,35.74265058519893,35.77669187096171,35.810733156724496,35.844774442487264,35.87881572825004,35.912857014012815,35.9468982997756,35.98093958553837,36.01498087130115,36.04902215706392,36.0830634428267,36.11710472858948,36.15114601435226,36.18518730011503,36.21922858587781,36.25326987164058,36.287311157403366,36.32135244316614,36.35539372892892,36.38943501469169,36.42347630045447,36.45751758621724,36.49155887198002,36.5256001577428,36.559641443505576,36.59368272926835,36.62772401503113,36.66176530079391,36.69671117421289,36.73256163562554,36.76841209703819,36.80426255845083,36.84011301986348,36.87596348127613,36.911813942688774,36.947664404101424,36.98351486551407,37.01936532692672,37.05521578833937,37.09106624975201,37.12691671116466,37.16276717257731,37.198617633989954,37.234468095402605,37.270318556815255,37.3061690182279,37.34201947964055,37.37786994105319,37.41372040246584,37.44957086387849,37.485421325291135,37.52127178670378,37.55712224811643,37.592972709529086,37.62882317094173,37.66660459586504,37.70535150254367,37.74409840922232,37.782845315900964,37.821592222579596,37.860339129258236,37.89908603593688,37.93783294261552,37.97657984929416,38.01532675597281,38.05407366265145,38.092820569330094,38.13156747600873,38.17031438268737,38.20906128936601,38.24780819604465,38.2865551027233,38.32530200940194,38.364048916080584,38.40279582275922,38.44154272943786,38.4802896361165,38.51903654279514,38.55778344947379,38.59653035615243,38.63527726283107,38.67402416950971,38.712771076188346,38.75151798286699,38.79026488954563,38.82901179622428,38.86775870290292,38.90650560958156,38.9452525162602,38.983999422938844,39.02274632961748,39.06149323629612,39.10024014297477,39.13898704965341,39.17773395633205,39.21648086301069,39.25522776968933,39.29397467636797,39.33272158304661,39.37146848972526,39.4102153964039,39.44896230308254,39.48770920976117,39.52645611643982,39.56520302311846,39.603949929797096,39.642696836475736,39.68144374315439,39.72019064983303,39.75893755651167,39.79768446319031,39.83643136986895,39.87517827654759,39.91392518322623,39.95267208990487,39.99141899658351,40.03016590326215,40.0689128099408,40.10765971661944,40.14640662329808,40.18515352997672,40.22390043665536,40.262647343334,40.30139425001264,40.34014115669128,40.37888806336993,40.41763497004857,40.45633179939329,40.49422733384958,40.53212286830586,40.57001840276215,40.60791393721844,40.645809471674724,40.683705006131014,40.721600540587296,40.759496075043586,40.79739160949987,40.83528714395615,40.87767548116975,40.92455662114067,40.971437761111574,41.01831890108249,41.0652000410534,41.11208118102431,41.15989176991638,41.20823894224188,41.256586114567384,41.30493328689288,41.3532804592184,41.4016276315439,41.44997480386941,41.49832197619491,41.54666914852042,41.595016320845914,41.64336349317142,41.69171066549693,41.740057837822434,41.78840501014794,41.83675218247344,41.885099354798946,41.933446527124445,41.98179369944995,42.03014087177546,42.07848804410096,42.126835216426464,42.17518238875198,42.22352956107748,42.271876733402976,42.32022390572848,42.36857107805399,42.416918250379496,42.465265422705,42.51361259503051,42.561959767356015,42.610306939681514,42.65865411200702,42.70700128433252,42.75534845665803,42.80369562898353,42.85204280130903,42.90038997363454,42.94873714596004,42.99708431828555,43.04543149061105,43.09377866293656,43.142125835262064,43.19047300758757,43.23882017991308,43.28716735223858,43.33551452456408,43.38386169688958,43.43218171370249,43.48049041579658,43.528799117890664,43.57710781998475,43.62541652207883,43.67372522417292,43.722033926267,43.7703426283611,43.81865133045518,43.86696003254927,43.915268734643355,43.96357743673744,44.01188613883153,44.060194840925625,44.10850354301971,44.15681224511379,44.205120947207874,44.25342964930197,44.301738351396054,44.35004705349014,44.39835575558423,44.44666445767831,44.4949731597724,44.54328186186649,44.59159056396057,44.63989926605466,44.688207968148745,44.736516670242835,44.784825372336925,44.83313407443101,44.77584688012013,44.50736789299943,44.23888890587873,43.970409918758016,43.701930931637314,43.43345194451662,43.1649729573959,42.89649397027517,42.6280149831545,42.35953599603378,42.091057008913054,41.82257802179236,41.55444782796208,41.29475757866216,41.035067329362256,40.775377080062356,40.515686830762434,40.25599658146253,39.99630633216263,39.7366160828627,39.47692583356278,39.21723558426288,38.95754533496299,38.69785508566306,38.43816483636316,38.17847458706326,37.91878433776333,37.65909408846343,37.399403839163526,37.139713589863604,36.88002334056369,36.62033309126381,36.36064284196389,36.100952592663965,35.84126234336406,35.581572094064164,35.321881844764235,35.062191595464334,34.80250134616443,34.54281109686451,34.28312084756461,34.02343059826471,33.76374034896479,33.504050099664866,33.244359850364965,32.98466960106506,32.72497935176514,32.465289102465235,32.20559885316534,31.945908603865412,31.68621835456551,31.42652810526561,31.166837855965692,30.90714760666576,30.64745735736589,30.38776710806596,30.12807685876604,29.868386609466143,29.608696360166242,29.349006110866316,29.089315861566416,28.82962561226652,28.56993536296659,28.310245113666696,28.050554864366788,27.790864615066866,27.531174365766944,27.271484116467068,27.011793867167142,26.75210361786722,26.492413368567313,26.23272311926742,25.973032869967497,25.713342620667593,25.453652371367692,25.19396212206777,24.934271872767845,24.674581623467972,24.414891374168043,24.155201124868118,23.89551087556822,23.63582062626832,23.376130376968394,23.115354547291528,22.84915081572964,22.58294708416775,22.316743352605865,22.05053962104403,21.784335889482144,21.518132157920256,21.25192842635842,20.985724694796534,20.719520963234647,20.45331723167281,20.187113500110925,19.92090976854903,19.65815093636156,19.398169113537367,19.138187290713127,18.878205467888883,18.61822364506469,18.358241822240448,18.098259999416207,17.838278176592016,17.578296353767772,17.318314530943532,17.058332708119337,16.798350885295097,16.538369062470856,16.278387239646612,16.018405416822418,15.758423593998177,15.498441771173935,15.238459948349742,14.978478125525504,14.718496302701261,14.458514479877067,14.198532657052827,13.938550834228586,13.678569011404342,13.41858718858015,13.158605365755909,12.898623542931666,12.638641720107472,12.378659897283232,12.183063717757687,12.033457283445511,11.883850849133308,11.734244414821104,11.584637980508926,11.435031546196722,11.285425111884516,11.135818677572312,10.986212243260134,10.836605808947931,10.686999374635725,10.53739294032355,10.387786506011345,10.238180071699139,10.088573637386963,9.938967203074757,9.789360768762553,9.639754334450348,9.490147900138172,9.340541465825966,9.190935031513762,9.041328597201584,8.89172216288938,8.742115728577176,8.592509294264998,8.442902859952795,8.29329642564059,8.143689991328412,7.994083557016206,7.840662320517954,7.6848326592938605,7.529002998069795,7.373173336845699,7.217343675621605,7.061514014397539,6.905684353173445,6.74985469194935,6.594025030725284,6.438195369501189,6.282365708277095,6.126536047053,5.970706385828935],[32.15703844604126,32.194920519864624,32.23280259368798,32.27068466751133,32.308566741334694,32.346448815158055,32.38433088898141,32.42221296280477,32.46009503662813,32.49797711045149,32.53585918427485,32.5737412580982,32.611623331921564,32.649505405744925,32.68738747956829,32.72526955339164,32.763151627214995,32.80103370103836,32.83891577486172,32.87679784868507,32.914679922508434,32.952561996331795,32.99044407015515,33.02832614397851,33.066208217801865,33.10409029162522,33.14197236544858,33.17985443927194,33.217736513095296,33.25561858691866,33.29350066074202,33.33138273456538,33.369264808388735,33.40714688221209,33.44502895603545,33.48291102985881,33.520793103682166,33.55867517750552,33.59655725132889,33.63443932515224,33.6723213989756,33.71020347279896,33.74808554662232,33.785967620445675,33.822389788797956,33.85808200417906,33.89377421956016,33.929466434941254,33.96515865032235,34.00085086570345,34.036543081084545,34.07223529646564,34.107927511846746,34.14361972722784,34.17931194260894,34.21500415799004,34.250696373371134,34.28638858875223,34.32208080413333,34.357773019514426,34.39346523489553,34.42915745027663,34.464849665657724,34.50054188103882,34.53623409641992,34.57192631180102,34.60761852718211,34.643310742563216,34.679002957944306,34.71469517332541,34.75038738870651,34.786079604087604,34.8217718194687,34.8574640348498,34.893156250230895,34.92884846561199,34.96454068099309,35.000232896374186,35.03592511175529,35.07161732713639,35.107309542517484,35.14300175789858,35.17869397327968,35.214386188660775,35.24870262935994,35.282743915122715,35.31678520088549,35.350826486648266,35.38486777241104,35.418909058173824,35.45295034393659,35.486991629699375,35.52103291546215,35.555074201224926,35.58911548698771,35.62315677275048,35.65719805851326,35.691239344276035,35.72528063003882,35.759321915801586,35.79336320156437,35.827404487327144,35.86144577308992,35.895487058852694,35.92952834461547,35.96356963037825,35.99761091614103,36.0316522019038,36.06569348766658,36.099734773429354,36.13377605919213,36.16781734495491,36.20185863071768,36.23589991648046,36.26994120224324,36.303982488006014,36.33802377376879,36.372065059531565,36.40610634529435,36.44014763105712,36.4741889168199,36.50823020258267,36.54227148834545,36.57631277423802,36.61216323565067,36.648013697063305,36.68386415847596,36.719714619888606,36.755565081301256,36.79141554271391,36.82726600412655,36.8631164655392,36.89896692695184,36.93481738836449,36.97066784977714,37.00651831118979,37.04236877260243,37.07821923401508,37.11406969542773,37.14992015684038,37.185770618253024,37.221621079665674,37.25747154107832,37.29332200249097,37.32917246390362,37.36502292531626,37.40087338672891,37.436723848141554,37.472574309554204,37.508424770966855,37.5442752323795,37.58012569379215,37.6159761552048,37.65182661661744,37.68767707803009,37.723527539442735,37.759378000855385,37.79522846226803,37.83107892368068,37.86692938509333,37.90277984650597,37.93863030791863,37.974480769331265,38.01033123074391,38.046181692156566,38.08203215356921,38.11788261498186,38.15566403990516,38.1944109465838,38.23315785326245,38.271904759941094,38.310651666619734,38.34939857329838,38.38814547997702,38.42689238665565,38.4656392933343,38.50438620001294,38.54313310669158,38.581880013370224,38.62062692004886,38.6593738267275,38.69812073340614,38.73686764008478,38.77561454676342,38.81436145344206,38.85310836012071,38.891855266799354,38.93060217347799,38.96934908015663,39.00809598683527,39.04684289351392,39.08558980019255,39.1243367068712,39.163083613549844,39.201830520228484,39.24057742690712,39.27932433358576,39.3180712402644,39.35681814694305,39.39556505362168,39.434311960300334,39.473058866978974,39.51180577365761,39.55055268033625,39.58929958701489,39.62804649369353,39.66679340037217,39.70554030705082,39.744287213729464,39.783034120408104,39.82178102708674,39.86052793376538,39.89927484044402,39.93802174712266,39.976768653801315,40.015515560479955,40.054262467158594,40.09300937383723,40.13175628051587,40.17050318719451,40.20925009387315,40.2479970005518,40.286743907230445,40.32549081390908,40.364237720587724,40.40298462726636,40.441731533945,40.48047844062364,40.51922534730228,40.557972253980935,40.59715837704404,40.63681508481107,40.6764717925781,40.71612850034512,40.75578520811215,40.79544191587918,40.83509862364621,40.87475533141323,40.91441203918026,40.95406874694729,40.99372545471432,41.033382162481345,41.073038870248375,41.11269557801539,41.15235228578243,41.19200899354945,41.23166570131648,41.2713224090835,41.31097911685053,41.35063582461757,41.395276635880364,41.44490155063893,41.49452646539751,41.54415138015608,41.593776294914655,41.643401209673236,41.6930261244318,41.74265103919038,41.79227595394895,41.84190086870752,41.89152578346609,41.941150698224675,41.99077561298324,42.04040052774181,42.0900254425004,42.139650357258965,42.18927527201754,42.238900186776114,42.28852510153469,42.338150016293255,42.38777493105184,42.43739984581041,42.48702476056897,42.53664967532755,42.586075500897934,42.63438420299202,42.6826929050861,42.73100160718019,42.77931030927428,42.82761901136836,42.87592771346245,42.92423641555654,42.97254511765062,43.020853819744715,43.06916252183879,43.11747122393289,43.165779926026964,43.21408862812106,43.262397330215144,43.31070603230923,43.35901473440332,43.40732343649741,43.45563213859149,43.50394084068557,43.55224954277967,43.600558244873746,43.64886694696784,43.69717564906193,43.745484351156016,43.7937930532501,43.84210175534419,43.89041045743827,43.938719159532354,43.98702786162645,44.035336563720534,44.083645265814624,44.1319539679087,44.1802626700028,44.22857137209688,44.27688007419097,44.32518877628506,44.37349747837914,44.421806180473226,44.470114882567316,44.518423584661406,44.56673228675549,44.615040988849586,44.66334969094367,44.71165839303775,44.75996709513184,44.80827579722593,44.856584499320014,44.9048932014141,44.95320190350819,45.00151060560228,45.04981930769636,45.09812800979044,45.14643671188453,45.194745413978616,45.243054116072706,45.291362818166796,45.33967152026088,45.38798022235497,45.330693028044095,45.062214040923394,44.79373505380269,44.525256066681976,44.256777079561274,43.98829809244057,43.71981910531986,43.45134011819913,43.182861131078454,42.91438214395774,42.645903156837015,42.37742416971632,42.10894518259562,41.8404661954749,41.5719872083542,41.3035082212335,41.035029234112784,40.76655024699208,40.49807125987138,40.229592272750665,39.961113285629935,39.69263429850925,39.424155311388546,39.15567632426782,38.88719733714713,38.61871835002643,38.35023936290571,38.08176037578501,37.81328138866431,37.544802401543585,37.27632341442286,37.00784442730219,36.73936544018147,36.47088645306074,36.202407465940055,35.933928478819354,35.66544949169863,35.396970504577936,35.128491517457235,34.86001253033651,34.59153354321581,34.323054556095116,34.05457556897439,33.78609658185367,33.517617594732975,33.249138607612274,32.98065962049155,32.71218063337085,32.443701646250155,32.17522265912943,31.906743672008734,31.638264684888043,31.36978569776732,31.101306710646593,30.832827723525924,30.5643487364052,30.295869749284474,30.02739076216378,29.75891177504308,29.490432787922355,29.221953800801657,28.953474813680963,28.68499582656024,28.41651683943954,28.148037852318847,27.879558865198124,27.611079878077405,27.342600890956728,27.07412190383601,26.805642916715282,26.537163929594584,26.268684942473886,26.000205955353167,25.73172696823247,25.46324798111177,25.177511260055315,24.889249008464347,24.600986756873425,24.312724505282453,24.02446225369148,23.736200002100535,23.44793775050959,23.159675498918613,22.876200168392053,22.616659443187224,22.357118717982395,22.097577992777566,21.838037267572783,21.578496542367954,21.318955817163125,21.059415091958343,20.799874366753517,20.54033364154869,20.280792916343906,20.021252191139077,19.761711465934244,19.50217074072942,19.242630015524636,18.983089290319807,18.723548565114974,18.464007839910195,18.204467114705366,17.944926389500537,17.685385664295758,17.425844939090926,17.1663042138861,16.906763488681317,16.64722276347649,16.387682038271656,16.128141313066827,15.868600587862048,15.609059862657217,15.34951913745239,15.089978412247607,14.830437687042778,14.57089696183795,14.311356236633168,14.051815511428337,13.792274786223508,13.532734061018678,13.273193335813898,13.013652610609068,12.75411188540424,12.494571160199458,12.236436203105566,12.047953594379791,11.899073422830565,11.749901574704094,11.60072972657762,11.451557878451176,11.302386030324703,11.153214182198232,11.00404233407176,10.854870485945314,10.705698637818845,10.556526789692374,10.407354941565925,10.258183093439456,10.109011245312983,9.95983939718654,9.810667549060067,9.661495700933596,9.512323852807123,9.36315200468068,9.213980156554207,9.064808308427736,8.91563646030129,8.76646461217482,8.617292764048347,8.468120915921904,8.318949067795433,8.16977721966896,8.020605371542514,7.871433523416043,7.7222616752895705,7.573089827163099,7.423917979036656,7.274746130910183,7.125574282783711,6.976402434657268,6.827230586530796,6.6780587384043235,6.52888689027788,6.379715042151408,6.230543194024935,6.0813713458984635,5.932199497772019],[32.58011382690138,32.617995900724736,32.65587797454809,32.69376004837145,32.73164212219481,32.76952419601817,32.80740626984152,32.84528834366489,32.883170417488245,32.921052491311606,32.95893456513496,32.99681663895832,33.034698712781676,33.07258078660504,33.1104628604284,33.14834493425175,33.18622700807511,33.22410908189847,33.26199115572183,33.299873229545184,33.337755303368546,33.37563737719191,33.41351945101526,33.45140152483862,33.489283598661984,33.52716567248534,33.56504774630869,33.602929820132054,33.640811893955416,33.67869396777877,33.71657604160213,33.75445811542549,33.79234018924885,33.83022226307221,33.86810433689557,33.905986410718924,33.94386848454228,33.98175055836564,34.019632632189,34.057514706012356,34.09539677983572,34.13327885365908,34.17116092748243,34.20904300130579,34.24692507512915,34.2848071489525,34.322689222775864,34.360571296599225,34.39845337042258,34.43633544424594,34.4742175180693,34.51209959189266,34.54998166571602,34.58786373953937,34.625745813362734,34.66362788718609,34.70150996100945,34.73939203483282,34.777274108656165,34.815156182479534,34.852673280414265,34.88836549579536,34.92405771117646,34.959749926557556,34.99544214193865,35.03113435731975,35.066826572700855,35.10251878808195,35.13821100346305,35.173903218844146,35.20959543422524,35.24528764960634,35.28097986498744,35.316672080368534,35.35236429574964,35.388056511130735,35.42374872651183,35.45944094189292,35.495133157274026,35.53082537265512,35.56651758803622,35.60220980341732,35.637902018798414,35.67359423417951,35.707910674878676,35.74195196064146,35.77599324640423,35.810034532167,35.844075817929784,35.87811710369256,35.912158389455335,35.94619967521811,35.980240960980886,36.01428224674367,36.048323532506444,36.08236481826922,36.116406104032,36.15044738979477,36.18448867555755,36.21852996132033,36.252571247083104,36.28661253284588,36.32065381860866,36.35469510437144,36.38873639013421,36.42277767589698,36.45681896165976,36.491764835675774,36.52761529708843,36.56346575850107,36.599316219913725,36.63516668132637,36.67101714273901,36.70686760415167,36.74271806556431,36.77856852697696,36.814418988389605,36.850269449802255,36.8861199112149,36.92197037262755,36.95782083404019,36.99367129545284,37.02952175686549,37.065372218278135,37.10122267969078,37.13707314110343,37.17292360251608,37.20877406392873,37.24462452534137,37.280474986754015,37.316325448166666,37.352175909579316,37.388026370991966,37.42387683240461,37.45972729381726,37.49557775522991,37.53142821664255,37.5672786780552,37.60312913946785,37.638979600880496,37.67483006229314,37.71068052370579,37.74653098511844,37.78238144653109,37.81823190794373,37.85408236935638,37.88993283076903,37.92578329218168,37.96163375359432,37.99748421500697,38.033334676419614,38.069185137832264,38.105035599244914,38.140886060657564,38.17673652207021,38.21258698348286,38.2484374448955,38.28428790630815,38.320138367720794,38.35598882913344,38.39183929054609,38.42768975195874,38.46354021337139,38.49939067478403,38.53524113619668,38.571091597609325,38.606942059021975,38.644723483945285,38.683470390623924,38.72221729730257,38.76096420398122,38.79971111065985,38.838458017338496,38.877204924017136,38.91595183069578,38.95469873737442,38.993445644053054,39.0321925507317,39.07093945741035,39.10968636408899,39.148433270767626,39.187180177446265,39.225927084124905,39.26467399080355,39.30342089748219,39.34216780416084,39.38091471083948,39.419661617518116,39.458408524196756,39.497155430875395,39.535902337554035,39.574649244232674,39.61339615091131,39.65214305758996,39.69088996426861,39.729636870947246,39.768383777625886,39.807130684304525,39.84587759098317,39.88462449766181,39.92337140434046,39.9621183110191,40.000865217697736,40.039612124376376,40.07895510912134,40.11861181688837,40.1582685246554,40.19792523242242,40.23758194018946,40.27723864795648,40.3168953557235,40.35655206349053,40.396208771257555,40.435865479024585,40.47552218679162,40.515178894558645,40.554835602325674,40.5944923100927,40.63414901785973,40.67380572562675,40.71346243339378,40.753119141160816,40.79277584892783,40.83243255669486,40.87208926446189,40.91174597222892,40.95140267999595,40.991059387762974,41.030716095529996,41.07037280329703,41.110029511064056,41.14968621883108,41.189342926598115,41.22899963436514,41.26865634213216,41.3083130498992,41.34796975766622,41.38762646543324,41.42728317320028,41.4669398809673,41.50659658873433,41.54625329650136,41.585910004268385,41.625566712035415,41.665223419802444,41.70488012756947,41.7445368353365,41.78419354310352,41.82385025087055,41.86350695863758,41.90814776990038,41.95777268465895,42.00739759941753,42.0570225141761,42.10664742893468,42.156272343693246,42.20589725845181,42.255522173210394,42.30514708796897,42.354772002727536,42.40439691748611,42.45402183224469,42.50364674700326,42.553271661761826,42.60289657652041,42.652521491278975,42.70214640603755,42.751771320796124,42.8013962355547,42.85102115031327,42.90064606507185,42.95027097983042,42.99989589458899,43.04952080934756,43.099145724106144,43.14877063886471,43.198395553623286,43.24802046838186,43.297645383140434,43.347270297898994,43.396895212657576,43.44652012741615,43.49614504217472,43.5457699569333,43.59539487169188,43.64501978645045,43.694644701209015,43.744269615967596,43.79389453072616,43.84351944548473,43.89314436024331,43.942769275001886,43.992394189760454,44.04201910451903,44.09164401927761,44.14126893403617,44.190893848794744,44.240518763553325,44.29014367831189,44.33976859307047,44.38939350782904,44.439018422587615,44.48864333734619,44.538268252104764,44.587893166863346,44.637518081621906,44.68680011583265,44.73510881792675,44.78341752002083,44.831726222114916,44.880034924209006,44.928343626303096,44.97665232839717,45.02496103049127,45.07326973258535,45.121578434679435,45.169887136773525,45.218195838867615,45.26650454096169,45.31481324305578,45.36312194514987,45.41143064724396,45.45973934933805,45.50804805143214,45.556356753526224,45.60466545562031,45.6529741577144,45.70128285980848,45.74959156190257,45.79790026399665,45.84620896609075,45.894517668184825,45.94282637027892,45.885539175968034,45.61706018884735,45.348581201726645,45.08010221460592,44.81162322748522,44.543144240364526,44.2746652532438,44.00618626612308,43.73770727900241,43.469228291881684,43.20074930476096,42.93227031764027,42.66379133051957,42.39531234339885,42.126833356278155,41.85835436915745,41.58987538203673,41.321396394916036,41.05291740779533,40.78443842067461,40.51595943355389,40.247480446433194,39.97900145931249,39.710522472191776,39.442043485071075,39.17356449795037,38.90508551082966,38.63660652370895,38.36812753658826,38.09964854946753,37.831169562346815,37.562690575226135,37.29421158810542,37.025732600984696,36.75241307777112,36.46415082618018,36.17588857458921,35.88762632299826,35.599364071407315,35.31110181981634,35.02283956822539,34.73457731663445,34.44631506504348,34.15805281345251,33.86979056186156,33.58152831027061,33.293266058679635,33.0050038070887,32.71674155549775,32.428479303906784,32.140217052315826,31.851954800724883,31.563692549133908,31.27543029754294,30.987168045952018,30.69890579436105,30.410643542770075,30.122381291179128,29.83411903958818,29.54585678799721,29.257594536406263,28.96933228481532,28.681070033224348,28.3928077816334,28.10454553004245,27.816283278451483,27.528021026860507,27.23975877526959,26.95149652367862,26.663234272087646,26.3749720204967,26.08670976890575,25.79844751731478,25.510185265723834,25.22192301413289,24.933660762541916,24.645398510950944,24.357136259360022,24.068874007769054,23.780611756178075,23.49234950458713,23.20408725299619,22.915825001405214,22.632349670878654,22.372808945673825,22.113268220468996,21.853727495264167,21.594186770059387,21.334646044854555,21.075105319649726,20.815564594444943,20.556023869240118,20.296483144035285,20.036942418830506,19.777401693625674,19.517860968420845,19.258320243216016,18.998779518011233,18.739238792806404,18.47969806760158,18.220157342396796,17.960616617191967,17.701075891987138,17.441535166782355,17.181994441577526,16.922453716372697,16.662912991167914,16.403372265963085,16.143831540758256,15.88939358444707,15.63653484091525,15.383676097383383,15.130817353851514,14.877958610319691,14.625099866787822,14.372241123255957,14.119382379724135,13.866523636192268,13.613664892660399,13.36080614912853,13.107947405596708,12.85508866206484,12.602229918532974,12.349371175001153,12.096512431469282,11.90802982274351,11.765530167450672,11.62303051215781,11.480530856864945,11.338031201572107,11.195531546279245,11.05303189098638,10.910532235693516,10.768032580400678,10.625532925107814,10.483033269814952,10.340533614522114,10.19803395922925,10.055534303936385,9.913034648643547,9.770534993350683,9.625346406623942,9.476174558497469,9.327002710371026,9.177830862244555,9.028659014118082,8.879487165991637,8.730315317865166,8.581143469738695,8.43197162161225,8.28279977348578,8.133627925359306,7.984456077232862,7.835284229106389,7.6861123809799174,7.536940532853446,7.387768684727002,7.2385968366005295,7.089424988474057,6.940253140347614,6.791081292221142,6.6419094440946695,6.492737595968226,6.343565747841755,6.194393899715282,6.0452220515888095,5.896050203462366],[33.00318920776149,33.04107128158485,33.0789533554082,33.11683542923156,33.15471750305492,33.19259957687828,33.230481650701634,33.268363724524995,33.30624579834836,33.34412787217171,33.38200994599507,33.419892019818434,33.45777409364179,33.49565616746515,33.53353824128851,33.571420315111865,33.60930238893522,33.64718446275858,33.68506653658194,33.7229486104053,33.76083068422866,33.79871275805202,33.836594831875374,33.87447690569873,33.91235897952208,33.95024105334545,33.988123127168805,34.02600520099216,34.06388727481553,34.10176934863888,34.13965142246224,34.177533496285605,34.21541557010896,34.253297643932314,34.291179717755675,34.329061791579036,34.36694386540239,34.404825939225745,34.442708013049106,34.48059008687247,34.51847216069582,34.55635423451918,34.594236308342545,34.6321183821659,34.67000045598926,34.707882529812615,34.745764603635976,34.78364667745933,34.82152875128269,34.859410825106046,34.89729289892941,34.93517497275277,34.97305704657613,35.010939120399485,35.04882119422284,35.0867032680462,35.12458534186956,35.16246741569292,35.20034948951628,35.23823156333964,35.27611363716299,35.31399571098635,35.35187778480971,35.38975985863307,35.427641932456424,35.465524006279786,35.50340608010314,35.5412881539265,35.57917022774986,35.61705230157322,35.65493437539658,35.69281644921993,35.7306985230433,35.768580596866656,35.80646267069001,35.84434474451337,35.882226818336726,35.918648987411665,35.95434120279276,35.99003341817386,36.025725633554956,36.06141784893605,36.09711006431716,36.132802279698254,36.16711872039741,36.201160006160194,36.23520129192297,36.269242577685745,36.30328386344852,36.337325149211296,36.37136643570089,36.407216897113535,36.443067358526186,36.47891781993883,36.51476828135148,36.55061874276413,36.58646920417677,36.62231966558942,36.65817012700207,36.694020588414716,36.729871049827366,36.76572151124002,36.80157197265266,36.83742243406531,36.87327289547795,36.9091233568906,36.944973818303254,36.9808242797159,37.01667474112855,37.05252520254119,37.08837566395384,37.12422612536649,37.160076586779134,37.195927048191784,37.23177750960443,37.26762797101708,37.30347843242973,37.33932889384237,37.37517935525502,37.411029816667664,37.446880278080314,37.482730739492965,37.51858120090561,37.55443166231825,37.5902821237309,37.62613258514355,37.6619830465562,37.69783350796885,37.7336839693815,37.769534430794145,37.80538489220679,37.84123535361944,37.87708581503209,37.91293627644473,37.94878673785738,37.984637199270026,38.020487660682676,38.056338122095326,38.09218858350797,38.12803904492062,38.16388950633326,38.19973996774591,38.23559042915856,38.271440890571206,38.30729135198386,38.3431418133965,38.37899227480915,38.4148427362218,38.45069319763445,38.48654365904709,38.522394120459744,38.55824458187239,38.59409504328504,38.62994550469768,38.66579596611034,38.70164642752298,38.737496888935624,38.773347350348274,38.809197811760924,38.84504827317357,38.88089873458622,38.91674919599886,38.95259965741151,38.988450118824154,39.024300580236805,39.060151041649455,39.0960015030621,39.133782927985415,39.17252983466405,39.211276741342694,39.25002364802133,39.28877055469997,39.32751746137862,39.36626436805726,39.4050112747359,39.44375818141454,39.48250508809318,39.52125199477182,39.56075184119864,39.60040854896567,39.6400652567327,39.67972196449973,39.71937867226675,39.75903538003378,39.7986920878008,39.83834879556783,39.87800550333486,39.91766221110189,39.95731891886892,39.996975626635944,40.036632334402974,40.076289042169996,40.115945749937026,40.155602457704056,40.19525916547108,40.234915873238116,40.27457258100513,40.31422928877217,40.35388599653919,40.39354270430621,40.43319941207324,40.47285611984027,40.512512827607296,40.55216953537433,40.591826243141355,40.63148295090838,40.67113965867541,40.71079636644244,40.75045307420946,40.79010978197649,40.82976648974352,40.86942319751054,40.90907990527757,40.9487366130446,40.98839332081163,41.028050028578654,41.067706736345684,41.10736344411271,41.14702015187974,41.18667685964677,41.22633356741379,41.265990275180826,41.30564698294785,41.34530369071487,41.38496039848191,41.42461710624893,41.46427381401596,41.50393052178299,41.54358722955001,41.583243937317036,41.622900645084066,41.662557352851096,41.702214060618125,41.741870768385155,41.781527476152185,41.8211841839192,41.86084089168624,41.90049759945326,41.9401543072203,41.97981101498732,42.01946772275435,42.05912443052137,42.0987811382884,42.138437846055425,42.17809455382245,42.21775126158948,42.25740796935651,42.29706467712354,42.336721384890566,42.37637809265759,42.42101890392039,42.470643818678965,42.52026873343754,42.56989364819611,42.61951856295469,42.66914347771326,42.71876839247183,42.768393307230404,42.81801822198898,42.867643136747546,42.91726805150613,42.96689296626471,43.016517881023276,43.06614279578184,43.115767710540425,43.16539262529899,43.21501754005756,43.26464245481614,43.314267369574715,43.36389228433329,43.41351719909186,43.46314211385044,43.512767028609005,43.56239194336757,43.612016858126154,43.66164177288473,43.7112666876433,43.76089160240187,43.810516517160444,43.860141431919004,43.90976634667759,43.95939126143617,44.009016176194734,44.05864109095331,44.10826600571188,44.157890920470464,44.207515835229025,44.257140749987606,44.30676566474618,44.35639057950475,44.40601549426332,44.455640409021896,44.50526532378047,44.55489023853904,44.60451515329762,44.654140068056186,44.70376498281476,44.753389897573335,44.80301481233191,44.852639727090484,44.90226464184906,44.951889556607625,45.0015144713662,45.051139386124774,45.100764300883355,45.15038921564192,45.2000141304005,45.24963904515907,45.29926395991764,45.34888887467622,45.398513789434794,45.44813870419336,45.49776361895194,45.54738853371051,45.597013448469085,45.64663836322765,45.696263277986226,45.745888192744815,45.795513107503375,45.84513802226195,45.89476293702053,45.94438785177909,45.994012766537665,46.04363768129625,46.09326259605482,46.142935012184104,46.19301121001523,46.243087407846346,46.29316360567747,46.343239803508595,46.39331600133971,46.44339219917084,46.49346839700196,46.42830106122246,46.132646658221866,45.836992255221254,45.54133785222063,45.24568344922002,44.950029046219406,44.65437464321877,44.35872024021813,44.06306583721756,43.767411434216925,43.471757031216285,43.17610262821567,42.880448225215076,42.584793822214436,42.289139419213825,41.99348501621323,41.69783061321258,41.40902085730399,41.120758605713036,40.83249635412207,40.54423410253111,40.255971850940156,39.967709599349206,39.67944734775824,39.39118509616729,39.10292284457634,38.81466059298537,38.526398341394426,38.238136089803476,37.949873838212504,37.66161158662153,37.37334933503061,37.085087083439646,36.79682483184867,36.50856258025772,36.220300328666774,35.9320380770758,35.643775825484866,35.355513573893916,35.06725132230294,34.778989070711994,34.49072681912105,34.20246456753008,33.91420231593911,33.62594006434816,33.337677812757214,33.04941556116624,32.76115330957529,32.47289105798435,32.18462880639338,31.896366554802427,31.608104303211483,31.319842051620512,31.03157980002954,30.74331754843862,30.455055296847647,30.166793045256668,29.878530793665725,29.59026854207478,29.30200629048381,29.01374403889286,28.725481787301916,28.437219535710945,28.148957284119998,27.860695032529055,27.572432780938083,27.284170529347115,26.995908277756186,26.707646026165218,26.41938377457424,26.131121522983296,25.842859271392353,25.55459701980138,25.266334768210434,24.978072516619488,24.689810265028516,24.401548013437544,24.113285761846623,23.82502351025565,23.536761258664676,23.248499007073733,22.960236755482786,22.67197450389181,22.38849917336525,22.128958448160425,21.869417722955593,21.609876997750767,21.350336272545984,21.090795547341152,20.831254822136323,20.571714096931544,20.312173371726715,20.052632646521882,19.795209709320492,19.542350965788625,19.289492222256754,19.036633478724887,18.783774735193067,18.5309159916612,18.27805724812933,18.02519850459751,17.77233976106564,17.519481017533774,17.26662227400195,17.013763530470083,16.760904786938216,16.50804604340639,16.255187299874528,16.002328556342654,15.74946981281079,15.496611069278966,15.2437523257471,14.990893582215232,14.738034838683411,14.485176095151541,14.232317351619674,13.979458608087853,13.726599864555984,13.473741121024116,13.220882377492249,12.968023633960428,12.715164890428559,12.46230614689669,12.20944740336487,11.956588659833002,11.768106051107228,11.62560639581439,11.483106740521528,11.340607085228664,11.198107429935826,11.055607774642963,10.913108119350099,10.770608464057235,10.628108808764397,10.485609153471534,10.343109498178668,10.20060984288583,10.058110187592968,9.915610532300104,9.773110877007266,9.630611221714403,9.488111566421539,9.345611911128675,9.203112255835837,9.060612600542974,8.918112945250108,8.775613289957272,8.633113634664408,8.490613979371544,8.348114324078706,8.205614668785843,8.063115013492979,7.920615358200141,7.778115702907277,7.6356160476144135,7.493116392321548,7.3506167370287105,7.2024475422908765,7.053275694164405,6.90410384603796,6.754931997911488,6.6057601497850165,6.456588301658573,6.307416453532101,6.158244605405628,6.0090727572791565,5.859900909152712],[33.421222036266705,33.461116011803014,33.50100998733933,33.54090396287564,33.58079793841195,33.620691913948264,33.66058588948457,33.70047986502089,33.7403738405572,33.78026781609351,33.81949115886573,33.857373232689085,33.895255306512446,33.93313738033581,33.97101945415916,34.00890152798252,34.04678360180588,34.08466567562924,34.1225477494526,34.16042982327595,34.198311897099316,34.23619397092267,34.27407604474603,34.311958118569386,34.34984019239275,34.3877222662161,34.42560434003946,34.463486413862825,34.50136848768618,34.53925056150954,34.5771326353329,34.615014709156256,34.65289678297961,34.69077885680298,34.72866093062633,34.766543004449694,34.80442507827305,34.84230715209641,34.880189225919764,34.918071299743126,34.95595337356648,34.99383544738984,35.031717521213196,35.069599595036564,35.10748166885992,35.14536374268328,35.183245816506634,35.221127890329996,35.25900996415335,35.296892037976704,35.334774111800066,35.37265618562343,35.41053825944679,35.44842033327014,35.486302407093504,35.52418448091686,35.56206655474022,35.599948628563574,35.637830702386935,35.67571277621029,35.71359485003365,35.75147692385701,35.78935899768037,35.82724107150373,35.86512314532709,35.903005219150444,35.9408872929738,35.97876936679716,36.01665144062052,36.05453351444388,36.09241558826724,36.1302976620906,36.16817973591395,36.206061809737314,36.24394388356067,36.28182595738403,36.319708031207384,36.357590105030745,36.39547217885411,36.43335425267746,36.47123632650082,36.509118400324176,36.54700047414754,36.5848825479709,36.621071611451995,36.656922072864646,36.69277253427729,36.72862299568994,36.76447345710258,36.80032391851523,36.83617437992788,36.872024841340526,36.90787530275317,36.94372576416582,36.97957622557847,37.01542668699111,37.05127714840377,37.087127609816406,37.12297807122906,37.15882853264171,37.19467899405436,37.23052945546701,37.26637991687965,37.3022303782923,37.33808083970494,37.373931301117594,37.409781762530244,37.44563222394289,37.48148268535553,37.51733314676818,37.55318360818083,37.58903406959348,37.624884531006124,37.660734992418774,37.69658545383142,37.73243591524407,37.76828637665672,37.80413683806936,37.83998729948201,37.875837760894655,37.911688222307305,37.947538683719955,37.9833891451326,38.01923960654525,38.05509006795789,38.09094052937054,38.12679099078319,38.162641452195835,38.198491913608486,38.23434237502113,38.27019283643378,38.30604329784643,38.34189375925907,38.37774422067172,38.413594682084366,38.449445143497016,38.485295604909666,38.52114606632231,38.55699652773496,38.59284698914761,38.62869745056025,38.6645479119729,38.70039837338555,38.7362488347982,38.77209929621085,38.80794975762349,38.84380021903614,38.87965068044879,38.915501141861434,38.951351603274084,38.987202064686734,39.02305252609937,39.05890298751203,39.09475344892467,39.13060391033732,39.166454371749964,39.20230483316262,39.23871118923642,39.27622933179711,39.313747474357804,39.3512656169185,39.38878375947919,39.42630190203988,39.46382004460057,39.50133818716126,39.53885632972195,39.576374472282644,39.61564937240976,39.6558026513201,39.69595593023045,39.73610920914078,39.77626248805112,39.816415766961455,39.856569045871794,39.89672232478213,39.93687560369247,39.977028882602816,40.01718216151315,40.057335440423486,40.097488719333825,40.13764199824416,40.1777952771545,40.21794855606485,40.25810183497518,40.29825511388552,40.338408392795856,40.3785616717062,40.41871495061654,40.45886822952688,40.49902150843722,40.53917478734755,40.579328066257894,40.61948134516823,40.65963462407857,40.6997879029889,40.73994118189925,40.78009446080958,40.82024773971992,40.860401018630256,40.9005542975406,40.94070757645093,40.98086085536127,41.02101413427161,41.06116741318195,41.10132069209229,41.14147397100263,41.18162724991297,41.2217805288233,41.26193380773365,41.30208708664398,41.34224036555433,41.38229433153056,41.42195103929758,41.46160774706461,41.50126445483165,41.54092116259867,41.5805778703657,41.620234578132724,41.65989128589975,41.69954799366678,41.739204701433806,41.778861409200836,41.818518116967866,41.85817482473489,41.89783153250192,41.93748824026894,41.97714494803598,42.016801655803,42.05645836357002,42.09611507133705,42.135771779104076,42.175428486871105,42.215085194638135,42.254741902405165,42.294398610172195,42.33405531793922,42.37371202570625,42.41336873347328,42.45302544124031,42.49268214900733,42.53233885677436,42.57199556454138,42.61165227230842,42.65130898007544,42.69096568784247,42.730622395609494,42.77027910337652,42.80993581114355,42.84959251891058,42.889249226677606,42.9338900379404,42.98351495269898,43.03313986745755,43.082764782216124,43.1323896969747,43.18201461173327,43.23163952649184,43.281264441250414,43.330889356008996,43.38051427076756,43.430139185526144,43.47976410028471,43.52938901504329,43.57901392980186,43.62863884456043,43.67826375931901,43.727888674077576,43.77751358883616,43.827138503594725,43.87676341835329,43.92638833311187,43.97601324787045,44.02563816262902,44.075263077387596,44.124887992146164,44.17453072058621,44.22460691841734,44.27468311624847,44.324759314079586,44.3748355119107,44.424911709741835,44.47498790757295,44.52506410540407,44.5751403032352,44.62521650106633,44.67529269889745,44.72536889672857,44.77544509455969,44.82552129239082,44.875597490221935,44.92567368805306,44.975749885884184,45.0258260837153,45.07590228154643,45.12597847937755,45.176054677208676,45.2261308750398,45.276207072870925,45.32628327070204,45.37635946853317,45.42643566636429,45.476511864195416,45.52658806202653,45.576664259857665,45.62674045768878,45.6768166555199,45.726892853351025,45.77696905118216,45.82704524901327,45.87712144684439,45.92719764467552,45.97727384250665,46.027350040337765,46.07742623816889,46.127502436000015,46.17757863383113,46.22765483166226,46.27773102949338,46.327807227324506,46.37788342515563,46.427959622986755,46.47803582081787,46.528112018649,46.57818821648012,46.62826441431124,46.67834061214236,46.72841680997348,46.77849300780461,46.82856920563573,46.878645403466855,46.92872160129799,46.978797799129104,47.02887399696023,46.96370666118073,46.668052258180126,46.372397855179514,46.076743452178874,45.78108904917827,45.485434646177666,45.189780243177026,44.8941258401764,44.59847143717582,44.302817034175185,44.00716263117455,43.71150822817394,43.41585382517333,43.1201994221727,42.82454501917209,42.52889061617148,42.23323621317085,41.937581810170244,41.64192740716963,41.346273004169,41.05061860116837,40.754964198167755,40.45930979516715,40.16365539216652,39.86800098916591,39.572346586165295,39.27669218316467,38.98103778016406,38.68538337716345,38.38972897416282,38.09407457116218,37.7984201681616,37.502765765160966,37.20711136216033,36.91145695915972,36.61580255615912,36.320148153158485,36.02449375015787,35.72883934715727,35.43318494415662,35.137530541156025,34.84187613815541,34.546221735154774,34.25056733215414,33.95491292915354,33.659258526152925,33.36360412315229,33.06794972015168,32.77229531715108,32.476640914150444,32.18098651114983,31.88533210814923,31.589677705148592,31.29402330214796,30.99836889914738,30.702714496146744,30.40706009314611,30.111405690145503,29.81575128714489,29.52009688414426,29.22444248114365,28.928788078143043,28.63313367514241,28.337479272141803,28.041824869141195,27.746170466140562,27.450516063139926,27.154861660139343,26.85920725713871,26.56183855917144,26.245612938345968,25.929387317520487,25.61316169669498,25.296936075869507,24.980710455044026,24.664484834218523,24.348259213393018,24.03203359256757,23.715807971742063,23.39958235091656,23.083356730091083,22.767131109265605,22.4509054884401,22.145278026920487,21.892641361929975,21.640004696939457,21.38736803194894,21.134731366958476,20.88209470196796,20.62945803697745,20.376821371986985,20.124184706996466,19.871548042005955,19.618911377015486,19.36627471202497,19.113638047034456,18.861001382043945,18.608364717053476,18.35572805206296,18.103091387072446,17.85045472208198,17.59781805709147,17.345181392100955,17.092544727110486,16.83990806211997,16.587271397129456,16.33463473213899,16.081998067148476,15.829361402157964,15.57672473716745,15.324088072176982,15.07145140718647,14.818814742195954,14.566178077205487,14.313541412214974,14.060904747224457,13.80826808223399,13.555631417243479,13.302994752252964,13.050358087262449,12.797721422271984,12.550635314831558,12.305063007007533,12.059490699183556,11.813918391359529,11.632687799815457,11.497415577042792,11.362143354270103,11.226871131497411,11.088931117210977,10.946655964600795,10.80438081199061,10.662105659380428,10.51983050677027,10.377555354160084,10.235280201549902,10.093005048939744,9.950729896329559,9.808454743719377,9.66617959110922,9.523904438499036,9.38162928588885,9.239354133278669,9.097078980668512,8.954803828058328,8.812528675448142,8.670253522837985,8.527978370227801,8.385703217617618,8.24342806500746,8.101152912397275,7.958877759787093,7.816602607176935,7.67432745456675,7.532052301956567,7.389777149346383,7.247501996736226,7.105226844126042,6.962951691515858,6.8206765389057,6.678401386295516,6.536126233685334,6.393851081075176,6.251575928464992,6.109300775854807,5.9670256232446235,5.824750470634467],[33.83569030231892,33.87558427785524,33.91547825339154,33.95537222892786,33.99526620446417,34.03516018000048,34.07505415553679,34.114948131073106,34.15484210660942,34.19473608214573,34.23463005768205,34.274524033218356,34.31441800875467,34.35431198429098,34.39420595982729,34.434099935363605,34.47399391089992,34.51388788643623,34.55378186197254,34.593675837508854,34.63356981304517,34.67346378858148,34.71335776411779,34.753251739654104,34.79314571519041,34.83303969072672,34.87293366626304,34.91115105851074,34.9490331323341,34.986915206157455,35.02479727998082,35.06267935380417,35.10056142762753,35.138443501450894,35.17632557527425,35.21420764909761,35.252089722920964,35.289971796744325,35.32785387056768,35.36573594439105,35.4036180182144,35.44150009203776,35.479382165861125,35.51726423968448,35.555146313507834,35.593028387331195,35.63091046115455,35.66879253497791,35.706674608801265,35.744556682624626,35.78243875644799,35.82032083027134,35.8582029040947,35.896084977918065,35.93396705174142,35.97184912556478,36.009731199388135,36.047613273211496,36.08549534703485,36.12337742085821,36.16125949468157,36.19914156850493,36.23702364232829,36.27490571615164,36.312787789975005,36.350669863798366,36.38855193762172,36.42643401144508,36.464316085268436,36.5021981590918,36.54008023291516,36.57796230673851,36.615844380561875,36.653726454385236,36.69160852820858,36.729490602031944,36.767372675855306,36.80525474967866,36.84313682350202,36.88101889732538,36.91890097114874,36.9567830449721,36.99466511879545,37.032547192618814,37.06873625609991,37.10458671751256,37.14043717892521,37.17628764033786,37.212138101750504,37.24798856316315,37.2838390245758,37.31968948598845,37.35553994740109,37.391390408813734,37.427240870226385,37.463091331639035,37.498941793051685,37.53479225446433,37.570642715876986,37.60649317728962,37.64234363870227,37.67819410011492,37.71404456152757,37.74989502294022,37.785745484352866,37.82159594576551,37.85744640717816,37.89329686859081,37.92914733000345,37.964997791416096,38.000848252828746,38.036698714241396,38.07254917565404,38.10839963706669,38.14425009847934,38.18010055989198,38.21595102130463,38.251801482717276,38.287651944129934,38.32350240554257,38.35935286695522,38.39520332836787,38.43105378978052,38.46690425119317,38.502754712605814,38.53860517401846,38.57445563543111,38.61030609684376,38.6461565582564,38.68200701966905,38.717857481081694,38.753707942494344,38.78955840390699,38.825408865319645,38.86125932673228,38.89710978814493,38.93296024955758,38.968810710970224,39.00466117238288,39.040511633795525,39.076362095208175,39.11360229213117,39.151120434691855,39.18863857725255,39.22615671981324,39.26367486237393,39.301193004934625,39.33871114749532,39.37622929005601,39.4137474326167,39.45126557517739,39.48878371773808,39.526301860298766,39.56382000285946,39.60133814542016,39.63885628798084,39.676374430541536,39.71389257310223,39.75141071566292,39.78892885822361,39.8264470007843,39.863965143345,39.901483285905684,39.93900142846638,39.97651957102707,40.01403771358776,40.051555856148454,40.09083075627558,40.13098403518591,40.171137314096256,40.211290593006595,40.25144387191693,40.29159715082727,40.33175042973761,40.37190370864794,40.41205698755829,40.45221026646862,40.492363545378964,40.5325168242893,40.57267010319964,40.61282338210998,40.65297666102032,40.69312993993066,40.733283218840995,40.773436497751334,40.81358977666167,40.85374305557201,40.89389633448235,40.934049613392695,40.974202892303026,41.014356171213365,41.05450945012371,41.09466272903405,41.13481600794438,41.17496928685472,41.215122565765064,41.2552758446754,41.295429123585734,41.33558240249607,41.37573568140641,41.41588896031675,41.456042239227095,41.496195518137434,41.536348797047765,41.57650207595811,41.61665535486844,41.65680863377878,41.69696191268912,41.73711519159946,41.777268470509796,41.81742174942014,41.85757502833047,41.89772830724082,41.93788158615116,41.97803486506149,42.018188143971834,42.05834142288217,42.09849470179251,42.13864798070285,42.17880125961318,42.218954538523526,42.25910781743387,42.2992610963442,42.33941437525454,42.37956765416488,42.41972093307522,42.45987421198556,42.5000274908959,42.54018076980623,42.58033404871657,42.62048732762692,42.66064060653725,42.70079388544758,42.74094716435793,42.78110044326827,42.821253722178604,42.86140700108895,42.90156027999928,42.94171355890962,42.98186683781996,43.02292517936271,43.06416453221334,43.10540388506399,43.14664323791464,43.187882590765284,43.22912194361593,43.270361296466575,43.31160064931723,43.35284000216787,43.39407935501852,43.44003219879088,43.49069853348496,43.541364868179045,43.59203120287312,43.64269753756721,43.69336387226129,43.744030206955365,43.794696541649444,43.84536287634353,43.89602921103761,43.94669554573169,43.99736188042577,44.04802821511986,44.098694549813935,44.14936088450801,44.200027219202084,44.25069355389617,44.301359888590255,44.35202622328433,44.40269255797841,44.4533588926725,44.504025227366576,44.554691562060654,44.60535789675474,44.65602423144882,44.706690566142896,44.75735690083698,44.80802323553107,44.85868957022514,44.909355904919224,44.9600222396133,45.01039350753124,45.06046970536235,45.11054590319348,45.1606221010246,45.210698298855725,45.26077449668685,45.310850694517974,45.3609268923491,45.411003090180216,45.46107928801134,45.511155485842465,45.56123168367358,45.611307881504715,45.66138407933584,45.71146027716695,45.76153647499808,45.811612672829206,45.86168887066032,45.91176506849145,45.961841266322566,46.0119174641537,46.061993661984815,46.112069859815946,46.162146057647064,46.21222225547818,46.262298453309306,46.31237465114043,46.362450848971555,46.41252704680268,46.462603244633804,46.51267944246493,46.56275564029605,46.612831838127164,46.662908035958296,46.71298423378941,46.76306043162054,46.81313662945166,46.86321282728278,46.91328902511391,46.963365222945036,47.013441420776154,47.06351761860728,47.1135938164384,47.16367001426953,47.21374621210064,47.26382240993178,47.31389860776289,47.36397480559401,47.41405100342514,47.46412720125626,47.514203399087386,47.5642795969185,47.49911226113902,47.20345785813841,46.907803455137795,46.61214905213716,46.31649464913656,46.02084024613595,45.72518584313532,45.42953144013468,45.1338770371341,44.838222634133466,44.54256823113283,44.24691382813223,43.95125942513162,43.655605022130985,43.35995061913037,43.06429621612976,42.768641813129136,42.472987410128525,42.17733300712792,41.88167860412727,41.58602420112665,41.29036979812604,40.99471539512544,40.6990609921248,40.40340658912419,40.107752186123584,39.812097783122944,39.51644338012234,39.220788977121735,38.925134574121095,38.62948017112046,38.33314002623769,38.01691440541218,37.70068878458668,37.384463163761204,37.06823754293573,36.75201192211023,36.43578630128475,36.119560680459266,35.80333505963377,35.48710943880829,35.170883817982805,34.854658197157306,34.5384325763318,34.22220695550632,33.905981334680845,33.58975571385534,33.27353009302987,32.957304472204385,32.641078851378886,32.32485323055341,32.00862760972793,31.692401988902425,31.376176368076923,31.059950747251474,30.74372512642597,30.427499505600462,30.111273884774988,29.79504826394951,29.478822643124005,29.16259702229853,28.84637140147305,28.530145780647548,28.21392015982207,27.89769453899659,27.581468918171087,27.265243297345577,26.949017676520135,26.63279205569463,26.316566434869124,26.000340814043646,25.684115193218172,25.367889572392663,25.05166395156719,24.735438330741715,24.41921270991621,24.102987089090703,23.786761468265254,23.47053584743975,23.154310226614243,22.838084605788765,22.52185898496329,22.205633364137785,21.90000590261817,21.647369237627657,21.394732572637142,21.142095907646627,20.88945924265616,20.636822577665647,20.38418591267513,20.131549247684667,19.878912582694152,19.626275917703637,19.37363925271317,19.121002587722657,18.868365922732142,18.615729257741627,18.363092592751162,18.110455927760647,17.857819262770132,17.605182597779667,17.352545932789152,17.099909267798637,16.84727260280817,16.594635937817657,16.34199927282714,16.095333668916346,15.849761361092323,15.604189053268296,15.358616745444271,15.113044437620292,14.867472129796266,14.621899821972242,14.376327514148262,14.130755206324238,13.885182898500211,13.63961059067623,13.394038282852208,13.14846597502818,12.902893667204157,12.657321359380179,12.411749051556152,12.166176743732127,11.92060443590815,11.675032128084123,11.493801536540051,11.358529313767386,11.223257090994696,11.087984868222005,10.95271264544934,10.81744042267665,10.682168199903959,10.546895977131268,10.411623754358603,10.276351531585911,10.14107930881322,10.005807086040555,9.870534863267864,9.735262640495174,9.599990417722509,9.464718194949818,9.329445972177126,9.194173749404435,9.05890152663177,8.921378359433401,8.779103206823216,8.63682805421306,8.494552901602875,8.352277748992691,8.210002596382534,8.06772744377235,7.925452291162166,7.783177138552009,7.6409019859418255,7.498626833331642,7.356351680721457,7.214076528111301,7.071801375501115,6.929526222890933,6.7872510702807745,6.644975917670591,6.502700765060407,6.360425612450249,6.218150459840066,6.0758753072298815,5.933600154619699,5.79132500200954],[34.25015856837112,34.290052543907436,34.32994651944375,34.36984049498005,34.40973447051637,34.449628446052685,34.489522421588994,34.5294163971253,34.56931037266162,34.609204348197935,34.64909832373424,34.68899229927055,34.72888627480687,34.768780250343184,34.80867422587949,34.8485682014158,34.88846217695212,34.928356152488426,34.968250128024735,35.00814410356105,35.04803807909737,35.087932054633676,35.127826030169985,35.1677200057063,35.207613981242616,35.24750795677892,35.28740193231524,35.32729590785155,35.367189883387866,35.40708385892417,35.44697783446048,35.4868718099968,35.52676578553311,35.566659761069424,35.60655373660573,35.64644771214205,35.686341687678365,35.726235663214666,35.76612963875098,35.8060236142873,35.84591758982361,35.885811565359916,35.92570554089623,35.96492888433238,36.002810958155735,36.040693031979096,36.07857510580245,36.11645717962581,36.154339253449166,36.19222132727252,36.23010340109588,36.26798547491924,36.305867548742604,36.34374962256596,36.38163169638932,36.419513770212674,36.457395844036036,36.4952779178594,36.53315999168275,36.57104206550611,36.608924139329474,36.64680621315283,36.68468828697619,36.722570360799544,36.760452434622906,36.79833450844626,36.83621658226962,36.874098656092976,36.91198072991634,36.94986280373969,36.98774487756305,37.025626951386414,37.063509025209775,37.10139109903313,37.139273172856484,37.177155246679845,37.2150373205032,37.25291939432656,37.29080146814992,37.32868354197328,37.36656561579663,37.40444768962,37.44232976344335,37.480211837266715,37.51640090074781,37.55225136216046,37.58810182357311,37.623952284985755,37.6598027463984,37.69565320781105,37.7315036692237,37.76735413063634,37.80320459204899,37.83905505346164,37.87490551487429,37.910755976286936,37.946606437699586,37.98245689911223,38.01830736052488,38.05415782193752,38.09000828335017,38.12585874476282,38.161709206175466,38.197559667588116,38.23341012900076,38.26926059041341,38.30511105182606,38.3409615132387,38.37681197465135,38.412662436064,38.44851289747665,38.4843633588893,38.52021382030194,38.55606428171459,38.591914743127234,38.627765204539884,38.663615665952534,38.69946612736518,38.73531658877783,38.77116705019047,38.80701751160312,38.84286797301577,38.87871843442842,38.914568895841064,38.950975252465206,38.9884933950259,39.02601153758659,39.063529680147276,39.10104782270796,39.13856596526866,39.176084107829354,39.21360225039004,39.25112039295073,39.288638535511424,39.32615667807212,39.36367482063281,39.4011929631935,39.438711105754194,39.47622924831489,39.51374739087558,39.55126553343627,39.58878367599696,39.62630181855765,39.66381996111834,39.701338103679035,39.73885624623973,39.77637438880042,39.81389253136111,39.851410673921805,39.88892881648249,39.92644695904319,39.963965101603875,40.00148324416456,40.03900138672525,40.076519529285946,40.114037671846646,40.15155581440733,40.18907395696802,40.226592099528716,40.26411024208941,40.3016283846501,40.33914652721079,40.376664669771486,40.41418281233217,40.45170095489287,40.48921909745356,40.526737240014256,40.566012140141375,40.60616541905171,40.64631869796205,40.68647197687239,40.72662525578273,40.76677853469307,40.806931813603406,40.847085092513744,40.88723837142408,40.92739165033442,40.96754492924476,41.0076982081551,41.047851487065444,41.08800476597578,41.12815804488612,41.16831132379645,41.2084646027068,41.24861788161713,41.28877116052747,41.32892443943781,41.36907771834814,41.40923099725849,41.44938427616882,41.48953755507917,41.529690833989505,41.569844112899844,41.609997391810175,41.65015067072052,41.69030394963086,41.7304572285412,41.770610507451536,41.810763786361875,41.85091706527221,41.89107034418255,41.93122362309289,41.97137690200323,42.01153018091357,42.051683459823906,42.091836738734244,42.13199001764458,42.17214329655492,42.21229657546526,42.2524498543756,42.29260313328594,42.332756412196275,42.372909691106614,42.41306297001695,42.45321624892729,42.49336952783763,42.53352280674797,42.573676085658306,42.613829364568645,42.65497821250206,42.6962175653527,42.73745691820336,42.778696271054,42.81993562390464,42.861174976755294,42.90241432960593,42.943653682456585,42.98489303530722,43.026132388157876,43.06737174100852,43.10861109385917,43.14985044670982,43.19108979956046,43.23232915241111,43.27356850526176,43.3148078581124,43.356047210963055,43.397286563813694,43.43852591666435,43.479765269514985,43.52100462236564,43.562243975216276,43.60348332806693,43.644722680917575,43.68596203376822,43.727201386618866,43.76844073946951,43.80968009232016,43.8509194451708,43.892158798021455,43.93811164179381,43.988777976487896,44.03944431118198,44.09011064587605,44.14077698057014,44.191443315264216,44.242109649958294,44.29277598465238,44.343442319346465,44.39410865404054,44.44477498873462,44.49544132342871,44.546107658122786,44.596773992816864,44.64744032751095,44.69810666220502,44.7487729968991,44.799439331593184,44.85010566628726,44.90077200098135,44.95143833567543,45.002104670369505,45.05277100506359,45.10343733975767,45.15410367445175,45.20477000914583,45.25543634383991,45.306102678533996,45.356769013228075,45.40743534792216,45.45810168261623,45.50876801731032,45.55943435200439,45.61010068669847,45.66076702139256,45.711433356086644,45.762099690780715,45.8127660254748,45.86343236016887,45.91409869486296,45.96476502955704,46.01543136425112,46.0660976989452,46.116764033639285,46.16743036833336,46.218096703027435,46.26876303772151,46.3194293724156,46.370095707109684,46.420762041803755,46.47142837649784,46.522094711191926,46.572761045886004,46.62342738058008,46.67409371527417,46.72476004996824,46.775426384662325,46.82609271935641,46.876759054050495,46.92742538874457,46.97809172343865,47.02875805813272,47.07942439282681,47.130090727520894,47.180757062214965,47.231423396909044,47.282089731603136,47.332756066297215,47.383422400991286,47.43408873568538,47.48475507037946,47.53542140507353,47.58608773976761,47.6367540744617,47.68742040915577,47.738086743849856,47.78875307854394,47.83941941323801,47.89009302042044,47.940787405995195,47.99148179156997,48.042176177144725,48.0928705627195,48.019297436012536,47.69718928474226,47.37508113347199,47.052972982201695,46.730864830931424,46.40875667966115,46.086648528390846,45.76454037712055,45.44243222585031,45.12032407458001,44.79821592330972,44.476107772039434,44.15399962076917,43.83189146949887,43.50978331822861,43.187675166958336,42.86556701568803,42.54345886441775,42.221350713147494,41.899242561877195,41.57713441060689,41.25502625933662,40.933898489364765,40.61767286853925,40.30144724771378,39.985221626888304,39.66899600606279,39.35277038523732,39.03654476441184,38.72031914358634,38.40409352276083,38.08786790193538,37.77164228110988,37.45541666028437,37.13919103945889,36.82296541863342,36.50673979780792,36.19051417698243,35.87428855615696,35.558062935331456,35.24183731450598,34.92561169368051,34.609386072855,34.29316045202949,33.97693483120402,33.66070921037854,33.344483589553036,33.02825796872756,32.71203234790208,32.395806727076575,32.0795811062511,31.763355485425624,31.44712986460012,31.130904243774616,30.814678622949167,30.498453002123664,30.182227381298155,29.866001760472678,29.549776139647204,29.2335505188217,28.917324897996224,28.601099277170746,28.28487365634524,27.968648035519763,27.652422414694286,27.33619679386878,27.019971173043274,26.703745552217825,26.387519931392326,26.07129431056682,25.755068689741343,25.438843068915865,25.12261744809036,24.806391827264882,24.490166206439405,24.173940585613902,23.857714964788396,23.541489343962947,23.22526372313744,22.90903810231194,22.59281248148646,22.276586860660984,21.96036123983548,21.65473377831586,21.40209711332535,21.149460448334835,20.896823783344324,20.644187118353855,20.391550453363337,20.138913788372825,19.88627712338236,19.640032023001094,19.39445971517707,19.148887407353087,18.903315099529063,18.65774279170504,18.412170483881017,18.166598176057036,17.92102586823301,17.675453560408986,17.429881252585005,17.184308944760982,16.938736636936955,16.693164329112975,16.44759202128895,16.202019713464924,15.956447405640946,15.710875097816922,15.465302789992895,15.21973048216887,14.97415817434489,14.728585866520866,14.483013558696841,14.237441250872862,13.991868943048836,13.746296635224809,13.500724327400828,13.255152019576808,13.009579711752782,12.764007403928757,12.518435096104776,12.27286278828075,12.027290480456726,11.781718172632747,11.536145864808722,11.354915273264652,11.219643050491985,11.084370827719294,10.949098604946602,10.81382638217394,10.678554159401248,10.543281936628556,10.408009713855865,10.2727374910832,10.13746526831051,10.002193045537819,9.866920822765154,9.731648599992463,9.596376377219771,9.461104154447106,9.325831931674415,9.190559708901725,9.055287486129034,8.920015263356367,8.784743040583677,8.649470817810986,8.514198595038321,8.378926372265632,8.24365414949294,8.108381926720275,7.973109703947584,7.837837481174894,7.702565258402227,7.567293035629536,7.432020812856845,7.296748590084155,7.161476367311488,7.026204144538798,6.890931921766108,6.7538256016558496,6.611550449045666,6.469275296435482,6.327000143825324,6.18472499121514,6.0424498386049565,5.900174685994773,5.757899533384616],[34.66462683442332,34.70452080995963,34.74441478549595,34.78430876103226,34.82420273656857,34.86409671210489,34.9039906876412,34.943884663177506,34.98377863871382,35.02367261425013,35.06356658978645,35.103460565322756,35.14335454085907,35.18324851639538,35.223142491931696,35.263036467468005,35.302930443004314,35.34282441854063,35.38271839407694,35.422612369613255,35.46250634514956,35.50240032068588,35.54229429622219,35.582188271758504,35.62208224729481,35.66197622283113,35.701870198367445,35.741764173903746,35.78165814944006,35.82155212497638,35.86144610051269,35.901340076048996,35.94123405158531,35.98112802712163,36.021022002657936,36.06091597819425,36.10080995373056,36.14070392926687,36.180597904803186,36.220491880339495,36.26038585587581,36.30027983141212,36.340173806948435,36.380067782484744,36.41996175802106,36.45985573355737,36.49974970909368,36.53964368462999,36.5795376601663,36.61943163570262,36.65932561123893,36.69921958677524,36.73911356231156,36.77900753784787,36.81890151338418,36.85879548892049,36.8986894644568,36.93858343999312,36.978477415529426,37.01837139106574,37.056588783977375,37.09447085780073,37.13235293162409,37.170235005447445,37.20811707927081,37.24599915309417,37.28388122691752,37.32176330074088,37.35964537456424,37.39752744838759,37.43540952221096,37.473291596034315,37.511173669857676,37.54905574368103,37.586937817504385,37.624819891327746,37.6627019651511,37.70058403897446,37.73846611279782,37.776348186621185,37.81423026044454,37.8521123342679,37.889994408091255,37.927876481914616,37.96406554539571,37.99991600680836,38.03576646822101,38.071616929633656,38.107467391046306,38.14331785245895,38.1791683138716,38.21501877528424,38.25086923669689,38.28671969810954,38.32257015952219,38.35842062093484,38.39427108234749,38.43012154376013,38.46597200517278,38.50182246658543,38.537672927998074,38.573523389410724,38.60937385082337,38.64522431223602,38.68107477364866,38.71692523506131,38.752775696473954,38.788626157886604,38.825866355359935,38.86338449792062,38.90090264048132,38.938420783042005,38.97593892560269,39.01345706816339,39.05097521072408,39.088493353284775,39.12601149584547,39.16352963840616,39.201047780966846,39.238565923527545,39.27608406608823,39.31360220864892,39.351120351209616,39.38863849377031,39.426156636331,39.46367477889169,39.501192921452386,39.53871106401307,39.576229206573764,39.61374734913446,39.65126549169515,39.68878363425584,39.726301776816534,39.76381991937723,39.80133806193791,39.838856204498605,39.8763743470593,39.91389248961999,39.95141063218068,39.988928774741375,40.02644691730207,40.06396505986275,40.10148320242345,40.13900134498414,40.17651948754484,40.21403763010552,40.251555772666215,40.28907391522691,40.32659205778759,40.36411020034829,40.40162834290898,40.43914648546968,40.47666462803036,40.514182770591056,40.55170091315175,40.589219055712434,40.626737198273126,40.66425534083382,40.70177348339452,40.739291625955204,40.776809768515896,40.81432791107659,40.85184605363729,40.889364196197974,40.92688233875866,40.96440048131936,41.001918623880044,41.04119352400717,41.08134680291751,41.121500081827854,41.161653360738185,41.201806639648524,41.24195991855886,41.2821131974692,41.32226647637954,41.36241975528988,41.402573034200216,41.44272631311056,41.4828795920209,41.52303287093123,41.56318614984157,41.603339428751916,41.643492707662254,41.68364598657259,41.72379926548293,41.76395254439327,41.80410582330361,41.84425910221394,41.884412381124285,41.92456566003462,41.96471893894496,42.0048722178553,42.04502549676564,42.08517877567598,42.12533205458631,42.165485333496655,42.20563861240699,42.24579189279077,42.287031245641415,42.32827059849206,42.36950995134271,42.41074930419336,42.451988657044005,42.49322800989465,42.53446736274529,42.57570671559594,42.61694606844659,42.65818542129723,42.699424774147886,42.740664126998524,42.78190347984918,42.823142832699816,42.86438218555047,42.90562153840112,42.94686089125176,42.98810024410241,43.02933959695305,43.0705789498037,43.11181830265434,43.153057655504995,43.19429700835563,43.235536361206286,43.276775714056924,43.31801506690758,43.35925441975822,43.40049377260887,43.44173312545952,43.48297247831016,43.524211831160805,43.56545118401146,43.606690536862104,43.64792988971275,43.689169242563395,43.73040859541405,43.771647948264686,43.81288730111534,43.85412665396598,43.89536600681662,43.93660535966727,43.97784471251792,44.019084065368574,44.06032341821921,44.10156277106986,44.142802123920504,44.18404147677116,44.225280829621795,44.26652018247245,44.307759535323086,44.34899888817374,44.39023824102438,44.43619108479675,44.48685741949083,44.53752375418491,44.58819008887899,44.63885642357307,44.68952275826715,44.74018909296123,44.790855427655316,44.841521762349394,44.89218809704347,44.94285443173755,44.99352076643164,45.044187101125715,45.09485343581979,45.145519770513886,45.19618610520796,45.246852439902035,45.29751877459612,45.3481851092902,45.39885144398427,45.44951777867837,45.50018411337244,45.55085044806652,45.6015167827606,45.65218311745468,45.70284945214876,45.75351578684284,45.804182121536925,45.854848456231004,45.90551479092508,45.95618112561917,46.00684746031325,46.057513795007324,46.10818012970141,46.15884646439549,46.20951279908957,46.260179133783645,46.31084546847773,46.361511803171815,46.41217813786589,46.462844472559965,46.51351080725405,46.56417714194813,46.614843476642214,46.66550981133629,46.716176146030364,46.76684248072445,46.81750881541853,46.86817515011262,46.91884148480669,46.96951820873261,47.020212594307374,47.07090697988213,47.1216013654569,47.17229575103167,47.22299013660642,47.27368452218119,47.32437890775596,47.375073293330715,47.42576767890548,47.476462064480245,47.52715645005501,47.57785083562977,47.62854522120453,47.6792396067793,47.729933992354056,47.78062837792882,47.83132276350359,47.88201714907835,47.932711534653116,47.98340592022788,48.03410030580264,48.084794691377404,48.13548907695217,48.186183462526934,48.23687784810169,48.28757223367646,48.33826661925122,48.38896100482599,48.439655390400745,48.49034977597552,48.541044161550275,48.59173854712504,48.518165420418086,48.19605726914781,47.873949117877544,47.551840966607244,47.22973281533697,46.9076246640667,46.585516512796396,46.2634083615261,45.94130021025586,45.61919205898556,45.29708390771527,44.97497575644499,44.65286760517472,44.33075945390442,44.008651302634156,43.686543151363885,43.36443500009358,43.04232684882331,42.720218697553044,42.39811054628274,42.07600239501244,41.75389424374217,41.4317860924719,41.109677941201596,40.787569789931325,40.46546163866106,40.14335348739076,39.82124533612049,39.49913718485022,39.17702903357992,38.854920882309614,38.53281273103938,38.21070457976908,37.88859642849878,37.5664882772285,37.24438012595824,36.92227197468794,36.60016382341767,36.278055672147396,35.955947520877096,35.633839369606825,35.31173121833656,34.989623067066255,34.667514915795955,34.34540676452569,34.02329861325541,33.70119046198512,33.37908231071485,33.05697415944458,32.73486600817427,32.41275785690401,32.09064970563374,31.76854155436343,31.44643340309314,31.124325251822896,30.802217100552593,30.480108949282297,30.158000798012022,29.835892646741755,29.51378449547145,29.191676344201184,28.869568192930913,28.547460041660614,28.22535189039034,27.90324373912007,27.56650959185702,27.22363779734121,26.880766002825453,26.537894208309634,26.19502241379382,25.85215061927803,25.509278824762248,25.166407030246425,24.823535235730645,24.48066344121486,24.137791646699043,23.794919852183227,23.452048057667472,23.109176263151653,22.766304468635838,22.42343267412005,22.080560879604263,21.737689085088448,21.412234327449006,21.17386475419108,20.935495180933152,20.697125607675222,20.458756034417338,20.220386461159407,19.982016887901484,19.7436473146436,19.50261959455805,19.257047286734025,19.01147497891004,18.765902671086018,18.520330363261994,18.27475805543797,18.02918574761399,17.783613439789963,17.53804113196594,17.292468824141956,17.046896516317933,16.80132420849391,16.55575190066993,16.310179592845905,16.06460728502188,15.819034977197898,15.573462669373875,15.327890361549848,15.082318053725823,14.836745745901844,14.591173438077817,14.345601130253794,14.100028822429813,13.85445651460579,13.608884206781763,13.363311898957782,13.117739591133759,12.872167283309736,12.626594975485709,12.38102266766173,12.135450359837703,11.889878052013678,11.644305744189701,11.398733436365674,11.217502844821606,11.08223062204894,10.946958399276248,10.81168617650356,10.676413953730894,10.541141730958202,10.40586950818551,10.27059728541282,10.135325062640154,10.000052839867463,9.864780617094771,9.729508394322108,9.594236171549415,9.458963948776725,9.32369172600406,9.18841950323137,9.053147280458678,8.917875057685988,8.782602834913323,8.647330612140632,8.51205838936794,8.376786166595275,8.241513943822586,8.106241721049894,7.9709694982772294,7.835697275504536,7.7004250527318465,7.56515282995918,7.429880607186489,7.294608384413799,7.159336161641109,7.0240639388684425,6.888791716095752,6.753519493323061,6.623809092653475,6.495509894247939,6.367210695842404,6.238911497436892,6.110612299031357,5.98231310062582,5.854013902220284,5.7257147038147735],[35.07909510047554,35.11898907601186,35.158883051548166,35.198777027084475,35.23867100262079,35.2785649781571,35.31845895369341,35.358352929229724,35.39824690476604,35.43814088030235,35.478034855838665,35.517928831374974,35.55782280691128,35.5977167824476,35.637610757983914,35.67750473352022,35.71739870905653,35.75729268459285,35.797186660129164,35.83708063566547,35.87697461120178,35.9168685867381,35.956762562274406,35.99665653781072,36.03655051334703,36.07644448888335,36.116338464419655,36.156232439955964,36.19612641549228,36.23602039102859,36.275914366564905,36.31580834210122,36.35570231763753,36.395596293173845,36.435490268710154,36.47538424424647,36.51527821978278,36.55517219531909,36.595066170855404,36.63496014639171,36.67485412192803,36.71474809746434,36.75464207300065,36.79453604853696,36.83443002407328,36.87432399960959,36.9142179751459,36.95411195068221,36.99400592621852,37.033899901754836,37.073793877291145,37.11368785282746,37.15358182836377,37.193475803900085,37.2333697794364,37.27326375497271,37.31315773050902,37.353051706045335,37.392945681581644,37.43283965711796,37.47273363265427,37.512627608190584,37.55252158372689,37.5924155592632,37.63230953479952,37.672203510335834,37.71209748587214,37.75199146140845,37.79188543694477,37.831779412481076,37.87167338801739,37.9115673635537,37.95146133909002,37.991355314626325,38.03124929016264,38.07114326569895,38.11036660979902,38.14824868362238,38.18613075744574,38.2240128312691,38.261894905092454,38.299776978915816,38.33765905273917,38.37554112656254,38.411730190043635,38.447580651456285,38.48343111286893,38.51928157428158,38.55513203569422,38.59098249710687,38.626832958519515,38.663239315693986,38.700757458254685,38.73827560081538,38.775793743376056,38.813311885936756,38.85083002849745,38.88834817105814,38.92586631361883,38.96338445617952,39.00090259874022,39.038420741300904,39.075938883861596,39.11345702642229,39.150975168982974,39.188493311543674,39.226011454104366,39.26352959666505,39.301047739225744,39.33856588178644,39.37608402434713,39.41360216690782,39.451120309468514,39.48863845202921,39.52615659458989,39.56367473715059,39.60119287971128,39.63871102227197,39.67622916483266,39.713747307393355,39.75126544995405,39.78878359251474,39.82630173507543,39.86381987763612,39.90133802019682,39.9388561627575,39.9763743053182,40.01389244787889,40.05141059043957,40.08892873300027,40.126446875560966,40.16396501812166,40.20148316068234,40.23900130324304,40.27651944580373,40.31403758836443,40.351555730925114,40.389073873485806,40.4265920160465,40.464110158607184,40.501628301167884,40.53914644372857,40.57666458628926,40.614182728849954,40.651700871410654,40.68921901397134,40.72673715653204,40.764255299092724,40.80177344165342,40.83929158421411,40.8768097267748,40.914327869335494,40.95184601189618,40.989364154456865,41.026882297017565,41.06440043957825,41.10191858213894,41.13943672469964,41.17695486726033,41.21447300982102,41.25199115238171,41.28950929494241,41.327027437503105,41.36454558006378,41.40206372262448,41.439581865185176,41.47710000774586,41.51637490787299,41.55652818678332,41.59668146569366,41.63683474460401,41.67698802351434,41.71714130242468,41.757294581335024,41.797447860245356,41.837601139155694,41.87784492593015,41.91908427878079,41.96032363163145,42.00156298448209,42.04280233733274,42.08404169018338,42.12528104303403,42.166520395884675,42.20775974873531,42.24899910158596,42.29023845443661,42.33147780728726,42.37271716013791,42.41395651298855,42.455195865839194,42.49643521868985,42.53767457154049,42.57891392439114,42.62015327724178,42.66139263009243,42.70263198294308,42.74387133579372,42.785110688644366,42.82635004149502,42.86758939434566,42.90882874719631,42.950068100046956,42.9913074528976,43.03254680574824,43.07378615859889,43.11502551144954,43.156264864300184,43.19750421715083,43.23874357000148,43.27998292285212,43.32122227570277,43.36246162855342,43.403700981404064,43.44494033425472,43.48617968710536,43.52741903995601,43.568658392806654,43.6098977456573,43.65113709850794,43.692376451358584,43.733615804209236,43.77485515705988,43.81609450991053,43.85733386276117,43.89857321561182,43.93981256846247,43.98105192131311,44.02229127416376,44.06353062701441,44.104769979865054,44.1460093327157,44.187248685566345,44.228488038417,44.269727391267644,44.31096674411829,44.35220609696893,44.39344544981957,44.434684802670226,44.47592415552087,44.51716350837152,44.55840286122216,44.599642214072816,44.640881566923454,44.6821209197741,44.723360272624745,44.7645996254754,44.80583897832604,44.84707833117669,44.888317684027335,44.9342705277997,44.98493686249378,45.03560319718786,45.08626953188194,45.136935866576025,45.1876022012701,45.23826853596418,45.28893487065827,45.33960120535235,45.39026754004642,45.4409338747405,45.49160020943459,45.542266544128665,45.59293287882275,45.643599213516836,45.694265548210915,45.744931882904986,45.79559821759907,45.84626455229315,45.89693088698723,45.94759722168132,45.9982635563754,46.048943397044795,46.09963778261955,46.15033216819432,46.20102655376908,46.25172093934385,46.30241532491861,46.35310971049338,46.40380409606814,46.4544984816429,46.50519286721767,46.55588725279243,46.606581638367196,46.65727602394196,46.707970409516726,46.758664795091484,46.80935918066625,46.860053566241014,46.91074795181577,46.96144233739054,47.012136722965295,47.06283110854007,47.11352549411483,47.164219879689604,47.214914265264355,47.26560865083912,47.31630303641389,47.36699742198866,47.417691807563415,47.46838619313817,47.51908057871294,47.5697749642877,47.62046934986247,47.67116373543723,47.72185812101199,47.772552506586756,47.82324689216153,47.87394127773629,47.92463566331105,47.97533004888581,48.026024434460574,48.07671882003534,48.12741320561011,48.17810759118487,48.22880197675963,48.2794963623344,48.330190747909164,48.380885133483915,48.43157951905869,48.482273904633445,48.5329682902082,48.583662675782975,48.63435706135774,48.685051446932505,48.73574583250726,48.78644021808203,48.83713460365679,48.88782898923155,48.93852337480632,48.98921776038108,49.039912145955846,49.090606531530604,49.01703340482365,48.69492525355337,48.372817102283115,48.05070895101281,47.72860079974254,47.40649264847227,47.08438449720197,46.762276345931674,46.440168194661425,46.118060043391125,45.79595189212083,45.47384374085056,45.15173558958029,44.829627438309984,44.50751928703972,44.18541113576945,43.86330298449916,43.54119483322888,43.21908668195861,42.89697853068831,42.57487037941801,42.25276222814774,41.930654076877474,41.608545925607174,41.286437774336896,40.96432962306663,40.64222147179633,40.32011332052606,39.998005169255784,39.66538459429414,39.32251279977832,38.979641005262565,38.636769210746756,38.29389741623094,37.951025621715154,37.60815382719937,37.265282032683544,36.922410238167764,36.57953844365198,36.23666664913616,35.893794854620374,35.55092306010459,35.20805126558877,34.865179471072956,34.52230767655717,34.17943588204138,33.836564087525566,33.49369229300978,33.15082049849399,32.807948703978184,32.46507690946239,32.12220511494661,31.779333320430794,31.43646152591497,31.09358973139922,30.750717936883404,30.407846142367585,30.064974347851802,29.722102553336015,29.3792307588202,29.03635896430441,28.693487169788625,28.35061537527281,28.007743580757023,27.66487178624124,27.32199999172542,26.979128197209604,26.636256402693846,26.29338460817803,25.95051281366222,25.607641019146428,25.264769224630644,24.921897430114825,24.57902563559904,24.236153841083254,23.893282046567435,23.55041025205162,23.20753845753587,22.86466666302005,22.52179486850423,22.178923073988447,21.83605127947266,21.493179484956844,21.167724727317406,20.929355154059472,20.690985580801545,20.452616007543618,20.214246434285734,19.975876861027807,19.737507287769876,19.499137714511992,19.260768141254065,19.022398567996134,18.78402899473825,18.545659421480323,18.307289848222396,18.068920274964466,17.83055070170658,17.592181128448654,17.353811555190724,17.11544198193284,16.877072408674913,16.638702835416986,16.4003332621591,16.16196368890117,15.923594115643242,15.68299512743375,15.437422819609727,15.191850511785702,14.946278203961676,14.700705896137697,14.455133588313672,14.209561280489647,13.963988972665668,13.71841666484164,13.472844357017618,13.227272049193637,12.981699741369612,12.736127433545587,12.490555125721563,12.244982817897583,11.999410510073556,11.753838202249533,11.508265894425554,11.262693586601527,11.081462995057457,10.94619077228479,10.8109185495121,10.675646326739411,10.540374103966744,10.405101881194055,10.269829658421363,10.134557435648674,9.999285212876007,9.864012990103316,9.728740767330626,9.59346854455796,9.45819632178527,9.322924099012578,9.187651876239912,9.052379653467222,8.917107430694532,8.78183520792184,8.646562985149174,8.517267643203578,8.388968444798044,8.260669246392531,8.132370047986997,8.00407084958146,7.875771651175949,7.747472452770413,7.619173254364878,7.490874055959366,7.362574857553829,7.2342756591482935,7.105976460742759,6.977677262337247,6.849378063931711,6.7210788655261755,6.592779667120663,6.464480468715128,6.336181270309593,6.207882071904081,6.079582873498545,5.951283675093009,5.822984476687474,5.694685278281963],[35.48844706332472,35.52834103886103,35.56823501439734,35.608128989933654,35.64802296546996,35.68791694100628,35.72781091654259,35.7677048920789,35.80759886761521,35.84749284315153,35.88738681868784,35.92728079422415,35.96717476976046,36.00706874529678,36.04696272083309,36.086856696369395,36.12675067190571,36.16664464744203,36.20653862297833,36.246432598514644,36.28632657405096,36.326220549587276,36.36611452512358,36.4060085006599,36.4459024761962,36.48579645173252,36.525690427268835,36.56558440280514,36.60547837834146,36.64537235387777,36.685266329414084,36.72516030495039,36.7650542804867,36.80494825602302,36.84484223155933,36.88473620709565,36.92463018263196,36.96452415816826,37.00441813370458,37.044312109240884,37.08420608477721,37.124100060313516,37.16399403584983,37.20388801138614,37.24378198692245,37.283675962458766,37.323569937995074,37.36346391353139,37.4033578890677,37.443251864604015,37.483145840140324,37.52303981567664,37.56293379121295,37.602827766749265,37.64272174228557,37.68261571782189,37.7225096933582,37.762403668894514,37.80229764443082,37.84219161996713,37.88208559550345,37.92197957103976,37.96187354657607,38.00176752211238,38.0416614976487,38.08155547318501,38.12144944872132,38.16134342425763,38.201237399793946,38.241131375330255,38.28102535086657,38.32091932640288,38.360813301939196,38.400707277475504,38.44060125301181,38.48203812174958,38.52378356689622,38.565529012042866,38.607274457189504,38.64901990233614,38.69076534748279,38.73251079262943,38.77425623777607,38.8160016829227,38.85548883709441,38.89452433307114,38.93355982904786,38.972595325024585,39.01163082100131,39.05066631697803,39.08970181295476,39.12873730893148,39.1677728049082,39.20554384122885,39.24306198378954,39.28058012635023,39.31809826891092,39.355616411471615,39.393134554032315,39.430652696593,39.4681708391537,39.505688981714385,39.54320712427508,39.58072526683577,39.61824340939646,39.655761551957156,39.69327969451785,39.73079783707853,39.768315979639226,39.80583412219992,39.84335226476061,39.880870407321304,39.918388549881996,39.95590669244269,39.993424835003374,40.03094297756407,40.06846112012476,40.10597926268545,40.143497405246144,40.18101554780684,40.218533690367536,40.25605183292822,40.29356997548891,40.33108811804961,40.36860626061029,40.406124403170985,40.44364254573168,40.48116068829237,40.51867883085306,40.55619697341376,40.59371511597445,40.63123325853513,40.66875140109583,40.70626954365652,40.74378768621721,40.7813058287779,40.818823971338595,40.85634211389929,40.89386025645998,40.93137839902067,40.96889654158136,41.00641468414205,41.04393282670274,41.081450969263436,41.11896911182413,41.15648725438482,41.194005396945514,41.231523539506206,41.2690416820669,41.30655982462759,41.344077967188284,41.38159610974897,41.41911425230967,41.456632394870354,41.49415053743105,41.53166867999174,41.569186822552425,41.606704965113124,41.64422310767381,41.6817412502345,41.719259392795195,41.75677753535589,41.79429567791658,41.83181382047727,41.869331963037965,41.90685010559865,41.94436824815934,41.985222018080975,42.02774360168307,42.07026518528516,42.112786768887254,42.15530835248934,42.19782993609144,42.24035151969353,42.28287310329563,42.32539468689773,42.36791627049982,42.40944890615328,42.45074884657274,42.492048786992214,42.533348727411685,42.57464866783115,42.61594860825062,42.65724854867008,42.698548489089546,42.739848429509024,42.78114836992849,42.82244831034796,42.86374825076743,42.90504819118689,42.94634813160637,42.987648072025834,43.0289480124453,43.07024795286477,43.11154789328424,43.15284783370371,43.19414777412318,43.235447714542644,43.27674765496211,43.318047595381586,43.35934753580105,43.40064747622052,43.44194741663999,43.483247357059454,43.524547297478925,43.565847237898396,43.60714717831786,43.64844711873733,43.6897470591568,43.731046999576265,43.772346939995735,43.813646880415206,43.85494682083467,43.89624676125413,43.93754670167361,43.978846642093075,44.02014658251255,44.061446522932016,44.10274646335148,44.14404640377095,44.18534634419042,44.22664628460989,44.267946225029355,44.309246165448826,44.35054610586829,44.39184604628776,44.43314598670723,44.474445927126695,44.515745867546165,44.557045807965636,44.59834574838511,44.63964568880457,44.68094562922404,44.72224556964351,44.76354551006298,44.804845450482446,44.84614539090192,44.88744533132137,44.928745271740844,44.970045212160315,45.011345152579786,45.05264509299925,45.09394503341872,45.13524497383819,45.17654491425766,45.21784485467713,45.259144795096596,45.30044473551607,45.34174467593553,45.383044616354994,45.42835477395942,45.47767514874879,45.52699552353815,45.57631589832751,45.62563627311687,45.67495664790623,45.724966152666916,45.77567491942943,45.826383686191924,45.87709245295442,45.92780121971692,45.97850998647942,46.02921875324193,46.07992752000443,46.13063628676693,46.181345053529434,46.232053820291924,46.282762587054435,46.33347135381693,46.38418012057944,46.434888887341934,46.485597654104446,46.536306420866936,46.58701518762944,46.637723954391944,46.68843272115444,46.739141487916946,46.78985025467944,46.84055902144195,46.89126778820445,46.94197655496695,46.992685321729454,47.043394088491944,47.094102855254455,47.14481162201695,47.19552038877946,47.246229155541954,47.29693792230446,47.34764668906696,47.39835545582946,47.449064222591964,47.49977298935446,47.55048175611695,47.60119052287946,47.651899289641975,47.702608056404465,47.75331682316697,47.80402558992948,47.85473435669197,47.905443123454475,47.95615189021698,48.00686065697948,48.057569423741974,48.10827819050448,48.15898695726698,48.20969572402948,48.260404490791984,48.31111325755449,48.361822024316986,48.41253079107949,48.46323955784199,48.51394832460449,48.56465709136699,48.61536585812949,48.66607462489199,48.716783391654495,48.767492158417,48.8182009251795,48.868909691941994,48.9196184587045,48.970327225467,49.0210359922295,49.071744758992,49.12245352575451,49.173162292517006,49.2238710592795,49.27457982604201,49.325288592804505,49.37599735956701,49.426706126329506,49.47741489309202,49.528123659854515,49.57883242661702,49.49689565545255,49.14966780843427,48.802439961416,48.45521211439769,48.107984267379415,47.76075642036114,47.41352857334283,47.06630072632453,46.71907287930629,46.37184503228798,46.024617185269676,45.6773893382514,45.33016149123313,44.982933644214825,44.63570579719655,44.288477950178276,43.94125010315997,43.5940222561417,43.24679440912342,42.899566562105115,42.552338715086805,42.20511086806854,41.85788302105026,41.51065517403196,41.16342732701368,40.816199479995404,40.4689716329771,40.121743785958834,39.77451593894055,39.42728809192225,39.08006024490394,38.73513140513097,38.39225961061516,38.04938781609934,37.70651602158356,37.36364422706777,37.02077243255195,36.677900638036164,36.335028843520384,35.99215704900457,35.64928525448879,35.306413459973,34.96354166545718,34.620669870941356,34.277798076425576,33.93492628190979,33.59205448739397,33.24918269287819,32.9063108983624,32.563439103846584,32.2205673093308,31.877695514815017,31.5348237202992,31.19195192578338,30.849080131267627,30.506208336751808,30.16333654223599,29.82046474772021,29.47759295320442,29.134721158688606,28.79184936417282,28.448977569657032,28.106105775141213,27.76323398062543,27.420362186109646,27.077490391593823,26.734618597078008,26.391746802562253,26.048875008046437,25.70600321353062,25.363131419014834,25.020259624499047,24.677387829983232,24.334516035467445,23.991644240951665,23.648772446435842,23.305900651920027,22.96302885740427,22.620157062888456,22.277285268372637,21.93441347385685,21.59154167934107,21.248669884825247,20.92321512718581,20.684845553927882,20.446475980669952,20.208106407412025,19.96973683415414,19.731367260896214,19.492997687638283,19.254628114380395,19.016258541122472,18.777888967864545,18.53951939460666,18.30114982134873,18.0627802480908,17.824410674832873,17.58604110157499,17.347671528317058,17.10930195505913,16.870932381801246,16.632562808543316,16.394193235285385,16.155823662027505,15.917454088769578,15.679084515511647,15.440714942253763,15.202345368995836,14.963975795737907,14.725606222479978,14.487236649222094,14.248867075964164,14.010497502706238,13.772127929448352,13.533758356190425,13.295388782932495,13.057019209674609,12.81864963641668,12.580280063158753,12.341910489900826,12.10354091664294,11.863370660309416,11.61779835248539,11.372226044661414,11.126653736837387,10.945423145293317,10.81015092252065,10.67487869974796,10.53960647697527,10.410726193753709,10.282426995348173,10.154127796942637,10.025828598537101,9.89752940013159,9.769230201726055,9.640931003320517,9.512631804915006,9.38433260650947,9.256033408103937,9.127734209698424,8.999435011292888,8.871135812887353,8.742836614481817,8.614537416076304,8.486238217670769,8.357939019265235,8.229639820859722,8.101340622454188,7.973041424048651,7.844742225643139,7.716443027237603,7.588143828832067,7.459844630426556,7.33154543202102,7.203246233615484,7.074947035209949,6.946647836804438,6.818348638398902,6.690049439993366,6.561750241587854,6.433451043182319,6.305151844776783,6.176852646371271,6.048553447965736,5.9202542495602,5.791955051154664,5.6636558527491525],[35.89353544152806,35.93342941706437,35.97332339260068,36.01321736813699,36.05311134367331,36.09300531920962,36.13289929474593,36.17279327028224,36.21268724581855,36.252581221354866,36.29247519689118,36.33236917242749,36.3722631479638,36.412157123500116,36.452051099036424,36.49194507457274,36.53183905010905,36.571733025645365,36.61162700118168,36.65152097671799,36.6914149522543,36.731308927790614,36.77120290332692,36.81109687886324,36.85099085439954,36.89088482993586,36.93077880547217,36.97067278100849,37.0105667565448,37.050460732081106,37.09035470761742,37.13024868315374,37.17014265869004,37.21003663422636,37.24993060976267,37.28982458529899,37.329718560835296,37.369612536371605,37.40950651190792,37.44940048744422,37.489294462980546,37.529188438516854,37.56908241405316,37.60897638958948,37.64887036512579,37.688764340662104,37.72865831619841,37.76855229173473,37.80844626727104,37.84834024280735,37.88823421834366,37.92812819387998,37.96802216941629,38.007916144952596,38.04781012048891,38.08770409602523,38.127598071561536,38.167492047097845,38.208003180021,38.24974862516765,38.291494070314286,38.333239515460924,38.37498496060756,38.41673040575421,38.45847585090085,38.500221296047485,38.54196674119412,38.58371218634077,38.62545763148741,38.667203076634046,38.70894852178069,38.75069396692733,38.792439412073975,38.83418485722061,38.87593030236725,38.91767574751389,38.95942119266053,39.001166637807174,39.04291208295382,39.08465752810045,39.126402973247096,39.168148418393734,39.20989386354038,39.25163930868702,39.29112646285873,39.330161958835454,39.36919745481217,39.4082329507889,39.44726844676562,39.486303942742346,39.525339438719065,39.56437493469579,39.60341043067252,39.64244592664924,39.68148142262596,39.720516918602684,39.7595524145794,39.79858791055614,39.837623406532856,39.87665890250958,39.9156943984863,39.95472989446302,39.99376539043975,40.032800886416474,40.071836382393194,40.11087187836992,40.14990737434664,40.188942870323366,40.22797836630009,40.26650807850147,40.30402622106216,40.34154436362285,40.379062506183544,40.41658064874424,40.45409879130492,40.491616933865615,40.52913507642631,40.566653218987,40.60417136154769,40.641689504108385,40.67920764666908,40.71672578922976,40.754243931790455,40.79176207435115,40.82928021691184,40.866798359472526,40.904316502033225,40.94183464459392,40.97935278715461,41.0168709297153,41.054389072275995,41.09190721483668,41.12942535739737,41.166943499958066,41.20446164251876,41.24197978507945,41.279497927640136,41.317016070200836,41.35453421276153,41.392052355322214,41.42957049788291,41.46708864044359,41.50460678300429,41.54212492556498,41.57964306812568,41.61716121068637,41.65467935324706,41.69219749580775,41.72971563836845,41.76723378092913,41.804751923489825,41.84227006605052,41.87978820861121,41.9173063511719,41.954824493732595,41.99234263629329,42.02986077885397,42.067378921414665,42.10489706397536,42.14241520653604,42.17993334909674,42.21745149165743,42.25496963421812,42.29248777677881,42.330005919339506,42.3675240619002,42.40504220446089,42.445895974382516,42.48841755798461,42.53093914158671,42.573460725188795,42.61598230879089,42.658503892392986,42.70102547599508,42.74354705959718,42.786068643199265,42.82859022680135,42.87111181040346,42.913633394005544,42.95615497760764,42.998676561209734,43.04119814481183,43.083719728413925,43.12624131201602,43.168762895618116,43.211284479220204,43.2538060628223,43.29632764642439,43.33884923002649,43.38137081362858,43.423892397230674,43.46641398083277,43.50893556443486,43.55145714803696,43.59397873163905,43.635598626699846,43.67689856711931,43.71819850753877,43.75949844795825,43.800798388377714,43.84209832879718,43.88339826921665,43.92469820963612,43.96599815005559,44.007298090475054,44.048598030894524,44.089897971313995,44.13119791173345,44.17249785215293,44.2137977925724,44.255097732991864,44.296397673411334,44.3376976138308,44.37899755425027,44.42029749466974,44.4615974350892,44.50289737550868,44.544197315928145,44.58549725634761,44.62679719676708,44.66809713718655,44.70939707760602,44.750697018025484,44.791996958444955,44.833296898864425,44.87459683928388,44.91589677970336,44.95719672012283,44.998496660542294,45.039796600961765,45.08109654138123,45.122396481800706,45.16369642222018,45.20499636263964,45.24629630305911,45.287596243478575,45.32889618389804,45.370196124317516,45.41149606473699,45.45279600515644,45.49409594557592,45.535395885995385,45.57669582641485,45.617995766834326,45.65929570725379,45.70059564767326,45.741895588092724,45.783195528512195,45.824495468931666,45.865795409351136,45.911105566955555,45.960425941744916,46.009746316534276,46.059066691323636,46.108387066112996,46.157707440902364,46.207027815691724,46.256348190481084,46.30566856527045,46.35498894005981,46.40430931484918,46.45362968963854,46.5029500644279,46.55227043921726,46.60159081400663,46.65091118879599,46.70023156358535,46.74955193837471,46.798872313164075,46.848192687953436,46.897513062742796,46.94683343753216,46.99615381232152,47.04547418711089,47.09479456190026,47.14411493668962,47.19343531147897,47.24275568626834,47.292076061057706,47.34139643584706,47.39071681063643,47.440037185425794,47.489357560215154,47.538677935004515,47.58910294438151,47.63981171114401,47.69052047790651,47.741229244669015,47.79193801143151,47.84264677819401,47.89335554495652,47.94406431171902,47.994773078481515,48.04548184524402,48.09619061200653,48.14689937876902,48.19760814553153,48.24831691229403,48.29902567905653,48.349734445819024,48.400443212581536,48.45115197934403,48.50186074610653,48.552569512869034,48.60327827963154,48.653987046394036,48.70469581315654,48.755404579919045,48.80611334668154,48.85682211344404,48.90753088020655,48.95823964696905,49.008948413731545,49.05965718049405,49.11036594725654,49.161074714019044,49.21178348078155,49.26249224754406,49.31320101430655,49.363909781069054,49.41461854783156,49.465327314594056,49.51603608135656,49.56674484811906,49.617453614881555,49.66816238164406,49.71887114840656,49.76957991516906,49.82028868193156,49.87099744869406,49.92170621545657,49.97241498221907,50.02312374898157,49.941186977817104,49.59395913079882,49.24673128378055,48.899503436762245,48.55227558974397,48.2050477427257,47.857819895707394,47.51059204868909,47.163364201670845,46.81613635465254,46.46890850763423,46.12168066061596,45.77445281359768,45.42722496657938,45.079997119561106,44.73276927254283,44.38554142552452,44.03831357850625,43.69108573148798,43.34385788446968,42.99663003745137,42.64940219043309,42.30217434341482,41.95494649639651,41.60771864937824,41.26049080235997,40.91326295534165,40.56603510832338,40.21880726130511,39.8715794142868,39.524351567268496,39.17712372025025,38.829895873231955,38.482668026213645,38.13544017919537,37.788212332177096,37.44098448515879,37.09375663814052,36.746528791122245,36.39930094410394,36.05207309708566,35.704845250067386,35.35761740304908,35.01038955603077,34.6631617090125,34.315933861994225,33.96870601497592,33.62147816795765,33.27425032093938,32.92702247392107,32.579794626902796,32.23256677988452,31.88533893286622,31.53811108584791,31.19088323882967,30.843655391811364,30.496427544793058,30.149199697774783,29.80197185075651,29.454744003738206,29.10751615671993,28.743461797582086,28.3759698028309,28.008477808079753,27.640985813328612,27.27349381857743,26.90600182382625,26.538509829075142,26.171017834323962,25.80352583957278,25.436033844821637,25.06854185007049,24.701049855319308,24.333557860568163,23.966065865817015,23.598573871065838,23.231081876314658,22.86358988156355,22.496097886812365,22.128605892061188,21.76111389731004,21.393621902558895,21.026129907807714,20.681385880451643,20.450381690070678,20.219377499689717,19.988373309308756,19.757369118927834,19.526364928546872,19.295360738165908,19.06435654778499,18.833352357404028,18.602348167023063,18.371343976642144,18.134897080709784,17.89676576225025,17.658634443790714,17.420503125331223,17.18237180687169,16.944240488412156,16.70610916995266,16.467977851493124,16.22984653303359,15.991715214574098,15.753583896114565,15.51545257765503,15.277321259195539,15.039189940736001,14.801058622276468,14.562927303816931,14.32479598535744,14.086664666897907,13.84853334843837,13.610402029978879,13.372270711519342,13.134139393059808,12.896008074600317,12.65787675614078,12.419745437681245,12.18161411922171,11.943482800762219,11.705351482302683,11.467220163843148,11.229088845383657,10.990957526924122,10.817018476983215,10.688931047412762,10.560843617842284,10.432756188271807,10.304668758701354,10.176581329130876,10.048493899560398,9.920406469989922,9.79231904041947,9.664231610848992,9.536144181278514,9.408056751708061,9.279969322137584,9.151881892567108,9.023794462996655,8.895707033426175,8.7676196038557,8.639532174285222,8.511444744714769,8.383357315144291,8.255269885573814,8.12718245600336,7.999095026432885,7.871007596862407,7.742920167291954,7.614832737721476,7.486745308150999,7.358657878580546,7.230570449010068,7.102483019439592,6.974395589869115,6.848965312302822,6.727471209661976,6.605977107021129,6.484483004380306,6.3629889017394605,6.241494799098614,6.120000696457791,5.998506593816944,5.877012491176098,5.755518388535252,5.63402428589443],[36.298623819731404,36.338517795267705,36.37841177080402,36.41830574634034,36.458199721876646,36.49809369741296,36.53798767294927,36.57788164848559,36.617775624021895,36.657669599558204,36.69756357509452,36.73745755063083,36.77735152616714,36.817245501703454,36.85713947723977,36.897033452776085,36.93692742831239,36.9768214038487,37.01671537938502,37.05660935492133,37.09650333045764,37.13639730599395,37.17629128153027,37.21618525706658,37.256079232602886,37.2959732081392,37.33586718367552,37.37576115921183,37.415655134748135,37.45554911028445,37.49544308582077,37.535337061357076,37.575231036893385,37.6151250124297,37.65501898796601,37.694912963502325,37.734806939038634,37.77470091457495,37.81459489011126,37.85448886564757,37.894382841183884,37.93427681672019,37.97571368343906,38.0174591285857,38.059204573732345,38.10095001887898,38.14269546402562,38.18444090917227,38.226186354318905,38.26793179946554,38.30967724461219,38.35142268975883,38.393168134905466,38.43491358005211,38.47665902519874,38.51840447034539,38.56014991549203,38.60189536063867,38.64364080578531,38.685386250931955,38.72713169607859,38.76887714122523,38.81062258637187,38.852368031518516,38.894113476665154,38.93585892181179,38.97760436695843,39.01934981210508,39.061095257251715,39.10284070239836,39.144586147545,39.18633159269163,39.228077037838275,39.269822482984914,39.31156792813156,39.3533133732782,39.39505881842484,39.436804263571474,39.47854970871812,39.520295153864765,39.562040599011404,39.60378604415804,39.64553148930468,39.687276934451326,39.72676408862303,39.76579958459976,39.80483508057648,39.8438705765532,39.88290607252993,39.921941568506654,39.96097706448337,40.00001256046009,40.039048056436826,40.078083552413545,40.117119048390265,40.15615454436699,40.19519004034372,40.23422553632044,40.273261032297164,40.31229652827388,40.35133202425061,40.39036752022733,40.42940301620406,40.46843851218078,40.5074740081575,40.54650950413423,40.58554500011095,40.624580496087674,40.66361599206439,40.70265148804112,40.741686984017846,40.780722479994566,40.819757975971285,40.85879347194802,40.897828967924745,40.936864463901465,40.975899959878184,41.0149354558549,41.05397095183164,41.093006447808364,41.13204194378508,41.1710774397618,41.21011293573852,41.24914843171525,41.288183927691975,41.327219423668694,41.364990458334766,41.40250860089545,41.44002674345615,41.47754488601684,41.51506302857753,41.55258117113823,41.590099313698914,41.627617456259614,41.6651355988203,41.70265374138099,41.740171883941684,41.77769002650238,41.81520816906306,41.852726311623755,41.89024445418445,41.92776259674514,41.96528073930584,42.002798881866525,42.04031702442721,42.0778351669879,42.1153533095486,42.152871452109295,42.19038959466998,42.22790773723068,42.265425879791366,42.30294402235206,42.34046216491275,42.37798030747344,42.415498450034136,42.45301659259482,42.49053473515552,42.528052877716206,42.565571020276906,42.60308916283759,42.640607305398284,42.678125447958976,42.71564359051967,42.75316173308036,42.79067987564105,42.828198018201746,42.86571616076243,42.90656993068406,42.94909151428615,42.99161309788825,43.03413468149034,43.07665626509243,43.11917784869453,43.16169943229662,43.20422101589872,43.246742599500806,43.2892641831029,43.331785766704996,43.37430735030709,43.41682893390919,43.45935051751128,43.50187210111337,43.544393684715466,43.58691526831756,43.62943685191966,43.671958435521745,43.71448001912384,43.757001602725936,43.79952318632803,43.842044769930126,43.88456635353222,43.9270879371343,43.9696095207364,44.01213110433849,44.05465268794059,44.097174271542684,44.13969585514478,44.18221743874687,44.22473902234897,44.26726060595105,44.30978218955315,44.35230377315525,44.39482535675734,44.43734694035943,44.47986852396153,44.52239010756362,44.56491169116571,44.60743327476781,44.649954858369895,44.69247644197199,44.734998025574086,44.77751960917618,44.82004119277828,44.861748347246404,44.90304828766587,44.94434822808534,44.98564816850481,45.02694810892427,45.068248049343744,45.109547989763215,45.15084793018268,45.19214787060215,45.23344781102161,45.27474775144108,45.316047691860554,45.357347632280025,45.398647572699495,45.43994751311896,45.48124745353843,45.5225473939579,45.56384733437737,45.605147274796835,45.646447215216305,45.68774715563577,45.72904709605524,45.7703470364747,45.811646976894174,45.852946917313645,45.894246857733116,45.93554679815258,45.97684673857204,46.01814667899151,46.05944661941099,46.100746559830455,46.14204650024992,46.183346440669396,46.22464638108886,46.26594632150833,46.3072462619278,46.34854620234726,46.39385635995168,46.443176734741044,46.492497109530404,46.541817484319765,46.59113785910914,46.64045823389849,46.68977860868785,46.73909898347722,46.78841935826658,46.83773973305594,46.88706010784531,46.93638048263467,46.98570085742403,47.035021232213396,47.08434160700276,47.133661981792116,47.18298235658148,47.232302731370844,47.281623106160204,47.33094348094957,47.380263855738924,47.4295842305283,47.47890460531765,47.52822498010702,47.57754535489639,47.62686572968575,47.67618610447511,47.72550647926447,47.774826854053835,47.824147228843195,47.87346760363256,47.92278797842192,47.97210835321128,48.02142872800064,48.07074910279002,48.12006947757937,48.16938985236874,48.2187102271581,48.26803060194746,48.31735097673682,48.36667135152619,48.415991726315546,48.465312101104914,48.514632475894274,48.563952850683634,48.613273225472994,48.66259360026237,48.71191397505173,48.76123434984108,48.81055472463045,48.85987509941981,48.90919547420917,48.95851584899854,49.007836223787905,49.057156598577265,49.10647697336662,49.155797348155986,49.20511772294536,49.25443809773472,49.30375847252408,49.35307884731344,49.4025309693336,49.45323973609611,49.503948502858606,49.5546572696211,49.6053660363836,49.65607480314611,49.70678356990861,49.757492336671106,49.8082011034336,49.858909870196115,49.90961863695861,49.96032740372112,50.011036170483614,50.06174493724612,50.11245370400861,50.16316247077111,50.21387123753362,50.26458000429612,50.31528877105862,50.36599753782112,50.41670630458363,50.467415071346124,50.38547830018166,50.038250453163386,49.69102260614511,49.3437947591268,48.99656691210853,48.64933906509025,48.30211121807195,47.95488337105364,47.60765552403541,47.26042767701709,46.91319982999879,46.565971982980514,46.21874413596224,45.87151628894394,45.524288441925655,45.17706059490738,44.829832747889085,44.48260490087081,44.13537705385254,43.788149206834234,43.44092135981592,43.09369351279764,42.74646566577937,42.39923781876107,42.052009971742805,41.70478212472453,41.357554277706214,40.99585204883269,40.62836005408154,40.26086805933037,39.893376064579186,39.52588406982808,39.1583920750769,38.79090008032572,38.42340808557457,38.05591609082342,37.68842409607225,37.3209321013211,36.95344010656996,36.58594811181877,36.21845611706763,35.85096412231648,35.48347212756531,35.11598013281412,34.74848813806298,34.38099614331183,34.013504148560656,33.64601215380951,33.27852015905836,32.91102816430718,32.543536169556035,32.176044174804886,31.808552180053706,31.441060185302533,31.073568190551416,30.70607619580024,30.33858420104906,29.97109220629791,29.60360021154677,29.236108216795586,28.868616222044437,28.501124227293296,28.13363223254212,27.76614023779097,27.398648243039823,27.031156248288646,26.663664253537462,26.296172258786356,25.928680264035172,25.561188269283992,25.19369627453285,24.826204279781702,24.45871228503052,24.091220290279374,23.723728295528232,23.356236300777052,22.98874430602587,22.621252311274752,22.25376031652358,21.8862683217724,21.51877632702125,21.1512843322701,20.783792337518936,20.439048310162853,20.208044119781892,19.97703992940093,19.74603573901997,19.515031548639044,19.284027358258086,19.05302316787712,18.822018977496203,18.591014787115242,18.360010596734277,18.129006406353355,17.898002215972394,17.66699802559143,17.435993835210468,17.204989644829546,16.973985454448584,16.742981264067623,16.5119770736867,16.28097288330574,16.04996869292478,15.818964502543857,15.587960312162895,15.35695612178193,15.12595193140101,14.894947741020049,14.663943550639086,14.431439936695313,14.193308618235818,13.955177299776285,13.717045981316748,13.478914662857257,13.240783344397723,13.002652025938186,12.764520707478695,12.526389389019158,12.288258070559625,12.05012675210009,11.811995433640597,11.573864115181062,11.335732796721526,11.097601478262035,10.859470159802498,10.685531109861593,10.55744368029114,10.429356250720664,10.301268821150186,10.173181391579734,10.045093962009254,9.917006532438776,9.7889191028683,9.660831673297848,9.532744243727372,9.404656814156894,9.27656938458644,9.148481955015964,9.020394525445486,8.892307095875033,8.764219666304555,8.642437330383151,8.520943227742306,8.399449125101484,8.277955022460638,8.156460919819791,8.034966817178967,7.913472714538121,7.791978611897276,7.670484509256452,7.548990406615605,7.42749630397476,7.306002201333936,7.18450809869309,7.063013996052243,6.941519893411399,6.8200257907705755,6.698531688129729,6.577037585488884,6.455543482848061,6.3340493802072135,6.212555277566368,6.091061174925544,5.969567072284699,5.848072969643852,5.726578867003006,5.605084764362184],[36.703712197934756,36.743606173471065,36.783500149007374,36.82339412454369,36.86328810008,36.903182075616314,36.94307605115263,36.98297002668893,37.02286400222525,37.062757977761564,37.10265195329788,37.14254592883419,37.1824399043705,37.22233387990681,37.26222785544312,37.30212183097944,37.34201580651575,37.38190978205206,37.42180375758837,37.46169773312468,37.501591708660996,37.54148568419731,37.581379659733614,37.62127363526994,37.661167610806245,37.701678741710495,37.74342418685714,37.78516963200377,37.82691507715042,37.868660522297056,37.910405967443694,37.95215141259034,37.99389685773697,38.03564230288362,38.07738774803026,38.1191331931769,38.16087863832354,38.202624083470184,38.24436952861682,38.28611497376346,38.327860418910106,38.369605864056744,38.41135130920338,38.45309675435003,38.49484219949666,38.536587644643305,38.57833308978994,38.62007853493658,38.66182398008323,38.703569425229865,38.745314870376504,38.78706031552315,38.828805760669795,38.870551205816426,38.912296650963064,38.95404209610971,38.99578754125635,39.037532986402994,39.07927843154963,39.12102387669627,39.162769321842916,39.20451476698955,39.24626021213619,39.28800565728284,39.32975110242947,39.371496547576115,39.41324199272275,39.45498743786939,39.49673288301604,39.538478328162675,39.58022377330932,39.62196921845596,39.6637146636026,39.705460108749236,39.74720555389588,39.78895099904252,39.83069644418915,39.8724418893358,39.91418733448244,39.95593277962908,39.997678224775726,40.03942366992236,40.08116911506901,40.12291456021564,40.16240171438735,40.20143721036408,40.240472706340796,40.27950820231752,40.31854369829425,40.35757919427097,40.396614690247695,40.43565018622442,40.47468568220114,40.51372117817786,40.55275667415459,40.59179217013131,40.63082766610803,40.669863162084766,40.708898658061486,40.747934154038205,40.786969650014925,40.82600514599166,40.86504064196838,40.904076137945104,40.94311163392182,40.98214712989855,41.02118262587527,41.06021812185199,41.09925361782872,41.13828911380544,41.17732460978216,41.21636010575889,41.255395601735614,41.294431097712334,41.33346659368906,41.37250208966579,41.411537585642506,41.45057308161923,41.48960857759595,41.52864407357268,41.5676795695494,41.606715065526124,41.64575056150285,41.68478605747957,41.7238215534563,41.762857049433016,41.801892545409736,41.84092804138646,41.87996353736319,41.918999033339915,41.958034529316635,41.99707002529336,42.03610552127008,42.07514101724681,42.11417651322353,42.15321200920025,42.19224750517698,42.2312830011537,42.27031849713042,42.309353993107145,42.34838948908387,42.3874249850606,42.425954695607395,42.46347283816809,42.50099098072879,42.53850912328947,42.57602726585016,42.61354540841085,42.65106355097154,42.688581693532235,42.72609983609293,42.76361797865362,42.80113612121431,42.838654263775005,42.8761724063357,42.91369054889638,42.951208691457076,42.98872683401777,43.02624497657846,43.06376311913915,43.101281261699846,43.13879940426054,43.17631754682124,43.213835689381916,43.25135383194261,43.2888719745033,43.326390117063994,43.36724388698562,43.409765470587715,43.45228705418981,43.4948086377919,43.537330221393994,43.57985180499609,43.622373388598184,43.66489497220028,43.70741655580237,43.74993813940446,43.79245972300656,43.834981306608654,43.87750289021074,43.920024473812845,43.962546057414926,44.005067641017035,44.04758922461912,44.09011080822122,44.13263239182331,44.1751539754254,44.21767555902749,44.26019714262959,44.30271872623169,44.34524030983378,44.38776189343587,44.43028347703796,44.472805060640056,44.51532664424215,44.55784822784425,44.600369811446335,44.64289139504843,44.685412978650525,44.72793456225262,44.770456145854716,44.81297772945681,44.8554993130589,44.898020896660995,44.94054248026308,44.98306406386518,45.02558564746728,45.06810723106936,45.110628814671465,45.15315039827355,45.19567198187565,45.238193565477744,45.28071514907984,45.32323673268192,45.36575831628403,45.40827989988612,45.45080148348821,45.4933230670903,45.5358446506924,45.57836623429449,45.62088781789659,45.66340940149868,45.70593098510077,45.74845256870287,45.79097415230496,45.83349573590705,45.876017319509145,45.91853890311124,45.961060486713336,46.00358207031543,46.04610365391751,46.08789806779298,46.12919800821245,46.17049794863192,46.21179788905139,46.25309782947086,46.294397769890324,46.335697710309795,46.376997650729265,46.41829759114873,46.4595975315682,46.50089747198766,46.542197412407134,46.583497352826605,46.62479729324607,46.66609723366554,46.70739717408501,46.74869711450447,46.78999705492395,46.831296995343415,46.876607152947834,46.9259275277372,46.975247902526554,47.02456827731592,47.07388865210528,47.12320902689464,47.172529401683995,47.22184977647337,47.27117015126273,47.32049052605208,47.36981090084146,47.41913127563082,47.468451650420185,47.517772025209545,47.567092399998906,47.61641277478827,47.665733149577626,47.71505352436699,47.764373899156354,47.813694273945714,47.86301464873509,47.91233502352445,47.96165539831381,48.01097577310317,48.06029614789254,48.1096165226819,48.15893689747126,48.208257272260624,48.257577647049985,48.306898021839345,48.356218396628705,48.40553877141808,48.454859146207426,48.5041795209968,48.55349989578616,48.60282027057552,48.65214064536488,48.70146102015425,48.75078139494361,48.800101769732976,48.849422144522336,48.898742519311696,48.94806289410106,48.99738326889042,49.046703643679784,49.09602401846914,49.145344393258505,49.19466476804787,49.24398514283724,49.29330551762659,49.34262589241597,49.39194626720533,49.44126664199469,49.49058701678406,49.53990739157342,49.58922776636277,49.638548141152135,49.6878685159415,49.73718889073086,49.78650926552022,49.83582964030959,49.88515001509896,49.934470389888304,49.98379076467767,50.03311113946703,50.0824315142564,50.131751889045766,50.181072263835134,50.23039263862449,50.279097601325795,50.326718246100846,50.37433889087589,50.421959535650934,50.46958018042598,50.51720082520102,50.56482146997606,50.61244211475111,50.660062759526156,50.70768340430119,50.755304049076244,50.802924693851296,50.85054533862634,50.89816598340138,50.80644519760834,50.43604155067926,50.0656379037502,49.6952342568211,49.32483060989203,48.95442696296297,48.584023316033864,48.213619669104766,47.84321602217573,47.472812375246626,47.10240872831753,46.73200508138846,46.361601434459395,45.99119778753029,45.62079414060122,45.25039049367216,44.87998684674305,44.50958319981399,44.13917955288491,43.76877590595582,43.398372259026715,43.027968612097645,42.65756496516858,42.28716131823947,41.91675767131041,41.546354024381344,41.17595037745224,40.805546730523176,40.4351430835941,40.064739436665,39.6943357897359,39.32393214280687,38.95352849587776,38.583124848948664,38.212721202019594,37.84231755509053,37.471913908161426,37.101510261232356,36.731106614303286,36.36070296737419,35.99029932044511,35.61989567351605,35.24949202658695,34.879088379657844,34.50868473272878,34.13865857302304,33.77116657827186,33.403674583520704,33.03618258876956,32.668690594018386,32.30119859926724,31.93370660451609,31.566214609764913,31.198722615013736,30.831230620262616,30.463738625511443,30.096246630760263,29.728754636009114,29.361262641257973,28.99377064650679,28.626278651755644,28.2587866570045,27.891294662253323,27.52380266750217,27.156310672751022,26.788818677999846,26.421326683248665,26.05383468849756,25.686342693746376,25.318850698995192,24.95135870424405,24.583866709492902,24.216374714741722,23.848882719990577,23.481390725239432,23.113898730488252,22.74640673573707,22.378914740985962,22.011422746234782,21.643930751483598,21.27643875673245,20.908946761981312,20.54145476723013,20.196710739874057,19.965706549493095,19.73470235911213,19.50369816873117,19.27269397835025,19.04168978796929,18.810685597588325,18.579681407207403,18.34867721682644,18.11767302644548,17.88666883606456,17.655664645683594,17.424660455302632,17.193656264921668,16.96265207454075,16.73164788415979,16.500643693778827,16.269639503397904,16.038635313016943,15.80763112263598,15.57662693225506,15.345622741874097,15.114618551493134,14.883614361112215,14.652610170731252,14.42160598035029,14.190601789969326,13.959597599588408,13.728593409207443,13.497589218826482,13.266585028445562,13.035580838064599,12.804576647683634,12.573572457302715,12.342568266921754,12.111564076540791,11.880559886159826,11.649555695778908,11.418551505397945,11.187547315016982,10.956543124636061,10.725538934255098,10.557403451104326,10.435909348463504,10.314415245822659,10.192921143181811,10.071427040540986,9.949932937900142,9.828438835259297,9.706944732618451,9.585450629977627,9.463956527336778,9.342462424695935,9.22096832205511,9.099474219414265,8.97798011677342,8.856486014132596,8.73499191149175,8.613497808850905,8.492003706210058,8.370509603569236,8.24901550092839,8.127521398287543,8.006027295646719,7.884533193005874,7.763039090365028,7.641544987724204,7.520050885083359,7.398556782442512,7.2770626798016895,7.155568577160843,7.034074474519997,6.912580371879151,6.791086269238328,6.669592166597482,6.548098063956636,6.426603961315813,6.305109858674967,6.183615756034121,6.062121653393298,5.940627550752452,5.8191334481116055,5.69763934547076,5.576145242829937],[37.108800576138094,37.1486945516744,37.18858852721072,37.22848250274703,37.26837647828334,37.30827045381965,37.34816442935596,37.38805840489228,37.427952380428586,37.46938924512855,37.5111346902752,37.55288013542183,37.594625580568476,37.636371025715114,37.67811647086175,37.7198619160084,37.76160736115503,37.80335280630167,37.84509825144832,37.88684369659495,37.9285891417416,37.97033458688824,38.01208003203487,38.05382547718152,38.09557092232816,38.137316367474796,38.17906181262144,38.22080725776808,38.26255270291472,38.30429814806136,38.346043593208,38.38778903835464,38.42953448350128,38.471279928647924,38.51302537379456,38.55477081894121,38.59651626408784,38.638261709234484,38.68000715438113,38.72175259952776,38.76349804467441,38.805243489821045,38.84698893496768,38.88873438011433,38.93047982526096,38.972225270407606,39.01397071555425,39.05571616070088,39.09746160584753,39.13920705099417,39.180952496140804,39.22269794128745,39.264443386434095,39.30618883158073,39.34793427672737,39.38967972187401,39.43142516702065,39.473170612167294,39.51491605731393,39.55666150246057,39.59840694760722,39.640152392753855,39.68189783790049,39.72364328304714,39.76538872819378,39.807134173340415,39.84887961848706,39.8906250636337,39.93237050878034,39.974115953926976,40.01586139907362,40.05760684422026,40.099352289366905,40.141097734513544,40.18284317966019,40.22458862480683,40.26633406995346,40.308079515100104,40.34982496024675,40.39157040539339,40.43331585054003,40.475061295686665,40.51680674083331,40.55855218597995,40.59803934015166,40.637074836128384,40.676110332105104,40.71514582808183,40.75418132405855,40.79321682003527,40.832252316012,40.87128781198872,40.91032330796544,40.94935880394217,40.98839429991889,41.027429795895614,41.06646529187233,41.10550078784907,41.144536283825786,41.183571779802506,41.22260727577924,41.26164277175596,41.30067826773268,41.339713763709405,41.37874925968613,41.41778475566285,41.45682025163957,41.4958557476163,41.53489124359302,41.57392673956974,41.61296223554647,41.651997731523196,41.691033227499915,41.730068723476634,41.76910421945336,41.80813971543009,41.84717521140681,41.88621070738353,41.92524620336026,41.96428169933698,42.0033171953137,42.04235269129043,42.08138818726715,42.12042368324387,42.1594591792206,42.19849467519732,42.23753017117404,42.27656566715076,42.31560116312749,42.354636659104216,42.393672155080935,42.43270765105766,42.47174314703439,42.51077864301111,42.549814138987834,42.588849634964554,42.62788513094128,42.666920626918,42.70595612289473,42.74499161887145,42.78402711484817,42.8230626108249,42.86209810680162,42.901133602778344,42.94016909875507,42.9792045947318,43.01824009070852,43.05727558668524,43.09631108266196,43.13534657863869,43.17438207461541,43.213417570592135,43.252453066568854,43.29148856254558,43.33052405852231,43.36955955449903,43.40859505047575,43.44763054645247,43.48666604242919,43.524437075440694,43.56195521800139,43.59947336056208,43.63699150312277,43.67450964568346,43.71202778824415,43.74954593080484,43.787064073365535,43.82791784328717,43.87043942688926,43.91296101049135,43.95548259409344,43.998004177695535,44.04052576129764,44.08304734489973,44.12556892850182,44.168090512103916,44.210612095706004,44.25313367930811,44.295655262910195,44.3381768465123,44.38069843011438,44.423220013716474,44.46574159731857,44.508263180920665,44.55078476452276,44.593306348124855,44.63582793172694,44.67834951532903,44.720871098931134,44.76339268253323,44.80591426613532,44.84843584973741,44.8909574333395,44.933479016941604,44.9760006005437,45.018522184145795,45.061043767747876,45.10356535134997,45.146086934952066,45.18860851855416,45.23113010215626,45.273651685758345,45.31617326936045,45.35869485296254,45.40121643656463,45.44373802016673,45.486259603768815,45.52878118737091,45.571302770973,45.6138243545751,45.65634593817719,45.69886752177929,45.74138910538138,45.783910688983475,45.82643227258556,45.86895385618766,45.911475439789754,45.95399702339185,45.99651860699394,46.03904019059603,46.08156177419813,46.124083357800224,46.16660494140231,46.20912652500441,46.2516481086065,46.29416969220859,46.33669127581069,46.37921285941278,46.42173444301488,46.46425602661697,46.50677761021906,46.549299193821156,46.59182077742325,46.63434236102535,46.67686394462744,46.71938552822953,46.761907111831626,46.804428695433714,46.84695027903581,46.88947186263791,46.93199344624,46.974515029842095,47.01703661344419,47.05955819704628,47.102079780648374,47.14460136425046,47.187122947852565,47.22964453145466,47.27216611505675,47.31404778833954,47.359357945943955,47.40867832073333,47.45799869552268,47.50731907031204,47.555291393450304,47.602912038225355,47.6505326830004,47.698153327775444,47.745773972550495,47.79339461732554,47.841015262100576,47.88863590687563,47.93625655165067,47.98387719642571,48.03149784120076,48.0791184859758,48.12673913075084,48.17435977552589,48.22198042030094,48.26960106507598,48.317221709851026,48.36484235462608,48.412462999401114,48.46008364417616,48.5077042889512,48.55532493372625,48.60294557850129,48.65056622327634,48.69818686805139,48.74580751282643,48.79342815760148,48.84104880237652,48.88866944715156,48.93629009192661,48.983910736701645,49.0315313814767,49.079152026251734,49.126772671026785,49.17439331580182,49.222013960576874,49.269634605351925,49.31725525012697,49.364875894902006,49.41249653967705,49.4601171844521,49.50773782922714,49.55535847400218,49.60297911877724,49.65059976355228,49.698220408327316,49.745841053102374,49.79346169787742,49.841082342652456,49.8887029874275,49.93632363220255,49.98394427697759,50.03156492175263,50.079185566527684,50.12680621130272,50.17442685607777,50.222047500852824,50.26966814562786,50.317288790402905,50.36490943517795,50.412530079952994,50.46015072472804,50.507771369503075,50.555392014278134,50.60301265905317,50.650633303828215,50.698253948603266,50.74587459337831,50.793495238153355,50.84111588292839,50.88873652770344,50.93635717247848,50.98397781725353,51.031598462028576,51.07921910680361,51.126839751578665,51.174460396353716,51.22208104112876,51.2697016859038,51.177980900110754,50.807577253181684,50.43717360625262,50.06676995932352,49.696366312394446,49.32596266546538,48.95555901853629,48.58515537160718,48.21475172467815,47.844348077749046,47.47394443081994,47.10354078389088,46.733137136961815,46.36273349003271,45.99232984310365,45.62192619617457,45.25152254924547,44.8811189023164,44.51071525538734,44.140311608458234,43.76990796152913,43.399504314600065,43.029100667671,42.6586970207419,42.28829337381283,41.917889726883764,41.54748607995466,41.17708243302559,40.806678786096526,40.43627513916742,40.065871492238315,39.69546784530929,39.32506419838018,38.954660551451084,38.58425690452202,38.213853257592945,37.84344961066384,37.473045963734776,37.10264231680571,36.7322386698766,36.36183502294754,35.99143137601847,35.62102772908936,35.25062408216027,34.8802204352312,34.50981678830213,34.139413141373026,33.769009494443964,33.398605847514894,33.028202200585795,32.657798553656725,32.287394906727656,31.916991259798557,31.546587612869452,31.17618396594042,30.80578031901132,30.435376672082214,30.05477784060101,29.6653789123162,29.275979984031345,28.886581055746532,28.49718212746172,28.107783199176865,27.718384270892052,27.32898534260724,26.939586414322385,26.550187486037537,26.16078855775276,25.771389629467905,25.381990701183057,24.992591772898244,24.60319284461343,24.213793916328576,23.824394988043764,23.43499605975895,23.045597131474096,22.65619820318925,22.26679927490447,21.877400346619616,21.48800141833477,21.098602490049956,20.70920356176514,20.319804633480288,19.958064682474834,19.73461961786593,19.511174553257025,19.28772948864812,19.064284424039258,18.840839359430355,18.61739429482145,18.393949230212588,18.170504165603685,17.947059100994775,17.723614036385914,17.500168971777008,17.276723907168105,17.0532788425592,16.822896072075608,16.592383535904318,16.361870999733018,16.13135846356177,15.900845927390478,15.670333391219184,15.439820855047932,15.20930831887664,14.978795782705342,14.748283246534093,14.517770710362798,14.287258174191505,14.056745638020214,13.82623310184896,13.595720565677667,13.365208029506373,13.134695493335123,12.904182957163828,12.673670420992535,12.443157884821284,12.212645348649989,11.982132812478696,11.751620276307403,11.521107740136152,11.290595203964857,11.060082667793564,10.829570131622312,10.599057595451018,10.432377173460536,10.311291118742064,10.190205064023566,10.069119009305073,9.948032954586603,9.826946899868105,9.705860845149612,9.58477479043112,9.463688735712646,9.342602680994151,9.221516626275656,9.100430571557185,8.97934451683869,8.858258462120196,8.737172407401724,8.61608635268323,8.495000297964737,8.37391424324624,8.252828188527769,8.131742133809274,8.01065607909078,7.889570024372308,7.768483969653813,7.647397914935318,7.526311860216847,7.405225805498351,7.2841397507798575,7.163053696061385,7.04310259476697,6.928150506829732,6.813198418892494,6.698246330955277,6.583294243018038,6.4683421550808,6.353390067143582,6.238437979206344,6.123485891269105,6.008533803331888,5.8935817153946495,5.778629627457411,5.663677539520172,5.548725451582956],[37.50869535054463,37.552160137361824,37.59562492417902,37.63908971099622,37.68255449781341,37.72601928463061,37.769484071447806,37.812948858265,37.85641364508219,37.89873220177549,37.94047764692213,37.982223092068764,38.02396853721541,38.06571398236205,38.10745942750869,38.14920487265533,38.19095031780197,38.23269576294861,38.274441208095254,38.316186653241886,38.35793209838853,38.39967754353518,38.44142298868181,38.48316843382845,38.52491387897509,38.56665932412173,38.608404769268375,38.650150214415014,38.69189565956166,38.7336411047083,38.775386549854936,38.81713199500158,38.85887744014821,38.900622885294865,38.9423683304415,38.98411377558814,39.02585922073478,39.06760466588142,39.109350111028064,39.151095556174695,39.19284100132134,39.234586446467986,39.276331891614625,39.31807733676126,39.3598227819079,39.40156822705454,39.443313672201185,39.485059117347824,39.52680456249446,39.56855000764111,39.610295452787746,39.652040897934384,39.69378634308103,39.73553178822767,39.777277233374306,39.81902267852095,39.86076812366759,39.90251356881423,39.944259013960874,39.98600445910751,40.02774990425415,40.069495349400796,40.111240794547435,40.15298623969407,40.19473168484072,40.23647712998735,40.278222575133995,40.31996802028063,40.36171346542727,40.40345891057391,40.445204355720556,40.486949800867194,40.52869524601384,40.57044069116048,40.612186136307116,40.653931581453755,40.6956770266004,40.73742247174704,40.77916791689368,40.820913362040315,40.86265880718696,40.9044042523336,40.946149697480244,40.987895142626876,41.02851560415148,41.06891106895167,41.109306533751855,41.14970199855204,41.190097463352224,41.230492928152415,41.2708883929526,41.311283857752784,41.35099933628754,41.39003483226426,41.42907032824098,41.46810582421771,41.50714132019443,41.546176816171155,41.58521231214789,41.62424780812461,41.663283304101334,41.70231880007806,41.74135429605477,41.7803897920315,41.819425288008226,41.858460783984945,41.89749627996167,41.93653177593839,41.97556727191512,42.01460276789184,42.053638263868564,42.09267375984529,42.13170925582201,42.170744751798736,42.209780247775456,42.24881574375218,42.2878512397289,42.32688673570563,42.365922231682354,42.40495772765907,42.4439932236358,42.48302871961252,42.52206421558924,42.56109971156597,42.60013520754269,42.63917070351941,42.678206199496145,42.717241695472865,42.75627719144959,42.79531268742631,42.83434818340303,42.87338367937976,42.912419175356476,42.95145467133321,42.99049016730993,43.02952566328665,43.068561159263375,43.107596655240094,43.14663215121682,43.18566764719354,43.224703143170274,43.26373863914699,43.30277413512372,43.34180963110044,43.380845127077166,43.419880623053885,43.45891611903061,43.49795161500734,43.53698711098406,43.576022606960784,43.6150581029375,43.65409359891423,43.69312909489095,43.73216459086768,43.7712000868444,43.81023558282113,43.84927107879785,43.888306574774575,43.927342070751294,43.96637756672802,44.00541306270475,44.04444855868147,44.08348405465819,44.12251955063491,44.16155504661163,44.20059054258836,44.239626038565085,44.281664734576246,44.325205030604636,44.36874532663303,44.412285622661415,44.45582591868981,44.49936621471819,44.54290651074658,44.586446806774966,44.62998710280336,44.67352739883175,44.717067694860134,44.759904090999754,44.802458929227974,44.845013767456194,44.88756860568442,44.93012344391266,44.97267828214088,45.01523312036911,45.05778795859734,45.10034279682556,45.14289763505379,45.18545247328201,45.22800731151024,45.27056214973847,45.313116987966694,45.35567182619492,45.39822666442315,45.440781502651376,45.4833363408796,45.52589117910783,45.56844601733605,45.61100085556428,45.653555693792505,45.69611053202073,45.73866537024896,45.78122020847718,45.823775046705414,45.866329884933634,45.90888472316186,45.95143956139009,45.993994399618316,46.03654923784654,46.07910407607478,46.121658914303,46.164213752531225,46.20676859075945,46.24932342898768,46.29187826721591,46.334433105444134,46.37698794367236,46.41954278190059,46.462097620128816,46.504652458357036,46.54720729658526,46.58976213481348,46.63231697304172,46.67487181126994,46.71742664949817,46.75998148772639,46.80253632595462,46.845091164182854,46.887646002411074,46.9302008406393,46.97275567886752,47.015310517095756,47.05786535532398,47.10042019355221,47.14297503178044,47.185529870008665,47.22808470823689,47.27063954646512,47.31319438469335,47.35574922292157,47.3983040611498,47.440858899378014,47.483413737606256,47.525968575834476,47.5685234140627,47.61107825229092,47.65363309051915,47.69618792874738,47.738742766975605,47.78129760520383,47.82540445499731,47.871063316356036,47.91672217771476,47.96238103907349,48.008039900432216,48.05369876179093,48.09935762314966,48.14501648450839,48.190675345867106,48.23633420722583,48.281993068584555,48.327651929943286,48.37331079130202,48.41896965266074,48.464628514019466,48.51028737537819,48.555946236736915,48.60160509809564,48.647263959454364,48.692922820813095,48.73858168217182,48.784240543530544,48.82989940488927,48.87555826624799,48.921217127606724,48.96687598896544,49.012534850324165,49.0581937116829,49.10385257304162,49.14951143440034,49.19517029575907,49.2408291571178,49.28648801847652,49.33214687983525,49.37780574119398,49.4234646025527,49.469123463911416,49.51478232527015,49.56044118662888,49.606100047987596,49.65175890934633,49.697417770705044,49.743076632063776,49.7887354934225,49.834394354781224,49.88005321613994,49.92689417650461,49.97451482127966,50.0221354660547,50.06975611082974,50.117376755604795,50.16499740037984,50.212618045154876,50.26023868992992,50.30785933470497,50.35547997948001,50.40310062425506,50.450721269030105,50.49834191380515,50.54596255858019,50.59358320335523,50.641203848130274,50.68882449290532,50.73644513768037,50.78406578245542,50.831686427230466,50.8793070720055,50.926927716780554,50.97454836155559,51.02216900633064,51.06978965110568,51.117410295880724,51.16503094065577,51.21265158543083,51.26027223020587,51.30789287498091,51.35551351975595,51.403134164531,51.45075480930604,51.498375454081085,51.54599609885613,51.59361674363117,51.64123738840622,51.54951660261317,51.179112955684104,50.80870930875504,50.438305661825936,50.06790201489687,49.6974983679678,49.3270947210387,48.9566910741096,48.586287427180565,48.21588378025147,47.84548013332237,47.4750764863933,47.10467283946423,46.73426919253513,46.36386554560606,45.993461898677,45.62305825174789,45.25265460481883,44.88225095788975,44.51184731096066,44.141443664031556,43.77104001710249,43.400636370173416,43.03023272324432,42.659829076315255,42.27617163546949,41.88677270718463,41.49737377889983,41.10797485061501,40.71857592233015,40.3291769940453,39.93977806576053,39.55037913747568,39.160980209190825,38.77158128090601,38.3821823526212,37.992783424336345,37.60338449605153,37.21398556776672,36.824586639481865,36.43518771119705,36.04578878291224,35.65638985462739,35.26699092634254,34.87759199805772,34.488193069772905,34.09879414148806,33.709395213203244,33.319996284918425,32.93059735663358,32.541198428348764,32.15179950006395,31.762400571779096,31.37300164349425,30.98360271520947,30.594203786924624,30.204804858639765,29.815405930354956,29.426007002070143,29.03660807378529,28.647209145500476,28.257810217215663,27.868411288930808,27.479012360645996,27.08961343236118,26.70021450407633,26.310815575791477,25.921416647506703,25.532017719221848,25.142618790937,24.753219862652188,24.36382093436737,23.97442200608252,23.585023077797707,23.19562414951289,22.80622522122804,22.416826292943192,22.02742736465841,21.63802843637356,21.24862950808871,20.859230579803896,20.46983165151908,20.08043272323423,19.718692772228774,19.49524770761987,19.271802643010968,19.048357578402065,18.8249125137932,18.601467449184295,18.37802238457539,18.15457731996653,17.931132255357625,17.70768719074872,17.484242126139858,17.26079706153095,17.037351996922048,16.813906932313145,16.59046186770428,16.367016803095375,16.14357173848647,15.920126673877611,15.696681609268705,15.4732365446598,15.249791480050938,15.026346415442031,14.802901350833128,14.579456286224264,14.356011221615361,14.132566157006458,13.909121092397552,13.685676027788688,13.462230963179785,13.238785898570882,13.00897212820631,12.778459592035013,12.54794705586372,12.317434519692469,12.086921983521176,11.856409447349883,11.62589691117859,11.395384375007337,11.164871838836042,10.934359302664749,10.703846766493498,10.473334230322205,10.306653808331722,10.18556775361325,10.064481698894756,9.94339564417626,9.822309589457788,9.701223534739292,9.580137480020799,9.459051425302306,9.337965370583833,9.216879315865338,9.095793261146843,8.974707206428372,8.85524994904939,8.740297861112152,8.625345773174937,8.510393685237698,8.39544159730046,8.280489509363221,8.165537421426004,8.050585333488765,7.935633245551526,7.82068115761431,7.705729069677071,7.5907769817398325,7.475824893802615,7.360872805865378,7.245920717928138,7.130968629990922,7.016016542053684,6.901064454116445,6.786112366179206,6.671160278241989,6.55620819030475,6.441256102367512,6.3263040144302956,6.211351926493057,6.0963998385558185,5.981447750618601,5.866495662681363,5.751543574744124,5.636591486806886,5.521639398869668],[37.90350039144549,37.94696517826269,37.990429965079876,38.03389475189707,38.077359538714276,38.12082432553147,38.164289112348655,38.20775389916586,38.251218685983055,38.29468347280025,38.33814825961745,38.38161304643464,38.425077833251834,38.46854262006903,38.51200740688623,38.55547219370342,38.59893698052062,38.642401767337816,38.68586655415501,38.72933134097221,38.7727961277894,38.816260914606595,38.859725701423784,38.903190488240995,38.94665527505818,38.98983350287044,39.03157894801708,39.07332439316372,39.11506983831036,39.156815283457,39.198560728603645,39.240306173750284,39.28205161889693,39.32379706404356,39.365542509190206,39.40728795433685,39.44903339948348,39.49077884463013,39.53252428977677,39.574269734923405,39.61601518007005,39.65776062521669,39.69950607036333,39.74125151550997,39.782996960656604,39.82474240580325,39.866487850949895,39.90823329609653,39.94997874124317,39.99172418638981,40.03346963153645,40.075215076683094,40.11696052182974,40.15870596697638,40.200451412123016,40.242196857269654,40.28394230241629,40.32568774756294,40.367433192709576,40.409178637856215,40.45092408300286,40.4926695281495,40.53441497329614,40.57616041844278,40.61790586358942,40.65965130873606,40.7013967538827,40.74314219902934,40.78488764417598,40.82663308932262,40.868378534469265,40.9101239796159,40.95186942476254,40.99361486990919,41.035360315055826,41.077105760202464,41.1188512053491,41.16059665049575,41.20234209564239,41.244087540789025,41.28583298593567,41.32757843108231,41.369323876228954,41.411069321375585,41.45168978290018,41.49208524770037,41.53248071250056,41.57287617730074,41.61327164210093,41.65366710690112,41.6940625717013,41.734458036501486,41.77485350130168,41.81524896610186,41.85564443090205,41.89603989570223,41.93643536050243,41.976830825302606,42.017226290102805,42.05762175490299,42.098017219703166,42.13841268450335,42.17880814930354,42.219203614103726,42.25959907890391,42.2999945437041,42.340390008504286,42.38078547330447,42.42118093647536,42.46021643245208,42.499251928428805,42.53828742440553,42.57732292038225,42.61635841635898,42.6553939123357,42.69442940831242,42.73346490428915,42.77250040026587,42.81153589624259,42.85057139221932,42.88960688819604,42.92864238417276,42.967677880149495,43.006713376126214,43.04574887210293,43.08478436807965,43.12381986405639,43.162855360033106,43.20189085600983,43.24092635198655,43.27996184796327,43.31899734394,43.35803283991672,43.39706833589345,43.43610383187017,43.47513932784689,43.514174823823616,43.55321031980034,43.59224581577706,43.63128131175378,43.670316807730515,43.709352303707234,43.74838779968396,43.78742329566068,43.82645879163741,43.865494287614126,43.90452978359085,43.94356527956758,43.9826007755443,44.021636271521025,44.060671767497745,44.09970726347447,44.13874275945119,44.17777825542791,44.21681375140464,44.25584924738136,44.29488474335809,44.33392023933481,44.37295573531153,44.411991231288255,44.45102672726498,44.49006222324171,44.52909771921843,44.56813321519515,44.60716871117187,44.6462042071486,44.685239703125326,44.72727839913649,44.77081869516488,44.81435899119327,44.857899287221656,44.901439583250045,44.944979879278435,44.988520175306824,45.03206047133521,45.0756007673636,45.119141063391986,45.16268135942038,45.20622165544877,45.249761951477154,45.29330224750555,45.33684254353393,45.380382839562316,45.42392313559071,45.467463431619095,45.511003727647484,45.554544023675874,45.59808431970426,45.64162461573265,45.68516491176104,45.72870520778943,45.77224550381782,45.8157857998462,45.85932609587459,45.90286639190299,45.94640668793137,45.98994698395977,46.03348727998815,46.07702757601655,46.120539715465874,46.1630945536941,46.20564939192232,46.24820423015055,46.290759068378776,46.333313906607,46.37586874483523,46.41842358306346,46.460978421291685,46.50353325951992,46.54608809774814,46.588642935976374,46.63119777420459,46.673752612432814,46.71630745066105,46.758862288889276,46.8014171271175,46.84397196534573,46.88652680357395,46.92908164180218,46.97163648003041,47.014191318258625,47.05674615648685,47.09930099471508,47.14185583294331,47.18441067117154,47.22696550939976,47.269520347627996,47.312075185856216,47.354630024084436,47.39718486231267,47.4397397005409,47.482294538769125,47.524849376997345,47.56740421522558,47.6099590534538,47.65251389168203,47.695068729910254,47.73762356813848,47.78017840636671,47.822733244594936,47.86528808282317,47.90784292105139,47.95039775927962,47.99295259750784,48.035507435736065,48.07806227396429,48.12061711219252,48.16317195042075,48.205726788648974,48.2482816268772,48.29238847667067,48.3380473380294,48.38370619938813,48.429365060746846,48.47502392210558,48.52068278346431,48.56634164482303,48.61200050618176,48.657659367540475,48.70331822889921,48.748977090257924,48.79463595161666,48.84029481297539,48.885953674334104,48.931612535692835,48.97727139705155,49.022930258410284,49.06858911976901,49.11424798112773,49.15990684248645,49.20556570384518,49.25122456520391,49.29688342656263,49.34254228792136,49.388201149280086,49.43386001063881,49.479518871997534,49.52517773335626,49.57083659471499,49.61649545607371,49.662154317432446,49.70781317879117,49.75347204014989,49.79913090150862,49.84478976286734,49.89044862422607,49.936107485584785,49.981766346943516,50.02742520830224,50.073084069660965,50.11874293101969,50.16440179237841,50.21006065373713,50.25571951509587,50.30137837645459,50.34703723781331,50.39269609917204,50.43835496053077,50.48401382188949,50.529672683248215,50.57533154460694,50.620990405965664,50.66664926732439,50.71230812868313,50.75796699004185,50.80362585140057,50.84928471275929,50.894943574118024,50.94060243547674,50.986261296835465,51.03192015819419,51.07757901955293,51.12323788091165,51.16889674227038,51.2145556036291,51.26021446498782,51.30587332634654,51.351532187705274,51.39719104906399,51.44284991042272,51.488508771781454,51.53416763314018,51.5798264944989,51.62548535585763,51.67114421721635,51.71680307857507,51.757184004571414,51.79712512171118,51.83706623885096,51.87700735599073,51.9169484731305,51.95688959027027,51.99683070741004,51.893109441968654,51.50206341136509,51.111017380761524,50.71997135015793,50.328925319554365,49.937879288950796,49.5468332583472,49.15578722774361,48.764741197140076,48.37369516653648,47.982649135932874,47.59160310532931,47.200557074725744,46.809511044122154,46.41846501351859,46.02741898291502,45.636372952311426,45.245326921707864,44.8542808911043,44.4632348605007,44.0721888298971,43.68114279929354,43.29009676868998,42.89905073808638,42.50800470748282,42.11695867687925,41.725912646275646,41.334866615672084,40.94382058506853,40.552774554464925,40.16172852386133,39.7706824932578,39.379636462654204,38.9885904320506,38.59754440144704,38.20649837084348,37.81545234023988,37.42440630963631,37.03336027903275,36.64231424842915,36.25126821782559,35.86022218722203,35.469176156618424,35.07813012601483,34.687084095411265,34.2960380648077,33.9049920342041,33.51394600360054,33.122899972996976,32.73185394239337,32.34080791178982,31.949761881186255,31.55871585058265,31.167669819979054,30.776623789375527,30.385577758771927,29.994531728168326,29.603485697564768,29.212439666961203,28.821393636357605,28.43034760575404,28.039301575150475,27.648255544546878,27.257209513943316,26.86616348333975,26.475117452736153,26.084071422132553,25.693025391529027,25.301979360925426,24.910933330321825,24.519887299718263,24.1288412691147,23.7377952385111,23.346749207907543,22.956252239266824,22.566853310981973,22.177454382697128,21.788055454412344,21.398656526127493,21.009257597842645,20.61985866955783,20.230459741273016,19.841060812988164,19.47932086198271,19.255875797373804,19.0324307327649,18.808985668155998,18.585540603547134,18.362537126199513,18.13984907929828,17.917161032397086,17.694472985495853,17.47178493859462,17.249096891693426,17.026408844792194,16.80372079789096,16.581032750989728,16.358344704088537,16.1356566571873,15.912968610286068,15.690280563384878,15.467592516483645,15.244904469582412,15.022216422681218,14.799528375779985,14.57684032887875,14.354152281977559,14.131464235076326,13.908776188175093,13.68608814127386,13.46340009437267,13.240712047471437,13.018024000570202,12.79533595366901,12.572647906767777,12.349959859866544,12.12727181296535,11.904583766064118,11.681895719162885,11.459207672261652,11.23651962536046,11.013831578459227,10.791143531557994,10.568455484656802,10.345767437755567,10.186266909996228,10.071900324481101,9.957533738965955,9.843167153450805,9.728800567935679,9.61443398242053,9.500067396905385,9.385700811390237,9.27133422587511,9.156967640359962,9.042601054844814,8.928234469329688,8.81386788381454,8.699501298299392,8.585134712784267,8.47076812726912,8.356401541753971,8.242034956238824,8.127668370723697,8.013301785208549,7.898935199693401,7.784568614178275,7.670202028663127,7.555835443147979,7.441468857632852,7.327102272117704,7.212735686602557,7.098369101087431,6.984002515572282,6.869635930057134,6.755269344541988,6.640902759026861,6.526536173511713,6.412169587996565,6.297803002481439,6.183436416966291,6.069069831451143,5.954361697905313,5.839409609968074,5.724457522030836,5.609505434093597,5.494553346156381],[38.29830543234633,38.34177021916353,38.38523500598072,38.428699792797914,38.47216457961511,38.51562936643231,38.559094153249504,38.6025589400667,38.6460237268839,38.68948851370109,38.73295330051829,38.776418087335486,38.81988287415268,38.86334766096988,38.906812447787075,38.95027723460427,38.99374202142146,39.03720680823866,39.080671595055854,39.12413638187305,39.16760116869024,39.211065955507436,39.25453074232463,39.297995529141836,39.341460315959026,39.38492510277622,39.42838988959342,39.47185467641061,39.51531946322781,39.558784250045,39.6022490368622,39.6457138236794,39.68917861049658,39.732643397313794,39.776108184130976,39.81957297094817,39.863037757765376,39.906502544582565,39.94996733139977,39.99343211821696,40.036896905034155,40.08036169185135,40.12268024911202,40.16442569425867,40.2061711394053,40.247916584551945,40.28966202969858,40.33140747484522,40.37315291999187,40.414898365138505,40.456643810285144,40.49838925543179,40.54013470057843,40.581880145725066,40.623625590871704,40.66537103601835,40.70711648116499,40.74886192631163,40.79060737145827,40.83235281660491,40.87409826175155,40.91584370689819,40.95758915204483,40.99933459719147,41.041080042338116,41.082825487484754,41.12457093263139,41.16631637777803,41.20806182292468,41.249807268071315,41.29155271321796,41.33329815836459,41.37504360351124,41.416789048657876,41.45853449380452,41.50027993895116,41.54202538409779,41.58377082924444,41.62551627439108,41.66726171953772,41.70900716468436,41.750752609831,41.79249805497764,41.83424350012428,41.87486396164887,41.91525942644906,41.955654891249246,41.99605035604944,42.03644582084962,42.076841285649806,42.11723675044999,42.157632215250175,42.198027680050366,42.23842314485055,42.27881860965074,42.319214074450926,42.359609539251124,42.400005004051295,42.44040046885149,42.48079593365168,42.52119139845186,42.561586863252046,42.60198232805223,42.642377792852415,42.6827732576526,42.72316872245279,42.76356418725298,42.803959652053166,42.84435511685335,42.884750581653535,42.92514604645372,42.96554151125391,43.00593697605409,43.046332440854286,43.08672790565447,43.127123370454655,43.16751883525484,43.20791430005502,43.24830976485522,43.28870522965539,43.32910069445559,43.369496159255775,43.40989162405596,43.45028708885615,43.49068255365633,43.53039803263988,43.56943352861661,43.60846902459333,43.64750452057005,43.68654001654678,43.7255755125235,43.764611008500225,43.803646504476944,43.84268200045367,43.8817174964304,43.92075299240712,43.959788488383836,43.99882398436056,44.03785948033729,44.07689497631401,44.115930472290735,44.15496596826746,44.19400146424418,44.2330369602209,44.27207245619763,44.31110795217435,44.35014344815108,44.3891789441278,44.42821444010452,44.46724993608125,44.50628543205797,44.54532092803469,44.58435642401142,44.62339191998814,44.66242741596487,44.70146291194159,44.74049840791831,44.779533903895036,44.818569399871755,44.85760489584848,44.89664039182521,44.93567588780193,44.974711383778654,45.013746879755374,45.0527823757321,45.09181787170882,45.13085336768555,45.172892063696715,45.216432359725104,45.259972655753494,45.30351295178188,45.347053247810265,45.39059354383866,45.434133839867044,45.47767413589544,45.52121443192382,45.56475472795221,45.6082950239806,45.651835320008985,45.69537561603738,45.73891591206577,45.78245620809416,45.82599650412254,45.86953680015093,45.91307709617932,45.95661739220771,46.0001576882361,46.04369798426448,46.08723828029288,46.13077857632127,46.17431887234966,46.21785916837804,46.26139946440642,46.30493976043482,46.34848005646321,46.3920203524916,46.43556064851999,46.47910094454838,46.52264124057677,46.56618153660516,46.60972183263354,46.653262128661936,46.69680242469032,46.74034272071871,46.7838830167471,46.82742331277548,46.870963608803876,46.91450390483226,46.95804420086065,47.00158449688904,47.045124792917434,47.08866508894582,47.132205384974206,47.17574568100259,47.21928597703098,47.262826273059375,47.30636656908776,47.349906865116154,47.393447161144536,47.436987457172926,47.480527753201315,47.523730178160214,47.566285016388434,47.60883985461666,47.65139469284489,47.693949531073116,47.736504369301336,47.77905920752957,47.82161404575779,47.864168883986025,47.906723722214245,47.94927856044247,47.99183339867069,48.03438823689893,48.07694307512715,48.119497913355374,48.1620527515836,48.20460758981183,48.247162428040056,48.28971726626828,48.332272104496504,48.37482694272474,48.41738178095296,48.459936619181185,48.50249145740942,48.54504629563765,48.587601133865874,48.6301559720941,48.67271081032232,48.715265648550556,48.75937249834402,48.80503135970275,48.85069022106147,48.8963490824202,48.942007943778925,48.98766680513765,49.033325666496374,49.0789845278551,49.12464338921383,49.17030225057255,49.21596111193128,49.26161997329,49.30727883464873,49.35293769600745,49.39859655736618,49.44425541872491,49.489914280083624,49.535573141442356,49.58123200280108,49.626890864159805,49.672549725518536,49.71820858687726,49.76386744823598,49.80952630959471,49.85518517095343,49.900844032312165,49.946502893670875,49.99216175502961,50.03782061638833,50.08347947774706,50.129138339105786,50.17479720046451,50.220456061823235,50.26611492318196,50.31177378454069,50.357432645899415,50.40309150725814,50.44875036861687,50.49440922997559,50.54006809133431,50.58572695269304,50.63138581405176,50.677044675410485,50.72065099843485,50.760592115574624,50.8005332327144,50.84047434985417,50.880415466993945,50.920356584133714,50.96029770127349,51.00023881841326,51.04017993555303,51.0801210526928,51.12006216983258,51.16000328697235,51.19994440411212,51.23988552125189,51.27982663839167,51.31976775553144,51.359708872671206,51.39964998981098,51.43959110695076,51.47953222409052,51.519473341230295,51.55941445837007,51.59935557550985,51.639296692649616,51.67923780978939,51.71917892692916,51.75912004406893,51.799061161208705,51.839002278348474,51.87894339548825,51.918884512628026,51.9588256297678,51.99876674690756,52.03870786404734,52.078648981187115,52.118590098326884,52.15853121546666,52.19847233260643,52.238413449746204,52.27835456688597,52.17463330144458,51.78358727084102,51.392541240237456,51.00149520963385,50.6104491790303,50.21940314842673,49.82835711782313,49.437311087219534,49.04626505661601,48.655219026012404,48.264172995408806,47.87312696480525,47.482080934201676,47.091034903598086,46.69998887299452,46.30894284239096,45.91789681178735,45.526850781183796,45.135804750580235,44.74475871997663,44.35371268937303,43.96266665876947,43.5716206281659,43.180574597562305,42.789528566958744,42.398482536355175,42.00743650575158,41.616390475148016,41.225344444544454,40.83429841394085,40.44325238333725,40.05220635273373,39.66116032213013,39.27011429152653,38.87906826092297,38.4880222303194,38.096976199715805,37.70593016911224,37.31488413850868,36.923838107905084,36.532792077301515,36.14174604669795,35.750700016094356,35.35965398549075,34.9686079548872,34.577561924283636,34.18651589368003,33.79546986307647,33.4044238324729,33.013377801869304,32.62233177126575,32.23128574066218,31.840239710058583,31.44919367945498,31.04319075017134,30.63523294937605,30.227275148580752,29.819317347785493,29.41135954699024,29.003401746194942,28.595443945399687,28.187486144604428,27.77952834380913,27.371570543013874,26.963612742218615,26.555654941423324,26.147697140628026,25.73973933983281,25.33178153903751,24.923823738242216,24.51586593744696,24.1079081366517,23.699950335856407,23.291992535061148,22.884034734265892,22.476076933470598,22.068119132675303,21.660161331880083,21.25220353108479,20.844245730289494,20.436287929494235,20.028330128698975,19.62037232790368,19.244458248813928,19.02876277825142,18.813067307688915,18.59737183712641,18.38167636656394,18.165980896001436,17.950285425438928,17.734589954876462,17.518894484313954,17.30319901375145,17.08750354318898,16.871808072626475,16.656112602063967,16.440417131501462,16.224721660938993,16.00902619037649,15.793300047258327,15.570612000357135,15.347923953455902,15.125235906554671,14.902547859653478,14.679859812752245,14.457171765851012,14.23448371894982,14.011795672048585,13.789107625147352,13.56641957824612,13.343731531344927,13.121043484443696,12.898355437542463,12.67566739064127,12.452979343740036,12.230291296838804,12.00760324993761,11.784915203036379,11.562227156135144,11.339539109233911,11.116851062332719,10.894163015431484,10.671474968530251,10.448786921629061,10.226098874727828,10.066598346968487,9.95223176145336,9.837865175938212,9.723498590423066,9.609132004907938,9.494765419392792,9.380398833877642,9.266032248362496,9.15166566284737,9.037299077332221,8.922932491817075,8.808565906301947,8.6941993207868,8.579832735271651,8.465466149756525,8.351099564241379,8.23673297872623,8.122366393211083,8.007999807695956,7.893633222180808,7.7792666366656595,7.664900051150534,7.550533465635385,7.436166880120239,7.321800294605112,7.208353166102001,7.099652440578556,6.990951715055131,6.882250989531685,6.7735502640082395,6.664849538484795,6.55614881296137,6.447448087437925,6.338747361914479,6.230046636391053,6.121345910867609,6.012645185344163,5.903944459820738,5.795243734297293,5.686543008773848,5.577842283250403,5.469141557726977],[38.693110473247174,38.73657526006437,38.78004004688157,38.82350483369876,38.86696962051596,38.910434407333156,38.953899194150345,38.99736398096754,39.040828767784745,39.084293554601935,39.12775834141913,39.17122312823633,39.214687915053524,39.25815270187072,39.30161748868792,39.34508227550511,39.3885470623223,39.432011849139506,39.475476635956696,39.51894142277389,39.56240620959109,39.605870996408285,39.649335783225474,39.69280057004268,39.73626535685987,39.779730143677064,39.82319493049426,39.86665971731145,39.91012450412865,39.95358929094585,39.997054077763046,40.040518864580235,40.083983651397425,40.12744843821463,40.170913225031825,40.21437801184902,40.25784279866622,40.30130758548341,40.34477237230061,40.3882371591178,40.431701945934996,40.47516673275219,40.51863151956939,40.562096306386586,40.605561093203775,40.64902588002097,40.69249066683817,40.73595545365537,40.77942024047256,40.82288502728976,40.866349814106954,40.90981460092415,40.95327938774134,40.996744174558536,41.04020896137573,41.08367374819293,41.127138535010126,41.17060332182732,41.21378155020696,41.2555269953536,41.29727244050024,41.33901788564688,41.38076333079352,41.42250877594016,41.4642542210868,41.505999666233436,41.54774511138008,41.58949055652672,41.631236001673365,41.67298144682,41.71472689196665,41.75647233711328,41.798217782259925,41.839963227406564,41.88170867255321,41.92345411769985,41.965199562846486,42.006945007993124,42.04869045313977,42.09043589828641,42.132181343433054,42.173926788579685,42.21567223372633,42.25741767887297,42.298038140397566,42.33843360519776,42.37882906999794,42.419224534798126,42.45961999959831,42.500015464398494,42.540410929198686,42.58080639399887,42.62120185879906,42.66159732359924,42.70199278839944,42.742388253199614,42.782783717999806,42.82317918279999,42.86357464760018,42.903970112400366,42.94436557720055,42.984761042000734,43.025156506800926,43.06555197160111,43.105947436401294,43.146342901201486,43.18673836600167,43.227133830801854,43.26752929560204,43.30792476040223,43.348320225202414,43.3887156900026,43.42911115480278,43.469506619602974,43.50990208440316,43.55029754920335,43.590693014003534,43.63108847880372,43.67148394360391,43.71187940840409,43.752274873204286,43.79267033800446,43.833065802804654,43.87346126760484,43.91385673240502,43.95425219720521,43.9946476620054,44.03504312680558,44.075438591605774,44.11583405640596,44.15622952120614,44.19662498600633,44.23702045080652,44.2774159156067,44.31781138040689,44.35820684520707,44.39860231000726,44.43899777480745,44.47939323960764,44.51978870440782,44.56018416920801,44.60057963282769,44.63961512880441,44.67865062478113,44.717686120757854,44.75672161673458,44.79575711271131,44.834792608688026,44.873828104664746,44.91286360064148,44.9518990966182,44.99093459259492,45.029970088571645,45.069005584548364,45.1080410805251,45.14707657650182,45.18611207247854,45.22514756845526,45.26418306443198,45.30321856040871,45.342254056385435,45.381289552362155,45.42032504833888,45.4593605443156,45.49839604029233,45.53743153626905,45.57646703224577,45.618505728256935,45.66204602428533,45.705586320313714,45.7491266163421,45.79266691237049,45.83620720839889,45.87974750442727,45.92328780045566,45.96682809648405,46.01036839251243,46.05390868854083,46.09744898456922,46.1409892805976,46.18452957662599,46.22806987265437,46.27161016868277,46.31515046471116,46.35869076073955,46.40223105676793,46.44577135279632,46.48931164882471,46.5328519448531,46.57639224088149,46.61993253690988,46.66347283293826,46.70701312896665,46.75055342499505,46.79409372102343,46.837634017051826,46.881174313080216,46.924714609108605,46.96825490513699,47.011795201165384,47.05533549719375,47.09887579322215,47.14241608925054,47.185956385278935,47.22949668130732,47.27303697733571,47.316577273364096,47.36011756939248,47.40365786542087,47.447198161449265,47.490738457477654,47.534278753506044,47.577819049534426,47.621359345562816,47.664899641591205,47.708439937619595,47.751980233647984,47.795520529676374,47.83906082570476,47.88260112173315,47.926141417761535,47.969681713789925,48.013222009818314,48.056762305846696,48.100302601875086,48.14384289790348,48.18738319393187,48.230923489960254,48.274463785988644,48.31800408201704,48.36154437804543,48.40508467407381,48.4486249701022,48.492165266130584,48.53570556215898,48.57924585818737,48.62278615421575,48.66632645024414,48.70986674627254,48.75340704230093,48.79694733832931,48.8404876343577,48.88402793038609,48.92692064085453,48.96947547908276,49.01203031731099,49.054585155539215,49.09713999376744,49.13969483199567,49.1822496702239,49.22635652001737,49.27201538137609,49.317674242734824,49.363333104093556,49.40899196545228,49.454650826811,49.50030968816973,49.54596854952845,49.59162741088718,49.637286272245895,49.682945133604626,49.724059109438066,49.76400022657784,49.803941343717604,49.84388246085739,49.883823577997155,49.923764695136924,49.96370581227671,50.003646929416476,50.04358804655625,50.083529163696014,50.12347028083579,50.16341139797556,50.20335251511533,50.2432936322551,50.28323474939488,50.323175866534655,50.36311698367442,50.4030581008142,50.44299921795397,50.482940335093744,50.52288145223351,50.56282256937328,50.60276368651306,50.64270480365283,50.6826459207926,50.72258703793238,50.76252815507215,50.80246927221192,50.84241038935169,50.88235150649146,50.922292623631236,50.962233740771005,51.00217485791078,51.04211597505055,51.082057092190325,51.1219982093301,51.16193932646988,51.20188044360964,51.241821560749415,51.28176267788919,51.32170379502895,51.36164491216873,51.401586029308504,51.44152714644828,51.48146826358804,51.52140938072782,51.5613504978676,51.60129161500736,51.64123273214713,51.68117384928691,51.72111496642668,51.76105608356645,51.800997200706234,51.840938317845996,51.88087943498577,51.92082055212554,51.96076166926532,52.000702786405085,52.040643903544854,52.08058502068463,52.120526137824406,52.160467254964175,52.20040837210395,52.24034948924373,52.28029060638349,52.320231723523264,52.36017284066304,52.400113957802816,52.440055074942585,52.47999619208235,52.51993730922213,52.559878426361905,52.456157160920505,52.06511113031695,51.67406509971338,51.28301906910978,50.891973038506215,50.50092700790265,50.109880977299056,49.71883494669545,49.32778891609193,48.93674288548833,48.54569685488473,48.15465082428117,47.76360479367761,47.37255876307401,46.98151273247044,46.59046670186687,46.19942067126328,45.80837464065972,45.41732861005616,45.02628257945255,44.63523654884896,44.2441905182454,43.85314448764183,43.45382441358366,43.0458666127884,42.63790881199315,42.229951011197855,41.821993210402596,41.41403540960734,41.00607760881204,40.59811980801675,40.19016200722153,39.782204206426236,39.374246405630934,38.966288604835675,38.55833080404042,38.15037300324513,37.74241520244988,37.33445740165461,36.926499600859316,36.518541800064064,36.110583999268805,35.70262619847351,35.294668397678215,34.886710596882956,34.4787527960877,34.0707949952924,33.66283719449714,33.25487939370189,32.8469215929066,32.43896379211134,32.03100599131608,31.623048190520784,31.21509038972549,30.807132588930266,30.399174788134975,29.99121698733968,29.58325918654442,29.175301385749165,28.76734358495387,28.35938578415861,27.95142798336336,27.543470182568058,27.135512381772802,26.727554580977543,26.31959678018225,25.911638979386957,25.503681178591734,25.09572337779644,24.687765577001144,24.279807776205885,23.87184997541063,23.463892174615335,23.05593437382008,22.64797657302482,22.240018772229526,21.83206097143423,21.424103170639007,21.016145369843713,20.608187569048418,20.200229768253163,19.792271967457907,19.384314166662612,19.008400087572856,18.792704617010347,18.57700914644784,18.361313675885334,18.14561820532287,17.92992273476036,17.714227264197852,17.498531793635387,17.28283632307288,17.067140852510374,16.851445381947908,16.635749911385403,16.420054440822895,16.20435897026039,15.988663499697921,15.772968029135416,15.55727255857291,15.341577088010443,15.125881617447934,14.910186146885428,14.694490676322962,14.478795205760456,14.26309973519795,14.047404264635482,13.831708794072977,13.616013323510469,13.400317852947962,13.184622382385497,12.968926911822988,12.753231441260484,12.537535970698016,12.32184050013551,12.106145029573002,11.88793468690987,11.665246640008638,11.442558593107403,11.21987054620617,10.997182499304978,10.774494452403747,10.551806405502512,10.32911835860132,10.106430311700088,9.946929783940746,9.832563198425621,9.718196612910472,9.603830027395325,9.489463441880199,9.375096856365051,9.260730270849903,9.146363685334757,9.031997099819629,8.922202964214366,8.813502238690917,8.704801513167494,8.596100787644048,8.487400062120603,8.378699336597178,8.269998611073733,8.161297885550287,8.052597160026842,7.943896434503417,7.835195708979972,7.726494983456527,7.6177942579331015,7.509093532409657,7.400392806886211,7.291692081362786,7.1829913558393415,7.074290630315895,6.96558990479247,6.856889179269024,6.748188453745579,6.639487728222134,6.530787002698709,6.422086277175264,6.313385551651818,6.204684826128394,6.095984100604948,5.987283375081503,5.878582649558077,5.7698819240346335,5.661181198511187,5.5524804729877415,5.443779747464317],[39.087915514148015,39.13138030096521,39.1748450877824,39.218309874599605,39.2617746614168,39.305239448234,39.34870423505119,39.39216902186838,39.43563380868558,39.47909859550278,39.52256338231997,39.56602816913716,39.609492955954366,39.65295774277156,39.69642252958875,39.739887316405955,39.783352103223145,39.82681689004034,39.87028167685754,39.913746463674734,39.95721125049192,40.00067603730912,40.04414082412632,40.08760561094352,40.13107039776071,40.174535184577906,40.2179999713951,40.2614647582123,40.304929545029495,40.348394331846684,40.39185911866388,40.43532390548108,40.478788692298274,40.52225347911546,40.56571826593266,40.609183052749856,40.65264783956705,40.69611262638425,40.739577413201445,40.78304220001864,40.82650698683584,40.869971773653035,40.91343656047023,40.95690134728743,41.00036613410462,41.04383092092181,41.08729570773901,41.130760494556206,41.1742252813734,41.21769006819059,41.26115485500779,41.304619641824985,41.34808442864218,41.39154921545938,41.435014002276574,41.47847878909377,41.52194357591097,41.565408362728164,41.60887314954536,41.65233793636256,41.695802723179746,41.73926750999694,41.78273229681414,41.82619708363133,41.869661870448525,41.91312665726572,41.95659144408292,42.000056230900114,42.04352101771731,42.08698580453451,42.1304505913517,42.1739153781689,42.21738016498609,42.260844951803286,42.30430973862048,42.346628296448536,42.388373741595174,42.43011918674182,42.47186463188846,42.513610077035096,42.55535552218174,42.59710096732838,42.638846412475026,42.680591857621664,42.72121231914626,42.761607783946445,42.80200324874664,42.84239871354682,42.882794178347,42.92318964314719,42.96358510794738,43.003980572747565,43.04437603754775,43.08477150234794,43.12516696714812,43.1655624319483,43.205957896748494,43.24635336154868,43.28674882634887,43.327144291149054,43.367539755949245,43.40793522074943,43.44833068554962,43.488726150349805,43.52912161514999,43.569517079950174,43.60991254475036,43.65030800955055,43.690703474350734,43.731098939150925,43.77149440395111,43.811889868751294,43.85228533355148,43.89268079835167,43.933076263151854,43.973471727952045,44.01386719275223,44.054262657552414,44.0946581223526,44.13505358715278,44.17544905195297,44.21584451675315,44.25623998155335,44.296635446353534,44.33703091115372,44.3774263759539,44.41782184075409,44.45821730555428,44.49861277035446,44.539008235154654,44.57940369995484,44.61979916475502,44.66019462955521,44.7005900943554,44.74098555915558,44.78138102395577,44.82177648875596,44.86217195355614,44.90256741835633,44.94296288315651,44.9833583479567,45.02375381275689,45.06414927755707,45.104544742357255,45.14494020715745,45.18533567195763,45.225731136757815,45.26612660155801,45.30652206635819,45.34691753115838,45.38731299595857,45.42770846075875,45.46810392555894,45.50849939035912,45.54889485515931,45.589290319959495,45.62968578475969,45.67008124955987,45.7097967289922,45.74883222496892,45.787867720945655,45.826903216922375,45.8659387128991,45.90497420887582,45.94400970485254,45.98304520082927,46.02208069680599,46.06411939281716,46.107659688845544,46.15119998487394,46.19474028090233,46.23828057693072,46.2818208729591,46.32536116898749,46.36890146501588,46.41244176104427,46.45598205707266,46.49952235310105,46.54306264912944,46.58660294515783,46.63014324118622,46.6736835372146,46.717223833243,46.76076412927139,46.80430442529977,46.84784472132815,46.89138501735655,46.93492531338494,46.97846560941333,47.022005905441716,47.065546201470106,47.10908649749849,47.15262679352688,47.196167089555274,47.239707385583664,47.28324768161205,47.326787977640436,47.37032827366882,47.413868569697215,47.457408865725604,47.50094916175398,47.544489457782376,47.588029753810765,47.63157004983916,47.675165055660564,47.71878057761459,47.76239609956862,47.80601162152263,47.84962714347665,47.89324266543068,47.9368581873847,47.980473709338725,48.024089231292734,48.06770475324676,48.11132027520078,48.154935797154806,48.19855131910883,48.24216684106285,48.285782363016864,48.32939788497089,48.37301340692492,48.41662892887895,48.46024445083296,48.503859972786984,48.54747549474101,48.591091016695025,48.634706538649056,48.67832206060307,48.72193758255709,48.76555310451111,48.80916862646514,48.85278414841916,48.89639967037318,48.9400151923272,48.983630714281226,49.02724623623526,49.07086175818927,49.11447728014329,49.15809280209731,49.20170832405133,49.24532384600536,49.28893936795938,49.3325548899134,49.37617041186742,49.419785933821444,49.46340145577547,49.507016977729485,49.55063249968351,49.59424802163753,49.63786354359155,49.674302120081066,49.7035637511061,49.73282538213111,49.76208701315614,49.79134864418117,49.820610275206185,49.84987190623121,49.87913353725622,49.90839516828126,49.93765679930628,49.9669184303313,49.99618006135633,50.02544169238134,50.054703323406365,50.083964954431394,50.11322658545641,50.14357261262367,50.184039796535984,50.2245069804483,50.26497416436061,50.305441348272915,50.34590853218522,50.38637571609752,50.42684290000983,50.46731008392214,50.507777267834456,50.54824445174676,50.588711635659074,50.62917881957138,50.66964600348368,50.710113187396,50.7505803713083,50.791047555220615,50.83151473913293,50.87198192304524,50.91244910695754,50.95291629086985,50.993383474782156,51.03385065869446,51.074317842606774,51.11478502651907,51.155252210431385,51.1957193943437,51.23618657825601,51.276653762168316,51.31712094608062,51.35758812999293,51.398055313905246,51.43852249781755,51.47898968172986,51.51945686564217,51.55992404955447,51.60039123346678,51.64085841737909,51.681325601291405,51.721792785203704,51.762259969116016,51.80272715302833,51.843194336940634,51.88366152085294,51.92412870476525,51.96459588867756,52.00506307258986,52.045530256502175,52.08599744041448,52.126464624326786,52.1669318082391,52.20739899215141,52.24786617606372,52.28833335997602,52.32880054388833,52.36926772780064,52.409734911712945,52.45020209562526,52.49066927953757,52.53113646344987,52.57160364736218,52.61207083127449,52.65253801518679,52.69300519909911,52.73347238301142,52.77393956692372,52.81440675083603,52.70518154465346,52.29657155828131,51.88796157190916,51.47935158553696,51.070741599164805,50.66213161279265,50.253521626420465,49.84491164004827,49.43630165367615,49.02769166730396,48.619081680931764,48.21047169455961,47.80186170818745,47.393251721815254,46.984641735443105,46.57603174907095,46.16742176269875,45.758811776326596,45.35020178995445,44.941591803582256,44.53298181721006,44.12437183083791,43.715761844465746,43.30715185809356,42.8985418717214,42.48993188534924,42.081321898977045,41.672711912604896,41.26410192623273,40.855491939860556,40.44688195348836,40.03827196711624,39.629661980744046,39.22105199437185,38.81244200799969,38.40383202162754,37.995222035255345,37.58661204888319,37.178002062511034,36.76939207613884,36.36078208976669,35.95217210339453,35.54356211702235,35.13495213065015,34.72634214427799,34.31773215790584,33.909122171533646,33.50051218516149,33.091902198789334,32.68329221241714,32.27468222604498,31.86607223967283,31.457462253300633,31.048852266928442,30.64024228055633,30.23163229418413,29.82302230781194,29.414412321439784,29.005802335067628,28.597192348695437,28.18858236232328,27.779972375951125,27.371362389578934,26.96275240320678,26.554142416834623,26.14553243046243,25.73692244409024,25.32831245771812,24.919702471345925,24.51109248497373,24.102482498601574,23.69387251222942,23.285262525857227,22.87665253948507,22.46804255311292,22.059432566740725,21.650822580368533,21.242212593996413,20.833602607624222,20.424992621252024,20.00613975813896,19.583513179737306,19.16088660133561,18.77407331072138,18.566326459044035,18.358160526311526,18.143498921082728,17.928837315853965,17.714175710625163,17.49951410539636,17.284852500167602,17.070190894938797,16.855529289709995,16.640867684481236,16.426206079252434,16.211544474023633,15.996882868794831,15.782221263566067,15.567559658337267,15.352898053108465,15.138236447879704,14.9235748426509,14.708913237422099,14.49425163219334,14.279590026964534,14.064928421735736,13.850266816506972,13.635605211278172,13.42094360604937,13.206282000820568,12.991620395591806,12.776958790363004,12.562297185134202,12.347635579905441,12.132973974676638,11.918312369447838,11.703650764219075,11.488989158990275,11.274327553761474,11.05966594853267,10.84500434330391,10.630342738075107,10.415681132846306,10.201019527617545,9.986357922388743,9.833940105710921,9.725982137998086,9.618024170285231,9.510066202572377,9.402108234859542,9.294150267146687,9.18619229943383,9.078234331720978,8.970276364008145,8.862318396295288,8.754360428582434,8.6464024608696,8.538444493156744,8.43048652544389,8.322528557731054,8.2145705900182,8.106612622305345,7.998654654592491,7.8906966868796555,7.782738719166802,7.674780751453946,7.566822783741112,7.458864816028257,7.350906848315404,7.242948880602569,7.134990912889712,7.027032945176859,6.919074977464024,6.81111700975117,6.7031590420383145,6.595201074325461,6.487243106612626,6.379285138899771,6.271327171186916,6.1633692034740815,6.055411235761227,5.947453268048372,5.839495300335537,5.731537332622683,5.6241308954426295,5.521373108790611,5.418615322138612],[39.4774795553011,39.5209443421183,39.56440912893549,39.60787391575269,39.65133870256989,39.694803489387084,39.73826827620427,39.78173306302147,39.825197849838666,39.86866263665586,39.91212742347306,39.95559221029025,39.99905699710745,40.04252178392464,40.08598657074184,40.12945135755904,40.17291614437623,40.21638093119343,40.259845718010624,40.30331050482782,40.34677529164501,40.390240078462206,40.4337048652794,40.4771696520966,40.520634438913795,40.56409922573099,40.60756401254818,40.651028799365385,40.694493586182574,40.73795837299977,40.78142315981697,40.824887946634156,40.86835273345136,40.91181752026855,40.955282307085746,40.99874709390294,41.04221188072014,41.085676667537335,41.12914145435453,41.17260624117173,41.216071027988924,41.25953581480612,41.30300060162332,41.346465388440514,41.3899301752577,41.4333949620749,41.476859748892096,41.52032453570929,41.56378932252648,41.60725410934368,41.650718896160875,41.69418368297807,41.73764846979527,41.781113256612464,41.82457804342966,41.86804283024686,41.91150761706405,41.95497240388125,41.998437190698446,42.041901977515636,42.08536676433283,42.12883155115003,42.172296337967225,42.215761124784414,42.25922591160161,42.30269069841881,42.346155485236004,42.3896202720532,42.4330850588704,42.47654984568759,42.52001463250479,42.56347941932198,42.606944206139175,42.65040899295637,42.69387377977357,42.737338566590765,42.781615653235264,42.82670504145529,42.87179442967531,42.91688381789533,42.96197320611535,43.00706259433537,43.052151982555394,43.097241370775414,43.138419156145574,43.17881462094576,43.21921008574595,43.259605550546134,43.30000101534632,43.3403964801465,43.380791944946694,43.42118740974688,43.46158287454706,43.501978339347254,43.54237380414743,43.58276926894763,43.623164733747814,43.663560198548,43.70395566334818,43.74435112814837,43.78474659294856,43.82514205774874,43.865537522548934,43.90593298734912,43.9463284521493,43.98672391694949,44.02711938174967,44.06751484654986,44.10791031135005,44.14830577615024,44.18870124095042,44.22909670575061,44.26949217055079,44.30988763535098,44.35028310015117,44.39067856495136,44.43107402975154,44.47146949455173,44.51186495935191,44.552260424152095,44.592655888952294,44.63305135375248,44.67344681855266,44.71384228335285,44.75423774815303,44.794633212953215,44.8350286777534,44.87542414255359,44.91581960735378,44.95621507215397,44.99661053695415,45.037006001754335,45.07740146655452,45.11779693135471,45.158192396154895,45.19858786095508,45.23898332575527,45.279378790555455,45.31977425535564,45.360169720155824,45.400565184956015,45.4409606497562,45.481356114556384,45.521751579356575,45.56214704415676,45.602542508956944,45.64293797375713,45.68333343855732,45.72372890335751,45.764124368157695,45.80451983295788,45.844915297758064,45.885310762558255,45.92570622735843,45.966101692158624,46.00649715695881,46.046892621759,46.087288086559184,46.12768355135937,46.168477761733136,46.210069465184944,46.25166116863676,46.29325287208856,46.33484457554037,46.37643627899218,46.41802798244398,46.459619685895795,46.503070550775675,46.54745099636959,46.591831441963514,46.63621188755743,46.68059233315135,46.724972778745276,46.76935322433918,46.8137336699331,46.85811411552702,46.90249456112094,46.94687500671486,46.99125545230877,47.0355812598237,47.079196781777725,47.12281230373174,47.16642782568577,47.21004334763979,47.253658869593814,47.29727439154783,47.340889913501854,47.384505435455885,47.42812095740991,47.471736479363926,47.51535200131795,47.55896752327197,47.60258304522599,47.64619856718001,47.68981408913403,47.733429611088056,47.77704513304207,47.820660654996104,47.86427617695012,47.90789169890414,47.95150722085816,47.995122742812185,48.03873826476621,48.08235378672023,48.12596930867426,48.169584830628274,48.21320035258229,48.256815874536315,48.30043139649034,48.34404691844436,48.38766244039839,48.43127796235241,48.47489348430643,48.518509006260444,48.562124528214476,48.60574005016849,48.649355572122516,48.69297109407653,48.73658661603055,48.78020213798458,48.8238176599386,48.86743318189262,48.91104870384664,48.95466422580067,48.99827974775468,49.041895269708704,49.085510791662735,49.12912631361676,49.172741835570775,49.2163573575248,49.25997287947882,49.30358840143285,49.347203923386864,49.39081944534088,49.434434967294905,49.47805048924893,49.52166601120295,49.56528153315698,49.608897055111,49.65251257706502,49.696128099019035,49.73974362097306,49.78335914292708,49.82697466488111,49.87059018683512,49.91420570878914,49.95782123074317,50.00143675269719,50.04505227465121,50.088667796605236,50.12510637309475,50.154368004119775,50.1836296351448,50.21289126616983,50.24215289719485,50.271414528219864,50.30067615924489,50.32993779026991,50.359199421294946,50.388461052319954,50.41772268334498,50.446984314370006,50.47624594539502,50.505507576420044,50.53476920744507,50.56403083847009,50.59329246949511,50.622554100520134,50.651815731545156,50.681077362570186,50.7103389935952,50.73960062462024,50.76886225564525,50.79812388667027,50.8273855176953,50.85664714872031,50.88590877974534,50.915170410770365,50.94443204179539,50.9736936728204,51.00295530384543,51.03221693487046,51.06147856589548,51.09074019692049,51.120001827945515,51.149263458970545,51.178525089995574,51.20778672102058,51.237048352045605,51.26630998307063,51.29557161409565,51.33170115844866,51.372168342360965,51.41263552627328,51.45310271018559,51.49356989409789,51.5340370780102,51.57450426192251,51.61497144583482,51.655438629747124,51.69590581365944,51.73637299757175,51.77684018148405,51.81730736539636,51.85777454930867,51.89824173322097,51.93870891713328,51.9791761010456,52.0196432849579,52.060110468870214,52.10057765278252,52.141044836694824,52.18151202060714,52.22197920451945,52.262446388431755,52.30291357234406,52.34338075625637,52.383847940168685,52.424315124080984,52.464782307993296,52.50524949190561,52.545716675817914,52.58618385973022,52.62665104364254,52.66711822755484,52.70758541146714,52.74805259537945,52.78851977929177,52.82898696320407,52.869454147116386,52.9099213310287,52.950388514941,52.99085569885331,52.88163049267074,52.47302050629858,52.064410519926426,51.65580053355424,51.24719054718208,50.83858056080992,50.42997057443773,50.021360588065534,49.61275060169342,49.20414061532123,48.79553062894904,48.38692064257687,47.97831065620472,47.56970066983253,47.16109068346037,46.75248069708822,46.343870710716025,45.93526072434388,45.526650737971714,45.11804075159953,44.70943076522733,44.30082077885518,43.89221079248301,43.48360080611083,43.074990819738666,42.66638083336652,42.257770846994326,41.84916086062217,41.440550874250015,41.03194088787782,40.623330901505625,40.21472091513351,39.80611092876132,39.397500942389115,38.98889095601696,38.58028096964481,38.17167098327262,37.763060996900464,37.35445101052831,36.94584102415612,36.53723103778396,36.1286210514118,35.720011065039614,35.31140107866742,34.90279109229527,34.494181105923104,34.08557111955092,33.676961133178764,33.26835114680661,32.85974116043441,32.45113117406226,32.0295828083902,31.606956229988505,31.18432965158681,30.761703073185192,30.339076494783498,29.9164499163818,29.493823337980146,29.071196759578488,28.64857018117679,28.225943602775136,27.803317024373477,27.380690445971783,26.958063867570125,26.535437289168467,26.112810710766773,25.690184132365076,25.267557553963456,24.84493097556176,24.422304397160065,23.999677818758407,23.577051240356752,23.154424661955055,22.7317980835534,22.309171505151745,21.886544926750048,21.46391834834835,21.04129176994673,20.618665191545038,20.196038613143344,19.773412034741686,19.350785456340027,18.928158877938333,18.541345587324106,18.33359873564676,18.125851883969418,17.918105032292072,17.710358180614765,17.50261132893742,17.29486447726007,17.087117625582767,16.87937077390542,16.67162392222808,16.46387707055077,16.256130218873423,16.048383367196077,15.840636515518732,15.632889663841425,15.42514281216408,15.217395960486735,15.009649108809429,14.801902257132083,14.594155405454739,14.380803408751476,14.16614180352267,13.951480198293872,13.736818593065108,13.522156987836308,13.307495382607506,13.092833777378704,12.878172172149942,12.66351056692114,12.448848961692338,12.234187356463577,12.019525751234774,11.804864146005976,11.590202540777211,11.375540935548411,11.16087933031961,10.946217725090806,10.731556119862047,10.516894514633243,10.302232909404442,10.087571304175679,9.872909698946877,9.720491882269057,9.612533914556222,9.504575946843369,9.396617979130513,9.288660011417678,9.180702043704823,9.07274407599197,8.964786108279114,8.85682814056628,8.748870172853426,8.64091220514057,8.532954237427736,8.42499626971488,8.317038302002025,8.209080334289192,8.101122366576337,7.993164398863481,7.8852064311506265,7.777248463437793,7.669290495724937,7.561332528012082,7.453374560299249,7.347268169281438,7.24451038262942,7.141752595977419,7.0389948093254,6.936237022673381,6.833479236021381,6.730721449369362,6.627963662717343,6.525205876065324,6.422448089413324,6.319690302761305,6.216932516109286,6.114174729457286,6.011416942805266,5.908659156153249,5.805901369501249,5.703143582849229,5.60038579619721,5.497628009545191,5.394870222893191],[39.86100505236213,39.90446983917933,39.947934625996524,39.99139941281372,40.03486419963092,40.07832898644811,40.1217937732653,40.1652585600825,40.208723346899696,40.25218813371689,40.29565292053409,40.33911770735128,40.382582494168474,40.42604728098567,40.46951206780287,40.512976854620064,40.55644164143726,40.59990642825446,40.64337121507165,40.68683600188885,40.73030078870604,40.773765575523235,40.81723036234043,40.86069514915763,40.904159935974825,40.94762472279202,40.99108950960921,41.03455429642641,41.0780190832436,41.1214838700608,41.164948656877996,41.208413443695186,41.25187823051239,41.29534301732958,41.338807804146775,41.38227259096397,41.42573737778117,41.469202164598364,41.51266695141556,41.55613173823276,41.59959652504995,41.64306131186715,41.68652609868434,41.729990885501536,41.77345567231873,41.81692045913593,41.860385245953125,41.90385003277032,41.94731481958752,41.99077960640471,42.034244393221904,42.0777091800391,42.1211739668563,42.16463875367349,42.20810354049068,42.25156832730788,42.295033114125076,42.33849790094227,42.38196268775947,42.425427474576665,42.470516862190635,42.51560625041066,42.56069563863068,42.6057850268507,42.650874415070724,42.695963803290745,42.741053191510765,42.786142579730786,42.83123196795081,42.87632135617083,42.92141074439085,42.96650013261087,43.01158952083089,43.05667890905091,43.10176829727094,43.14685768549096,43.19194707371098,43.23703646193099,43.28212585015102,43.32721523837104,43.37230462659106,43.41739401481108,43.4624834030311,43.50757279125112,43.54875057662129,43.58914604142147,43.629541506221656,43.66993697102184,43.710332435822025,43.75072790062221,43.7911233654224,43.83151883022259,43.871914295022776,43.91230975982296,43.952705224623145,43.993100689423336,44.03349615422352,44.073891619023705,44.114287083823896,44.15468254862408,44.195078013424265,44.235473478224456,44.27586894302464,44.31626440782483,44.356659872625016,44.3970553374252,44.437450802225385,44.47784626702557,44.51824173182576,44.558637196625945,44.599032661426136,44.63942812622632,44.679823591026505,44.720219055826696,44.76061452062687,44.801009985427065,44.84140545022725,44.88180091502744,44.922196379827625,44.96259184462781,45.00298730942799,45.043382774228185,45.08377823902837,45.124173703828546,45.16456916862874,45.20496463342892,45.24536009822911,45.285755563029305,45.32615102782949,45.36654649262967,45.40694195742986,45.44733742223005,45.48773288703023,45.528128351830425,45.56852381663061,45.60891928143079,45.64931474623098,45.68971021103117,45.73010567583135,45.77050114063154,45.81089660543172,45.851292070231914,45.8916875350321,45.933079864929056,45.97467156838086,46.01626327183266,46.05785497528448,46.099446678736285,46.14103838218809,46.1826300856399,46.224221789091715,46.265813492543515,46.30740519599533,46.34899689944714,46.390588602898944,46.43218030635076,46.47377200980256,46.51536371325437,46.55695541670618,46.59854712015799,46.640138823609796,46.6817305270616,46.72332223051341,46.764913933965225,46.80650563741703,46.84809734086883,46.88968904432065,46.93313990920053,46.97752035479445,47.021900800388366,47.06628124598228,47.1106616915762,47.15504213717012,47.199422582764036,47.24380302835795,47.288183473951875,47.33256391954579,47.37694436513971,47.42132481073362,47.465705256327546,47.51008570192146,47.55446614751538,47.5988465931093,47.64322703870321,47.68760748429714,47.73198792989105,47.776368375484964,47.82074882107889,47.8651292666728,47.909509712266726,47.95389015786064,47.99827060345455,48.04265104904848,48.087031494642396,48.13141194023631,48.175792385830235,48.220172831424144,48.26455327701807,48.30893372261198,48.3533141682059,48.397694613799814,48.44207505939374,48.48645550498765,48.530835950581576,48.575216396175485,48.61959684176941,48.66397728736332,48.70762012754997,48.751235649504004,48.79485117145802,48.83846669341205,48.882082215366076,48.92569773732009,48.96931325927412,49.01292878122814,49.05654430318215,49.100159825136174,49.1437753470902,49.18739086904422,49.23100639099824,49.27462191295227,49.31823743490629,49.361852956860304,49.405468478814335,49.44908400076835,49.492699522722376,49.5363150446764,49.57993056663042,49.62354608858444,49.667161610538464,49.71077713249249,49.754392654446505,49.79800817640053,49.84162369835455,49.88523922030857,49.9288547422626,49.97247026421662,50.016085786170635,50.05970130812466,50.10331683007868,50.14693235203271,50.19054787398672,50.23416339594075,50.27777891789477,50.32139443984879,50.36500996180281,50.408625483756836,50.45224100571086,50.495856527664884,50.5394720496189,50.575910626108424,50.60517225713345,50.63443388815847,50.663695519183484,50.692957150208514,50.722218781233536,50.75148041225856,50.78074204328358,50.810003674308604,50.83926530533362,50.86852693635865,50.89778856738367,50.92705019840869,50.956311829433716,50.98557346045874,51.01483509148376,51.04409672250878,51.073358353533806,51.10261998455883,51.13188161558385,51.16114324660887,51.190404877633895,51.21966650865891,51.24892813968394,51.27818977070896,51.307451401733985,51.336713032759,51.36597466378403,51.39523629480905,51.42449792583407,51.453759556859104,51.48302118788412,51.51228281890914,51.54154444993416,51.57080608095919,51.60006771198421,51.62932934300923,51.658590974034254,51.68785260505928,51.71711423608429,51.74637586710932,51.775637498134344,51.80489912915936,51.83416076018439,51.86342239120941,51.89268402223443,51.92194565325945,51.95120728428448,51.9804689153095,52.00973054633452,52.038992177359546,52.06825380838456,52.097515439409584,52.12677707043461,52.156038701459636,52.18530033248466,52.214561963509674,52.243823594534696,52.273085225559726,52.30234685658474,52.33160848760977,52.360870118634786,52.390131749659815,52.41939338068484,52.44865501170986,52.47936252036133,52.51982970427364,52.560296888185945,52.60076407209825,52.64123125601056,52.68169843992287,52.722165623835174,52.76263280774749,52.80309999165979,52.843567175572105,52.8840343594844,52.924501543396715,52.96496872730903,53.00543591122133,53.045903095133646,53.08637027904595,53.126837462958264,53.16730464687057,53.058079440688005,52.64946945431585,52.24085946794369,51.8322494815715,51.42363949519935,51.01502950882718,50.606419522455006,50.1978095360828,49.78919954971069,49.38058956333849,48.971979576966305,48.563369590594135,48.154759604221994,47.74614961784979,47.33753963147764,46.928929645105484,46.52031965873329,46.11170967236114,45.70309968598898,45.29448969961679,44.8858797132446,44.47565243704307,44.05302585864141,43.630399280239715,43.20777270183806,42.785146123436405,42.36251954503471,41.93989296663305,41.5172663882314,41.0946398098297,40.672013231428004,40.249386653026384,39.82676007462469,39.404133496223,38.981506917821335,38.55888033941968,38.13625376101798,37.71362718261633,37.29100060421467,36.868374025812976,36.445747447411314,36.02312086900966,35.60049429060796,35.17786771220627,34.7552411338046,34.332614555402955,33.90998797700125,33.4873613985996,33.06473482019794,32.64210824179625,32.21948166339459,31.796855084992934,31.374228506591237,30.951601928189543,30.528975349787924,30.10634877138623,29.68372219298453,29.261095614582874,28.83846903618122,28.415842457779522,27.993215879377868,27.57058930097621,27.147962722574515,26.72533614417286,26.3027095657712,25.880082987369505,25.457456408967808,25.034829830566192,24.612203252164495,24.189576673762797,23.766950095361143,23.344323516959488,22.92169693855779,22.499070360156136,22.076443781754477,21.65381720335278,21.231190624951086,20.808564046549467,20.385937468147773,19.963310889746076,19.54068431134442,19.118057732942763,18.695431154541065,18.30861786392684,18.100871012249495,17.89312416057215,17.685377308894807,17.477630457217497,17.26988360554015,17.062136753862806,16.854389902185503,16.646643050508157,16.43889619883081,16.231149347153504,16.023402495476155,15.815655643798811,15.607908792121465,15.400161940444159,15.192415088766813,14.984668237089469,14.776921385412162,14.569174533734817,14.361427682057471,14.153680830380164,13.945933978702818,13.738187127025473,13.530440275348166,13.322693423670822,13.114946571993476,12.90719972031613,12.699452868638824,12.491706016961478,12.283959165284132,12.076212313606826,11.868465461929482,11.660718610252136,11.452971758574828,11.245224906897484,11.037478055220136,10.829731203542792,10.618107896420186,10.403446291191385,10.188784685962583,9.974123080733822,9.759461475505018,9.607043658827196,9.499085691114361,9.391127723401508,9.283169755688654,9.175211787975819,9.070405443120245,8.967647656468227,8.864889869816206,8.762132083164209,8.65937429651219,8.55661650986017,8.453858723208171,8.35110093655615,8.248343149904132,8.145585363252133,8.042827576600114,7.940069789948095,7.837312003296075,7.734554216644075,7.631796429992057,7.529038643340037,7.426280856688037,7.3235230700360185,7.220765283383999,7.118007496732,7.015249710079981,6.912491923427961,6.809734136775961,6.706976350123942,6.604218563471923,6.501460776819904,6.398702990167904,6.2959452035158865,6.193187416863868,6.090429630211866,5.987671843559848,5.884914056907829,5.782156270255829,5.67939848360381,5.576640696951791,5.473882910299771,5.371125123647771],[40.24453054942316,40.28799533624036,40.33146012305755,40.37492490987474,40.418389696691946,40.46185448350914,40.505319270326325,40.54878405714353,40.592248843960725,40.635713630777914,40.67917841759511,40.72264320441231,40.766107991229504,40.8095727780467,40.8530375648639,40.89650235168109,40.93996713849829,40.983431925315486,41.02689671213268,41.07036149894988,41.11382628576707,41.15729107258427,41.200755859401454,41.24422064621865,41.28768543303585,41.33115021985304,41.37461500667024,41.418079793487436,41.46154458030463,41.50500936712183,41.548474153939026,41.591938940756215,41.63540372757342,41.67886851439061,41.722333301207804,41.765798088025,41.80926287484219,41.852727661659394,41.89619244847658,41.93965723529379,41.983122022110976,42.02658680892817,42.07005159574537,42.114328682925986,42.159418071146014,42.204507459366035,42.249596847586055,42.294686235806076,42.339775624026096,42.38486501224612,42.42995440046614,42.475043788686165,42.52013317690618,42.5652225651262,42.610311953346226,42.65540134156624,42.70049072978627,42.74558011800629,42.7906695062263,42.83575889444633,42.88084828266635,42.92593767088637,42.97102705910639,43.01611644732641,43.06120583554643,43.10629522376645,43.15138461198647,43.19647400020649,43.24156338842652,43.28665277664654,43.33174216486656,43.37683155308658,43.4219209413066,43.46701032952663,43.51209971774665,43.55718910596667,43.60227849418669,43.64736788240671,43.69245727062673,43.73754665884675,43.782636047066774,43.827725435286794,43.872814823506815,43.917904211726835,43.95908199709699,43.99947746189718,44.03987292669736,44.080268391497555,44.12066385629774,44.16105932109792,44.20145478589811,44.24185025069829,44.28224571549849,44.32264118029866,44.36303664509885,44.40343210989904,44.44382757469923,44.48422303949942,44.524618504299596,44.56501396909978,44.60540943389998,44.64580489870016,44.68620036350035,44.72659582830054,44.766991293100716,44.80738675790091,44.84778222270109,44.88817768750128,44.92857315230147,44.96896861710165,45.009364081901836,45.04975954670203,45.09015501150221,45.1305504763024,45.17094594110259,45.21134140590277,45.25173687070296,45.29213233550315,45.332527800303325,45.37292326510352,45.4133187299037,45.45371419470389,45.494109659504076,45.53450512430426,45.57490058910445,45.615296053904636,45.65609026467316,45.69768196812497,45.739273671576775,45.78086537502858,45.8224570784804,45.8640487819322,45.90564048538401,45.94723218883582,45.98882389228763,46.030415595739434,46.07200729919124,46.11359900264305,46.155190706094864,46.19678240954667,46.23837411299848,46.279965816450286,46.32155751990209,46.3631492233539,46.404740926805715,46.44633263025752,46.48792433370933,46.52951603716114,46.571107740612945,46.61269944406475,46.65429114751657,46.695882850968374,46.73747455442019,46.77906625787199,46.820657961323796,46.862249664775604,46.90384136822741,46.945433071679226,46.98702477513103,47.02861647858285,47.070208182034655,47.11179988548646,47.15339158893826,47.19498329239008,47.23657499584189,47.27816669929369,47.3197584027455,47.363209267625386,47.407589713219295,47.45197015881322,47.49635060440714,47.54073105000106,47.58511149559497,47.62949194118889,47.673872386782804,47.71825283237672,47.762633277970636,47.807013723564566,47.85139416915848,47.8957746147524,47.940155060346314,47.98453550594023,48.028915951534145,48.07329639712807,48.11767684272199,48.16205728831591,48.20643773390982,48.25081817950374,48.295198625097655,48.33957907069157,48.38395951628549,48.42833996187941,48.472720407473325,48.51710085306725,48.56148129866116,48.60586174425508,48.650242189849,48.69462263544292,48.73900308103683,48.78338352663075,48.82776397222467,48.87214441781859,48.916524863412505,48.96090530900642,49.00528575460034,49.04966620019426,49.094046645788175,49.13842709138209,49.18280753697601,49.22718798256993,49.27156842816385,49.31594887375776,49.360329319351685,49.4047097649456,49.44909021053952,49.49347065613344,49.537851101727355,49.58223154732127,49.626611992915194,49.6709924385091,49.715372884103026,49.75975332969694,49.804133775290865,49.84851422088478,49.892894666478696,49.93727511207261,49.981655557666535,50.026036003260444,50.070416448854374,50.11479689444829,50.15917734004221,50.20355778563612,50.24793823123004,50.29231867682396,50.336043473322235,50.379658995276266,50.42327451723028,50.46689003918431,50.51050556113833,50.55412108309235,50.59773660504637,50.64135212700039,50.68496764895442,50.72858317090843,50.77219869286246,50.81581421481648,50.85942973677051,50.90304525872452,50.94666078067855,50.990276302632566,51.026714879122096,51.05597651014711,51.08523814117214,51.11449977219715,51.14376140322218,51.1730230342472,51.202284665272224,51.231546296297246,51.26080792732227,51.29006955834729,51.319331189372306,51.348592820397336,51.37785445142236,51.40711608244738,51.4363777134724,51.46563934449743,51.49490097552245,51.52416260654747,51.55342423757249,51.58268586859752,51.611947499622545,51.64120913064757,51.67047076167258,51.6997323926976,51.72899402372263,51.75825565474765,51.787517285772665,51.81677891679769,51.84604054782272,51.87530217884773,51.90456380987276,51.933825440897785,51.96308707192281,51.99234870294782,52.02161033397286,52.050871964997874,52.0801335960229,52.10939522704792,52.13865685807294,52.16791848909796,52.19718012012299,52.22644175114801,52.255703382173024,52.284965013198054,52.314226644223076,52.34348827524809,52.372749906273114,52.402011537298144,52.431273168323166,52.46053479934818,52.48979643037322,52.519058061398226,52.54831969242325,52.57758132344827,52.606842954473294,52.63610458549832,52.66536621652334,52.693598133140206,52.7187408868237,52.74388364050721,52.7690263941907,52.79416914787421,52.81931190155772,52.84445465524122,52.86959740892472,52.89474016260822,52.919882916291726,52.94502566997522,52.97016842365873,52.99531117734223,53.02045393102574,53.045596684709245,53.070739438392735,53.095882192076246,53.12102494575974,53.14616769944325,53.17131045312674,53.196453206810254,53.22159596049376,53.24673871417726,53.27188146786076,53.29702422154426,53.322166975227766,53.19474604245912,52.76219773678634,52.32964943111356,51.897101125440734,51.46455281976796,51.03200451409517,50.59945620842235,50.166907902749536,49.73792124641583,49.31529466801413,48.89266808961243,48.47004151121078,48.047414932809126,47.62478835440743,47.20216177600577,46.77953519760411,46.356908619202414,45.93428204080076,45.5116554623991,45.08902888399741,44.66640230559571,44.243775727194055,43.821149148792394,43.3985225703907,42.97589599198904,42.553269413587394,42.13064283518569,41.70801625678404,41.28538967838238,40.86276309998069,40.44013652157899,40.017509943177366,39.594883364775676,39.17225678637398,38.749630207972324,38.32700362957066,37.90437705116897,37.48175047276731,37.059123894365655,36.63649731596396,36.2138707375623,35.79124415916065,35.36861758075895,34.94599100235725,34.5233644239556,34.100737845553944,33.67811126715225,33.25548468875059,32.83285811034893,32.41023153194724,31.987604953545578,31.564978375143923,31.142351796742226,30.719725218340532,30.297098639938913,29.87447206153722,29.45184548313552,29.029218904733867,28.60659232633221,28.183965747930515,27.761339169528856,27.338712591127198,26.916086012725504,26.493459434323846,26.07083285592219,25.648206277520494,25.225579699118796,24.80295312071718,24.380326542315483,23.95769996391379,23.53507338551213,23.112446807110473,22.68982022870878,22.26719365030712,21.844567071905466,21.42194049350377,20.999313915102075,20.576687336700456,20.15406075829876,19.731434179897064,19.308807601495406,18.886181023093748,18.463554444692054,18.078102790680447,17.878525758618842,17.67894872655723,17.479371694495626,17.279794662434053,17.078323303462675,16.871900872897527,16.665478442332414,16.459056011767267,16.25263358120212,16.046211150637006,15.83978872007186,15.63336628950671,15.426943858941563,15.220521428376452,15.014098997811304,14.807676567246157,14.601254136681046,14.394831706115898,14.18840927555075,13.981986844985641,13.775564414420492,13.569141983855346,13.362719553290235,13.156297122725087,12.949874692159938,12.74345226159479,12.53702983102968,12.330607400464531,12.124184969899382,11.917762539334275,11.711340108769125,11.504917678203977,11.298495247638868,11.092072817073719,10.88565038650857,10.679227955943423,10.472805525378313,10.266383094813165,10.059960664248015,9.853538233682906,9.647115803117757,9.501676753160526,9.399797260780383,9.297917768400218,9.196038276020056,9.094158783639912,8.992279291259749,8.890399798879587,8.788520306499423,8.686640814119277,8.584761321739116,8.482881829358952,8.381002336978808,8.279122844598644,8.17724335221848,8.075363859838337,7.973484367458175,7.871604875078011,7.769725382697849,7.667845890317704,7.56596639793754,7.464086905557377,7.3622074131772335,7.260327920797069,7.158448428416907,7.056568936036763,6.9546894436566,6.852809951276436,6.750930458896292,6.649050966516129,6.547171474135967,6.445291981755803,6.343412489375658,6.241532996995495,6.139653504615332,6.037774012235188,5.935894519855025,5.8340150274748614,5.736353684921255,5.639214023849888,5.542074362778521,5.4449347017071545,5.3477950406358055],[40.6280560464842,40.6715208333014,40.71498562011859,40.758450406935786,40.80191519375298,40.84537998057017,40.88884476738737,40.932309554204565,40.97577434102176,41.01923912783896,41.062703914656154,41.10616870147335,41.14963348829055,41.193098275107744,41.23656306192494,41.28002784874214,41.323492635559326,41.36695742237653,41.41042220919372,41.453886996010915,41.497351782828105,41.54081656964531,41.5842813564625,41.627746143279694,41.67121093009689,41.71467571691409,41.75814050373128,41.80322989188138,41.8483192801014,41.89340866832142,41.93849805654144,41.98358744476146,42.02867683298148,42.0737662212015,42.11885560942153,42.16394499764154,42.20903438586157,42.254123774081584,42.29921316230161,42.34430255052163,42.389391938741646,42.434481326961674,42.47957071518169,42.524660103401715,42.569749491621735,42.61483887984175,42.659928268061776,42.7050176562818,42.75010704450182,42.79519643272184,42.84028582094186,42.885375209161886,42.930464597381906,42.97555398560192,43.02064337382195,43.06573276204196,43.110822150261995,43.15591153848201,43.20100092670202,43.24609031492206,43.29117970314206,43.3362690913621,43.38135847958211,43.42644786780213,43.47153725602216,43.51662664424218,43.5617160324622,43.60680542068222,43.65189480890224,43.69698419712226,43.74207358534228,43.78716297356231,43.832252361782324,43.87734175000235,43.922431138222365,43.9675205264424,44.01260991466241,44.057699302882426,44.102788691102454,44.14787807932247,44.1929674675425,44.238056855762515,44.283146243982536,44.32823563220256,44.369413417572716,44.40980888237291,44.45020434717309,44.49059981197327,44.53099527677347,44.571390741573644,44.611786206373836,44.65218167117402,44.692577135974204,44.732972600774396,44.77336806557458,44.813763530374764,44.854158995174956,44.89455445997514,44.934949924775324,44.97534538957551,45.0157408543757,45.05613631917589,45.096531783976076,45.13692724877626,45.177322713576444,45.21771817837663,45.25811364317681,45.298509107977004,45.33890457277719,45.37930003757737,45.42069236786909,45.4622840713209,45.50387577477271,45.54546747822452,45.587059181676324,45.62865088512813,45.67024258857994,45.71183429203175,45.75342599548355,45.79501769893537,45.836609402387175,45.87820110583899,45.9197928092908,45.961384512742605,46.00297621619441,46.04456791964621,46.08615962309803,46.12775132654984,46.16934303000164,46.210934733453456,46.252526436905256,46.29411814035707,46.33570984380888,46.377301547260686,46.4188932507125,46.4604849541643,46.502076657616115,46.54366836106792,46.58526006451973,46.626851767971544,46.668443471423345,46.71003517487516,46.75162687832697,46.79321858177877,46.83481028523059,46.87640198868239,46.9179936921342,46.959585395586004,47.00117709903781,47.042768802489626,47.08436050594143,47.12595220939324,47.16754391284505,47.209135616296855,47.25072731974866,47.29231902320048,47.333910726652284,47.37550243010409,47.4170941335559,47.45868583700771,47.500277540459514,47.54186924391132,47.583460947363136,47.625052650814936,47.66664435426675,47.70823605771856,47.74982776117037,47.79327862605025,47.83765907164417,47.88203951723809,47.92641996283201,47.970800408425916,48.01518085401984,48.05956129961376,48.10394174520768,48.14832219080159,48.19270263639551,48.237083081989425,48.28146352758335,48.325843973177264,48.37022441877119,48.4146048643651,48.45898530995902,48.50336575555294,48.547746201146865,48.59212664674077,48.63650709233469,48.680887537928605,48.72526798352253,48.769648429116444,48.81402887471036,48.858409320304276,48.9027897658982,48.94717021149212,48.99155065708603,49.035931102679946,49.08031154827387,49.124691993867785,49.1690724394617,49.213452885055624,49.25783333064953,49.302213776243455,49.34659422183738,49.390974667431294,49.43535511302521,49.479735558619126,49.52411600421304,49.56849644980696,49.61287689540088,49.6572573409948,49.70163778658871,49.74601823218264,49.79039867777656,49.83477912337047,49.87915956896438,49.9235400145583,49.96792046015222,50.01230090574614,50.05668135134005,50.10106179693397,50.14544224252789,50.189822688121815,50.23420313371573,50.278583579309654,50.32296402490357,50.367344470497486,50.4117249160914,50.45610536168532,50.50048580727923,50.544866252873156,50.58924669846707,50.63362714406098,50.678007589654904,50.722410059001575,50.76688961153191,50.81136916406222,50.85584871659256,50.90032826912288,50.94480782165321,50.98928737418354,51.03376692671387,51.0782464792442,51.12272603177452,51.167205584304845,51.21168513683518,51.2561646893655,51.30064424189583,51.34512379442616,51.38960334695649,51.43408289948682,51.46416080208959,51.4798370547648,51.49551330744002,51.511189560115234,51.52686581279045,51.54254206546567,51.55821831814088,51.573894570816094,51.589570823491314,51.60524707616653,51.62092332884174,51.636599581516954,51.652275834192174,51.66795208686739,51.6836283395426,51.699304592217814,51.7227709934458,51.747913747129296,51.7730565008128,51.79819925449631,51.82334200817981,51.84848476186331,51.87362751554681,51.89877026923031,51.923913022913815,51.94905577659732,51.97419853028082,51.99934128396433,52.024484037647824,52.04962679133133,52.07476954501483,52.099912298698335,52.12505505238184,52.150197806065336,52.17534055974885,52.20048331343235,52.22562606711584,52.25076882079935,52.275911574482855,52.30105432816635,52.326197081849855,52.35133983553336,52.37648258921686,52.40162534290036,52.42676809658388,52.45191085026737,52.47705360395088,52.502196357634375,52.527339111317886,52.55248186500138,52.577624618684894,52.60276737236839,52.627910126051894,52.6530528797354,52.6781956334189,52.70333838710239,52.7284811407859,52.75362389446941,52.77876664815291,52.803909401836414,52.82905215551992,52.85419490920342,52.879337662886925,52.90448041657042,52.92962317025392,52.95476592393743,52.979908677620934,53.00505143130443,53.03019418498793,53.05533693867144,53.08047969235494,53.10562244603844,53.130765199721935,53.155907953405446,53.18105070708894,53.206193460772454,53.23133621445596,53.256478968139454,53.28162172182296,53.30676447550647,53.331907229189966,53.35704998287346,53.382192736556966,53.25477180378832,52.82222349811554,52.389675192442766,51.95712688676994,51.52457858109716,51.09203027542438,50.65948196975155,50.22693366407874,49.794385358406,49.36183705273318,48.929288747060355,48.49674044138757,48.06419213571479,47.63164383004198,47.19909552436919,46.76654721869642,46.33399891302359,45.90145060735081,45.468902301678035,45.03635399600521,44.60380569033239,44.17125738465961,43.73870907898683,43.30616077331401,42.87361246764122,42.44106416196844,42.008515856295624,41.57596755062284,41.14341924495007,40.71087093927724,40.278322633604425,39.845774327931686,39.41322602225886,38.980677716586044,38.54812941091326,38.11558110524048,37.683032799567656,37.25213811586231,36.829511537460654,36.40688495905896,35.9842583806573,35.56163180225564,35.13900522385395,34.71637864545225,34.29375206705059,33.871125488648936,33.44849891024724,33.025872331845584,32.60324575344393,32.18061917504223,31.757992596640577,31.335366018238922,30.912739439837225,30.490112861435527,30.06748628303391,29.644859704632214,29.222233126230517,28.799606547828862,28.376979969427204,27.95435339102551,27.53172681262385,27.109100234222197,26.6864736558205,26.263847077418845,25.841220499017183,25.418593920615493,24.995967342213795,24.573340763812176,24.15071418541048,23.72808760700878,23.305461028607127,22.882834450205472,22.460207871803775,22.03758129340212,21.614954715000458,21.192328136598768,20.76970155819707,20.34707497979545,19.924448401393757,19.50182182299206,19.0791952445904,18.656568666188747,18.23394208778705,17.84849043377545,17.648913401713838,17.44933636965223,17.249759337590618,17.05018230552905,16.85060527346744,16.651028241405832,16.451451209344256,16.251874177282648,16.05229714522104,15.852720113159467,15.65314308109786,15.453566049036251,15.25398901697464,15.054411984913065,14.85483495285146,14.655257920789849,14.455680888728278,14.256103856666668,14.05652682460506,13.856949792543487,13.657372760481877,13.457795728420269,13.25564628416921,13.049223853604062,12.842801423038912,12.636378992473764,12.429956561908654,12.223534131343506,12.017111700778358,11.810689270213249,11.6042668396481,11.397844409082952,11.191421978517845,10.984999547952693,10.778577117387545,10.572154686822396,10.365732256257287,10.15930982569214,9.95288739512699,9.74646496456188,9.540042533996733,9.394603484039502,9.292723991659358,9.190844499279194,9.088965006899032,8.987085514518887,8.885206022138723,8.783326529758561,8.681447037378398,8.579567544998254,8.47768805261809,8.375808560237926,8.273929067857782,8.17204957547762,8.070170083097455,7.968290590717313,7.866411098337149,7.764531605956986,7.662652113576822,7.560772621196679,7.462641764729849,7.365502103658482,7.268362442587133,7.171222781515766,7.074083120444398,6.97694345937305,6.879803798301684,6.7826641372303165,6.685524476158968,6.588384815087601,6.491245154016234,6.394105492944868,6.2969658318735195,6.199826170802153,6.102686509730786,6.005546848659437,5.90840718758807,5.811267526516703,5.714127865445354,5.616988204373988,5.51984854330262,5.4227088822312535,5.325569221159905],[41.01158154354523,41.05504633036243,41.09851111717962,41.141975903996816,41.18544069081402,41.22890547763121,41.2723702644484,41.315835051265594,41.3592998380828,41.402764624899994,41.44704171261673,41.49213110083675,41.53722048905677,41.58230987727679,41.62739926549681,41.67248865371683,41.717578041936854,41.762667430156874,41.807756818376895,41.852846206596915,41.89793559481694,41.943024983036956,41.98811437125698,42.033203759477004,42.07829314769702,42.123382535917045,42.168471924137066,42.213561312357086,42.25865070057711,42.30374008879713,42.34882947701715,42.39391886523717,42.43900825345719,42.48409764167721,42.52918702989724,42.57427641811726,42.61936580633728,42.6644551945573,42.70954458277732,42.75463397099734,42.79972335921736,42.84481274743738,42.8899021356574,42.93499152387743,42.98008091209745,43.02517030031746,43.07025968853749,43.11534907675751,43.160438464977524,43.20552785319755,43.25061724141757,43.29570662963759,43.34079601785761,43.385885406077634,43.430974794297654,43.476064182517675,43.5211535707377,43.566242958957716,43.611332347177736,43.656421735397764,43.70151112361778,43.746600511837805,43.791689900057825,43.83677928827784,43.88186867649787,43.92695806471789,43.97204745293791,44.017136841157935,44.062226229377956,44.107315617597976,44.152405005818,44.19749439403802,44.24258378225804,44.28767317047806,44.33276255869808,44.3778519469181,44.42294133513812,44.46803072335814,44.51312011157816,44.55820949979818,44.60329888801821,44.64838827623822,44.69347766445824,44.73856705267827,44.77974483804843,44.820140302848614,44.8605357676488,44.90093123244899,44.941326697249174,44.98172216204936,45.022117626849536,45.062513091649734,45.10290855644991,45.143702767613206,45.18529447106501,45.22688617451682,45.26847787796863,45.31006958142044,45.35166128487224,45.39325298832405,45.434844691775865,45.47643639522767,45.51802809867948,45.55961980213129,45.601211505583095,45.642803209034895,45.68439491248671,45.725986615938524,45.76757831939033,45.80917002284214,45.850761726293946,45.892353429745754,45.933945133197554,45.97553683664937,46.017128540101176,46.05872024355298,46.1003119470048,46.1419036504566,46.18349535390841,46.22508705736021,46.26667876081203,46.30827046426384,46.34986216771564,46.39145387116746,46.433045574619264,46.47463727807107,46.51622898152288,46.557820684974686,46.5994123884265,46.6410040918783,46.682595795330116,46.72418749878192,46.76577920223373,46.80737090568554,46.848962609137345,46.89055431258916,46.93214601604096,46.973737719492775,47.01532942294458,47.05692112639639,47.0985128298482,47.140104533300004,47.18169623675182,47.223287940203626,47.26487964365543,47.306471347107234,47.34806305055904,47.389654754010856,47.43124645746266,47.47283816091448,47.514429864366285,47.55602156781809,47.5976132712699,47.63920497472171,47.68079667817352,47.72238838162533,47.76398008507714,47.80557178852894,47.84716349198075,47.88875519543256,47.93034689888437,47.97193860233618,48.01353030578798,48.055122009239795,48.0967137126916,48.13830541614341,48.17989711959522,48.223347984475105,48.26772843006902,48.312108875662936,48.35648932125685,48.400869766850775,48.44525021244469,48.48963065803861,48.53401110363252,48.578391549226446,48.62277199482036,48.667152440414284,48.7115328860082,48.755913331602116,48.80029377719603,48.844674222789955,48.88905466838387,48.93343511397779,48.97781555957171,49.022196005165625,49.06657645075954,49.11095689635345,49.15533734194738,49.19971778754129,49.24409823313521,49.28851722034639,49.332996772876726,49.37747632540706,49.42195587793738,49.46643543046771,49.51091498299804,49.555394535528364,49.59987408805869,49.64435364058902,49.68883319311935,49.73331274564967,49.777792298179996,49.82227185071033,49.866751403240656,49.91123095577098,49.955710508301316,50.00019006083164,50.04466961336197,50.089149165892294,50.13362871842263,50.178108270952954,50.22258782348328,50.26706737601361,50.31154692854394,50.35602648107426,50.40050603360459,50.44498558613492,50.489465138665246,50.53394469119558,50.578424243725905,50.62290379625624,50.667383348786565,50.711862901316884,50.75634245384721,50.800822006377544,50.84530155890788,50.8897811114382,50.934260663968516,50.97874021649885,51.02321976902918,51.0676993215595,51.112178874089835,51.15665842662016,51.20113797915049,51.24561753168082,51.29009708421114,51.334576636741474,51.3790561892718,51.423535741802134,51.46801529433246,51.512494846862786,51.55697439939311,51.60145395192344,51.645933504453765,51.69041305698409,51.73489260951442,51.77937216204475,51.823851714575085,51.868331267105404,51.898409169708174,51.914085422383394,51.92976167505861,51.94543792773382,51.961114180409034,51.976790433084254,51.99246668575947,52.00814293843468,52.0238191911099,52.039495443785114,52.05517169646033,52.07084794913555,52.08652420181076,52.102200454485974,52.11787670716119,52.13355295983641,52.14922921251162,52.164905465186834,52.180581717862054,52.19625797053727,52.21193422321249,52.22761047588771,52.243286728562914,52.25896298123813,52.27463923391335,52.29031548658856,52.305991739263774,52.321667991938995,52.33734424461421,52.35302049728943,52.36869674996464,52.38437300263986,52.40004925531507,52.41572550799028,52.4314017606655,52.447078013340715,52.462754266015935,52.47843051869115,52.49410677136637,52.50978302404158,52.5254592767168,52.541135529392015,52.55681178206722,52.57248803474245,52.58816428741766,52.60384054009287,52.61951679276808,52.63519304544331,52.65086929811852,52.666545550793735,52.682221803468956,52.69789805614416,52.71357430881938,52.72925056149459,52.74492681416981,52.763364148431606,52.7885069021151,52.8136496557986,52.83879240948211,52.86393516316562,52.88907791684911,52.914220670532615,52.939363424216126,52.96450617789963,52.989648931583126,53.01479168526662,53.03993443895013,53.06507719263364,53.090219946317134,53.11536270000064,53.14050545368414,53.165648207367646,53.19079096105114,53.215933714734646,53.24107646841816,53.266219222101654,53.29136197578515,53.31650472946866,53.34164748315216,53.36679023683566,53.391932990519166,53.41707574420266,53.44221849788617,53.31479756511752,52.88224925944474,52.449700953771966,52.01715264809914,51.58460434242636,51.15205603675358,50.71950773108076,50.28695942540794,49.854411119735204,49.42186281406238,48.989314508389555,48.55676620271677,48.124217897044,47.69166959137118,47.2591212856984,46.82657298002562,46.3940246743528,45.96147636868001,45.528928063007235,45.09637975733442,44.66383145166159,44.231283145988805,43.79873484031603,43.366186534643205,42.93363822897042,42.50108992329765,42.06854161762483,41.63599331195205,41.20344500627927,40.77089670060644,40.33834839493363,39.905800089260886,39.47325178358807,39.040703477915244,38.60815517224246,38.17560686656969,37.74305856089686,37.31051025522408,36.877961949551306,36.44541364387848,36.0128653382057,35.58031703253292,35.14776872686009,34.71522042118728,34.282672115514494,33.85012380984172,33.417575504168894,32.98502719849611,32.55247889282334,32.11993058715051,31.68738228147773,31.254833975804956,30.822285670132132,30.389737364459315,29.95718905878657,29.52464075311375,29.092092447440933,28.659544141768144,28.22699583609537,27.79444753042255,27.361899224749767,26.929350919076985,26.496802613404167,26.06425430773138,25.631706002058607,25.199157696385782,24.766609390712965,24.343728406907182,23.921101828505485,23.49847525010379,23.075848671702133,22.653222093300478,22.23059551489878,21.807968936497126,21.385342358095468,20.962715779693774,20.540089201292076,20.117462622890457,19.694836044488763,19.272209466087066,18.84958288768541,18.426956309283753,18.004329730882056,17.618878076870452,17.419301044808844,17.219724012747236,17.02014698068563,16.820569948624055,16.620992916562443,16.421415884500835,16.221838852439262,16.022261820377654,15.822684788316046,15.623107756254473,15.423530724192863,15.223953692131255,15.024376660069645,14.824799628008073,14.625222595946465,14.425645563884856,14.226068531823282,14.026491499761674,13.826914467700064,13.627337435638493,13.427760403576883,13.228183371515273,13.028606339453702,12.829029307392094,12.629452275330483,12.429875243268874,12.230298211207302,12.030721179145694,11.831144147084084,11.631567115022511,11.431990082960903,11.232413050899293,11.03283601883772,10.833258986776114,10.633681954714506,10.434104922652896,10.234527890591322,10.034950858529712,9.835373826468105,9.63579679440653,9.43296926487571,9.28753021491848,9.18892984453846,9.091790183467095,8.994650522395727,8.89751086132438,8.800371200253013,8.703231539181646,8.606091878110279,8.50895221703893,8.411812555967563,8.314672894896196,8.217533233824847,8.12039357275348,8.023253911682113,7.926114250610765,7.828974589539397,7.731834928468031,7.634695267396664,7.537555606325315,7.44041594525395,7.343276284182582,7.246136623111234,7.148996962039867,7.0518573009685,6.954717639897151,6.857577978825784,6.760438317754417,6.663298656683069,6.566158995611701,6.469019334540334,6.371879673468968,6.27474001239762,6.1776003513262525,6.080460690254886,5.9833210291835375,5.88618136811217,5.789041707040803,5.691902045969455,5.594762384898088,5.497622723826721,5.400483062755354,5.303343401684005],[41.390038592531674,41.435127980751695,41.480217368971715,41.525306757191736,41.570396145411756,41.61548553363178,41.660574921851804,41.705664310071825,41.750753698291845,41.795843086511866,41.840932474731886,41.88602186295191,41.93111125117193,41.97620063939195,42.02129002761197,42.06637941583199,42.11146880405201,42.15655819227204,42.20164758049206,42.24673696871208,42.2918263569321,42.33691574515212,42.38200513337214,42.42709452159216,42.47218390981218,42.5172732980322,42.56236268625222,42.60745207447225,42.65254146269227,42.69763085091229,42.74272023913231,42.78780962735233,42.83289901557235,42.87798840379237,42.92307779201239,42.96816718023241,43.013256568452434,43.058345956672454,43.103435344892475,43.148524733112495,43.193614121332516,43.238703509552536,43.28379289777256,43.32888228599258,43.3739716742126,43.41906106243262,43.464150450652646,43.50923983887266,43.55432922709268,43.599418615312715,43.64450800353273,43.689597391752756,43.73468677997277,43.77977616819279,43.82486555641282,43.86995494463283,43.91504433285286,43.96013372107288,44.00522310929289,44.05031249751292,44.09540188573293,44.14049127395296,44.18558066217298,44.230670050393,44.27575943861302,44.32084882683304,44.36593821505307,44.41102760327309,44.45611699149311,44.50120637971313,44.54629576793315,44.59138515615317,44.63647454437319,44.681563932593214,44.72665332081324,44.77174270903326,44.816832097253275,44.863208867124804,44.90984311279467,44.956477358464525,45.00311160413439,45.04974584980425,45.09638009547411,45.143014341143974,45.18544646829879,45.2270381717506,45.26862987520241,45.310221578654215,45.35181328210602,45.39340498555784,45.43499668900964,45.47658839246145,45.51818009591325,45.559771799365066,45.60136350281688,45.64295520626868,45.684546909720495,45.726138613172296,45.76773031662411,45.809322020075925,45.850913723527725,45.89250542697954,45.93409713043135,45.975688833883154,46.017280537334955,46.05887224078677,46.100463944238584,46.142055647690384,46.1836473511422,46.225239054594,46.26683075804581,46.308422461497614,46.35001416494943,46.39160586840124,46.43319757185304,46.47478927530486,46.51638097875666,46.55797268220847,46.59956438566028,46.64115608911209,46.6827477925639,46.7243394960157,46.76593119946751,46.807522902919324,46.84911460637113,46.89070630982294,46.932298013274746,46.97388971672655,47.01548142017836,47.057073123630175,47.098664827081976,47.14025653053379,47.18184823398559,47.223439937437405,47.26503164088921,47.30662334434103,47.348215047792834,47.389806751244635,47.43139845469645,47.472990158148264,47.514581861600064,47.55617356505187,47.59776526850368,47.63935697195548,47.68094867540731,47.72254037885911,47.764132082310915,47.80572378576272,47.84731548921452,47.88890719266634,47.930498896118145,47.97209059956997,48.013682303021774,48.055274006473574,48.09686570992538,48.13845741337719,48.18004911682901,48.22164082028081,48.26323252373262,48.304824227184426,48.347101162986576,48.38972071452148,48.432340266056386,48.47495981759129,48.517579369126196,48.5601989206611,48.602818472196006,48.64705099408563,48.692090001152614,48.73712900821959,48.78216801528657,48.827207022353555,48.87224602942054,48.91728503648751,48.962324043554496,49.00736305062148,49.052402057688454,49.09744106475544,49.14248007182242,49.1875190788894,49.23255808595638,49.27759709302336,49.32244961519204,49.366929167722375,49.411408720252695,49.45588827278303,49.50036782531335,49.54484737784368,49.58932693037401,49.63380648290433,49.67828603543466,49.722765587964986,49.76724514049532,49.81172469302565,49.85620424555597,49.900683798086305,49.94516335061663,49.98964290314696,50.034122455677284,50.07860200820761,50.123081560737944,50.16756111326827,50.2120406657986,50.25652021832892,50.30099977085925,50.34547932338958,50.3899588759199,50.434438428450235,50.478917980980555,50.52339753351089,50.567877086041214,50.61235663857154,50.65683619110187,50.70131574363219,50.74579529616253,50.790274848692846,50.83475440122319,50.879233953753506,50.92371350628383,50.968193058814165,51.01267261134449,51.05715216387482,51.10163171640515,51.14611126893547,51.190590821465804,51.23507037399612,51.27954992652646,51.32402947905679,51.36850903158711,51.41298858411744,51.45746813664777,51.501947689178095,51.54642724170843,51.59090679423875,51.63538634676908,51.679865899299415,51.724345451829734,51.76882500436007,51.813304556890394,51.85778410942072,51.90226366195105,51.94674321448137,51.99122276701169,52.035702319542025,52.08018187207236,52.12466142460268,52.16914097713301,52.21362052966334,52.258100082193664,52.302579634724,52.33265753732676,52.34833379000198,52.364010042677194,52.37968629535241,52.39536254802762,52.41103880070284,52.42671505337806,52.442391306053274,52.45806755872849,52.47374381140371,52.48942006407892,52.505096316754134,52.520772569429354,52.53644882210457,52.55212507477978,52.567801327455,52.583477580130214,52.59915383280543,52.61483008548065,52.630506338155854,52.646182590831074,52.661858843506295,52.6775350961815,52.69321134885672,52.70888760153194,52.72456385420715,52.74024010688237,52.75591635955759,52.771592612232794,52.787268864908015,52.802945117583235,52.818621370258455,52.83429762293366,52.84997387560888,52.86565012828409,52.88132638095931,52.89700263363453,52.912678886309735,52.928355138984955,52.944031391660175,52.95970764433539,52.9753838970106,52.99106014968581,53.00673640236104,53.02241265503625,53.038088907711455,53.053765160386675,53.069441413061895,53.08511766573711,53.10079391841232,53.11647017108754,53.13214642376275,53.14782267643797,53.16349892911319,53.1791751817884,53.194851434463615,53.210527687138836,53.226203939814056,53.24188019248926,53.25755644516448,53.2732326978397,53.28890895051491,53.30458520319013,53.32026145586535,53.335937708540555,53.351613961215776,53.367290213890996,53.3829664665662,53.398642719241415,53.41431897191664,53.42999522459186,53.44567147726707,53.45422912945358,53.45709183730952,53.459954545165466,53.462817253021406,53.465679960877345,53.468542668733285,53.47140537658923,53.474268084445164,53.47713079230111,53.47999350015706,53.482856208013,53.338586972566375,52.900053850514794,52.461520728463206,52.0229876064116,51.584454484360016,51.14592136230843,50.70738824025681,50.26885511820519,49.83032199615365,49.393856025937815,48.96085511036972,48.527854194801655,48.09485327923359,47.66185236366549,47.22885144809743,46.79585053252936,46.362849616961256,45.9298487013932,45.49684778582514,45.06384687025704,44.63084595468894,44.19784503912087,43.764844123552805,43.33184320798471,42.89884229241664,42.46584137684859,42.03284046128048,41.59983954571242,41.166838630144355,40.733837714576254,40.30083679900816,39.86783588344012,39.434834967872035,39.00183405230393,38.56883313673587,38.1358322211678,37.7028313055997,37.269830390031636,36.83682947446358,36.40382855889548,35.97082764332741,35.53782672775935,35.10482581219125,34.67182489662315,34.238823981055084,33.805823065487026,33.372822149918925,32.93982123435086,32.5068203187828,32.07381940321469,31.640818487646634,31.207817572078575,30.77481665651047,30.34181574094237,29.908814825374346,29.475813909806245,29.04281299423814,28.609812078670082,28.17681116310202,27.743810247533915,27.310809331965856,26.877808416397794,26.44480750082969,26.01180658526163,25.578805669693566,25.145804754125464,24.712803838557363,24.27980292298934,23.84680200742124,23.413801091853138,22.980800176285076,22.547799260717014,22.114798345148913,21.681797429580847,21.248796514012785,20.815795598444684,20.382794682876586,19.94979376730856,19.51679285174046,19.08379193617236,18.650791020604295,18.217790105036233,17.78478918946813,17.392088368765183,17.200888022387527,17.009687676009875,16.81848732963222,16.6272869832546,16.436086636876944,16.24488629049929,16.053685944121675,15.860633566359894,15.662686522509073,15.46473947865829,15.266792434807472,15.068845390956652,14.870898347105834,14.672951303255052,14.475004259404233,14.277057215553416,14.07911017170263,13.881163127851813,13.683216084000993,13.48526904015021,13.287321996299392,13.089374952448575,12.891427908597791,12.693480864746972,12.495533820896153,12.297586777045334,12.09963973319455,11.901692689343733,11.703745645492914,11.505798601642132,11.307851557791313,11.109904513940494,10.911957470089712,10.714010426238891,10.516063382388072,10.318116338537253,10.120169294686471,9.922222250835652,9.724275206984831,9.52632816313405,9.328381119283232,9.189817679980036,9.093671101068004,8.997524522155953,8.9013779432439,8.805231364331867,8.709084785419815,8.612938206507764,8.516791627595712,8.42064504868368,8.324498469771628,8.228351890859576,8.132205311947542,8.03605873303549,7.939912154123439,7.843765575211406,7.747618996299355,7.651472417387303,7.555325838475253,7.45917925956322,7.363032680651168,7.266886101739116,7.170739522827082,7.074592943915031,6.978446365002979,6.882299786090947,6.786153207178894,6.690006628266843,6.593860049354809,6.497713470442758,6.401566891530707,6.305420312618655,6.209273733706622,6.11312715479457,6.016980575882518,5.92466739187849,5.832817582984902,5.740967774091311,5.649117965197738,5.557268156304149,5.465418347410559,5.3735685385169685,5.281718729623397],[41.76161703378718,41.8067064220072,41.85179581022722,41.896885198447244,41.941974586667264,41.98706397488729,42.03215336310731,42.07724275132733,42.12233213954735,42.167421527767374,42.212510915987394,42.257600304207415,42.302689692427435,42.347779080647456,42.392868468867476,42.4379578570875,42.48304724530752,42.52813663352754,42.57322602174756,42.61831540996758,42.66340479818761,42.70849418640763,42.753583574627655,42.798672962847675,42.843762351067696,42.888851739287716,42.93394112750774,42.97903051572776,43.02411990394778,43.0692092921678,43.11429868038782,43.15938806860784,43.20447745682786,43.24956684504788,43.2946562332679,43.33974562148792,43.38483500970794,43.42992439792796,43.47501378614798,43.520103174368,43.565192562588024,43.610281950808044,43.655371339028065,43.70046072724809,43.74555011546811,43.79063950368814,43.83572889190816,43.880818280128175,43.925907668348195,43.97099705656822,44.01608644478824,44.061175833008264,44.106265221228284,44.151354609448305,44.19644399766833,44.241533385888346,44.28662277410837,44.33171216232839,44.37680155054841,44.421890938768435,44.467495280169935,44.514129525839806,44.560763771509656,44.60739801717952,44.654032262849384,44.70066650851925,44.74730075418911,44.79393499985897,44.84056924552883,44.88720349119869,44.933837736868554,44.98047198253842,45.027106228208275,45.07374047387814,45.120374719547996,45.16700896521786,45.213643210887724,45.26027745655759,45.306911702227445,45.35354594789731,45.40018019356717,45.44681443923703,45.49344868490689,45.54008293057675,45.58251505773157,45.62410676118338,45.665698464635184,45.70729016808699,45.7488818715388,45.790473574990614,45.832065278442414,45.87365698189423,45.915248685346036,45.95684038879784,45.99843209224966,46.04002379570146,46.08161549915327,46.12320720260508,46.16479890605689,46.2063906095087,46.2479823129605,46.28957401641232,46.331165719864124,46.37275742331593,46.41434912676773,46.45594083021955,46.49753253367136,46.53912423712316,46.580715940574976,46.622307644026776,46.66389934747859,46.7054910509304,46.747082754382205,46.78867445783402,46.83026616128582,46.871857864737635,46.91344956818944,46.95504127164124,46.99663297509306,47.038224678544864,47.07981638199668,47.121408085448486,47.16299978890029,47.2045914923521,47.24618319580391,47.287774899255716,47.32936660270752,47.37095830615934,47.41255000961114,47.454141713062945,47.49573341651476,47.53732511996657,47.578916823418375,47.62050852687018,47.66210023032199,47.7036919337738,47.745283637225604,47.78687534067742,47.828467044129226,47.87005874758104,47.91165045103284,47.953242154484656,47.99483385793646,48.03659686986666,48.07921642140157,48.121835972936466,48.16445552447137,48.207075076006284,48.24969462754118,48.292314179076094,48.33493373061099,48.377553282145904,48.4201728336808,48.46279238521571,48.50541193675061,48.54803148828552,48.59065103982042,48.63327059135533,48.67589014289023,48.71850969442514,48.76112924596004,48.80374879749495,48.846368349029845,48.88898790056476,48.931607452099655,48.97422700363457,49.016846555169465,49.0610790770591,49.106118084126074,49.15115709119305,49.19619609826003,49.241235105327014,49.286274112394,49.33131311946097,49.37635212652795,49.42139113359494,49.46643014066191,49.5114691477289,49.55650815479588,49.60154716186286,49.64658616892984,49.69162517599682,49.7366641830638,49.781703190130784,49.82674219719776,49.87178120426474,49.916820211331725,49.9618592183987,50.00689822546568,50.051937232532666,50.09697623959965,50.142015246666624,50.187054253733606,50.23209326080059,50.277132267867565,50.32217127493455,50.36721028200153,50.41224928906851,50.45728829613549,50.50232730320247,50.54736631026945,50.59240531733643,50.637444324403404,50.6824833314704,50.72752233853737,50.77256134560435,50.817600352671334,50.86263935973832,50.9076783668053,50.952717373872275,50.99775638093926,51.04279538800624,51.08783439507322,51.1328734021402,51.177912409207174,51.222951416274164,51.267990423341146,51.31302943040812,51.357961873902426,51.40244142643276,51.446920978963085,51.49140053149342,51.535880084023745,51.580359636554064,51.6248391890844,51.669318741614724,51.71379829414505,51.758277846675384,51.8027573992057,51.84723695173603,51.891716504266356,51.93619605679669,51.980675609327015,52.02515516185734,52.06963471438767,52.114114266918,52.15859381944833,52.203073371978654,52.24755292450899,52.292032477039314,52.33651202956964,52.380991582099966,52.425471134630286,52.469950687160626,52.51443023969095,52.55890979222127,52.603389344751605,52.647868897281924,52.69234844981226,52.73682800234259,52.766905904945354,52.78258215762057,52.79825841029579,52.81393466297101,52.829610915646214,52.845287168321434,52.86096342099664,52.87663967367186,52.89231592634708,52.907992179022294,52.923668431697514,52.93934468437273,52.95502093704795,52.970697189723154,52.986373442398374,53.00204969507359,53.0177259477488,53.03340220042402,53.049078453099234,53.064754705774455,53.08043095844967,53.09610721112488,53.111783463800094,53.127459716475315,53.143135969150535,53.15881222182575,53.17448847450096,53.19016472717618,53.20584097985139,53.22151723252661,53.23719348520182,53.25286973787704,53.268545990552255,53.284222243227475,53.28850871380756,53.2913714216635,53.294234129519445,53.297096837375385,53.299959545231324,53.30282225308727,53.3056849609432,53.30854766879916,53.31141037665509,53.314273084511036,53.31713579236698,53.31999850022292,53.32286120807886,53.3257239159348,53.32858662379075,53.33144933164668,53.334312039502635,53.33717474735857,53.340037455214514,53.34290016307045,53.3457628709264,53.34862557878234,53.351488286638286,53.35435099449422,53.357213702350165,53.360076410206105,53.362939118062044,53.365801825917984,53.36866453377393,53.37152724162987,53.37438994948582,53.37725265734176,53.380115365197696,53.382978073053636,53.385840780909575,53.38870348876553,53.39156619662146,53.39442890447741,53.39729161233335,53.40015432018929,53.40301702804523,53.405879735901166,53.40874244375711,53.41160515161306,53.41446785946899,53.41733056732494,53.42019327518088,53.42305598303682,53.425918690892765,53.28164945544614,52.84311633339456,52.40458321134298,51.966050089291365,51.527516967239784,51.0889838451882,50.650450723136586,50.21191760108496,49.773384479033425,49.3348513569818,48.89631823493018,48.457785112878604,48.019251990827016,47.5807188687754,47.142185746723825,46.70365262467224,46.26511950262062,45.82658638056904,45.38805325851746,44.94952013646584,44.51098701441421,44.07245389236264,43.63392077031105,43.195387648259434,42.75685452620786,42.31832140415627,41.879788282104656,41.441255160053075,41.002722038001494,40.56418891594988,40.125655793898254,39.687122671846716,39.2485895497951,38.810056427743476,38.37152330569189,37.932990183640314,37.4944570615887,37.05592393953711,36.61739081748553,36.17885769543391,35.74457783197029,35.311576916402224,34.878576000834116,34.445575085266015,34.012574169697956,33.57957325412989,33.14657233856179,32.713571422993724,32.280570507425665,31.84756959185756,31.4145686762895,30.98156776072144,30.548566845153335,30.115565929585234,29.682565014017214,29.24956409844911,28.81656318288101,28.383562267312946,27.950561351744884,27.517560436176783,27.08455952060872,26.65155860504066,26.21855768947256,25.785556773904496,25.352555858336434,24.919554942768332,24.486554027200228,24.053553111632205,23.620552196064104,23.187551280496002,22.754550364927944,22.32154944935988,21.888548533791777,21.45554761822371,21.022546702655653,20.58954578708755,20.15654487151945,19.723543955951428,19.290543040383323,18.857542124815225,18.42454120924716,17.9915402936791,17.558539378110996,17.165838557408048,16.974638211030392,16.78343786465274,16.592237518275084,16.401037171897467,16.20983682551981,16.018636479142156,15.82743613276454,15.636235786386884,15.44503544000923,15.253835093631611,15.06263474725396,14.871434400876304,14.680234054498648,14.48903370812103,14.297833361743374,14.10663301536572,13.915432668988101,13.724232322610447,13.533031976232794,13.341831629855175,13.150631283477521,12.959430937099867,12.768230590722247,12.577030244344595,12.38582989796694,12.194629551589284,11.99889834175756,11.800951297906742,11.603004254055922,11.40505721020514,11.207110166354319,11.009163122503502,10.81121607865272,10.6132690348019,10.415321990951082,10.217374947100263,10.01942790324948,9.821480859398662,9.623533815547841,9.42558677169706,9.22763972784624,9.089076288543046,8.99292970963101,8.89678313071896,8.800636551806909,8.704489972894876,8.608343393982823,8.512196815070773,8.416050236158721,8.319903657246687,8.223757078334636,8.127610499422584,8.03146392051055,7.9353173415985,7.839170762686448,7.743024183774415,7.649004931672819,7.557155122779228,7.465305313885641,7.373455504992068,7.281605696098477,7.189755887204888,7.097906078311315,7.0060562694177255,6.914206460524136,6.822356651630562,6.730506842736974,6.6386570338433835,6.54680722494981,6.45495741605622,6.363107607162631,6.2712577982690405,6.179407989375468,6.087558180481879,5.995708371588289,5.903858562694715,5.812008753801125,5.720158944907536,5.628309136013963,5.536459327120373,5.444609518226783,5.352759709333194,5.260909900439621],[42.13319547504271,42.17828486326274,42.22337425148276,42.26846363970277,42.3135530279228,42.358642416142814,42.40373180436284,42.44882119258286,42.49391058080288,42.53899996902291,42.584089357242924,42.629178745462944,42.674268133682965,42.719357521902985,42.76444691012301,42.809536298343026,42.854625686563054,42.899715074783074,42.944804463003095,42.989893851223115,43.034983239443136,43.08007262766316,43.12516201588318,43.1702514041032,43.21534079232322,43.26043018054324,43.30551956876326,43.35060895698328,43.3956983452033,43.44078773342332,43.48587712164334,43.53096650986337,43.57605589808339,43.62114528630341,43.66623467452344,43.71132406274346,43.75641345096348,43.8015028391835,43.84659222740352,43.89168161562354,43.93677100384356,43.98186039206358,44.0269497802836,44.07203916850362,44.11841593888495,44.165050184554815,44.21168443022468,44.258318675894536,44.30495292156439,44.35158716723426,44.39822141290412,44.444855658573985,44.49148990424384,44.5381241499137,44.58475839558356,44.63139264125343,44.67802688692329,44.724661132593155,44.771295378263005,44.81792962393287,44.86456386960273,44.9111981152726,44.95783236094246,45.00446660661232,45.051100852282175,45.09773509795204,45.144369343621904,45.19100358929177,45.23763783496163,45.28427208063149,45.330906326301346,45.37754057197121,45.424174817641074,45.47080906331094,45.517443308980795,45.56407755465066,45.610711800320516,45.65734604599038,45.703980291660244,45.7506145373301,45.79724878299996,45.84388302866982,45.890517274339686,45.93715152000955,45.97958364716436,46.021175350616176,46.062767054067976,46.10435875751979,46.14595046097159,46.187542164423405,46.229133867875206,46.27072557132702,46.31231727477883,46.353908978230635,46.39550068168245,46.43709238513425,46.478684088586064,46.52027579203787,46.561867495489686,46.60345919894149,46.6450509023933,46.68664260584511,46.728234309296916,46.76982601274872,46.81141771620053,46.85300941965234,46.89460112310415,46.93619282655595,46.97778453000776,47.019376233459575,47.06096793691138,47.1025596403632,47.144151343815,47.185743047266804,47.22733475071861,47.268926454170426,47.310518157622234,47.35210986107404,47.39370156452585,47.43529326797765,47.47688497142947,47.51847667488128,47.560068378333085,47.60166008178489,47.64325178523669,47.68484348868851,47.72643519214032,47.76871212828166,47.81133167981656,47.85395123135147,47.89657078288638,47.93919033442128,47.98180988595619,48.02442943749109,48.06704898902599,48.1096685405609,48.1522880920958,48.19490764363071,48.23752719516561,48.28014674670052,48.32276629823542,48.36538584977033,48.40800540130523,48.45062495284013,48.49324450437504,48.53586405590994,48.57848360744485,48.62110315897975,48.663722710514655,48.70634226204956,48.748961813584465,48.79158136511937,48.834200916654275,48.87682046818917,48.919440019724085,48.96205957125899,49.004679122793895,49.0472986743288,49.0899182258637,49.13253777739861,49.17515732893351,49.21777688046842,49.26039643200332,49.30301598353823,49.34563553507313,49.38825508660804,49.43087463814294,49.475107160032564,49.52014616709955,49.56518517416653,49.610224181233505,49.65526318830049,49.70030219536747,49.745341202434446,49.790380209501436,49.83541921656841,49.88045822363539,49.925497230702376,49.97053623776935,50.015575244836334,50.06061425190332,50.10565325897029,50.150692266037275,50.19573127310426,50.24077028017123,50.28580928723821,50.3308482943052,50.375887301372174,50.42092630843916,50.46596531550614,50.51100432257312,50.5560433296401,50.60108233670709,50.646121343774055,50.69116035084104,50.73619935790802,50.781238364974996,50.826277372041986,50.87131637910896,50.916355386175944,50.96139439324293,51.00643340030991,51.051472407376885,51.09651141444386,51.14155042151084,51.186589428577825,51.23162843564481,51.27666744271179,51.321706449778766,51.366745456845756,51.41178446391273,51.45682347097971,51.50186247804669,51.54690148511367,51.591940492180655,51.63697949924763,51.68201850631462,51.727057513381595,51.77209652044857,51.81713552751556,51.862174534582536,51.90721354164952,51.9522525487165,51.99729155578348,52.04233056285046,52.087369569917435,52.132408576984425,52.17744758405141,52.22248659111838,52.267525598185365,52.31256460525234,52.35760361231932,52.402642619386306,52.44768162645328,52.49272063352027,52.537759640587254,52.58279864765422,52.62783765472121,52.67287666178819,52.71791566885516,52.76295467592215,52.80799368298913,52.85303269005611,52.89807169712309,52.94311070419007,52.98814971125705,53.033214368301735,53.07836025117094,53.12350613404015,53.168652016909355,53.19034461537156,53.18858392942674,53.18682324348194,53.18506255753713,53.18330187159233,53.18154118564752,53.17978049970271,53.178019813757906,53.1762591278131,53.174498441868295,53.172737755923485,53.170977069978676,53.169216384033874,53.17145433171255,53.174317039568486,53.17717974742443,53.18004245528037,53.18290516313631,53.18576787099225,53.188630578848205,53.19149328670414,53.194355994560084,53.19721870241602,53.20008141027196,53.2029441181279,53.20580682598385,53.20866953383979,53.21153224169573,53.214394949551675,53.217257657407615,53.220120365263554,53.2229830731195,53.22584578097545,53.22870848883139,53.23157119668733,53.234433904543266,53.237296612399206,53.24015932025515,53.243022028111085,53.24588473596704,53.24874744382298,53.25161015167892,53.25447285953486,53.2573355673908,53.26019827524675,53.26306098310269,53.26592369095863,53.26878639881457,53.27164910667051,53.27451181452645,53.277374522382395,53.28023723023834,53.28309993809428,53.28596264595022,53.28882535380616,53.2916880616621,53.29455076951805,53.29741347737398,53.30027618522993,53.30313889308587,53.30600160094181,53.30886430879775,53.31172701665369,53.31458972450964,53.31745243236558,53.320315140221524,53.323177848077464,53.3260405559334,53.32890326378934,53.3317659716453,53.33462867950122,53.337491387357176,53.34035409521311,53.34321680306905,53.346079510924994,53.348942218780934,53.35180492663688,53.35466763449282,53.35753034234876,53.360393050204706,53.363255758060646,53.36611846591659,53.36898117377253,53.22471193832591,52.78617881627433,52.34764569422275,51.90911257217113,51.470579450119544,51.03204632806798,50.59351320601635,50.15498008396473,49.71644696191319,49.27791383986157,48.839380717809945,48.400847595758364,47.96231447370678,47.52378135165516,47.085248229603586,46.646715107552005,46.20818198550039,45.76964886344881,45.33111574139723,44.8925826193456,44.45404949729398,44.01551637524241,43.57698325319082,43.1384501311392,42.69991700908763,42.26138388703604,41.822850764984416,41.38431764293284,40.94578452088126,40.50725139882964,40.06871827677802,39.630185154726476,39.19165203267486,38.753118910623236,38.314585788571655,37.87605266652008,37.43751954446846,36.99898642241688,36.560453300365296,36.12192017831368,35.6833870562621,35.24485393421052,34.8063208121589,34.36778769010728,33.92925456805569,33.490721446004116,33.05218832395249,32.61365520190091,32.17512207984934,31.73658895779771,31.298055835746133,30.859522713694552,30.42098959164293,29.982456469591312,29.54392334753977,29.10539022548815,28.666857103436534,28.22832398138495,27.789790859333372,27.351257737281756,26.912724615230175,26.47419149317859,26.03565837112697,25.597125249075393,25.158592127023805,24.720059004972185,24.281525882920565,23.842992760869027,23.404459638817407,22.965926516765787,22.5283005535708,22.095299638002736,21.662298722434638,21.22929780686657,20.79629689129851,20.363295975730406,19.930295060162308,19.497294144594285,19.06429322902618,18.631292313458083,18.198291397890017,17.765290482321955,17.33228956675385,16.939588746050905,16.748388399673253,16.557188053295594,16.36598770691794,16.174787360540325,15.98358701416267,15.792386667785017,15.601186321407397,15.409985975029743,15.218785628652089,15.027585282274469,14.836384935896817,14.645184589519161,14.453984243141505,14.262783896763889,14.071583550386233,13.880383204008577,13.689182857630959,13.497982511253305,13.306782164875653,13.115581818498033,12.924381472120379,12.733181125742725,12.541980779365106,12.350780432987452,12.159580086609797,11.968379740232141,11.777179393854524,11.585979047476869,11.414584991722107,11.274575684270992,11.13456637681985,10.99455706936871,10.854547761917594,10.714538454466453,10.574529147015312,10.43451983956417,10.294510532113053,10.154501224661912,10.014491917210773,9.874482609759657,9.734473302308515,9.594463994857374,9.454454687406258,9.314445379955117,9.174436072503974,9.03442676505286,8.894417457601717,8.754408150150576,8.614398842699435,8.47438953524832,8.33438022779718,8.194370920346037,8.054361612894922,7.914352305443781,7.8118957202762065,7.720045911382633,7.628196102489043,7.536346293595453,7.444496484701865,7.352646675808291,7.260796866914703,7.1689470580211125,7.07709724912754,6.98524744023395,6.89339763134036,6.8015478224467865,6.709698013553197,6.617848204659607,6.525998395766035,6.434148586872444,6.342298777978854,6.250448969085266,6.158599160191692,6.066749351298103,5.974899542404513,5.883049733510941,5.7911999246173504,5.69935011572376,5.607500306830188,5.515650497936599,5.423800689043008,5.331950880149417,5.240101071255846],[42.50477391629823,42.54986330451824,42.59495269273827,42.64004208095829,42.68513146917831,42.730220857398336,42.77531024561835,42.82039963383837,42.8654890220584,42.91057841027842,42.95566779849843,43.00075718671845,43.04584657493847,43.0909359631585,43.13602535137852,43.18111473959854,43.22620412781856,43.27129351603858,43.3163829042586,43.361472292478624,43.406561680698644,43.451651068918665,43.496740457138685,43.541829845358706,43.586919233578726,43.63200862179875,43.677098010018774,43.72270235193009,43.769336597599946,43.81597084326981,43.862605088939674,43.90923933460953,43.955873580279395,44.00250782594925,44.049142071619116,44.09577631728898,44.14241056295884,44.1890448086287,44.23567905429856,44.28231329996842,44.32894754563828,44.37558179130814,44.42221603697801,44.46885028264787,44.51548452831773,44.56211877398759,44.60875301965745,44.65538726532732,44.70202151099717,44.748655756667034,44.7952900023369,44.841924248006755,44.888558493676626,44.935192739346476,44.98182698501634,45.028461230686204,45.07509547635606,45.12172972202593,45.16836396769579,45.21499821336565,45.26163245903551,45.30826670470537,45.35490095037524,45.4015351960451,45.44816944171495,45.49480368738482,45.54143793305468,45.588072178724545,45.6347064243944,45.681340670064266,45.72797491573412,45.77460916140399,45.821243407073844,45.86787765274371,45.91451189841357,45.961146144083436,46.00778038975329,46.05441463542315,46.101048881093014,46.14768312676288,46.19431737243274,46.2409516181026,46.28758586377246,46.33422010944232,46.37665223659714,46.418243940048946,46.45983564350075,46.50142734695257,46.54301905040437,46.58461075385618,46.62620245730798,46.66779416075979,46.709385864211605,46.75097756766341,46.79256927111522,46.83416097456703,46.87575267801884,46.91734438147064,46.95893608492246,47.00052778837427,47.04211949182608,47.083711195277886,47.12530289872969,47.1668946021815,47.20848630563331,47.250078009085115,47.29166971253693,47.33326141598873,47.37485311944054,47.41644482289235,47.45820783516174,47.50082738669665,47.54344693823155,47.58606648976646,47.62868604130136,47.67130559283627,47.713925144371174,47.75654469590607,47.79916424744098,47.84178379897588,47.884403350510794,47.9270229020457,47.9696424535806,48.0122620051155,48.054881556650415,48.09750110818531,48.140120659720225,48.18274021125512,48.22535976279002,48.26797931432493,48.31059886585984,48.35321841739474,48.39583796892965,48.438457520464546,48.48107707199945,48.523696623534356,48.56631617506926,48.608935726604166,48.65155527813907,48.694174829673976,48.73679438120888,48.779413932743786,48.82203348427869,48.86465303581359,48.9072725873485,48.9498921388834,48.99251169041831,49.035131241953216,49.07775079348812,49.12037034502303,49.162989896557924,49.20560944809283,49.248228999627734,49.29084855116264,49.333468102697545,49.37608765423245,49.41870720576736,49.46132675730226,49.50394630883716,49.54656586037207,49.58918541190697,49.63180496344188,49.67442451497678,49.71704406651168,49.759663618046595,49.80228316958149,49.8449027211164,49.889135243006024,49.934174250073,49.97921325713998,50.024252264206964,50.06929127127395,50.11433027834093,50.15936928540791,50.20440829247489,50.24944729954187,50.294486306608846,50.339525313675836,50.38456432074281,50.429603327809794,50.474642334876776,50.51968134194375,50.56472034901074,50.60975935607772,50.65479836314469,50.699837370211675,50.74487637727866,50.78991538434563,50.83495439141262,50.8799933984796,50.92503240554658,50.970071412613564,51.01511041968054,51.06014942674752,51.10518843381449,51.150227440881494,51.19526644794847,51.240305455015445,51.28534446208242,51.3303834691494,51.375422476216386,51.42046148328337,51.465500490350344,51.51053949741733,51.55557850448431,51.600617511551285,51.64565651861827,51.69069552568524,51.73573453275223,51.78077353981921,51.82581254688619,51.87085155395317,51.91589056102015,51.96092956808713,52.005968575154114,52.05100758222109,52.09611071471552,52.14125659758473,52.186402480453935,52.23154836332314,52.27669424619235,52.321840129061556,52.366986011930756,52.41213189479997,52.45727777766918,52.50242366053838,52.54756954340759,52.5927154262768,52.637861309146004,52.683007192015204,52.72815307488441,52.773298957753624,52.818444840622824,52.86359072349203,52.90873660636124,52.953882489230445,52.99902837209966,53.044174254968866,53.089320137838065,53.13446602070728,53.17961190357648,53.224757786445686,53.2699036693149,53.31504955218411,53.36019543505331,53.40534131792252,53.45048720079173,53.495633083660934,53.54077896653014,53.58592484939935,53.607617447861536,53.60585676191674,53.60409607597193,53.60233539002712,53.60057470408232,53.59881401813751,53.5970533321927,53.59529264624789,53.59353196030308,53.59177127435827,53.59001058841347,53.58824990246866,53.58648921652385,53.58472853057904,53.58296784463424,53.58120715868943,53.57944647274463,53.57768578679982,53.57592510085502,53.57416441491021,53.5724037289654,53.57064304302059,53.568882357075786,53.56712167113098,53.565360985186175,53.56360029924136,53.561839613296556,53.560078927351746,53.55831824140694,53.55655755546213,53.55479686951733,53.553036183572516,53.55127549762771,53.5495148116829,53.547754125738095,53.54599343979329,53.544232753848476,53.542472067903674,53.54071138195887,53.538950696014055,53.53719001006925,53.53542932412444,53.533668638179634,53.53190795223483,53.53014726629002,53.52838658034521,53.52662589440041,53.524865208455594,53.52310452251079,53.52134383656599,53.51958315062118,53.51782246467637,53.516061778731554,53.51430109278675,53.51254040684195,53.51077972089714,53.50901903495233,53.50725834900753,53.50549766306273,53.50373697711791,53.50197629117311,53.500215605228306,53.49845491928349,53.49669423333868,53.494933547393885,53.49317286144907,53.491412175504266,53.489651489559456,53.487890803614654,53.486130117669845,53.48436943172503,53.482608745780226,53.480848059835424,53.47908737389061,53.477326687945805,53.475566002000996,53.45358131276441,53.4276131681853,53.401645023606186,53.37567687902707,53.34970873444796,53.32374058986884,53.29777244528972,53.13350827476351,52.69265205234324,52.25179582992298,51.810939607502675,51.37008338508241,50.92922716266215,50.488370940241836,50.047514717821535,49.606658495401305,49.165802272981004,48.72546494802769,48.28640962224655,47.84735429646541,47.408298970684235,46.96924364490309,46.530188319121955,46.091132993340764,45.65207766755964,45.2130223417785,44.77396701599732,44.33491169021614,43.895856364435,43.456801038653865,43.01774571287268,42.57869038709154,42.1396350613104,41.700579735529224,41.26152440974809,40.82246908396695,40.38341375818576,39.94435843240459,39.50530310662349,39.06624778084232,38.627192455061135,38.18813712928,37.749081803498854,37.31002647771767,36.87097115193654,36.4319158261554,35.99286050037422,35.55380517459308,35.11474984881194,34.675694523030764,34.23663919724958,33.79758387146845,33.35852854568731,32.91947321990612,32.48041789412498,32.04136256834385,31.602307242562667,31.16325191678153,30.72419659100039,30.285141265219213,29.84608593943803,29.407030613656932,28.967975287875753,28.528919962094577,28.08986463631344,27.6508093105323,27.21175398475112,26.77269865896998,26.33364333318884,25.894588007407663,25.455532681626522,25.01647735584539,24.577422030064206,24.138366704283023,23.699311378501932,23.26025605272075,22.821200726939573,22.382145401158432,21.94309007537729,21.504034749596116,21.064979423814975,20.62592409803384,20.18686877225266,19.747813446471476,19.308758120690378,18.869702794909198,18.430647469128022,17.99159214334688,17.55253681756574,17.113481491784565,16.71715471173872,16.53447066036903,16.351786608999348,16.169102557629657,15.986418506260005,15.803734454890318,15.621050403520634,15.43836635215098,15.255682300781293,15.072998249411606,14.890314198041954,14.708791334639926,14.568782027188785,14.428772719737646,14.28876341228653,14.148754104835387,14.008744797384246,13.86873548993313,13.728726182481989,13.588716875030848,13.448707567579733,13.30869826012859,13.16868895267745,13.028679645226333,12.888670337775192,12.748661030324051,12.60865172287291,12.468642415421794,12.328633107970653,12.188623800519512,12.048614493068396,11.908605185617255,11.768595878166114,11.628586570714997,11.488577263263856,11.348567955812715,11.208558648361572,11.068549340910458,10.928540033459317,10.788530726008176,10.64852141855706,10.508512111105919,10.368502803654778,10.228493496203662,10.088484188752522,9.948474881301381,9.808465573850265,9.668456266399124,9.528446958947981,9.38843765149684,9.248428344045724,9.108419036594583,8.968409729143442,8.828400421692326,8.688391114241186,8.548381806790044,8.408372499338927,8.268363191887786,8.128353884436645,7.988344576985504,7.848335269534389,7.708325962083248,7.568316654632107,7.428307347180991,7.28829803972985,7.148288732278709,7.0082794248275935,6.868270117376452,6.7282608099253105,6.588251502474195,6.448242195023054,6.308232887571913,6.175633953514626,6.088762181640108,6.001890409765576,5.915018637891044,5.828146866016527,5.7412750941419946,5.654403322267463,5.567531550392945,5.480659778518414,5.393788006643881,5.306916234769348,5.2200444628948315],[42.876352357553735,42.921441745773755,42.96653113399378,43.011620522213796,43.05670991043382,43.101799298653845,43.146888686873865,43.191978075093886,43.237067463313906,43.28215685153393,43.32724623975395,43.373623010645076,43.42025725631494,43.466891501984804,43.51352574765466,43.560159993324525,43.60679423899439,43.65342848466425,43.70006273033412,43.74669697600397,43.79333122167383,43.839965467343696,43.88659971301356,43.93323395868342,43.97986820435328,44.02650245002314,44.073136695693,44.119770941362866,44.16640518703272,44.21303943270258,44.259673678372444,44.30630792404231,44.35294216971217,44.39957641538203,44.44621066105189,44.49284490672176,44.539479152391614,44.58611339806148,44.632747643731335,44.6793818894012,44.726016135071056,44.77265038074092,44.819284626410784,44.86591887208065,44.912553117750505,44.95918736342036,45.005821609090226,45.05245585476009,45.099090100429954,45.14572434609981,45.19235859176967,45.23899283743953,45.2856270831094,45.33226132877925,45.378895574449125,45.425529820118975,45.472164065788846,45.5187983114587,45.56543255712857,45.61206680279843,45.65870104846828,45.70533529413815,45.75196953980801,45.798603785477866,45.84523803114774,45.8918722768176,45.93850652248746,45.985140768157315,46.03177501382718,46.07840925949704,46.12504350516691,46.171677750836764,46.21831199650663,46.264946242176485,46.31158048784635,46.35821473351621,46.40484897918607,46.451483224855934,46.49811747052579,46.544751716195655,46.59138596186552,46.63802020753538,46.68465445320524,46.731288698875105,46.773720826029916,46.81531252948172,46.85690423293353,46.89849593638534,46.94008763983715,46.98167934328896,47.02327104674076,47.064862750192574,47.10645445364438,47.148046157096196,47.19032309357672,47.23294264511163,47.27556219664653,47.31818174818144,47.36080129971634,47.40342085125125,47.44604040278615,47.48865995432105,47.53127950585596,47.57389905739087,47.61651860892577,47.65913816046067,47.701757711995576,47.74437726353048,47.786996815065386,47.82961636660029,47.872235918135196,47.91485546967011,47.957475021205006,48.00009457273992,48.042714124274816,48.08533367580973,48.12795322734463,48.17057277887953,48.21319233041444,48.25581188194934,48.298431433484254,48.34105098501915,48.38367053655405,48.42629008808896,48.468909639623874,48.51152919115877,48.554148742693684,48.59676829422858,48.63938784576348,48.68200739729839,48.7246269488333,48.7672465003682,48.80986605190311,48.852485603438005,48.89510515497291,48.937724706507815,48.98034425804272,49.022963809577625,49.06558336111253,49.10820291264744,49.15082246418234,49.19344201571724,49.23606156725215,49.27868111878705,49.32130067032196,49.36392022185686,49.40653977339177,49.449159324926676,49.49177887646158,49.534398427996486,49.57701797953139,49.619637531066296,49.662257082601194,49.7048766341361,49.747496185671004,49.79011573720591,49.832735288740814,49.87535484027572,49.917974391810624,49.96059394334553,50.003213494880434,50.04583304641534,50.088452597950244,50.13107214948515,50.17369170102005,50.21631125255495,50.25893080408986,50.30316332597948,50.348202333046466,50.39324134011344,50.438280347180424,50.483319354247406,50.52835836131439,50.57339736838137,50.61843637544834,50.66347538251533,50.70851438958231,50.753553396649295,50.79859240371626,50.84363141078325,50.888670417850236,50.93370942491721,50.978748431984194,51.023787439051176,51.06882644611816,51.11386545318514,51.1590070611293,51.2041529439985,51.249298826867715,51.29444470973692,51.33959059260613,51.38473647547534,51.42988235834454,51.47502824121375,51.520174124082956,51.56532000695216,51.61046588982137,51.65561177269058,51.700757655559784,51.74590353842899,51.7910494212982,51.836195304167404,51.88134118703661,51.92648706990582,51.971632952775025,52.01677883564423,52.06192471851344,52.10707060138264,52.15221648425185,52.19736236712106,52.242508249990266,52.28765413285947,52.33280001572868,52.377945898597886,52.42309178146709,52.4682376643363,52.51338354720551,52.558529430074714,52.60367531294392,52.64882119581313,52.693967078682334,52.73911296155154,52.78425884442075,52.829404727289955,52.87455061015916,52.91969649302837,52.964842375897575,53.009988258766775,53.05513414163599,53.100280024505196,53.1454259073744,53.19057179024361,53.235717673112816,53.28086355598202,53.32600943885123,53.37115532172044,53.416301204589644,53.46144708745885,53.506592970328064,53.551738853197264,53.59688473606648,53.64203061893568,53.687176501804885,53.73232238467409,53.7774682675433,53.822614150412505,53.867760033281705,53.91290591615092,53.95805179902013,54.00319768188934,54.02489028035153,54.023129594406726,54.021368908461916,54.019608222517114,54.017847536572305,54.0160868506275,54.014326164682686,54.012565478737876,54.010804792793074,54.009044106848265,54.00728342090346,54.00552273495865,54.003762049013844,54.00200136306904,54.00024067712423,53.99847999117942,53.99671930523461,53.99495861928981,53.993197933345,53.9914372474002,53.98967656145538,53.98791587551058,53.986155189565764,53.98439450362096,53.98263381767616,53.98087313173134,53.97911244578654,53.97735175984174,53.97559107389692,53.97383038795213,53.97206970200732,53.970309016062515,53.9685483301177,53.96678764417289,53.96502695822808,53.96326627228328,53.96150558633846,53.95974490039366,53.95798421444886,53.95622352850405,53.95446284255924,53.952702156614436,53.950941470669626,53.94918078472482,53.94742009878001,53.9456594128352,53.943898726890396,53.94213804094559,53.94037735500078,53.938616669055975,53.93685598311117,53.935095297166356,53.91265097411126,53.88668282953215,53.860714684953024,53.834746540373914,53.808778395794796,53.782810251215686,53.75684210663656,53.73087396205746,53.70490581747834,53.678937672899224,53.6529695283201,53.62700138374099,53.60103323916188,53.57506509458276,53.549096950003644,53.523128805424534,53.49716066084541,53.4711925162663,53.44522437168718,53.419256227108065,53.393288082528954,53.36731993794984,53.34135179337072,53.31538364879161,53.289415504212485,53.263447359633375,53.237479215054265,53.21151107047514,53.18554292589602,53.15957478131691,53.133606636737795,52.96934246621158,52.52848624379132,52.08763002137105,51.64677379895075,51.20591757653048,50.765061354110216,50.324205131689915,49.88334890926961,49.442492686849384,49.00163646442908,48.560780242008775,48.11992401958851,47.679067797168244,47.23821157474794,46.79735535232768,46.35649912990741,45.91564290748711,45.474786685066846,45.03393046264658,44.59307424022627,44.152218017805964,43.711361795385706,43.27050557296545,42.82964935054514,42.388793128124874,41.94793690570461,41.50708068328431,41.066224460864035,40.62536823844377,40.18451201602347,39.74365579360317,39.302799571182945,38.861943348762644,38.421087126342336,37.98023090392206,37.539374681501805,37.098518459081504,36.65766223666124,36.21680601424097,35.775949791820665,35.3350935694004,34.894237346980134,34.453610047536905,34.01455472175573,33.57549939597459,33.13644407019346,32.69738874441227,32.25833341863114,31.81927809285,31.38022276706882,30.941167441287682,30.50211211550654,30.063056789725366,29.624001463944182,29.184946138163085,28.745890812381905,28.306835486600725,27.86778016081959,27.42872483503845,26.98966950925727,26.55061418347613,26.11155885769499,25.67250353191382,25.233448206132675,24.794392880351538,24.355337554570358,23.91628222878918,23.47722690300808,23.0381715772269,22.59911625144572,22.16006092566458,21.721005599883444,21.281950274102265,20.842894948321128,20.403839622539987,19.96478429675881,19.525728970977624,19.08667364519653,18.647618319415347,18.208562993634175,17.769507667853034,17.33045234207189,16.891397016290718,16.495070236244867,16.31238618487518,16.129702133505496,15.947018082135807,15.764334030766156,15.58164997939647,15.398965928026783,15.216281876657128,15.033597825287444,14.85091377391776,14.668229722548105,14.485545671178418,14.30286161980873,14.120177568439047,13.937493517069392,13.754809465699706,13.572125414330019,13.389441362960367,13.20675731159068,13.024073260220993,12.841389208851341,12.658705157481656,12.476021106111968,12.293337054742315,12.110653003372628,11.927968952002942,11.745284900633255,11.562600849263601,11.379916797893916,11.197232746524232,11.014548695154579,10.860241875846311,10.720232568395172,10.580223260944056,10.440213953492913,10.300204646041772,10.16019533859063,10.020186031139513,9.880176723688374,9.740167416237233,9.600158108786117,9.460148801334975,9.320139493883834,9.180130186432718,9.040120878981575,8.900111571530434,8.76010226407932,8.620092956628179,8.480083649177038,8.340074341725897,8.20006503427478,8.06005572682364,7.920046419372499,7.806696275969379,7.719824504094847,7.632952732220313,7.5460809603457975,7.459209188471265,7.372337416596732,7.2854656447221995,7.198593872847683,7.111722100973151,7.024850329098618,6.937978557224102,6.85110678534957,6.764235013475037,6.677363241600521,6.590491469725988,6.503619697851455,6.416747925976939,6.329876154102406,6.243004382227873,6.1561326103533425,6.069260838478825,5.982389066604293,5.8955172947297605,5.808645522855244,5.721773750980711,5.6349019791061785,5.548030207231664,5.46115843535713,5.374286663482597,5.287414891608065,5.200543119733549],[43.24338433259992,43.291446707592414,43.339509082584904,43.387571457577394,43.435633832569884,43.48369620756237,43.53175858255486,43.57886887253096,43.62550311820082,43.67213736387068,43.718771609540546,43.7654058552104,43.81204010088027,43.858674346550124,43.90530859221999,43.95194283788985,43.99857708355972,44.04521132922957,44.09184557489944,44.138479820569295,44.18511406623916,44.23174831190902,44.27838255757888,44.32501680324874,44.3716510489186,44.418285294588465,44.46491954025833,44.511553785928186,44.55818803159805,44.60482227726791,44.65145652293777,44.698090768607635,44.7447250142775,44.791359259947356,44.83799350561721,44.88462775128708,44.93126199695694,44.977896242626805,45.02453048829666,45.07116473396652,45.11779897963638,45.16443322530625,45.21106747097611,45.25770171664597,45.304335962315825,45.35097020798569,45.39760445365556,45.44423869932542,45.490872944995274,45.53750719066514,45.58414143633499,45.63077568200487,45.67740992767472,45.72404417334458,45.770678419014445,45.81731266468431,45.86394691035417,45.91058115602402,45.95721540169389,46.00384964736375,46.050483893033615,46.09711813870348,46.14375238437333,46.19038663004319,46.23702087571306,46.283655121382914,46.330289367052785,46.37692361272264,46.4235578583925,46.47019210406236,46.51682634973223,46.563460595402084,46.61009484107195,46.656729086741805,46.70336333241167,46.74999757808153,46.79663182375139,46.843266069421254,46.88990031509112,46.936534560760975,46.98316880643084,47.0298030521007,47.07643729777056,47.123071543440425,47.16707693513827,47.210556556041716,47.25403617694516,47.297515797848604,47.34099541875205,47.38447503965549,47.427524626596565,47.47014417813147,47.512763729666375,47.55538328120128,47.598002832736185,47.64062238427108,47.68324193580599,47.72586148734089,47.7684810388758,47.8111005904107,47.85372014194561,47.89633969348051,47.93895924501542,47.98157879655032,48.02419834808523,48.06681789962013,48.10943745115504,48.15205700268994,48.19467655422485,48.237296105759754,48.27991565729466,48.32253520882957,48.36515476036447,48.407774311899374,48.45039386343427,48.493013414969184,48.535632966504096,48.578252518038994,48.6208720695739,48.663491621108804,48.70611117264371,48.748730724178614,48.79135027571351,48.833969827248424,48.87658937878333,48.919208930318234,48.96182848185314,49.004448033388044,49.04706758492294,49.089687136457854,49.13230668799275,49.174926239527665,49.21754579106256,49.260165342597475,49.30278489413237,49.34540444566728,49.38802399720218,49.43064354873709,49.47326310027199,49.51588265180689,49.5585022033418,49.6011217548767,49.64374130641161,49.68636085794651,49.72898040948142,49.77159996101632,49.81421951255123,49.85683906408614,49.89945861562104,49.94207816715595,49.98469771869085,50.02731727022575,50.069936821760656,50.11255637329556,50.155175924830466,50.19779547636537,50.24041502790027,50.283034579435174,50.32565413097008,50.368273682504984,50.41089323403989,50.453512785574794,50.4961323371097,50.538751888644605,50.58137144017951,50.62399099171442,50.66661054324932,50.71115759537482,50.756668397795615,50.802179200216415,50.84769000263721,50.893200805058,50.9387116074788,50.984222409899594,51.029733212320394,51.07524401474119,51.12075481716198,51.16626561958278,51.21177642200358,51.25728722442437,51.30279802684517,51.34830882926596,51.39381963168676,51.43933043410755,51.484841236528354,51.53035203894915,51.57586284136995,51.62137364379074,51.666571659357714,51.71171754222692,51.75686342509613,51.802009307965335,51.84715519083454,51.89230107370375,51.937446956572956,51.98259283944218,52.02773872231137,52.072884605180576,52.11803048804978,52.16317637091899,52.2083222537882,52.2534681366574,52.29861401952661,52.34375990239582,52.388905785265024,52.43405166813423,52.47919755100344,52.524343433872644,52.56948931674185,52.61463519961106,52.659781082480265,52.70492696534947,52.75007284821868,52.795218731087886,52.84036461395709,52.8855104968263,52.930656379695506,52.97580226256471,53.02094814543392,53.06609402830313,53.11123991117233,53.15638579404154,53.20153167691075,53.246677559779954,53.29182344264917,53.336969325518375,53.382115208387575,53.42726109125679,53.472406974125995,53.5175528569952,53.5626987398644,53.60784462273361,53.652990505602816,53.69813638847202,53.74328227134123,53.788428154210436,53.83357403707966,53.878719919948864,53.92386580281807,53.96901168568727,54.01415756855648,54.059303451425684,54.10444933429489,54.1495952171641,54.194741100033305,54.23988698290251,54.28503286577171,54.330178748640925,54.37532463151013,54.420470514379346,54.442163112841534,54.44040242689673,54.43864174095192,54.43688105500711,54.435120369062304,54.4333596831175,54.43159899717269,54.42983831122788,54.42807762528308,54.426316939338264,54.42455625339346,54.42279556744865,54.42103488150384,54.41927419555904,54.41751350961423,54.41575282366943,54.41399213772461,54.41223145177981,54.41047076583501,54.4087100798902,54.40694939394539,54.40518870800059,54.40342802205578,54.40166733611097,54.39990665016616,54.39814596422136,54.39638527827654,54.39462459233174,54.371720635458104,54.34575249087898,54.31978434629987,54.293816201720745,54.267848057141634,54.241879912562524,54.2159117679834,54.18994362340429,54.163975478825165,54.138007334246055,54.112039189666945,54.08607104508782,54.06010290050871,54.0341347559296,54.00816661135048,53.982198466771365,53.95623032219224,53.93026217761313,53.90429403303402,53.87832588845491,53.852357743875785,53.826389599296675,53.80042145471756,53.77445331013844,53.74848516555932,53.72251702098021,53.696548876401096,53.670580731821985,53.64461258724286,53.61864444266375,53.592676298084626,53.566708153505516,53.5407400089264,53.51477186434728,53.48880371976817,53.46283557518905,53.43686743060994,53.41089928603083,53.384931141451716,53.35896299687259,53.33299485229348,53.307026707714364,53.28105856313525,53.25509041855614,53.22912227397702,53.2031541293979,53.177185984818784,53.151217840239674,53.12524969566055,53.09928155108144,53.07331340650233,53.04734526192321,53.021377117344095,52.99540897276498,52.96944082818587,52.80517665765964,52.36432043523938,51.92346421281911,51.48260799039881,51.04175176797855,50.60089554555829,50.16003932313797,49.71918310071768,49.27832687829745,48.83747065587715,48.39661443345684,47.95575821103657,47.51490198861631,47.07404576619601,46.63318954377574,46.19233332135548,45.751477098935176,45.31062087651491,44.869764654094645,44.42890843167434,43.988052209254036,43.54719598683377,43.106339764413505,42.665483541993204,42.224627319572946,41.78377109715267,41.34291487473237,40.90205865231211,40.46120242989184,40.02034620747154,39.57948998505123,39.13863376263101,38.69777754021071,38.2569213177904,37.816065095370135,37.37520887294987,36.93435265052957,36.4934964281093,36.05264020568904,35.61178398326872,35.170927760848464,34.7300715384282,34.28921531600789,33.84835909358759,33.407502871167324,32.96664664874706,32.52579042632676,32.08493420390649,31.64407798148623,31.203221759065922,30.76236553664566,30.321509314225395,29.88065309180509,29.439796869384786,28.998940646964563,28.558084424544255,28.117228202123954,27.67637197970369,27.235515757283423,26.79465953486312,26.353803312442857,25.91294709002259,25.472090867602287,25.031234645182025,24.590378422761756,24.14952220034145,23.70866597792115,23.267809755500924,22.82695353308062,22.38609731066031,21.945241088240053,21.504384865819787,21.06352864339948,20.622672420979217,20.181816198558952,19.74269982126495,19.30364449548377,18.864589169702676,18.42553384392149,17.986478518140316,17.547423192359176,17.108367866578035,16.66931254079686,16.27298576075101,16.090301709381322,15.907617658011636,15.724933606641951,15.5422495552723,15.35956550390261,15.176881452532925,14.994197401163273,14.811513349793586,14.628829298423899,14.446145247054247,14.26346119568456,14.080777144314876,13.898093092945189,13.715409041575535,13.532724990205848,13.35004093883616,13.214128897584544,13.081059196705176,12.947989495825807,12.814919794946462,12.681850094067094,12.548780393187725,12.41571069230838,12.282640991429012,12.149571290549645,12.016501589670277,11.883431888790932,11.750362187911565,11.617292487032193,11.48422278615285,11.351153085273483,11.218083384394111,11.085013683514768,10.9519439826354,10.81887428175603,10.685804580876662,10.552734879997319,10.41966517911795,10.286595478238581,10.153525777359237,10.020456076479869,9.8873863756005,9.754316674721155,9.621246973841787,9.48817727296242,9.355107572083075,9.222037871203707,9.088968170324337,8.955898469444968,8.822828768565625,8.689759067686255,8.556689366806886,8.423619665927543,8.290549965048175,8.157480264168806,8.024410563289461,7.891340862410092,7.758271161530724,7.625201460651354,7.492131759772011,7.3590620588926425,7.225992358013274,7.092922657133929,6.9598529562545615,6.826783255375192,6.693713554495848,6.570990126564704,6.484118354690171,6.397246582815654,6.310374810941122,6.223503039066589,6.136631267192058,6.0497594953175415,5.962887723443009,5.876015951568476,5.78914417969396,5.702272407819427,5.615400635944895,5.528528864070379,5.441657092195846,5.354785320321313,5.2679135484467805,5.181041776572265],[43.60311803490278,43.65118040989527,43.69924278488776,43.74730515988025,43.79536753487274,43.84342990986522,43.89149228485772,43.93955465985022,43.98761703484269,44.03567940983518,44.08374178482768,44.13180415982017,44.17986653481266,44.22792890980515,44.275991284797634,44.324053659790124,44.372116034782614,44.420178409775104,44.468240784767595,44.516303159760085,44.564365534752575,44.612427909745065,44.660490284737556,44.70831463859633,44.75494888426619,44.80158312993605,44.84821737560591,44.89485162127577,44.941485866945634,44.98812011261549,45.034754358285355,45.08138860395522,45.12802284962508,45.17465709529494,45.221291340964804,45.26792558663467,45.314559832304525,45.36119407797439,45.407828323644246,45.45446256931411,45.50109681498397,45.54773106065383,45.594365306323695,45.64099955199356,45.687633797663416,45.73426804333327,45.78090228900314,45.827536534673,45.87417078034285,45.92080502601272,45.96743927168258,46.01407351735245,46.06070776302231,46.10734200869217,46.15397625436203,46.200610500031885,46.24724474570175,46.29387899137161,46.34051323704148,46.387147482711335,46.43378172838119,46.48041597405106,46.52705021972092,46.573684465390784,46.62031871106065,46.66695295673051,46.71358720240037,46.760221448070226,46.80685569374009,46.853489939409954,46.90012418507982,46.946758430749675,46.99339267641954,47.040026922089396,47.08666116775926,47.13329541342912,47.17992965909898,47.226563904768845,47.2731981504387,47.319832396108566,47.36646664177843,47.41310088744829,47.45973513311815,47.506369378788015,47.55037477048586,47.5938543913893,47.63733401229275,47.680813633196195,47.724293254099635,47.767772875003075,47.81125249590652,47.85473211680997,47.89821173771341,47.94169135861686,47.985170979520305,48.02865060042375,48.07213022132719,48.11560984223064,48.15908946313409,48.20256908403752,48.24604870494097,48.289528325844415,48.33300794674786,48.37648756765131,48.41996718855475,48.4634468094582,48.506926430361645,48.54954598214952,48.59216553368442,48.63478508521933,48.67740463675423,48.72002418828913,48.762643739824036,48.80526329135894,48.847882842893846,48.89050239442875,48.933121945963656,48.97574149749856,49.018361049033466,49.06098060056837,49.103600152103276,49.14621970363818,49.188839255173086,49.23145880670799,49.27407835824289,49.316697909777794,49.359317461312706,49.401937012847604,49.44455656438251,49.48717611591742,49.52979566745232,49.57241521898723,49.61503477052213,49.65765432205704,49.70027387359194,49.742893425126844,49.78551297666175,49.828132528196655,49.87075207973156,49.913371631266465,49.95599118280137,49.998610734336275,50.04123028587118,50.08384983740608,50.12646938894099,50.16908894047589,50.2117084920108,50.254328043545705,50.29694759508061,50.339567146615515,50.38218669815041,50.42480624968532,50.46742580122023,50.51004535275513,50.55266490429003,50.59528445582494,50.63790400735984,50.68052355889475,50.723143110429646,50.76576266196456,50.80838221349946,50.85100176503437,50.89362131656927,50.93624086810418,50.97886041963908,51.02147997117399,51.06409952270889,51.108646574834395,51.15415737725519,51.19966817967598,51.24517898209678,51.29068978451758,51.336200586938375,51.38171138935917,51.42722219177997,51.472732994200754,51.518243796621555,51.563754599042355,51.60926540146315,51.65477620388394,51.70028700630475,51.74579780872554,51.791308611146334,51.83681941356713,51.88233021598792,51.92784101840872,51.97335182082952,52.01886262325031,52.064373425671114,52.1098842280919,52.15539503051271,52.20090583293349,52.24641663535429,52.29192743777509,52.33743824019588,52.38294904261669,52.42845984503748,52.473970647458266,52.519481449879066,52.56499225229987,52.61050305472065,52.65601385714145,52.70152465956225,52.747035461983046,52.792546264403846,52.83805706682463,52.883567869245425,52.92907867166623,52.974589474087026,53.02010027650782,53.06561107892862,53.11112188134942,53.15663268377021,53.202143486191005,53.2476542886118,53.29316509103259,53.3386758934534,53.38418669587419,53.42969749829498,53.47520830071578,53.52071910313658,53.56622990555737,53.61174070797817,53.657251510398964,53.70276231281976,53.74827311524055,53.79378391766135,53.839294720082144,53.884805522502944,53.930316324923744,53.97582712734454,54.02133792976532,54.06684873218613,54.112359534606924,54.15787033702772,54.20338113944852,54.24889194186931,54.2944027442901,54.33991354671091,54.385424349131696,54.43093515155249,54.4764459539733,54.52172216678488,54.56686804965409,54.6120139325233,54.6571598153925,54.7023056982617,54.74745158113091,54.792597464000124,54.83774334686933,54.85943594533152,54.85767525938672,54.85591457344191,54.854153887497105,54.83079029680494,54.804822152225825,54.77885400764671,54.75288586306759,54.72691771848848,54.70094957390936,54.674981429330245,54.649013284751135,54.62304514017202,54.59707699559291,54.57110885101378,54.54514070643467,54.51917256185556,54.49320441727644,54.46723627269733,54.44126812811821,54.41529998353909,54.38933183895997,54.363363694380865,54.33739554980174,54.31142740522263,54.28545926064351,54.25916617429081,54.23264813850206,54.20613010271331,54.17961206692456,54.15309403113582,54.12657599534705,54.10005795955831,54.07353992376956,54.047021887980804,54.02050385219205,53.9939858164033,53.967467780614555,53.9409497448258,53.914431709037046,53.88791367324829,53.86139563745955,53.8348776016708,53.80835956588204,53.78184153009329,53.75532349430455,53.728805458515794,53.70228742272704,53.675769386938285,53.64925135114954,53.62273331536078,53.596215279572036,53.56969724378329,53.54317920799454,53.51666117220578,53.49014313641703,53.46362510062828,53.43710706483952,53.410589029050776,53.38407099326203,53.35755295747328,53.33103492168452,53.30451688589577,53.277998850107025,53.25148081431828,53.22496277852953,53.19844474274077,53.17192670695202,53.14540867116327,53.11889063537451,53.092372599585765,53.06585456379702,53.03933652800826,53.01281849221951,52.98630045643076,52.959782420642014,52.93326438485326,52.906746349064505,52.88022831327575,52.853710277487004,52.82719224169825,52.800674205909495,52.774156170120754,52.609852960777246,52.16997940432439,51.73010584787154,51.29023229141864,50.850358734965795,50.41048517851293,49.97061162206004,49.530738065607146,49.09086450915433,48.650990952701434,48.21111739624853,47.771137316504934,47.330029539848724,46.88892176319245,46.44781398653623,46.00670620988,45.56559843322374,45.12449065656752,44.683382879911285,44.24227510325503,43.801167326598765,43.36005954994254,42.91895177328631,42.47784399663005,42.036736219973825,41.5956284433176,41.15452066666134,40.71341289000512,40.27230511334889,39.83119733669263,39.39008956003636,38.94898178338018,38.50787400672391,38.06676623006766,37.625658453411425,37.1845506767552,36.74344290009894,36.30233512344272,35.86122734678649,35.420119570130225,34.979011793474,34.53790401681778,34.09679624016152,33.65568846350525,33.214580686849025,32.7734729101928,32.332365133536534,31.89125735688031,31.45014958022409,31.009041803567825,30.5679340269116,30.126826250255377,29.685718473599113,29.244610696942846,28.803502920286665,28.3623951436304,27.921287366974138,27.480179590317913,27.03907181366169,26.597964037005426,26.1568562603492,25.715748483692977,25.27464070703671,24.83353293038049,24.392425153724265,23.951317377068,23.510209600411734,23.069101823755553,22.62799404709929,22.186886270443026,21.7457784937868,21.304670717130577,20.86356294047431,20.42245516381809,19.981347387161865,19.540239610505598,19.099131833849334,18.658024057193153,18.216916280536886,17.775808503880622,17.334700727224398,16.893592950568177,16.45248517391191,16.05587941318166,15.881783732081008,15.707688050980355,15.533592369879702,15.359496688779082,15.185401007678426,15.011305326577773,14.837209645477154,14.663113964376498,14.489018283275847,14.314922602175226,14.140826921074572,13.96673123997392,13.792635558873265,13.618539877772644,13.465102642903858,13.33203294202449,13.198963241145146,13.065893540265776,12.932823839386408,12.799754138507065,12.666684437627698,12.533614736748326,12.400545035868983,12.267475334989616,12.134405634110246,12.001335933230877,11.868266232351534,11.735196531472166,11.602126830592795,11.469057129713452,11.335987428834084,11.202917727954713,11.06984802707537,10.936778326196002,10.803708625316633,10.670638924437265,10.53756922355792,10.40449952267855,10.271429821799183,10.138360120919838,10.00529042004047,9.8722207191611,9.739151018281756,9.606081317402388,9.47301161652302,9.339941915643676,9.206872214764307,9.073802513884939,8.940732813005571,8.807663112126225,8.674593411246857,8.541523710367489,8.408454009488144,8.275384308608775,8.142314607729407,8.009244906850062,7.876175205970694,7.743105505091325,7.6100358042119565,7.476966103332612,7.343896402453244,7.210826701573875,7.077757000694531,6.944687299815163,6.811617598935794,6.6785478980564505,6.545478197177081,6.412408496297713,6.313078127393147,6.230888012056891,6.148697896720634,6.066507781384379,5.984317666048137,5.902127550711882,5.819937435375626,5.737747320039385,5.65555720470313,5.573367089366874,5.491176974030633,5.408986858694377,5.326796743358122,5.244606628021866,5.162416512685625],[43.96285173720564,44.01091411219813,44.05897648719062,44.1070388621831,44.15510123717559,44.20316361216808,44.25122598716058,44.299288362153064,44.347350737145554,44.395413112138044,44.44347548713054,44.49153786212303,44.539600237115515,44.587662612108005,44.635724987100495,44.683787362092986,44.731849737085476,44.779912112077966,44.827974487070456,44.87603686206294,44.92409923705543,44.97216161204793,45.02022398704041,45.06828636203291,45.11634873702539,45.16441111201788,45.21247348701037,45.26053586200286,45.30859823699535,45.35666061198784,45.40472298698033,45.45278536197282,45.50084773696531,45.548910111957795,45.59697248695029,45.645034861942776,45.69309723693527,45.741159611927756,45.78922198692025,45.83728436191274,45.88439465033156,45.931028896001415,45.97766314167127,46.024297387341136,46.070931633011,46.117565878680864,46.16420012435073,46.210834370020585,46.25746861569044,46.304102861360306,46.35073710703017,46.397371352700034,46.44400559836989,46.49063984403975,46.53727408970961,46.583908335379476,46.63054258104934,46.6771768267192,46.723811072389054,46.770445318058925,46.81707956372878,46.86371380939865,46.91034805506851,46.95698230073836,47.003616546408225,47.05025079207809,47.09688503774795,47.14351928341782,47.19015352908767,47.23678777475753,47.283422020427395,47.33005626609726,47.37669051176712,47.42332475743698,47.46995900310684,47.5165932487767,47.563227494446565,47.60986174011642,47.656495985786286,47.70313023145614,47.74976447712601,47.79639872279587,47.843032968465735,47.88966721413559,47.93367260583344,47.97715222673689,48.02063184764033,48.06411146854377,48.107591089447226,48.151070710350666,48.194550331254106,48.23802995215756,48.281509573061,48.32498919396444,48.36846881486789,48.411948435771336,48.455428056674776,48.498907677578224,48.54238729848167,48.58586691938511,48.629346540288566,48.672826161192006,48.71630578209545,48.7597854029989,48.803265023902334,48.84674464480578,48.89022426570923,48.93370388661267,48.977183507516116,49.020663128419564,49.06414274932301,49.10762237022645,49.1511019911299,49.194581612033346,49.23806123293678,49.28154085384023,49.325020474743674,49.36850009564712,49.41197971655056,49.45545933745401,49.498938958357456,49.542418579260904,49.585898200164344,49.62894778616756,49.67156733770247,49.714186889237375,49.75680644077229,49.799425992307185,49.84204554384209,49.884665095376995,49.92728464691189,49.969904198446805,50.0125237499817,50.055143301516615,50.09776285305152,50.140382404586425,50.18300195612133,50.22562150765623,50.26824105919114,50.31086061072604,50.35348016226095,50.39609971379585,50.438719265330754,50.48133881686566,50.523958368400564,50.56657791993547,50.609197471470374,50.65181702300528,50.694436574540184,50.73705612607509,50.779675677609994,50.8222952291449,50.8649147806798,50.9075343322147,50.95015388374961,50.99277343528451,51.03539298681942,51.07801253835433,51.12063208988923,51.163251641424125,51.20587119295904,51.24849074449394,51.29111029602885,51.333729847563745,51.37634939909866,51.418968950633555,51.46158850216847,51.50613555429396,51.55164635671476,51.59715715913556,51.64266796155635,51.68817876397715,51.73368956639794,51.779200368818735,51.82471117123954,51.870221973660335,51.91573277608113,51.96124357850192,52.00675438092272,52.052265183343515,52.097775985764315,52.14328678818511,52.18879759060591,52.23430839302671,52.2798191954475,52.325329997868295,52.37084080028909,52.41635160270988,52.46186240513069,52.507373207551474,52.552884009972274,52.59839481239307,52.64390561481386,52.68941641723465,52.73492721965546,52.780438022076254,52.82594882449705,52.87145962691784,52.91697042933864,52.96248123175944,53.00799203418023,53.05350283660103,53.09901363902182,53.14452444144263,53.19003524386342,53.235546046284206,53.281056848705006,53.3265676511258,53.37207845354659,53.417589255967385,53.463100058388186,53.508610860808986,53.554121663229786,53.59963246565058,53.64514326807137,53.69065407049217,53.736164872912966,53.78167567533376,53.82718647775455,53.87269728017535,53.91820808259615,53.963718885016945,54.00922968743774,54.05474048985854,54.10025129227933,54.145762094700125,54.191272897120925,54.23678369954172,54.28229450196252,54.32780530438331,54.373381806005185,54.418992721368326,54.46460363673148,54.51021455209463,54.55582546745778,54.60143638282093,54.64704729818408,54.692658213547226,54.738269128910375,54.78388004427352,54.82949095963667,54.875101874999814,54.92071279036297,54.96632370572611,55.01193462108927,55.05754553645241,55.10315645181556,55.148767367178706,55.194378282541855,55.239989197905004,55.23963933204796,55.19332868497071,55.14701803789347,55.100707390816225,55.05439674373898,55.008086096661735,54.96177544958449,54.915464802507245,54.869154155429996,54.82284350835277,54.77653286127551,54.73022221419828,54.68391156712103,54.637600920043795,54.591290272966546,54.5449796258893,54.49866897881206,54.452358331734814,54.40604768465757,54.35973703758033,54.31342639050308,54.26711574342583,54.2208050963486,54.17449444927135,54.12818380219411,54.08187315511687,54.03556250803962,53.98925186096238,53.94710805101361,53.92059001522486,53.894071979436106,53.86755394364736,53.84103590785861,53.81451787206986,53.787999836281095,53.761481800492355,53.73496376470359,53.70844572891485,53.6819276931261,53.65540965733736,53.62889162154859,53.60237358575984,53.575855549971095,53.54933751418234,53.522819478393586,53.496301442604846,53.46978340681609,53.44326537102734,53.41674733523858,53.39022929944983,53.36371126366109,53.33719322787233,53.31067519208358,53.28415715629484,53.25763912050608,53.23112108471733,53.204603048928576,53.17808501313983,53.151566977351074,53.125048941562326,53.09853090577357,53.072012869984825,53.04549483419607,53.018976798407316,52.99245876261857,52.96594072682982,52.93942269104107,52.91290465525232,52.886386619463565,52.85986858367481,52.83335054788607,52.80683251209731,52.780314476308554,52.75379644051981,52.72727840473106,52.700760368942305,52.67424233315355,52.64772429736481,52.62120626157605,52.594688225787294,52.56817018999855,52.5416521542098,52.51513411842105,52.350830909077544,51.910957352624685,51.47108379617183,51.031210239718945,50.59133668326609,50.15146312681323,49.71158957036034,49.271716013907444,48.83184245745463,48.39196890100173,47.95209534454883,47.51222178809598,47.07234823164312,46.63247467519023,46.19260111873737,45.75272756228452,45.312854005831625,44.87298044937877,44.43310689292591,43.993233336473025,43.55335978002013,43.11348622356727,42.67361266711441,42.23373911066152,41.79386555420867,41.353991997755806,40.91411844130292,40.474244884850066,40.0343713283972,39.59449777194431,39.15462421549142,38.7147506590386,38.274877102585705,37.83500354613281,37.39512998967996,36.9552564332271,36.515382876774204,36.07550932032135,35.63563576386849,35.1957622074156,34.755888650962746,34.31601509450989,33.876141538057,33.4362679816041,32.99639442515125,32.556271088863,32.11516331220673,31.674055535550508,31.232947758894284,30.791839982238017,30.350732205581796,29.909624428925575,29.46851665226931,29.02740887561304,28.586301098956863,28.145193322300596,27.704085545644332,27.262977768988108,26.821869992331884,26.380762215675624,25.939654439019396,25.49854666236317,25.057438885706908,24.616331109050684,24.17522333239446,23.734115555738196,23.293007779081933,22.851900002425747,22.410792225769484,21.969684449113224,21.528576672456996,21.08746889580077,20.646361119144508,20.205253342488284,19.76414556583206,19.323037789175796,18.88193001251953,18.440822235863347,17.999714459207084,17.55860668255082,17.117498905894596,16.67639112923837,16.23528335258211,15.838677591851857,15.664581910751204,15.49048622965055,15.316390548549897,15.142294867449277,14.968199186348622,14.79410350524797,14.620007824147347,14.445912143046694,14.271816461946042,14.097720780845421,13.923625099744767,13.749529418644114,13.575433737543461,13.401338056442839,13.227242375342186,13.053146694241534,12.879051013140911,12.704955332040258,12.530859650939604,12.356763969838983,12.18266828873833,12.008572607637676,11.834476926537056,11.660381245436401,11.486285564335748,11.312189883235096,11.138094202134475,10.96399852103382,10.78990283993317,10.615807158832546,10.441711477731895,10.26761579663124,10.09352011553062,9.919424434429967,9.758349428145388,9.62527972726602,9.492210026386676,9.359140325507306,9.226070624627939,9.093000923748596,8.959931222869226,8.826861521989859,8.693791821110514,8.560722120231144,8.427652419351775,8.294582718472432,8.161513017593062,8.028443316713695,7.938585156444044,7.856395041107803,7.774204925771547,7.692014810435291,7.60982469509905,7.527634579762795,7.445444464426538,7.3632543490902975,7.2810642337540425,7.198874118417786,7.116684003081531,7.03449388774529,6.952303772409033,6.870113657072778,6.787923541736538,6.705733426400281,6.623543311064025,6.541353195727785,6.459163080391528,6.376972965055273,6.294782849719033,6.212592734382777,6.130402619046521,6.048212503710264,5.966022388374025,5.8838322730377675,5.801642157701512,5.719452042365272,5.637261927029016,5.555071811692759,5.472881696356518,5.3906915810202625,5.308501465684007,5.2263113503477525,5.144121235011511],[44.322585439508494,44.370647814500984,44.418710189493474,44.466772564485964,44.514834939478455,44.562897314470945,44.610959689463435,44.659022064455925,44.707084439448415,44.755146814440906,44.80320918943339,44.85127156442588,44.89933393941837,44.94739631441086,44.99545868940335,45.04352106439584,45.09158343938833,45.13964581438082,45.18770818937331,45.23577056436581,45.28383293935829,45.331895314350774,45.37995768934327,45.428020064335755,45.47608243932825,45.52414481432074,45.572207189313225,45.620269564305715,45.6683319392982,45.716394314290696,45.76445668928319,45.812519064275676,45.860581439268174,45.90864381426066,45.95670618925315,46.00476856424563,46.05283093923812,46.10089331423062,46.1489556892231,46.1970180642156,46.24508043920809,46.29314281420057,46.34120518919306,46.389267564185545,46.437329939178035,46.485392314170525,46.53345468916302,46.581517064155506,46.629579439147996,46.67764181414049,46.725704189132976,46.773766564125474,46.82182893911796,46.86989131411045,46.917953689102944,46.96601606409543,47.013840416396924,47.06047466206678,47.107108907736645,47.15374315340651,47.200377399076366,47.24701164474623,47.29364589041609,47.34028013608595,47.386914381755815,47.43354862742568,47.480182873095536,47.52681711876539,47.57345136443526,47.62008561010512,47.666719855774986,47.71335410144484,47.7599883471147,47.806622592784564,47.85325683845443,47.89989108412429,47.94652532979415,47.99315957546401,48.03979382113387,48.086428066803734,48.1330623124736,48.179696558143455,48.22633080381332,48.272965049483176,48.31697044118102,48.36045006208447,48.40392968298791,48.44740930389136,48.4908889247948,48.53436854569824,48.57784816660169,48.62132778750514,48.66480740840858,48.708287029312025,48.75176665021547,48.79524627111891,48.83872589202237,48.88220551292581,48.92568513382925,48.969164754732695,49.01264437563614,49.05612399653958,49.09960361744303,49.14308323834648,49.18656285924992,49.230042480153365,49.27352210105681,49.31700172196025,49.3604813428637,49.40396096376715,49.44744058467059,49.490920205574035,49.53439982647748,49.57787944738092,49.62135906828436,49.66483868918781,49.70831831009126,49.7517979309947,49.795277551898145,49.83875717280159,49.88223679370504,49.92571641460849,49.96919603551192,50.01267565641537,50.05615527731881,50.09963489822226,50.1431145191257,50.18659414002915,50.2300737609326,50.27355338183604,50.31703300273948,50.36051262364293,50.40399224454637,50.44747186544981,50.49095148635326,50.53443110725671,50.57791072816015,50.621390349063596,50.66486996996704,50.70834959018561,50.75096914172052,50.79358869325542,50.83620824479033,50.87882779632523,50.92144734786014,50.96406689939504,51.00668645092994,51.049306002464846,51.09192555399975,51.134545105534656,51.17716465706956,51.219784208604466,51.26240376013938,51.305023311674276,51.34764286320919,51.390262414744086,51.432881966279,51.475501517813896,51.51812106934881,51.560740620883706,51.60336017241861,51.645979723953516,51.68859927548842,51.731218827023326,51.77383837855823,51.81645793009314,51.859077481628034,51.903624533753536,51.94913533617433,51.99464613859513,52.04015694101592,52.08566774343672,52.13117854585752,52.17668934827831,52.22220015069911,52.2677109531199,52.313221755540695,52.358732557961496,52.404243360382296,52.44975416280309,52.49526496522388,52.54077576764468,52.586286570065475,52.631797372486275,52.67730817490707,52.72281897732786,52.76832977974866,52.813840582169455,52.859351384590255,52.90486218701105,52.95037298943184,52.99588379185264,53.04139459427343,53.08690539669423,53.13241619911503,53.17792700153583,53.22343780395662,53.26894860637741,53.314459408798214,53.359970211219014,53.4054810136398,53.4509918160606,53.496502618481394,53.542013420902194,53.58752422332299,53.63303502574378,53.67858337047744,53.72419428584058,53.76980520120374,53.81541611656688,53.86102703193003,53.90663794729318,53.95224886265633,53.997859778019475,54.04347069338263,54.08908160874577,54.13469252410893,54.18030343947207,54.22591435483522,54.27152527019837,54.31713618556152,54.362747100924665,54.40835801628782,54.45396893165096,54.49957984701411,54.54519076237726,54.590801677740416,54.63641259310355,54.6820235084667,54.72763442382984,54.773245339193,54.81885625455615,54.864467169919294,54.91007808528245,54.95568900064559,55.00129991600875,55.04691083137189,55.09252174673504,55.13813266209819,55.18374357746134,55.229354492824484,55.27496540818763,55.32057632355078,55.36618723891393,55.41179815427708,55.45740906964022,55.50301998500338,55.548630900366526,55.594241815729674,55.639852731092816,55.63950286523577,55.59319221815852,55.546881571081286,55.50057092400404,55.45426027692679,55.407949629849554,55.361638982772305,55.315328335695064,55.269017688617815,55.22270704154059,55.17639639446333,55.13008574738609,55.08377510030885,55.03746445323161,54.99115380615436,54.94484315907712,54.898532511999875,54.852221864922626,54.80591121784539,54.75960057076815,54.7132899236909,54.66697927661366,54.62066862953641,54.574357982459176,54.52804733538193,54.48173668830468,54.435426041227444,54.389115394150195,54.34280474707295,54.29649409999571,54.25018345291846,54.203872805841215,54.15756215876398,54.11125151168673,54.06494086460948,54.01863021753225,53.972319570455,53.926008923377765,53.879698276300516,53.833387629223274,53.787076982146026,53.740766335068784,53.69445568799154,53.6481450409143,53.60183439383705,53.55552374675981,53.50921309968257,53.46290245260532,53.416591805528086,53.37028115845084,53.32397051137359,53.277659864296346,53.231349217219105,53.185038570141856,53.13872792306461,53.09241727598737,53.046106628910124,52.999795981832875,52.95348533475564,52.9071746876784,52.86086404060116,52.81455339352391,52.78647278249637,52.75995474670761,52.733436710918866,52.70691867513012,52.680400639341364,52.65388260355262,52.62736456776386,52.60084653197511,52.574328496186354,52.54781046039761,52.52129242460886,52.494774388820105,52.46825635303135,52.44173831724261,52.41522028145385,52.3887022456651,52.362184209876354,52.3356661740876,52.309148138298845,52.28263010251009,52.25611206672134,52.09180885737784,51.65193530092498,51.21206174447214,50.772188188019236,50.33231463156638,49.892441075113524,49.452567518660636,49.01269396220774,48.572820405754925,48.13294684930203,47.693073292849135,47.25319973639628,46.81332617994342,46.37345262349053,45.93357906703766,45.49370551058481,45.05383195413192,44.61395839767907,44.17408484122621,43.73421128477332,43.29433772832042,42.85446417186757,42.41459061541471,41.974717058961815,41.53484350250896,41.0949699460561,40.655096389603216,40.215222833150364,39.775349276697504,39.33547572024461,38.895602163791715,38.4557286073389,38.015855050886,37.57598149443311,37.136107937980256,36.6962343815274,36.2563608250745,35.81648726862165,35.37661371216879,34.936740155715896,34.49686659926304,34.056993042810184,33.61711948635729,33.1772459299044,32.73737237345154,32.29749881699869,31.857625260545795,31.41775170409294,30.977878147640084,30.53800459118719,30.098131034734337,29.658257478281477,29.218383921828586,28.778510365375688,28.33863680892287,27.89876325246998,27.45888969601708,27.01901613956423,26.579142583111373,26.13926902665848,25.699395470205623,25.25952191375277,24.819648357299876,24.37977480084702,23.939901244394164,23.50002768794127,23.060154131488375,22.620280575035558,22.180407018582663,21.74053346212977,21.30065990567691,20.860786349224057,20.420912792771166,19.98103923631831,19.541165679865454,19.10129212341256,18.661418566959664,18.22154501050685,17.781671454053953,17.341404861221015,16.90029708456479,16.459189307908563,16.018081531252303,15.621475770522053,15.4473800894214,15.273284408320746,15.099188727220092,14.925093046119471,14.750997365018819,14.576901683918166,14.43669261123889,14.31043657318341,14.18418053512793,14.057924497072475,13.931668459016997,13.805412420961519,13.679156382906042,13.552900344850586,13.426644306795108,13.30038826873963,13.174132230684172,13.047876192628696,12.921620154573215,12.79536411651776,12.669108078462282,12.542852040406805,12.41659600235135,12.290339964295871,12.164083926240393,12.037827888184914,11.911571850129457,11.785315812073978,11.6590597740185,11.532803735963045,11.406547697907566,11.28029165985209,11.154035621796634,11.027779583741156,10.901523545685677,10.775267507630199,10.649011469574743,10.522755431519263,10.396499393463785,10.27024335540833,10.14398731735285,10.01773127929737,9.891475241241915,9.76521920318644,9.63896316513096,9.512707127075505,9.386451089020028,9.26019505096455,9.13393901290907,9.007682974853614,8.881426936798135,8.755170898742657,8.628914860687201,8.502658822631725,8.376402784576245,8.25014674652079,8.12389070846531,7.997634670409831,7.871378632354354,7.745122594298898,7.61886655624342,7.492610518187942,7.366354480132486,7.240098442077008,7.113842404021529,6.987586365966074,6.861330327910595,6.735074289855116,6.608818251799661,6.482562213744182,6.356306175688705,6.230050137633226,6.103794099577771,5.977538061522292,5.851282023466814,5.725025985411358,5.618966649354902,5.536776534018646,5.454586418682405,5.37239630334615,5.290206188009893,5.208016072673638,5.125825957337397],[44.68231914181137,44.73038151680386,44.77844389179635,44.82650626678884,44.87456864178133,44.92263101677382,44.97069339176631,45.018755766758794,45.06681814175129,45.114880516743774,45.162942891736265,45.21100526672876,45.25906764172125,45.307130016713735,45.355192391706225,45.403254766698716,45.451317141691206,45.499379516683696,45.547441891676186,45.59550426666867,45.64356664166116,45.69162901665365,45.73969139164614,45.78775376663863,45.83581614163112,45.88387851662361,45.9319408916161,45.98000326660859,46.02806564160108,46.07612801659357,46.124190391586055,46.17225276657855,46.220315141571035,46.26837751656353,46.316439891556016,46.36450226654851,46.412564641540996,46.460627016533486,46.50868939152598,46.55675176651847,46.60481414151096,46.65287651650345,46.70093889149594,46.74900126648843,46.79706364148092,46.84512601647341,46.8931883914659,46.94125076645839,46.98931314145088,47.03737551644336,47.08543789143586,47.13350026642834,47.18156264142084,47.22962501641332,47.27768739140582,47.3257497663983,47.3738121413908,47.42187451638328,47.469936891375774,47.517999266368264,47.566061641360754,47.614124016353244,47.662186391345735,47.710248766338225,47.75831114133071,47.806373516323205,47.85443589131569,47.90249826630818,47.95056064130067,47.99862301629316,48.04668539128565,48.09474776627814,48.14281014127063,48.18992042813217,48.236554673802026,48.28318891947189,48.32982316514175,48.37645741081161,48.423091656481475,48.46972590215134,48.516360147821196,48.56299439349106,48.60962863916092,48.65626288483078,48.70026827652862,48.74374789743207,48.78722751833551,48.83070713923896,48.8741867601424,48.91766638104585,48.961146001949295,49.004625622852735,49.04810524375618,49.09158486465963,49.13506448556308,49.17854410646652,49.22202372736997,49.26550334827341,49.30898296917685,49.3524625900803,49.39594221098375,49.43942183188719,49.482901452790635,49.52638107369408,49.56986069459752,49.61334031550096,49.65681993640442,49.70029955730786,49.743779178211305,49.787258799114745,49.83073842001819,49.87421804092163,49.91769766182508,49.96117728272853,50.00465690363197,50.04813652453541,50.09161614543886,50.1350957663423,50.17857538724574,50.2220550081492,50.26553462905264,50.309014249956086,50.352493870859526,50.39597349176297,50.43945311266641,50.48293273356986,50.52641235447331,50.56989197537675,50.613371596280196,50.65685121718364,50.70033083808708,50.74381045899053,50.78729007989398,50.830769700797426,50.87424932170087,50.91772894260431,50.96120856350776,51.00468818441121,51.04816780531465,51.091647426218096,51.13512704712154,51.17860666802498,51.22208628892842,51.26556590983187,51.30904553073532,51.35252515163876,51.396004772542206,51.43948439344565,51.48296401434909,51.52644363525254,51.56992325615598,51.61340287705943,51.656882497962876,51.700362118866316,51.74384173976976,51.78732136067321,51.83037094573858,51.872990497273484,51.91561004880839,51.958229600343294,52.0008491518782,52.043468703413104,52.08608825494801,52.128707806482915,52.17132735801782,52.213946909552725,52.25656646108763,52.301113513213124,52.34662431563392,52.39213511805472,52.43764592047551,52.483156722896304,52.528667525317104,52.5741783277379,52.6196891301587,52.66519993257948,52.710710735000276,52.756221537421084,52.80173233984188,52.84724314226268,52.89275394468347,52.93826474710426,52.9837849349497,53.02939585031285,53.075006765676,53.12061768103915,53.166228596402306,53.211839511765454,53.2574504271286,53.303061342491745,53.3486722578549,53.39428317321804,53.43989408858119,53.48550500394434,53.53111591930748,53.57672683467064,53.62233775003378,53.66794866539693,53.71355958076008,53.759170496123225,53.804781411486374,53.85039232684952,53.89600324221268,53.94161415757582,53.98722507293897,54.032835988302125,54.078446903665274,54.124057819028415,54.169668734391564,54.21527964975471,54.26089056511786,54.30650148048102,54.35211239584416,54.397723311207315,54.44333422657045,54.48894514193361,54.53455605729675,54.5801669726599,54.62577788802305,54.6713888033862,54.71699971874934,54.7626106341125,54.80822154947565,54.85383246483879,54.89944338020194,54.945054295565086,54.990665210928235,55.03627612629138,55.08188704165453,55.12749795701769,55.17310887238084,55.21871978774398,55.26433070310713,55.309941618470276,55.355552533833425,55.401163449196574,55.44677436455973,55.49238527992287,55.53799619528601,55.58360711064917,55.62921802601231,55.674828941375466,55.720439856738615,55.766050772101764,55.81166168746491,55.85727260282806,55.9028835181912,55.94849443355436,55.9941053489175,56.039716264280656,56.039366398423596,55.99305575134635,55.94674510426911,55.900434457191864,55.85412381011463,55.80781316303738,55.761502515960146,55.7151918688829,55.66888122180565,55.62257057472841,55.576259927651165,55.529949280573916,55.48363863349668,55.43732798641943,55.39101733934219,55.34470669226495,55.29839604518771,55.25208539811046,55.20577475103321,55.15946410395598,55.113153456878734,55.066842809801486,55.02053216272425,54.974221515647,54.927910868569754,54.88160022149251,54.83528957441527,54.78897892733802,54.74266828026078,54.696357633183545,54.6500469861063,54.60373633902905,54.55742569195181,54.511115044874565,54.46480439779732,54.418493750720074,54.37218310364283,54.325872456565584,54.27956180948835,54.23325116241111,54.18694051533386,54.14062986825662,54.094319221179376,54.048008574102134,54.001697927024885,53.955387279947644,53.909076632870395,53.86276598579315,53.816455338715905,53.77014469163867,53.72383404456142,53.67752339748418,53.63121275040693,53.58490210332968,53.53859145625245,53.492280809175206,53.44597016209796,53.39965951502071,53.353348867943474,53.30703822086623,53.260727573788984,53.21441692671174,53.1681062796345,53.12179563255725,53.07548498548001,53.029174338402775,52.98286369132553,52.923876754075636,52.86176948219525,52.799662210314835,52.737554938434435,52.675447666554035,52.61334039467363,52.55123312279323,52.48912585091283,52.42701857903243,52.36491130715202,52.30280403527163,52.24069676339123,52.17858949151083,52.11648221963041,52.05437494775002,51.99226767586962,51.80553473010863,51.36955043658661,50.93356614306458,50.49758184954252,50.06159755602049,49.62561326249847,49.1896289689764,48.75364467545433,48.31766038193235,47.88167608841029,47.44569179488821,47.0097075013662,46.573723207844175,46.13505202454201,45.69547769117906,45.2559033578161,44.81632902445311,44.376754691090156,43.93718035772719,43.497606024364195,43.058031691001204,42.61845735763825,42.178883024275294,41.739308690912296,41.29973435754934,40.86016002418638,40.42058569082339,39.98101135746043,39.541437024097476,39.10186269073448,38.66228835737148,38.22271402400857,37.78313969064557,37.34356535728257,36.90399102391962,36.46441669055666,36.02484235719366,35.58526802383071,35.14569369046775,34.70611935710476,34.2665450237418,33.82697069037884,33.387396357015845,32.947822023652854,32.50824769028989,32.068673356926936,31.629099023563942,31.189524690200987,30.749950356838028,30.310376023475033,29.870801690112074,29.431227356749122,28.991653023386128,28.55207869002313,28.112504356660214,27.672930023297216,27.23335568993422,26.793781356571266,26.35420702320831,25.914632689845313,25.475058356482357,25.035484023119402,24.595909689756404,24.15633535639345,23.716761023030493,23.277186689667495,22.8376123563045,22.398038022941584,21.958463689578586,21.518889356215592,21.079315022852633,20.63974068948968,20.200166356126683,19.760592022763728,19.32101768940077,18.881443356037774,18.44186902267478,18.002294689311864,17.56272035594887,17.12314602258587,16.683571689222916,16.24399735585996,15.804423022496962,15.410528771670103,15.245034933523444,15.079541095376786,14.91404725723013,14.7485534190835,14.583059580936842,14.417565742790185,14.252071904643556,14.0865780664969,13.921084228350239,13.755590390203613,13.590096552056952,13.424602713910295,13.259108875763637,13.093615037617008,12.92812119947035,12.762627361323695,12.597133523177066,12.431639685030408,12.292304371285878,12.166048333230423,12.039792295174943,11.913536257119466,11.78728021906401,11.661024181008532,11.534768142953054,11.408512104897577,11.28225606684212,11.156000028786641,11.029743990731163,10.903487952675707,10.777231914620229,10.65097587656475,10.524719838509295,10.398463800453817,10.272207762398338,10.145951724342858,10.019695686287404,9.893439648231926,9.767183610176447,9.640927572120992,9.514671534065513,9.388415496010035,9.26215945795458,9.135903419899101,9.009647381843623,8.883391343788167,8.757135305732689,8.63087926767721,8.504623229621732,8.378367191566277,8.252111153510798,8.12585511545532,7.999599077399864,7.873343039344385,7.747087001288907,7.620830963233452,7.494574925177973,7.368318887122495,7.242062849067016,7.115806811011561,6.989550772956083,6.863294734900604,6.737038696845149,6.610782658789669,6.508758596142534,6.430966486691115,6.3531743772396805,6.275382267788248,6.197590158336829,6.1197980488853965,6.042005939433963,5.964213829982531,5.886421720531112,5.80862961107968,5.730837501628247,5.6530453921768276,5.575253282725394,5.497461173273962,5.419669063822543,5.341876954371109,5.264084844919677,5.186292735468244,5.108500626016825],[45.03807957735301,45.0874066863838,45.13673379541458,45.18606090444537,45.23538801347616,45.284715122506945,45.33362065144723,45.38168302643972,45.42974540143221,45.4778077764247,45.525870151417195,45.573932526409685,45.62199490140217,45.67005727639466,45.71811965138715,45.76618202637964,45.81424440137213,45.86230677636462,45.91036915135711,45.95843152634959,46.00649390134208,46.05455627633458,46.10261865132706,46.15068102631956,46.19874340131204,46.246805776304534,46.294868151297024,46.342930526289514,46.390992901282004,46.439055276274495,46.48711765126698,46.53518002625947,46.58324240125196,46.63130477624445,46.67936715123694,46.72742952622943,46.77549190122192,46.82355427621441,46.8716166512069,46.91967902619939,46.96774140119187,47.01580377618437,47.06386615117685,47.11192852616935,47.159990901161834,47.20805327615433,47.256115651146814,47.30417802613931,47.352240401131795,47.400302776124285,47.448365151116775,47.49642752610926,47.544489901101755,47.59255227609424,47.64061465108673,47.68867702607923,47.73673940107171,47.784801776064214,47.8328641510567,47.88092652604918,47.92898890104168,47.97705127603416,48.02511365102666,48.07317602601914,48.12123840101163,48.16930077600412,48.21736315099661,48.2654255259891,48.3134879009816,48.36155027597408,48.40961265096657,48.45767502595906,48.50573740095155,48.55379977594404,48.601862150936526,48.64992452592902,48.69798690092151,48.746049275914,48.794111650906494,48.84217402589898,48.89023640089147,48.93829877588395,48.98636115087645,49.03442352586894,49.07866693912056,49.12214656002401,49.16562618092744,49.20910580183089,49.252585422734334,49.296065043637775,49.33954466454122,49.38302428544467,49.42650390634811,49.46998352725156,49.513463148155,49.55694276905844,49.60042238996189,49.64390201086533,49.68738163176879,49.73086125267223,49.774340873575674,49.817820494479115,49.86130011538256,49.90477973628601,49.94825935718946,49.9917389780929,50.03521859899634,50.07869821989978,50.12217784080323,50.16565746170667,50.20913708261012,50.25261670351357,50.29609632441701,50.339575945320455,50.383055566223895,50.42653518712734,50.47001480803078,50.51349442893422,50.55697404983768,50.60045367074112,50.64393329164457,50.68741291254801,50.73089253345145,50.7743721543549,50.81785177525834,50.86133139616179,50.904811017065235,50.94829063796868,50.99177025887212,51.03524987977557,51.07872950067902,51.12220912158246,51.165688742485905,51.20916836338935,51.25264798429279,51.29612760519624,51.33960722609969,51.38308684700313,51.426566467906575,51.47004608881002,51.51352570971347,51.55700533061692,51.60048495152035,51.6439645724238,51.687444193327245,51.730923814230685,51.77440343513413,51.81788305603758,51.86136267694102,51.90484229784447,51.94832191874791,51.991801539651355,52.0352811605548,52.07876078145825,52.1222404023617,52.16572002326514,52.209199644168585,52.25267926507203,52.29615888597547,52.33963850687891,52.38311812778236,52.42682885541854,52.47100179993721,52.51517474445589,52.559347688974576,52.603520633493254,52.647693578011925,52.69294439477926,52.738734147670925,52.78452390056258,52.83031365345425,52.876103406345905,52.92189315923756,52.96768291212922,53.013472665020885,53.05926241791254,53.1050521708042,53.150841923695864,53.19663167658752,53.24242142947918,53.288211182370844,53.33400093526251,53.379790688154166,53.425580441045824,53.47137019393748,53.517159946829146,53.562949699720804,53.60873945261247,53.654529205504126,53.70031895839578,53.74610871128745,53.7918984641791,53.83768821707076,53.88347796996242,53.92926772285408,53.97505747574575,54.0208472286374,54.066636981529065,54.11242673442074,54.158216487312394,54.20400624020405,54.24979599309571,54.295585745987374,54.34137549887903,54.38708860612678,54.43269952148994,54.478310436853086,54.52392135221623,54.56953226757938,54.61514318294253,54.66075409830568,54.70636501366883,54.75197592903197,54.79758684439512,54.843197759758276,54.888808675121425,54.93441959048457,54.980030505847715,55.025641421210864,55.07125233657401,55.11686325193717,55.1624741673003,55.20808508266346,55.25369599802661,55.29930691338975,55.344917828752905,55.390528744116054,55.4361396594792,55.48175057484235,55.5273614902055,55.57297240556865,55.6185833209318,55.66419423629494,55.709805151658095,55.75541606702124,55.801026982384386,55.84663789774753,55.89224881311068,55.93785972847383,55.98347064383698,56.02908155920013,56.07469247456328,56.12030338992643,56.165914305289576,56.211525220652724,56.25713613601587,56.30274705137903,56.34835796674217,56.39396888210532,56.43957979746847,56.439229931611415,56.392919284534166,56.346608637456924,56.30029799037968,56.25398734330244,56.20767669622519,56.16136604914796,56.11505540207071,56.06874475499347,56.022434107916226,55.97612346083898,55.92981281376173,55.883502166684494,55.837191519607245,55.79088087253,55.74457022545276,55.69825957837552,55.65194893129827,55.60563828422104,55.559327637143795,55.502680924158796,55.44057365227839,55.378466380397995,55.31635910851759,55.254251836637195,55.192144564756795,55.13003729287639,55.06793002099599,55.00582274911559,54.94371547723519,54.88160820535478,54.81950093347437,54.75739366159398,54.69528638971357,54.63317911783318,54.57107184595277,54.508964574072365,54.44685730219197,54.38475003031157,54.32264275843117,54.26053548655077,54.19842821467037,54.136320942789965,54.07421367090957,54.012106399029165,53.94999912714877,53.887891855268364,53.82578458338796,53.763677311507564,53.70157003962716,53.639462767746764,53.57735549586636,53.515248223985964,53.45314095210556,53.39103368022515,53.328926408344756,53.26681913646435,53.20471186458395,53.14260459270355,53.080497320823156,53.01839004894274,52.95628277706235,52.89417550518195,52.83206823330155,52.76996096142114,52.70785368954074,52.645746417660334,52.583639145779934,52.52153187389954,52.45942460201913,52.39731733013873,52.335210058258326,52.27310278637793,52.210995514497526,52.14888824261713,52.08678097073673,52.024673698856326,51.962566426975926,51.900459155095525,51.838351883215125,51.77624461133472,51.714137339454325,51.65203006757392,51.465297121812924,51.029312828290905,50.59332853476887,50.15734424124682,49.72135994772479,49.28537565420277,48.8493913606807,48.41340706715863,47.97742277363665,47.54143848011458,47.10545418659252,46.6694698930705,46.23348559954847,45.797501306026405,45.36151701250438,44.92553271898235,44.48954842546029,44.053564131938266,43.61757983841624,43.18159554489417,42.74561125137211,42.309626957850085,41.87364266432806,41.437658370806,41.001674077283965,40.56568978376194,40.12970549023988,39.69372119671785,39.25773690319583,38.821752609673766,38.3857683161517,37.949784022629714,37.51379972910765,37.07781543558558,36.64183114206356,36.20584684854154,35.76986255501947,35.333878261497446,34.89789396797543,34.46190967445335,34.02592538093133,33.58994108740931,33.15395679388724,32.71797250036518,32.28198820684315,31.846003913321127,31.41001961979906,30.974035326277036,30.538051032755014,30.098668611628355,29.6590942782654,29.21951994490244,28.779945611539446,28.34037127817645,27.900796944813532,27.461222611450538,27.02164827808754,26.582073944724584,26.14249961136163,25.70292527799863,25.263350944635675,24.82377661127272,24.38420227790973,23.94462794454677,23.50505361118381,23.065479277820813,22.625904944457822,22.186330611094903,21.746756277731908,21.307181944368914,20.867607611005955,20.428033277643,19.988458944280005,19.54888461091705,19.10931027755409,18.669735944191096,18.230161610828098,17.790587277465185,17.351012944102187,16.91143861073919,16.471864277376234,16.03228994401328,15.592715610650282,15.198821359823423,15.033327521676764,14.867833683530105,14.702339845383449,14.53684600723682,14.371352169090162,14.205858330943505,14.040364492796877,13.87487065465022,13.70937681650356,13.543882978356933,13.378389140210274,13.212895302063616,13.047401463916957,12.88190762577033,12.71641378762367,12.550919949477013,12.385426111330386,12.219932273183726,12.05443843503707,11.888944596890441,11.723450758743784,11.557956920597125,11.392463082450497,11.226969244303838,11.06147540615718,10.895981568010521,10.730487729863894,10.564993891717236,10.399500053570579,10.23400621542395,10.06851237727729,9.903018539130635,9.737524700984007,9.572030862837348,9.406537024690689,9.241043186544033,9.075549348397402,8.910055510250745,8.744561672104089,8.601956624411685,8.475700586356206,8.349444548300728,8.223188510245272,8.125203006137015,8.047410896685582,7.969618787234164,7.891826677782731,7.814034568331298,7.736242458879865,7.658450349428447,7.580658239977013,7.50286613052558,7.4250740210741615,7.347281911622729,7.269489802171297,7.1916976927198775,7.113905583268444,7.036113473817013,6.958321364365578,6.88052925491416,6.802737145462727,6.724945036011294,6.647152926559874,6.569360817108443,6.491568707657009,6.413776598205591,6.335984488754158,6.258192379302725,6.180400269851306,6.102608160399873,6.02481605094844,5.947023941497007,5.869231832045588,5.7914397225941565,5.713647613142724,5.635855503691305,5.558063394239872,5.480271284788438,5.40247917533702,5.324687065885587,5.246894956434154,5.16910284698272,5.091310737531303],[45.386244058263784,45.43557116729457,45.48489827632535,45.53422538535614,45.583552494386936,45.63287960341772,45.6822067124485,45.73153382147929,45.78086093051008,45.830188039540865,45.879515148571656,45.92884225760244,45.978169366633225,46.02749647566401,46.0768235846948,46.126150693725585,46.175477802756376,46.22480491178716,46.274132020817945,46.32345912984873,46.37278623887952,46.422113347910305,46.47144045694108,46.519713619070906,46.56777599406339,46.61583836905588,46.66390074404838,46.71196311904087,46.76002549403335,46.80808786902584,46.85615024401832,46.90421261901082,46.95227499400331,47.00033736899581,47.048399743988284,47.09646211898078,47.144524493973265,47.19258686896576,47.24064924395825,47.288711618950735,47.336773993943225,47.384836368935716,47.432898743928206,47.4809611189207,47.529023493913186,47.57708586890568,47.62514824389817,47.67321061889066,47.72127299388315,47.76933536887564,47.81739774386813,47.86546011886061,47.91352249385311,47.96158486884559,48.00964724383809,48.05770961883057,48.10577199382307,48.15383436881555,48.20189674380804,48.24995911880053,48.29802149379302,48.34608386878551,48.394146243778,48.44220861877049,48.49027099376298,48.538333368755474,48.58639574374796,48.634458118740454,48.682520493732945,48.730582868725435,48.77864524371792,48.82670761871041,48.8747699937029,48.922832368695396,48.97089474368788,49.01895711868037,49.06701949367286,49.11508186866534,49.16314424365784,49.21120661865033,49.25926899364282,49.30733136863531,49.3553937436278,49.403456118620284,49.447699531871905,49.49117915277535,49.53465877367879,49.57813839458224,49.62161801548568,49.66509763638912,49.708577257292575,49.752056878196015,49.795536499099455,49.83901612000291,49.88249574090635,49.92597536180979,49.969454982713245,50.012934603616685,50.05641422452014,50.09989384542358,50.14337346632702,50.18685308723046,50.230332708133915,50.273812329037355,50.317291949940795,50.36077157084425,50.40425119174769,50.44773081265113,50.491210433554585,50.534690054458025,50.578169675361465,50.62164929626491,50.66512891716836,50.7086085380718,50.75208815897525,50.795567779878695,50.839047400782135,50.88252702168558,50.92600664258903,50.96948626349247,51.012965884395925,51.056445505299365,51.099925126202805,51.14340474710625,51.18688436800969,51.23036398891313,51.27384360981658,51.31732323072003,51.360802851623475,51.404282472526916,51.44776209343036,51.49124171433381,51.53472133523725,51.5782009561407,51.621680577044145,51.665160197947586,51.70863981885103,51.75211943975448,51.79559906065793,51.83907868156137,51.882558302464815,51.92603792336826,51.969517544271696,52.01299716517514,52.05647678607859,52.10053417563678,52.144707120155466,52.188880064674144,52.23305300919283,52.27722595371151,52.32139889823018,52.365571842748864,52.409744787267535,52.45391773178621,52.4980906763049,52.54226362082357,52.58643656534225,52.630609509860925,52.67478245437961,52.71895539889829,52.76312834341696,52.807301287935644,52.85147423245432,52.895647176973,52.93982012149168,52.983993066010356,53.028166010529034,53.07341682729637,53.11920658018802,53.164996333079685,53.21078608597135,53.256575838863014,53.302365591754665,53.34815534464633,53.393945097537994,53.43973485042965,53.48552460332131,53.531314356212974,53.577104109104624,53.62289386199629,53.668683614887954,53.71447336777961,53.76026312067127,53.80605287356293,53.85184262645459,53.89763237934625,53.94342213223791,53.98921188512957,54.035001638021235,54.08079139091289,54.12658114380455,54.172370896696215,54.21816064958788,54.26395040247953,54.30974015537119,54.35552990826285,54.40131966115452,54.447109414046174,54.49289916693783,54.53868891982949,54.584478672721154,54.63026842561281,54.676058178504476,54.721847931396134,54.767637684287784,54.81342743717945,54.859217190071114,54.90500694296278,54.950796695854436,54.996586448746086,55.04237620163776,55.088165954529416,55.13395570742107,55.17974546031273,55.225535213204395,55.27132496609605,55.31711471898771,55.362904471879375,55.40869422477104,55.4544839776627,55.50027373055435,55.54606348344602,55.591853236337684,55.637642989229334,55.683432742121,55.729222495012664,55.775012247904314,55.82080200079598,55.86659175368763,55.912381506579294,55.95817125947096,56.00396101236261,56.04975076525428,56.09554051814594,56.141330271037596,56.18712002392926,56.232909776820925,56.27869952971258,56.32448928260424,56.3703376876308,56.41620913455801,56.46208058148522,56.507952028412426,56.553823475339634,56.599694922266856,56.64556636919406,56.691437816121265,56.73730926304848,56.78318070997569,56.829052156902904,56.81570018652639,56.743124798846175,56.67054941116596,56.59797402348574,56.525398635805516,56.452823248125306,56.38024786044509,56.30767247276487,56.23509708508464,56.162521697404436,56.08994630972422,56.017370922044,55.944795534363784,55.87222014668357,55.79964475900334,55.72706937132313,55.65449398364292,55.5819185959627,55.50934320828249,55.43676782060227,55.364192432922046,55.29161704524182,55.21904165756162,55.1464662698814,55.073890882201184,55.001315494520966,54.92874010684074,54.856164719160525,54.78358933148031,54.711013943800104,54.63843855611987,54.56586316843966,54.493287780759445,54.42071239307923,54.348137005399,54.27556161771879,54.202986230038576,54.13041084235836,54.05783545467814,53.985260066997924,53.92029787825507,53.85819060637468,53.79608333449427,53.73397606261386,53.67186879073346,53.60976151885307,53.54765424697267,53.48554697509226,53.42343970321186,53.36133243133146,53.29922515945106,53.23711788757066,53.175010615690255,53.11290334380986,53.050796071929454,52.988688800049054,52.926581528168654,52.864474256288254,52.802366984407854,52.740259712527454,52.67815244064705,52.616045168766654,52.553937896886254,52.491830625005846,52.42972335312544,52.367616081245046,52.30550880936464,52.24340153748423,52.18129426560384,52.11918699372344,52.05707972184303,51.99497244996263,51.93286517808224,51.87075790620183,51.80865063432143,51.74654336244103,51.684436090560624,51.622328818680224,51.56022154679982,51.49811427491943,51.436007003039016,51.373899731158616,51.311792459278216,51.12505951351722,50.6890752199952,50.25309092647318,49.81710663295111,49.38112233942909,48.94513804590706,48.509153752385004,48.07316945886293,47.63718516534095,47.201200871818884,46.765216578296815,46.3292322847748,45.893247991252764,45.4572636977307,45.02127940420868,44.58529511068666,44.14931081716459,43.713326523642564,43.27734223012054,42.84135793659847,42.405373643076416,41.96938934955438,41.533405056032365,41.09742076251029,40.66143646898827,40.225452175466245,39.789467881944184,39.35348358842216,38.917499294900125,38.48151500137807,38.045530707855995,37.60954641433402,37.17356212081195,36.73757782728988,36.30159353376786,35.86560924024583,35.42962494672377,34.993640653201744,34.557656359679726,34.12167206615766,33.68568777263563,33.249703479113606,32.81371918559154,32.377734892069476,31.94175059854745,31.505766305025425,31.069782011503357,30.633797717981334,30.197813424459312,29.761829130937247,29.325844837415225,28.8898605438932,28.453876250371135,28.01789195684907,27.58190766332708,27.14592336980502,26.70993907628295,26.273954782760924,25.837970489238906,25.401986195716837,24.96600190219481,24.53001760867279,24.094033315150725,23.658049021628695,23.222064728106673,22.78608043458461,22.350096141062544,21.91411184754056,21.478127554018496,21.04214326049643,20.606158966974405,20.170174673452383,19.734190379930318,19.298206086408292,18.862221792886267,18.4262374993642,17.990253205842134,17.554268912320154,17.118284618798082,16.682300325276017,16.247143343426675,15.812222751836053,15.377302160245398,14.988712772250532,14.851824744083036,14.7322320208391,14.612639297595164,14.493046574351249,14.373453851107312,14.253861127863379,14.134268404619464,14.014675681375527,13.895082958131592,13.775490234887677,13.65589751164374,13.536304788399804,13.416712065155867,13.297119341911953,13.177526618668017,13.05793389542408,12.938341172180166,12.81874844893623,12.699155725692293,12.57956300244838,12.459970279204445,12.340377555960506,12.220784832716593,12.101192109472656,11.98159938622872,11.862006662984784,11.742413939740869,11.622821216496932,11.503228493252998,11.383635770009082,11.264043046765146,11.144450323521209,11.024857600277295,10.905264877033359,10.785672153789422,10.666079430545487,10.546486707301574,10.426893984057635,10.307301260813698,10.187708537569785,10.068115814325846,9.948523091081912,9.828930367837996,9.709337644594061,9.589744921350125,9.47015219810621,9.350559474862273,9.230966751618336,9.111374028374401,8.991781305130488,8.872188581886551,8.752595858642614,8.633003135398699,8.513410412154764,8.39381768891083,8.274224965666914,8.154632242422977,8.03503951917904,7.915446795935104,7.79585407269119,7.676261349447254,7.556668626203317,7.437075902959403,7.317483179715467,7.19789045647153,7.0782977332276165,6.95870500998368,6.839112286739743,6.719519563495829,6.599926840251893,6.480334117007956,6.3607413937640205,6.241148670520106,6.121555947276169,6.001963224032234,5.882370500788319,5.762777777544383,5.643185054300447,5.523592331056532,5.403999607812596,5.284406884568659,5.164814161324723,5.074147625712663],[45.73440853917457,45.78373564820535,45.833062757236135,45.88238986626692,45.93171697529771,45.981044084328495,46.03037119335929,46.07969830239007,46.129025411420855,46.17835252045164,46.22767962948243,46.277006738513215,46.32633384754401,46.37566095657479,46.424988065605575,46.47431517463636,46.523642283667144,46.57296939269794,46.62229650172873,46.67162361075951,46.720950719790295,46.77027782882108,46.819604937851864,46.86893204688266,46.91825915591345,46.96758626494423,47.016913373975015,47.0662404830058,47.11556759203659,47.16489470106738,47.21422181009817,47.26354891912895,47.312876028159735,47.36220313719052,47.41153024622131,47.460857355252095,47.51018446428289,47.55951157331367,47.608838682344455,47.6577442117021,47.70580658669459,47.75386896168709,47.80193133667958,47.84999371167206,47.898056086664546,47.94611846165704,47.994180836649534,48.04224321164203,48.09030558663451,48.138367961627,48.186430336619495,48.234492711611985,48.282555086604475,48.33061746159696,48.37867983658945,48.42674221158194,48.47480458657443,48.52286696156692,48.57092933655941,48.6189917115519,48.66705408654438,48.71511646153688,48.76317883652937,48.81124121152186,48.85930358651435,48.907365961506834,48.955428336499324,49.00349071149182,49.051553086484304,49.0996154614768,49.147677836469285,49.195740211461775,49.243802586454265,49.291864961446755,49.339927336439246,49.387989711431736,49.436052086424226,49.484114461416716,49.53217683640921,49.58023921140169,49.62830158639419,49.67636396138667,49.72442633637917,49.77248871137165,49.81673212462327,49.86021174552671,49.90369136643015,49.94717098733361,49.99065060823705,50.034130229140494,50.07760985004394,50.12108947094738,50.16456909185082,50.20804871275427,50.25152833365772,50.29500795456116,50.33848757546461,50.38196719636805,50.4254468172715,50.46892643817495,50.51240605907839,50.555885679981834,50.59936530088528,50.64284492178872,50.68632454269216,50.72980416359561,50.77328378449906,50.8167634054025,50.860243026305945,50.90372264720939,50.94720226811283,50.99068188901628,51.03416150991973,51.077641130823174,51.121120751726615,51.16460037263006,51.2080799935335,51.25155961443694,51.2950392353404,51.33851885624384,51.381998477147285,51.425478098050725,51.468957718954165,51.51243733985761,51.55591696076105,51.59939658166451,51.642876202567955,51.686355823471395,51.730066551336364,51.77423949585505,51.81841244037373,51.86258538489241,51.90675832941108,51.95093127392976,51.99510421844844,52.03927716296712,52.083450107485795,52.12762305200448,52.17179599652315,52.21596894104184,52.260141885560515,52.30431483007919,52.348487774597864,52.39266071911654,52.43683366363523,52.481006608153905,52.52517955267258,52.56935249719126,52.61352544170994,52.65769838622862,52.701871330747295,52.74604427526597,52.79021721978465,52.83439016430333,52.87856310882201,52.922736053340685,52.96690899785936,53.01108194237804,53.05525488689672,53.0994278314154,53.143600775934075,53.18777372045275,53.23194666497143,53.27611960949011,53.32029255400879,53.36446549852747,53.408638443046144,53.45388925981349,53.499679012705144,53.54546876559681,53.591258518488466,53.637048271380124,53.68283802427179,53.72862777716345,53.77441753005511,53.82020728294677,53.86599703583842,53.91178678873008,53.95757654162175,54.00336629451341,54.04915604740507,54.09494580029673,54.14073555318839,54.18652530608005,54.232315058971714,54.27810481186337,54.32389456475502,54.36968431764669,54.41547407053835,54.46126382343001,54.50705357632167,54.552843329213324,54.59863308210498,54.64442283499665,54.69021258788831,54.73600234077997,54.781792093671626,54.82758184656329,54.873371599454956,54.91916135234661,54.96495110523827,55.010740858129935,55.056530611021586,55.10232036391325,55.148110116804915,55.193899869696565,55.23968962258823,55.28547937547989,55.331269128371545,55.37705888126322,55.42284863415487,55.46863838704653,55.51442813993819,55.56021789282985,55.60600764572152,55.651797398613176,55.697587151504834,55.7433769043965,55.78916665728816,55.83497107319418,55.880842520121384,55.92671396704861,55.972585413975814,56.01845686090303,56.064328307830245,56.110199754757446,56.15607120168466,56.20194264861187,56.24781409553907,56.293685542466285,56.3395569893935,56.38542843632071,56.43129988324792,56.47717133017513,56.52304277710235,56.568914224029555,56.61478567095676,56.66065711788397,56.70652856481118,56.7524000117384,56.79827145866561,56.84414290559282,56.890014352520026,56.935885799447234,56.98175724637446,57.02762869330166,57.073500140228866,57.11937158715608,57.16524303408329,57.211114481010505,57.19776251063399,57.125187122953776,57.05261173527356,56.98003634759334,56.90746095991312,56.834885572232906,56.762310184552696,56.68973479687247,56.61715940919225,56.54458402151204,56.47200863383182,56.3994332461516,56.326857858471385,56.25428247079117,56.18170708311095,56.10913169543073,56.036556307750516,55.9639809200703,55.89140553239008,55.818830144709864,55.74625475702965,55.67367936934943,55.60110398166922,55.528528593988995,55.45595320630878,55.38337781862856,55.31080243094835,55.238227043268125,55.16565165558791,55.093076267907705,55.02050088022747,54.94792549254726,54.87535010486705,54.802774717186836,54.730199329506604,54.65762394182639,54.58504855414618,54.512473166465966,54.43989777878574,54.36732239110553,54.2947470034253,54.22217161574509,54.14959622806488,54.07702084038466,54.00444545270443,53.93187006502423,53.859294677344,53.78671928966379,53.71414390198357,53.64156851430336,53.56899312662314,53.496417738942924,53.42384235126271,53.35126696358249,53.27869157590227,53.206116188222055,53.13354080054183,53.06096541286162,52.9883900251814,52.915814637501185,52.84323924982096,52.77066386214075,52.69808847446053,52.625513086780316,52.552937699100106,52.48036231141989,52.407786923739664,52.33521153605945,52.26263614837924,52.19006076069901,52.117485373018795,52.04490998533858,51.97233459765837,51.88831901083758,51.78662295638165,51.68492690192572,51.58323084746979,51.48153479301387,51.379838738557936,51.27814268410201,51.17644662964607,51.07475057519014,50.97305452073421,50.76205469165607,50.332447313333624,49.90283993501117,49.473232556688686,49.043625178366234,48.6140178000438,48.1844104217213,47.75480304339882,47.325195665076414,46.895588286753934,46.46598090843143,46.03637353010899,45.60676615178655,45.177158773464065,44.74622307578132,44.3113024841907,43.87638189260004,43.441461301009426,43.00654070941881,42.571620117828154,42.136699526237486,41.701778934646875,41.26685834305625,40.831937751465595,40.39701715987498,39.962096568284366,39.5271759766937,39.09225538510309,38.65733479351246,38.22241420192181,37.78749361033115,37.352573018740564,36.91765242714991,36.48273183555925,36.04781124396863,35.61289065237801,35.17797006078735,34.74304946919674,34.308128877606116,33.873208286015455,33.438287694424844,33.00336710283422,32.568446511243565,32.133525919652904,31.698605328062285,31.263684736471667,30.828764144881006,30.39384355329039,29.958922961699777,29.524002370109116,29.089081778518498,28.654161186927873,28.21924059533722,27.784320003746558,27.34939941215598,26.91447882056532,26.479558228974664,26.044637637384042,25.609717045793428,25.174796454202767,24.73987586261215,24.30495527102153,23.870034679430873,23.435114087840255,23.000193496249633,22.565272904658976,22.130352313068318,21.69543172147774,21.260511129887085,20.82559053829642,20.390669946705806,19.955749355115188,19.520828763524527,19.08590817193391,18.650987580343287,18.21606698875263,17.781146397161976,17.346225805571397,16.91130521398074,16.476384622390075,16.04146403079946,15.60654343920884,15.171622847618185,14.783033459623319,14.626100089606929,14.46916671959054,14.31223334957415,14.155299979557793,13.998366609541403,13.841433239525013,13.684499869508656,13.527566499492266,13.370633129475875,13.213699759459516,13.056766389443126,12.899833019426739,12.742899649410347,12.585966279393988,12.4290329093776,12.27209953936121,12.115166169344851,11.958232799328464,11.801299429312074,11.644366059295713,11.487432689279323,11.330499319262934,11.191223161332092,11.071630438088155,10.952037714844218,10.832444991600283,10.712852268356368,10.593259545112433,10.473666821868497,10.354074098624581,10.234481375380645,10.11488865213671,9.995295928892794,9.875703205648858,9.756110482404921,9.636517759160986,9.516925035917073,9.397332312673136,9.2777395894292,9.158146866185286,9.038554142941349,8.91896141969741,8.799368696453497,8.679775973209562,8.560183249965625,8.44059052672171,8.320997803477773,8.201405080233837,8.081812356989902,7.962219633745987,7.842626910502052,7.723034187258115,7.6034414640142005,7.483848740770263,7.364256017526328,7.244663294282413,7.125070571038477,7.005477847794541,6.8858851245506045,6.76629240130669,6.67856307541961,6.604896378692256,6.531229681964917,6.457562985237564,6.383896288510211,6.31022959178287,6.236562895055518,6.1628961983281645,6.089229501600824,6.015562804873471,5.941896108146118,5.868229411418765,5.794562714691426,5.720896017964073,5.64722932123672,5.57356262450938,5.499895927782026,5.4262292310546725,5.352562534327333,5.278895837599981,5.205229140872627,5.131562444145274,5.057895747417934],[46.082573020085334,46.13190012911612,46.1812272381469,46.23055434717769,46.27988145620848,46.32920856523926,46.378535674270054,46.42786278330084,46.47718989233163,46.526517001362414,46.575844110393206,46.62517121942398,46.674498328454774,46.72382543748556,46.77315254651634,46.822479655547134,46.87180676457792,46.92113387360871,46.970460982639494,47.019788091670286,47.06911520070106,47.118442309731854,47.16776941876264,47.21709652779343,47.266423636824214,47.315750745855,47.36507785488578,47.414404963916574,47.463732072947366,47.51305918197815,47.562386291008934,47.61171340003972,47.6610405090705,47.71036761810129,47.75969472713208,47.80902183616286,47.858348945193654,47.90767605422444,47.95700316325524,48.006330272286014,48.0556573813168,48.10498449034759,48.154311599378374,48.20363870840916,48.25296581743994,48.30229292647073,48.35162003550152,48.4009471445323,48.450274253563094,48.49960136259388,48.54892847162466,48.598255580655454,48.64758268968624,48.69690979871702,48.746236907747814,48.7955640167786,48.843837179325774,48.89189955431827,48.93996192931076,48.988024304303245,49.03608667929574,49.08414905428823,49.132211429280716,49.18027380427321,49.228336179265696,49.276398554258186,49.32446092925068,49.37252330424317,49.42058567923566,49.46864805422814,49.51671042922064,49.56477280421312,49.61283517920562,49.66089755419811,49.7089599291906,49.75702230418308,49.80508467917557,49.85314705416806,49.90120942916055,49.94927180415304,49.99733417914553,50.04539655413802,50.093458929130506,50.141521304123,50.185764717374624,50.229244338278065,50.27272395918151,50.31620358008496,50.3596832009884,50.40316282189184,50.44664244279529,50.490122063698735,50.533601684602175,50.57708130550562,50.62056092640907,50.66404054731251,50.707520168215964,50.750999789119405,50.79447941002285,50.8379590309263,50.88143865182974,50.92491827273318,50.96839789363663,51.011877514540075,51.055357135443515,51.09883675634696,51.14231637725041,51.18579599815384,51.2292756190573,51.27275523996074,51.316234860864185,51.359714481767625,51.403771871554625,51.4479448160733,51.49211776059198,51.53629070511066,51.58046364962934,51.62463659414801,51.668809538666686,51.71298248318537,51.757155427704056,51.80132837222273,51.845501316741405,51.88967426126008,51.93384720577876,51.97802015029744,52.02219309481613,52.0663660393348,52.11053898385347,52.15471192837215,52.19888487289083,52.243057817409515,52.28723076192819,52.33140370644687,52.37557665096555,52.41974959548422,52.4639225400029,52.50809548452158,52.55226842904026,52.596441373558946,52.64061431807762,52.684787262596295,52.72896020711497,52.77313315163365,52.817306096152336,52.86147904067101,52.90565198518969,52.94982492970837,52.99399787422705,53.038170818745726,53.082343763264404,53.12651670778308,53.17068965230176,53.21486259682044,53.25903554133912,53.30320848585779,53.34738143037647,53.39155437489515,53.43572731941383,53.47990026393251,53.524073208451185,53.56824615296986,53.61241909748854,53.65659204200722,53.7007649865259,53.744937931044575,53.78911087556325,53.83436169233059,53.88015144522225,53.92594119811391,53.97173095100557,54.01752070389722,54.063310456788884,54.10910020968055,54.15488996257221,54.20067971546386,54.24646946835552,54.29225922124719,54.33804897413885,54.38383872703051,54.42962847992217,54.47541823281383,54.521207985705495,54.56699773859715,54.61278749148882,54.658577244380474,54.70436699727213,54.75015675016378,54.795946503055454,54.841736255947104,54.88752600883876,54.93331576173043,54.979105514622084,55.024895267513756,55.07068502040542,55.11647477329708,55.162264526188736,55.208054279080386,55.25384403197206,55.299633784863715,55.345475905684765,55.39134735261198,55.43721879953919,55.483090246466396,55.52896169339361,55.57483314032082,55.62070458724803,55.666576034175236,55.712447481102444,55.75831892802965,55.804190374956875,55.85006182188408,55.895933268811284,55.9418047157385,55.98767616266572,56.03354760959292,56.07941905652014,56.125290503447346,56.171161950374554,56.21703339730177,56.26290484422897,56.30877629115619,56.3546477380834,56.40051918501061,56.44639063193783,56.492262078865025,56.53813352579225,56.584004972719455,56.629876419646656,56.67574786657387,56.72161931350108,56.767490760428295,56.8133622073555,56.85923365428272,56.90510510120993,56.95097654813714,56.99684799506434,57.04271944199155,57.08859088891877,57.13446233584598,57.18033378277319,57.2262052297004,57.27207667662761,57.317948123554814,57.363819570482036,57.409691017409244,57.455562464336445,57.50143391126366,57.54730535819087,57.59317680511809,57.57982483474157,57.507249447061355,57.43467405938114,57.36209867170092,57.2895232840207,57.216947896340486,57.14437250866028,57.07179712098005,56.999221733299834,56.92664634561963,56.854070957939406,56.78149557025918,56.70892018257897,56.63634479489876,56.56376940721854,56.49119401953832,56.418618631858095,56.34604324417789,56.273467856497675,56.20089246881746,56.12831708113723,56.05574169345702,55.983166305776805,55.91059091809659,55.838015530416364,55.765440142736146,55.692864755055936,55.620289367375705,55.54771397969549,55.475138592015284,55.40256320433506,55.32998781665485,55.25741242897463,55.184837041294415,55.11226165361419,55.03968626593398,54.96711087825376,54.894535490573546,54.82196010289333,54.74938471521311,54.676809327532894,54.604233939852676,54.53165855217247,54.45908316449224,54.386507776812024,54.31393238913181,54.226796722977,54.12510066852106,54.02340461406514,53.921708559609215,53.82001250515328,53.71831645069735,53.61662039624142,53.51492434178549,53.41322828732956,53.31153223287364,53.2098361784177,53.108140123961775,53.00644406950583,52.90474801504992,52.803051960593976,52.70135590613805,52.59965985168213,52.49796379722619,52.39626774277026,52.29457168831434,52.19287563385841,52.091179579402464,51.98948352494655,51.88778747049062,51.78609141603469,51.68439536157876,51.58269930712283,51.481003252666895,51.37930719821097,51.27761114375504,51.17591508929911,51.07421903484319,50.97252298038726,50.870826925931325,50.76913087147539,50.66743481701946,50.565738762563534,50.35473893348538,49.925131555162935,49.49552417684049,49.065916798518,48.63630942019556,48.206702041873115,47.77709466355063,47.34748728522814,46.91787990690574,46.488272528583245,46.058665150260765,45.629057771938314,45.19945039361587,44.769843015293375,44.34023563697093,43.91062825864849,43.481020880326,43.051413502003555,42.62180612368111,42.192198745358624,41.76259136703614,41.332983988713686,40.903376610391234,40.47376923206875,40.0441618537463,39.61455447542386,39.18494709710137,38.75533971877893,38.325732340456476,37.896124962133996,37.46651758381151,37.0369102054891,36.60730282716661,36.177695448844126,35.748088070521675,35.31848069219923,34.88887331387674,34.4592659355543,34.029658557231855,33.60005117890936,33.17044380058691,32.740836422264465,32.31122904394198,31.88162166561949,31.452014287297047,31.0224069089746,30.592799530652115,30.163192152329664,29.73358477400722,29.303977395684733,28.87437001736229,28.444762639039837,28.013561282710008,27.578640691119354,27.14372009952877,26.708799507938117,26.273878916347464,25.838958324756838,25.404037733166227,24.96911714157556,24.534196549984948,24.099275958394326,23.66435536680367,23.22943477521305,22.794514183622432,22.35959359203177,21.924673000441114,21.489752408850535,21.05483181725988,20.61991122566922,20.1849906340786,19.750070042487984,19.315149450897323,18.880228859306705,18.445308267716083,18.01038767612543,17.575467084534772,17.140546492944193,16.70562590135353,16.27070530976287,15.835784718172256,15.40086412658164,14.96594353499098,14.577354146996115,14.420420776979725,14.263487406963334,14.106554036946948,13.949620666930587,13.792687296914197,13.635753926897808,13.47882055688145,13.321887186865059,13.164953816848671,13.00802044683231,12.851087076815922,12.694153706799531,12.537220336783143,12.380286966766784,12.223353596750396,12.066420226734007,11.909486856717646,11.75255348670126,11.595620116684868,11.438686746668509,11.28175337665212,11.12482000663573,10.96788663661937,10.810953266602983,10.654019896586593,10.497086526570204,10.340153156553844,10.183219786537455,10.026286416521065,9.869353046504706,9.712419676488317,9.555486306471927,9.398552936455566,9.24161956643918,9.08468619642279,8.962285314032764,8.84918154104365,8.736077768054514,8.622973995065378,8.509870222076264,8.396766449087128,8.283662676097991,8.170558903108876,8.05745513011974,7.944351357130606,7.83124758414149,7.718143811152355,7.6199782545804196,7.546311557853067,7.472644861125727,7.398978164398374,7.325311467671021,7.251644770943681,7.177978074216327,7.104311377488975,7.030644680761634,6.956977984034282,6.883311287306928,6.809644590579574,6.735977893852235,6.6623111971248825,6.588644500397529,6.514977803670188,6.441311106942837,6.367644410215482,6.293977713488143,6.22031101676079,6.146644320033436,6.072977623306096,5.999310926578744,5.92564422985139,5.851977533124037,5.778310836396698,5.704644139669345,5.630977442941991,5.557310746214652,5.483644049487298,5.409977352759945,5.336310656032606,5.262643959305253,5.1889772625778985,5.115310565850546,5.041643869123206],[46.4307375009961,46.48006461002689,46.52939171905767,46.57871882808846,46.62804593711925,46.67737304615004,46.726700155180815,46.776027264211606,46.8253543732424,46.87468148227319,46.924008591303966,46.97333570033476,47.02266280936554,47.07198991839633,47.12131702742712,47.17064413645791,47.219971245488686,47.26929835451948,47.31862546355026,47.36795257258105,47.41727968161184,47.46660679064263,47.515933899673406,47.5652610087042,47.61458811773498,47.663915226765766,47.71324233579656,47.76256944482734,47.81189655385813,47.86122366288892,47.9105507719197,47.959877880950486,48.00920498998127,48.05853209901206,48.10785920804285,48.15718631707364,48.20651342610442,48.255840535135206,48.305167644166005,48.35449475319679,48.40382186222757,48.45314897125836,48.50247608028914,48.551803189319926,48.60113029835072,48.6504574073815,48.699784516412294,48.74911162544308,48.79843873447386,48.84776584350465,48.89709295253544,48.94642006156622,48.995747170597014,49.0450742796278,49.09440138865858,49.14372849768937,49.19305560672016,49.24238271575095,49.291709824781734,49.34103693381252,49.3903640428433,49.439691151874094,49.48901826090488,49.53834536993566,49.587672478966454,49.63699958799724,49.68632669702802,49.73565380605881,49.7849809150896,49.83430802412038,49.883635133151174,49.93296224218196,49.98186777195696,50.029930146949454,50.077992521941944,50.12605489693443,50.17411727192692,50.22217964691941,50.2702420219119,50.318304396904395,50.36636677189688,50.414429146889375,50.46249152188186,50.51055389687435,50.55479731012597,50.59827693102942,50.64175655193286,50.685236172836305,50.72871579373975,50.772195414643186,50.81567503554663,50.85915465645008,50.90263427735352,50.94611389825697,50.989593519160415,51.033304247254186,51.077477191772864,51.12165013629155,51.16582308081023,51.209996025328905,51.254168969847576,51.29834191436626,51.34251485888494,51.38668780340362,51.430860747922296,51.475033692440974,51.51920663695965,51.56337958147833,51.60755252599701,51.651725470515686,51.695898415034364,51.74007135955304,51.78424430407173,51.828417248590405,51.872590193109076,51.91676313762776,51.96093608214644,52.00510902666511,52.04928197118379,52.09345491570247,52.13762786022115,52.18180080473983,52.225973749258515,52.27014669377719,52.31431963829586,52.35849258281455,52.40266552733323,52.446838471851905,52.491011416370576,52.53518436088926,52.57935730540794,52.62353024992662,52.667703194445295,52.71187613896397,52.75604908348265,52.80022202800133,52.84439497252001,52.888567917038685,52.93274086155736,52.97691380607604,53.02108675059472,53.0652596951134,53.109432639632075,53.15360558415075,53.19777852866943,53.24195147318811,53.28612441770679,53.330297362225465,53.37447030674414,53.41864325126283,53.4628161957815,53.506989140300185,53.551162084818856,53.595335029337534,53.63950797385621,53.6836809183749,53.72785386289357,53.772026807412246,53.81619975193093,53.86037269644961,53.90454564096828,53.948718585486965,53.99289153000564,54.03706447452433,54.081237419043006,54.12541036356168,54.169583308080355,54.21483412484769,54.260623877739356,54.30641363063101,54.35220338352268,54.39799313641433,54.44378288930599,54.48957264219766,54.53536239508931,54.58115214798097,54.62694190087263,54.672731653764295,54.71852140665595,54.76431115954762,54.81010929124814,54.85598073817535,54.90185218510256,54.94772363202977,54.993595078956986,55.039466525884194,55.08533797281141,55.13120941973862,55.177080866665825,55.222952313593034,55.26882376052025,55.31469520744746,55.360566654374665,55.40643810130188,55.45230954822908,55.4981809951563,55.54405244208351,55.58992388901072,55.63579533593793,55.681666782865136,55.72753822979235,55.77340967671956,55.819281123646775,55.86515257057398,55.91102401750119,55.9568954644284,56.002766911355614,56.04863835828283,56.09450980521004,56.140381252137246,56.186252699064454,56.232124145991676,56.27799559291887,56.32386703984608,56.3697384867733,56.41560993370051,56.461481380627724,56.507352827554925,56.55322427448213,56.599095721409356,56.644967168336564,56.69083861526377,56.73671006219098,56.78258150911819,56.82845295604541,56.87432440297261,56.92019584989983,56.966067296827035,57.01193874375424,57.05781019068146,57.103681637608666,57.149553084535874,57.19542453146309,57.2412959783903,57.28716742531751,57.33303887224472,57.37891031917193,57.424781766099144,57.47065321302635,57.51652465995357,57.562396106880776,57.608267553807984,57.6541390007352,57.70001044766241,57.745881894589616,57.791753341516824,57.83762478844403,57.88349623537124,57.92936768229846,57.97523912922567,57.961887158849166,57.88931177116894,57.81673638348873,57.744160995808514,57.67158560812829,57.59901022044808,57.52643483276786,57.453859445087645,57.38128405740742,57.30870866972721,57.23613328204699,57.16355789436677,57.09098250668656,57.01840711900634,56.945831731326116,56.8732563436459,56.80068095596569,56.72810556828547,56.655530180605254,56.56527443511642,56.463578380660486,56.36188232620455,56.26018627174864,56.158490217292695,56.056794162836766,55.95509810838084,55.85340205392492,55.75170599946898,55.65000994501305,55.54831389055713,55.4466178361012,55.344921781645255,55.24322572718934,55.1415296727334,55.03983361827746,54.938137563821535,54.83644150936562,54.73474545490968,54.63304940045376,54.531353345997815,54.4296572915419,54.32796123708596,54.22626518263004,54.1245691281741,54.02287307371817,53.92117701926226,53.81948096480632,53.71778491035038,53.61608885589446,53.51439280143853,53.41269674698259,53.311000692526676,53.20930463807075,53.107608583614805,53.00591252915887,52.90421647470296,52.80252042024702,52.700824365791085,52.599128311335164,52.497432256879236,52.3957362024233,52.29404014796738,52.19234409351145,52.09064803905551,51.98895198459958,51.88725593014367,51.78555987568772,51.68386382123179,51.58216776677587,51.48047171231994,51.378775657864,51.277079603408076,51.175383548952155,51.07368749449621,50.97199144004029,50.870295385584356,50.76859933112843,50.66690327667251,50.56520722221658,50.46351116776064,50.36181511330471,50.26011905884878,50.15842300439285,49.947423175314704,49.51781579699226,49.08820841866981,48.65860104034732,48.22899366202488,47.79938628370243,47.36977890537994,46.94017152705746,46.51056414873504,46.08095677041256,45.65134939209008,45.22174201376763,44.79213463544519,44.36252725712271,43.93291987880025,43.503312500477804,43.07370512215532,42.64409774383287,42.21449036551042,41.784882987187935,41.355275608865455,40.925668230543,40.49606085222056,40.06645347389807,39.63684609557562,39.207238717253176,38.77763133893069,38.348023960608245,37.91841658228579,37.488809203963314,37.05920182564082,36.62959444731842,36.19998706899593,35.770379690673444,35.340772312351,34.91116493402855,34.48155755570606,34.05195017738362,33.62234279906117,33.19273542073868,32.763128042416234,32.33352066409378,31.903913285771303,31.474305907448812,31.044698529126364,30.61509115080392,30.185483772481433,29.75587639415898,29.326269015836537,28.896661637514054,28.467054259191606,28.037446880869155,27.60783950254667,27.178232124224188,26.74862474590178,26.319017367579292,25.889409989256805,25.459802610934357,25.03019523261191,24.600587854289426,24.170980475966978,23.74137309764453,23.311765719322043,22.8821583409996,22.452752043208022,22.02511897125192,21.597485899295812,21.169852827339792,20.742219755383687,20.314586683427585,19.886953611471522,19.45932053951546,19.031687467559358,18.604054395603296,18.176421323647233,17.748788251691128,17.32115517973503,16.893522107779003,16.465889035822904,16.038255963866796,15.610622891910733,15.182989819954674,14.755356747998567,14.374251153810603,14.22578294846284,14.077314743115078,13.928846537767315,13.780737772252756,13.667633999263622,13.554530226274485,13.44142645328537,13.328322680296235,13.2152189073071,13.102115134317984,12.98901136132885,12.875907588339713,12.762803815350576,12.649700042361461,12.536596269372327,12.423492496383192,12.310388723394077,12.19728495040494,12.084181177415804,11.971077404426689,11.857973631437552,11.744869858448418,11.631766085459303,11.518662312470166,11.40555853948103,11.292454766491895,11.17935099350278,11.066247220513644,10.953143447524507,10.840039674535394,10.726935901546257,10.613832128557123,10.500728355568008,10.387624582578871,10.274520809589735,10.161417036600598,10.048313263611483,9.93520949062235,9.822105717633214,9.709001944644099,9.595898171654962,9.482794398665826,9.36969062567671,9.256586852687574,9.14348307969844,9.030379306709325,8.917275533720188,8.804171760731052,8.691067987741917,8.577964214752802,8.464860441763665,8.35175666877453,8.238652895785416,8.12554912279628,8.012445349807145,7.8993415768180295,7.786237803828894,7.673134030839758,7.560030257850622,7.446926484861508,7.3338227118723704,7.220718938883236,7.107615165894121,6.994511392904984,6.88140761991585,6.768303846926734,6.655200073937598,6.542096300948462,6.428992527959347,6.315888754970212,6.202784981981075,6.08968120899194,5.976577436002825,5.863473663013689,5.750369890024554,5.637266117035439,5.524162344046303,5.411058571057167,5.304731652854059,5.234929695210907,5.1651277375677545,5.095325779924602,5.025523822281463],[46.77550918504886,46.824836294079645,46.87416340311043,46.92349051214122,46.97281762117201,47.0221447302028,47.07147183923358,47.120798948264365,47.17012605729515,47.21945316632594,47.26878027535673,47.31810738438752,47.3674344934183,47.416761602449085,47.46608871147988,47.51541582051067,47.564742929541445,47.61407003857224,47.66339714760302,47.712724256633805,47.76205136566459,47.81137847469538,47.860705583726165,47.91003269275696,47.95935980178774,48.008686910818525,48.058014019849324,48.107341128880094,48.15666823791089,48.20599534694168,48.25532245597246,48.304649565003245,48.35397667403403,48.40330378306483,48.45263089209561,48.5019580011264,48.55128511015718,48.600612219187965,48.649939328218764,48.69926643724954,48.748593546280325,48.79792065531112,48.8472477643419,48.896574873372685,48.94590198240347,48.99522909143426,49.04455620046505,49.09388330949584,49.14321041852662,49.192537527557405,49.2418646365882,49.29119174561898,49.34051885464977,49.38984596368056,49.43917307271135,49.488500181742126,49.53782729077292,49.58715439980371,49.63648150883449,49.68580861786528,49.73513572689606,49.78446283592685,49.83378994495764,49.88311705398842,49.93244416301921,49.981771272050004,50.03109838108078,50.08042549011157,50.12975259914236,50.17907970817314,50.22840681720393,50.27773392623472,50.32706103526551,50.376388144296286,50.42571525332708,50.47504236235787,50.52436947138865,50.57369658041944,50.62302368945023,50.67322674907432,50.72360499984865,50.77398325062297,50.8243615013973,50.87473975217163,50.920388335551515,50.96509098545252,51.00979363535352,51.05449628525452,51.09919893515552,51.14346016347137,51.18763310799005,51.23180605250873,51.27597899702741,51.32015194154609,51.364324886064765,51.40849783058344,51.45267077510212,51.496843719620806,51.54101666413948,51.585189608658155,51.62936255317683,51.67353549769552,51.717708442214196,51.76188138673287,51.806054331251545,51.85022727577023,51.89440022028891,51.93857316480758,51.98274610932626,52.02691905384494,52.07109199836362,52.1152649428823,52.159437887400976,52.20361083191966,52.24778377643833,52.29195672095702,52.336129665475696,52.38030260999437,52.424475554513045,52.46864849903173,52.51282144355041,52.556994388069086,52.601167332587764,52.64534027710644,52.68951322162512,52.7336861661438,52.777859110662476,52.822032055181154,52.86620499969983,52.91037794421851,52.95455088873719,52.998723833255866,53.042896777774544,53.08706972229323,53.1312426668119,53.17541561133058,53.219588555849256,53.263761500367934,53.30793444488661,53.3521073894053,53.39628033392397,53.44045327844265,53.48462622296133,53.52879916748001,53.572972111998695,53.61714505651736,53.661318001036044,53.70549094555473,53.74966389007339,53.793836834592085,53.83800977911076,53.882182723629434,53.92635566814812,53.9705286126668,54.014701557185475,54.05887450170415,54.103047446222824,54.14722039074151,54.19139333526018,54.23556627977886,54.27973922429754,54.32391216881622,54.3680851133349,54.41225805785358,54.456431002372256,54.500603946890934,54.54477689140961,54.59011333273475,54.636031522463114,54.68194971219148,54.72786790191984,54.77378609164821,54.81970428137658,54.865586515065964,54.91145796199317,54.95732940892038,55.00320085584759,55.0490723027748,55.09494374970202,55.14081519662923,55.186686643556435,55.23255809048364,55.27842953741086,55.324300984338066,55.37017243126528,55.41604387819249,55.4619153251197,55.507786772046906,55.55365821897412,55.59952966590132,55.64540111282854,55.69127255975575,55.73714400668296,55.78301545361017,55.82888690053738,55.87475834746459,55.92062979439181,55.966501241319015,56.012372688246224,56.05824413517343,56.10411558210065,56.149987029027855,56.19585847595507,56.24172992288228,56.28760136980949,56.333472816736695,56.37934426366391,56.42521571059112,56.471087157518326,56.51695860444554,56.56283005137275,56.608701498299965,56.654572945227166,56.70044439215438,56.746315839081596,56.792187286008804,56.83805873293601,56.88393017986322,56.92980162679043,56.97567307371765,57.021544520644845,57.067415967572074,57.113287414499275,57.159158861426484,57.205030308353706,57.2509017552809,57.29677320220812,57.34264464913533,57.38851609606254,57.43438754298975,57.48025898991696,57.52613043684417,57.572001883771385,57.61787333069859,57.6637447776258,57.70961622455302,57.755487671480225,57.80135911840743,57.84723056533464,57.89310201226186,57.93897345918907,57.98484490611628,58.03071635304349,58.076587799970696,58.12245924689791,58.16833069382512,58.21420214075233,58.260073587679535,58.30594503460675,58.351816481533966,58.309537790945896,58.179108962842555,58.04868013473923,57.91825130663591,57.78782247853256,57.65739365042924,57.526964822325915,57.396535994222575,57.266107166119234,57.15827215676025,57.05652005149182,56.9547679462234,56.853015840954974,56.75126373568655,56.649511630418125,56.54775952514971,56.44600741988128,56.34425531461285,56.242503209344434,56.14075110407602,56.038998998807585,55.93724689353916,55.83549478827074,55.73374268300231,55.63199057773389,55.53023847246547,55.428486367197046,55.32673426192862,55.224982156660204,55.12323005139177,55.021477946123355,54.919725840854916,54.817973735586506,54.71622163031808,54.61446952504965,54.51271741978123,54.41096531451281,54.30921320924438,54.207461103975966,54.10570899870754,54.00395689343911,53.90220478817069,53.800452682902275,53.69870057763384,53.59694847236541,53.495196367096995,53.39344426182858,53.291692156560146,53.18994005129173,53.088187946023304,52.98643584075488,52.88468373548646,52.78293163021803,52.68117952494961,52.57942741968118,52.477675314412764,52.37592320914433,52.274171103875915,52.17241899860748,52.070666893339066,51.968914788070634,51.86716268280222,51.7654105775338,51.66365847226537,51.56190636699695,51.46015426172853,51.358402156460095,51.25665005119168,51.15489794592326,51.05314584065483,50.951393735386404,50.84964163011798,50.747889524849555,50.64613741958114,50.54438531431271,50.44263320904429,50.34088110377587,50.23912899850744,50.13737689323902,50.0356247879706,49.933872682702166,49.83212057743375,49.73036847216533,49.522146820230034,49.10098607496115,48.679825329692264,48.25866458442333,47.837503839154444,47.41634309388556,46.99518234861662,46.574021603347695,46.15286085807885,45.731700112809925,45.310539367541,44.88937862227211,44.46821787700322,44.0470571317343,43.625896386465406,43.20473564119652,42.7799485714739,42.35231549951783,41.92468242756177,41.497049355605675,41.06941628364957,40.6417832116935,40.21415013973744,39.78651706778134,39.35888399582527,38.931250923869214,38.50361785191311,38.07598477995705,37.64835170800099,37.220718636044886,36.79308556408877,36.36545249213275,35.93781942017665,35.51018634822054,35.082553276264484,34.65492020430842,34.22728713235232,33.79965406039626,33.3720209884402,32.9443879164841,32.51675484452803,32.08912177257197,31.661488700615863,31.233855628659757,30.806222556703695,30.378589484747636,29.95095641279153,29.523323340835468,29.0956902688794,28.6680571969233,28.240424124967237,27.812791053011175,27.385157981055073,26.95752490909897,26.529891837142948,26.102258765186843,25.67462569323074,25.24699262127468,24.819359549318612,24.39172647736251,23.96409340540645,23.536460333450385,23.108827261494284,22.681194189538225,22.25356111758216,21.825928045626057,21.398294973669948,20.97066190171393,20.543028829757823,20.11539575780172,19.68776268584566,19.260129613889596,18.832496541933494,18.404863469977432,17.97723039802137,17.549597326065264,17.121964254109166,16.694331182153142,16.26669811019704,15.839065038240935,15.411431966284871,14.983798894328814,14.556165822372707,14.175060228184739,14.026592022836976,13.878123817489216,13.729655612141455,13.581187406793719,13.432719201445957,13.284250996098198,13.135782790750461,12.987314585402702,12.838846380054937,12.690378174707202,12.541909969359441,12.393441764011678,12.244973558663917,12.096505353316184,11.94803714796842,11.79956894262066,11.651100737272925,11.502632531925164,11.354164326577402,11.205696121229668,11.057227915881906,10.908759710534145,10.76029150518641,10.611823299838647,10.463355094490886,10.314886889143121,10.166418683795388,10.04871467669455,9.935610903705411,9.822507130716298,9.709403357727162,9.596299584738025,9.48319581174891,9.370092038759774,9.256988265770637,9.143884492781503,9.030780719792388,8.917676946803253,8.804573173814116,8.691469400825001,8.578365627835867,8.46526185484673,8.352158081857615,8.23905430886848,8.125950535879344,8.012846762890229,7.8997429899010925,7.786639216911957,7.673535443922821,7.560431670933706,7.447327897944571,7.334224124955435,7.22112035196632,7.108016578977184,6.994912805988048,6.89465873756688,6.824856779923728,6.755054822280576,6.685252864637423,6.615450906994285,6.545648949351133,6.47584699170798,6.406045034064841,6.336243076421688,6.266441118778536,6.196639161135398,6.126837203492245,6.057035245849093,5.987233288205953,5.917431330562801,5.847629372919649,5.777827415276498,5.708025457633358,5.638223499990206,5.5684215423470524,5.498619584703913,5.428817627060762,5.35901566941761,5.289213711774471,5.219411754131318,5.149609796488166,5.079807838845014,5.010005881201874],[47.112477434384935,47.16180454341571,47.2111316524465,47.26045876147729,47.30978587050808,47.359112979538864,47.40844008856965,47.45776719760043,47.507094306631224,47.556421415662015,47.6057485246928,47.655075633723584,47.70440274275437,47.75372985178516,47.803056960815944,47.852384069846735,47.90171117887752,47.951038287908304,48.00036539693909,48.04969250596988,48.099019615000664,48.14834672403145,48.19767383306223,48.247000942093024,48.29632805112381,48.34565516015459,48.39498226918539,48.444309378216175,48.49363648724696,48.542963596277744,48.59229070530853,48.64161781433931,48.6909449233701,48.740272032400895,48.78959914143168,48.838926250462464,48.88825335949325,48.93758046852403,48.98690757755483,49.03623468658561,49.08556179561639,49.134888904647184,49.18421601367797,49.23354312270875,49.282870231739544,49.33219734077033,49.38152444980112,49.430851558831904,49.48017866786269,49.52950577689348,49.578832885924264,49.62815999495505,49.67748710398584,49.726814213016624,49.776141322047415,49.82546843107819,49.874795540108984,49.924122649139775,49.97344975817056,50.022776867201344,50.072103976232135,50.12143108526292,50.17110857418867,50.221486824963,50.27186507573734,50.32224332651167,50.372621577286,50.42299982806033,50.473378078834656,50.52375632960899,50.57413458038332,50.624512831157645,50.674891081931975,50.725269332706304,50.775647583480634,50.82602583425496,50.87640408502929,50.92678233580362,50.97716058657796,51.02753883735229,51.07791708812662,51.12829533890095,51.17867358967528,51.22905184044961,51.27470042382949,51.3194030737305,51.364105723631496,51.408808373532494,51.45351102343349,51.49821367333449,51.54291632323549,51.587618973136486,51.632321623037484,51.677024272938496,51.72172692283949,51.76642957274049,51.81113222264149,51.85583487254249,51.900537522443486,51.945240172344484,51.98994282224548,52.03464547214648,52.07934812204748,52.12405077194848,52.16875342184948,52.213279502943905,52.25745244746258,52.301625391981254,52.34579833649993,52.38997128101861,52.43414422553729,52.47831717005596,52.52249011457465,52.56666305909333,52.61083600361201,52.655008948130686,52.699181892649364,52.743354837168035,52.78752778168671,52.8317007262054,52.875873670724076,52.920046615242754,52.96421955976143,53.00839250428011,53.05256544879879,53.096738393317466,53.14091133783615,53.18508428235482,53.2292572268735,53.27343017139218,53.317603115910856,53.36177606042954,53.40594900494821,53.4501219494669,53.49429489398557,53.538467838504246,53.582640783022924,53.62681372754161,53.67098667206028,53.715159616578966,53.75933256109764,53.80350550561632,53.84767845013499,53.89185139465368,53.93602433917236,53.980197283691034,54.02437022820972,54.0685431727284,54.11271611724707,54.15688906176575,54.20106200628443,54.24523495080311,54.28940789532178,54.333580839840465,54.377753784359136,54.421926728877814,54.4660996733965,54.51027261791518,54.55444556243385,54.59861850695253,54.64279145147121,54.68696439598989,54.73113734050857,54.775310285027246,54.819483229545924,54.8636561740646,54.90782911858328,54.95316555990842,54.99908374963679,55.04500193936514,55.09092012909352,55.13683831882188,55.18275650855024,55.22867469827861,55.27459288800697,55.32051107773535,55.36642926746371,55.41234745719207,55.45826564692044,55.5041838366488,55.55010202637717,55.596020216105536,55.641938405833905,55.687856595562266,55.73377478529063,55.779692975018996,55.825611164747365,55.871529354475726,55.917447544204094,55.96336573393245,56.009283923660824,56.05520211338919,56.1011059207113,56.146977367638506,56.192848814565714,56.23872026149293,56.28459170842014,56.33046315534735,56.37633460227456,56.42220604920177,56.468077496128984,56.51394894305619,56.5598203899834,56.60569183691061,56.651563283837824,56.69743473076503,56.74330617769225,56.789177624619455,56.83504907154666,56.88092051847387,56.92679196540109,56.9726634123283,57.01853485925551,57.06440630618272,57.110277753109926,57.156149200037135,57.20202064696436,57.247892093891565,57.29376354081877,57.33963498774598,57.38550643467319,57.43137788160041,57.477249328527606,57.52312077545483,57.568992222382036,57.614863669309244,57.66073511623645,57.706606563163675,57.75247801009087,57.79834945701809,57.8442209039453,57.89009235087251,57.93596379779972,57.98183524472693,58.027706691654146,58.073578138581354,58.11944958550856,58.16532103243577,58.21119247936298,58.25706392629019,58.30293537321741,58.34880682014461,58.394678267071825,58.44054971399903,58.48642116092625,58.532292607853456,58.578164054780665,58.62403550170787,58.66990694863509,58.7157783955623,58.67349970497423,58.54307087687089,58.412642048767566,58.28221322066423,58.1517843925609,58.021355564457565,57.89092673635425,57.76049790825091,57.63006908014757,57.49964025204426,57.36921142394091,57.23878259583758,57.10835376773424,56.97792493963093,56.84749611152759,56.71706728342426,56.58663845532094,56.456209627217596,56.32578079911427,56.19535197101094,56.0649231429076,55.93449431480427,55.80406548670095,55.673636658597616,55.543207830494275,55.412779002390955,55.28235017428762,55.15192134618428,55.02149251808096,54.891063689977635,54.760634861874294,54.63020603377095,54.49977720566764,54.3693483775643,54.23891954946096,54.10849072135764,53.978061893254306,53.848719321157716,53.746967215889285,53.64521511062087,53.543463005352436,53.44171090008402,53.3399587948156,53.23820668954716,53.136454584278745,53.03470247901033,52.932950373741896,52.83119826847347,52.729446163205054,52.62769405793662,52.5259419526682,52.42418984739978,52.322437742131356,52.220685636862925,52.11893353159451,52.01718142632609,51.91542932105766,51.813677215789234,51.711925110520816,51.61017300525239,51.50842089998396,51.40666879471554,51.304916689447126,51.20316458417869,51.10141247891028,50.99966037364185,50.89790826837342,50.79615616310499,50.69440405783658,50.59265195256815,50.49089984729972,50.38914774203131,50.28739563676288,50.18564353149445,50.08389142622604,49.98213932095762,49.88038721568918,49.778635110420765,49.676883005152355,49.575130899883916,49.473378794615485,49.371626689347075,49.26987458407865,49.06165293214336,48.64049218687447,48.21933144160558,47.798170696336655,47.37700995106777,46.95584920579888,46.53468846052995,46.11352771526103,45.69236696999218,45.271206224723244,44.85004547945432,44.42888473418543,44.007723988916545,43.58656324364762,43.165402498378725,42.74424175310985,42.32308100784091,41.901920262572034,41.48075951730314,41.05959877203422,40.638438026765286,40.2172772814964,39.796116536227515,39.37495579095859,38.9537950456897,38.53263430042081,38.11147355515188,37.690312809883,37.269152064614104,36.847991319345184,36.42683057407625,36.0056698288074,35.58450908353848,35.16334833826955,34.742187593000665,34.32102684773177,33.89986610246285,33.47870535719396,33.05754461192507,32.63638386665614,32.215223121387254,31.79406237611836,31.372901630849437,30.951740885580506,30.53058014031162,30.109419395042735,29.688258649773807,29.26709790450492,28.84593715923603,28.424776413967102,28.003615668698217,27.582454923429328,27.1612941781604,26.740133432891472,26.318972687622626,25.897811942353698,25.475434767604874,25.04780169564881,24.62016862369275,24.192535551736643,23.76490247978058,23.337269407824518,22.909636335868413,22.482003263912354,22.054370191956288,21.626737120000186,21.19910404804408,20.77147097608806,20.343837904131956,19.91620483217585,19.48857176021979,19.06093868826373,18.633305616307624,18.205672544351565,17.7780394723955,17.350406400439397,16.922773328483295,16.49514025652727,16.06750718457117,15.639874112615065,15.212241040659002,14.784607968702943,14.356974896746836,13.97586930255887,13.827401097211109,13.678932891863344,13.530464686515584,13.38199648116785,13.233528275820088,13.085060070472327,12.93659186512459,12.788123659776831,12.639655454429068,12.491187249081332,12.34271904373357,12.19425083838581,12.045782633038048,11.897314427690313,11.748846222342552,11.60037801699479,11.451909811647056,11.303441606299295,11.154973400951532,11.006505195603797,10.858036990256036,10.709568784908274,10.561100579560538,10.412632374212777,10.264164168865015,10.115695963517254,9.99673425632633,9.8899223114669,9.783110366607474,9.676298421748067,9.569486476888638,9.462674532029212,9.355862587169803,9.249050642310376,9.14223869745095,9.035426752591519,8.928614807732112,8.821802862872683,8.714990918013257,8.608178973153848,8.501367028294421,8.394555083434993,8.287743138575586,8.180931193716159,8.07411924885673,7.967307303997322,7.860495359137895,7.753683414278466,7.64687146941904,7.5400595245596325,7.433247579700204,7.3264356348407755,7.219623689981368,7.11281174512194,7.005999800262512,6.899187855403104,6.809338838844139,6.739536881200986,6.669734923557835,6.599932965914696,6.530131008271543,6.460329050628391,6.390527092985251,6.320725135342099,6.250923177698947,6.181121220055807,6.111319262412656,6.0415173047695045,5.971715347126365,5.901913389483212,5.83211143184006,5.762309474196908,5.692507516553769,5.622705558910616,5.552903601267463,5.483101643624325,5.413299685981173,5.34349772833802,5.273695770694881,5.203893813051728,5.134091855408577,5.064289897765425,4.994487940122285],[47.44944568372098,47.498772792751765,47.54809990178255,47.59742701081334,47.64675411984413,47.69608122887492,47.7454083379057,47.794735446936485,47.84406255596728,47.89338966499807,47.94271677402885,47.99204388305964,48.04137099209042,48.09069810112121,48.140025210152004,48.18935231918279,48.23867942821357,48.28800653724436,48.33733364627515,48.386660755305925,48.43598786433672,48.48531497336751,48.53464208239829,48.583969191429084,48.63329630045986,48.68262340949065,48.731950518521444,48.78127762755222,48.83060473658301,48.8799318456138,48.92925895464459,48.97858606367537,49.02791317270616,49.07724028173694,49.126567390767725,49.17589449979852,49.22522160882931,49.27454871786009,49.323875826890884,49.37320293592167,49.42253004495245,49.47185715398324,49.52118426301402,49.57051137204481,49.6198384810756,49.66916559010639,49.71936865007735,49.76974690085168,49.820125151626,49.870503402400345,49.92088165317467,49.971259903949004,50.021638154723334,50.072016405497656,50.12239465627199,50.172772907046316,50.22315115782065,50.27352940859498,50.32390765936931,50.37428591014364,50.42466416091796,50.47504241169231,50.52542066246663,50.57579891324096,50.626177164015296,50.676555414789625,50.726933665563955,50.77731191633828,50.82769016711261,50.87806841788694,50.92844666866128,50.97882491943561,51.02920317020993,51.07958142098426,51.12995967175859,51.18033792253292,51.23071617330725,51.28109442408159,51.33147267485592,51.381850925630246,51.432229176404576,51.482607427178905,51.532985677953235,51.583363928727564,51.62901251210745,51.67371516200845,51.71841781190945,51.763120461810445,51.80782311171144,51.85252576161245,51.897228411513446,51.941931061414444,51.98663371131545,52.03133636121645,52.076039011117444,52.12074166101844,52.16544431091945,52.210146960820445,52.25484961072144,52.29955226062244,52.34425491052344,52.38895756042444,52.433660210325435,52.47836286022644,52.52306551012744,52.567768160028436,52.612470809929434,52.65717345983044,52.70187610973144,52.746578759632435,52.79128140953343,52.83598405943443,52.88068670933543,52.925389359236426,52.97009200913743,53.01479465903842,53.059497308939434,53.104199958840425,53.14890260874143,53.19360525864242,53.238307908543426,53.283010558444424,53.327271786935086,53.371444731453764,53.41561767597244,53.45979062049112,53.503963565009805,53.54813650952848,53.59230945404716,53.63648239856584,53.68065534308451,53.724828287603195,53.76900123212187,53.81317417664056,53.85734712115923,53.90152006567791,53.94569301019658,53.98986595471526,54.03403889923394,54.07821184375263,54.122384788271305,54.16655773278998,54.21073067730865,54.25490362182733,54.29907656634602,54.343249510864695,54.38742245538337,54.43159539990205,54.47576834442073,54.51994128893941,54.564114233458085,54.60828717797676,54.65246012249544,54.69663306701412,54.7408060115328,54.784978956051475,54.82915190057015,54.87332484508883,54.91749778960751,54.96167073412619,55.005843678644865,55.05001662316354,55.09418956768222,55.1383625122009,55.18253545671958,55.22670840123826,55.27088134575693,55.316217787082074,55.36213597681044,55.408054166538804,55.453972356267165,55.49989054599554,55.54580873572391,55.591726925452264,55.63764511518063,55.68356330490899,55.72948149463736,55.77539968436572,55.82131787409409,55.86723606382245,55.91315425355082,55.95907244327918,56.00499063300756,56.05090882273592,56.09682701246429,56.14274520219265,56.18866339192102,56.23458158164939,56.28049977137775,56.3264179611061,56.37233615083448,56.41825434056284,56.464172530291215,56.510090720019576,56.55600890974794,56.60192709947631,56.64784528920467,56.693763478933036,56.739681668661405,56.78559985838976,56.831518048118134,56.877436237846496,56.92335442757487,56.96927261730323,57.0151908070316,57.06110899675997,57.107027186488324,57.15294537621669,57.198863565945054,57.24478175567342,57.29069994540179,57.336618135130145,57.382496773283826,57.428368220211034,57.47423966713825,57.52011111406546,57.565982560992666,57.61185400791988,57.65772545484709,57.703596901774304,57.74946834870151,57.79533979562872,57.84121124255593,57.887082689483144,57.93295413641035,57.97882558333757,58.024697030264775,58.07056847719198,58.11643992411919,58.16231137104641,58.208182817973615,58.25405426490083,58.29992571182804,58.345797158755246,58.39166860568246,58.43754005260967,58.483411499536885,58.52928294646409,58.5751543933913,58.62102584031851,58.66689728724572,58.71276873417293,58.75864018110014,58.804511628027356,58.850383074954564,58.89625452188177,58.94212596880898,58.987997415736196,59.03386886266341,59.07974030959062,59.03746161900255,58.907032790899216,58.77660396279589,58.646175134692555,58.51574630658922,58.385317478485895,58.25488865038257,58.124459822279235,57.994030994175894,57.86360216607258,57.73317333796925,57.6027445098659,57.47231568176258,57.34188685365925,57.211458025555906,57.08102919745258,56.95060036934926,56.82017154124592,56.68974271314259,56.55931388503927,56.428885056935925,56.29845622883259,56.16802740072927,56.03759857262594,55.9071697445226,55.776740916419264,55.64631208831594,55.51588326021261,55.38545443210927,55.25502560400595,55.12459677590262,54.994167947799276,54.86373911969596,54.73331029159263,54.60288146348928,54.472452635385956,54.34202380728264,54.211594979179296,54.08116615107596,53.95073732297264,53.820308494869295,53.689879666765975,53.55945083866265,53.42902201055931,53.298593182455974,53.168164354352655,53.037735526249314,52.90730669814598,52.776877870042654,52.64644904193932,52.51602021383599,52.38559138573266,52.25516255762933,52.124733729526,51.99430490142266,51.86387607331935,51.73344724521601,51.603018417112665,51.47258958900933,51.34216076090602,51.21173193280268,51.08130310469935,50.950874276596025,50.820445448492684,50.69001662038936,50.55958779228603,50.43741438028677,50.335662275018336,50.23391016974993,50.1321580644815,50.03040595921307,49.92865385394465,49.826901748676235,49.7251496434078,49.623397538139386,49.52164543287096,49.41989332760253,49.31814122233411,49.21638911706569,49.114637011797264,49.01288490652883,48.911132801260415,48.809380695992,48.6011590440567,48.179998298787815,47.758837553518916,47.33767680825,46.91651606298111,46.495355317712225,46.07419457244329,45.65303382717437,45.23187308190552,44.8107123366366,44.38955159136766,43.96839084609878,43.54723010082989,43.12606935556097,42.70490861029207,42.28374786502319,41.86258711975427,41.441426374485374,41.02026562921649,40.59910488394756,40.17794413867863,39.75678339340974,39.335622648140856,38.91446190287193,38.49330115760304,38.07214041233415,37.65097966706522,37.22981892179634,36.80865817652745,36.387497431258524,35.966336685989596,35.545175940720746,35.124015195451825,34.70285445018289,34.281693704914005,33.86053295964512,33.43937221437619,33.0182114691073,32.597050723838414,32.17588997856949,31.754729233300594,31.33356848803171,30.912407742762777,30.491246997493853,30.070086252224964,29.64892550695608,29.227764761687148,28.806604016418262,28.385443271149374,27.96428252588045,27.54312178061156,27.12196103534267,26.700800290073744,26.279780881977747,25.86158829604967,25.443395710121536,25.02520312419339,24.607010538265286,24.188817952337182,23.770625366409035,23.35243278048093,22.934240194552828,22.51604760862468,22.09785502269658,21.679662436768474,21.26146985084033,20.84327726491219,20.42508467898412,20.00689209305598,19.588699507127835,19.17050692119973,18.752314335271627,18.334121749343485,17.915929163415377,17.497736577487274,17.07954399155913,16.661351405630988,16.24315881970292,15.824966233774777,15.406773647846634,14.98858106191853,14.570388475990425,14.15219589006228,13.780344219197701,13.640197123650461,13.500050028103217,13.359902932555974,13.219755837008758,13.079608741461517,12.939461645914275,12.799314550367058,12.663227536007351,12.556415591147925,12.449603646288516,12.342791701429089,12.235979756569662,12.129167811710232,12.022355866850825,11.915543921991397,11.80873197713197,11.701920032272563,11.595108087413132,11.488296142553706,11.381484197694297,11.274672252834872,11.167860307975442,11.061048363116035,10.954236418256608,10.84742447339718,10.740612528537753,10.633800583678344,10.526988638818917,10.420176693959489,10.313364749100081,10.206552804240653,10.099740859381225,9.992928914521817,9.88611696966239,9.77930502480296,9.672493079943536,9.565681135084127,9.4588691902247,9.352057245365271,9.245245300505863,9.138433355646436,9.031621410787007,8.9248094659276,8.81799752106817,8.711185576208745,8.604373631349336,8.497561686489908,8.390749741630481,8.283937796771054,8.177125851911645,8.070313907052219,7.96350196219279,7.856690017333382,7.749878072473955,7.643066127614528,7.536254182755118,7.4294422378956915,7.322630293036263,7.215818348176835,7.109006403317428,7.002194458458001,6.895382513598572,6.788570568739164,6.681758623879737,6.574946679020309,6.468134734160902,6.361322789301473,6.254510844442046,6.147698899582638,6.040886954723211,5.934075009863783,5.827263065004355,5.720451120144947,5.6136391752855195,5.508650081287764,5.442462505953447,5.376274930619116,5.310087355284786,5.243899779950467,5.177712204616137,5.1115246292818055,5.045337053947476,4.979149478613158],[47.78641393305704,47.835741042087825,47.88506815111861,47.9343952601494,47.983722369180185,48.03304947821097,48.082376587241754,48.131703696272545,48.18103080530333,48.23035791433412,48.279685023364905,48.32901213239569,48.378339241426474,48.427666350457265,48.47699345948806,48.52632056851884,48.575647677549625,48.62497478658042,48.6743018956112,48.72362900464199,48.77295611367277,48.82228322270356,48.871610331734345,48.92093744076513,48.970264549795914,49.019591658826705,49.0689187678575,49.11824587688828,49.167572985919065,49.2172504751917,49.26762872596603,49.31800697674036,49.368385227514686,49.41876347828902,49.469141729063345,49.51951997983768,49.56989823061201,49.62027648138634,49.67065473216067,49.721032982935,49.77141123370933,49.82178948448365,49.87216773525799,49.92254598603232,49.97292423680665,50.02330248758097,50.073680738355314,50.12405898912964,50.174437239903966,50.22481549067831,50.275193741452625,50.32557199222697,50.37595024300129,50.426328493775614,50.47670674454996,50.52708499532427,50.57746324609862,50.62784149687293,50.67821974764727,50.728597998421606,50.77897624919593,50.829354499970265,50.87973275074459,50.93011100151892,50.98048925229325,51.03086750306758,51.08124575384191,51.13162400461624,51.18200225539057,51.2323805061649,51.28275875693923,51.33313700771356,51.38351525848789,51.43389350926222,51.48427176003655,51.534650010810886,51.58502826158521,51.63540651235954,51.68578476313387,51.736163013908204,51.786541264682526,51.836919515456856,51.887297766231185,51.93767601700552,51.98332460038541,52.028027250286414,52.072729900187404,52.11743255008841,52.16213519998941,52.206837849890405,52.2515404997914,52.2962431496924,52.3409457995934,52.3856484494944,52.4303510993954,52.47505374929641,52.5197563991974,52.5644590490984,52.6091616989994,52.6538643489004,52.6985669988014,52.743269648702395,52.7879722986034,52.832674948504405,52.877377598405396,52.9220802483064,52.9667828982074,53.011485548108396,53.056188198009394,53.1008908479104,53.14559349781139,53.190296147712395,53.234998797613386,53.27970144751439,53.32440409741539,53.36910674731639,53.41380939721739,53.45851204711839,53.50321469701939,53.547917346920386,53.59261999682139,53.63732264672238,53.68202529662339,53.72672794652438,53.77143059642538,53.81613324632638,53.860835896227385,53.905538546128376,53.95024119602938,53.99494384593038,54.03964649583138,54.08434914573238,54.12905179563337,54.17375444553438,54.21845709543537,54.26315974533638,54.30786239523737,54.35256504513838,54.397091126407595,54.44126407092628,54.48543701544495,54.529609959963636,54.573782904482314,54.617955849000985,54.66212879351967,54.70630173803834,54.75047468255703,54.794647627075705,54.83882057159438,54.88299351611306,54.92716646063174,54.97133940515042,55.015512349669095,55.05968529418777,55.10385823870646,55.14803118322513,55.19220412774381,55.236377072262485,55.28055001678117,55.32472296129984,55.36889590581852,55.413068850337204,55.457241794855875,55.50141473937455,55.54558768389324,55.589760628411916,55.63393357293059,55.679270014255735,55.725188203984096,55.77110639371246,55.81702458344082,55.862942773169195,55.908860962897556,55.954779152625925,56.000697342354286,56.046615532082654,56.092533721811016,56.13845191153938,56.184370101267746,56.23028829099612,56.27620648072448,56.322124670452844,56.36804286018121,56.413961049909574,56.45987923963794,56.505797429366304,56.55171561909467,56.59763380882305,56.6435519985514,56.68947018827977,56.73538837800814,56.78130656773649,56.82722475746487,56.87314294719323,56.91906113692159,56.96497932664997,57.01089751637833,57.0568157061067,57.10273389583506,57.14865208556341,57.194570275291795,57.24048846502015,57.28640665474852,57.33232484447689,57.378243034205255,57.42416122393362,57.47007941366198,57.515997603390346,57.56191579311871,57.60783398284708,57.65375217257544,57.6996703623038,57.745588552032174,57.791506741760536,57.837424931488904,57.883343121217266,57.92926131094564,57.975179500674,58.021097690402364,58.06701588013074,58.112934069859094,58.15885225958746,58.20477044931583,58.25068863904419,58.29660682877257,58.34252501850092,58.38844320822929,58.43436139795766,58.48027958768603,58.52619777741438,58.57211596714275,58.61801617892915,58.66388762585636,58.70975907278357,58.755630519710785,58.801501966638,58.84737341356521,58.893244860492416,58.939116307419624,58.98498775434683,59.03085920127404,59.07673064820125,59.12260209512847,59.16847354205568,59.21434498898289,59.260216435910095,59.3060878828373,59.35195932976451,59.39783077669173,59.443702223618935,59.40142353303088,59.27099470492753,59.14056587682421,59.010137048720885,58.879708220617545,58.74927939251422,58.61885056441089,58.48842173630755,58.357992908204224,58.2275640801009,58.097135251997564,57.96670642389422,57.8362775957909,57.70584876768757,57.575419939584236,57.4449911114809,57.31456228337758,57.18413345527424,57.053704627170916,56.92327579906758,56.792846970964256,56.66241814286091,56.53198931475759,56.40156048665426,56.27113165855092,56.140702830447594,56.01027400234427,55.87984517424093,55.7494163461376,55.618987518034274,55.48855868993093,55.35812986182761,55.22770103372429,55.09727220562094,54.966843377517606,54.83641454941427,54.70598572131095,54.57555689320762,54.445128065104285,54.314699237000966,54.18427040889762,54.0538415807943,53.923412752690965,53.79298392458763,53.66255509648428,53.53212626838098,53.401697440277644,53.271268612174296,53.14083978407097,53.01041095596765,52.87998212786431,52.74955329976098,52.619124471657656,52.48869564355432,52.35826681545098,52.22783798734767,52.09740915924432,51.96698033114099,51.83586798458509,51.691086052759374,51.54630412093364,51.40152218910793,51.2567402572822,51.111958325456484,50.96717639363076,50.82239446180504,50.677612529979314,50.53283059815358,50.38804866632788,50.24326673450215,50.098484802676424,49.953702870850705,49.808920939024986,49.66413900719925,49.51935707537354,49.37457514354782,49.22979321172209,49.08501127989638,48.94022934807066,48.795447416244926,48.6506654844192,48.50588355259349,48.36110162076777,48.12756612631302,47.71652350660033,47.30548088688766,46.894438267174934,46.48339564746226,46.07235302774958,45.661310408036854,45.250267788324145,44.8392251686115,44.42818254889878,44.017139929186065,43.606097309473384,43.19505468976071,42.784012070047986,42.372969450335304,41.96192683062263,41.550884210909906,41.139841591197225,40.72422191427867,40.30602932835052,39.88783674242238,39.469644156494276,39.05145157056617,38.63325898463803,38.21506639870992,37.796873812781826,37.37868122685367,36.96048864092556,36.542296054997465,36.12410346906932,35.70591088314118,35.28771829721311,34.869525711284965,34.451333125356825,34.03314053942872,33.61494795350062,33.19675536757247,32.77856278164437,32.360370195716264,31.942177609788118,31.523985023860014,31.10579243793191,30.687599852003768,30.269407266075625,29.85121468014752,29.433022094219414,29.014829508291268,28.59663692236317,28.178444336435064,27.760251750506917,27.342059164578817,26.923866578650706,26.505673992722564,26.08748140679442,25.669288820866356,25.25109623493821,24.83290364901007,24.41471106308197,23.99651847715386,23.578325891225717,23.160133305297617,22.741940719369506,22.32374813344137,21.905555547513266,21.487362961585156,21.069170375657016,20.65097778972887,20.232785203800802,19.814592617872663,19.396400031944516,18.978207446016416,18.56001486008831,18.141822274160166,17.723629688232062,17.305437102303955,16.887244516375812,16.46905193044767,16.0508593445196,15.63266675859146,15.214474172663316,14.796281586735214,14.378089000807108,13.959896414878964,13.588044744014383,13.447897648467142,13.307750552919899,13.167603457372655,13.02745636182544,12.887309266278198,12.747162170730956,12.607015075183739,12.466867979636497,12.326720884089255,12.18657378854204,12.046426692994798,11.906279597447556,11.766132501900312,11.625985406353097,11.485838310805853,11.345691215258613,11.205544119711396,11.065397024164152,10.92524992861691,10.785102833069695,10.644955737522453,10.504808641975211,10.364661546427996,10.224514450880754,10.08436735533351,9.944220259786269,9.804073164239053,9.663926068691811,9.52377897314457,9.383631877597352,9.24348478205011,9.103337686502869,8.989687805274473,8.882875860415046,8.776063915555618,8.66925197069619,8.562440025836782,8.455628080977355,8.348816136117927,8.24200419125852,8.135192246399091,8.028380301539665,7.921568356680256,7.814756411820829,7.707944466961401,7.601132522101992,7.494320577242565,7.387508632383137,7.28069668752371,7.173884742664302,7.082176677345652,7.015989102011322,6.949801526677004,6.8836139513426735,6.817426376008342,6.751238800674025,6.685051225339693,6.618863650005364,6.552676074671034,6.486488499336716,6.420300924002386,6.354113348668054,6.287925773333736,6.221738197999406,6.155550622665075,6.089363047330757,6.023175471996426,5.956987896662096,5.890800321327777,5.824612745993448,5.758425170659117,5.692237595324787,5.626050019990469,5.559862444656138,5.493674869321809,5.42748729398749,5.361299718653159,5.295112143318828,5.22892456798451,5.1627369926501805,5.096549417315849,5.030361841981519,4.964174266647201],[48.12338218239311,48.1727092914239,48.22203640045468,48.27136350948547,48.32069061851626,48.370017727547044,48.41934483657783,48.46867194560861,48.517999054639404,48.567326163670195,48.61665327270098,48.665980381731764,48.71530749076255,48.765510551080396,48.815888801854726,48.866267052629055,48.916645303403385,48.967023554177715,49.017401804952044,49.067780055726374,49.1181583065007,49.16853655727504,49.21891480804936,49.2692930588237,49.31967130959803,49.37004956037235,49.42042781114669,49.47080606192102,49.52118431269534,49.57156256346967,49.621940814244006,49.67231906501833,49.722697315792665,49.773075566567,49.823453817341324,49.87383206811566,49.92421031888998,49.97458856966431,50.02496682043864,50.07534507121298,50.12572332198731,50.17610157276164,50.22647982353597,50.2768580743103,50.32723632508463,50.37761457585895,50.427992826633286,50.478371077407616,50.528749328181945,50.579127578956275,50.629505829730604,50.679884080504934,50.73026233127926,50.78064058205359,50.83101883282792,50.88139708360225,50.93177533437659,50.98215358515091,51.03253183592524,51.082910086699584,51.1332883374739,51.18366658824824,51.234044839022566,51.28442308979689,51.33480134057123,51.38517959134556,51.43555784211989,51.48593609289422,51.53631434366855,51.58669259444288,51.63707084521721,51.68744909599153,51.73782734676587,51.7882055975402,51.83858384831453,51.88896209908886,51.93934034986319,51.98971860063752,52.040096851411846,52.090475102186176,52.14085335296051,52.191231603734835,52.24160985450917,52.2919881052835,52.33763668866339,52.38233933856439,52.42704198846538,52.47174463836639,52.516447288267386,52.561149938168384,52.60585258806938,52.65055523797038,52.69525788787138,52.739960537772376,52.78466318767338,52.82936583757437,52.874068487475384,52.91877113737637,52.96347378727738,53.00817643717838,53.052879087079376,53.09758173698037,53.14228438688138,53.18698703678238,53.23168968668337,53.27639233658437,53.32109498648537,53.36579763638637,53.41050028628737,53.45520293618837,53.49990558608937,53.54460823599037,53.589310885891365,53.63401353579236,53.67871618569336,53.72341883559436,53.768121485495364,53.81282413539636,53.85752678529736,53.902229435198365,53.94693208509936,53.99163473500036,54.03633738490136,54.081040034802356,54.125742684703354,54.17044533460436,54.21514798450536,54.25985063440636,54.30455328430736,54.34925593420836,54.393958584109356,54.438661234010354,54.48336388391136,54.52806653381236,54.572769183713355,54.61747183361435,54.66217448351535,54.706877133416356,54.751579783317354,54.79628243321835,54.84098508311935,54.88568773302035,54.930390382921345,54.97509303282234,55.019795682723355,55.064498332624346,55.10920098252535,55.15390363242635,55.19860628232735,55.243308932228345,55.28801158212934,55.33271423203034,55.377416881931346,55.422119531832344,55.46682218173334,55.511083410398804,55.55525635491748,55.59942929943617,55.64360224395484,55.687775188473516,55.731948132992194,55.77612107751088,55.82029402202956,55.86446696654823,55.90863991106691,55.95281285558559,55.99698580010426,56.042322241429396,56.08824043115777,56.13415862088613,56.180076810614494,56.22599500034286,56.271913190071224,56.317831379799586,56.363749569527954,56.40966775925633,56.455585948984684,56.50150413871306,56.547422328441414,56.59334051816979,56.63925870789815,56.68517689762652,56.73109508735489,56.77701327708324,56.82293146681161,56.86884965653998,56.91476784626835,56.9606860359967,57.00660422572507,57.05252241545344,57.09844060518181,57.14435879491017,57.19027698463853,57.2361951743669,57.28211336409526,57.328031553823635,57.373949743552,57.419867933280365,57.465786123008726,57.511704312737095,57.55762250246546,57.60354069219382,57.649458881922186,57.695377071650555,57.741295261378916,57.78721345110728,57.83313164083565,57.879049830564014,57.92496802029238,57.97088621002075,58.01680439974912,58.06272258947749,58.10864077920586,58.15455896893421,58.20047715866258,58.246395348390934,58.2923135381193,58.33823172784767,58.38414991757604,58.4300681073044,58.47598629703276,58.52190448676113,58.56782267648949,58.61374086621787,58.65965905594623,58.70557724567459,58.751495435402965,58.79741362513133,58.843331814859695,58.889250004588064,58.935168194316425,58.98108638404478,59.027004573773155,59.07292276350152,59.11884095322989,59.164759142958246,59.210677332686615,59.256595522414976,59.30251371214334,59.348431901871706,59.39435009160007,59.44026828132844,59.486186471056804,59.53210466078517,59.57802285051354,59.6239410402419,59.669859229970264,59.7156624816768,59.76141976048828,59.80717703929975,59.749525580919766,59.588465385348314,59.44301440245627,59.29823247063055,59.15345053880482,59.00866860697911,58.86388667515339,58.71910474332766,58.57432281150193,58.429540879676225,58.2847589478505,58.13997701602476,57.99519508419905,57.850413152373335,57.7056312205476,57.56084928872188,57.416067356896164,57.271285425070445,57.126503493244726,56.98172156141901,56.836939629593275,56.69215769776755,56.547375765941844,56.40259383411612,56.25781190229038,56.113029970464666,55.968248038638954,55.82346610681322,55.6786841749875,55.53390224316179,55.38912031133605,55.244338379510324,55.09955644768462,54.954774515858894,54.80999258403316,54.66521065220744,54.52042872038173,54.37564678855601,54.23086485673029,54.08608292490456,53.94130099307884,53.79651906125312,53.6517371294274,53.50695519760168,53.36217326577594,53.217391333950246,53.07260940212451,52.92782747029878,52.78304553847306,52.63826360664734,52.493481674821616,52.348699742995905,52.203917811170186,52.05913587934445,51.91435394751873,51.769572015693015,51.624790083867296,51.48000815204156,51.335226220215844,51.190444288390125,51.04566235656439,50.90088042473867,50.75609849291296,50.611316561087236,50.46653462926152,50.321752697435805,50.17697076561007,50.03218883378434,49.887406901958634,49.74262497013291,49.59784303830718,49.453061106481464,49.308279174655745,49.16349724283001,49.0187153110043,48.87393337917859,48.72915144735285,48.584369515527136,48.43958758370142,48.294805651875684,48.15002372004996,48.00524178822424,47.86045985639852,47.62692436194378,47.2158817422311,46.804839122518416,46.39379650280569,45.98275388309301,45.57171126338034,45.16066864366762,44.7496260239549,44.33858340424226,43.92754078452954,43.516498164816824,43.10545554510415,42.69441292539146,42.283370305678744,41.87232768596606,41.46128506625338,41.050242446540665,40.63919982682799,40.2281572071153,39.817114587402585,39.40607196768986,38.99502934797718,38.583986728264506,38.17294410855179,37.76190148883911,37.35085886912643,36.93981624941371,36.52877362970103,36.11773100998835,35.70668839027563,35.29564577056291,34.88460315085027,34.47356053113755,34.062517911424834,33.65147529171215,33.24043267199947,32.829390052286755,32.41834743257407,32.00730481286139,31.596262193148675,31.185219573435994,30.774176953723313,30.363134334010596,29.95209171429788,29.541049094585198,29.13000647487252,28.7189638551598,28.307921235447118,27.896878615734437,27.485835996021724,27.074793376309042,26.663750756596357,26.25270813688364,25.841665517170927,25.430622897458285,25.019580277745565,24.608537658032844,24.197495038320167,23.78645241860749,23.37540979889477,22.964367179182087,22.549641244186184,22.131448658258037,21.71325607232994,21.29506348640183,20.876870900473687,20.458678314545544,20.040485728617476,19.622293142689333,19.20410055676119,18.785907970833094,18.367715384904983,17.949522798976837,17.531330213048737,17.11313762712063,16.694945041192486,16.276752455264344,15.858559869336277,15.440367283408134,15.02217469747999,14.603982111551888,14.18578952562378,13.767596939695634,13.395745268831059,13.255598173283815,13.115451077736573,12.975303982189331,12.835156886642114,12.695009791094872,12.55486269554763,12.414715600000413,12.274568504453171,12.13442140890593,11.994274313358712,11.85412721781147,11.713980122264228,11.573833026716986,11.43368593116977,11.29353883562253,11.153391740075287,11.013244644528069,10.873097548980827,10.74305541118996,10.642317815207424,10.54158021922487,10.440842623242318,10.340105027259783,10.239367431277229,10.138629835294674,10.037892239312121,9.937154643329587,9.836417047347034,9.73567945136448,9.634941855381946,9.534204259399392,9.433466663416837,9.332729067434302,9.231991471451748,9.131253875469195,9.03051627948664,8.929778683504107,8.829041087521553,8.728303491538998,8.627565895556463,8.52682829957391,8.426090703591356,8.325353107608821,8.224615511626267,8.123877915643714,8.023140319661179,7.9224027236786245,7.821665127696072,7.720927531713517,7.620189935730984,7.51945233974843,7.418714743765876,7.317977147783341,7.2172395518007875,7.116501955818233,7.015764359835698,6.915026763853144,6.814289167870591,6.713551571888037,6.612813975905501,6.512076379922949,6.411338783940395,6.310601187957859,6.2098635919753065,6.140575410699118,6.074387835364799,6.008200260030469,5.942012684696138,5.87582510936182,5.809637534027491,5.74344995869316,5.67726238335883,5.611074808024512,5.544887232690181,5.47869965735585,5.412512082021532,5.346324506687202,5.280136931352871,5.213949356018552,5.147761780684222,5.081574205349892,5.015386630015562,4.949199054681244],[48.45743858355185,48.50862337348658,48.55980816342131,48.61099295335604,48.66217774329077,48.712824840457685,48.76320309123201,48.813581342006344,48.863959592780674,48.91433784355501,48.96471609432933,49.01509434510366,49.06547259587799,49.11585084665232,49.16622909742665,49.21660734820098,49.26698559897532,49.31736384974965,49.36774210052398,49.418120351298306,49.46849860207263,49.518876852846965,49.56925510362129,49.61963335439563,49.67001160516996,49.72038985594428,49.77076810671861,49.82114635749294,49.87152460826727,49.9219028590416,49.97228110981594,50.02265936059027,50.0730376113646,50.12341586213893,50.17379411291326,50.224172363687586,50.274550614461916,50.324928865236245,50.375307116010575,50.425685366784904,50.476063617559234,50.52644186833356,50.57682011910789,50.62719836988222,50.67757662065655,50.72795487143088,50.77833312220522,50.82871137297954,50.87908962375387,50.92946787452821,50.97984612530254,51.030224376076866,51.080602626851196,51.130980877625525,51.18135912839986,51.231737379174184,51.28211562994852,51.33249388072284,51.38287213149717,51.43325038227151,51.48362863304583,51.534006883820176,51.5843851345945,51.63476338536882,51.68514163614316,51.73551988691749,51.78589813769182,51.836276388466146,51.886654639240476,51.937032890014805,51.98741114078914,52.03778939156347,52.0881676423378,52.13854589311213,52.18892414388646,52.23930239466079,52.28968064543511,52.34005889620944,52.39043714698378,52.44081539775811,52.49119364853244,52.54157189930677,52.5919501500811,52.642328400855426,52.688286020016704,52.73335951285539,52.778433005694055,52.82350649853274,52.868394569905234,52.91309721980623,52.95779986970723,53.00250251960823,53.047205169509226,53.091907819410224,53.13661046931123,53.18131311921222,53.22601576911323,53.27071841901422,53.31542106891523,53.360123718816226,53.404826368717224,53.44952901861823,53.49423166851923,53.538934318420225,53.58363696832122,53.62833961822222,53.67304226812322,53.717744918024216,53.76244756792522,53.80715021782622,53.85185286772722,53.896555517628215,53.94125816752921,53.98596081743021,54.030663467331216,54.07536611723222,54.120068767133205,54.16477141703421,54.209474066935215,54.25417671683621,54.29887936673721,54.34358201663821,54.38828466653921,54.43298731644021,54.4776899663412,54.5223926162422,54.567095266143205,54.61179791604421,54.65650056594521,54.701203215846206,54.745905865747204,54.7906085156482,54.8353111655492,54.8800138154502,54.9247164653512,54.9694191152522,55.0141217651532,55.0588244150542,55.1035270649552,55.1482297148562,55.1929323647572,55.237635014658196,55.28233766455919,55.32704031446019,55.37174296436119,55.41644561426219,55.46114826416319,55.5058509140642,55.55055356396519,55.59525621386619,55.63995886376719,55.68466151366819,55.72936416356919,55.774066813470185,55.81876946337119,55.86347211327219,55.908174763173186,55.952877413074184,55.99758006297518,56.04228271287619,56.086985362777185,56.13168801267819,56.17639066257919,56.221093312480185,56.26579596238118,56.31049861228218,56.35520126218318,56.400615353059166,56.44638516442264,56.49215497578612,56.5379247871496,56.58369459851308,56.62946440987656,56.67522873824866,56.720986017060135,56.76674329587161,56.812500574683085,56.858257853494564,56.90401513230603,56.94977241111751,56.995529689928986,57.041286968740444,57.08704424755193,57.1328015263634,57.178558805174866,57.22431608398635,57.27007336279782,57.315830641609296,57.361587920420774,57.407345199232246,57.45310247804372,57.49885975685519,57.54461703566667,57.59037431447814,57.63613159328961,57.68188887210109,57.727646150912555,57.773403429724034,57.819160708535506,57.864917987346985,57.91067526615845,57.95643254496993,58.0021898237814,58.04794710259288,58.09370438140435,58.13946166021583,58.185218939027294,58.23097621783877,58.27673349665025,58.32249077546173,58.368248054273195,58.414005333084674,58.45976261189614,58.50551989070762,58.551277169519096,58.59703444833056,58.64279172714204,58.68854900595352,58.73430628476498,58.78006356357646,58.82582084238794,58.871578121199406,58.917335400010884,58.963092678822356,59.008849957633835,59.05460723644531,59.10036451525678,59.14612179406825,59.19187907287972,59.23763635169121,59.28339363050267,59.32915090931415,59.37490818812562,59.420665466937095,59.466422745748574,59.51218002456005,59.55793730337152,59.603694582182996,59.64945186099447,59.69520913980594,59.74096641861742,59.78672369742888,59.83248097624036,59.87823825505183,59.923995533863305,59.96975281267478,60.01551009148625,60.06126737029773,60.107024649109206,60.15278192792068,60.09513046954069,59.93407027396924,59.7730100783978,59.61194988282636,59.450889687254914,59.28982949168348,59.12876929611203,58.96770910054059,58.80664890496913,58.645588709397714,58.48452851382626,58.32346831825481,58.162408122683374,58.00134792711193,57.84028773154048,57.67922753596905,57.51816734039761,57.35710714482615,57.196046949254715,57.034986753683285,56.87392655811183,56.71286636254038,56.55180616696896,56.39074597139751,56.22968577582605,56.06862558025462,55.90756538468318,55.74650518911172,55.58544499354029,55.424384797968855,55.263324602397404,55.10226440682595,54.94120421125453,54.78014401568308,54.619083820111626,54.45802362454019,54.29696342896875,54.13590323339729,53.97484303782586,53.81378284225442,53.65272264668297,53.49166245111154,53.3306022555401,53.169542059968634,53.00848186439719,52.847421668825774,52.686361473254316,52.525301277682864,52.36424108211143,52.20318088653998,52.04212069096854,51.88106049539711,51.720000299825664,51.558940104254205,51.4137121831495,51.26893025132379,51.12414831949807,50.97936638767234,50.834584455846624,50.689802524020905,50.54502059219517,50.40023866036946,50.255456728543734,50.11067479671801,49.96589286489229,49.82111093306658,49.676329001240845,49.53154706941511,49.38676513758941,49.24198320576368,49.097201273937955,48.952419342112236,48.80763741028652,48.66285547846079,48.51807354663507,48.37329161480936,48.22850968298362,48.08372775115791,47.93894581933219,47.79416388750647,47.64938195568073,47.50460002385501,47.35981809202929,47.12628259757455,46.71523997786187,46.30419735814919,45.89315473843647,45.48211211872379,45.07106949901112,44.66002687929839,44.248984259585676,43.83794163987304,43.42689902016032,43.015856400447596,42.604813780734915,42.19377116102224,41.782728541309524,41.371685921596836,40.960643301884154,40.549600682171445,40.138558062458756,39.72751544274608,39.316472823033365,38.90543020332064,38.49438758360796,38.08334496389528,37.67230234418257,37.26125972446988,36.8502171047572,36.43917448504449,36.0281318653318,35.61708924561913,35.20604662590641,34.795004006193686,34.38396138648104,33.97291876676833,33.56187614705561,33.150833527342925,32.73979090763025,32.32874828791753,31.917705668204853,31.50666304849217,31.09562042877945,30.684577809066766,30.273535189354092,29.862492569641375,29.451449949928655,29.04040733021597,28.630390396863298,28.223339661455164,27.816288926047076,27.40923819063898,27.00218745523085,26.595136719822754,26.188085984414663,25.781035249006532,25.373984513598398,24.966933778190345,24.55988304278221,24.152832307374084,23.74578157196599,23.338730836557893,22.93168010114977,22.524629365741674,22.11757863033358,21.71052789492545,21.303477159517353,20.896426424109258,20.48937568870113,20.082324953292996,19.67527421788494,19.268223482476813,18.861172747068682,18.454122011660587,18.04707127625249,17.64002054084436,17.23296980543627,16.825919070028178,16.418868334620043,16.011817599211916,15.604766863803858,15.197716128395726,14.790665392987597,14.383614657579502,13.97656392217141,13.569513186763276,13.208301791359608,13.076287095977795,12.944272400595981,12.81225770521417,12.680243009832381,12.54822831445057,12.41621361906876,12.28419892368697,12.15218422830516,12.020169532923347,11.88815483754156,11.756140142159747,11.624125446777935,11.517540984611909,11.416803388629374,11.31606579264682,11.215328196664267,11.114590600681732,11.013853004699177,10.913115408716623,10.812377812734088,10.711640216751535,10.61090262076898,10.510165024786446,10.409427428803893,10.308689832821338,10.207952236838784,10.10721464085625,10.006477044873698,9.905739448891143,9.805001852908607,9.704264256926054,9.6035266609435,9.502789064960965,9.402051468978412,9.301313872995857,9.200576277013305,9.09983868103077,8.999101085048217,8.898363489065662,8.797625893083127,8.696888297100573,8.59615070111802,8.495413105135484,8.39467550915293,8.293937913170378,8.193200317187843,8.092462721205289,7.991725125222735,7.890987529240181,7.7902499332576465,7.689512337275093,7.588774741292539,7.488037145310004,7.387299549327451,7.286561953344896,7.185824357362361,7.085086761379808,6.984349165397254,6.8836115694147,6.7828739734321655,6.682136377449612,6.581398781467058,6.480661185484523,6.37992358950197,6.279185993519416,6.178448397536881,6.077710801554327,5.976973205571773,5.876235609589239,5.7754980136066845,5.68817085306883,5.625358238092113,5.56254562311541,5.499733008138693,5.4369203931619765,5.374107778185271,5.311295163208555,5.248482548231838,5.1856699332551335,5.122857318278417,5.0600447033017,4.997232088324983,4.934419473348278],[48.783319410889455,48.834504200824185,48.885688990758915,48.93687378069364,48.988058570628375,49.0392433605631,49.09042815049783,49.14161294043256,49.192797730367296,49.24398252030202,49.29516731023675,49.34635210017148,49.39753689010621,49.44872168004094,49.49990646997567,49.55109125991039,49.60227604984513,49.653460839779854,49.70464562971459,49.755830419649314,49.807015209584044,49.85806557646424,49.908443827238564,49.9588220780129,50.00920032878723,50.05957857956155,50.10995683033589,50.16033508111022,50.21071333188455,50.26109158265888,50.31146983343321,50.36184808420754,50.41222633498187,50.462604585756196,50.512982836530526,50.563361087304855,50.613739338079185,50.664117588853514,50.714495839627844,50.764874090402174,50.8152523411765,50.86563059195083,50.91600884272517,50.9663870934995,51.01676534427383,51.06714359504815,51.117521845822495,51.16790009659682,51.21827834737115,51.26865659814549,51.319034848919806,51.36941309969414,51.41979135046847,51.4701696012428,51.52054785201714,51.57092610279146,51.6213043535658,51.67168260434012,51.72206085511445,51.772439105888786,51.82281735666311,51.873195607437445,51.92357385821177,51.9739521089861,52.02433035976043,52.074708610534756,52.125086861309086,52.175465112083415,52.22584336285775,52.27622161363208,52.32659986440641,52.37697811518074,52.42735636595507,52.4777346167294,52.52811286750373,52.57849111827806,52.62886936905239,52.679247619826725,52.729625870601055,52.780004121375384,52.830382372149714,52.880760622924036,52.931138873698366,52.981517124472695,53.02747474363399,53.07254823647266,53.11762172931133,53.16269522215001,53.20776871498869,53.252842207827356,53.29791570066604,53.34298919350471,53.38806268634338,53.43313617918206,53.47820967202073,53.52328316485941,53.568356657698075,53.61343015053676,53.65850364337543,53.70357713621411,53.74865062905278,53.79372412189145,53.838797614730126,53.8838711075688,53.928944600407476,53.97364725037232,54.01834990027332,54.06305255017432,54.10775520007532,54.152457849976315,54.19716049987732,54.24186314977832,54.286565799679316,54.33126844958032,54.37597109948132,54.42067374938232,54.465376399283315,54.51007904918431,54.55478169908531,54.59948434898631,54.64418699888732,54.68888964878831,54.73359229868931,54.778294948590315,54.822997598491305,54.86770024839231,54.91240289829331,54.957105548194306,55.001808198095304,55.0465108479963,55.0912134978973,55.13591614779831,55.18061879769931,55.22532144760031,55.270024097501306,55.314726747402304,55.3594293973033,55.4041320472043,55.4488346971053,55.4935373470063,55.53823999690731,55.582942646808306,55.6276452967093,55.6723479466103,55.7170505965113,55.7617532464123,55.806455896313295,55.8511585462143,55.89586119611529,55.940563846016296,55.985266495917294,56.02996914581829,56.0746717957193,56.11937444562029,56.16407709552129,56.20877974542229,56.25348239532329,56.29818504522429,56.342887695125285,56.38759034502628,56.432292994927295,56.47699564482829,56.52169829472929,56.56640094463029,56.611103594531286,56.655806244432284,56.70050889433328,56.74592298520927,56.79169279657274,56.837462607936224,56.8832324192997,56.92900223066319,56.97477204202666,57.02054185339014,57.06631166475361,57.1120814761171,57.15785128748057,57.20362109884405,57.249390910207524,57.29516072157101,57.34093053293448,57.386700344297964,57.43247015566144,57.47823996702492,57.5240097783884,57.569779589751874,57.61554940111536,57.66131921247883,57.707089023842315,57.752858835205785,57.79862864656927,57.84439845793274,57.89016826929622,57.9359380806597,57.98170789202317,58.02747770338666,58.073247514750136,58.11900831834496,58.16476559715643,58.210522875967904,58.256280154779375,58.30203743359085,58.347794712402326,58.393551991213805,58.43930927002528,58.48506654883675,58.53082382764822,58.5765811064597,58.62233838527118,58.66809566408265,58.71385294289412,58.75961022170559,58.805367500517065,58.85112477932854,58.896882058140015,58.94263933695149,58.98839661576296,59.03415389457444,59.07991117338591,59.12566845219739,59.17142573100885,59.21718300982033,59.26294028863181,59.30869756744328,59.354454846254754,59.40021212506623,59.4459694038777,59.491726682689176,59.537483961500655,59.58324124031213,59.628998519123606,59.67475579793506,59.72051307674654,59.76627035555802,59.8120276343695,59.857784913180964,59.903542191992436,59.949299470803915,59.995056749615394,60.040814028426865,60.086571307238344,60.1323285860498,60.17808586486128,60.22384314367276,60.26960042248423,60.31535770129571,60.361114980107175,60.40687225891865,60.45262953773013,60.498386816541604,60.44073535816161,60.279675162590166,60.11861496701872,59.95755477144729,59.79649457587583,59.63543438030439,59.47437418473296,59.31331398916151,59.152253793590056,58.99119359801864,58.83013340244718,58.66907320687574,58.50801301130429,58.346952815732855,58.18589262016141,58.024832424589974,57.86377222901853,57.702712033447085,57.54165183787565,57.3805916423042,57.21953144673275,57.05847125116131,56.897411055589885,56.73635086001843,56.57529066444698,56.414230468875544,56.25317027330411,56.09211007773265,55.93104988216122,55.76998968658978,55.60892949101832,55.447869295446864,55.286809099875455,55.12574890430399,54.964688708732545,54.803628513161115,54.64256831758967,54.48150812201822,54.32044792644679,54.15938773087535,53.99832753530389,53.83726733973245,53.67620714416102,53.51514694858956,53.35408675301811,53.1930265574467,53.031966361875234,52.87090616630378,52.70984597073235,52.54878577516091,52.38772557958946,52.22666538401803,52.06560518844658,51.90454499287514,51.74348479730369,51.58242460173226,51.421364406160805,51.26030421058936,51.099244015017916,50.938183819446486,50.77712362387503,50.6160634283036,50.45500323273215,50.29394303716071,50.13288284158927,49.971822646017834,49.810762450446376,49.649702254874924,49.48864205930351,49.32758186373206,49.14671812184349,48.95756449114948,48.768410860455475,48.57925722976145,48.39010359906744,48.200949968373436,48.01179633767941,47.82264270698539,47.63348907629138,47.44433544559736,47.25518181490334,47.06602818420932,46.87687455351532,46.6175608113882,46.217926846395,45.8182928814018,45.41865891640856,45.01902495141537,44.619390986422175,44.21975702142893,43.820123056435705,43.42048909144253,43.020855126449305,42.62122116145607,42.22158719646286,41.821953231469664,41.42231926647643,41.022685301483236,40.623051336490036,40.2234173714968,39.823783406503594,39.4241494415104,39.02451547651716,38.62162536066539,38.2145746252573,37.8075238898492,37.40047315444107,36.99342241903298,36.58637168362488,36.17932094821675,35.77227021280866,35.36521947740056,34.95816874199244,34.551118006584296,34.14406727117624,33.73701653576812,33.329965800359986,32.92291506495189,32.5158643295438,32.10881359413567,31.70176285872757,31.294712123319478,30.887661387911347,30.48061065250326,30.073559917095164,29.66650918168703,29.2594584462789,28.852407710870807,28.445356975462712,28.03830624005458,27.631255504646486,27.224204769238394,26.817154033830267,26.410103298422168,26.003052563014077,25.596001827605946,25.18895109219781,24.781900356789762,24.374849621381628,23.967798885973494,23.56074815056541,23.15369741515731,22.74664667974918,22.339595944341088,21.93254520893299,21.525494473524866,21.11844373811677,20.71139300270867,20.304342267300548,19.897291531892414,19.49024079648436,19.08319006107623,18.676139325668096,18.269088590259997,17.86203785485191,17.454987119443775,17.047936384035687,16.640885648627588,16.233834913219457,15.826784177811332,15.41973344240327,15.012682706995138,14.605631971587016,14.198581236178914,13.79153050077083,13.384479765362693,13.02326836995902,12.89125367457721,12.759238979195397,12.627224283813586,12.495209588431798,12.363194893049986,12.231180197668174,12.099165502286386,11.967150806904574,11.835136111522761,11.703121416140974,11.571106720759165,11.439092025377349,11.307077329995538,11.175062634613752,11.04304793923194,10.911033243850127,10.77901854846834,10.647003853086527,10.514989157704715,10.382974462322927,10.250959766941115,10.118945071559304,9.986930376177515,9.854915680795706,9.722900985413892,9.590886290032081,9.458871594650294,9.326856899268481,9.194842203886669,9.062827508504881,8.930812813123069,8.798798117741256,8.666783422359469,8.534768726977658,8.402754031595846,8.270739336214033,8.138724640832246,8.012063611221853,7.9113260152392995,7.810588419256764,7.70985082327421,7.609113227291656,7.5083756313091214,7.407638035326567,7.306900439344014,7.243917078378842,7.181104463402125,7.118291848425408,7.0554792334486915,6.992666618471988,6.929854003495271,6.867041388518555,6.804228773541849,6.741416158565133,6.678603543588416,6.615790928611712,6.552978313634995,6.490165698658278,6.427353083681561,6.364540468704856,6.30172785372814,6.238915238751424,6.176102623774719,6.1132900087980016,6.050477393821286,5.987664778844581,5.924852163867864,5.862039548891147,5.799226933914443,5.736414318937726,5.67360170396101,5.610789088984293,5.547976474007588,5.485163859030871,5.4223512440541555,5.35953862907745,5.2967260141007335,5.233913399124017,5.1711007841473124,5.108288169170596,5.045475554193879,4.982662939217162,4.919850324240458],[49.10920023822705,49.16038502816178,49.211569818096514,49.26275460803124,49.313939397965974,49.3651241879007,49.41630897783543,49.46749376777016,49.518678557704895,49.56986334763962,49.62104813757434,49.67223292750908,49.7234177174438,49.77460250737854,49.82578729731327,49.87697208724799,49.92815687718272,49.97934166711745,50.03052645705218,50.08171124698691,50.13289603692164,50.18408082685637,50.235265616791104,50.286450406725834,50.33763519666056,50.388819986595294,50.44000477653002,50.491189566464755,50.54237435639948,50.593559146334215,50.64474393626894,50.695928726203675,50.7471135161384,50.798298306073136,50.84948309600786,50.90066788594259,50.95185267587732,51.00303746581204,51.05368456324512,51.10406281401946,51.15444106479379,51.204819315568116,51.255197566342446,51.305575817116775,51.355954067891105,51.40633231866543,51.456710569439764,51.507088820214086,51.557467070988416,51.60784532176275,51.65822357253708,51.70860182331141,51.75898007408574,51.80935832486007,51.85973657563441,51.91011482640873,51.96049307718307,52.01087132795739,52.06124957873172,52.111627829506055,52.16200608028038,52.212384331054714,52.26276258182904,52.31314083260337,52.36351908337771,52.41389733415204,52.46427558492636,52.51465383570069,52.56503208647503,52.61541033724936,52.66578858802369,52.71616683879802,52.76654508957235,52.816923340346676,52.867301591121006,52.917679841895335,52.968058092669665,53.018436343443994,53.068814594218324,53.119192844992654,53.16957109576698,53.21994934654131,53.27032759731564,53.32070584808997,53.36666346725126,53.41173696008993,53.45681045292861,53.50188394576728,53.54695743860596,53.592030931444626,53.63710442428331,53.682177917121976,53.72725140996066,53.772324902799326,53.81739839563801,53.862471888476676,53.90754538131535,53.95261887415403,53.9976923669927,54.04276585983138,54.08783935267005,54.13291284550873,54.177986338347395,54.22305983118607,54.268133324024745,54.31320681686342,54.3582803097021,54.40335380254077,54.448427295379446,54.493500788218114,54.538574281056796,54.58364777389547,54.628721266734146,54.67379475957282,54.71886825241149,54.76394174525017,54.80901523808884,54.854088730927515,54.89916222376619,54.944235716604865,54.98930920944354,55.034197280938415,55.07889993083941,55.12360258074042,55.16830523064141,55.213007880542406,55.25771053044341,55.302413180344416,55.347115830245414,55.39181848014641,55.43652113004741,55.48122377994841,55.525926429849406,55.570629079750404,55.61533172965141,55.66003437955241,55.704737029453405,55.7494396793544,55.79414232925541,55.838844979156406,55.883547629057404,55.9282502789584,55.9729529288594,56.0176555787604,56.062358228661395,56.10706087856239,56.1517635284634,56.1964661783644,56.241168828265394,56.2858714781664,56.3305741280674,56.375276777968395,56.41997942786939,56.46468207777039,56.509384727671396,56.554087377572394,56.59879002747339,56.64349267737439,56.68819532727539,56.73289797717639,56.77760062707739,56.82230327697839,56.86700592687939,56.911708576780384,56.95641122668139,57.00111387658239,57.045816526483385,57.09123061735937,57.13700042872284,57.18277024008633,57.22854005144981,57.27430986281328,57.32007967417677,57.36584948554024,57.41161929690372,57.45738910826719,57.50315891963068,57.548928730994156,57.594698542357634,57.64046835372111,57.68623816508459,57.73200797644806,57.777777787811544,57.823547599175015,57.8693174105385,57.91508722190198,57.960857033265455,58.006626844628926,58.05239665599241,58.098166467355895,58.14393627871937,58.18970609008285,58.23547590144632,58.281245712809806,58.32701552417328,58.37278533553676,58.41855514690023,58.4643249582637,58.51009476962719,58.55586458099067,58.60163439235414,58.64740420371763,58.6931740150811,58.73894382644458,58.78471363780806,58.83048344917153,58.876253260535016,58.922023071898494,58.967792883261964,59.01356269462545,59.05933250598892,59.10510231735241,59.15087212871589,59.19664194007936,59.24241175144283,59.288181562806315,59.3339513741698,59.37972118553327,59.425490996896755,59.47126080826023,59.51703061962371,59.56278789844125,59.608545177252736,59.65430245606421,59.70005973487568,59.74581701368716,59.79157429249862,59.8373315713101,59.883088850121574,59.928846128933046,59.974603407744524,60.02036068655599,60.06611796536747,60.11187524417895,60.15763252299041,60.20338980180189,60.249147080613355,60.294904359424834,60.34066163823631,60.38641891704779,60.43217619585926,60.477933474670735,60.52369075348221,60.569448032293685,60.61520531110516,60.66096258991663,60.7067198687281,60.75247714753957,60.79823442635105,60.84399170516252,60.78634024678253,60.62528005121108,60.46421985563965,60.303159660068204,60.14209946449676,59.981039268925315,59.81997907335388,59.65891887778243,59.49785868221098,59.33679848663956,59.1757382910681,59.01467809549666,58.85361789992522,58.692557704353774,58.53149750878233,58.370437313210886,58.209377117639455,58.048316922068004,57.88725672649657,57.72619653092513,57.56513633535368,57.40407613978222,57.243015944210796,57.08195574863935,56.92089555306789,56.75983535749647,56.598775161925026,56.43771496635358,56.27665477078214,56.1155945752107,55.954534379639256,55.7934741840678,55.63241398849638,55.47135379292492,55.31029359735347,55.14923340178204,54.9881732062106,54.827113010639145,54.66605281506771,54.48219548749849,54.293041856804464,54.10388822611046,53.91473459541645,53.725580964722425,53.536427334028396,53.34727370333441,53.158120072640386,52.96896644194636,52.77981281125234,52.59065918055833,52.40150554986431,52.2123519191703,52.023198288476294,51.83404465778227,51.64489102708824,51.455737396394255,51.266583765700226,51.077430135006196,50.88827650431219,50.69912287361818,50.50996924292416,50.32081561223015,50.13166198153614,49.94250835084212,49.75335472014811,49.564201089454095,49.375047458760065,49.18589382806604,48.99674019737205,48.807586566678026,48.618432935984,48.429279305289995,48.24012567459599,48.05097204390196,47.861818413207956,47.672664782513934,47.48351115181991,47.2943575211259,47.105203890431895,46.916050259737865,46.726896629043836,46.537742998349835,46.348589367655826,46.089275625528714,45.689641660535514,45.290007695542315,44.89037373054907,44.49073976555587,44.09110580056268,43.691471835569445,43.29183787057621,42.892203905583045,42.4925699405898,42.092935975596575,41.693302010603375,41.293668045610175,40.89403408061695,40.49440011562374,40.09476615063055,39.695132185637306,39.295498220644106,38.895864255650906,38.49623029065767,38.096596325664436,37.696962360671236,37.297328395678036,36.89769443068481,36.49806046569161,36.09842650069841,35.698792535705174,35.29915857071197,34.899524605718774,34.49989064072554,34.100256675732304,33.70062271073914,33.300988745745904,32.90135478075267,32.50172081575947,32.10208685076627,31.702452885773035,31.302818920779842,30.90318495578664,30.5035509907934,30.1039170258002,29.704283060807,29.304649095813765,28.90501513082053,28.50538116582733,28.10574720083413,27.706113235840895,27.306479270847696,26.906845305854496,26.507211340861264,26.10757737586806,25.707943410874865,25.308309445881626,24.90867548088839,24.509041515895234,24.109407550901995,23.70977358590876,23.31013962091556,22.910505655922364,22.51087169092913,22.11123772593593,21.71160376094273,21.311969795949494,20.912335830956295,20.5127018659631,20.11306790096986,19.712258110491824,19.305207375083775,18.89815663967564,18.49110590426751,18.084055168859415,17.67700443345132,17.269953698043192,16.8629029626351,16.455852227227005,16.048801491818878,15.641750756410744,15.23470002100269,14.827649285594557,14.420598550186426,14.013547814778333,13.606497079370241,13.199446343962105,12.838234948558437,12.706220253176623,12.57420555779481,12.442190862413002,12.310176167031212,12.1781614716494,12.04614677626759,11.914132080885802,11.782117385503991,11.650102690122177,11.51808799474039,11.386073299358578,11.254058603976768,11.148997583206281,11.054099343001468,10.959201102796635,10.864302862591805,10.769404622386993,10.67450638218216,10.579608141977332,10.484709901772517,10.389811661567684,10.294913421362855,10.20001518115804,10.105116940953211,10.010218700748378,9.915320460543548,9.820422220338735,9.725523980133904,9.630625739929071,9.53572749972426,9.440829259519427,9.345931019314598,9.251032779109783,9.15613453890495,9.061236298700122,8.966338058495289,8.871439818290476,8.776541578085647,8.681643337880814,8.586745097676001,8.49184685747117,8.396948617266338,8.302050377061526,8.207152136856694,8.112253896651863,8.01735565644705,7.922457416242218,7.827559176037387,7.732660935832556,7.6377626956277425,7.542864455422912,7.447966215218081,7.353067975013267,7.258169734808437,7.163271494603606,7.068373254398793,6.97347501419396,6.87857677398913,6.783678533784299,6.688780293579486,6.593882053374655,6.498983813169823,6.404085572965009,6.309187332760178,6.214289092555347,6.119390852350534,6.024492612145703,5.929594371940872,5.834696131736059,5.739797891531227,5.659032554853189,5.596219939876473,5.533407324899768,5.470594709923051,5.407782094946334,5.344969479969629,5.2821568649929125,5.219344250016196,5.156531635039491,5.093719020062775,5.030906405086059,4.968093790109342,4.905281175132637],[49.43508106556466,49.4862658554994,49.53745064543413,49.58863543536885,49.63982022530359,49.69100501523831,49.74218980517304,49.79337459510777,49.84455938504251,49.89574417497723,49.94692896491196,49.99811375484669,50.049298544781415,50.10048333471615,50.15166812465088,50.202852914585606,50.25403770452034,50.305222494455066,50.356407284389796,50.407592074324526,50.45877686425926,50.50996165419399,50.561146444128724,50.61233123406345,50.66351602399817,50.71470081393291,50.76588560386763,50.81707039380237,50.8682551837371,50.91943997367183,50.97062476360655,51.02180955354129,51.07299434347601,51.12417913341075,51.17536392334547,51.2265487132802,51.27773350321493,51.32891829314966,51.38010308308439,51.43128787301912,51.48247266295385,51.533657452888576,51.58484224282331,51.63602703275804,51.68721182269277,51.7383966126275,51.789581402562234,51.84076619249696,51.89195098243168,51.94313577236642,51.99432056230114,52.04550535223588,52.09669014217061,52.14787493210534,52.1989252992517,52.24930355002602,52.29968180080036,52.35006005157469,52.400438302349016,52.450816553123346,52.501194803897675,52.551573054672005,52.601951305446335,52.652329556220664,52.702707806994994,52.75308605776932,52.80346430854365,52.85384255931798,52.90422081009231,52.95459906086664,53.00497731164098,53.0553555624153,53.10573381318963,53.15611206396396,53.206490314738296,53.256868565512626,53.307246816286955,53.357625067061285,53.408003317835615,53.45838156860995,53.50875981938428,53.5591380701586,53.60951632093293,53.65989457170727,53.70585219086854,53.750925683707216,53.79599917654589,53.841072669384566,53.88614616222324,53.931219655061916,53.97629314790059,54.02136664073927,54.06644013357794,54.11151362641661,54.15658711925529,54.20166061209396,54.24673410493264,54.29180759777131,54.33688109060999,54.38195458344866,54.427028076287336,54.47210156912601,54.51717506196469,54.56224855480336,54.60732204764203,54.65239554048071,54.69746903331938,54.74254252615806,54.78761601899674,54.832689511835405,54.87776300467409,54.92283649751275,54.96790999035143,55.012983483190105,55.05805697602878,55.103130468867455,55.14820396170613,55.1932774545448,55.23835094738348,55.28342444022215,55.328497933060824,55.373571425899506,55.41864491873817,55.46371841157685,55.508791904415524,55.55386539725419,55.598938890092874,55.64401238293155,55.689085875770225,55.73415936860889,55.77923286144756,55.82430635428624,55.869379847124925,55.914453339963586,55.95952683280227,56.004600325640936,56.04967381847962,56.0947473113183,56.13944996140552,56.18415261130652,56.228855261207514,56.273557911108526,56.31826056100952,56.36296321091052,56.40766586081152,56.45236851071252,56.497071160613515,56.54177381051452,56.58647646041552,56.631179110316516,56.675881760217514,56.72058441011851,56.76528706001952,56.80998970992051,56.85469235982151,56.89939500972251,56.94409765962351,56.98880030952451,57.033502959425505,57.0782056093265,57.1229082592275,57.16761090912851,57.21231355902951,57.25701620893051,57.30171885883151,57.346421508732504,57.3911241586335,57.43653824950949,57.48230806087297,57.52807787223644,57.57384768359992,57.61961749496339,57.66538730632688,57.71115711769036,57.75692692905383,57.80269674041732,57.84846655178079,57.89423636314427,57.940006174507744,57.98577598587123,58.031545797234706,58.07731560859818,58.123085419961654,58.16885523132514,58.21462504268861,58.260394854052095,58.306164665415565,58.35193447677905,58.397704288142535,58.443474099506005,58.48924391086949,58.53501372223297,58.58078353359643,58.626553344959916,58.6723231563234,58.71809296768688,58.763862779050356,58.80963259041383,58.85540240177731,58.90117221314078,58.94694202450426,58.99271183586774,59.038481647231215,59.0842514585947,59.13002126995817,59.17579108132165,59.22156089268513,59.26733070404861,59.31310051541208,59.358870326775566,59.40464013813904,59.45040994950252,59.496179760866,59.54194957222948,59.587719383592955,59.63348919495643,59.67925900631992,59.72502881768339,59.770798629046865,59.81656844041035,59.86233825177382,59.9081080631373,59.953877874500776,59.999647685864254,60.04541749722773,60.09118730859121,60.13695711995469,60.18272693131817,60.22849674268165,60.27426655404513,60.320036365408605,60.36580617677208,60.41157598813556,60.45734579949904,60.503115610862515,60.54888542222599,60.59465523358947,60.64042504495295,60.68619485631643,60.731964667679904,60.77773447904339,60.82350429040686,60.869274101770344,60.91504391313382,60.9608101997261,61.00656747853756,61.05232475734904,61.09808203616051,61.143839314971984,61.18959659378346,61.13194513540347,60.970884939832025,60.80982474426058,60.648764548689144,60.48770435311769,60.326644157546255,60.16558396197482,60.004523766403366,59.81767285315344,59.62851922245945,59.43936559176542,59.25021196107139,59.06105833037739,58.871904699683384,58.682751068989354,58.493597438295346,58.30444380760134,58.11529017690731,57.9261365462133,57.73698291551929,57.54782928482527,57.35867565413124,57.16952202343725,56.98036839274323,56.7912147620492,56.602061131355185,56.41290750066118,56.223753869967155,56.034600239273146,55.84544660857913,55.656292977885116,55.467139347191086,55.2779857164971,55.08883208580307,54.89967845510904,54.71052482441504,54.52137119372102,54.332217563027,54.14306393233299,53.953910301638984,53.764756670944955,53.575603040250954,53.38644940955694,53.197295778862916,53.008142148168886,52.81898851747489,52.62983488678087,52.44068125608684,52.25152762539283,52.06237399469883,51.873220364004794,51.6840667333108,51.494913102616785,51.30575947192276,51.11660584122873,50.92745221053474,50.738298579840716,50.54914494914669,50.35999131845268,50.17083768775867,49.98168405706464,49.79253042637063,49.603376795676624,49.4142231649826,49.225069534288586,49.03591590359458,48.846762272900556,48.657608642206526,48.46845501151254,48.27930138081851,48.09014775012449,47.90099411943048,47.71184048873647,47.52268685804245,47.33353322734843,47.14437959665443,46.9552259659604,46.766072335266394,46.57691870457238,46.387765073878356,46.19861144318433,46.009457812490325,45.82030418179631,45.5609904396692,45.161356474676,44.7617225096828,44.36208854468957,43.96245457969637,43.56282061470316,43.16318664970993,42.7635526847167,42.363918719723536,41.9642847547303,41.56465078973706,41.16501682474386,40.765382859750666,40.36574889475743,39.96611492976423,39.56648096477103,39.16684699977779,38.7672130347846,38.367579069791404,37.96794510479816,37.568311139804926,37.16867717481173,36.769043209818534,36.3694092448253,35.9697752798321,35.5701413148389,35.17050734984566,34.770873384852464,34.371239419859265,33.97160545486603,33.57197148987279,33.17233752487963,32.772703559886395,32.37306959489316,31.97343562989996,31.57380166490676,31.174167699913525,30.774533734920325,30.374899769927126,29.97847185899123,29.583831961160463,29.1891920633297,28.7945521654989,28.399912267668096,28.005272369837332,27.610632472006568,27.21599257417577,26.821352676345004,26.426712778514236,26.032072880683437,25.637432982852673,25.24279308502191,24.848153187191105,24.45351328936031,24.058873391529577,23.664233493698777,23.269593595867978,22.87495369803721,22.480313800206446,22.085673902375646,21.691034004544882,21.296394106714118,20.901754208883318,20.50711431105255,20.112474413221786,19.717834515390983,19.323194617560183,18.928554719729455,18.533914821898655,18.139274924067855,17.74463502623709,17.349995128406327,16.955355230575528,16.56071533274476,16.166075434913996,15.771435537083194,15.376795639252393,14.982155741421664,14.587515843590865,14.192875945760063,13.798236047929299,13.403596150098533,13.008956252267732,12.6594034947617,12.535286438879059,12.41116938299642,12.287052327113779,12.162935271231163,12.038818215348524,11.914701159465883,11.790584103583269,11.666467047700628,11.54234999181799,11.418232935935372,11.29411588005273,11.169998824170094,11.045881768287453,10.921764712404835,10.797647656522196,10.673530600639557,10.549761363695204,10.454863123490375,10.359964883285544,10.26506664308073,10.170168402875898,10.075270162671066,9.980371922466254,9.885473682261422,9.790575442056591,9.69567720185176,9.600778961646947,9.505880721442114,9.410982481237285,9.31608424103247,9.22118600082764,9.126287760622809,9.031389520417996,8.936491280213163,8.841593040008332,8.746694799803501,8.651796559598688,8.556898319393857,8.462000079189027,8.367101838984214,8.272203598779381,8.17730535857455,8.082407118369737,7.987508878164906,7.892610637960075,7.797712397755262,7.702814157550431,7.607915917345599,7.513017677140769,7.418119436935956,7.323221196731124,7.228322956526293,7.133424716321479,7.038526476116648,6.943628235911818,6.848729995707004,6.753831755502173,6.658933515297342,6.564035275092511,6.469137034887698,6.374238794682867,6.279340554478036,6.184442314273221,6.089544074068391,5.99464583386356,5.9052017851125385,5.845545824894545,5.785889864676552,5.726233904458571,5.666577944240577,5.606921984022584,5.547266023804591,5.48761006358661,5.4279541033686165,5.368298143150623,5.3086421829326405,5.248986222714647,5.1893302624966555,5.129674302278673,5.07001834206068,5.010362381842687,4.950706421624694,4.891050461406712],[49.76096189290226,49.81214668283699,49.86333147277172,49.91451626270645,49.96570105264118,50.01688584257591,50.06807063251064,50.11925542244537,50.1704402123801,50.22162500231483,50.27280979224956,50.32399458218429,50.375179372119014,50.42636416205375,50.477548951988474,50.528733741923205,50.579918531857935,50.631103321792665,50.6822881117274,50.733472901662125,50.784657691596855,50.835842481531586,50.887027271466316,50.938212061401046,50.989396851335776,51.04058164127051,51.09176643120523,51.14295122113997,51.1941360110747,51.24532080100943,51.29650559094415,51.34769038087889,51.39887517081361,51.45005996074835,51.50124475068307,51.55242954061781,51.60361433055253,51.65479912048726,51.70598391042199,51.75716870035672,51.80835349029145,51.85953828022618,51.91072307016091,51.96190786009564,52.01309265003037,52.064277439965096,52.11546222989983,52.166647019834556,52.21783180976928,52.26901659970402,52.32020138963874,52.37138617957348,52.42257096950821,52.47375575944294,52.524940549377675,52.57612533931239,52.62731012924713,52.67849491918186,52.72967970911658,52.78086449905132,52.83204928898604,52.88323407892078,52.9344188688555,52.98560365879023,53.03678844872496,53.08797323865969,53.13915802859442,53.19034281852916,53.24152760846388,53.29271239839861,53.343897188333344,53.39454428603258,53.44492253680691,53.495300787581236,53.545679038355566,53.596057289129895,53.646435539904225,53.696813790678554,53.747192041452884,53.79757029222722,53.84794854300155,53.89832679377588,53.94870504455021,53.99908329532454,54.04504091448582,54.09011440732449,54.13518790016317,54.18026139300184,54.22533488584051,54.270408378679186,54.31548187151786,54.36055536435654,54.40562885719521,54.450702350033886,54.49577584287257,54.540849335711236,54.58592282854991,54.63099632138858,54.67606981422727,54.721143307065944,54.76621679990461,54.81129029274329,54.85636378558196,54.90143727842064,54.94651077125931,54.99158426409798,55.036657756936656,55.08173124977533,55.12680474261401,55.17187823545268,55.216951728291356,55.26202522113003,55.307098713968706,55.35217220680738,55.39724569964605,55.442319192484725,55.4873926853234,55.532466178162075,55.57753967100075,55.62261316383942,55.6676866566781,55.712760149516775,55.75783364235545,55.80290713519412,55.8479806280328,55.89305412087147,55.938127613710144,55.98320110654882,56.028274599387494,56.07334809222617,56.11842158506484,56.16349507790352,56.208568570742194,56.25364206358087,56.29871555641954,56.34378904925822,56.38886254209689,56.43393603493557,56.47900952777424,56.52408302061291,56.56915651345159,56.61423000629026,56.65930349912894,56.704376991967614,56.74945048480629,56.794523977644964,56.83959747048364,56.884670963322314,56.92974445616099,56.974817948999664,57.01989144183833,57.064964934677015,57.11003842751568,57.15511192035436,57.19999999197161,57.24470264187261,57.289405291773605,57.3341079416746,57.3788105915756,57.4235132414766,57.46821589137761,57.51291854127861,57.55762119117961,57.602323841080604,57.6470264909816,57.6917291408826,57.7364317907836,57.781845881659585,57.82761569302306,57.87338550438655,57.91915531575002,57.964925127113496,58.01069493847697,58.05646474984046,58.102234561203936,58.148004372567414,58.193774183930884,58.23954399529437,58.28531380665785,58.331083618021324,58.3768534293848,58.42262324074828,58.46839305211176,58.514162863475235,58.55993267483872,58.60570248620219,58.65147229756568,58.697242108929146,58.74301192029264,58.78878173165611,58.834551543019586,58.880321354383064,58.92609116574654,58.97186097711002,59.0176307884735,59.06340059983698,59.10917041120045,59.15494022256393,59.20071003392741,59.24647984529089,59.292249656654356,59.338019468017855,59.38378927938131,59.4295590907448,59.47532890210828,59.52109871347176,59.566868524835236,59.612638336198714,59.658408147562184,59.70401099543361,59.74944688127704,59.794882767120455,59.84031865296385,59.88575453880726,59.93119042465069,59.97662631049408,60.022062196337515,60.06749808218091,60.11293396802432,60.15836985386774,60.20380573971114,60.24924162555456,60.294677511397985,60.34011339724138,60.385549283084806,60.43098516892821,60.47642105477163,60.521856940615045,60.56729282645844,60.61272871230186,60.65816459814527,60.70360048398868,60.7490363698321,60.794472255675515,60.83990814151892,60.885344027362336,60.93077991320574,60.97621579904915,61.021651684892575,61.06708757073598,61.11252345657939,61.1579593424228,61.20339522826621,61.248831114109635,61.29426699995304,61.33970288579645,61.385138771639866,61.43057465748327,61.47601054332668,61.5214464291701,61.4324002776925,61.20887208889389,60.98534390009531,60.76181571129673,60.53828752249813,60.314759333699534,60.09123114490095,59.86770295610235,59.64417476730375,59.420646578505185,59.19711838970658,58.973590200907985,58.750062012109396,58.526533823310814,58.30300563451221,58.07947744571362,57.855949256915046,57.632421068116436,57.40889287931786,57.19798982561045,57.00889391949021,56.81979801336997,56.630702107249775,56.44160620112953,56.252510295009294,56.06341438888907,55.87431848276885,55.685222576648606,55.49612667052838,55.30703076440817,55.11793485828793,54.928838952167695,54.73974304604748,54.55064713992724,54.361551233807,54.17245532768679,53.98335942156656,53.79426351544632,53.6051676093261,53.41607170320588,53.22697579708564,53.03787989096542,52.8487839848452,52.659688078724955,52.47059217260471,52.28149626648451,52.09240036036428,51.90330445424404,51.714208548123814,51.52511264200359,51.33601673588335,51.14692082976313,50.9578249236429,50.76872901752267,50.57963311140243,50.39053720528222,50.20144129916198,50.01234539304175,49.823249486921526,49.6341535808013,49.44505767468106,49.25596176856084,49.066865862440615,48.87776995632038,48.688674050200156,48.49957814407993,48.3104822379597,48.12138633183945,47.93229042571925,47.74319451959901,47.55409861347877,47.36500270735855,47.17590680123833,46.98681089511808,46.79771498899787,46.608619082877645,46.4195231767574,46.230427270637186,46.04133136451696,45.85223545839672,45.663139552276476,45.474043646156254,45.284947740036046,45.02978451921544,44.642486668994216,44.25518881877298,43.86789096855171,43.48059311833049,43.09329526810926,42.70599741788799,42.318699567666734,41.93140171744554,41.54410386722428,41.156806017003014,40.76950816678178,40.38221031656055,39.99491246633929,39.60761461611806,39.22031676589683,38.83301891567557,38.44572106545434,38.05842321523311,37.67112536501185,37.28382751479059,36.89652966456936,36.50923181434812,36.11539694557586,35.7207570477451,35.32611714991433,34.93147725208353,34.53683735425277,34.14219745642201,33.7475575585912,33.352917660760404,32.958277762929676,32.563637865098876,32.168997967268076,31.774358069437312,31.379718171606545,30.985078273775745,30.59043837594498,30.195798478114213,29.801158580283413,29.40651868245265,29.011878784621885,28.617238886791082,28.222598988960282,27.827959091129514,27.433319193298754,27.038679295467954,26.64403939763719,26.249399499806426,25.854759601975623,25.46011970414486,25.06547980631409,24.67083990848329,24.27620001065249,23.881560112821763,23.48692021499096,23.09228031716016,22.697640419329396,22.30300052149863,21.908360623667832,21.513720725837068,21.119080828006304,20.7244409301755,20.329801032344736,19.935161134513972,19.54052123668317,19.14588133885237,18.75124144102164,18.35660154319084,17.96196164536004,17.567321747529274,17.172681849698513,16.77804195186771,16.383402054036946,15.988762156206182,15.59412225837538,15.199482360544579,14.80484246271385,14.410202564883049,14.015562667052247,13.620922769221485,13.226282871390719,12.83164297355992,12.482090216053884,12.357973160171245,12.233856104288606,12.109739048405967,11.985621992523349,11.86150493664071,11.737387880758071,11.613270824875453,11.489153768992814,11.365036713110173,11.240919657227558,11.116802601344919,10.992685545462278,10.868568489579637,10.744451433697021,10.620334377814382,10.496217321931743,10.372100266049127,10.247983210166488,10.123866154283848,9.999749098401232,9.87563204251859,9.751514986635952,9.627397930753334,9.503280874870695,9.379163818988054,9.255046763105417,9.1309297072228,9.00681265134016,8.88269559545752,8.758578539574902,8.634461483692263,8.510344427809624,8.386227371927008,8.26211031604437,8.137993260161728,8.01387620427909,7.889759148396473,7.765642092513833,7.666183604193549,7.576878580847119,7.487573557500672,7.398268534154226,7.308963510807795,7.2196584874613485,7.143942580135044,7.084286619917062,7.024630659699069,6.9649746994810755,6.905318739263083,6.845662779045101,6.786006818827108,6.726350858609115,6.666694898391134,6.60703893817314,6.547382977955147,6.487727017737165,6.428071057519172,6.36841509730118,6.308759137083186,6.249103176865204,6.189447216647211,6.129791256429217,6.070135296211236,6.010479335993242,5.950823375775251,5.891167415557267,5.831511455339275,5.771855495121281,5.7121995349032995,5.652543574685307,5.592887614467313,5.53323165424932,5.4735756940313385,5.413919733813346,5.354263773595353,5.29460781337737,5.2349518531593775,5.175295892941385,5.115639932723402,5.05598397250541,4.9963280122874165,4.936672052069424,4.877016091851441],[50.08407527369974,50.135887269261815,50.187699264823884,50.23951126038597,50.29111418792755,50.34229897786228,50.393483767797,50.44466855773174,50.49585334766646,50.5470381376012,50.59822292753592,50.64940771747065,50.70059250740538,50.751777297340105,50.80296208727484,50.85414687720957,50.9053316671443,50.956516457079026,51.007701247013756,51.05888603694849,51.11007082688322,51.16125561681795,51.21244040675268,51.26362519668741,51.31480998662214,51.36599477655687,51.41717956649159,51.46836435642632,51.51954914636106,51.57073393629578,51.62191872623052,51.67310351616524,51.72428830609998,51.77547309603471,51.82665788596944,51.87784267590416,51.92902746583889,51.98021225577362,52.03139704570835,52.08258183564308,52.133766625577806,52.18495141551254,52.236136205447266,52.287320995382004,52.33850578531673,52.389690575251464,52.44087536518619,52.492060155120924,52.54324494505565,52.59442973499037,52.64561452492511,52.69679931485983,52.74798410479457,52.7991688947293,52.85035368466403,52.901538474598766,52.95272326453348,53.00390805446822,53.05509284440295,53.10627763433767,53.15746242427241,53.20864721420713,53.25983200414187,53.3110167940766,53.36220158401133,53.413386373946054,53.464571163880784,53.515755953815514,53.566940743750244,53.618125533684974,53.669310323619705,53.720495113554435,53.771679903489165,53.822864693423895,53.87404948335862,53.92523427329335,53.97641906322808,54.027603853162816,54.07878864309754,54.12997343303227,54.18115822296701,54.23234301290173,54.28352780283646,54.33471259277119,54.38080463512587,54.42587812796455,54.47095162080322,54.516025113641895,54.56109860648057,54.60617209931924,54.65124559215792,54.69631908499659,54.74139257783526,54.78646607067394,54.83153956351262,54.87661305635129,54.92168654918997,54.96676004202864,55.01183353486732,55.056907027705996,55.101980520544664,55.14705401338334,55.192127506222015,55.23720099906069,55.28227449189936,55.32734798473804,55.37242147757671,55.41749497041538,55.46256846325406,55.507641956092726,55.55271544893141,55.597788941770084,55.64286243460876,55.68793592744743,55.73300942028611,55.77808291312478,55.82315640596345,55.86822989880213,55.91330339164081,55.95837688447948,56.00345037731816,56.04852387015683,56.093597362995496,56.13867085583418,56.183744348672846,56.22881784151152,56.2738913343502,56.31896482718887,56.364038320027554,56.40911181286623,56.4541853057049,56.49925879854357,56.54433229138225,56.589405784220915,56.6344792770596,56.679552769898265,56.72462626273694,56.769699755575616,56.8147732484143,56.859846741252966,56.90492023409164,56.949993726930316,56.995067219768984,57.04014071260766,57.08521420544634,57.13028769828502,57.175361191123685,57.22043468396236,57.265508176801035,57.31058166963972,57.355655162478385,57.40072865531706,57.445802148155735,57.49087564099441,57.53594913383308,57.58102262667175,57.62609611951043,57.67116961234911,57.71624310518778,57.761316598026454,57.80639009086513,57.851463583703804,57.89653707654248,57.94168486237605,57.98698123364301,58.03227760490996,58.0775739761769,58.1229578760623,58.16838554025692,58.213813204451526,58.259240868646145,58.304668532840765,58.35009619703538,58.39552386123,58.44095908933111,58.48639497517453,58.53183086101794,58.57726674686135,58.622702632704765,58.66813851854817,58.71357440439158,58.75901029023499,58.8044461760784,58.84988206192182,58.895317947765236,58.94075383360864,58.98618971945206,59.031625605295474,59.07706149113888,59.12249737698229,59.167933262825706,59.213369148669116,59.25880503451253,59.304240920355944,59.34967680619935,59.395112692042765,59.44054857788617,59.48598446372959,59.531420349573004,59.57685623541641,59.622292121259825,59.667728007103236,59.71316389294664,59.75859977879006,59.804035664633474,59.849471550476885,59.894907436320295,59.9403433221637,59.98577920800712,60.031215093850534,60.07665097969394,60.122086865537355,60.16752275138076,60.212958637224176,60.25839452306759,60.303830408911,60.349266294754415,60.39470218059782,60.440138066441236,60.48557395228465,60.53100983812806,60.576445723971474,60.621881609814885,60.66731749565829,60.712753381501706,60.75818926734511,60.80362515318854,60.849061039031945,60.894496924875355,60.93993281071877,60.985368696562176,61.030804582405594,61.076240468249004,61.121676354092415,61.16711223993583,61.212548125779236,61.25798401162265,61.303419897466064,61.348855783309475,61.39429166915289,61.4397275549963,61.485163440839706,61.53059932668312,61.576035212526534,61.62147109836995,61.666906984213355,61.71234287005677,61.757778755900176,61.803214641743594,61.84865052758701,61.7596043761094,61.5360761873108,61.312547998512215,61.08901980971363,60.86549162091504,60.64196343211645,60.418435243317866,60.19490705451926,59.97137886572065,59.74785067692209,59.52432248812349,59.30079429932489,59.077266110526296,58.85373792172772,58.63020973292912,58.406681544130535,58.18315335533195,57.95962516653335,57.736096977734775,57.51256878893618,57.289040600137575,57.06551241133897,56.841984222540404,56.61845603374181,56.3949278449432,56.17139965614462,55.94787146734604,55.72434327854743,55.500815089748855,55.277286900950266,55.05375871215166,54.83023052335306,54.6067023345545,54.38317414575589,54.159645956957284,53.93611776815871,53.71258957936013,53.48906139056152,53.265533201762935,53.04200501296435,52.81847682416575,52.59494863536716,52.37142044656858,52.14789225776998,51.926659510547694,51.73756360442749,51.54846769830725,51.35937179218701,51.17027588606679,50.98117997994656,50.792084073826324,50.60298816770611,50.413892261585886,50.22479635546564,50.035700449345406,49.8466045432252,49.657508637104954,49.468412730984724,49.2793168248645,49.09022091874428,48.901125012624036,48.71202910650381,48.52293320038359,48.33383729426336,48.14474138814313,47.95564548202291,47.76654957590267,47.57745366978243,47.38835776366223,47.199261857541984,47.01016595142175,46.821070045301525,46.6319741391813,46.442878233061066,46.25378232694084,46.06468642082062,45.875590514700384,45.68649460858016,45.49739870245994,45.3083027963397,45.11920689021946,44.93011098409924,44.741015077979014,44.485851857158416,44.098554006937185,43.71125615671596,43.323958306494696,42.936660456273465,42.54936260605224,42.162064755830976,41.77476690560971,41.38746905538852,41.00017120516725,40.61287335494599,40.22557550472476,39.83827765450353,39.45097980428227,39.06368195406104,38.67638410383981,38.28908625361855,37.90178840339732,37.51449055317609,37.12719270295483,36.739894852733556,36.35259700251233,35.9652991522911,35.578001302069836,35.190703451848606,34.80340560162738,34.416107751406116,34.028809901184886,33.64151205096366,33.254214200742396,32.86691635052113,32.47961850029994,32.092320650078676,31.70502279985741,31.31772494963618,30.930427099414956,30.54312924919369,30.15583139897246,29.76853354875123,29.381235698529963,28.99393784830874,28.60663999808751,28.219342147866247,27.832044297644984,27.444746447423753,27.057448597202526,26.670150746981264,26.282852896760033,25.895555046538803,25.50825719631754,25.120959346096306,24.733661495875083,24.346363645653817,23.95906579543255,23.571767945211366,23.1844700949901,22.79717224476883,22.409874394547607,22.022576544326377,21.635278694105114,21.247980843883887,20.86068299366265,20.47338514344139,20.08608729322016,19.698789442998933,19.31149159277767,18.924193742556405,18.536895892335217,18.14959804211395,17.762300191892685,17.375002341671458,16.987704491450227,16.600406641228965,16.206088775329132,15.811448877498366,15.416808979667566,15.022169081836765,14.627529184006036,14.232889286175235,13.838249388344435,13.443609490513671,13.048969592682905,12.654329694852105,12.30477693734607,12.18065988146343,12.05654282558079,11.932425769698153,11.808308713815537,11.684191657932894,11.560074602050255,11.447561612538204,11.358256589191758,11.26895156584531,11.17964654249888,11.090341519152433,11.00103649580599,10.91173147245954,10.822426449113111,10.733121425766665,10.643816402420219,10.554511379073787,10.465206355727341,10.375901332380895,10.286596309034465,10.197291285688017,10.107986262341571,10.018681238995141,9.929376215648695,9.840071192302249,9.750766168955803,9.661461145609373,9.572156122262927,9.48285109891648,9.39354607557005,9.304241052223603,9.214936028877158,9.125631005530728,9.03632598218428,8.947020958837834,8.857715935491388,8.768410912144958,8.67910588879851,8.589800865452066,8.500495842105634,8.411190818759188,8.32188579541274,8.232580772066312,8.143275748719866,8.053970725373418,7.964665702026988,7.875360678680543,7.7860556553340965,7.6967506319876495,7.607445608641219,7.5181405852947725,7.4288355619483255,7.339530538601896,7.250225515255449,7.160920491909003,7.071615468562572,6.982310445216126,6.893005421869681,6.803700398523233,6.714395375176804,6.625090351830357,6.535785328483911,6.446480305137481,6.357175281791034,6.267870258444587,6.178565235098158,6.089260211751711,5.999955188405265,5.9106501650588354,5.8213451417123885,5.732040118365942,5.642735095019496,5.553430071673065,5.464125048326619,5.374820024980172,5.285515001633742,5.220917483604107,5.161261523386114,5.101605563168131,5.0419496029501385,4.982293642732145,4.922637682514154,4.862981722296171],[50.39750259430863,50.4493145898707,50.50112658543277,50.552938580994855,50.60475057655694,50.656562572119014,50.70837456768109,50.76018656324317,50.81199855880525,50.86381055436733,50.91562254992941,50.967434545491486,51.01924654105356,51.07105853661564,51.12287053217772,51.1746825277398,51.22649452330188,51.27830651886396,51.33011851442603,51.38193050998811,51.43374250555019,51.48503183038158,51.53621662031631,51.58740141025103,51.63858620018577,51.68977099012049,51.740955780055224,51.792140569989954,51.84332535992469,51.894510149859414,51.945694939794144,51.996879729728875,52.04806451966361,52.099249309598335,52.15043409953306,52.201618889467795,52.25280367940252,52.303988469337256,52.355173259271986,52.406358049206716,52.45754283914144,52.508727629076176,52.5599124190109,52.61109720894564,52.66228199888036,52.71346678881509,52.76465157874982,52.81583636868456,52.86702115861928,52.918205948554004,52.96939073848874,53.020575528423464,53.0717603183582,53.122945108292924,53.17412989822766,53.225314688162385,53.27649947809712,53.327684268031845,53.378869057966575,53.430053847901306,53.48123863783604,53.532423427770766,53.583608217705496,53.634793007640226,53.68597779757496,53.73716258750969,53.78834737744442,53.83953216737915,53.89071695731387,53.94190174724861,53.99308653718334,54.04427132711807,54.09545611705279,54.14664090698753,54.19782569692225,54.24901048685698,54.30019527679171,54.351380066726435,54.40256485666117,54.4537496465959,54.50493443653063,54.556119226465356,54.60730401640009,54.65848880633482,54.7045808486895,54.74965434152818,54.794727834366846,54.83980132720552,54.8848748200442,54.92994831288287,54.975021805721546,55.02009529856022,55.0651687913989,55.11024228423757,55.15531577707625,55.200389269914915,55.245462762753604,55.29053625559227,55.335609748430954,55.38068324126962,55.4257567341083,55.47083022694697,55.51590371978564,55.56097721262432,55.60605070546299,55.651124198301666,55.69619769114034,55.74127118397901,55.78634467681769,55.83141816965636,55.87649166249504,55.92156515533371,55.96663864817239,56.01171214101107,56.056785633849735,56.10185912668841,56.14693261952708,56.19200611236575,56.237079605204435,56.28215309804311,56.327226590881786,56.372300083720454,56.41737357655913,56.46244706939781,56.50752056223648,56.552594055075154,56.59766754791384,56.642741040752504,56.68781453359118,56.73288802642985,56.77796151926852,56.823035012107205,56.86810850494588,56.91318199778455,56.95825549062322,57.0033289834619,57.04840247630057,57.09347596913925,57.138549461977924,57.1836229548166,57.228696447655274,57.27376994049395,57.31884343333262,57.36391692617129,57.408990419009974,57.45406391184865,57.49913740468732,57.54439662977181,57.58969300103876,57.63498937230572,57.68028574357266,57.72558211483961,57.770878486106554,57.816174857373504,57.86147122864046,57.90676759990741,57.95206397117436,57.99736034244131,58.042656713708254,58.08795308497521,58.13324945624216,58.17854582750911,58.22384219877606,58.26913857004301,58.31443494130996,58.35973131257691,58.405027683843855,58.450411583729256,58.49583924792387,58.54126691211848,58.58669457631311,58.63212224050772,58.67754990470233,58.72297756889695,58.76840523309157,58.81383289728618,58.8592605614808,58.90468822567542,58.95011588987004,58.99554355406465,59.04097121825926,59.08639888245389,59.1318265466485,59.17725421084312,59.222681875037736,59.26810953923235,59.31353720342696,59.35896486762159,59.4043925318162,59.44982019601082,59.49524786020544,59.540675524400044,59.58610318859466,59.63153085278929,59.676958516983895,59.72238618117852,59.767813845373134,59.813241509567746,59.85866917376238,59.904096837956985,59.949524502151604,59.994952166346216,60.040379830540836,60.08580749473545,60.13123976305039,60.1766756488938,60.22211153473721,60.26754742058063,60.31298330642404,60.35841919226745,60.403855078110865,60.44929096395427,60.49472684979768,60.54016273564109,60.58559862148451,60.63103450732792,60.67647039317133,60.721906279014746,60.76734216485815,60.81277805070157,60.85821393654498,60.903649822388395,60.949085708231806,60.99452159407521,61.03995747991863,61.08539336576204,61.130829251605455,61.176265137448866,61.22170102329227,61.26713690913569,61.31257279497909,61.358008680822515,61.403444566665925,61.44888045250933,61.494316338352746,61.53975222419616,61.58518811003957,61.63062399588298,61.676059881726395,61.721495767569806,61.766931653413224,61.81236753925663,61.857803425100045,61.903239310943455,61.948675196786866,61.994111082630276,62.03954696847368,62.08498285431709,62.130418740160515,62.175854626003925,62.08680847452632,61.863280285727726,61.639752096929136,61.416223908130554,61.19269571933196,60.969167530533376,60.74563934173479,60.522111152936176,60.29858296413758,60.07505477533901,59.85152658654041,59.627998397741806,59.40447020894322,59.18094202014464,58.95741383134604,58.733885642547456,58.51035745374887,58.28682926495026,58.06330107615169,57.8397728873531,57.61624469855449,57.392716509755886,57.16918832095733,56.94566013215873,56.72213194336012,56.49860375456154,56.275075565762954,56.05154737696435,55.82801918816577,55.60449099936719,55.38096281056859,55.15743462176998,54.93390643297141,54.71037824417281,54.486850055374205,54.26332186657562,54.03979367777704,53.816265488978445,53.59273730017985,53.36920911138127,53.14568092258267,52.92215273378408,52.6986245449855,52.475096356186896,52.25156816738829,52.02803997858973,51.80451178979112,51.580983600992525,51.35745541219394,51.13392722339536,50.91039903459675,50.68687084579817,50.463342656999586,50.23981446820098,50.01628627940238,49.79275809060381,49.56922990180521,49.345701713006605,49.12217352420802,48.89864533540945,48.675117146610845,48.45158895781226,48.22806076901367,48.00453258021507,47.78100439141649,47.5574762026179,47.3339480138193,47.1104198250207,46.88689163622213,46.66336344742353,46.4662332893647,46.27713738324448,46.088041477124264,45.89894557100402,45.709849664883805,45.520753758763576,45.331657852643346,45.14256194652312,44.953466040402894,44.76437013428265,44.575274228162414,44.38617832204219,44.19708241592197,43.94191919510136,43.55462134488015,43.167323494658916,42.78002564443766,42.39272779421642,42.005429943995196,41.61813209377393,41.230834243552664,40.843536393331476,40.45623854311021,40.068940692888944,39.68164284266771,39.29434499244648,38.90704714222522,38.51974929200399,38.13245144178276,37.745153591561504,37.35785574134027,36.97055789111904,36.583260040897784,36.19596219067652,35.808664340455294,35.421366490234064,35.0340686400128,34.64677078979156,34.25947293957034,33.87217508934907,33.48487723912784,33.09757938890662,32.71028153868535,32.322983688464085,31.9356858382429,31.54838798802163,31.161090137800368,30.778236342840728,30.396863869435276,30.015491396029788,29.634118922624346,29.252746449218893,28.871373975813405,28.490001502407956,28.108629029002504,27.727256555597016,27.34588408219153,26.964511608786083,26.583139135380634,26.201766661975146,25.820394188569693,25.439021715164245,25.05764924175876,24.67627676835331,24.29490429494786,23.91353182154237,23.532159348136886,23.150786874731473,22.76941440132599,22.3880419279205,22.006669454515052,21.6252969811096,21.243924507704115,20.862552034298666,20.48117956089321,20.09980708748773,19.71843461408228,19.337062140676828,18.955689667271344,18.574317193865856,18.192944720460442,17.811572247054958,17.43019977364947,17.04882730024402,16.667454826838565,16.28608235343308,15.904709880027632,15.523337406622181,15.141964933216697,14.76059245981121,14.379219986405793,13.997847513000309,13.616475039594825,13.235102566189372,12.853730092783927,12.472357619378437,12.135130410762445,12.018629526093497,11.902128641424547,11.785627756755598,11.669126872086672,11.552625987417722,11.436125102748774,11.319624218079847,11.203123333410897,11.086622448741949,10.97012156407302,10.853620679404072,10.737119794735124,10.620618910066174,10.504118025397247,10.387617140728297,10.271116256059349,10.154615371390422,10.038114486721472,9.921613602052524,9.805112717383597,9.688611832714647,9.5721109480457,9.472710480852967,9.383405457506521,9.294100434160075,9.204795410813627,9.115490387467197,9.026185364120751,8.936880340774305,8.847575317427875,8.758270294081427,8.668965270734983,8.579660247388553,8.490355224042105,8.40105020069566,8.311745177349213,8.222440154002783,8.133135130656337,8.04383010730989,7.9545250839634605,7.865220060617014,7.775915037270568,7.686610013924137,7.59730499057769,7.507999967231244,7.418694943884814,7.329389920538368,7.240084897191921,7.150779873845475,7.061474850499044,6.972169827152599,6.882864803806152,6.793559780459722,6.704254757113276,6.614949733766829,6.5256447104204,6.436339687073953,6.347034663727506,6.25772964038106,6.1684246170346295,6.096663892258757,6.039976414725173,5.983288937191599,5.9266014596580145,5.86991398212443,5.813226504590856,5.756539027057272,5.699851549523687,5.643164071990114,5.5864765944565296,5.529789116922945,5.47310163938936,5.416414161855786,5.359726684322202,5.303039206788617,5.246351729255044,5.189664251721459,5.132976774187874,5.076289296654301,5.019601819120717,4.962914341587132,4.906226864053548,4.849539386519974],[50.7109299149175,50.76274191047958,50.81455390604166,50.86636590160374,50.91817789716582,50.969989892727895,51.02180188828997,51.07361388385205,51.12542587941413,51.17723787497621,51.22904987053829,51.280861866100366,51.33267386166244,51.384485857224526,51.4362978527866,51.488109848348685,51.53992184391076,51.59173383947284,51.643545835034914,51.695357830597,51.747169826159066,51.79898182172115,51.85079381728323,51.90260581284531,51.954417808407385,52.00622980396946,52.058041799531544,52.10985379509361,52.1616657906557,52.21347778621777,52.265289781779856,52.31710177734193,52.36891377290401,52.42072576846609,52.47253776402816,52.524349759590244,52.57616175515233,52.62776468290087,52.678949472835605,52.730134262770335,52.78131905270505,52.832503842639795,52.88368863257452,52.93487342250925,52.98605821244398,53.03724300237871,53.08842779231343,53.139612582248176,53.1907973721829,53.24198216211762,53.29316695205236,53.34435174198708,53.39553653192182,53.44672132185655,53.49790611179127,53.549090901726004,53.60027569166074,53.651460481595464,53.702645271530194,53.753830061464924,53.80501485139965,53.856199641334385,53.907384431269115,53.95856922120384,54.009754011138575,54.060938801073306,54.11212359100803,54.163308380942766,54.21449317087749,54.26567796081222,54.31686275074695,54.36804754068168,54.41923233061641,54.47041712055114,54.52160191048587,54.5727867004206,54.62397149035533,54.675156280290054,54.72634107022479,54.777525860159514,54.82871065009425,54.879895440028974,54.93108022996371,54.982265019898435,55.02835706225312,55.073430555091804,55.11850404793047,55.16357754076914,55.20865103360782,55.25372452644649,55.298798019285165,55.34387151212384,55.388945004962515,55.43401849780119,55.47909199063987,55.52416548347854,55.56923897631722,55.61431246915589,55.659385961994566,55.70445945483324,55.74953294767191,55.79460644051059,55.83967993334927,55.88475342618794,55.92982691902661,55.97490041186529,56.01997390470396,56.065047397542635,56.11012089038132,56.15519438321998,56.20026787605866,56.24534136889733,56.29041486173601,56.33548835457468,56.38056184741336,56.42563534025203,56.470708833090704,56.51578232592937,56.560855818768054,56.60592931160672,56.651002804445405,56.69607629728408,56.74114979012275,56.78622328296143,56.8312967758001,56.87637026863877,56.92144376147745,56.96651725431612,57.0115907471548,57.056664239993474,57.1018120259006,57.14710839716756,57.1924047684345,57.23770113970144,57.2829975109684,57.32829388223535,57.37359025350229,57.41888662476925,57.4641829960362,57.50947936730315,57.5547757385701,57.60007210983705,57.645368481104,57.69066485237094,57.7359612236379,57.78125759490485,57.8265539661718,57.87185033743875,57.9171467087057,57.96244307997266,58.0077394512396,58.05303582250655,58.0983321937735,58.143628565040444,58.1889249363074,58.234221307574344,58.2795176788413,58.32481405010825,58.3701104213752,58.415406792642145,58.4607031639091,58.50599953517605,58.551295906443,58.596592277709945,58.6418886489769,58.68718502024385,58.7324813915108,58.777865291396196,58.82329295559081,58.86872061978543,58.91414828398004,58.95957594817466,59.00500361236927,59.05043127656389,59.0958589407585,59.14128660495313,59.18671426914774,59.23214193334236,59.277569597536974,59.32299726173159,59.36842492592621,59.413852590120825,59.459280254315445,59.50470791851006,59.55013558270468,59.595563246899296,59.64099091109391,59.68641857528853,59.73184623948314,59.77727390367775,59.82270156787237,59.86812923206699,59.91355689626161,59.95898456045622,60.004412224650835,60.049839888845455,60.095267553040074,60.14069521723469,60.1861228814293,60.231550545623925,60.276978209818544,60.32240587401316,60.367833538207776,60.413261202402396,60.458688866597,60.50411653079162,60.54954419498624,60.59497185918085,60.64039952337548,60.685827187570084,60.7312548517647,60.77668251595932,60.82211018015394,60.86753784434856,60.91296550854317,60.95839317273779,61.00382083693241,61.049248501127025,61.09467616532164,61.14010382951625,61.18553149371087,61.23095915790549,61.276386822100115,61.32181448629472,61.36724215048934,61.41266981468396,61.45809747887858,61.50352514307319,61.5489528072678,61.59438047146242,61.639808135657034,61.685235799851654,61.73066346404627,61.77609112824089,61.82152043676965,61.86695632261306,61.912392208456474,61.95782809429989,62.0032639801433,62.04869986598671,62.09413575183012,62.139571637673534,62.185007523516944,62.23044340936036,62.27587929520377,62.32131518104718,62.36675106689059,62.412186952734004,62.45762283857742,62.50305872442083,62.41401257294323,62.19048438414463,61.96695619534604,61.74342800654746,61.51989981774886,61.296371628950276,61.07284344015169,60.84931525135309,60.62578706255449,60.402258873755926,60.178730684957316,59.95520249615871,59.73167430736012,59.50814611856155,59.28461792976294,59.061089740964356,58.83756155216577,58.61403336336717,58.39050517456859,58.166976985770006,57.943448796971396,57.7199206081728,57.49639241937424,57.27286423057563,57.04933604177703,56.82580785297845,56.60227966417986,56.378751475381264,56.155223286582675,55.93169509778409,55.70816690898549,55.48463872018689,55.261110531388326,55.037582342589715,54.81405415379112,54.59052596499252,54.36699777619394,54.143469587395344,53.919941398596755,53.69641320979817,53.47288502099957,53.249356832200995,53.025828643402406,52.80230045460381,52.569528054848085,52.33560014731228,52.10167223977641,51.86774433224055,51.633816424704705,51.399888517168876,51.16596060963301,50.93203270209716,50.69810479456133,50.464176887025474,50.2302489794896,49.99632107195379,49.76239316441793,49.52846525688207,49.29453734934623,49.060609441810385,48.82668153427453,48.592753626738684,48.35882571920284,48.12489781166698,47.89096990413114,47.6570419965953,47.42311408905944,47.18918618152358,46.95525827398776,46.7213303664519,46.487402458916044,46.2534745513802,46.019546643844365,45.78561873630849,45.55169082877266,45.31776292123682,45.08383501370096,44.84990710616512,44.615979198629276,44.38205129109341,44.148123383557554,43.91419547602171,43.680267568485874,43.39953209883133,43.025181504939496,42.65083091104767,42.27648031715581,41.902129723263975,41.52777912937215,41.15342853548027,40.77907794158842,40.404727347696614,40.03037675380475,39.65602615991289,39.28167556602106,38.90732497212923,38.53297437823736,38.15862378434553,37.7842731904537,37.409922596561834,37.03557200267001,36.661221408778175,36.28687081488631,35.912520220994445,35.53816962710261,35.163819033210785,34.789468439318924,34.41511784542709,34.04076725153526,33.660063555373185,33.278691081967736,32.897318608562294,32.5159461351568,32.13457366175132,31.753201188345905,31.37182871494042,30.990456241534933,30.609083768129484,30.22771129472403,29.846338821318543,29.46496634791309,29.08359387450765,28.702221401102157,28.32084892769671,27.93947645429125,27.558103980885775,27.176731507480284,26.795359034074835,26.413986560669386,26.0326140872639,25.65124161385845,25.269869140452997,24.888496667047512,24.507124193642063,24.125751720236615,23.744379246831123,23.36300677342564,22.981634300020225,22.600261826614744,22.218889353209253,21.8375168798038,21.45614440639835,21.074771932992867,20.693399459587418,20.312026986181962,19.93065451277648,19.549282039371036,19.167909565965587,18.786537092560092,18.40516461915461,18.023792145749194,17.64241967234371,17.261047198938222,16.87967472553277,16.498302252127324,16.11692977872184,15.735557305316384,15.354184831910935,14.972812358505452,14.591439885099964,14.21006741169455,13.828694938289061,13.44732246488358,13.065949991478126,12.684577518072679,12.30320504466719,11.965977836051197,11.849476951382249,11.732976066713299,11.616475182044352,11.499974297375424,11.383473412706476,11.266972528037526,11.150471643368599,11.03397075869965,10.9174698740307,10.800968989361774,10.684468104692826,10.567967220023876,10.451466335354926,10.334965450686,10.218464566017051,10.101963681348103,9.985462796679176,9.868961912010226,9.752461027341276,9.63596014267235,9.519459258003401,9.402958373334453,9.286457488665524,9.169956603996575,9.053455719327626,8.936954834658678,8.820453949989751,8.703953065320801,8.587452180651852,8.470951295982925,8.354450411313977,8.257182696434032,8.173217210522887,8.089251724611724,8.005286238700563,7.921320752789402,7.837355266878257,7.753389780967096,7.669424295055934,7.585458809144788,7.5014933232336265,7.4175278373224645,7.333562351411318,7.249596865500157,7.165631379588996,7.08166589367785,6.997700407766688,6.913734921855527,6.829769435944366,6.74580395003322,6.6618384641220585,6.593572036653898,6.536884559120324,6.48019708158674,6.423509604053155,6.3668221265195815,6.310134648985997,6.253447171452413,6.196759693918828,6.140072216385255,6.08338473885167,6.026697261318086,5.970009783784512,5.913322306250928,5.856634828717343,5.79994735118377,5.743259873650185,5.6865723961166,5.629884918583026,5.573197441049443,5.516509963515858,5.459822485982273,5.403135008448699,5.346447530915114,5.28976005338153,5.233072575847957,5.176385098314372,5.119697620780788,5.063010143247213,5.00632266571363,4.949635188180045,4.89294771064646,4.8362602331128866],[51.02435723552638,51.07616923108846,51.12798122665055,51.17979322221262,51.2316052177747,51.283417213336776,51.33522920889885,51.38704120446093,51.43885320002302,51.490665195585095,51.54247719114717,51.59428918670925,51.64610118227132,51.697913177833414,51.74972517339549,51.801537168957566,51.85334916451964,51.90516116008172,51.956973155643794,52.00878515120587,52.06059714676795,52.11240914233004,52.164221137892106,52.21603313345419,52.26784512901626,52.31965712457834,52.371469120140425,52.423281115702494,52.475093111264584,52.52690510682666,52.57871710238874,52.63052909795082,52.68234109351289,52.73415308907497,52.78596508463704,52.83777708019913,52.88958907576121,52.94140107132328,52.99321306688537,53.045025062447436,53.09683705800953,53.1486490535716,53.20046104913368,53.252273044695755,53.30408504025783,53.35589703581991,53.407709031381984,53.459521026944074,53.51133302250615,53.56314501806823,53.6149570136303,53.66676900919238,53.718581004754455,53.77039300031653,53.82168232535489,53.87286711528964,53.92405190522436,53.97523669515909,54.02642148509382,54.07760627502854,54.12879106496328,54.17997585489801,54.231160644832734,54.282345434767464,54.3335302247022,54.384715014636924,54.435899804571655,54.487084594506385,54.538269384441115,54.589454174375845,54.640638964310575,54.6918237542453,54.74300854418003,54.794193334114766,54.84537812404949,54.896562913984226,54.94774770391895,54.99893249385368,55.05011728378841,55.10130207372315,55.15248686365787,55.2036716535926,55.25485644352733,55.30604123346207,55.35213327581674,55.39720676865542,55.44228026149409,55.48735375433277,55.53242724717144,55.57750074001011,55.62257423284879,55.66764772568746,55.712721218526134,55.75779471136481,55.80286820420349,55.84794169704216,55.893015189880835,55.93808868271951,55.98316217555819,56.02823566839687,56.07330916123554,56.11838265407421,56.163456146912885,56.20852963975156,56.25360313259023,56.298676625428904,56.343750118267586,56.388823611106254,56.43389710394493,56.4789705967836,56.52404408962228,56.569117582460954,56.61419107529963,56.659264568138305,56.70452379329634,56.74982016456329,56.79511653583024,56.84041290709719,56.88570927836414,56.93100564963108,56.97630202089803,57.02159839216499,57.06689476343193,57.11219113469888,57.15748750596583,57.20278387723279,57.24808024849974,57.29337661976669,57.33867299103363,57.38396936230059,57.42926573356753,57.47456210483449,57.51985847610144,57.56515484736838,57.61045121863533,57.65574758990229,57.70104396116923,57.74634033243618,57.79163670370313,57.83693307497009,57.882229446237034,57.92752581750399,57.972822188770934,58.018118560037884,58.06341493130484,58.10871130257179,58.154007673838734,58.19930404510569,58.244600416372634,58.28989678763959,58.335193158906534,58.38048953017349,58.425785901440435,58.47108227270738,58.516378643974335,58.56167501524128,58.606971386508235,58.652267757775185,58.697564129042135,58.74286050030909,58.788156871576035,58.83345324284299,58.878749614109935,58.924045985376885,58.969342356643836,59.01463872791078,59.059935099177736,59.10531899906314,59.15074666325775,59.19617432745236,59.24160199164698,59.2870296558416,59.33245732003621,59.37788498423084,59.42331264842545,59.46874031262007,59.51416797681468,59.5595956410093,59.605023305203915,59.65045096939853,59.69587863359315,59.741306297787766,59.78673396198238,59.832161626177,59.87758929037162,59.923016954566236,59.968444618760856,60.01387228295546,60.05929994715008,60.10472761134469,60.15015527553931,60.19558293973394,60.241010603928544,60.28643826812316,60.331865932317776,60.377293596512395,60.42272126070702,60.46814892490163,60.513576589096246,60.559004253290865,60.604431917485485,60.649859581680104,60.69528724587471,60.740714910069336,60.78614257426395,60.83157023845857,60.87699790265318,60.9224255668478,60.96785323104241,61.01328089523703,61.05870855943165,61.104136223626256,61.14956388782088,61.194991552015495,61.240419216210114,61.28584688040473,61.33127454459935,61.37670220879396,61.42212987298858,61.4675575371832,61.512985201377816,61.558412865572436,61.60384052976704,61.64926819396167,61.694695858156294,61.7401235223509,61.78555118654551,61.83097885074013,61.87640651493474,61.92183417912937,61.96726184332398,62.012689507518594,62.058117171713214,62.10305533992913,62.147969033243115,62.19288272655711,62.2377964198711,62.2827101131851,62.32762380649909,62.372537499813085,62.41745119312708,62.46236488644108,62.50727857975507,62.55219227306905,62.597105966383054,62.64201965969704,62.686933353011035,62.73184704632503,62.77676073963903,62.821674432953024,62.71687178398849,62.46235279274545,62.207833801502424,61.95331481025941,61.698795819016354,61.444276827773336,61.18975783653032,60.935238845287266,60.68071985404422,60.426200862801224,60.17168187155818,59.91716288031513,59.662643889072115,59.4081248978291,59.153605906586044,58.89908691534303,58.6445679241,58.390048932856956,58.13552994161394,57.881010950370914,57.63395907498766,57.4000311674518,57.16610325991598,56.93217535238013,56.69824744484427,56.46431953730842,56.230391629772576,55.99646372223672,55.76253581470088,55.52860790716504,55.294679999629174,55.06075209209332,54.826824184557495,54.59289627702164,54.35896836948578,54.125040461949936,53.8911125544141,53.657184646878235,53.42325673934239,53.18932883180655,52.9554009242707,52.721473016734855,52.48754510919901,52.253617201663154,52.019689294127296,51.785761386591474,51.5518334790556,51.317905571519745,51.08397766398391,50.85004975644807,50.61612184891221,50.38219394137637,50.14826603384053,49.91433812630467,49.680410218768806,49.446482311232984,49.21255440369712,48.97862649616127,48.744698588625425,48.51077068108958,48.276842773553724,48.04291486601789,47.808986958482045,47.57505905094618,47.34113114341035,47.10720323587451,46.873275328338636,46.63934742080278,46.40541951326696,46.171491605731106,45.93756369819524,45.703635790659405,45.46970788312356,45.2357799755877,45.00185206805186,44.76792416051602,44.53399625298016,44.300068345444316,44.06614043790847,43.832212530372615,43.59828462283676,43.364356715300914,43.13042880776507,42.84969333811054,42.47534274421871,42.100992150326874,41.72664155643501,41.35229096254318,40.977940368651346,40.603589774759484,40.22923918086762,39.85488858697582,39.480537993083956,39.106187399192095,38.73183680530026,38.35748621140843,37.98313561751657,37.60878502362473,37.23443442973291,36.86008383584104,36.485733241949205,36.11138264805738,35.73703205416551,35.36268146027365,34.988330866381816,34.61398027248999,34.23962967859812,33.86527908470629,33.49092849081446,33.1165778969226,32.742227303030774,32.36787670913894,31.99352611524707,31.61917552135521,31.244824927463412,30.870474333571543,30.496123739679682,30.121773145787852,29.74742255189602,29.373071958004154,28.99872136411232,28.624370770220494,28.250020176328626,27.875669582436796,27.501318988544966,27.126968394653098,26.752617800761236,26.378267206869403,26.003916612977573,25.629566019085708,25.255215425193878,24.88086483130205,24.506514237410183,24.132163643518354,23.75781304962652,23.38346245573466,23.00911186184279,22.634761267950996,22.26041067405913,21.886060080167265,21.511709486275436,21.137358892383606,20.76300829849174,20.388657704599908,20.014307110708078,19.639956516816213,19.265605922924383,18.891255329032553,18.516904735140688,18.142554141248823,17.76820354735703,17.393852953465164,17.0195023595733,16.64515176568147,16.270801171789635,15.89645057789777,15.52209998400594,15.14774939011411,14.773398796222246,14.39904820233038,14.024697608438586,13.650347014546718,13.275996420654852,12.896797416766878,12.515424943361433,12.134052469955943,11.79682526133995,11.680324376671003,11.571618504997605,11.487653019086444,11.4036875331753,11.319722047264136,11.235756561352975,11.151791075441828,11.067825589530669,10.983860103619508,10.89989461770836,10.8159291317972,10.731963645886037,10.647998159974875,10.564032674063728,10.480067188152567,10.396101702241406,10.312136216330261,10.228170730419098,10.144205244507939,10.060239758596792,9.97627427268563,9.892308786774468,9.808343300863324,9.724377814952161,9.640412329041002,9.55644684312984,9.472481357218694,9.388515871307533,9.30455038539637,9.220584899485225,9.136619413574063,9.0526539276629,8.968688441751755,8.884722955840594,8.800757469929431,8.71679198401827,8.632826498107123,8.548861012195962,8.464895526284803,8.380930040373656,8.296964554462495,8.212999068551333,8.129033582640186,8.045068096729025,7.961102610817864,7.877137124906718,7.793171638995557,7.709206153084395,7.625240667173233,7.541275181262088,7.457309695350927,7.373344209439764,7.2893787235286185,7.205413237617457,7.121447751706294,7.037482265795149,6.953516779883988,6.869551293972827,6.785585808061666,6.701620322150519,6.617654836239358,6.5336893503281965,6.44972386441705,6.365758378505888,6.281792892594728,6.197827406683582,6.11386192077242,6.029896434861259,5.945930948950113,5.861965463038951,5.777999977127789,5.6940344912166285,5.6100690053054825,5.52610351939432,5.442138033483159,5.358172547572013,5.274207061660852,5.190241575749691,5.106276089838545,5.022310603927383,4.938345118016222,4.8796685572393725,4.822981079705801],[51.33778455613526,51.38959655169734,51.441408547259414,51.4932205428215,51.54503253838357,51.59684453394565,51.648656529507726,51.7004685250698,51.75228052063189,51.80409251619397,51.85590451175605,51.90771650731812,51.959528502880204,52.01134049844228,52.06315249400436,52.11496448956644,52.166776485128516,52.21858848069059,52.27040047625267,52.32221247181475,52.37402446737683,52.42583646293891,52.47764845850098,52.52946045406307,52.581272449625146,52.633084445187215,52.6848964407493,52.736708436311375,52.78852043187346,52.840332427435534,52.89214442299761,52.943956418559694,52.99576841412177,53.04758040968385,53.09939240524593,53.151204400808005,53.20301639637009,53.25482839193216,53.30664038749425,53.35845238305632,53.4102643786184,53.46207637418048,53.51388836974255,53.56570036530463,53.617512360866705,53.66932435642878,53.721136351990864,53.77294834755295,53.824760343115024,53.8765723386771,53.928384334239176,53.98019632980125,54.032008325363336,54.08382032092541,54.13563231648749,54.187444312049564,54.23925630761165,54.29106830317373,54.3428802987358,54.394692294297876,54.446504289859966,54.49831628542204,54.55012828098412,54.601940276546195,54.65375227210827,54.705564267670354,54.75737626323243,54.80918825879451,54.86100025435658,54.912812249918666,54.964415177874194,55.01559996780892,55.066784757743655,55.117969547678385,55.16915433761311,55.220339127547845,55.27152391748257,55.322708707417306,55.37389349735203,55.425078287286766,55.476263077221496,55.52744786715622,55.57863265709095,55.62981744702568,55.67590948938036,55.72098298221904,55.76605647505771,55.81112996789639,55.85620346073506,55.901276953573735,55.94635044641241,55.991423939251085,56.03649743208975,56.08157092492843,56.12664441776711,56.17171791060578,56.21679140344446,56.26193918942513,56.30723556069208,56.35253193195903,56.39782830322598,56.44312467449293,56.488421045759885,56.533717417026836,56.57901378829378,56.624310159560736,56.66960653082768,56.71490290209463,56.76019927336158,56.80549564462853,56.85079201589548,56.89608838716243,56.94138475842938,56.986681129696336,57.03197750096328,57.07727387223023,57.12257024349718,57.16786661476413,57.21316298603108,57.25845935729804,57.30375572856498,57.34905209983194,57.39434847109888,57.43964484236584,57.48494121363278,57.53023758489973,57.57553395616669,57.62083032743364,57.66612669870058,57.71142306996754,57.75671944123448,57.80201581250144,57.84731218376839,57.89260855503533,57.93790492630228,57.98320129756923,58.02849766883618,58.07379404010313,58.11909041137008,58.164386782637024,58.20968315390398,58.25497952517094,58.300275896437874,58.34557226770483,58.390868638971774,58.436165010238724,58.48146138150568,58.526757752772625,58.57205412403958,58.61735049530653,58.662646866573475,58.70794323784043,58.75323960910738,58.798535980374325,58.84383235164128,58.88912872290823,58.934425094175175,58.97972146544213,59.025017836709075,59.070314207976026,59.11561057924298,59.160906950509926,59.20620332177688,59.25149969304383,59.296796064310776,59.34209243557773,59.38738880684468,59.43277270673008,59.47820037092469,59.5236280351193,59.56905569931393,59.61448336350854,59.65991102770316,59.70533869189778,59.750766356092385,59.796194020287004,59.84162168448162,59.88704934867625,59.932477012870855,59.977904677065474,60.02333234126009,60.068760005454706,60.11418766964932,60.159615333843945,60.20504299803855,60.25047066223317,60.29589832642779,60.3413259906224,60.386753654817014,60.43218131901164,60.47760898320626,60.52303664740087,60.56846431159549,60.61389197579011,60.65931963998472,60.70474730417934,60.75012601780284,60.79503971111684,60.83995340443084,60.88486709774483,60.92978079105881,60.974694484372804,61.019608177686806,61.06452187100081,61.10943556431479,61.15434925762879,61.19926295094278,61.24417664425678,61.28909033757076,61.334004030884756,61.37891772419875,61.42383141751276,61.46874511082674,61.51365880414073,61.558572497454726,61.60348619076872,61.64839988408272,61.69331357739671,61.7382272707107,61.7831409640247,61.82805465733868,61.872968350652684,61.91788204396668,61.96279573728067,62.00770943059467,62.05262312390865,62.09753681722266,62.14245051053664,62.18736420385063,62.232277897164636,62.27719159047862,62.32210528379262,62.36701897710661,62.41193267042061,62.456846363734606,62.5017600570486,62.54667375036259,62.59158744367658,62.636501136990574,62.681414830304576,62.72632852361856,62.77124221693256,62.81615591024655,62.861069603560544,62.90598329687454,62.950896990188525,62.99581068350252,63.04072437681651,63.085638070130514,63.13055176344451,63.02574911447997,62.77123012323693,62.51671113199391,62.262192140750884,62.00767314950784,61.75315415826482,61.4986351670218,61.24411617577876,60.98959718453571,60.73507819329271,60.48055920204966,60.226040210806616,59.9715212195636,59.71700222832058,59.462483237077535,59.20796424583451,58.953445254591486,58.69892626334845,58.44440727210542,58.1898882808624,57.93536928961935,57.680850298376306,57.42633130713331,57.171812315890264,56.917293324647225,56.6627743334042,56.408255342161176,56.15373635091814,55.89921735967512,55.64469836843209,55.39017937718904,55.135660385946,54.88114139470301,54.62662240345996,54.37210341221691,54.11758442097389,53.86306542973087,53.60854643848783,53.3540274472448,53.09950845600178,52.84498946475873,52.590470473515715,52.33595148227269,52.081432491029645,51.8269134997866,51.57239450854361,51.317875517300564,51.063356526057525,50.80883753481448,50.55431854357147,50.29979955232842,50.045280561085406,49.790761569842374,49.53624257859933,49.28172358735629,49.02720459611329,48.77268560487025,48.5181666136272,48.26364762238418,48.00912863114116,47.75460963989812,47.50009064865509,47.25914819776125,47.02522029022538,46.79129238268955,46.557364475153705,46.32343656761785,46.08950866008198,45.85558075254617,45.6216528450103,45.387724937474445,45.1537970299386,44.91986912240276,44.6859412148669,44.45201330733106,44.21808539979522,43.984157492259364,43.75022958472353,43.516301677187684,43.28237376965182,43.048445862115955,42.81451795458012,42.580590047044275,42.29985457738974,41.925503983497904,41.55115338960607,41.17680279571421,40.802452201822376,40.42810160793054,40.05375101403868,39.67940042014682,39.30504982625502,38.93069923236315,38.55634863847129,38.18199804457946,37.80764745068763,37.433296856795764,37.05894626290394,36.684595669012104,36.31024507512025,35.93589448122841,35.56154388733658,35.187193293444714,34.812842699552846,34.43849210566102,34.064141511769186,33.689790917877325,33.3154403239855,32.941089730093665,32.5667391362018,32.19238854230997,31.818037948418137,31.443687354526276,31.075627192083108,30.708045635043646,30.34046407800411,29.972882520964575,29.605300963925078,29.237719406885578,28.870137849846042,28.50255629280654,28.134974735767045,27.767393178727506,27.39981162168801,27.032230064648516,26.664648507608977,26.29706695056944,25.929485393529944,25.561903836490444,25.194322279450912,24.826740722411408,24.459159165371904,24.091577608332376,23.723996051292872,23.356414494253375,22.98883293721384,22.621251380174307,22.253669823134842,21.886088266095307,21.518506709055774,21.150925152016274,20.783343594976778,20.41576203793724,20.04818048089774,19.68059892385824,19.313017366818706,18.945435809779205,18.577854252739705,18.210272695700173,17.84269113866064,17.475109581621176,17.10752802458164,16.739946467542104,16.372364910502604,16.004783353463107,15.637201796423573,15.269620239384071,14.902038682344568,14.534457125305039,14.166875568265505,13.799294011226042,13.431712454186503,13.06413089714697,12.69654934010747,12.328967783067972,11.961386226028434,11.636866853784282,11.527658405516593,11.418449957248903,11.309241508981216,11.200033060713547,11.090824612445859,10.98161616417817,10.872407715910501,10.763199267642813,10.653990819375124,10.544782371107457,10.435573922839769,10.32636547457208,10.21715702630439,10.107948578036723,9.998740129769034,9.889531681501346,9.780323233233677,9.67111478496599,9.561906336698302,9.452697888430631,9.343489440162942,9.234280991895256,9.125072543627587,9.015864095359898,8.906655647092208,8.797447198824521,8.688238750556852,8.579030302289162,8.483732648695256,8.399767162784112,8.31580167687295,8.231836190961788,8.147870705050643,8.06390521913948,7.97993973322832,7.895974247317158,7.8120087614060125,7.7280432754948505,7.644077789583689,7.560112303672543,7.476146817761382,7.39218133185022,7.308215845939075,7.224250360027913,7.140284874116752,7.056319388205606,6.972353902294444,6.8883884163832825,6.80442293047212,6.720457444560975,6.636491958649813,6.552526472738652,6.468560986827506,6.384595500916344,6.319152299929067,6.265275459988876,6.2113986200486755,6.157521780108475,6.103644940168274,6.049768100228083,5.995891260287881,5.942014420347681,5.88813758040749,5.834260740467289,5.780383900527088,5.726507060586897,5.672630220646695,5.618753380706494,5.564876540766304,5.510999700826103,5.457122860885902,5.403246020945701,5.34936918100551,5.295492341065309,5.241615501125109,5.187738661184918,5.133861821244716,5.0799849813045155,5.0261081413643245,4.972231301424124,4.918354461483922,4.864477621543721,4.81060078160353],[51.648617303101766,51.70042929866385,51.752241294225925,51.804053289788,51.85586528535008,51.907677280912154,51.95948927647423,52.01130127203631,52.06311326759838,52.11492526316047,52.16673725872255,52.21854925428463,52.27036124984671,52.322173245408784,52.37398524097086,52.42579723653294,52.47760923209502,52.52942122765709,52.58123322321917,52.63304521878125,52.68485721434334,52.736669209905415,52.78848120546749,52.84029320102957,52.89210519659164,52.94391719215373,52.9957291877158,53.04754118327788,53.099353178839955,53.15116517440204,53.20297716996412,53.2547891655262,53.30660116108827,53.35841315665035,53.410225152212426,53.46203714777451,53.51384914333658,53.56566113889866,53.617473134460745,53.669285130022814,53.7210971255849,53.77290912114698,53.82472111670906,53.87653311227114,53.928345107833216,53.98015710339529,54.03196909895737,54.083781094519445,54.13559309008153,54.187405085643604,54.23921708120569,54.291029076767764,54.34284107232984,54.394653067891916,54.44646506345399,54.49827705901607,54.55008905457815,54.601901050140235,54.653713045702304,54.70552504126439,54.75733703682647,54.80914903238855,54.86096102795062,54.912773023512706,54.96458501907478,55.01639701463686,55.068209010198935,55.12002100576101,55.171833001323094,55.22364499688517,55.275456992447246,55.32726898800932,55.379080983571406,55.43089297913348,55.482704974695565,55.53451697025764,55.58632896581972,55.6381409613818,55.68995295694388,55.74176495250595,55.793576948068036,55.84584217230289,55.89819804127502,55.950553910247166,55.997100980671675,56.04248629138668,56.08787160210168,56.13318279674587,56.17847916801282,56.223775539279764,56.26907191054672,56.31436828181367,56.35966465308062,56.404961024347564,56.45025739561452,56.495553766881464,56.540850138148414,56.586146509415364,56.631442880682314,56.676739251949265,56.722035623216215,56.76733199448317,56.81262836575012,56.85792473701707,56.903221108284015,56.94851747955097,56.993813850817915,57.039110222084865,57.084406593351815,57.12970296461876,57.174999335885715,57.220295707152665,57.265592078419616,57.31088844968657,57.356184820953516,57.401481192220466,57.446777563487416,57.492073934754366,57.537370306021316,57.582666677288266,57.627963048555216,57.673259419822166,57.718555791089116,57.763852162356066,57.809148533623016,57.85444490488997,57.899741276156924,57.945037647423874,57.99033401869081,58.03563038995777,58.08092676122472,58.12622313249167,58.171519503758624,58.21681587502557,58.26211224629252,58.30740861755947,58.35270498882642,58.39800136009336,58.44329773136032,58.48859410262727,58.53389047389422,58.57918684516116,58.62448321642812,58.66977958769506,58.71507595896202,58.76037233022896,58.80566870149592,58.85096507276287,58.89626144402981,58.94155781529677,58.98685418656372,59.03215055783067,59.07744692909761,59.12274330036456,59.16803967163152,59.21333604289846,59.25863241416541,59.30392878543236,59.34922515669931,59.39452152796626,59.43981789923321,59.48511427050017,59.53041064176712,59.57570701303406,59.62100338430102,59.66629975556797,59.71159612683491,59.75662597623004,59.80152256468924,59.84641915314845,59.89131574160767,59.93621233006687,59.98110891852608,60.02600550698529,60.0709020954445,60.11581578870048,60.160729482014474,60.20564317532847,60.250556868642455,60.29547056195645,60.34038425527045,60.38529794858444,60.43021164189843,60.475125335212425,60.520039028526426,60.56495272184042,60.60986641515441,60.6547801084684,60.699693801782395,60.74460749509639,60.78952118841038,60.83443488172437,60.87934857503837,60.92426226835236,60.96917596166636,61.014089654980346,61.05900334829434,61.10391704160833,61.14883073492233,61.19374442823632,61.238658121550316,61.2835718148643,61.328485508178304,61.37339920149229,61.418312894806284,61.46322658812028,61.50814028143428,61.553053974748266,61.59796766806227,61.64288136137626,61.687795054690255,61.73270874800424,61.777622441318236,61.82253613463223,61.867449827946224,61.91236352126022,61.95727721457422,62.002190907888206,62.04710460120219,62.092018294516194,62.13693198783018,62.18184568114419,62.22675937445818,62.27167306777217,62.31658676108616,62.361500454400144,62.40641414771416,62.451327841028146,62.49624153434213,62.541155227656134,62.58606892097012,62.63098261428412,62.675896307598116,62.7208100009121,62.7657236942261,62.8106373875401,62.855551080854084,62.90046477416808,62.94537846748207,62.99029216079607,63.03520585411006,63.08011954742405,63.12503324073805,63.16994693405204,63.214860627366036,63.25977432068002,63.30468801399402,63.34960170730801,63.394515400622005,63.439429093936,63.33462644497148,63.080107453728424,62.8255884624854,62.571069471242396,62.31655047999934,62.06203148875632,61.807512497513294,61.552993506270255,61.29847451502721,61.043955523784206,60.78943653254116,60.534917541298114,60.2803985500551,60.02587955881208,59.77136056756903,59.516841576326,59.262322585082984,59.00780359383994,58.75328460259692,58.49876561135389,58.24424662011084,57.9897276288678,57.73520863762481,57.48068964638176,57.226170655138716,56.97165166389569,56.717132672652674,56.46261368140963,56.208094690166604,55.953575698923586,55.69905670768054,55.444537716437495,55.1900187251945,54.93549973395146,54.68098074270841,54.42646175146538,54.171942760222365,53.917423768979326,53.6629047777363,53.40838578649327,53.15386679525024,52.89934780400721,52.64482881276419,52.39030982152114,52.1357908302781,51.88127183903511,51.626752847792055,51.372233856549016,51.117714865305985,50.86319587406297,50.60867688281992,50.354157891576904,50.09963890033387,49.845119909090826,49.59060091784779,49.33608192660479,49.081562935361745,48.8270439441187,48.57252495287567,48.31800596163266,48.06348697038962,47.80896797914659,47.55444898790356,47.299929996660524,47.045411005417506,46.78705259782858,46.50904533772019,46.23103807761181,45.95303081750346,45.67502355739508,45.397016297286676,45.119009037178316,44.84100177706995,44.56299451696157,44.284987256853206,44.00697999674484,43.72897273663644,43.45096547652808,43.172958216419715,42.894950956311334,42.616943696202945,42.33893643609458,42.06092917598622,41.75524268082289,41.39419771554979,41.03315275027666,40.67210778500352,40.3110628197304,39.950017854457286,39.58897288918414,39.22792792391099,38.866882958637916,38.50583799336476,38.14479302809161,37.7837480628185,37.42270309754539,37.061658132272235,36.70061316699912,36.339568201726,35.97852323645286,35.61747827117975,35.25643330590663,34.89538834063348,34.534343375360336,34.17329841008722,33.812253444814104,33.45120847954096,33.09016351426784,32.72911854899473,32.368073583721575,32.00702861844846,31.64598365317535,31.282589587949886,30.915008030910347,30.547426473870882,30.17984491683135,29.812263359791814,29.444681802752317,29.077100245712817,28.709518688673278,28.341937131633784,27.974355574594284,27.60677401755475,27.23919246051525,26.871610903475748,26.504029346436216,26.13644778939668,25.768866232357183,25.401284675317683,25.033703118278147,24.666121561238644,24.298540004199147,23.93095844715961,23.56337689012011,23.195795333080618,22.82821377604108,22.460632219001546,22.09305066196208,21.725469104922546,21.35788754788301,20.990305990843517,20.622724433804017,20.25514287676448,19.887561319724977,19.51997976268548,19.152398205645945,18.784816648606444,18.417235091566944,18.04965353452741,17.68207197748788,17.31449042044841,16.94690886340888,16.579327306369343,16.211745749329843,15.844164192290345,15.476582635250812,15.109001078211307,14.74141952117181,14.373837964132274,14.00625640709274,13.638674850053278,13.271093293013744,12.903511735974206,12.535930178934711,12.16834862189521,11.800767064855677,11.47624769261152,11.367039244343829,11.257830796076142,11.148622347808454,11.039413899540785,10.930205451273098,10.820997003005408,10.71178855473774,10.602580106470052,10.493371658202364,10.384163209934695,10.274954761667004,10.165746313399318,10.056537865131629,9.947329416863962,9.838120968596272,9.728912520328583,9.619704072060916,9.510495623793226,9.401287175525539,9.29207872725787,9.182870278990181,9.073661830722493,8.964453382454824,8.855244934187137,8.746036485919447,8.656969049729534,8.578083715732737,8.499198381735923,8.420313047739107,8.341427713742307,8.262542379745492,8.183657045748678,8.104771711751876,8.025886377755063,7.947001043758247,7.868115709761433,7.7892303757646335,7.710345041767818,7.631459707771004,7.5525743737742035,7.47368903977739,7.394803705780574,7.315918371783774,7.23703303778696,7.158147703790146,7.079262369793345,7.000377035796531,6.921491701799716,6.842606367802902,6.763721033806102,6.6848356998092875,6.605950365812473,6.527065031815672,6.448179697818858,6.369294363822044,6.290409029825244,6.211523695828429,6.145203966932283,6.091327126992083,6.037450287051891,5.983573447111691,5.92969660717149,5.875819767231299,5.821942927291097,5.768066087350897,5.714189247410706,5.660312407470505,5.606435567530303,5.552558727590112,5.498681887649912,5.444805047709711,5.390928207769511,5.337051367829319,5.283174527889118,5.229297687948917,5.175420848008726,5.1215440080685255,5.067667168128324,5.013790328188133,4.959913488247932,4.906036648307731,4.85215980836753,4.79828296842734],[51.9477744764175,51.999586471979576,52.05139846754166,52.103210463103736,52.15502245866581,52.20683445422789,52.258646449789964,52.310458445352054,52.36227044091412,52.41408243647621,52.46589443203828,52.51770642760036,52.569518423162435,52.62133041872452,52.673142414286595,52.72495440984868,52.776766405410754,52.82857840097283,52.88039039653491,52.93220239209699,52.984014387659066,53.03582638322114,53.087638378783225,53.1394503743453,53.19126236990738,53.24307436546946,53.29488636103154,53.34669835659362,53.39851035215569,53.450322347717766,53.50213434327985,53.55394633884193,53.605758334404015,53.657570329966084,53.70938232552816,53.76119432109024,53.81300631665231,53.864818312214396,53.91663030777648,53.96844230333856,54.02025429890063,54.07206629446271,54.123878290024784,54.17569028558687,54.22750228114894,54.27931427671102,54.3311262722731,54.38293826783518,54.434750263397255,54.48656225895934,54.538374254521415,54.59018625008349,54.64199824564557,54.69381024120765,54.74562223676973,54.7974342323318,54.84924622789388,54.90105822345597,54.95287021901804,55.004682214580114,55.0564942101422,55.108306205704274,55.16011820126636,55.21193019682843,55.263923484061735,55.31627935303386,55.368635222006006,55.42099109097814,55.47334695995028,55.52570282892242,55.578058697894555,55.63041456686669,55.682770435838826,55.73512630481097,55.787482173783104,55.83983804275524,55.892193911727375,55.94454978069951,55.99690564967165,56.04926151864378,56.101617387615924,56.15397325658807,56.206329125560195,56.25868499453234,56.305232064956854,56.35061737567185,56.39600268638685,56.44138799710185,56.48677330781685,56.532158618531845,56.57754392924684,56.622929239961834,56.66831455067684,56.71369986139183,56.75908517210683,56.80447048282183,56.849855793536825,56.895241104251824,56.94062641496682,56.98601172568182,57.03139703639681,57.07678234711181,57.122167657826814,57.167523322146536,57.212819693413486,57.258116064680436,57.30341243594738,57.34870880721434,57.39400517848129,57.43930154974823,57.48459792101518,57.52989429228214,57.57519066354908,57.62048703481604,57.66578340608298,57.71107977734994,57.75637614861689,57.80167251988383,57.84696889115078,57.89226526241773,57.93756163368468,57.98285800495164,58.02815437621858,58.07345074748553,58.11874711875248,58.16404349001944,58.20933986128639,58.254636232553345,58.29993260382028,58.345228975087245,58.39052534635419,58.435821717621145,58.48111808888809,58.52641446015504,58.57171083142198,58.61700720268894,58.66230357395588,58.70759994522283,58.75289631648978,58.79819268775673,58.84348905902368,58.88878543029064,58.93408180155758,58.97937817282453,59.02467454409148,59.06997091535843,59.11526728662538,59.16056365789234,59.20586002915928,59.25115640042624,59.29645277169318,59.34174914296013,59.38704551422708,59.432341885494026,59.47763825676098,59.52293462802793,59.56823099929488,59.61352737056183,59.658823741828776,59.70412011309573,59.74941648436268,59.79471285562963,59.84000922689658,59.885305598163534,59.930601969430484,59.975898340697434,60.021194711964384,60.066224561359505,60.11112114981871,60.15601773827792,60.200914326737134,60.24581091519634,60.29070750365555,60.33560409211476,60.38050068057397,60.42539726903317,60.47029385749238,60.51519044595159,60.5600870344108,60.60498362287,60.64988021132922,60.69477679978842,60.739673388247624,60.78456997670684,60.82946656516605,60.874363153625254,60.91925974208446,60.96415633054368,61.00905291900288,61.05394950746209,61.0988460959213,61.14374268438051,61.18863927283971,61.233535861298925,61.278432449758135,61.32332903821734,61.36822562667655,61.41312221513575,61.45801880359497,61.50291539205418,61.54781198051339,61.5927085689726,61.63760515743181,61.68250174589102,61.72739833435021,61.77229492280942,61.81719151126863,61.86208809972784,61.906984688187045,61.95188127664626,61.99677786510547,62.041674453564674,62.086571042023884,62.13146763048309,62.1763642189423,62.22126080740151,62.266157395860716,62.311068238379676,62.355981931693684,62.40089562500768,62.445809318321665,62.490723011635666,62.53563670494966,62.58055039826365,62.62546409157765,62.670377784891635,62.71529147820563,62.76020517151963,62.80511886483362,62.85003255814762,62.894946251461604,62.9398599447756,62.98477363808959,63.02968733140359,63.07460102471758,63.119514718031574,63.16442841134557,63.20934210465957,63.254255797973556,63.29916949128755,63.344083184601544,63.38899687791553,63.433910571229525,63.478824264543526,63.52373795785751,63.56865165117151,63.61356534448551,63.658479037799495,63.70339273111349,63.74830642442749,63.64350377546296,63.388984784219915,63.1344657929769,62.879946801733865,62.62542781049082,62.3709088192478,62.116389828004785,61.86187083676174,61.60735184551869,61.35283285427569,61.09831386303265,60.8437948717896,60.58927588054658,60.33475688930356,60.08023789806051,59.82571890681749,59.57119991557447,59.31668092433143,59.062161933088404,58.80764294184537,58.55312395060233,58.29860495935928,58.04408596811629,57.789566976873246,57.5350479856302,57.280528994387176,57.026010003144165,56.77149101190112,56.516972020658095,56.24709536775801,55.96908810764962,55.69108084754122,55.41307358743289,55.135066327324495,54.85705906721611,54.579051807107746,54.30104454699938,54.023037286891,53.74503002678263,53.46702276667427,53.18901550656587,52.911008246457506,52.633000986349145,52.35499372624075,52.076986466132354,51.79897920602403,51.52097194591563,51.242964685807245,50.964957425698884,50.68695016559052,50.40894290548213,50.13093564537377,49.8529283852654,49.57492112515701,49.29691386504862,49.018906604940284,48.74089934483189,48.4628920847235,48.18488482461514,47.90687756450677,47.628870304398376,47.35086304429002,47.072855784181655,46.79484852407327,46.516841263964906,46.23883400385654,45.96082674374815,45.68281948363976,45.404812223531415,45.12680496342302,44.84879770331463,44.57079044320627,44.29278318309791,44.014775922989514,43.73676866288116,43.4587614027728,43.180754142664405,42.90274688255604,42.62473962244767,42.34673236233929,42.06872510223089,41.79071784212253,41.51271058201416,41.20702408685085,40.845979121577734,40.48493415630462,40.123889191031466,39.76284422575836,39.40179926048524,39.040754295212096,38.679709329938945,38.318664364665864,37.95761939939271,37.59657443411956,37.23552946884645,36.87448450357334,36.51343953830019,36.15239457302708,35.79134960775396,35.43030464248081,35.0692596772077,34.70821471193458,34.347169746661436,33.986124781388284,33.625079816115175,33.26403485084206,32.902989885568914,32.5419449202958,32.18089995502268,31.819854989749533,31.45881002447642,31.097765059203304,30.736720093930153,30.375675128657008,30.014630163383924,29.65358519811078,29.29254023283763,28.931495267564515,28.5704503022914,28.20940533701825,27.848360371745137,27.48731540647202,27.12627044119887,26.765225475925753,26.404180510652644,26.043135545379492,25.682090580106344,25.321045614833228,24.960000649560115,24.598955684286967,24.237910719013854,23.876865753740738,23.515820788467586,23.154775823194473,22.79373085792136,22.432685892648212,22.071640927375064,21.71059596210198,21.34955099682883,20.988506031555687,20.62746106628257,20.266416101009455,19.90537113573631,19.544326170463194,19.183281205190077,18.822236239916933,18.461191274643816,18.1001463093707,17.739101344097556,17.378056378824404,17.017011413551323,16.655966448278175,16.294921483005027,15.933876517731914,15.572831552458798,15.21178658718565,14.850741621912535,14.48969665663942,14.128651691366272,13.767606726093124,13.406561760820043,13.045516795546892,12.689764757285943,12.336241378550552,11.982717999815158,11.629194621079737,11.317545686377525,11.215268971840985,11.112992257304445,11.018916041800956,10.940030707804157,10.861145373807343,10.782260039810527,10.703374705813728,10.624489371816912,10.545604037820098,10.466718703823298,10.387833369826483,10.308948035829669,10.230062701832853,10.151177367836056,10.07229203383924,9.993406699842426,9.914521365845626,9.83563603184881,9.756750697851997,9.677865363855195,9.598980029858382,9.520094695861568,9.441209361864768,9.362324027867952,9.283438693871137,9.204553359874325,9.125668025877523,9.04678269188071,8.967897357883894,8.889012023887094,8.81012668989028,8.731241355893465,8.652356021896665,8.573470687899851,8.494585353903037,8.415700019906222,8.336814685909422,8.257929351912608,8.179044017915793,8.100158683918993,8.021273349922179,7.9423880159253635,7.863502681928564,7.78461734793175,7.705732013934934,7.626846679938135,7.547961345941321,7.469076011944505,7.390190677947691,7.311305343950892,7.232420009954076,7.153534675957262,7.074649341960463,6.995764007963648,6.916878673966833,6.8379933399700334,6.759108005973218,6.680222671976404,6.601337337979588,6.522452003982789,6.443566669985975,6.36468133598916,6.28579600199236,6.206910667995546,6.12802533399873,6.04914000000193,5.970254666005117,5.891369332008301,5.812483998011501,5.733598664014687,5.654713330017873,5.575827996021058,5.496942662024258,5.418057328027444,5.339171994030629,5.260286660033828,5.1814013260370135,5.1025159920402,5.0236306580434,4.944745324046585,4.8884541445519165,4.837254710688502,4.786055276825098],[52.246931649733234,52.29874364529532,52.350555640857394,52.40236763641947,52.454179631981546,52.50599162754362,52.5578036231057,52.60961561866779,52.661427614229865,52.71323960979194,52.76505160535402,52.81686360091609,52.86867559647817,52.92048759204025,52.972299587602336,53.02411158316441,53.07592357872649,53.127735574288565,53.17954756985064,53.231359565412724,53.28317156097481,53.33498355653688,53.38679555209896,53.43860754766103,53.49041954322312,53.54223153878519,53.594043534347264,53.645855529909355,53.697667525471424,53.74947952103351,53.80129151659558,53.85310351215766,53.90491550771974,53.95672750328181,54.0085394988439,54.06035149440598,54.11216348996805,54.16397548553014,54.21578748109221,54.2675994766543,54.319411472216366,54.37122346777845,54.423035463340526,54.4748474589026,54.52665945446468,54.578471450026754,54.63028344558883,54.68209544115092,54.73436066479271,54.786716533764846,54.83907240273698,54.891428271709124,54.94378414068126,54.996140009653395,55.04849587862553,55.10085174759767,55.15320761656981,55.205563485541944,55.25791935451408,55.31027522348622,55.36263109245835,55.41498696143049,55.46734283040263,55.51969869937477,55.57205456834691,55.62441043731904,55.67676630629117,55.72912217526331,55.781478044235456,55.833833913207584,55.88618978217973,55.93854565115186,55.990901520124,56.04325738909614,56.095613258068276,56.14796912704041,56.20032499601254,56.25268086498468,56.30503673395682,56.35739260292896,56.409748471901096,56.46210434087323,56.51446020984537,56.56681607881751,56.61336314924202,56.65874845995703,56.70413377067202,56.749519081387014,56.79490439210202,56.84028970281702,56.88567501353201,56.93106032424701,56.97644563496201,57.021830945676996,57.067216256391994,57.112601567107,57.157986877822,57.20337218853699,57.248757499251994,57.29414280996699,57.33952812068199,57.38491343139698,57.43029874211198,57.475684052826985,57.52106936354198,57.566454674256974,57.61183998497197,57.65722529568697,57.70261060640197,57.74799591711696,57.793381227831965,57.83876653854696,57.884151849261954,57.92953715997696,57.97492247069195,58.020307781406956,58.06569309212195,58.111078402836945,58.15646371355194,58.20184902426694,58.24716021881415,58.2924565900811,58.337752961348045,58.383049332615,58.42834570388195,58.4736420751489,58.51893844641586,58.5642348176828,58.609531188949745,58.6548275602167,58.70012393148366,58.7454203027506,58.79071667401756,58.8360130452845,58.88130941655145,58.9266057878184,58.97190215908535,59.0171985303523,59.06249490161925,59.107791272886196,59.15308764415315,59.1983840154201,59.24368038668705,59.288976757953996,59.33427312922095,59.3795695004879,59.424865871754854,59.470162243021804,59.515458614288754,59.560754985555704,59.606051356822654,59.651347728089604,59.69664409935655,59.74194047062349,59.78723684189045,59.83253321315739,59.87782958442435,59.923125955691305,59.96842232695825,60.0137186982252,60.05901506949215,60.1043114407591,60.149607812026055,60.194904183293,60.24020055455995,60.285496925826905,60.33079329709385,60.375823146488976,60.42071973494818,60.46561632340739,60.5105129118666,60.55540950032581,60.60030608878502,60.64520267724423,60.69009926570343,60.73499585416264,60.77989244262184,60.82478903108105,60.86968561954026,60.914582207999466,60.95947879645868,61.00437538491789,61.0492719733771,61.094168561836305,61.139065150295515,61.18396173875473,61.228858327213935,61.273754915673145,61.31865150413235,61.36354809259156,61.40844468105077,61.45334126950998,61.49823785796918,61.54313444642839,61.58803103488759,61.63292762334681,61.67782421180601,61.72272080026523,61.76761738872443,61.81251397718364,61.85741056564285,61.90230715410206,61.94720374256127,61.99210033102048,62.036996919479684,62.08189350793889,62.126790096398096,62.171686684857306,62.216583273316516,62.261479861775726,62.306376450234936,62.351273038694146,62.396169627153355,62.44106621561255,62.48596280407176,62.53085939253097,62.57575598099018,62.62065256944939,62.66554915790859,62.71044574636781,62.75534233482702,62.80023892328623,62.84513551174543,62.89003210020464,62.93492868866385,62.97982527712306,63.02472186558227,63.069618454041475,63.11451504250068,63.159411630959895,63.2043082194191,63.24920480787831,63.294101396337524,63.33899798479672,63.383894573255944,63.42879116171514,63.473687750174356,63.518584338633566,63.563480927092755,63.60837751555198,63.65327410401119,63.698170692470384,63.7430672809296,63.78796386938881,63.832735818567244,63.87693441682714,63.921133015087044,63.96533161334695,64.00953021160684,64.05372880986675,63.933287628988055,63.64820666897076,63.3631257089535,63.07804474893623,62.79296378891894,62.50788282890168,62.22280186888442,61.93772090886712,61.65263994884983,61.36755898883259,61.08247802881531,60.79739706879802,60.512316108780745,60.22723514876349,59.942154188746194,59.65707322872893,59.37199226871168,59.08691130869438,58.801830348677115,58.516749388659846,58.231668428642564,57.94658746862527,57.66150650860803,57.376425548590746,57.091344588573456,56.810905814219446,56.532898554111085,56.25489129400269,55.97688403389432,55.698876773785955,55.42086951367757,55.142862253569184,54.864854993460845,54.58684773335246,54.30884047324406,54.03083321313569,53.75282595302733,53.47481869291895,53.19681143281059,52.918804172702224,52.64079691259383,52.36278965248546,52.08478239237709,51.80677513226871,51.52876787216032,51.25076061205198,50.97275335194359,50.6947460918352,50.41673883172683,50.138731571618464,49.86072431151008,49.582717051401715,49.304709791293355,49.02670253118497,48.74869527107657,48.47068801096823,48.19268075085984,47.914673490751454,47.63666623064309,47.35865897053473,47.08065171042634,46.80264445031797,46.52463719020961,46.24662993010122,45.96862266999286,45.690615409884494,45.4126081497761,45.13460088966771,44.85659362955937,44.57858636945098,44.30057910934259,44.02257184923423,43.74456458912587,43.466557329017476,43.18855006890911,42.91054280880075,42.63253554869235,42.35452828858399,42.07652102847563,41.798513768367236,41.520506508258855,41.24249924815049,40.96449198804213,40.6588054928788,40.29776052760568,39.93671556233258,39.57567059705942,39.214625631786305,38.8535806665132,38.492535701240044,38.131490735966906,37.77044577069382,37.409400805420674,37.04835584014752,36.68731087487441,36.3262659096013,35.965220944328145,35.60417597905503,35.24313101378191,34.88208604850877,34.52104108323565,34.159996117962535,33.79895115268939,33.43790618741624,33.07686122214312,32.71581625687001,32.35477129159686,31.99372632632375,31.632681361050636,31.274735541583063,30.921212162847674,30.567688784112278,30.214165405376857,29.860642026641433,29.507118647906076,29.153595269170648,28.800071890435227,28.446548511699834,28.093025132964442,27.739501754229018,27.38597837549363,27.032454996758233,26.678931618022812,26.32540823928742,25.97188486055203,25.61836148181661,25.264838103081182,24.91131472434579,24.5577913456104,24.204267966874973,23.850744588139584,23.49722120940419,23.143697830668767,22.790174451933378,22.436651073197986,22.08312769446256,21.729604315727137,21.37608093699178,21.022557558256356,20.66903417952093,20.31551080078554,19.96198742205015,19.608464043314726,19.254940664579333,18.90141728584394,18.547893907108516,18.194370528373128,17.840847149637735,17.48732377090231,17.133800392166886,16.78027701343153,16.4267536346961,16.07323025596068,15.719706877225288,15.366183498489896,15.012660119754473,14.659136741019083,14.30561336228369,13.952089983548266,13.598566604812842,13.245043226077483,12.89151984734206,12.537996468606636,12.184473089871243,11.830949711135853,11.47742633240043,11.165777397698218,11.063500683161678,10.961223968625138,10.858947254088598,10.756670539552076,10.654393825015536,10.552117110478996,10.449840395942475,10.347563681405934,10.245286966869395,10.143010252332875,10.040733537796335,9.938456823259795,9.836180108723255,9.733903394186733,9.631626679650193,9.529349965113653,9.427073250577132,9.32479653604059,9.22251982150405,9.12024310696753,9.01796639243099,8.91568967789445,8.81341296335793,8.71113624882139,8.608859534284848,8.50658281974831,8.404306105211788,8.302029390675246,8.19975267613871,8.097475961602186,7.995199247065646,7.892922532529107,7.790645817992585,7.688369103456044,7.586092388919505,7.498670505729562,7.419785171732761,7.340899837735947,7.262014503739132,7.183129169742333,7.104243835745518,7.025358501748704,6.946473167751903,6.867587833755088,6.7887024997582746,6.709817165761475,6.63093183176466,6.56676462376563,6.515565189902216,6.464365756038811,6.413166322175397,6.361966888311983,6.310767454448579,6.259568020585165,6.208368586721751,6.157169152858346,6.105969718994933,6.054770285131518,6.003570851268104,5.9523714174046995,5.9011719835412855,5.849972549677871,5.798773115814466,5.747573681951053,5.696374248087639,5.645174814224234,5.5939753803608205,5.5427759464974065,5.491576512634001,5.440377078770588,5.389177644907173,5.33797821104376,5.286778777180356,5.235579343316941,5.1843799094535274,5.133180475590123,5.081981041726708,5.030781607863295,4.979582173999891,4.928382740136476,4.8771833062730625,4.8259838724096475,4.774784438546243],[52.546088823048976,52.59790081861106,52.64971281417313,52.70152480973521,52.753336805297295,52.80514880085937,52.85696079642145,52.90877279198352,52.9605847875456,53.01239678310769,53.064208778669766,53.116020774231835,53.16783276979392,53.219644765356,53.27145676091808,53.32326875648016,53.37508075204223,53.42689274760431,53.47870474316639,53.53051673872847,53.58232873429054,53.634140729852625,53.685952725414694,53.73776472097678,53.78957671653885,53.84138871210094,53.89320070766301,53.94501270322509,53.996824698787165,54.048636694349256,54.100448689911325,54.152441976551565,54.20479784552371,54.25715371449584,54.30950958346798,54.36186545244012,54.414221321412256,54.46657719038439,54.51893305935653,54.57128892832867,54.623644797300805,54.67600066627294,54.72835653524508,54.78071240421721,54.83306827318935,54.88542414216148,54.937780011133626,54.99013588010576,55.0424917490779,55.09484761805003,55.147203487022175,55.19955935599431,55.251915224966446,55.30427109393858,55.356626962910724,55.40898283188286,55.461338700854995,55.51369456982713,55.566050438799266,55.6184063077714,55.670762176743544,55.72311804571568,55.77547391468782,55.82782978365996,55.88018565263209,55.93254152160423,55.984897390576364,56.0372532595485,56.089609128520635,56.14196499749278,56.19432086646491,56.24667673543705,56.299032604409184,56.35138847338132,56.403744342353455,56.4561002113256,56.50845608029773,56.56081194926987,56.61316781824201,56.66552368721415,56.71787955618629,56.770235425158425,56.82259129413056,56.87494716310269,56.92149423352721,56.96687954424221,57.01226485495721,57.05765016567221,57.1030354763872,57.1484207871022,57.1938060978172,57.2391914085322,57.28457671924719,57.32996202996219,57.37534734067719,57.420732651392186,57.46611796210718,57.51150327282219,57.55688858353717,57.60227389425218,57.64765920496718,57.693044515682175,57.738429826397166,57.78381513711217,57.82920044782716,57.87458575854216,57.91997106925717,57.965356379972164,58.010741690687155,58.05612700140216,58.10151231211715,58.14689762283215,58.19228293354715,58.23766824426215,58.283053554977144,58.328438865692135,58.37382417640714,58.41920948712213,58.46459479783712,58.50998010855213,58.55536541926712,58.600750729982124,58.64613604069712,58.69152135141211,58.736906662127126,58.78229197284212,58.827677283557115,58.87306259427211,58.918447904987104,58.9638332157021,59.0092185264171,59.054603837132106,59.0999891478471,59.14537445856209,59.19075976927708,59.236145079992085,59.281500744214824,59.32679711548178,59.372093486748724,59.417389858015675,59.462686229282625,59.50798260054958,59.553278971816525,59.598575343083475,59.643871714350425,59.689168085617375,59.73446445688433,59.77976082815128,59.82505719941823,59.87035357068518,59.91564994195213,59.96094631321908,60.006242684486025,60.051539055752976,60.096835427019926,60.142131798286876,60.187428169553826,60.232724540820776,60.278020912087726,60.32331728335468,60.368613654621626,60.413910025888576,60.459206397155526,60.504502768422476,60.549799139689426,60.59509551095638,60.64039188222333,60.68542173161845,60.73031832007766,60.775214908536874,60.82011149699608,60.86500808545529,60.90990467391449,60.95480126237371,60.999697850832916,61.04459443929212,61.08949102775132,61.13438761621053,61.17928420466974,61.22418079312895,61.26907738158816,61.31397397004737,61.358870558506574,61.403767146965784,61.448663735425,61.493560323884196,61.53845691234341,61.583353500802616,61.628250089261826,61.673146677721036,61.718043266180246,61.762939854639455,61.80783644309866,61.85273303155787,61.89762962001707,61.94252620847629,61.9874227969355,62.0323193853947,62.07721597385391,62.12211256231312,62.16700915077233,62.21190573923154,62.25680232769075,62.30169891614996,62.34659550460916,62.391492093068365,62.43638868152758,62.481285269986785,62.526181858445995,62.571078446905204,62.615975035364414,62.660871623823624,62.705768212282834,62.75066480074203,62.79556138920124,62.84045797766045,62.88535456611966,62.930051730444674,62.97425032870458,63.01844892696449,63.06264752522438,63.10684612348428,63.151044721744185,63.19524332000408,63.239441918263985,63.28364051652388,63.327839114783785,63.37203771304368,63.41623631130359,63.46043490956349,63.50463350782339,63.548832106083296,63.59303070434319,63.6372293026031,63.681427900863,63.725626499122896,63.7698250973828,63.8140236956427,63.8582222939026,63.9024208921625,63.94661949042241,63.9908180886823,64.03501668694221,64.07921528520211,64.123413883462,64.1676124817219,64.21181107998181,64.25600967824172,64.3002082765016,64.34440687476152,64.22396569388282,63.938884733865535,63.65380377384827,63.368722813831,63.08364185381372,62.79856089379645,62.51347993377919,62.228398973761884,61.9433180137446,61.65823705372736,61.37315609371008,61.08807513369278,60.802994173675515,60.51791321365825,60.23283225364097,59.94775129362371,59.662670333606435,59.377589373589146,59.092508413571885,58.807427453554624,58.52234649353733,58.23726553352004,57.952184573502805,57.667103613485516,57.382022653468226,57.09694169345096,56.81186073343369,56.52677977341641,56.24169881339914,55.95661785338187,55.67153689336459,55.38645593334729,55.10137497333006,54.81629401331277,54.531213053295474,54.24613209327822,53.96105113326095,53.67597017324366,53.39088921322639,53.105808253209126,52.82072729319184,52.53564633317457,52.250565373157315,51.96548441314002,51.680403453122736,51.395322493105496,51.1102415330882,50.82516057307092,50.54007961305364,50.25499865303638,49.96991769301909,49.68483673300183,49.39975577298457,49.11467481296728,48.829593852949984,48.544512892932744,48.259431932915454,47.974350972898165,47.689270012880904,47.40418905286364,47.119108092846346,46.834027132829085,46.54894617281182,46.26386521279453,45.97878425277727,45.69370329276,45.408622332742716,45.12354137272542,44.83846041270818,44.55337945269089,44.26829849267361,43.97730065412289,43.65649910920172,43.33569756428052,43.014896019359355,42.6940944744382,42.373292929517,42.05249138459583,41.73168983967467,41.41088829475348,41.09008674983228,40.769285204911114,40.448483659989954,40.11875762603719,39.77118261402135,39.423607602005504,39.07603258998962,38.728457577973785,38.38088256595793,38.03330755394206,37.685732541926185,37.338157529910376,36.990582517894495,36.64300750587862,36.295432493862776,35.94785748184693,35.60028246983106,35.25270745781521,34.905132445799374,34.557557433783494,34.20998242176765,33.86240740975181,33.51483239773593,33.16725738572005,32.819682373704204,32.472107361688366,32.124532349672485,31.776957337656647,31.429382325640802,31.081807313624928,30.73423230160908,30.386657289593238,30.03908227757736,29.691507265561484,29.34393225354567,28.996357241529793,28.648303601755913,28.294780223020524,27.94125684428513,27.587733465549707,27.234210086814315,26.880686708078922,26.527163329343498,26.17363995060811,25.820116571872717,25.466593193137292,25.113069814401868,24.759546435666476,24.406023056931087,24.05249967819566,23.698976299460274,23.345452920724878,22.991929541989457,22.63840616325406,22.284882784518672,21.93135940578325,21.577836027047823,21.224312648312466,20.870789269577045,20.517265890841617,20.163742512106225,19.810219133370836,19.456695754635412,19.10317237590002,18.749648997164627,18.396125618429203,18.042602239693814,17.68907886095842,17.335555482222997,16.982032103487576,16.628508724752216,16.27498534601679,15.921461967281367,15.567938588545976,15.214415209810586,14.86089183107516,14.507368452339769,14.153845073604376,13.800321694868952,13.446798316133528,13.09327493739817,12.739751558662746,12.386228179927322,12.03270480119193,11.67918142245654,11.325658043721116,11.014009109018904,10.911732394482364,10.809455679945824,10.707178965409284,10.604902250872764,10.502625536336225,10.400348821799682,10.298072107263163,10.195795392726623,10.093518678190083,9.991241963653561,9.888965249117021,9.786688534580481,9.684411820043941,9.582135105507419,9.479858390970879,9.377581676434339,9.27530496189782,9.173028247361279,9.070751532824739,8.970237579154148,8.8961650694971,8.822092559840051,8.748020050183017,8.673947540525969,8.599875030868922,8.525802521211872,8.451730011554838,8.37765750189779,8.303584992240742,8.229512482583708,8.155439972926658,8.081367463269611,8.007294953612575,7.933222443955529,7.859149934298481,7.7850774246414325,7.7110049149843976,7.636932405327348,7.562859895670301,7.488787386013266,7.414714876356218,7.34064236669917,7.2665698570421355,7.192497347385086,7.118424837728039,7.044352328071003,6.970279818413957,6.8962073087569085,6.822134799099859,6.748062289442825,6.673989779785778,6.599917270128729,6.525844760471694,6.451772250814646,6.377699741157598,6.303627231500563,6.229554721843514,6.155482212186468,6.0814097025294185,6.0073371928723835,5.933264683215336,5.859192173558288,5.787502277535612,5.736302843672198,5.685103409808783,5.63390397594538,5.582704542081966,5.531505108218552,5.480305674355147,5.429106240491733,5.377906806628318,5.326707372764905,5.2755079389015,5.224308505038087,5.173109071174673,5.121909637311267,5.070710203447854,5.019510769584439,4.968311335721035,4.917111901857622,4.865912467994208,4.8147130341307935,4.763513600267389],[52.84524599636471,52.89705799192679,52.94886998748886,53.000681983050946,53.05249397861303,53.104305974175105,53.15611796973718,53.20792996529926,53.25974196086134,53.31155395642342,53.3633659519855,53.41517794754757,53.466989943109645,53.51880193867173,53.57061393423381,53.62287915728254,53.67523502625469,53.727590895226825,53.779946764198954,53.832302633171096,53.88465850214324,53.93701437111537,53.98937024008751,54.04172610905964,54.09408197803178,54.146437847003924,54.19879371597605,54.251149584948195,54.30350545392033,54.355861322892466,54.40821719186461,54.46057306083674,54.51292892980888,54.565284798781015,54.61764066775315,54.66999653672529,54.72235240569742,54.774708274669564,54.8270641436417,54.879420012613835,54.93177588158598,54.984131750558106,55.03648761953025,55.08884348850239,55.14119935747452,55.193555226446655,55.245911095418805,55.29826696439093,55.350622833363076,55.402978702335204,55.45533457130735,55.50769044027949,55.56004630925162,55.61240217822376,55.66475804719589,55.71711391616803,55.76946978514017,55.8218256541123,55.87418152308444,55.92653739205658,55.97889326102871,56.03124913000085,56.08360499897299,56.13596086794512,56.18831673691726,56.2406726058894,56.29302847486153,56.34538434383367,56.39774021280581,56.45009608177794,56.502451950750086,56.554807819722214,56.60716368869436,56.65951955766649,56.71187542663863,56.76423129561077,56.8165871645829,56.86894303355505,56.92129890252719,56.97365477149931,57.026010640471455,57.07836650944359,57.130722378415726,57.18307824738787,57.22962531781239,57.27501062852738,57.32039593924238,57.36578124995739,57.41116656067238,57.456551871387376,57.501937182102374,57.54732249281737,57.59270780353237,57.63809311424737,57.68347842496237,57.728863735677365,57.774249046392356,57.81963435710736,57.86501966782235,57.91040497853736,57.95579028925235,58.00117559996735,58.046560910682345,58.09194622139734,58.13733153211234,58.18271684282734,58.22810215354234,58.27348746425733,58.31887277497232,58.364258085687325,58.409643396402316,58.45502870711732,58.50041401783232,58.54579932854732,58.591184639262316,58.63656994997731,58.681955260692305,58.72734057140731,58.772725882122295,58.81811119283731,58.8634965035523,58.908881814267296,58.954267124982294,58.999652435697286,59.04503774641229,59.09042305712728,59.13580836784229,59.181193678557285,59.22657898927228,59.271964299987275,59.31734961070227,59.36273492141728,59.408120232132276,59.45350554284726,59.49889085356226,59.54427616427725,59.58966147499226,59.635046785707246,59.68043209642225,59.72581740713724,59.77120271785223,59.816588028567246,59.86197333928224,59.907358649997235,59.952743960712226,59.99812927142723,60.04351458214224,60.08889989285722,60.13428520357222,60.179670514287224,60.225055825002215,60.27044113571722,60.31582644643221,60.36113764088245,60.4064340121494,60.45173038341635,60.4970267546833,60.54232312595025,60.58761949721719,60.63291586848415,60.67821223975109,60.72350861101805,60.76880498228499,60.81410135355194,60.85939772481889,60.90469409608584,60.94999046735279,60.99502031674792,61.03991690520713,61.08481349366633,61.12971008212554,61.17460667058475,61.21950325904396,61.26439984750317,61.30929643596238,61.35419302442159,61.3990896128808,61.443986201339996,61.488882789799206,61.533779378258416,61.578675966717626,61.623572555176835,61.668469143636045,61.713365732095255,61.758262320554465,61.80315890901367,61.848055497472885,61.89295208593208,61.93784867439129,61.9827452628505,62.027367642322105,62.071566240582,62.1157648388419,62.15996343710181,62.20416203536171,62.2483606336216,62.29255923188151,62.33675783014141,62.38095642840131,62.42515502666121,62.46935362492111,62.51355222318101,62.557750821440905,62.601949419700816,62.646148017960726,62.690346616220616,62.73454521448052,62.77874381274042,62.82294241100033,62.86714100926022,62.911339607520134,62.95553820578003,62.99973680403993,63.04393540229982,63.088134000559734,63.13233259881963,63.17653119707953,63.22072979533943,63.264928393599334,63.30912699185923,63.35332559011914,63.39752418837904,63.44172278663894,63.48592138489884,63.53011998315874,63.574318581418645,63.61851717967855,63.662715777938445,63.70691437619834,63.751112974458245,63.79531157271815,63.839510170978045,63.883708769237955,63.92790736749785,63.972105965757756,64.01630456401766,64.06050316227756,64.10470176053747,64.14890035879736,64.19309895705726,64.23729755531716,64.28149615357705,64.32569475183696,64.36989335009686,64.41409194835677,64.45829054661667,64.50248914487656,64.54668774313646,64.59088634139637,64.63508493965628,64.51464375877757,64.22956279876028,63.944481838743016,63.65940087872576,63.374319918708466,63.08923895869121,62.80415799867394,62.519077038656654,62.23399607863936,61.948915118622125,61.663834158604836,61.37875319858753,61.09367223857028,60.80859127855301,60.52351031853572,60.23842935851846,59.95334839850119,59.66826743848391,59.38318647846664,59.09810551844938,58.81302455843209,58.5279435984148,58.24286263839757,57.95778167838027,57.672700718362975,57.387619758345714,57.10253879832846,56.81745783831116,56.532376878293896,56.247295918276635,55.962214958259345,55.677133998242056,55.392053038224816,55.10697207820753,54.82189111819023,54.53681015817297,54.25172919815571,53.96664823813842,53.68156727812116,53.39648631810388,53.11140535808659,52.82632439806933,52.541243438052064,52.256162478034774,51.97108151801749,51.68600055800025,51.400919597982956,51.115838637965666,50.81476012008252,50.49395857516135,50.173157030240155,49.852355485318995,49.53155394039783,49.21075239547663,48.88995085055544,48.5691493056343,48.2483477607131,47.927546215791914,47.60674467087074,47.28594312594958,46.965141581028384,46.644340036107224,46.323538491186056,46.002736946264854,45.681935401343694,45.361133856422526,45.04033231150133,44.719530766580135,44.398729221658996,44.0779276767378,43.757126131816605,43.436324586895445,43.11552304197427,42.794721497053075,42.473919952131915,42.15311840721075,41.83231686228956,41.51151531736839,41.190713772447225,40.86991222752603,40.549110682604834,40.22830913768367,39.9075075927625,39.57778155880975,39.2302065467939,38.88263153477806,38.535056522762176,38.18748151074634,37.83990649873049,37.49233148671462,37.144756474698745,36.79718146268293,36.449606450667055,36.102031438651174,35.75445642663533,35.406881414619484,35.05930640260361,34.711731390587765,34.36415637857192,34.016581366556046,33.66900635454021,33.32143134252436,32.97385633050848,32.6262813184926,32.278706306476764,31.93113129446092,31.58355628244504,31.235981270429196,30.888406258413355,30.540831246397477,30.193256234381636,29.84568122236579,29.498106210349917,29.150531198334036,28.802956186318227,28.45538117430235,28.107806162286476,27.760231150270627,27.41265613825479,27.065081126238912,26.717506114223067,26.369931102207225,26.022356090191348,25.674781078175503,25.327206066159658,24.979631054143784,24.632056042127907,24.28448103011206,23.93690601809622,23.58933100608034,23.241755994064498,22.894180982048653,22.54660597003278,22.199030958016934,21.851455946001092,21.503880933985215,21.156305921969338,20.80873090995353,20.461155897937648,20.113580885921774,19.76600587390593,19.418430861890087,19.070855849874206,18.723280837858365,18.375705825842523,18.028130813826643,17.6805558018108,17.33298078979496,16.985405777779082,16.637830765763205,16.290255753747395,15.942680741731515,15.595105729715641,15.247530717699796,14.899955705683954,14.55815354950303,14.21876554329945,13.879377537095866,13.539989530892253,13.20060152468864,12.861213518485089,12.521825512281476,12.182437506077864,11.843049499874283,11.5036614936707,11.164273487467087,10.86549386258337,10.769756144298757,10.674018426014143,10.57828070772953,10.482542989444934,10.38680527116032,10.291067552875706,10.195329834591112,10.099592116306498,10.021908783560354,9.94783627390332,9.873763764246274,9.799691254589224,9.725618744932175,9.651546235275141,9.577473725618091,9.503401215961045,9.429328706304009,9.35525619664696,9.281183686989912,9.207111177332878,9.13303866767583,9.058966158018782,8.984893648361748,8.910821138704701,8.836748629047653,8.762676119390605,8.688603609733569,8.614531100076523,8.540458590419473,8.466386080762438,8.39231357110539,8.318241061448342,8.244168551791308,8.17009604213426,8.096023532477211,8.021951022820163,7.947878513163128,7.87380600350608,7.799733493849032,7.725660984191997,7.6515884745349485,7.5775159648779,7.503443455220866,7.429370945563818,7.355298435906769,7.281225926249735,7.207153416592687,7.133080906935638,7.059008397278591,6.984935887621557,6.910863377964508,6.8367908683074585,6.7627183586504245,6.688645848993376,6.614573339336328,6.540500829679294,6.466428320022246,6.392355810365197,6.31828330070815,6.244210791051115,6.170138281394067,6.096065771737019,6.021993262079984,5.947920752422935,5.873848242765887,5.799775733108852,5.725703223451804,5.651630713794757,5.577558204137722,5.503485694480674,5.429413184823625,5.355340675166578,5.281268165509542,5.2071956558524946,5.141598188718759,5.09295096511596,5.0443037415131515,4.995656517910344,4.947009294307546,4.898362070704738,4.84971484710193,4.801067623499122,4.752420399896323],[53.14213077651395,53.19448664548609,53.24684251445822,53.29919838343036,53.351554252402494,53.403910121374636,53.45626599034677,53.50862185931891,53.56097772829105,53.61333359726318,53.665689466235314,53.71804533520746,53.7704012041796,53.82275707315173,53.87511294212386,53.927468811096,53.97982468006814,54.03218054904027,54.08453641801241,54.13689228698455,54.18924815595669,54.241604024928826,54.29395989390096,54.3463157628731,54.39867163184524,54.451027500817375,54.5033833697895,54.55573923876165,54.60809510773378,54.660450976705924,54.71280684567806,54.76516271465019,54.81751858362233,54.869874452594466,54.92223032156661,54.974586190538744,55.02694205951087,55.07929792848302,55.13165379745515,55.18400966642729,55.23636553539943,55.288721404371564,55.34107727334371,55.39343314231584,55.44578901128798,55.49814488026012,55.55050074923225,55.60285661820439,55.65521248717652,55.70756835614866,55.7599242251208,55.812280094092934,55.864635963065076,55.91699183203721,55.96934770100935,56.02170356998148,56.07405943895362,56.12641530792576,56.1787711768979,56.23112704587003,56.28348291484217,56.33583878381431,56.388194652786446,56.44055052175858,56.49290639073072,56.54526225970285,56.597618128674995,56.64997399764713,56.702329866619266,56.75468573559141,56.80704160456354,56.85939747353568,56.911753342507815,56.96410921147995,57.01646508045209,57.06882094942422,57.121176818396364,57.1735326873685,57.225888556340635,57.27824442531278,57.33060029428491,57.38305000291506,57.43596891354329,57.48888782417152,57.53549966951357,57.5808501017984,57.62621797333658,57.67160328405158,57.716988594766576,57.762373905481574,57.807759216196565,57.853144526911564,57.89852983762657,57.94391514834156,57.98930045905656,58.034685769771556,58.080071080486555,58.12545639120155,58.17084170191655,58.21622701263155,58.26161232334654,58.30699763406154,58.352382944776544,58.39776825549154,58.44315356620653,58.48853887692153,58.53392418763653,58.57930949835153,58.624694809066526,58.670080119781524,58.71546543049652,58.76085074121151,58.80623605192652,58.85162136264151,58.897006673356515,58.942391984071506,58.987777294786504,59.0331626055015,59.07854791621649,59.1239332269315,59.1693185376465,59.214703848361495,59.260089159076486,59.30547446979149,59.35085978050648,59.39624509122149,59.441630401936486,59.487015712651484,59.532401023366475,59.57778633408148,59.62317164479647,59.66855695551148,59.713942266226475,59.75932757694146,59.804712887656464,59.85009819837146,59.89548350908645,59.94086881980145,59.98625413051646,60.03163944123145,60.077024751946446,60.122410062661444,60.16779537337645,60.21318068409144,60.25856599480644,60.30395130552144,60.34933661623644,60.39472192695143,60.440107237666425,60.48549254838143,60.53087785909642,60.576263169811426,60.62164848052642,60.66703379124141,60.712419101956414,60.757804412671405,60.80318972338641,60.8485750341014,60.8939603448164,60.9393456555314,60.984730966246396,61.030116276961394,61.07550158767639,61.12088689839139,61.16627220910639,61.21165751982139,61.25704283053638,61.30162613267803,61.34580843053299,61.389990728387964,61.43417302624293,61.4783553240979,61.522537621952864,61.56671991980783,61.6109022176628,61.65508451551777,61.69926681337273,61.74346392983814,61.78766252809804,61.83186112635794,61.876059724617846,61.92025832287774,61.964456921137646,62.00865551939755,62.05285411765745,62.09705271591735,62.141251314177254,62.18544991243715,62.229648510697054,62.27384710895695,62.31804570721686,62.362244305476764,62.40644290373666,62.45064150199656,62.49484010025646,62.539038698516364,62.583237296776254,62.627435895036164,62.67163449329607,62.715833091555965,62.76003168981587,62.80423028807577,62.848428886335675,62.89262748459558,62.936826082855475,62.98102468111538,63.02522327937528,63.06942187763517,63.113620475895075,63.15781907415498,63.20201767241488,63.24621627067478,63.29041486893468,63.334613467194586,63.37881206545449,63.42301066371439,63.46720926197429,63.511407860234186,63.55560645849409,63.59980505675399,63.6440036550139,63.68820225327379,63.7324008515337,63.77659944979359,63.820798048053504,63.864996646313394,63.9091952445733,63.953393842833194,63.997592441093104,64.041791039353,64.08598963761291,64.13018823587281,64.1743868341327,64.21858543239262,64.26278403065251,64.30698262891241,64.3511812271723,64.39537982543222,64.43957842369211,64.48377702195202,64.52797562021192,64.57217421847182,64.61637281673173,64.66057141499162,64.70477001325152,64.74896861151143,64.79316720977133,64.83736580803122,64.88156440629113,64.92576300455103,64.80532182367233,64.52024086365505,64.23515990363778,63.95007894362052,63.66499798360323,63.37991702358597,63.0948360635687,62.80975510355141,62.524674143534114,62.239593183516874,61.954512223499584,61.6694312634823,61.384350303465034,61.099269343447766,60.81418838343048,60.529107423413215,60.24402646339595,59.95894550337866,59.6738645433614,59.388783583344136,59.10370262332684,58.81862166330956,58.53354070329232,58.24845974327503,57.96337878325774,57.65221958604215,57.33141804112098,57.01061649619979,56.68981495127862,56.36901340635745,56.04821186143626,55.72741031651507,55.40660877159393,55.085807226672735,54.76500568175154,54.44420413683037,54.1234025919092,53.80260104698801,53.48179950206684,53.16099795714568,52.840196412224486,52.519394867303326,52.19859332238215,51.87779177746096,51.55699023253976,51.23618868761863,50.91538714269744,50.59458559777624,50.27378405285508,49.9529825079339,49.63218096301271,49.31137941809155,48.99057787317038,48.669776328249185,48.34897478332799,48.02817323840685,47.70737169348566,47.386570148564466,47.065768603643306,46.74496705872214,46.42416551380094,46.10336396887977,45.78256242395861,45.46176087903741,45.140959334116246,44.82015778919508,44.49935624427388,44.17855469935269,43.85775315443155,43.53695160951035,43.216150064589165,42.895348519668,42.57454697474682,42.253745429825635,41.93294388490447,41.6121423399833,41.29134079506211,40.970539250140945,40.64973770521978,40.32893616029858,40.00813461537739,39.68733307045622,39.36653152553505,39.0368054915823,38.68923047956646,38.34165546755061,37.99408045553473,37.64650544351889,37.298930431503045,36.95135541948717,36.60378040747129,36.25620539545548,35.9086303834396,35.56105537142373,35.21348035940788,34.86590534739204,34.51833033537616,34.17075532336032,33.82318031134447,33.475605299328606,33.128030287312754,32.780455275296916,32.43288026328104,32.085305251265154,31.737730239249316,31.390155227233475,31.045519101374,30.70613109517042,30.366743088966835,30.027355082763222,29.68796707655964,29.34857907035606,29.00919106415245,28.669803057948833,28.330415051745284,27.991027045541674,27.651639039338058,27.312251033134473,26.972863026930895,26.633475020727282,26.2940870145237,25.954699008320123,25.615311002116503,25.27592299591292,24.93653498970934,24.59714698350573,24.257758977302117,23.918370971098536,23.57898296489495,23.239594958691338,22.90020695248776,22.560818946284172,22.221430940080563,21.88204293387698,21.5426549276734,21.20326692146979,20.86387891526617,20.52449090906262,20.18510290285901,19.845714896655398,19.506326890451817,19.166938884248232,18.827550878044622,18.488162871841038,18.14877486563746,17.809386859433843,17.469998853230262,17.13061084702668,16.791222840823067,16.451834834619454,16.112446828415905,15.773058822212292,15.433670816008679,15.094282809805096,14.754894803601513,14.415506797397903,14.07611879119432,13.73673078499074,13.397342778787126,13.057954772583512,12.718566766379961,12.379178760176348,12.039790753972735,11.700402747769154,11.361014741565572,11.02162673536196,10.722847110478241,10.627109392193628,10.531371673909016,10.4356339556244,10.339896237339806,10.244158519055194,10.148420800770579,10.052683082485984,9.95694536420137,9.861207645916759,9.76546992763216,9.669732209347547,9.573994491062935,9.478256772778321,9.382519054493725,9.286781336209112,9.191043617924498,9.095305899639904,8.99956818135529,8.903830463070676,8.80809274478608,8.712355026501466,8.616617308216853,8.520879589932257,8.425141871647645,8.329404153363031,8.233666435078419,8.137928716793823,8.04219099850921,7.9464532802245955,7.8507155619399995,7.754977843655386,7.659240125370772,7.563502407086177,7.467764688801563,7.37202697051695,7.276289252232337,7.180551533947741,7.084813815663128,6.989076097378514,6.893338379093919,6.821839045585293,6.752292555384854,6.6877875458233635,6.639140322220555,6.590493098617748,6.541845875014949,6.4931986514121425,6.444551427809334,6.395904204206526,6.347256980603729,6.29860975700092,6.249962533398112,6.201315309795314,6.152668086192506,6.104020862589699,6.055373638986899,6.006726415384091,5.958079191781285,5.909431968178476,5.860784744575678,5.81213752097287,5.763490297370062,5.7148430737672635,5.666195850164456,5.617548626561648,5.56890140295885,5.520254179356042,5.471606955753234,5.422959732150436,5.374312508547627,5.32566528494482,5.277018061342012,5.228370837739213,5.179723614136407,5.1310763905335985,5.082429166930799,5.033781943327991,4.985134719725184,4.9364874961223855,4.887840272519577,4.839193048916769,4.790545825313962,4.7418986017111635],[53.42521887614693,53.477574745119064,53.5299306140912,53.58228648306334,53.63464235203547,53.68699822100761,53.739354089979756,53.791709958951884,53.84406582792403,53.896421696896155,53.9487775658683,54.00113343484044,54.05348930381258,54.10584517278471,54.15820104175685,54.21055691072898,54.262912779701125,54.31526864867325,54.36762451764539,54.41998038661753,54.47233625558967,54.5246921245618,54.57704799353394,54.62940386250608,54.681759731478216,54.734115600450345,54.786471469422494,54.83882733839463,54.891183207366765,54.9435390763389,54.99589494531103,55.04825081428318,55.100606683255315,55.15296255222745,55.205318421199586,55.25767429017172,55.310030159143864,55.362386028116,55.414741897088135,55.46709776606027,55.519453635032406,55.57180950400454,55.624165372976684,55.67652124194882,55.728877110920955,55.78123297989309,55.833588848865226,55.88594471783737,55.9383005868095,55.99065645578164,56.043012324753775,56.09536819372591,56.14772406269805,56.20007993167019,56.252435800642324,56.30479166961446,56.357147538586595,56.40950340755874,56.46185927653087,56.51421514550301,56.566571014475144,56.61892688344728,56.67128275241942,56.72363862139156,56.77599449036369,56.8287257199148,56.88164463054302,56.93456354117126,56.98748245179948,57.04040136242771,57.09332027305593,57.14623918368416,57.19915809431239,57.25207700494061,57.30499591556884,57.35791482619707,57.410833736825296,57.46375264745352,57.51667155808175,57.569590468709976,57.622509379338204,57.675428289966426,57.72834720059466,57.781266111222884,57.82787795656493,57.87322838884976,57.91857882113458,57.9639292534194,58.00927968570423,58.05463011798904,58.09998055027386,58.14533098255869,58.19068141484351,58.23603184712833,58.28138227941315,58.32673271169797,58.37208314398279,58.41743357626761,58.46278400855243,58.50813444083725,58.55348487312208,58.598835305406894,58.64418573772426,58.68957104843925,58.734956359154246,58.780341669869244,58.82572698058424,58.87111229129924,58.91649760201424,58.96188291272924,59.00726822344423,59.05265353415923,59.098038844874225,59.14342415558923,59.18880946630422,59.23419477701922,59.27958008773422,59.32496539844921,59.37035070916421,59.41573601987921,59.46112133059421,59.5065066413092,59.5518919520242,59.597277262739205,59.64266257345419,59.688047884169194,59.7334331948842,59.77881850559919,59.82420381631419,59.86958912702919,59.91497443774418,59.96035974845918,60.005745059174174,60.05113036988918,60.09651568060417,60.141900991319176,60.18728630203416,60.232671612749165,60.27805692346416,60.323442234179154,60.36882754489415,60.41421285560915,60.459598166324156,60.50498347703915,60.55036878775415,60.59575409846914,60.64113940918414,60.68652471989914,60.73191003061414,60.777295341329136,60.82268065204413,60.86806596275913,60.913451273474124,60.95883658418912,61.00422189490412,61.04960720561912,61.094992516334116,61.14037782704911,61.18576313776411,61.23114844847911,61.2765337591941,61.3219190699091,61.367304380624105,61.4126896913391,61.458075002054095,61.50346031276909,61.54884562348409,61.59342892562573,61.6376112234807,61.68179352133567,61.72597581919064,61.7701581170456,61.81434041490057,61.85852271275553,61.902705010610504,61.94688730846546,61.99106960632044,62.035251904175404,62.07943420203037,62.12361649988533,62.167798797740296,62.21198109559526,62.25616339345024,62.300345691305196,62.34452798916017,62.388710287015144,62.43289258487011,62.47707488272506,62.52125718058004,62.565439478435,62.60962177628997,62.65380407414493,62.6979863719999,62.74216866985488,62.786350967709836,62.83053326556481,62.87471556341977,62.91889786127473,62.96308015912972,63.00726245698468,63.05144475483963,63.09562705269461,63.13980935054957,63.18399164840454,63.2281739462595,63.27235624411447,63.316538541969436,63.360720839824396,63.40490313767937,63.44908543553433,63.49326773338931,63.537450031244276,63.581632329099236,63.6258146269542,63.66999692480917,63.71417922266414,63.7583615205191,63.802543818374076,63.84672611622904,63.89090841408401,63.935090711938976,63.97927300979394,64.0234553076489,64.06763760550388,64.11181990335884,64.15600220121381,64.20018449906877,64.24436679692374,64.28854909477872,64.33273139263368,64.37691369048865,64.42109598834361,64.46527828619857,64.50946058405354,64.5536428819085,64.59782517976348,64.64200747761845,64.68618977547341,64.73037207332838,64.77455437118334,64.81873666903832,64.86291896689328,64.90710126474823,64.95128356260322,64.99546586045818,65.03964815831314,65.08384527466609,65.12804387292599,65.17224247118588,65.21644106944579,65.09599988856708,64.81048059692296,64.48967905200178,64.16887750708061,63.84807596215941,63.52727441723825,63.206472872317086,62.88567132739589,62.564869782474695,62.244109696790915,61.92338810819972,61.60266651960851,61.281944931017335,60.96122334242617,60.64050175383497,60.3197801652438,59.999058576652615,59.67833698806142,59.35761539947025,59.03689381087908,58.71617222228787,58.39545063369667,58.07472904510553,57.75400745651432,57.43328586792312,57.11256427933195,56.79184269074078,56.47112110214957,56.1503995135584,55.82967792496723,55.50895633637602,55.18823474778482,54.86751315919368,54.54679157060248,54.22606998201127,53.9053483934201,53.58462680482893,53.26390521623773,52.943183627646555,52.622462039055385,52.30174045046418,51.98101886187301,51.660297273281834,51.33957568469063,51.01885409609943,50.69813250750829,50.37741091891708,50.05668933032588,49.73596774173471,49.415246153143535,49.09452456455233,48.77380297596116,48.45308138736999,48.13235979877878,47.81163821018758,47.49091662159644,47.17019503300523,46.84947344441404,46.52875185582287,46.20803026723169,45.887308678640494,45.56658709004932,45.24586550145814,44.925143912866936,44.60442232427577,44.2837007356846,43.96297914709339,43.642257558502195,43.32153596991105,43.00081438131984,42.680092792728644,42.359371204137474,42.038649615546305,41.71792802695509,41.397206438363924,41.076484849772754,40.75576326118154,40.43504167259037,40.1143200839992,39.79359849540799,39.4728769068168,39.152155318225624,38.831433729634455,38.50625800634775,38.17217401367011,37.83809002099246,37.50400602831478,37.16992203563713,36.83583804295948,36.5017540502818,36.16767005760411,35.8335860649265,35.499502072248816,35.16541807957113,34.831334086893484,34.497250094215836,34.16316610153816,33.82908210886051,33.494998116182856,33.16091412350517,32.82683013082753,32.492746138149876,32.1586621454722,31.82457815279452,31.490494160116867,31.156410167439216,30.822326174761535,30.488242182083887,30.15415818940624,29.82007419672856,29.48599020405091,29.151906211373262,28.817822218695575,28.4837382260179,28.149654233340282,27.815570240662602,27.481486247984925,27.147402255307274,26.813318262629622,26.479234269951945,26.14515027727429,25.81106628459664,25.472664250011377,25.133276243807792,24.793888237604214,24.4545002314006,24.11511222519699,23.775724218993407,23.436336212789826,23.096948206586212,22.75756020038263,22.418172194179046,22.078784187975437,21.739396181771852,21.40000817556827,21.06062016936466,20.721232163161048,20.381844156957495,20.042456150753882,19.70306814455027,19.363680138346687,19.024292132143106,18.684904125939493,18.345516119735912,18.00612811353233,17.666740107328714,17.327352101125136,16.98796409492155,16.648576088717938,16.30918808251433,15.969800076310776,15.630412070107162,15.291024063903551,14.951636057699968,14.612248051496387,14.272860045292774,13.933472039089192,13.594084032885611,13.254696026681998,12.915308020478385,12.575920014274836,12.236532008071219,11.897144001867607,11.557755995664026,11.218367989460443,10.878979983256832,10.580200358373114,10.4844626400885,10.388724921803888,10.292987203519274,10.197249485234678,10.101511766950065,10.005774048665451,9.910036330380855,9.814298612096241,9.71856089381163,9.622823175527033,9.527085457242421,9.431347738957806,9.335610020673194,9.239872302388596,9.144134584103984,9.07177366950652,9.002227179306095,8.932680689105656,8.863134198905218,8.793587708704791,8.724041218504354,8.654494728303915,8.58494823810349,8.51540174790305,8.445855257702613,8.376308767502174,8.30676227730175,8.237215787101311,8.167669296900872,8.098122806700447,8.028576316500008,7.95902982629957,7.889483336099145,7.819936845898707,7.750390355698268,7.680843865497829,7.611297375297404,7.541750885096967,7.4722043948965275,7.4026579046961025,7.333111414495664,7.263564924295226,7.1940184340948,7.124471943894362,7.054925453693922,6.985378963493497,6.91583247329306,6.846285983092621,6.776739492892183,6.707193002691758,6.637646512491319,6.568100022290881,6.498553532090455,6.429007041890017,6.359460551689578,6.289914061489152,6.220367571288714,6.150821081088276,6.081274590887838,6.011728100687412,5.942181610486974,5.872635120286535,5.803088630086109,5.733542139885671,5.663995649685233,5.594449159484808,5.524902669284369,5.461085157568074,5.412437933965275,5.363790710362467,5.315143486759659,5.266496263156851,5.217849039554053,5.169201815951245,5.120554592348437,5.071907368745639,5.023260145142832,4.974612921540023,4.925965697937224,4.877318474334417,4.828671250731609,4.7800240271288015,4.731376803526002],[53.70830697577992,53.76066284475205,53.81301871372419,53.86537458269633,53.91773045166846,53.970086320640604,54.02244218961273,54.074798058584875,54.12715392755702,54.179509796529146,54.23186566550129,54.28422153447342,54.33657740344556,54.3889332724177,54.44128914138983,54.49364501036197,54.5460008793341,54.598356748306244,54.65071261727839,54.703068486250515,54.75542435522266,54.807780224194794,54.86013609316693,54.912491962139065,54.96484783111121,55.01720370008334,55.06955956905547,55.12191543802762,55.17427130699975,55.226627175971885,55.27898304494403,55.331338913916156,55.383694782888305,55.436050651860434,55.48840652083257,55.54076238980471,55.59311825877684,55.64547412774899,55.69782999672112,55.75018586569326,55.8025417346654,55.85489760363754,55.90725347260967,55.95960934158181,56.01196521055394,56.06432107952608,56.116676948498224,56.16903281747035,56.22148252628632,56.274401436914545,56.327320347542766,56.380239258170995,56.433158168799224,56.486077079427446,56.53899599005568,56.5919149006839,56.64483381131214,56.69775272194036,56.75067163256858,56.80359054319681,56.85650945382503,56.90942836445326,56.9623472750815,57.01526618570972,57.06818509633794,57.12110400696618,57.1740229175944,57.226941828222635,57.27986073885086,57.33277964947908,57.38569856010731,57.43861747073554,57.491536381363765,57.54445529199199,57.597374202620216,57.650293113248445,57.703212023876674,57.756130934504895,57.809049845133124,57.86196875576135,57.91488766638958,57.967806577017804,58.02072548764604,58.07364439827426,58.12025624361631,58.16560667590113,58.21095710818595,58.25630754047078,58.301657972755606,58.34700840504041,58.39235883732524,58.43770926961007,58.48305970189489,58.52841013417971,58.57376056646453,58.61911099874935,58.66446143103417,58.70981186331899,58.75516229560381,58.80051272788863,58.84586316017346,58.89121359245827,58.9365640247431,58.98191445702792,59.02726488931275,59.07261532159756,59.11796575388239,59.16331618616721,59.20866661845203,59.25401705073685,59.29936748302167,59.34471791530649,59.39006834759131,59.43541877987614,59.48076921216096,59.52611964444577,59.5714700767306,59.61682050901542,59.66217094130024,59.707538812826925,59.75292412354191,59.798309434256915,59.84369474497191,59.88908005568691,59.9344653664019,59.9798506771169,60.025235987831906,60.0706212985469,60.116006609261895,60.16139191997689,60.20677723069189,60.25216254140689,60.29754785212189,60.342933162836886,60.38831847355188,60.43370378426688,60.47908909498187,60.52447440569688,60.56985971641187,60.61524502712687,60.660630337841866,60.70601564855686,60.75140095927186,60.79678626998685,60.84217158070186,60.88755689141685,60.93294220213185,60.97832751284685,61.02371282356185,61.06909813427684,61.11448344499184,61.15986875570684,61.20525406642184,61.250639377136835,61.29602468785184,61.341409998566824,61.38679530928183,61.43218061999683,61.47756593071182,61.52295124142681,61.568336552141815,61.61372186285681,61.65910717357181,61.7044924842868,61.74987779500181,61.7952631057168,61.840648416431804,61.88523171857345,61.92941401642841,61.973596314283384,62.01777861213834,62.06196090999332,62.10614320784828,62.15032550570325,62.19450780355821,62.238690101413184,62.28287239926814,62.32705469712312,62.371236994978084,62.41541929283305,62.45960159068802,62.50378388854298,62.54796618639795,62.59214848425292,62.63633078210788,62.68051307996285,62.724695377817824,62.768877675672776,62.81305997352776,62.85724227138272,62.90142456923769,62.94560686709265,62.98978916494761,63.03397146280258,63.07815376065755,63.122336058512516,63.16651835636748,63.21070065422245,63.25488295207742,63.29906524993239,63.34324754778734,63.38742984564232,63.431612143497276,63.475794441352264,63.51997673920722,63.56415903706218,63.60834133491715,63.652523632772116,63.69670593062708,63.74088822848205,63.78507052633702,63.82925282419198,63.873435122046956,63.91761741990191,63.96179971775689,64.00598201561186,64.05016431346682,64.0943466113218,64.13852890917676,64.18271120703173,64.22689350488669,64.27107580274165,64.31525810059662,64.35944039845158,64.40362269630656,64.44780499416152,64.49198729201649,64.53616958987145,64.58035188772642,64.62453418558138,64.6680106045762,64.71131055470455,64.75461050483288,64.79791045496123,64.84121040508957,64.88451035521791,64.92781030534626,64.9711102554746,65.01441020560294,65.05771015573127,65.10101010585961,65.14431005598796,65.1876100061163,65.23090995624464,65.27420990637299,65.31750985650132,65.36080980662966,65.404109756758,65.44740970688635,65.49070965701469,65.34047548114843,64.99670717928758,64.65293887742675,64.30917057556593,63.96540227370507,63.62163397184425,63.27786566998343,62.93409736812257,62.59032906626172,62.24656076440093,61.90279246254007,61.559024160679215,61.215255858818395,60.871487556957575,60.52771925509672,60.18395095323589,59.840182651375066,59.49641434951421,59.15264604765339,58.808877745792564,58.46510944393171,58.121341142070854,57.77757284021006,57.433804538349214,57.09003623648836,56.74626793462754,56.402499632766705,56.05873133090586,55.71496302904503,55.37119472718421,55.027426425323355,54.68365812346249,54.3398898216017,54.017053812754234,53.69633222416303,53.37561063557186,53.05488904698068,52.734167458389486,52.41344586979831,52.09272428120714,51.772002692615935,51.451281104024766,51.130559515433596,50.809837926842384,50.48911633825119,50.16839474966004,49.84767316106884,49.52695157247764,49.20622998388646,48.88550839529529,48.564786806704085,48.24406521811291,47.92334362952174,47.60262204093054,47.28190045233934,46.961178863748195,46.64045727515699,46.31973568656579,45.99901409797462,45.67829250938345,45.35757092079224,45.03684933220107,44.7161277436099,44.39540615501869,44.07468456642753,43.75396297783635,43.433241389245154,43.11251980065394,42.7917982120628,42.4710766234716,42.1503550348804,41.82963344628923,41.50891185769805,41.18819026910685,40.86746868051568,40.54674709192451,40.226025503333304,39.905303914742134,39.58458232615096,39.26386073755975,38.943139148968555,38.62241756037738,38.3016959717862,37.97652024849951,37.642436255821856,37.308352263144215,36.97426827046654,36.640184277788876,36.306100285111235,35.972016292433544,35.63793229975587,35.303848307078255,34.96976431440057,34.63568032172289,34.301596329045246,33.96751233636759,33.63342834368991,33.299344351012266,32.96526035833461,32.63117636565693,32.297092372979286,31.963008380301634,31.628924387623957,31.294840394946274,30.960756402268622,30.62667240959097,30.292588416913297,29.958504424235645,29.624420431557997,29.290336438880317,28.956252446202672,28.622168453525013,28.288084460847333,27.954000468169653,27.619916475492037,27.285832482814357,26.951748490136676,26.617664497459028,26.283580504781376,25.949496512103696,25.615412519426044,25.2813285267484,24.94724453407072,24.613160541393064,24.279076548715416,23.94499255603774,23.61090856336006,23.276824570682404,22.94274057800476,22.608656585327076,22.274572592649427,21.94048859997178,21.6064046072941,21.272320614616447,20.9382366219388,20.60415262926112,20.27006863658344,19.935984643905822,19.60190065122814,19.267816658550462,18.933732665872814,18.59964867319516,18.26556468051748,17.93148068783983,17.597396695162182,17.2633127024845,16.92922870980685,16.5951447171292,16.26106072445152,15.933174943581538,15.607865963234044,15.282556982886492,14.957248002538938,14.631939022191414,14.306630041843889,13.981321061496335,13.656012081148813,13.330703100801287,13.005394120453733,12.68008514010618,12.354776159758686,12.02946717941113,11.704158199063578,11.378849218716054,11.05354023836853,10.728231258020974,10.442203877554798,10.352584496495142,10.262965115435485,10.173345734375829,10.08372635331619,9.994106972256533,9.904487591196876,9.814868210137238,9.725248829077582,9.635629448017927,9.546010066958285,9.45639068589863,9.366771304838974,9.277151923779316,9.187532542719678,9.106611449804374,9.037064959603935,8.96751846940351,8.89797197920307,8.828425489002633,8.758878998802206,8.689332508601769,8.61978601840133,8.550239528200905,8.480693038000465,8.411146547800026,8.341600057599589,8.272053567399164,8.202507077198726,8.132960586998287,8.063414096797862,7.993867606597423,7.9243211163969836,7.8547746261965585,7.785228135996122,7.715681645795684,7.646135155595244,7.576588665394819,7.50704217519438,7.437495684993942,7.367949194793516,7.2984027045930775,7.228856214392639,7.159309724192214,7.089763233991776,7.020216743791337,6.9506702535909115,6.881123763390473,6.811577273190036,6.742030782989597,6.672484292789171,6.602937802588733,6.533391312388295,6.46384482218787,6.394298331987431,6.324751841786993,6.255205351586567,6.185658861386129,6.116112371185691,6.046565880985253,5.977019390784827,5.907472900584389,5.83792641038395,5.768379920183524,5.698833429983086,5.629286939782647,5.559740449582222,5.490193959381783,5.420647469181346,5.368200988159265,5.321972748431627,5.275744508703985,5.2295162689763455,5.183288029248713,5.137059789521073,5.090831549793433,5.044603310065801,4.998375070338161,4.952146830610521,4.905918590882889,4.859690351155249,4.813462111427609,4.767233871699968,4.7210056319723375],[53.991395075412896,54.04375094438503,54.09610681335716,54.14846268232931,54.20081855130144,54.25317442027358,54.305530289245716,54.357886158217845,54.410242027189994,54.46259789616212,54.514953765134265,54.5673096341064,54.61966550307854,54.67202137205067,54.724377241022815,54.77673310999495,54.829088978967086,54.88144484793922,54.933800716911364,54.9861565858835,55.038512454855635,55.09086832382778,55.1432241927999,55.19558006177205,55.24793593074418,55.30029179971632,55.35264766868846,55.40500353766059,55.45735940663273,55.50971527560487,55.562071144577004,55.61442701354915,55.667158243286046,55.720077153914275,55.772996064542504,55.82591497517073,55.878833885798954,55.931752796427176,55.98467170705541,56.037590617683634,56.09050952831186,56.14342843894009,56.19634734956831,56.24926626019655,56.30218517082477,56.35510408145299,56.40802299208123,56.46094190270945,56.51386081333767,56.56677972396591,56.61969863459413,56.67261754522236,56.72553645585059,56.77845536647881,56.831374277107045,56.88429318773527,56.93721209836349,56.990131008991725,57.043049919619946,57.095968830248175,57.1488877408764,57.201806651504626,57.25472556213286,57.30764447276108,57.360563383389305,57.413482294017534,57.466401204645756,57.519320115273985,57.57223902590222,57.62515793653044,57.67807684715867,57.7309957577869,57.78391466841513,57.83683357904335,57.88975248967158,57.94267140029981,57.99559031092804,58.04850922155626,58.10142813218449,58.15434704281272,58.20726595344094,58.26018486406916,58.3131037746974,58.366022685325625,58.412634530667674,58.457984962952494,58.503335395237315,58.548685827522135,58.59403625980696,58.63938669209178,58.684737124376596,58.730087556661424,58.775437988946244,58.82078842123107,58.86613885351589,58.91148928580071,58.95683971808553,59.00219015037035,59.047540582655174,59.092891014939994,59.138241447224814,59.18359187950964,59.22894231179446,59.27429274407929,59.319643176364096,59.36499360864892,59.41034404093375,59.45569447321857,59.50104490550339,59.54639533778821,59.59174577007303,59.63709620235785,59.68244663464267,59.727797066927494,59.773147499212314,59.818497931497134,59.86384836378196,59.90919879606678,59.9545492283516,59.99989966063642,60.04525009292125,60.090600525206064,60.135950957490884,60.18130138977571,60.22665182206053,60.27200225434535,60.31735268663018,60.362703118915,60.408053551199814,60.453403983484634,60.498754415769454,60.54410484805428,60.5894552803391,60.634805712623915,60.68015614490874,60.72550657721458,60.77089188792957,60.81627719864458,60.861662509359576,60.90704782007457,60.952433130789565,60.99781844150456,61.04320375221956,61.08858906293456,61.133974373649565,61.179359684364556,61.224744995079554,61.27013030579455,61.31551561650954,61.36090092722455,61.40628623793954,61.45167154865454,61.49705685936954,61.542442170084534,61.58782748079953,61.63321279151453,61.67859810222953,61.72398341294452,61.76936872365952,61.814754034374516,61.860139345089515,61.90552465580451,61.95090996651952,61.99629527723451,62.04168058794951,62.087065898664505,62.1324512093795,62.17703451152115,62.221216809376116,62.26539910723109,62.30958140508604,62.353763702941016,62.39794600079599,62.44212829865096,62.486310596505916,62.53049289436088,62.57467519221585,62.61885749007082,62.66303978792578,62.70722208578076,62.75140438363572,62.79558668149069,62.83976897934565,62.88395127720062,62.92813357505559,62.972315872910556,63.016498170765516,63.06068046862048,63.10486276647546,63.14904506433042,63.19322736218538,63.237409660040356,63.28159195789531,63.32577425575029,63.369956553605256,63.41413885146023,63.45832114931519,63.502503447170156,63.54668574502512,63.59086804288009,63.63505034073505,63.67923263859003,63.72341493644498,63.767597234299956,63.81177953215492,63.85596183000988,63.90014412786485,63.94432642571982,63.98808015435003,64.03138010447836,64.07468005460672,64.11798000473506,64.16127995486339,64.20457990499173,64.24787985512008,64.29117980524842,64.33447975537676,64.3777797055051,64.42107965563345,64.46437960576179,64.50767955589012,64.55097950601848,64.59427945614682,64.63757940627514,64.68087935640351,64.72417930653184,64.76747925666018,64.81077920678852,64.85407915691685,64.89737910704521,64.94067905717354,64.98397900730188,65.02727895743023,65.07057890755857,65.11387885768691,65.15717880781526,65.2004787579436,65.24377870807194,65.28707865820027,65.33037860832862,65.37367855845696,65.4169785085853,65.46027845871365,65.50357840884197,65.54687835897033,65.59017830909866,65.63347825922702,65.67677820935535,65.72007815948369,65.76337810961203,65.61314393374577,65.26937563188491,64.92560733002409,64.58183902816327,64.23807072630241,63.89430242444159,63.55053412258077,63.206765820719916,62.86299751885906,62.51922921699827,62.17546091513742,61.831692613276566,61.48792431141574,61.14415600955491,60.80038770769406,60.45661940583324,60.11285110397241,59.769082802111555,59.425314500250735,59.08154619838991,58.73777789652905,58.394009594668205,58.050241292807414,57.70647299094655,57.362704689085696,57.018936387224876,56.67516808536405,56.3313997835032,55.98763148164237,55.64386317978155,55.30009487792069,54.95632657605984,54.612558274199046,54.2687899723382,53.925021670477335,53.581253368616515,53.23748506675569,52.89371676489483,52.54994846303402,52.20618016117319,51.86241185931233,51.51864355745152,51.174875255590685,50.83110695372983,50.48733865186898,50.14357035000819,49.799802048147335,49.456033746286465,49.112265444425645,48.76849714256482,48.42472884070398,48.08096053884315,47.73719223698233,47.393423935121476,47.04965563326061,46.70588733139982,46.362119029538974,46.01835072767811,45.674582425817285,45.330814123956465,44.98704582209561,44.64327752023479,44.29950921837396,43.95574091651312,43.611972614652295,43.26820431279147,42.924436010930606,42.582782042805725,42.26206045421458,41.94133886562338,41.62061727703218,41.299895688441,40.97917409984983,40.65845251125862,40.33773092266746,40.01700933407628,39.69628774548508,39.3755661568939,39.054844568302734,38.734122979711536,38.41340139112033,38.092679802529155,37.771958213937985,37.44678249065129,37.11269849797363,36.77861450529599,36.444530512618314,36.11044651994065,35.776362527263004,35.44227853458533,35.10819454190764,34.77411054923003,34.44002655655235,34.10594256387466,33.77185857119702,33.43777457851937,33.10369058584169,32.76960659316404,32.43552260048639,32.10143860780871,31.76735461513106,31.43327062245341,31.09918662977573,30.765102637098046,30.43878384536947,30.113474865021946,29.78816588467439,29.46285690432687,29.137547923979344,28.81223894363179,28.48692996328427,28.161620982936746,27.836312002589192,27.51100302224164,27.185694041894145,26.860385061546587,26.535076081199033,26.209767100851508,25.884458120503986,25.559149140156432,25.23384015980891,24.908531179461388,24.583222199113834,24.25791321876631,23.932604238418786,23.60729525807123,23.281986277723675,22.956677297376153,22.631368317028624,22.30605933668107,21.980750356333548,21.655441375986026,21.330132395638472,21.00482341529095,20.679514434943425,20.35420545459587,20.028896474248313,19.703587493900823,19.37827851355327,19.05296953320572,18.72766055285819,18.402351572510668,18.077042592163114,17.751733611815588,17.426424631468066,17.101115651120512,16.77580667077299,16.450497690425465,16.12518871007791,15.799879729730357,15.474570749382863,15.14926176903531,14.823952788687755,14.498643808340232,14.173334827992706,13.848025847645154,13.522716867297632,13.197407886950106,12.872098906602552,12.546789926254998,12.221480945907501,11.89617196555995,11.570862985212397,11.245554004864871,10.92024502451735,10.594936044169792,10.308908663703615,10.21928928264396,10.129669901584304,10.040050520524648,9.950431139465007,9.860811758405351,9.771192377345695,9.681572996286057,9.5919536152264,9.502334234166744,9.412714853107104,9.323095472047449,9.233476090987791,9.143856709928134,9.054237328868496,8.96461794780884,8.874998566749184,8.785379185689544,8.695759804629887,8.606140423570231,8.516521042510591,8.426901661450936,8.337282280391278,8.247662899331639,8.158043518271983,8.068424137212327,7.978804756152671,7.889185375093031,7.799565994033374,7.709946612973719,7.620327231914079,7.530707850854423,7.441088469794767,7.351469088735127,7.26184970767547,7.184882315133852,7.119554792431067,7.054227269728296,6.988899747025512,6.923572224322728,6.858244701619956,6.792917178917172,6.727589656214389,6.662262133511616,6.596934610808832,6.531607088106048,6.466279565403275,6.400952042700492,6.335624519997707,6.282631967427803,6.236403727700171,6.190175487972532,6.14394724824489,6.0977190085172595,6.051490768789619,6.005262529061978,5.959034289334347,5.912806049606707,5.866577809879067,5.820349570151427,5.774121330423795,5.7278930906961545,5.681664850968514,5.635436611240882,5.589208371513243,5.542980131785603,5.49675189205797,5.45052365233033,5.40429541260269,5.358067172875058,5.311838933147419,5.265610693419778,5.219382453692138,5.173154213964506,5.126925974236865,5.080697734509226,5.034469494781593,4.988241255053953,4.942013015326314,4.895784775598681,4.8495565358710415,4.803328296143402,4.75710005641576,4.71087181668813],[54.27448317504588,54.326839044018016,54.379194912990144,54.43155078196229,54.48390665093443,54.536262519906565,54.58861838887869,54.64097425785083,54.69333012682297,54.745685995795114,54.79804186476725,54.85039773373938,54.90275360271153,54.955109471683656,55.0074653406558,55.059915049657555,55.11283396028578,55.16575287091401,55.218671781542234,55.27159069217046,55.324509602798685,55.37742851342691,55.43034742405514,55.48326633468337,55.5361852453116,55.58910415593982,55.64202306656805,55.69494197719628,55.74786088782451,55.80077979845272,55.85369870908096,55.90661761970918,55.95953653033742,56.01245544096564,56.06537435159387,56.118293262222096,56.17121217285032,56.22413108347855,56.277049994106775,56.329968904735,56.382887815363226,56.435806725991455,56.488725636619684,56.54164454724791,56.594563457876134,56.64748236850436,56.70040127913259,56.753320189760814,56.806239100389035,56.85915801101727,56.91207692164549,56.96499583227372,57.01791474290195,57.07083365353017,57.12375256415841,57.17667147478663,57.229590385414866,57.28250929604309,57.33542820667132,57.38834711729954,57.44126602792776,57.494184938556,57.547103849184225,57.60002275981245,57.65294167044067,57.7058605810689,57.75877949169712,57.81169840232536,57.864617312953584,57.917536223581806,57.97045513421004,58.02337404483826,58.07629295546649,58.129211866094714,58.18213077672295,58.23504968735117,58.2879685979794,58.34088750860762,58.39380641923585,58.44672532986408,58.4996442404923,58.55256315112052,58.605482061748766,58.65840097237699,58.70501281771904,58.750363250003865,58.79571368228868,58.841064114573506,58.886414546858326,58.931764979143146,58.977115411427974,59.022465843712794,59.06781627599761,59.113166708282435,59.15851714056726,59.203867572852076,59.249218005136896,59.29456843742172,59.339918869706544,59.385269301991364,59.430619734276185,59.475970166561005,59.52132059884583,59.56667103113065,59.612021463415466,59.65737189570029,59.702722327985114,59.748072760269935,59.793423192554755,59.838773624839575,59.884124057124396,59.929474489409216,59.97482492169404,60.020175353978864,60.065525786263684,60.1108762185485,60.15622665083332,60.20157708311814,60.246927515402966,60.29227794768779,60.337628379972614,60.382978812257434,60.428329244542255,60.473679676827075,60.519030109111895,60.564380541396716,60.609730973681536,60.65508140596636,60.70043183825118,60.745782270536004,60.791132702820825,60.83648313510565,60.88183356739047,60.927183999675286,60.972534431960106,61.01788486424493,61.063235296529754,61.108585728814575,61.15393616109939,61.199286593384215,61.244637025669036,61.289987457953856,61.335337890238684,61.380688322523504,61.42603875480832,61.47138918709314,61.516739619377965,61.562090051662786,61.607440483947606,61.652790916232426,61.69814134851725,61.743491780802074,61.78885965231724,61.83424496303224,61.87963027374724,61.92501558446224,61.97040089517723,62.01578620589223,62.061171516607224,62.10655682732222,62.15194213803722,62.19732744875222,62.242712759467224,62.288098070182215,62.33348338089721,62.37886869161221,62.4242540023272,62.468837304468856,62.51301960232382,62.55720190017878,62.60138419803375,62.64556649588872,62.689748793743696,62.73393109159865,62.77811338945362,62.82229568730859,62.866477985163556,62.91066028301852,62.95484258087349,62.999024878728456,63.04320717658342,63.08738947443838,63.131571772293356,63.17575407014832,63.21993636800329,63.264118665858255,63.308149704123856,63.35144965425221,63.39474960438054,63.438049554508886,63.48134950463722,63.524649454765566,63.56794940489391,63.61124935502226,63.654549305150596,63.69784925527894,63.741149205407275,63.78444915553561,63.827749105663955,63.8710490557923,63.91434900592064,63.95764895604898,64.00094890617731,64.04424885630567,64.08754880643401,64.13084875656234,64.17414870669069,64.21744865681903,64.26074860694737,64.30404855707572,64.34734850720406,64.3906484573324,64.43394840746075,64.47724835758908,64.52054830771742,64.56384825784576,64.60714820797412,64.65044815810244,64.69374810823078,64.73704805835914,64.78034800848746,64.82364795861582,64.86694790874415,64.9102478588725,64.95354780900084,64.99684775912918,65.04014770925752,65.08344765938587,65.1267476095142,65.17004755964255,65.21334750977088,65.25664745989923,65.29994741002757,65.34324736015591,65.38654731028426,65.4298472604126,65.47314721054093,65.51644716066927,65.55974711079762,65.60304706092596,65.6463470110543,65.68964696118265,65.73294691131099,65.77624686143932,65.81954681156768,65.862846761696,65.90614671182435,65.94944666195268,65.99274661208104,66.03604656220938,65.88581238634312,65.54204408448226,65.19827578262144,64.85450748076062,64.51073917889977,64.16697087703893,63.823202575178115,63.47943427331727,63.135665971456405,62.79189766959561,62.44812936773475,62.1043610658739,61.760592764013076,61.41682446215226,61.0730561602914,60.72928785843058,60.38551955656975,60.041751254708906,59.69798295284808,59.35421465098726,59.0104463491264,58.666678047265535,58.32290974540475,57.97914144354389,57.63537314168303,57.291604839822206,56.947836537961386,56.604068236100545,56.26029993423971,55.91653163237889,55.57276333051803,55.22899502865718,54.88522672679639,54.54145842493554,54.19769012307468,53.85392182121386,53.510153519353025,53.16638521749218,52.82261691563136,52.47884861377053,52.135080311909675,51.791312010048856,51.44754370818802,51.10377540632717,50.76000710446632,50.41623880260553,50.07247050074467,49.72870219888382,49.384933897023,49.04116559516217,48.69739729330131,48.353628991440495,48.00986068957967,47.666092387718805,47.32232408585796,46.978555783997166,46.63478748213631,46.29101918027546,45.947250878414636,45.59475645117533,45.23312042537398,44.87148439957268,44.509848373771376,44.14821234797004,43.78657632216873,43.424940296367424,43.06330427056608,42.70166824476475,42.34003221896347,41.978396193162126,41.61676016736079,41.255124141559484,40.89348811575818,40.531852089956836,40.17021606415553,39.80858003835422,39.446944012552876,39.08530798675157,38.72367196095027,38.36203593514893,38.00039990934759,37.63876388354629,37.27712785774498,36.929146308081435,36.60847371069349,36.28780111330554,35.967128515917565,35.64645591852962,35.32578332114168,35.0051107237537,34.68443812636573,34.36376552897781,34.04309293158983,33.72242033420186,33.40174773681392,33.08107513942597,32.760402542037994,32.43972994465005,32.1190573472621,31.798384749874128,31.477712152486184,31.157039555098237,30.83636695771026,30.515694360322286,30.195021762934342,29.874349165546395,29.553676568158423,29.233003970770476,28.91233137338253,28.591658775994556,28.27098617860661,27.950313581218666,27.62964098383069,27.308968386442714,26.988295789054796,26.667623191666824,26.346950594278848,26.026277996890904,25.705605399502957,25.384932802114985,25.064260204727038,24.74358760733909,24.422915009951115,24.102242412563175,23.781569815175224,23.46089721778725,23.140224620399277,22.81955202301133,22.498073103177443,22.17276412282989,21.847455142482367,21.522146162134845,21.196837181787288,20.871528201439766,20.54621922109224,20.220910240744686,19.895601260397132,19.57029228004964,19.244983299702085,18.919674319354534,18.59436533900701,18.269056358659483,17.943747378311933,17.618438397964407,17.293129417616885,16.96782043726933,16.642511456921806,16.317202476574284,15.991893496226728,15.666584515879174,15.34127553553168,15.015966555184127,14.690657574836573,14.365348594489049,14.040039614141525,13.71473063379397,13.389421653446448,13.064112673098922,12.73880369275137,12.413494712403816,12.088185732056322,11.762876751708768,11.437567771361214,11.11225879101369,10.786949810666165,10.461640830318611,10.175613449852435,10.085994068792779,9.996374687733123,9.906755306673466,9.817135925613828,9.727516544554168,9.637897163494515,9.548277782434875,9.458658401375219,9.369039020315562,9.279419639255924,9.195620167313153,9.13029264461037,9.064965121907585,8.999637599204814,8.93431007650203,8.868982553799245,8.803655031096474,8.73832750839369,8.672999985690906,8.607672462988134,8.54234494028535,8.477017417582566,8.411689894879794,8.346362372177008,8.281034849474224,8.21570732677144,8.150379804068669,8.085052281365886,8.0197247586631,7.954397235960329,7.889069713257546,7.823742190554761,7.758414667851988,7.693087145149205,7.627759622446421,7.562432099743637,7.497104577040865,7.431777054338081,7.366449531635297,7.301122008932525,7.23579448622974,7.170466963526956,7.105139440824184,7.0398119181214005,6.9744843954186155,6.909156872715844,6.84382935001306,6.778501827310276,6.7131743046074925,6.64784678190472,6.582519259201936,6.517191736499152,6.45186421379638,6.386536691093596,6.321209168390812,6.25588164568804,6.190554122985255,6.125226600282471,6.059899077579687,5.994571554876916,5.929244032174131,5.863916509471347,5.798588986768575,5.733261464065791,5.667933941363007,5.602606418660234,5.537278895957451,5.471951373254667,5.406623850551895,5.341296327849111,5.275968805146327,5.210641282443543,5.163020398680298,5.116792158952658,5.070563919225018,5.024335679497386,4.9781074397697465,4.931879200042106,4.885650960314474,4.839422720586834,4.793194480859193,4.746966241131553,4.700738001403922],[54.55579416076376,54.60938262325181,54.662747901604064,54.71566681223229,54.768585722860514,54.82150463348874,54.87442354411697,54.92734245474519,54.98026136537342,55.033180276001644,55.08609918662988,55.1390180972581,55.19193700788633,55.24485591851456,55.29777482914279,55.35069373977102,55.40361265039924,55.45653156102747,55.5094504716557,55.56236938228392,55.61528829291214,55.66820720354037,55.7211261141686,55.774045024796834,55.826963935425056,55.87988284605328,55.93280175668151,55.98572066730973,56.03863957793797,56.091558488566186,56.144477399194415,56.197396309822636,56.25031522045087,56.3032341310791,56.35615304170732,56.40907195233555,56.46199086296378,56.514909773591995,56.56782868422023,56.62074759484845,56.67366650547669,56.72658541610491,56.77950432673314,56.83242323736137,56.88534214798959,56.93826105861782,56.99117996924605,57.04409887987428,57.097017790502505,57.14993670113073,57.20285561175896,57.255774522387185,57.308693433015414,57.36161234364364,57.414531254271864,57.46745016490009,57.52036907552832,57.573287986156544,57.62620689678477,57.679125807413,57.73204471804122,57.78496362866946,57.83788253929768,57.8908014499259,57.94372036055413,57.99663927118236,58.04955818181059,58.10247709243881,58.15539600306704,58.20831491369526,58.2612338243235,58.31415273495172,58.367071645579955,58.41999055620818,58.472909466836406,58.52582837746463,58.578747288092856,58.631666198721085,58.68458510934931,58.737504019977536,58.79042293060577,58.84334184123399,58.896260751862215,58.94917966249045,58.99566729146928,59.04089350743153,59.08624393971634,59.13159437200116,59.17694480428599,59.22229523657081,59.26764566885563,59.31299610114045,59.35834653342527,59.4036969657101,59.44904739799492,59.49439783027974,59.53974826256456,59.58509869484938,59.630449127134206,59.675799559419026,59.72114999170384,59.76650042398867,59.81185085627349,59.8572012885583,59.90255172084312,59.94790215312795,59.99325258541277,60.03860301769759,60.08395344998242,60.12930388226724,60.17465431455206,60.22000474683688,60.2653551791217,60.31070561140652,60.35605604369134,60.40140647597616,60.44675690826098,60.4921073405458,60.537457772830635,60.58280820511544,60.628158637400276,60.67350906968509,60.7188595019699,60.76420993425474,60.80956036653956,60.85491079882438,60.900261231109205,60.945611663394025,60.99096209567884,61.03631252796366,61.08166296024848,61.1270133925333,61.17236382481812,61.21771425710295,61.26306468938777,61.308415121672596,61.353765553957416,61.39911598624223,61.44446641852706,61.48981685081188,61.5351672830967,61.58051771538152,61.62586814766634,61.67121857995116,61.71656901223598,61.7619194445208,61.80726987680563,61.85262030909045,61.89797074137526,61.94332117366009,61.98867160594491,62.03402203822973,62.079372470514556,62.12472290279938,62.1700733350842,62.21542376736902,62.26077419965384,62.30612463193866,62.35147506422348,62.3968254965083,62.44217592879312,62.48752636107795,62.53287679336277,62.57822722564759,62.6235776579324,62.66892809021723,62.71427852250205,62.75825699755479,62.80154949399148,62.84484199042818,62.88813448686488,62.93142698330157,62.974719479738276,63.01801197617497,63.06130447261166,63.10459696904836,63.14788946548506,63.19118196192176,63.23447445835845,63.27776695479515,63.32105945123184,63.36435194766854,63.40764444410523,63.450936940541936,63.494229436978635,63.537521933415334,63.580818156721215,63.624118106849565,63.667418056977894,63.71071800710624,63.75401795723458,63.797317907362924,63.84061785749125,63.88391780761961,63.927217757747954,63.97051770787628,64.01381765800463,64.05711760813297,64.10041755826131,64.14371750838966,64.187017458518,64.23031740864633,64.27361735877467,64.31691730890302,64.36021725903136,64.4035172091597,64.44681715928805,64.49011710941639,64.53341705954472,64.57671700967306,64.6200169598014,64.66331690992976,64.70661686005809,64.74991681018643,64.79321676031478,64.8365167104431,64.87981666057146,64.9231166106998,64.96641656082814,65.00971651095648,65.05301646108482,65.09631641121317,65.13961636134151,65.18291631146985,65.2262162615982,65.26951621172653,65.31281616185487,65.35611611198323,65.39941606211156,65.4427160122399,65.48601596236824,65.52931591249657,65.57261586262491,65.61591581275326,65.65921576288162,65.70251571300994,65.74581566313829,65.78911561326663,65.83241556339496,65.87571551352332,65.91901546365166,65.96231541378,66.00561536390833,66.04891531403668,66.09221526416502,66.13551521429335,66.1788151644217,66.22211511455004,66.2654150646784,66.30871501480674,66.15848083894048,65.81471253707961,65.4709442352188,65.12717593335796,64.78340763149711,64.4396393296363,64.09587102777547,63.75210272591461,63.40833442405375,63.06456612219296,62.72079782033211,62.377029518471254,62.03326121661043,61.68949291474961,61.34572461288875,60.99094480752032,60.629308781719004,60.267672755917665,59.90603673011637,59.54440070431505,59.18276467851371,58.821128652712375,58.45949262691111,58.09785660110977,57.73622057530843,57.37458454950712,57.012948523705816,56.65131249790447,56.28967647210317,55.92804044630186,55.56640442050052,55.20476839469918,54.84313236889791,54.48149634309658,54.119860317295235,53.75822429149393,53.396588265692614,53.03495223989128,52.67331621408996,52.311680188288655,51.950044162487316,51.58840813668602,51.22677211088472,50.86513608508338,50.50350005928204,50.14186403348076,49.78022800767942,49.41859198187808,49.05695595607676,48.69531993027547,48.33368390447413,47.972047878672825,47.61041185287152,47.248775827070176,46.88713980126884,46.52550377546756,46.163867749666224,45.802231723864885,45.440595698063575,45.07895967226227,44.717323646460926,44.35568762065962,43.99405159485832,43.63241556905698,43.27077954325567,42.90914351745436,42.54750749165302,42.18587146585168,41.824235440050415,41.46259941424907,41.10096338844773,40.739327362646435,40.377691336845125,40.016055311043786,39.65441928524247,39.292783259441165,38.931147233639834,38.56951120783852,38.20787518203721,37.84623915623588,37.484603130434536,37.12296710463323,36.76133107883192,36.41334952916837,36.09267693178043,35.772004334392484,35.45133173700451,35.13065913961656,34.80998654222862,34.489313944840646,34.16864134745267,33.84796875006475,33.52729615267678,33.20662355528881,32.88595095790086,32.56527836051291,32.24460576312494,31.923933165736994,31.603260568349043,31.282587970961075,30.961915373573127,30.641242776185184,30.320570178797205,29.99989758140923,29.679224984021282,29.35855238663334,29.037879789245366,28.71720719185742,28.396534594469472,28.075861997081496,27.755189399693553,27.43451680230561,27.113844204917633,26.793171607529658,26.472499010141743,26.151826412753763,25.831153815365795,25.510481217977848,25.189808620589904,24.86913602320193,24.548463425813978,24.227790828426034,23.90711823103806,23.586445633650115,23.26577303626217,22.945100438874196,22.624427841486217,22.303755244098273,21.98308264671033,21.662410049322354,21.34173745193441,21.021064854546466,20.700392257158484,20.37971965977054,20.059047062382596,19.738374464994624,19.417701867606645,19.097029270218734,18.776356672830758,18.455684075442782,18.135011478054835,17.81433888066689,17.493666283278916,17.172993685890972,16.860757683446195,16.549382565174596,16.238007446903026,15.926632328631456,15.615257210359855,15.303882092088259,14.992506973816718,14.681131855545118,14.369756737273516,14.058381619001949,13.747006500730377,13.435631382458777,13.124256264187206,12.812881145915638,12.501506027644039,12.19013090937244,11.878755791100897,11.567380672829298,11.2560055545577,10.944630436286129,10.63325531801456,10.321880199742962,10.048409893894359,9.964463650160408,9.880517406426454,9.796571162692503,9.712624918958564,9.628678675224611,9.544732431490658,9.460786187756721,9.37683994402277,9.292893700288817,9.20894745655488,9.125001212820926,9.041054969086973,8.95710872535302,8.873162481619083,8.789216237885132,8.705269994151179,8.621323750417242,8.537377506683288,8.453431262949335,8.369485019215398,8.285538775481445,8.201592531747492,8.134780956439158,8.069453433736374,8.00412591103359,7.938798388330806,7.873470865628034,7.80814334292525,7.742815820222467,7.6774882975196945,7.6121607748169104,7.546833252114126,7.481505729411355,7.416178206708571,7.3508506840057874,7.2855231613030025,7.220195638600231,7.154868115897447,7.089540593194663,7.02421307049189,6.958885547789107,6.893558025086321,6.8282305023835494,6.762902979680765,6.697575456977982,6.63224793427521,6.5669204115724265,6.5015928888696415,6.436265366166857,6.370937843464086,6.305610320761302,6.240282798058518,6.174955275355745,6.109627752652962,6.044300229950177,5.978972707247404,5.913645184544621,5.848317661841837,5.782990139139054,5.717662616436281,5.65760119156402,5.613648055915471,5.5696949202669295,5.52574178461838,5.481788648969831,5.43783551332129,5.393882377672742,5.349929242024192,5.30597610637565,5.2620229707271005,5.218069835078552,5.1741166994300025,5.130163563781461,5.086210428132912,5.042257292484363,4.998304156835821,4.954351021187272,4.910397885538723,4.866444749890181,4.822491614241633,4.778538478593083,4.734585342944533,4.690632207295992],[54.821288829583615,54.87487729207166,54.92846575455971,54.98205421704776,55.03564267953581,55.08923114202386,55.142819604511914,55.196408066999965,55.249996529488016,55.30358499197607,55.35717345446412,55.41076191695216,55.46435037944021,55.51793884192826,55.57152730441631,55.625115766904365,55.67870422939241,55.73229269188046,55.78588115436851,55.838911656901324,55.89183056752955,55.944749478157775,55.997668388785996,56.05058729941423,56.103506210042454,56.15642512067068,56.20934403129891,56.26226294192713,56.31518185255537,56.36810076318359,56.42101967381182,56.47393858444005,56.52685749506827,56.57977640569651,56.63269531632473,56.68561422695295,56.738533137581186,56.79145204820941,56.84437095883764,56.897289869465865,56.95020878009409,57.003127690722316,57.056046601350545,57.10896551197877,57.161884422606995,57.214803333235224,57.267722243863446,57.32064115449168,57.373560065119904,57.426478975748125,57.47939788637636,57.53231679700459,57.58523570763281,57.63815461826104,57.69107352888926,57.74399243951749,57.79691135014572,57.84983026077394,57.90274917140217,57.9556680820304,58.00858699265863,58.06150590328686,58.11442481391508,58.1673437245433,58.22026263517154,58.273181545799766,58.32610045642799,58.379019367056216,58.43193827768444,58.484857188312674,58.537776098940896,58.59069500956912,58.64361392019735,58.696532830825575,58.749451741453804,58.80237065208203,58.85528956271026,58.90820847333848,58.96112738396671,59.01404629459494,59.06696520522317,59.11988411585139,59.17280302647962,59.22572193710785,59.27220956608669,59.31741093873565,59.36261231138461,59.40781368403357,59.45301505668253,59.49821642933149,59.54341780198045,59.588619174629414,59.633820547278376,59.67902191992734,59.7242232925763,59.76942466522526,59.81462603787422,59.85982741052318,59.90502878317215,59.95023015582111,59.995431528470064,60.04063290111903,60.08593364687461,60.13128407915943,60.17663451144425,60.22198494372907,60.26733537601389,60.31268580829871,60.35803624058353,60.40338667286835,60.448737105153185,60.494087537438,60.53943796972282,60.584788402007646,60.63013883429247,60.67548926657729,60.72083969886211,60.76619013114693,60.81154056343175,60.85689099571656,60.902241428001396,60.94759186028621,60.99294229257103,61.03829272485586,61.08364315714067,61.12899358942549,61.174344021710326,61.21969445399514,61.26504488627996,61.31039531856479,61.35574575084959,61.40109618313443,61.44644661541925,61.49179704770407,61.53714747998889,61.58249791227371,61.62784834455853,61.67319877684336,61.71854920912817,61.763899641413,61.80925007369782,61.854600505982646,61.89995093826745,61.94530137055227,61.99065180283711,62.03600223512193,62.08135266740674,62.12670309969157,62.17205353197639,62.21740396426121,62.26275439654603,62.30810482883085,62.35345526111568,62.3988056934005,62.444156125685325,62.489506557970145,62.53485699025496,62.58020742253978,62.6255578548246,62.67090828710943,62.71625871939424,62.76160915167906,62.80695958396389,62.85231001624871,62.89766044853353,62.943010880818356,62.98836131310318,63.03233978815591,63.075632284592594,63.11892478102931,63.162217277466,63.2055097739027,63.24880227033939,63.292094766776096,63.33538726321279,63.378679759649486,63.421972256086185,63.46526475252287,63.508557248959576,63.55184974539626,63.59514224183296,63.63843473826966,63.68172723470636,63.72501973114305,63.76831222757975,63.81160472401645,63.85489722045314,63.898189716889846,63.94148221332653,63.98477470976323,64.02806720619992,64.07135970263663,64.11465219907332,64.15794469551001,64.20123719194672,64.24452968838341,64.2878221848201,64.3311146812568,64.37440717769351,64.41769967413019,64.4609921705669,64.50428466700359,64.54757716344028,64.59086965987699,64.63416215631368,64.67745465275038,64.72074714918708,64.76403964562377,64.80733214206046,64.85062463849717,64.89391713493384,64.93720963137055,64.98050212780726,65.02379462424395,65.06708712068065,65.11037961711733,65.15367211355405,65.19696460999074,65.24025710642744,65.28354960286413,65.32684209930082,65.37013459573753,65.41342709217422,65.45671958861091,65.50001208504762,65.5433045814843,65.586597077921,65.62988957435769,65.6731820707944,65.71647456723109,65.75976706366778,65.80305956010449,65.84635205654118,65.88964455297787,65.93293704941456,65.97622954585127,66.01952204228797,66.06281453872467,66.10559905255741,66.14782478526179,66.19005051796617,66.23227625067054,66.27450198337492,66.3167277160793,66.35895344878367,66.40117918148805,66.44340491419243,66.48563064689681,66.52785637960116,66.57008211230556,66.40530053876745,66.03351165898687,65.66172277920633,65.28993389942578,64.91814501964521,64.54635613986466,64.17456726008412,63.802778380303536,63.430989500522955,63.05920062074245,62.68741174096187,62.315622861181296,61.94383398140074,61.572045101620205,61.20025622183962,60.828467342059085,60.456678462278546,60.084889582497965,59.71310070271742,59.34131182293687,58.969522943156306,58.597734063375725,58.22594518359521,57.854156303814634,57.48236742403405,57.110578544253514,56.73878966447296,56.367000784692394,55.99521190491184,55.623423025131295,55.25163414535072,54.87984526557014,54.50805638578963,54.13626750600906,53.764478626228474,53.392689746447935,53.02090086666739,52.64911198688682,52.27732310710627,51.905534227325724,51.53374534754515,51.1619564677646,50.79016758798406,50.41837870820348,50.046589828422896,49.67480094864239,49.30301206886181,48.93122318908124,48.55943430930069,48.187645429520146,47.81788712556109,47.45625109975978,47.09461507395847,46.732979048157134,46.371343022355795,46.00970699655453,45.648070970753196,45.28643494495185,44.92479891915055,44.56316289334924,44.2015268675479,43.839890841746595,43.47825481594528,43.11661879014394,42.75498276434263,42.39334673854133,42.031710712739994,41.670074686938655,41.30843866113737,40.946802635336034,40.585166609534696,40.22353058373339,39.86189455793208,39.500258532130744,39.13862250632943,38.77698648052814,38.4153504547268,38.05371442892548,37.69207840312418,37.33044237732284,36.9688063515215,36.60717032572019,36.24553429991889,35.897552750255336,35.576880152867396,35.25620755547945,34.93553495809147,34.614862360703526,34.294189763315586,33.97351716592761,33.652844568539635,33.332171971151716,33.01149937376375,32.690826776375765,32.37015417898782,32.04948158159988,31.7288089842119,31.40813638682396,31.08746378943601,30.766791192048036,30.44611859466009,30.1261346968721,29.814759578600498,29.503384460328903,29.19200934205733,28.880634223785762,28.569259105514163,28.25788398724259,27.946508868971023,27.635133750699428,27.323758632427854,27.012383514156287,26.701008395884678,26.38963327761309,26.07825815934154,25.766883041069942,25.455507922798343,25.144132804526773,24.832757686255206,24.521382567983604,24.210007449712037,23.898632331440467,23.587257213168865,23.275882094897298,22.964506976625724,22.65313185835413,22.341756740082527,22.030381621810957,21.71900650353939,21.407631385267784,21.096256266996214,20.784881148724644,20.473506030453052,20.16213091218148,19.850755793909908,19.53938067563831,19.22800555736671,18.91663043909517,18.60525532082357,18.29388020255197,17.9825050842804,17.67112996600883,17.359754847737232,17.04837972946566,16.737004611194088,16.42562949292249,16.11425437465092,15.802879256379349,15.49150413810775,15.180129019836151,14.86875390156461,14.55737878329301,14.246003665021412,13.934628546749844,13.62325342847827,13.311878310206673,13.000503191935103,12.68912807366353,12.377752955391934,12.066377837120335,11.755002718848791,11.443627600577193,11.132252482305594,10.820877364034025,10.509502245762453,10.198127127490856,9.924656821642255,9.840710577908302,9.756764334174349,9.672818090440398,9.58887184670646,9.504925602972508,9.420979359238553,9.337033115504617,9.253086871770664,9.169140628036711,9.085194384302774,9.001248140568821,8.917301896834868,8.833355653100915,8.749409409366978,8.665463165633026,8.581516921899073,8.497570678165136,8.413624434431183,8.32967819069723,8.245731946963293,8.16178570322934,8.077839459495387,7.993893215761449,7.909946972027497,7.826000728293544,7.742054484559591,7.658108240825654,7.574161997091701,7.490215753357749,7.419401822925754,7.357968175789916,7.296534528654077,7.235100881518252,7.173667234382414,7.112233587246577,7.05079994011074,6.989366292974913,6.927932645839077,6.866498998703238,6.805065351567413,6.743631704431575,6.682198057295738,6.620764410159912,6.559330763024074,6.497897115888238,6.436463468752411,6.3750298216165735,6.313596174480737,6.252162527344899,6.190728880209074,6.129295233073236,6.067861585937398,6.006427938801572,5.955191283654315,5.911238148005767,5.867285012357225,5.823331876708675,5.779378741060126,5.735425605411577,5.691472469763036,5.647519334114486,5.603566198465937,5.559613062817395,5.515659927168847,5.4717067915202975,5.427753655871756,5.383800520223207,5.339847384574657,5.295894248926116,5.251941113277567,5.207987977629017,5.1640348419804685,5.120081706331927,5.0761285706833785,5.032175435034828,4.988222299386287,4.944269163737738,4.900316028089189,4.8563628924406474,4.812409756792098,4.768456621143548,4.724503485494999,4.680550349846458],[55.086783498403456,55.14037196089151,55.19396042337956,55.24754888586761,55.30113734835565,55.35472581084371,55.408314273331754,55.461902735819805,55.515491198307856,55.56907966079591,55.62266812328396,55.67625658577201,55.72984504826005,55.78343351074811,55.837021973236155,55.890610435724206,55.94419889821226,55.99778736070031,56.05137582318835,56.10496428567641,56.15855274816445,56.212141210652504,56.265729673140555,56.319318135628606,56.37290659811666,56.42649506060471,56.48008352309276,56.53367198558081,56.587260448068854,56.640848910556905,56.694437373044956,56.748025835533,56.80161429802105,56.8552027605091,56.90879122299715,56.96215650157036,57.015075412198584,57.067994322826806,57.12091323345504,57.17383214408326,57.22675105471149,57.27966996533972,57.33258887596794,57.38550778659617,57.4384266972244,57.49134560785262,57.54426451848086,57.59718342910908,57.6501023397373,57.70302125036554,57.75594016099376,57.80885907162199,57.86177798225022,57.91469689287844,57.96761580350667,58.0205347141349,58.07345362476312,58.126372535391354,58.179291446019576,58.232210356647805,58.28512926727603,58.338048177904255,58.39096708853249,58.44388599916071,58.496804909788935,58.549723820417164,58.602642731045385,58.655561641673614,58.70848055230185,58.76139946293007,58.8143183735583,58.86723728418653,58.92015619481476,58.97307510544298,59.0259940160712,59.07891292669944,59.13183183732767,59.18475074795589,59.23766965858412,59.290588569212346,59.34350747984057,59.39642639046879,59.44934530109703,59.502264211725254,59.548751840704085,59.593953213353046,59.63915458600201,59.68435595865097,59.72955733129993,59.77475870394889,59.81996007659785,59.86516144924681,59.91036282189578,59.95556419454474,60.0007655671937,60.045966939842664,60.091168312491625,60.136369685140586,60.18157105778955,60.22677243043851,60.27197380308747,60.31717517573643,60.3623765483854,60.40757792103436,60.452779293683314,60.49798066633228,60.54318203898124,60.5883834116302,60.633584784279165,60.678786156928126,60.72398752957709,60.76918890222605,60.81439027487501,60.85959164752397,60.90479302017293,60.94999439282189,60.995195765470854,61.040397138119815,61.085623354032876,61.13097378631768,61.17632421860252,61.22167465088732,61.26702508317214,61.31237551545698,61.35772594774179,61.40307638002662,61.44842681231144,61.49377724459626,61.53912767688108,61.5844781091659,61.62982854145072,61.67517897373554,61.72052940602036,61.76587983830519,61.81123027059001,61.85658070287484,61.90193113515966,61.94728156744447,61.9926319997293,62.03798243201412,62.08333286429894,62.12868329658376,62.17403372886858,62.2193841611534,62.26473459343822,62.31008502572304,62.35543545800787,62.40078589029268,62.4461363225775,62.49148675486233,62.53683718714715,62.58218761943198,62.62753805171679,62.67288848400161,62.71823891628644,62.76358934857126,62.80893978085608,62.85429021314091,62.89964064542573,62.94499107771054,62.99034150999536,63.03569194228019,63.08104237456501,63.12639280684983,63.17174323913465,63.21709367141947,63.26244410370429,63.30642257875704,63.34971507519373,63.39300757163042,63.43630006806712,63.47959256450381,63.52288506094052,63.56617755737721,63.60947005381391,63.65276255025061,63.6960550466873,63.739347543124,63.7826400395607,63.82593253599739,63.86922503243409,63.91251752887078,63.95581002530748,63.99910252174417,64.04239501818087,64.08568751461758,64.12898001105427,64.17227250749096,64.21556500392765,64.25885750036434,64.30214999680105,64.34544249323774,64.38873498967445,64.43202748611114,64.47531998254783,64.51861247898452,64.56190497542123,64.60519747185792,64.64848996829463,64.69178246473132,64.73507496116801,64.77836745760472,64.82165995404141,64.86495245047811,64.9082449469148,64.9515374433515,64.99482993978819,65.03812243622488,65.08141493266159,65.1247074290983,65.16799992553497,65.21129242197168,65.25458491840837,65.29787741484506,65.34116991128177,65.38446240771846,65.42775490415517,65.47104740059186,65.51433989702855,65.55763239346525,65.60034070969577,65.64256644240014,65.68479217510452,65.72701790780889,65.76924364051328,65.81146937321765,65.85369510592203,65.8959208386264,65.93814657133078,65.98037230403514,66.02259803673952,66.0648237694439,66.10704950214827,66.14927523485265,66.19150096755703,66.2337267002614,66.27595243296578,66.31817816567016,66.36040389837454,66.40262963107891,66.44485536378329,66.48708109648767,66.52930682919204,66.57153256189642,66.6137582946008,66.65598402730518,66.69820976000955,66.74043549271391,66.78266122541831,66.82488695812268,66.66010538458457,66.28831650480399,65.91652762502345,65.54473874524291,65.17294986546233,64.80116098568179,64.42937210590124,64.05758322612067,63.68579434634009,63.31400546655958,62.942216586779,62.57042770699842,62.19863882721788,61.82684994743733,61.45506106765676,61.083272187876204,60.711483308095666,60.339694428315084,59.967905548534546,59.596116668754,59.224327788973426,58.852538909192845,58.480750029412334,58.10896114963175,57.73717226985118,57.36538339007063,56.993594510290094,56.62180563050951,56.250016750728975,55.87822787094842,55.50643899116785,55.13465011138727,54.76286123160676,54.39107235182618,54.0192834720456,53.64749459226506,53.275705712484516,52.90391683270394,52.53212795292339,52.160339073142836,51.78855019336227,51.41676131358172,51.04497243380118,50.6731835540206,50.30139467424002,49.92960579445952,49.55781691467894,49.18602803489836,48.81423915511781,48.442450275337265,48.0706613955567,47.698872515776145,47.327083635995606,46.955294756215025,46.583505876434444,46.21171699665394,45.83992811687337,45.468139237092785,45.09635035731224,44.724561477531694,44.35277259775111,43.980983717970574,43.609194838190035,43.237405958409454,42.865617078628915,42.49382819884836,42.12203931906779,41.750250439287214,41.3734873600416,40.972848053829836,40.57220874761808,40.171569441406355,39.77093013519463,39.370290828982874,38.96965152277115,38.56901221655943,38.168372910347664,37.76773360413594,37.36709429792422,36.96645499171246,36.5658156855007,36.16517637928897,35.76453707307725,35.39497538544934,35.08756893498914,34.780162484528944,34.47275603406871,34.16534958360851,33.85794313314831,33.550536682688076,33.24313023222785,32.93572378176767,32.62831733130745,32.320910880847215,32.013504430387016,31.706097979926813,31.398691529466586,31.091285079006383,30.783878628546184,30.476472178085952,30.16906572762575,29.86165927716555,29.554252826705316,29.246846376245088,28.939439925784885,28.63203347532469,28.32462702486446,28.017220574404256,27.70981412394405,27.402407673483825,27.095001223023626,26.787594772563423,26.480188322103192,26.172781871642968,25.86537542118279,25.55796897072256,25.250562520262328,24.94315606980213,24.63574961934193,24.328343168881702,24.020936718421495,23.713530267961296,23.40612381750106,23.098717367040862,22.79131091658066,22.48390446612043,22.1764980156602,21.8690915652,21.5616851147398,21.254278664279568,20.94687221381937,20.63946576335917,20.332059312898938,20.024652862438735,19.717246411978532,19.409839961518305,19.102433511058074,18.79287736684306,18.481502248571466,18.17012713029986,17.858752012028297,17.547376893756724,17.236001775485125,16.92462665721355,16.613251538941984,16.30187642067039,15.990501302398815,15.679126184127245,15.367751065855643,15.056375947584048,14.745000829312504,14.433625711040909,14.122250592769305,13.810875474497735,13.499500356226164,13.188125237954567,12.876750119682995,12.565375001411427,12.253999883139828,11.94262476486823,11.631249646596686,11.319874528325087,11.008499410053489,10.69712429178192,10.385749173510352,10.07437405523875,9.80090374939015,9.716957505656195,9.633011261922244,9.54906501818829,9.465118774454353,9.381172530720402,9.297226286986447,9.217166140582709,9.155732493446871,9.094298846311034,9.032865199175209,8.971431552039371,8.909997904903532,8.848564257767697,8.787130610631868,8.725696963496034,8.664263316360195,8.60282966922437,8.541396022088533,8.479962374952695,8.418528727816868,8.357095080681031,8.295661433545193,8.234227786409368,8.172794139273531,8.111360492137692,8.049926845001856,7.988493197866029,7.927059550730192,7.865625903594355,7.804192256458529,7.742758609322691,7.681324962186854,7.619891315051028,7.5584576679151905,7.497024020779353,7.435590373643516,7.374156726507691,7.312723079371852,7.251289432236015,7.189855785100189,7.1284221379643515,7.066988490828514,7.005554843692688,6.94412119655685,6.882687549421013,6.8212539022851875,6.759820255149348,6.698386608013512,6.636952960877675,6.575519313741849,6.514085666606011,6.4526520194701735,6.391218372334348,6.32978472519851,6.268351078062673,6.206917430926847,6.1454837837910095,6.084050136655172,6.022616489519335,5.961182842383509,5.899749195247672,5.838315548111835,5.776881900976008,5.7154482538401705,5.654014606704333,5.592580959568507,5.531147312432671,5.469713665296833,5.4082800181610065,5.34684637102517,5.285412723889332,5.223979076753494,5.162545429617667,5.10111178248183,5.039678135345993,4.9782444882101675,4.934187306288203,4.890234170639655,4.846281034991113,4.802327899342564,4.758374763694015,4.714421628045465,4.670468492396924],[55.352278167223304,55.405866629711355,55.459455092199406,55.51304355468746,55.56663201717551,55.62022047966356,55.673808942151595,55.727397404639646,55.78098586712771,55.83457432961576,55.8881627921038,55.94175125459185,55.9953397170799,56.04892817956795,56.102516642056,56.156105104544054,56.209693567032105,56.263282029520155,56.316870492008206,56.37045895449626,56.42404741698431,56.47763587947236,56.531224341960396,56.584812804448454,56.6384012669365,56.69198972942455,56.74557819191261,56.79916665440065,56.85275511688871,56.90634357937675,56.9599320418648,57.013520504352854,57.0671089668409,57.120697429328956,57.17428589181701,57.22787435430506,57.2814628167931,57.33505127928115,57.388639741769204,57.44222820425725,57.4958166667453,57.54940512923335,57.6029935917214,57.65658205420945,57.7101705166975,57.76375897918555,57.817347441673604,57.870935904161655,57.92452436664969,57.97811282913774,58.03170129162581,58.08528975411386,58.13832025686762,58.19123916749585,58.24415807812407,58.2970769887523,58.34999589938053,58.40291481000875,58.45583372063698,58.5087526312652,58.56167154189343,58.61459045252167,58.66750936314989,58.72042827377811,58.77334718440635,58.826266095034576,58.87918500566279,58.93210391629103,58.98502282691925,59.03794173754748,59.090860648175706,59.14377955880393,59.19669846943216,59.249617380060386,59.302536290688614,59.355455201316836,59.408374111945065,59.46129302257329,59.514211933201516,59.56713084382975,59.62004975445798,59.6729686650862,59.72588757571443,59.77880648634265,59.8252941153215,59.87049548797046,59.91569686061942,59.96089823326838,60.00609960591734,60.0513009785663,60.096502351215264,60.141703723864225,60.186905096513186,60.23210646916215,60.27730784181111,60.32250921446006,60.36771058710903,60.41291195975799,60.45811333240696,60.50331470505592,60.548516077704875,60.593717450353836,60.6389188230028,60.68412019565176,60.72932156830072,60.77452294094968,60.81972431359864,60.8649256862476,60.91012705889658,60.955328431545524,61.000529804194485,61.04573117684346,61.09093254949241,61.13613392214138,61.181335294790344,61.226536667439305,61.27173804008826,61.31693941273722,61.36214078538619,61.40734215803514,61.45254353068411,61.497744903333064,61.542946275982025,61.588147648630994,61.63334902127995,61.678550393928916,61.72375176657788,61.76895313922684,61.8141545118758,61.85935588452476,61.90455725717372,61.94975862982268,61.99496000247164,62.040161375120604,62.085362747769565,62.13066349347595,62.17601392576077,62.2213643580456,62.266714790330425,62.31206522261524,62.35741565490006,62.40276608718489,62.44811651946971,62.49346695175453,62.53881738403935,62.58416781632417,62.62951824860899,62.67486868089381,62.72021911317863,62.76556954546345,62.81091997774827,62.85627041003309,62.90162084231792,62.94697127460274,62.992321706887566,63.037672139172386,63.0830225714572,63.12837300374203,63.17372343602685,63.21907386831167,63.26442430059648,63.309774732881316,63.35512516516613,63.40047559745095,63.44582602973578,63.4911764620206,63.53652689430542,63.58050536935815,63.62379786579484,63.66709036223155,63.71038285866824,63.75367535510493,63.79696785154163,63.84026034797833,63.88355284441503,63.92684534085173,63.970137837288426,64.01343033372513,64.05672283016182,64.10001532659851,64.1433078230352,64.1866003194719,64.2298928159086,64.27318531234529,64.316477808782,64.35977030521869,64.40306280165538,64.44635529809209,64.48964779452876,64.53294029096547,64.57623278740218,64.61952528383887,64.66281778027556,64.70611027671225,64.74940277314896,64.79269526958565,64.83598776602236,64.87928026245905,64.92257275889574,64.96586525533243,65.00915775176914,65.05245024820583,65.0950823668341,65.1373080995385,65.17953383224287,65.22175956494723,65.26398529765162,65.306211030356,65.34843676306036,65.39066249576476,65.43288822846912,65.47511396117349,65.51733969387789,65.55956542658225,65.60179115928663,65.644016891991,65.68624262469538,65.72846835739976,65.77069409010414,65.81291982280851,65.85514555551289,65.89737128821727,65.93959702092164,65.98182275362602,66.0240484863304,66.06627421903477,66.10849995173915,66.15072568444351,66.1929514171479,66.23517714985228,66.27740288255666,66.31962861526102,66.3618543479654,66.40408008066979,66.44630581337415,66.48853154607853,66.5307572787829,66.57298301148728,66.61520874419166,66.65743447689604,66.69966020960041,66.74188594230479,66.78411167500917,66.82633740771354,66.86856314041792,66.9107888731223,66.95301460582667,66.99524033853106,67.03746607123541,67.0796918039398,66.9149102304017,66.54312135062112,66.17133247084058,65.79954359106003,65.42775471127945,65.05596583149891,64.68417695171837,64.31238807193779,63.940599192157215,63.5688103123767,63.19702143259612,62.82523255281555,62.453443673035,62.08165479325446,61.70986591347388,61.33807703369334,60.96628815391279,60.59449927413221,60.222710394351665,59.85092151457112,59.479132634790545,59.10734375500997,58.73555487522947,58.36376599544889,57.991977115668305,57.62018823588777,57.248399356107214,56.87661047632663,56.504821596546094,56.133032716765555,55.76124383698498,55.3894549572044,55.01766607742389,54.645877197643316,54.27408831786273,53.90229943808218,53.53051055830164,53.15872167852107,52.786932798740516,52.41514391895997,52.043355039179396,51.67156615939885,51.28982888692576,50.889189580714,50.488550274502245,50.08791096829056,49.68727166207879,49.28663235586703,48.885993049655305,48.48535374344358,48.084714437231824,47.684075131020094,47.28343582480838,46.88279651859662,46.482157212384855,46.08151790617317,45.68087859996141,45.28023929374965,44.87959998753793,44.4789606813262,44.07832137511444,43.67768206890271,43.277042762690996,42.87640345647923,42.47576415026751,42.07512484405579,41.67448553784403,41.27384623163226,40.87320692542058,40.472567619208824,40.07192831299706,39.67128900678534,39.270649700573614,38.870010394361856,38.46937108815013,38.06873178193841,37.668092475726645,37.26745316951492,36.8668138633032,36.466174557091435,36.06553525087968,35.66489594466796,35.26425663845623,34.894694950828324,34.58728850036812,34.27988204990792,33.97247559944769,33.66506914898749,33.35766269852729,33.05025624806706,32.74284979760683,32.43544334714665,32.128036896686424,31.820630446226197,31.513223995765998,31.205817545305795,30.898411094845564,30.591004644385364,30.283598193925158,29.976191743464934,29.66878529300473,29.361378842544532,29.0539723920843,28.74656594162407,28.43915949116387,28.131753040703668,27.824346590243437,27.516940139783237,27.209533689323035,26.902127238862803,26.594720788402604,26.287314337942405,25.97990788748217,25.672501437021946,25.365094986561772,25.05768853610154,24.750282085641313,24.44287563518111,24.135469184720908,23.82806273426068,23.520656283800477,23.213249833340274,22.905843382880043,22.598436932419844,22.29103048195964,21.98362403149941,21.676217581039182,21.36881113057898,21.061404680118777,20.753998229658553,20.446591779198346,20.139185328738144,19.83177887827792,19.524372427817717,19.21696597735751,18.909559526897286,18.602153076437055,18.29474662597688,17.987340175516653,17.684407924471877,17.386763376274875,17.089118828077872,16.791474279880838,16.493829731683835,16.196185183486833,15.898540635289802,15.600896087092798,15.303251538895795,15.005606990698762,14.707962442501733,14.410317894304757,14.112673346107727,13.815028797910696,13.51738424971369,13.219739701516687,12.922095153319658,12.624450605122654,12.326806056925651,12.02916150872862,11.731516960531588,11.433872412334612,11.136227864137581,10.83858331594055,10.540938767743548,10.243294219546542,9.945649671349512,9.684490420808945,9.605757658550376,9.527024896291804,9.448292134033235,9.369559371774677,9.290826609516108,9.212093847257536,9.133361084998981,9.05462832274041,8.97589556048184,8.897162798223285,8.818430035964713,8.739697273706142,8.660964511447572,8.582231749189017,8.503498986930445,8.424766224671874,8.346033462413319,8.267300700154749,8.188567937896178,8.10983517563762,8.03110241337905,7.95236965112048,7.873636888861924,7.7949041266033525,7.716171364344783,7.637438602086213,7.558705839827656,7.4799730775690865,7.401240315310515,7.32250755305196,7.243774790793388,7.181929223993484,7.1204955768576585,7.059061929721821,6.997628282585983,6.936194635450146,6.87476098831432,6.813327341178483,6.7518936940426455,6.69046004690682,6.629026399770982,6.567592752635145,6.506159105499318,6.4447254583634805,6.383291811227643,6.321858164091817,6.26042451695598,6.198990869820143,6.137557222684305,6.076123575548479,6.0146899284126425,5.956990680107154,5.915162412808262,5.873334145509363,5.831505878210465,5.789677610911573,5.747849343612673,5.706021076313775,5.664192809014875,5.622364541715984,5.580536274417085,5.538708007118186,5.4968797398192955,5.455051472520395,5.413223205221497,5.371394937922606,5.329566670623706,5.287738403324807,5.245910136025914,5.204081868727016,5.162253601428118,5.120425334129218,5.078597066830326,5.036768799531428,4.994940532232528,4.953112264933637,4.911283997634738,4.869455730335839,4.827627463036948,4.785799195738049,4.743970928439149,4.70214266114025,4.660314393841358],[55.617772836043166,55.67136129853122,55.72494976101926,55.77853822350731,55.83212668599537,55.88571514848341,55.939303610971464,55.992892073459515,56.04648053594756,56.10006899843561,56.15365746092367,56.20724592341171,56.26083438589976,56.314422848387814,56.368011310875865,56.421599773363916,56.47518823585196,56.52877669834001,56.58236516082806,56.63595362331612,56.68954208580416,56.743130548292214,56.79671901078026,56.850307473268316,56.90389593575636,56.95748439824442,57.01107286073247,57.06466132322051,57.11824978570856,57.17183824819661,57.22542671068466,57.27901517317271,57.33260363566076,57.38619209814881,57.43978056063686,57.49336902312491,57.546957485612964,57.600545948101015,57.654134410589066,57.70772287307711,57.76131133556516,57.81489979805321,57.86848826054126,57.92207672302931,57.97566518551736,58.02925364800541,58.08284211049346,58.13643057298151,58.190019035469554,58.243607497957605,58.29719596044566,58.350784422933714,58.404372885421765,58.45796134790981,58.51154981039786,58.56513827288591,58.61872673537396,58.672315197862005,58.72590366035006,58.779492122838114,58.83308058532616,58.88666904781421,58.94025751030226,58.993845972790304,59.047434435278355,59.101022897766406,59.15461136025446,59.20819982274251,59.26156510153666,59.3144840121649,59.36740292279312,59.42032183342134,59.473240744049576,59.526159654677805,59.57907856530603,59.631997475934256,59.684916386562485,59.737835297190706,59.790754207818935,59.84367311844717,59.89659202907539,59.949510939703615,60.00242985033184,60.05534876096007,60.1018363899389,60.14703776258787,60.192239135236825,60.237440507885786,60.28264188053475,60.32784325318371,60.37304462583268,60.41824599848164,60.4634473711306,60.50864874377956,60.55385011642852,60.599051489077475,60.64425286172645,60.689454234375404,60.73465560702437,60.77985697967333,60.82505835232229,60.87025972497125,60.915461097620216,60.96066247026918,61.00586384291814,61.0510652155671,61.09626658821606,61.14146796086502,61.18666933351398,61.231870706162944,61.277072078811905,61.322273451460866,61.36747482410983,61.41267619675879,61.45787756940775,61.50307894205671,61.54828031470567,61.59348168735463,61.6386830600036,61.683884432652555,61.72908580530152,61.774287177950484,61.81948855059944,61.864689923248406,61.90989129589737,61.95509266854633,62.00029404119529,62.04549541384425,62.09069678649321,62.13589815914217,62.181099531791126,62.2263009044401,62.271502277089056,62.31670364973802,62.36190502238698,62.40710639503594,62.45230776768491,62.49750914033387,62.54271051298283,62.58791188563179,62.633113258280744,62.67831463092971,62.72351600357867,62.768717376227634,62.813918748876596,62.85912012152556,62.90432149417452,62.94952286682348,62.99472423947244,63.0399256121214,63.08512698477036,63.13035320063422,63.175703632919046,63.221054065203866,63.266404497488686,63.31175492977351,63.35710536205833,63.402455794343155,63.447806226627975,63.493156658912795,63.53850709119761,63.583857523482436,63.62920795576726,63.67455838805208,63.719908820336904,63.765259252621725,63.81060968490654,63.85458815995928,63.89788065639598,63.941173152832675,63.984465649269374,64.02775814570606,64.07105064214277,64.11434313857947,64.15763563501616,64.20092813145286,64.24422062788955,64.28751312432625,64.33080562076294,64.37409811719964,64.41739061363634,64.46068311007303,64.50397560650973,64.54726810294642,64.58982402397248,64.63204975667685,64.67427548938123,64.71650122208561,64.75872695478998,64.80095268749436,64.84317842019874,64.8854041529031,64.92762988560749,64.96985561831187,65.01208135101623,65.05430708372062,65.096532816425,65.13875854912938,65.18098428183374,65.22321001453813,65.26543574724249,65.30766147994687,65.34988721265125,65.39211294535563,65.43433867806,65.47656441076438,65.51879014346875,65.56101587617313,65.60324160887751,65.64546734158188,65.68769307428626,65.72991880699064,65.772144539695,65.81437027239939,65.85659600510377,65.89882173780813,65.94104747051253,65.9832732032169,66.02549893592128,66.06772466862564,66.10995040133002,66.1521761340344,66.19440186673879,66.23662759944315,66.27885333214753,66.3210790648519,66.36330479755628,66.40553053026066,66.44775626296504,66.48998199566941,66.53220772837379,66.57443346107816,66.61665919378254,66.65888492648692,66.70111065919129,66.74333639189567,66.78556212460005,66.82778785730441,66.8700135900088,66.91223932271318,66.95446505541756,66.99669078812192,67.0389165208263,67.08114225353069,67.12336798623505,67.16559371893943,67.20781945164381,67.25004518434818,67.29227091705256,67.33449664975694,67.16971507621884,66.79792619643825,66.42613731665772,66.05434843687716,65.6825595570966,65.31077067731604,64.9389817975355,64.56719291775492,64.19540403797434,63.82361515819383,63.45182627841326,63.08003739863268,62.70824851885214,62.33645963907159,61.96467075929101,61.592881879510465,61.20617041380989,60.80553110759814,60.40489180138641,60.00425249517469,59.60361318896293,59.20297388275117,58.80233457653949,58.40169527032772,58.00105596411596,57.60041665790424,57.19977735169252,56.79913804548075,56.39849873926903,55.99785943305731,55.59722012684555,55.196580820633784,54.795941514422104,54.39530220821034,53.99466290199858,53.59402359578686,53.193384289575135,52.79274498336338,52.39210567715165,51.991466370939925,51.59082706472817,51.190187758516444,50.78954845230472,50.38890914609296,49.9882698398812,49.58763053366951,49.18699122745775,48.78635192124599,48.38571261503427,47.98507330882254,47.58443400261078,47.18379469639906,46.78315539018734,46.38251608397558,45.98187677776382,45.581237471552136,45.18059816534037,44.77995885912861,44.37931955291689,43.97868024670517,43.5780409404934,43.17740163428168,42.77676232806996,42.37612302185819,41.975483715646476,41.574844409434746,41.17420510322299,40.77356579701123,40.37292649079955,39.972287184587785,39.57164787837602,39.1710085721643,38.770369265952574,38.369729959740816,37.96909065352909,37.568451347317364,37.167812041105606,36.76717273489388,36.36653342868216,35.9658941224704,35.56525481625864,35.164615510046914,34.76397620383519,34.394414516207284,34.08700806574708,33.77960161528688,33.47219516482665,33.16478871436645,32.85738226390625,32.54997581344602,32.24256936298579,31.935162912525616,31.62775646206539,31.320350011605157,31.012943561144958,30.70553711068475,30.398130660224524,30.090724209764325,29.783317759304122,29.475911308843894,29.1781650563171,28.880520508120096,28.582875959923065,28.28523141172603,27.987586863529028,27.689942315332026,27.392297767135,27.09465321893799,26.79700867074099,26.499364122543955,26.201719574346953,25.90407502614995,25.60643047795292,25.308785929755892,25.011141381558915,24.713496833361884,24.415852285164853,24.118207736967847,23.820563188770844,23.522918640573817,23.225274092376807,22.92762954417981,22.629984995982777,22.33234044778577,22.03469589958877,21.737051351391738,21.439406803194707,21.1417622549977,20.844117706800695,20.546473158603668,20.248828610406665,19.951184062209663,19.653539514012632,19.35589496581563,19.058250417618623,18.760605869421592,18.46296132122456,18.165316773027584,17.867672224830557,17.570027676633522,17.27238312843652,16.974738580239517,16.677094032042486,16.37944948384548,16.08180493564848,15.784160387451447,15.486515839254444,15.188871291057442,14.89122674286041,14.59358219466338,14.295937646466404,13.998293098269372,13.700648550072344,13.403004001875338,13.105359453678336,12.807714905481305,12.510070357284299,12.212425809087296,11.914781260890265,11.617136712693236,11.319492164496259,11.021847616299228,10.724203068102197,10.426558519905193,10.12891397170819,9.83126942351116,9.570110172970594,9.491377410712023,9.412644648453453,9.333911886194882,9.255179123936326,9.176446361677755,9.097713599419185,9.018980837160628,8.940248074902058,8.861515312643489,8.782782550384931,8.70404978812636,8.625317025867789,8.546584263609219,8.467851501350664,8.389118739092092,8.310385976833523,8.231653214574967,8.152920452316396,8.074187690057824,7.995454927799269,7.9167221655406985,7.837989403282128,7.759256641023572,7.680523878765,7.605664428156958,7.54780000038994,7.48993557262293,7.432071144855912,7.374206717088894,7.316342289321886,7.258477861554867,7.200613433787847,7.14274900602084,7.0848845782538215,7.027020150486803,6.969155722719784,6.911291294952777,6.853426867185758,6.79556243941874,6.737698011651731,6.6798335838847125,6.621969156117694,6.564104728350686,6.506240300583666,6.448375872816649,6.39051144504964,6.332647017282621,6.2747825895156035,6.216918161748584,6.159053733981576,6.1011893062145575,6.043324878447538,5.985460450680531,5.927596022913512,5.869731595146494,5.811867167379486,5.754002739612467,5.6961383118454485,5.6540063122543565,5.612178044955466,5.570349777656567,5.528521510357668,5.486693243058776,5.444864975759876,5.403036708460978,5.361208441162087,5.319380173863188,5.277551906564288,5.235723639265397,5.193895371966498,5.152067104667599,5.1102388373686995,5.068410570069808,5.026582302770909,4.98475403547201,4.942925768173119,4.9010975008742195,4.85926923357532,4.817440966276429,4.77561269897753,4.733784431678631,4.691956164379731,4.650127897080841],[55.88229784405495,55.936549327679444,55.99013779053373,56.04372625302179,56.09731471550984,56.15090317799789,56.204491640485934,56.258080102973985,56.31166856546204,56.36525702795009,56.41884549043814,56.47243395292619,56.52602241541424,56.57961087790228,56.63319934039034,56.68678780287839,56.740376265366436,56.79396472785449,56.84755319034254,56.90114165283059,56.95473011531863,57.00831857780668,57.06190704029474,57.115495502782785,57.16908396527084,57.22267242775888,57.27626089024693,57.329849352734996,57.38343781522303,57.437026277711084,57.490614740199135,57.54420320268718,57.59779166517524,57.65138012766328,57.70496859015134,57.75855705263939,57.812145515127426,57.86573397761549,57.91932244010353,57.97291090259159,58.02649936507963,58.08008782756768,58.13367629005573,58.18726475254378,58.240853215031834,58.294441677519885,58.348030140007936,58.40161860249599,58.45520706498404,58.50879552747209,58.56238398996014,58.61597245244818,58.669560914936234,58.72314937742429,58.776737839912336,58.83032630240039,58.88391476488844,58.93750322737649,58.99109168986453,59.04468015235259,59.09826861484064,59.151857077328685,59.205445539816736,59.25903400230479,59.31262246479284,59.36621092728089,59.41979938976894,59.47338785225699,59.526976314745035,59.580564777233086,59.63415323972114,59.68774170220918,59.74133016469723,59.79491862718528,59.84850708967333,59.90209555216139,59.955684014649435,60.009272477137486,60.06286093962554,60.11644940211359,60.17003786460164,60.22362632708968,60.27721478957774,60.33080325206579,60.377402473021256,60.422603845670224,60.467805218319185,60.513006590968146,60.5582079636171,60.60340933626606,60.64861070891502,60.69381208156399,60.73901345421295,60.78421482686191,60.829416199510874,60.87461757215983,60.919818944808796,60.96502031745776,61.010221690106725,61.055423062755686,61.10062443540465,61.14582580805361,61.19102718070257,61.23622855335154,61.281429926000484,61.326631298649446,61.37183267129841,61.41703404394737,61.462235416596336,61.5074367892453,61.55263816189425,61.59783953454321,61.64304090719217,61.68824227984114,61.7334436524901,61.77864502513906,61.823846397788024,61.86904777043698,61.91424914308595,61.9594505157349,62.004651888383876,62.04985326103283,62.09505463368179,62.14025600633076,62.18545737897972,62.23065875162868,62.27586012427764,62.3210614969266,62.366262869575564,62.411464242224525,62.45666561487349,62.501866987522455,62.54706836017141,62.59226973282037,62.63747110546933,62.68267247811829,62.72787385076726,62.77307522341622,62.818276596065175,62.863477968714136,62.9086793413631,62.95388071401207,62.999082086661026,63.04428345930999,63.08948483195895,63.13468620460791,63.17988757725688,63.22508894990584,63.27029032255479,63.315491695203754,63.360693067852715,63.405894440501676,63.451095813150644,63.496297185799605,63.541498558448566,63.58669993109753,63.63190130374648,63.67710267639545,63.72230404904441,63.76750542169337,63.81270679434233,63.857908166991294,63.90310953964026,63.948310912289216,63.99351228493818,64.03871365758714,64.0837298288325,64.12618703242957,64.16777212587846,64.20992462213282,64.25207711838718,64.29422961464154,64.33638211089591,64.37853460715027,64.42068710340463,64.46283959965899,64.50499209591335,64.54714459216771,64.58929708842207,64.63144958467645,64.67360208093079,64.71575457718517,64.75790707343953,64.80005956969389,64.84221206594825,64.88436456220262,64.92651705845697,64.96866955471134,65.0108220509657,65.05297454722006,65.09512704347442,65.1372795397288,65.17943203598314,65.22158453223751,65.26373702849186,65.30588952474623,65.3480420210006,65.39019451725495,65.43234701350931,65.47449950976369,65.51665200601803,65.55880450227241,65.60095699852677,65.64310949478113,65.68526199103549,65.72741448728985,65.76956698354421,65.81171947979857,65.85387197605293,65.89602447230729,65.93817696856166,65.98032946481602,66.02248196107038,66.06463445732474,66.10678695357912,66.14893944983346,66.19109194608784,66.2332444423422,66.27539693859656,66.31754943485093,66.35970193110528,66.40185442735965,66.44400692361401,66.48615941986837,66.52831191612275,66.57046441237709,66.61261690863145,66.65476940488583,66.69692190114017,66.73907439739455,66.78122689364889,66.82337938990327,66.86553188615763,66.90768438241199,66.94983687866636,66.99198937492072,67.03414187117508,67.07629436742944,67.1184468636838,67.16059935993816,67.20275185619253,67.2449043524469,67.28705684870125,67.32920934495561,67.37136184120997,67.41351433746433,67.4556668337187,67.49781932997307,67.53997182622743,67.58212432248179,67.3908407542415,66.96612112150656,66.54140148877167,66.11668185603676,65.69196222330184,65.26724259056694,64.84252295783205,64.41780332509711,63.99308369236217,63.568364059627314,63.14364442689238,62.718924794157445,62.3150947668349,61.914493088347726,61.5138914098605,61.113289731373314,60.71268805288613,60.312086374398916,59.911484695911724,59.51088301742454,59.11028133893732,58.70967966045009,58.30907798196295,57.90847630347573,57.50787462498851,57.107272946501325,56.706671268014134,56.30606958952691,55.905467911039736,55.50486623255255,55.104264554065324,54.703662875578104,54.303061197090955,53.90245951860374,53.501857840116514,53.10125616162934,52.70065448314215,52.300052804654925,51.89945112616773,51.498849447680556,51.098247769193335,50.69764609070616,50.297044412218966,49.896442733731746,49.495841055244526,49.09523937675738,48.69463769827016,48.294036019782936,47.89343434129575,47.49283266280857,47.09223098432135,46.691629305834155,46.29102762734698,45.89042594885976,45.48982427037254,45.08922259188539,44.68862091339817,44.28801923491094,43.887417556423756,43.48681587793658,43.08621419944936,42.68561252096217,42.28501084247499,41.88440916398777,41.48380748550058,41.0832058070134,40.68260412852617,40.28200245003895,39.88140077155181,39.48079909306458,39.08019741457737,38.67959573609018,38.278994057603,37.87839237911577,37.47779070062859,37.077189022141404,36.676587343654184,36.275985665167,35.875383986679815,35.47478230819259,35.074180629705374,34.67357895121819,34.27297727273101,33.907799701237245,33.613470343730434,33.31914098622362,33.024811628716776,32.730482271209965,32.436152913703154,32.14182355619631,31.847494198689468,31.55316484118268,31.258835483675846,30.964506126169,30.670176768662184,30.375847411155373,30.081518053648534,29.78718869614172,29.492859338634904,29.198529981128065,28.90420062362125,28.609871266114435,28.315541908607596,28.021212551100753,27.72688319359394,27.432553836087123,27.138224478580288,26.843895121073473,26.549565763566658,26.255236406059815,25.960907048553004,25.66657769104619,25.37224833353935,25.077918976032507,24.78358961852572,24.489260261018877,24.194930903512038,23.900601546005227,23.606272188498416,23.31194283099157,23.017613473484758,22.723284115977943,22.4289547584711,22.134625400964286,21.84029604345747,21.54596668595063,21.251637328443792,20.957307970936977,20.662978613430163,20.368649255923323,20.074319898416505,19.779990540909694,19.485661183402854,19.19133182589604,18.897002468389225,18.602673110882385,18.308343753375546,18.014014395868756,17.719685038361916,17.425355680855073,17.131026323348262,16.836696965841448,16.542367608334608,16.24803825082779,15.953708893320979,15.65937953581414,15.365050178307323,15.07072082080051,14.776391463293669,14.479201946825032,14.181557398628055,13.883912850431024,13.586268302233993,13.28862375403699,12.990979205839986,12.693334657642957,12.395690109445953,12.098045561248949,11.800401013051918,11.502756464854889,11.205111916657911,10.907467368460882,10.60982282026385,10.312178272066847,10.014533723869842,9.716889175672812,9.455729925132246,9.376997162873675,9.298264400615103,9.219531638356536,9.156410620275324,9.098546192508305,9.040681764741288,8.982817336974279,8.92495290920726,8.867088481440241,8.809224053673235,8.751359625906215,8.693495198139196,8.635630770372178,8.57776634260517,8.519901914838151,8.462037487071132,8.404173059304124,8.346308631537106,8.288444203770087,8.23057977600308,8.17271534823606,8.114850920469042,8.056986492702034,7.999122064935015,7.941257637167997,7.883393209400977,7.82552878163397,7.767664353866951,7.709799926099932,7.651935498332924,7.594071070565906,7.536206642798887,7.478342215031879,7.42047778726486,7.362613359497841,7.304748931730822,7.246884503963815,7.189020076196796,7.131155648429777,7.073291220662769,7.0154267928957506,6.957562365128732,6.899697937361724,6.841833509594705,6.783969081827687,6.726104654060678,6.66824022629366,6.61037579852664,6.552511370759621,6.494646942992614,6.436782515225596,6.378918087458577,6.321053659691569,6.26318923192455,6.205324804157533,6.147460376390524,6.089595948623505,6.031731520856487,5.973867093089467,5.91600266532246,5.8581382375554405,5.800273809788422,5.742409382021414,5.684544954254395,5.626680526487377,5.568816098720369,5.51095167095335,5.4530872431863315,5.395222815419324,5.337358387652305,5.279493959885286,5.221629532118268,5.16376510435126,5.105900676584241,5.048036248817223,4.990171821050214,4.932307393283195,4.874442965516176,4.8165785377491686,4.765426202217012,4.7235979349181125,4.681769667619214,4.639941400320322],[56.13179311821963,56.18604460184413,56.24029608546862,56.29454756909312,56.34879905271762,56.40305053634211,56.457302019966605,56.5115535035911,56.56580498721559,56.62005647084009,56.67430795446458,56.72855943808908,56.78281092171357,56.83706240533806,56.89131388896256,56.945565372587055,56.99981685621155,57.05406833983604,57.10798831336797,57.161576775856005,57.215165238344056,57.26875370083211,57.32234216332016,57.37593062580821,57.42951908829626,57.48310755078431,57.53669601327236,57.59028447576041,57.643872938248464,57.697461400736515,57.751049863224566,57.8046383257126,57.85822678820065,57.91181525068871,57.96540371317676,58.01899217566482,58.07258063815286,58.12616910064091,58.17975756312896,58.23334602561701,58.28693448810506,58.34052295059311,58.39411141308116,58.447699875569214,58.50128833805726,58.554876800545316,58.60846526303337,58.66205372552142,58.715642188009454,58.769230650497505,58.822819112985556,58.87640757547361,58.92999603796166,58.98358450044971,59.03717296293776,59.09076142542581,59.14434988791386,59.19793835040191,59.251526812889956,59.30511527537801,59.35870373786606,59.412292200354116,59.46588066284217,59.51946912533021,59.57305758781826,59.62664605030631,59.680234512794364,59.733822975282415,59.78741143777046,59.84099990025851,59.89458836274656,59.94817682523461,60.001765287722655,60.055353750210706,60.108942212698764,60.162530675186815,60.21611913767486,60.26970760016291,60.32329606265096,60.37688452513901,60.43047298762706,60.484061450115114,60.537649912603165,60.591238375091216,60.63783759604668,60.68303896869565,60.72824034134461,60.77344171399357,60.81864308664253,60.863844459291485,60.909045831940446,60.95424720458941,60.999448577238375,61.04464994988734,61.0898513225363,61.13505269518525,61.18025406783422,61.225455440483174,61.27065681313215,61.31585818578111,61.36105955843007,61.40626093107903,61.45146230372799,61.496663676376954,61.54186504902591,61.587066421674876,61.63226779432384,61.6774691669728,61.72267053962176,61.76787191227072,61.81307328491968,61.85827465756864,61.903476030217604,61.948677402866565,61.993878775515526,62.03908014816449,62.08428152081345,62.12948289346241,62.17468426611137,62.21988563876033,62.2650870114093,62.31028838405825,62.355489756707215,62.400691129356176,62.44589250200514,62.49109387465411,62.53629524730307,62.58149661995203,62.62669799260099,62.67189936524995,62.71710073789891,62.76230211054788,62.80750348319684,62.8527048558458,62.89790622849476,62.943107601143716,62.988308973792684,63.033510346441645,63.078711719090606,63.12391309173957,63.16911446438853,63.214315837037496,63.25951720968645,63.30471858233541,63.34991995498437,63.39512132763333,63.4403227002823,63.48552407293126,63.530725445580224,63.57588051771736,63.62080408849112,63.665727659264874,63.71065123003863,63.75557480081239,63.800498371586144,63.845421942359906,63.89034551313366,63.935269083907414,63.98019265468118,64.02511622545494,64.0700397962287,64.11496336700245,64.1598869377762,64.20481050854997,64.24973407932373,64.29465765009749,64.33958122087125,64.3820384244683,64.423262444477,64.4644864644857,64.50571048449441,64.54693450450313,64.58815852451184,64.62938254452054,64.67060656452925,64.71183058453795,64.75305460454666,64.79427862455537,64.83550264456407,64.87672666457279,64.91795068458148,64.9591747045902,65.0003987245989,65.04162274460761,65.0828467646163,65.12407078462502,65.16529480463372,65.20651882464243,65.24774284465113,65.28925056488379,65.33140306113816,65.37355555739252,65.4157080536469,65.45786054990126,65.5000130461556,65.54216554240998,65.58431803866434,65.6264705349187,65.66862303117307,65.71077552742743,65.75292802368179,65.79508051993615,65.83723301619051,65.87938551244487,65.92153800869923,65.96369050495359,66.00584300120795,66.04799549746232,66.09014799371668,66.13230048997104,66.1744529862254,66.21660548247976,66.25875797873412,66.30091047498848,66.34306297124286,66.3852154674972,66.42736796375158,66.46952046000592,66.5116729562603,66.55382545251467,66.59597794876902,66.63813044502339,66.68028294127775,66.72243543753211,66.76458793378649,66.80674043004083,66.8488929262952,66.89104542254957,66.93319791880391,66.97535041505829,67.01750291131265,67.059655407567,67.10180790382137,67.14396040007573,67.18611289633009,67.22826539258446,67.27041788883882,67.31257038509318,67.35472288134756,67.3968753776019,67.43902787385628,67.48118037011064,67.523332866365,67.56548536261936,67.60763785887372,67.64979035512808,67.69194285138244,67.73409534763681,67.77624784389116,67.81840034014553,67.62711677190524,67.2023971391703,66.77767750643541,66.35295787370052,65.92823824096558,65.50351860823068,65.07879897549579,64.65407934276085,64.22935971002592,63.804640077291054,63.37992044455612,62.955200811821186,62.53048117908628,62.105761546351395,61.681041913616454,61.25632228088156,60.831602648146664,60.406883015411736,59.98216338267684,59.55744374994194,59.132724117207,58.70800448447206,58.28328485173721,57.85856521900227,57.43384558626734,57.00912595353244,56.584406320797555,56.15968668806261,55.734967055327715,55.31024742259282,54.88552778985788,54.460808157122955,54.03608852438809,53.61136889165316,53.18664925891822,52.761929626183324,52.337209993448425,51.9124903607135,51.4877707279786,51.0630510952437,50.63833146250876,50.21361182977387,49.81263033319195,49.41202865470472,49.01142697621749,48.61082529773036,48.21022361924314,47.80962194075591,47.409020262268726,47.00841858378155,46.60781690529432,46.207215226807136,45.80661354831995,45.40601186983273,45.00541019134552,44.604808512858355,44.204206834371135,43.803605155883915,43.40300347739674,43.002401798909546,42.601800120422325,42.20119844193514,41.800596763447956,41.399995084960736,40.99939340647356,40.59879172798637,40.19819004949915,39.797588371011926,39.396986692524784,38.99638501403756,38.59578333555034,38.19518165706315,37.79457997857597,37.39397830008875,36.99337662160156,36.592774943114385,36.19217326462716,35.79157158613997,35.39096990765279,34.99036822916556,34.58976655067835,34.18916487219116,33.78856319370398,33.42338562221022,33.12905626470341,32.8347269071966,32.54039754968975,32.24606819218294,31.951738834676128,31.65740947716929,31.36308011966245,31.06875076215566,30.77442140464882,30.480092047141977,30.185762689635162,29.89143333212835,29.597103974621508,29.302774617114697,29.008445259607882,28.71411590210104,28.419786544594224,28.125457187087413,27.83112782958057,27.53679847207373,27.242469114566916,26.948139757060105,26.653810399553265,26.359481042046447,26.065151684539632,25.770822327032793,25.47649296952598,25.182163612019163,24.887834254512327,24.593504897005484,24.299175539498695,24.004846181991855,23.710516824485016,23.4161874669782,23.12185810947139,22.82752875196455,22.533199394457732,22.238870036950917,21.944540679444074,21.65021132193726,21.35588196443045,21.061552606923605,20.767223249416766,20.472893891909955,20.178564534403137,19.884235176896297,19.589905819389482,19.295576461882668,19.001247104375828,18.706917746869017,18.412588389362202,18.12308081743746,17.83892704240588,17.554773267374358,17.27061949234278,16.9864657173112,16.70231194227965,16.418158167248098,16.13400439221652,15.849850617184972,15.565696842153418,15.281543067121843,14.99738929209029,14.713235517058738,14.429081742027162,14.144927966995585,13.86077419196406,13.57662041693248,13.292466641900905,13.008312866869353,12.724159091837802,12.440005316806225,12.155851541774673,11.871697766743122,11.587543991711545,11.303390216679967,11.019236441648442,10.735082666616865,10.450928891585287,10.166775116553735,9.882621341522183,9.598467566490607,9.349345098267417,9.275379164085859,9.201413229904297,9.127447295722735,9.05348136154119,8.97951542735963,8.905549493178068,8.831583558996522,8.757617624814962,8.6836516906334,8.609685756451855,8.535719822270295,8.461753888088733,8.387787953907173,8.313822019725626,8.239856085544066,8.165890151362504,8.091924217180958,8.017958282999398,7.943992348817837,7.870026414636291,7.796060480454729,7.722094546273169,7.648128612091623,7.574162677910063,7.500196743728502,7.426230809546942,7.352264875365394,7.2782989411838335,7.2043330070022735,7.130367072820727,7.056401138639167,6.982435204457607,6.9084692702760595,6.834503336094499,6.760537401912938,6.686571467731378,6.61260553354983,6.53863959936827,6.4646736651867105,6.390707731005164,6.316741796823603,6.263511128690184,6.223664758892442,6.183818389094694,6.143972019296946,6.1041256494992036,6.064279279701456,6.024432909903707,5.984586540105958,5.944740170308218,5.904893800510468,5.865047430712719,5.825201060914979,5.785354691117229,5.74550832131948,5.705661951521741,5.665815581723992,5.625969211926242,5.5861228421284945,5.546276472330753,5.506430102533004,5.4665837327352556,5.426737362937514,5.386890993139765,5.347044623342017,5.307198253544275,5.267351883746528,5.227505513948778,5.187659144151037,5.147812774353289,5.1079664045555395,5.068120034757792,5.02827366496005,4.988427295162301,4.948580925364553,4.908734555566812,4.8688881857690625,4.829041815971315,4.789195446173572,4.749349076375824,4.709502706578076,4.669656336780327,4.629809966982585],[56.381288392384334,56.43553987600883,56.489791359633315,56.54404284325781,56.59829432688231,56.6525458105068,56.706797294131306,56.761048777755796,56.81530026138029,56.869551745004784,56.92380322862928,56.978054712253766,57.03230619587826,57.08655767950277,57.14080916312726,57.195060646751756,57.24931213037624,57.303563614000744,57.357815097625235,57.41206658124973,57.46631806487422,57.52056954849872,57.57482103212321,57.62907251574771,57.683323999372206,57.737575482996704,57.791826966621194,57.84607845024569,57.90032993387018,57.95458141749468,58.00883290111918,58.06308438474367,58.117335868368166,58.17158735199266,58.225838835617154,58.27942729869025,58.3330157611783,58.386604223666346,58.440192686154404,58.49378114864245,58.5473696111305,58.60095807361854,58.65454653610661,58.708134998594645,58.761723461082696,58.81531192357075,58.8689003860588,58.922488848546855,58.9760773110349,59.02966577352294,59.08325423601101,59.136842698499045,59.1904311609871,59.244019623475154,59.29760808596319,59.351196548451256,59.40478501093929,59.45837347342735,59.511961935915394,59.565550398403445,59.619138860891496,59.67272732337955,59.726315785867605,59.77990424835565,59.83349271084369,59.88708117333176,59.9406696358198,59.994258098307846,60.047846560795904,60.10143502328395,60.155023485772006,60.20861194826005,60.2622004107481,60.315788873236144,60.369377335724195,60.422965798212246,60.4765542607003,60.53014272318835,60.58373118567639,60.63731964816444,60.690908110652494,60.74449657314055,60.7980850356286,60.851673498116654,60.898272719072125,60.943474091721086,60.98867546437005,61.03387683701901,61.079078209667976,61.12427958231693,61.169480954965884,61.21468232761485,61.25988370026381,61.305085072912775,61.35028644556174,61.3954878182107,61.440689190859665,61.48589056350862,61.531091936157594,61.576293308806555,61.6214946814555,61.66669605410447,61.71189742675343,61.75709879940239,61.80230017205135,61.84750154470032,61.89270291734927,61.93790428999823,61.983105662647205,62.02830703529616,62.07350840794512,62.11870978059409,62.16391115324305,62.20911252589201,62.25431389854097,62.29951527118993,62.344716643838886,62.38991801648785,62.435119389136815,62.48032076178577,62.525522134434745,62.5707235070837,62.61592487973265,62.66112625238162,62.70632762503058,62.75152899767955,62.79673037032851,62.84193174297747,62.887133115626426,62.932334488275394,62.97753586092435,63.02273723357331,63.06793860622227,63.11295477737597,63.15787834814973,63.20280191892348,63.247725489697245,63.292649060471,63.33757263124476,63.38249620201852,63.42741977279228,63.47234334356603,63.517266914339785,63.562190485113554,63.60711405588731,63.65203762666107,63.696961197434824,63.74188476820859,63.78680833898235,63.8317319097561,63.87665548052986,63.92157905130362,63.96650262207737,64.01142619285113,64.0563497636249,64.10127333439864,64.1461969051724,64.19112047594616,64.23604404671993,64.28096761749369,64.32589118826743,64.3708147590412,64.41573832981496,64.46066190058872,64.50558547136248,64.55050904213624,64.59543261290999,64.63788981650706,64.67911383651575,64.72033785652447,64.76156187653316,64.80278589654186,64.84400991655058,64.88523393655929,64.926457956568,64.9676819765767,65.0089059965854,65.05013001659411,65.09135403660281,65.13257805661152,65.17380207662023,65.21502609662895,65.25625011663764,65.29747413664634,65.33869815665506,65.37992217666377,65.42114619667247,65.46237021668117,65.50359423668989,65.54481825669858,65.58604227670729,65.627266296716,65.66849031672471,65.70971433673341,65.75093835674213,65.79216237675084,65.83338639675954,65.87461041676823,65.91583443677695,65.95705845678565,65.99828247679436,66.03950649680306,66.08073051681177,66.12195453682048,66.16317855682918,66.20440257683788,66.2456265968466,66.2868506168553,66.328074636864,66.36929865687272,66.41072900388916,66.45288150014352,66.49503399639788,66.53718649265224,66.57933898890661,66.62149148516096,66.66364398141533,66.70579647766968,66.74794897392404,66.79010147017841,66.83225396643277,66.87440646268715,66.91655895894151,66.95871145519585,67.00086395145023,67.04301644770459,67.08516894395896,67.12732144021331,67.16947393646768,67.21162643272203,67.25377892897639,67.29593142523076,67.33808392148512,67.3802364177395,67.42238891399386,67.46454141024822,67.50669390650256,67.54884640275694,67.59099889901131,67.63315139526566,67.67530389152003,67.71745638777438,67.75960888402875,67.80176138028311,67.84391387653747,67.88606637279183,67.92821886904619,67.97037136530055,68.01252386155491,68.05467635780929,67.86339278956899,67.43867315683406,67.01395352409915,66.58923389136426,66.16451425862932,65.73979462589443,65.31507499315954,64.89035536042459,64.46563572768966,64.04091609495481,63.61619646221987,63.19147682948494,62.76675719675005,62.34203756401515,61.91731793128021,61.49259829854532,61.06787866581042,60.643159033075484,60.218439400340586,59.79371976760568,59.36900013487076,58.94428050213581,58.519560869400955,58.09484123666603,57.67012160393109,57.24540197119619,56.820682338461296,56.39596270572636,55.97124307299147,55.54652344025657,55.12180380752163,54.697084174786696,54.27236454205185,53.8476449093169,53.42292527658198,52.99820564384707,52.57348601111218,52.148766378377246,51.724046745642354,51.29932711290746,50.874607480172514,50.449887847437616,50.025168214702724,49.60044858196779,49.175728949232855,48.75100931649799,48.326289683763065,47.90157005102812,47.47685041829323,47.05213078555833,46.6274111528234,46.2026915200885,45.77797188735361,45.353252254618674,44.92853262188373,44.50381298914888,44.07909335641394,43.65437372367901,43.229654090944116,42.80493445820921,42.38021482547428,41.955495192739384,41.530775560004486,41.10605592726955,40.68133629453465,40.25661666179976,39.83189702906482,39.4071773963299,38.982457763595036,38.5577381308601,38.13301849812517,37.71076757803611,37.31016589954892,36.90956422106171,36.508962542574515,36.10836086408734,35.70775918560012,35.30715750711293,34.90655582862575,34.50595415013852,34.10535247165131,33.704750793164116,33.30414911467694,32.93897154318318,32.64464218567637,32.35031282816955,32.05598347066271,31.761654113155895,31.467324755649084,31.172995398142245,30.8786660406354,30.584336683128615,30.290007325621772,29.995677968114933,29.70134861060812,29.407019253101307,29.112689895594464,28.818360538087653,28.53094795016055,28.24679417512897,27.962640400097417,27.678486625065865,27.394332850034292,27.110179075002712,26.826025299971164,26.54187152493961,26.25771774990803,25.97356397487648,25.68941019984493,25.405256424813352,25.121102649781804,24.83694887475025,24.552795099718676,24.268641324687096,23.984487549655572,23.700333774623992,23.416179999592412,23.13202622456086,22.847872449529312,22.563718674497736,22.279564899466184,21.995411124434636,21.711257349403056,21.427103574371504,21.142949799339952,20.858796024308372,20.5746422492768,20.290488474245247,20.006334699213696,19.722180924182116,19.438027149150564,19.153873374119016,18.869719599087436,18.585565824055884,18.301412049024332,18.01725827399276,17.73310449896118,17.448950723929656,17.16479694889808,16.8806431738665,16.596489398834947,16.312335623803396,16.02818184877182,15.74402807374027,15.459874298708717,15.175720523677143,14.891566748645587,14.607412973614036,14.323259198582459,14.039105423550883,13.754951648519356,13.47079787348778,13.186644098456203,12.90249032342465,12.618336548393101,12.334182773361523,12.05002899832997,11.76587522329842,11.481721448266843,11.197567673235264,10.91341389820374,10.629260123172163,10.345106348140584,10.060952573109034,9.776798798077483,9.492645023045904,9.243522554822716,9.169556620641156,9.095590686459595,9.021624752278033,8.947658818096487,8.873692883914927,8.799726949733367,8.72576101555182,8.65179508137026,8.577829147188698,8.503863213007152,8.429897278825592,8.35593134464403,8.28196541046247,8.207999476280923,8.134033542099363,8.060067607917803,7.986101673736256,7.912135739554696,7.838169805373135,7.764203871191588,7.697751140074761,7.643165024006855,7.58857890793896,7.533992791871054,7.479406675803148,7.424820559735242,7.370234443667346,7.31564832759944,7.261062211531533,7.206476095463637,7.151889979395731,7.097303863327826,7.04271774725993,6.988131631192024,6.933545515124118,6.878959399056212,6.824373282988316,6.769787166920409,6.715201050852503,6.660614934784608,6.606028818716702,6.551442702648796,6.4968565865809,6.4422704705129945,6.3876843544450885,6.333098238377192,6.278512122309286,6.223926006241381,6.169339890173474,6.114753774105579,6.060167658037673,6.005581541969766,5.950995425901871,5.896409309833965,5.841823193766059,5.787237077698164,5.732650961630258,5.678064845562351,5.623478729494445,5.568892613426549,5.514306497358643,5.459720381290737,5.4166163042816144,5.376769934483866,5.336923564686117,5.2970771948883755,5.257230825090628,5.217384455292878,5.177538085495137,5.137691715697389,5.09784534589964,5.057998976101892,5.018152606304151,4.978306236506402,4.938459866708653,4.898613496910912,4.858767127113163,4.818920757315414,4.7790743875176736,4.739228017719925,4.699381647922176,4.659535278124427,4.619688908326686],[56.63078366654902,56.68503515017352,56.739286633798,56.7935381174225,56.847789601047,56.902041084671495,56.95629256829599,57.01054405192048,57.06479553554498,57.11904701916947,57.17329850279397,57.22754998641846,57.28180147004296,57.336052953667455,57.390304437291945,57.44455592091644,57.49880740454094,57.55305888816544,57.607310371789936,57.66156185541442,57.71581333903892,57.770064822663414,57.82431630628791,57.87856778991241,57.93281927353689,57.98707075716139,58.04132224078589,58.095573724410386,58.14982520803488,58.20407669165937,58.258328175283864,58.31257965890836,58.36683114253285,58.42108262615735,58.47533410978185,58.52958559340634,58.58383707703083,58.638088560655326,58.692340044279824,58.74659152790432,58.80084301152882,58.85509449515331,58.9093459787778,58.9635974624023,59.017848946026795,59.072100429651286,59.12635191327578,59.180603396900274,59.234854880524765,59.28910636414926,59.34335784777376,59.397277821524476,59.45086628401253,59.50445474650057,59.55804320898862,59.61163167147667,59.66522013396472,59.718808596452774,59.772397058940825,59.825985521428876,59.87957398391693,59.93316244640498,59.98675090889303,60.04033937138107,60.09392783386912,60.14751629635717,60.201104758845226,60.25469322133327,60.30828168382132,60.36187014630937,60.41545860879742,60.46904707128547,60.52263553377352,60.576223996261575,60.62981245874962,60.68340092123768,60.73698938372572,60.79057784621377,60.84416630870182,60.897754771189874,60.951343233677925,61.004931696165976,61.05852015865402,61.11210862114208,61.15870784209755,61.20390921474651,61.249110587395464,61.294311960044425,61.339513332693386,61.38471470534235,61.429916077991315,61.475117450640276,61.52031882328924,61.5655201959382,61.61072156858717,61.65592294123611,61.70112431388509,61.74632568653405,61.79152705918301,61.83672843183197,61.88192980448093,61.927131177129894,61.97233254977886,62.01753392242782,62.06273529507677,62.10793666772574,62.1531380403747,62.19833941302366,62.24354078567263,62.28874215832159,62.333943530970544,62.37914490361951,62.424346276268466,62.46954764891743,62.51474902156639,62.559950394215356,62.60510546626081,62.65002903703458,62.69495260780833,62.739876178582094,62.78479974935585,62.8297233201296,62.87464689090337,62.919570461677125,62.96449403245089,63.00941760322464,63.054341173998395,63.099264744772164,63.14418831554591,63.18911188631968,63.234035457093434,63.27895902786719,63.32388259864096,63.368806169414704,63.413729740188465,63.45865331096222,63.50357688173598,63.54850045250974,63.593424023283504,63.63834759405726,63.68327116483101,63.728194735604774,63.77311830637853,63.81804187715228,63.86296544792605,63.9078890186998,63.95281258947357,63.99773616024732,64.04265973102108,64.08758330179484,64.1325068725686,64.17743044334236,64.2223540141161,64.26727758488987,64.31220115566363,64.35712472643738,64.40204829721114,64.4469718679849,64.49189543875866,64.53681900953242,64.58174258030617,64.62666615107993,64.67158972185369,64.71651329262745,64.7614368634012,64.80636043417496,64.85128400494872,64.89374120854579,64.93496522855449,64.97618924856319,65.0174132685719,65.05863728858061,65.09986130858931,65.14108532859802,65.18230934860674,65.22353336861543,65.26475738862413,65.30598140863285,65.34720542864156,65.38842944865027,65.42965346865896,65.47087748866767,65.51210150867638,65.5533255286851,65.59454954869379,65.63577356870249,65.6769975887112,65.71822160871992,65.75944562872861,65.80066964873733,65.84189366874602,65.88311768875474,65.92434170876345,65.96556572877215,66.00678974878086,66.04801376878956,66.08923778879827,66.13046180880698,66.17168582881568,66.21290984882438,66.2541338688331,66.2953578888418,66.3365819088505,66.37780592885922,66.41902994886792,66.46025396887663,66.50147798888534,66.54270200889404,66.58392602890274,66.62515004891145,66.66637406892015,66.70759808892886,66.74882210893757,66.79004612894627,66.83127014895499,66.8724941689637,66.9137181889724,66.95494220898111,66.99616622898981,67.03739024899852,67.07861426900723,67.11983828901592,67.16106230902464,67.20228632903334,67.24351034904205,67.28473436905075,67.32595838905947,67.36718240906816,67.40840642907688,67.44963044908557,67.49085446909429,67.5322074428945,67.57435993914886,67.61651243540322,67.6586649316576,67.70081742791196,67.74296992416632,67.78512242042068,67.82727491667504,67.8694274129294,67.91157990918376,67.95373240543813,67.99588490169249,68.03803739794685,68.0801898942012,68.12234239045557,68.16449488670993,68.20664738296429,68.24879987921867,68.29095237547303,68.09966880723273,67.6749491744978,67.2502295417629,66.825509909028,66.40079027629307,65.97607064355817,65.55135101082328,65.12663137808835,64.70191174535341,64.27719211261855,63.85247247988361,63.42775284714868,63.003033214413776,62.578313581678884,62.15359394894395,61.72887431620906,61.30415468347417,60.87943505073922,60.45471541800433,60.02999578526942,59.6052761525345,59.18055651979956,58.7558368870647,58.33111725432977,57.906397621594834,57.48167798885994,57.05695835612504,56.63223872339011,56.207519090655204,55.78279945792031,55.358079825185385,54.93336019245045,54.50864055971559,54.083920926980646,53.65920129424572,53.23448166151081,52.80976202877592,52.38504239604099,51.960322763306095,51.53560313057119,51.110883497836255,50.68616386510136,50.261444232366465,49.83672459963152,49.41200496689659,48.98728533416174,48.562565701426806,48.13784606869187,47.713126435956966,47.28636337103998,46.84901200090443,46.41166063076893,45.97430926063342,45.536957890497874,45.09960652036233,44.662255150226855,44.22490378009131,43.78755240995577,43.35020103982026,42.91284966968476,42.47549829954921,42.038146929413706,41.6007955592782,41.16344418914265,40.72609281900715,40.28874144887163,39.85139007873609,39.41403870860055,38.976687338465084,38.53933596832953,38.10198459819399,37.664633228058484,37.227281857922975,36.78993048778743,36.35257911765193,35.91522774751642,35.477876377380866,35.04052500724537,34.60317363710986,34.16582226697432,33.72847089683877,33.29111952670326,32.85376815656775,32.4683750702482,32.186898551560624,31.905422032873044,31.623945514185433,31.34246899549785,31.060992476810267,30.77951595812266,30.498039439435054,30.216562920747496,29.93508640205989,29.653609883372283,29.3721333646847,29.09065684599712,28.809180327309512,28.52770380862193,28.246227289934346,27.96475077124674,27.68327425255916,27.401797733871575,27.12032121518397,26.838844696496363,26.55736817780878,26.2758916591212,25.99441514043359,25.712938621746012,25.43146210305843,25.149985584370818,24.868509065683238,24.587032546995655,24.305556028308047,24.02407950962044,23.742602990932888,23.461126472245276,23.179649953557664,22.898173434870085,22.6166969161825,22.3352203974949,22.053743878807314,21.77226736011973,21.490790841432123,21.209314322744543,20.92783780405696,20.646361285369355,20.364884766681747,20.083408247994164,19.80193172930658,19.520455210618973,19.238978691931393,18.95750217324381,18.6760256545562,18.394549135868623,18.11307261718104,17.831596098493435,17.550119579805823,17.26864306111827,16.98716654243066,16.705690023743053,16.424213505055473,16.14273698636789,15.861260467680282,15.579783948992699,15.298307430305117,15.016830911617511,14.73535439292993,14.453877874242348,14.17240135555474,13.89092483686713,13.609448318179576,13.327971799491968,13.046495280804361,12.76501876211678,12.483542243429195,12.202065724741589,11.920589206054006,11.639112687366426,11.357636168678818,11.07615964999121,10.794683131303653,10.513206612616044,10.231730093928435,9.950253575240854,9.668777056553273,9.386822479601207,9.13794579524964,9.083359679181733,9.028773563113829,8.974187447045924,8.919601330978027,8.865015214910121,8.810429098842215,8.755842982774318,8.701256866706414,8.646670750638506,8.592084634570611,8.537498518502705,8.482912402434799,8.428326286366893,8.373740170298998,8.319154054231092,8.264567938163186,8.20998182209529,8.155395706027383,8.100809589959477,8.046223473891581,7.991637357823676,7.9370512417557695,7.882465125687874,7.827879009619968,7.773292893552062,7.718706777484155,7.66412066141626,7.609534545348355,7.554948429280449,7.500362313212553,7.445776197144647,7.391190081076741,7.336603965008845,7.282017848940939,7.227431732873033,7.172845616805127,7.11825950073723,7.0636733846693245,7.009087268601419,6.954501152533524,6.899915036465616,6.84532892039771,6.790742804329815,6.736156688261908,6.681570572194002,6.626984456126107,6.572398340058201,6.517812223990296,6.46322610792239,6.408639991854494,6.354053875786587,6.299467759718682,6.2448816436507855,6.190295527582879,6.135709411514973,6.081123295447077,6.026537179379171,5.971951063311265,5.91736494724336,5.862778831175464,5.808192715107558,5.753606599039652,5.699020482971755,5.644434366903849,5.589848250835944,5.535262134768049,5.480676018700143,5.426089902632237,5.3715037865643405,5.3169176704964345,5.2623315544285285,5.207745438360622,5.153159322292725,5.09857320622482,5.043987090156914,4.989400974089018,4.934814858021112,4.880228741953207,4.82564262588531,4.771056509817404,4.716470393749498,4.661884277681592,4.609567849670787],[56.88027894071371,56.9345304243382,56.9887819079627,57.04303339158719,57.097284875211685,57.15153635883618,57.20578784246068,57.26003932608517,57.31429080970966,57.36854229333416,57.422793776958656,57.477045260583154,57.53129674420765,57.58554822783214,57.63979971145664,57.69405119508113,57.74830267870563,57.802554162330125,57.856805645954616,57.91105712957911,57.965308613203604,58.0195600968281,58.0738115804526,58.12806306407709,58.18231454770159,58.23656603132608,58.290817514950575,58.34506899857507,58.39932048219956,58.45357196582406,58.50782344944856,58.56207493307304,58.61632641669754,58.67057790032204,58.724829383946535,58.779080867571025,58.83333235119552,58.88758383482002,58.941835318444504,58.996086802069,59.0503382856935,59.104589769318,59.158841252942494,59.21309273656699,59.267344220191475,59.32159570381597,59.37584718744047,59.43009867106497,59.48435015468945,59.53860163831395,59.59285312193845,59.647104605562944,59.70135608918744,59.75560757281194,59.80985905643644,59.86411054006092,59.91836202368541,59.97261350730991,60.02686499093441,60.08111647455891,60.1353679581834,60.189619441807885,60.24387092543238,60.29812240905688,60.35237389268138,60.406625376305875,60.46087685993036,60.515128343554856,60.56871680684675,60.6223052693348,60.67589373182285,60.729482194310904,60.783070656798955,60.836659119287006,60.89024758177506,60.94383604426311,60.99742450675115,61.0510129692392,61.104601431727254,61.158189894215305,61.211778356703356,61.26536681919141,61.31895528167946,61.37254374416751,61.41914296512298,61.46434433777194,61.5095457104209,61.55474708306986,61.599948455718824,61.64514982836778,61.690351201016746,61.73555257366571,61.78075394631467,61.82595531896363,61.8711566916126,61.91635806426155,61.96155943691052,62.00676080955948,62.05196218220844,62.0971635548574,62.14217972591942,62.18710329669318,62.232026867466935,62.276950438240696,62.32187400901445,62.36679757978821,62.411721150561974,62.45664472133573,62.50156829210949,62.546491862883244,62.591415433657005,62.63633900443076,62.681262575204514,62.72618614597828,62.771109716752036,62.8160332875258,62.86095685829955,62.90588042907331,62.95080399984707,62.99572757062083,63.04065114139459,63.085574712168345,63.1304982829421,63.17542185371586,63.220345424489615,63.26526899526337,63.31019256603714,63.35511613681089,63.40003970758465,63.444963278358415,63.48988684913216,63.53481041990593,63.579733990679685,63.62465756145344,63.669581132227194,63.714504703000955,63.759428273774716,63.80435184454848,63.84927541532223,63.89419898609599,63.93912255686975,63.9840461276435,64.02896969841726,64.07389326919102,64.11881683996478,64.16374041073854,64.2086639815123,64.25358755228606,64.29851112305981,64.34343469383359,64.38835826460733,64.43328183538108,64.47820540615484,64.5231289769286,64.56805254770237,64.61297611847613,64.65789968924987,64.70282326002364,64.74774683079738,64.79267040157116,64.8375939723449,64.88251754311867,64.92744111389243,64.97236468466619,65.01728825543995,65.0622118262137,65.10713539698746,65.14959260058451,65.19081662059322,65.23204064060194,65.27326466061064,65.31448868061933,65.35571270062806,65.39693672063676,65.43816074064546,65.47938476065417,65.52060878066287,65.56183280067158,65.60305682068028,65.64428084068899,65.6855048606977,65.72672888070642,65.76795290071512,65.80917692072383,65.85040094073253,65.89162496074124,65.93284898074994,65.97407300075864,66.01529702076735,66.05652104077606,66.09774506078477,66.13896908079347,66.18019310080217,66.22141712081088,66.2626411408196,66.30386516082831,66.34508918083701,66.3863132008457,66.42753722085442,66.46876124086313,66.50998526087183,66.55120928088053,66.59243330088924,66.63365732089795,66.67488134090665,66.71610536091536,66.75732938092408,66.79855340093278,66.83977742094147,66.8810014409502,66.9222254609589,66.9634494809676,67.0046735009763,67.04589752098502,67.08712154099372,67.12834556100242,67.16956958101113,67.21079360101984,67.25201762102854,67.29324164103724,67.33446566104595,67.37568968105467,67.41691370106338,67.45813772107208,67.49936174108079,67.54058576108949,67.5818097810982,67.6230338011069,67.66425782111563,67.70548184112431,67.74670586113302,67.78792988114174,67.82915390115043,67.87037792115913,67.91160194116785,67.95282596117656,67.99404998118526,68.03527400119397,68.07649802120267,68.11772204121138,68.15894606122008,68.2000151546617,68.24072276238016,68.28143037009862,68.32213797781709,68.36284558553554,68.40355319325401,68.44426080097247,68.48496840869093,68.5256760164094,68.32121404801663,67.87158250351264,67.42195095900868,66.97231941450472,66.52268787000075,66.07305632549678,65.62378591454787,65.18643454441232,64.74908317427678,64.31173180414132,63.87438043400577,63.43702906387021,62.99967769373472,62.562326323599216,62.124974953463656,61.68762358332816,61.25027221319266,60.8129208430571,60.3755694729216,59.938218102786095,59.500866732650536,59.063515362515005,58.62616399237953,58.18881262224399,57.75146125210844,57.31410988197293,56.87675851183742,56.43940714170189,56.002055771566376,55.56470440143088,55.12735303129533,54.690001661159776,54.2526502910243,53.815298920888765,53.37794755075322,52.9405961806177,52.5032448104822,52.065893440346656,51.62854207021116,51.19119070007565,50.7538393299401,50.31648795980459,49.87913658966909,49.44178521953354,49.00443384939799,48.56708247926253,48.12973110912698,47.69237973899144,47.25502836885593,46.81767699872043,46.38032562858488,45.942974258449375,45.50562288831387,45.06827151817832,44.630920148042776,44.19356877790731,43.75621740777176,43.31886603763622,42.88151466750071,42.44416329736521,42.00681192722966,41.56946055709415,41.132109186958644,40.6947578168231,40.2574064466876,39.820055076552094,39.38270370641654,38.945352336281,38.50800096614553,38.070649596009986,37.63329822587444,37.19594685573893,36.75859548560342,36.32124411546788,35.88389274533238,35.446541375196865,35.00919000506133,34.57183863492581,34.13448726479031,33.697135894654764,33.25978452451921,32.82243315438371,32.385081784248214,31.999688697928654,31.71821217924107,31.43673566055349,31.155259141865884,30.8737826231783,30.592306104490717,30.310829585803113,30.029353067115505,29.74787654842795,29.466400029740342,29.184923511052734,28.903446992365147,28.62197047367757,28.340493954989963,28.05901743630238,27.7775409176148,27.49606439892719,27.21458788023961,26.93311136155203,26.651634842864418,26.37015832417681,26.088681805489227,25.807205286801647,25.52572876811404,25.24425224942646,24.962775730738876,24.681299212051265,24.39982269336369,24.118346174676105,23.8368696559885,23.55539313730089,23.273916618613335,22.992440099925723,22.71096358123812,22.429487062550535,22.148010543862952,21.866534025175348,21.585057506487765,21.30358098780018,21.022104469112577,20.740627950424994,20.45915143173741,20.177674913049803,19.896198394362195,19.614721875674615,19.33324535698703,19.051768838299424,18.77029231961184,18.48927156525735,18.21834226126134,17.947412957265353,17.676483653269372,17.40555434927336,17.13462504527735,16.863695741281386,16.592766437285377,16.321837133289367,16.050907829293383,15.779978525297395,15.509049221301385,15.2381199173054,14.967190613309416,14.696261309313403,14.425332005317417,14.154402701321434,13.883473397325423,13.612544093329412,13.341614789333452,13.070685485337442,12.79975618134143,12.528826877345445,12.25789757334946,11.986968269353449,11.71603896535746,11.44510966136148,11.174180357365465,10.903251053369457,10.632321749373496,10.361392445377486,10.090463141381473,9.81953383738549,9.5486045333895,9.277675229393493,9.040299879183683,8.970694297904586,8.901088716625491,8.831483135346394,8.761877554067311,8.692271972788216,8.622666391509119,8.553060810230036,8.483455228950941,8.413849647671844,8.344244066392761,8.274638485113666,8.205032903834569,8.135427322555472,8.065821741276391,7.996216159997294,7.926610578718197,7.857004997439113,7.787399416160017,7.717793834880921,7.648188253601838,7.578582672322742,7.508977091043646,7.4393715097645625,7.369765928485467,7.300160347206372,7.230554765927275,7.1609491846481905,7.091343603369095,7.021738022089998,6.952132440810916,6.882526859531819,6.812921278252724,6.7433156969736405,6.673710115694544,6.604104534415449,6.534498953136353,6.473443965078263,6.421879227007028,6.3703144889357946,6.318749750864569,6.267185012793335,6.2156202747221005,6.164055536650876,6.112490798579641,6.060926060508407,6.009361322437182,5.9672025359908245,5.929216298516167,5.891230061041511,5.853243823566861,5.815257586092204,5.777271348617547,5.739285111142896,5.7012988736682395,5.663312636193583,5.625326398718933,5.587340161244275,5.549353923769618,5.511367686294961,5.473381448820311,5.4353952113456545,5.397408973870998,5.359422736396347,5.32143649892169,5.283450261447033,5.245464023972383,5.2074777864977255,5.169491549023068,5.131505311548418,5.093519074073761,5.055532836599104,5.017546599124447,4.979560361649797,4.9415741241751405,4.903587886700484,4.865601649225833,4.827615411751176,4.789629174276519,4.751642936801869,4.713656699327212,4.675670461852555,4.637684224377898,4.599697986903248],[57.12952550410629,57.18377698773078,57.23802847135528,57.292279954979776,57.34653143860426,57.40078292222876,57.455034405853254,57.50928588947775,57.56353737310224,57.61778885672674,57.67204034035124,57.72629182397573,57.780543307600226,57.834794791224724,57.889046274849214,57.94329775847371,57.9975492420982,58.0518007257227,58.1060522093472,58.160303692971695,58.21455517659618,58.268806660220676,58.32305814384518,58.37730962746967,58.43156111109417,58.48581259471865,58.54006407834316,58.594315561967655,58.648567045592145,58.702818529216636,58.75707001284113,58.81132149646563,58.86557298009012,58.91982446371462,58.97407594733912,59.02832743096361,59.0825789145881,59.1368303982126,59.19108188183709,59.24533336546158,59.29958484908608,59.35383633271057,59.40808781633507,59.46233929995957,59.51659078358406,59.570842267208555,59.62509375083305,59.67934523445754,59.73359671808203,59.78784820170653,59.84209968533103,59.89635116895552,59.95060265258002,60.004854136204514,60.05910561982901,60.113357103453495,60.16760858707799,60.22186007070249,60.27611155432699,60.330363037951486,60.384614521575976,60.43886600520047,60.493117488824964,60.54736897244946,60.60162045607395,60.65587193969845,60.71012342332294,60.76437490694744,60.818626390571936,60.872877874196426,60.927129357820924,60.981380841445414,61.03563232506991,61.08988380869441,61.14413529231891,61.1983867759434,61.25263825956789,61.306889743192386,61.36114122681688,61.41539271044138,61.46964419406588,61.52389567769037,61.57814716131487,61.63246679851004,61.67886759363147,61.723791164405235,61.76871473517899,61.81363830595275,61.858561876726505,61.903485447500266,61.94840901827403,61.99333258904778,62.03825615982154,62.0831797305953,62.12810330136906,62.17302687214281,62.21795044291657,62.262874013690336,62.30779758446409,62.35272115523785,62.397644726011606,62.44256829678536,62.48749186755912,62.53241543833288,62.57733900910663,62.6222625798804,62.66718615065415,62.712109721427915,62.757033292201676,62.80195686297543,62.846880433749185,62.891804004522946,62.9367275752967,62.98165114607047,63.02657471684422,63.07149828761798,63.11642185839174,63.16134542916549,63.20626899993925,63.251192570713016,63.29611614148677,63.34103971226053,63.385963283034286,63.43088685380804,63.4758104245818,63.52073399535556,63.565657566129325,63.61058113690308,63.65550470767683,63.700428278450595,63.745351849224356,63.79027541999812,63.83519899077187,63.880122561545626,63.92504613231939,63.969969703093135,64.0148932738669,64.05981684464065,64.10474041541441,64.14966398618817,64.19458755696193,64.23951112773568,64.28443469850944,64.3293582692832,64.37428184005697,64.41920541083073,64.46412898160447,64.50905255237824,64.553976123152,64.59889969392574,64.6438232646995,64.68874683547327,64.73367040624703,64.77859397702078,64.82351754779454,64.8684411185683,64.91336468934206,64.95828826011582,65.00321183088957,65.04813540166333,65.09305897243709,65.13798254321085,65.18290611398461,65.22782968475836,65.27275325553212,65.31767682630588,65.36260039707963,65.40430788231272,65.4450154900312,65.48572309774966,65.52643070546813,65.56713831318658,65.60784592090505,65.64855352862351,65.68926113634197,65.72996874406044,65.7706763517789,65.81138395949736,65.85209156721582,65.8927991749343,65.93350678265276,65.97421439037122,66.01492199808969,66.05562960580814,66.09633721352661,66.13704482124507,66.17775242896353,66.218460036682,66.25916764440045,66.29987525211892,66.34058285983738,66.38129046755584,66.42199807527432,66.46270568299278,66.50341329071124,66.5441208984297,66.58482850614817,66.62553611386663,66.66624372158509,66.70695132930356,66.74765893702201,66.78836654474048,66.82907415245894,66.8697817601774,66.91048936789588,66.95119697561434,66.9919045833328,67.03261219105126,67.07331979876972,67.11402740648819,67.15473501420665,67.19544262192512,67.23615022964357,67.27685783736203,67.3175654450805,67.35827305279896,67.39898066051742,67.4396882682359,67.48039587595434,67.52110348367282,67.56181109139128,67.60251869910975,67.64322630682821,67.68393391454667,67.72464152226513,67.76534912998359,67.80605673770206,67.84676434542052,67.88747195313898,67.92817956085746,67.9688871685759,68.00959477629438,68.05030238401284,68.09100999173131,68.13171759944976,68.17242520716823,68.2131328148867,68.25384042260515,68.29454803032363,68.33525563804209,68.37596324576054,68.41667085347902,68.45737846119746,68.49808606891594,68.5387936766344,68.57950128435286,68.62020889207133,68.66091649978979,68.70162410750825,68.74233171522671,68.53786974683396,68.08823820232996,67.638606657826,67.18897511332206,66.73934356881806,66.28971202431411,65.84008047981015,65.39044893530617,64.94081739080217,64.49118584629827,64.04155430179426,63.59192275729028,63.14229121278632,62.692659668282374,62.24302812377837,61.79339657927443,61.34376503477048,60.89413349026648,60.44450194576253,59.99487040125858,59.54523885675459,59.09560731225059,58.64597576774669,58.19634422324269,57.7467126787387,57.29708113423475,56.84744958973079,56.397818045226806,55.94818650072285,55.4985549562189,55.04892341171491,54.59929186721091,54.149660322707,53.70002877820302,53.25039723369901,52.80076568919507,52.351134144691116,51.90150260018712,51.45187105568318,51.00223951117922,50.55260796667523,50.10297642217127,49.65334487766733,49.203713333163336,48.75408178865935,48.30445024415543,47.85481869965144,47.405187155147445,46.955555610643486,46.50592406613955,46.05629252163555,45.606660977131604,45.157029432627645,44.70739788812365,44.25776634361966,43.80813479911575,43.35850325461176,42.90887171010777,42.459240165603816,42.00960862109986,41.55997707659588,41.11034553209191,40.66342281463909,40.226071444503546,39.788720074368044,39.35136870423254,38.914017334097,38.47666596396145,38.039314593825985,37.60196322369043,37.16461185355489,36.727260483419386,36.289909113283876,35.852557743148324,35.41520637301282,34.97785500287732,34.540503632741775,34.103152262606265,33.66580089247076,33.22844952233522,32.791098152199666,32.35374678206416,31.916395411928654,31.531002325609105,31.249525806921525,30.96804928823394,30.68657276954633,30.40509625085875,30.12361973217117,29.842143213483563,29.560666694795955,29.2791901761084,28.99771365742079,28.716237138733185,28.4347606200456,28.15328410135802,27.873728234844407,27.602798930848422,27.331869626852438,27.060940322856425,26.790011018860444,26.519081714864456,26.24815241086845,25.977223106872437,25.70629380287645,25.435364498880464,25.164435194884454,24.893505890888466,24.622576586892485,24.351647282896472,24.080717978900488,23.8097886749045,23.538859370908494,23.267930066912484,22.997000762916517,22.726071458920508,22.4551421549245,22.18421285092851,21.913283546932526,21.642354242936516,21.371424938940535,21.100495634944544,20.829566330948534,20.558637026952546,20.287707722956565,20.016778418960552,19.745849114964543,19.474919810968558,19.203990506972573,18.93306120297656,18.662131898980576,18.39120259498459,18.12027329098858,17.849343986992594,17.57841468299661,17.307485379000596,17.036556075004587,16.765626771008627,16.494697467012614,16.223768163016604,15.95283885902062,15.681909555024633,15.41098025102862,15.140050947032638,14.869121643036653,14.598192339040642,14.327263035044654,14.056333731048671,13.785404427052658,13.51447512305665,13.243545819060689,12.97261651506468,12.701687211068666,12.430757907072683,12.159828603076697,11.888899299080688,11.6179699950847,11.347040691088713,11.076111387092704,10.805182083096696,10.534252779100735,10.263323475104722,9.99239417110871,9.72146486711273,9.45053556311674,9.179606259120728,8.94223090891092,8.872625327631825,8.803019746352728,8.733414165073633,8.663808583794548,8.594203002515455,8.524597421236358,8.454991839957275,8.385386258678178,8.315780677399083,8.246175096119998,8.176569514840903,8.106963933561808,8.03735835228271,7.967752771003628,7.898147189724531,7.828541608445435,7.763258323390302,7.711693585319068,7.660128847247834,7.60856410917661,7.556999371105375,7.50543463303414,7.453869894962916,7.402305156891681,7.350740418820447,7.2991756807492125,7.247610942677987,7.196046204606754,7.144481466535519,7.092916728464294,7.041351990393061,6.989787252321825,6.938222514250601,6.886657776179367,6.835093038108132,6.783528300036898,6.7319635619656735,6.680398823894439,6.628834085823204,6.5772693477519795,6.525704609680746,6.474139871609511,6.422575133538286,6.371010395467052,6.319445657395817,6.267880919324592,6.216316181253358,6.164751443182124,6.1131867051108895,6.061621967039664,6.01005722896843,5.958492490897196,5.906927752825971,5.855363014754737,5.803798276683503,5.752233538612278,5.7006688005410435,5.649104062469809,5.597539324398575,5.54597458632735,5.494409848256116,5.442845110184882,5.391280372113657,5.339715634042423,5.288150895971189,5.236586157899963,5.197609813240575,5.1596235757659175,5.121637338291268,5.08365110081661,5.045664863341953,5.007678625867297,4.969692388392646,4.931706150917989,4.8937199134433325,4.855733675968683,4.817747438494025,4.779761201019368,4.741774963544718,4.703788726070062,4.6658024885954035,4.627816251120747,4.589830013646097],[57.36670964580023,57.420961129424725,57.47521261304922,57.52946409667372,57.583715580298204,57.6379670639227,57.6922185475472,57.7464700311717,57.80072151479619,57.854972998420685,57.90922448204518,57.96347596566967,58.01772744929417,58.07197893291867,58.12623041654316,58.180481900167656,58.23473338379215,58.288984867416644,58.34323635104114,58.39748783466564,58.45173931829013,58.50599080191462,58.56024228553912,58.614493769163616,58.6687452527881,58.7229967364126,58.777248220037094,58.83149970366159,58.88575118728609,58.94000267091058,58.99425415453508,59.04850563815957,59.102757121784066,59.15700860540856,59.21126008903306,59.265511572657545,59.31976305628204,59.37401453990654,59.42826602353104,59.482517507155535,59.53676899078002,59.591020474404516,59.645271958029014,59.69952344165351,59.753774925278,59.8080264089025,59.862277892527,59.91652937615149,59.97078085977598,60.025032343400476,60.07928382702497,60.133535310649464,60.18778679427396,60.24203827789846,60.29628976152296,60.35054124514744,60.40479272877194,60.459044212396435,60.51329569602093,60.56754717964542,60.62179866326992,60.67605014689441,60.73030163051891,60.7845531141434,60.8388045977679,60.893056081392395,60.947307565016885,61.00183166102902,61.056492062733355,61.11115246443767,61.165812866142005,61.22047326784633,61.27513366955065,61.32979407125498,61.3844544729593,61.43911487466363,61.493775276367955,61.54843567807227,61.603096079776606,61.657756481480924,61.712416883185256,61.767077284889574,61.8217376865939,61.87639808829823,61.922580513696786,61.96706734383419,62.01155417397159,62.056041004109,62.10052783424641,62.14501466438381,62.18950149452121,62.23398832465862,62.27847515479603,62.32296198493343,62.36744881507082,62.41193564520823,62.45642247534563,62.50090930548304,62.54539613562044,62.589882965757845,62.63436979589525,62.67929336631183,62.724216937085586,62.76914050785935,62.8140640786331,62.85898764940687,62.903911220180625,62.94883479095438,62.99375836172814,63.038681932501895,63.08360550327565,63.12852907404941,63.173452644823165,63.21837621559693,63.26329978637069,63.30822335714445,63.3531469279182,63.398070498691965,63.44299406946572,63.48791764023948,63.53284121101324,63.577764781786996,63.62268835256076,63.66761192333451,63.71253549410827,63.757459064882035,63.802382635655796,63.84730620642955,63.892229777203305,63.937153347977066,63.98207691875083,64.0270004895246,64.07192406029834,64.11684763107209,64.16177120184585,64.20669477261961,64.25161834339337,64.29654191416712,64.34146548494088,64.38638905571464,64.4313126264884,64.47623619726215,64.52115976803591,64.56608333880968,64.61100690958344,64.6559304803572,64.70085405113095,64.74577762190472,64.79070119267847,64.83562476345223,64.88054833422599,64.92547190499974,64.9703954757735,65.01531904654725,65.06024261732102,65.10516618809477,65.15008975886853,65.1950133296423,65.23993690041604,65.28486047118982,65.32978404196356,65.37470761273732,65.41963118351109,65.46455475428483,65.50947832505861,65.55440189583236,65.59932546660612,65.6409271860636,65.68086797986294,65.72080877366228,65.76074956746162,65.80069036126096,65.84063115506031,65.88057194885965,65.92051274265899,65.96045353645833,66.00039433025766,66.04033512405701,66.08027591785635,66.12021671165569,66.16015750545503,66.20009829925436,66.24003909305371,66.27997988685306,66.3199206806524,66.35986147445175,66.39980226825108,66.43974306205041,66.47968385584977,66.5196246496491,66.55956544344843,66.59950623724778,66.63944703104713,66.67938782484646,66.72006898952856,66.76077659724703,66.80148420496549,66.84219181268396,66.88289942040242,66.92360702812088,66.96431463583934,67.0050222435578,67.04572985127628,67.08643745899474,67.1271450667132,67.16785267443166,67.20856028215013,67.24926788986859,67.28997549758705,67.33068310530551,67.37139071302397,67.41209832074244,67.4528059284609,67.49351353617936,67.53422114389784,67.57492875161628,67.61563635933476,67.65634396705322,67.69705157477168,67.73775918249015,67.7784667902086,67.81917439792707,67.85988200564555,67.90058961336399,67.94129722108246,67.98200482880092,68.0227124365194,68.06342004423784,68.1041276519563,68.14483525967478,68.18554286739324,68.2262504751117,68.26695808283017,68.30766569054863,68.34837329826709,68.38908090598557,68.42978851370401,68.47049612142249,68.51120372914095,68.5519113368594,68.59261894457788,68.63332655229632,68.6740341600148,68.71474176773326,68.75544937545172,68.79615698317019,68.83686459088865,68.87757219860711,68.91827980632559,68.95898741404403,68.75452544565127,68.30489390114728,67.85526235664332,67.40563081213938,66.95599926763538,66.50636772313143,66.05673617862749,65.60710463412349,65.15747308961949,64.70784154511558,64.2582100006116,63.8085784561076,63.35894691160365,62.9093153670997,62.45968382259571,62.010052278091756,61.560420733587804,61.11078918908382,60.66115764457986,60.211526100075915,59.761894555571914,59.31226301106793,58.86263146656401,58.412999922060024,57.96336837755602,57.51373683305208,57.06410528854812,56.614473744044126,56.164842199540175,55.71521065503622,55.26557911053224,54.81594756602824,54.36631602152433,53.91668447702034,53.46705293251635,53.017421388012394,52.56778984350844,52.11815829900445,51.6685267545005,51.218895209996546,50.769263665492545,50.31963212098861,49.87000057648466,49.42036903198066,48.97073748747666,48.52110594297275,48.071474398468766,47.62184285396477,47.17221130946082,46.72257976495686,46.27294822045288,45.82331667594892,45.37368513144497,44.924053586940985,44.474422042437,44.02479049793308,43.57515895342908,43.125527408925095,42.675895864421136,42.22626431991719,41.77663277541319,41.32700123090925,40.877369686405295,40.4277381419013,39.97740044223291,39.50534922537997,39.03329800852699,38.561246791674,38.089195574821105,37.617144357968115,37.14509314111514,36.67304192426219,36.200990707409254,35.728939490556265,35.256888273703325,34.784837056850385,34.3127858399974,33.840734623144456,33.36868340629152,32.896632189438535,32.424580972585545,31.952529755732606,31.480478538879666,31.07615437020432,30.807284297884237,30.538414225564154,30.269544153244045,30.00067408092396,29.731804008603874,29.46293393628377,29.19406386396366,28.9251937916436,28.65632371932349,28.387453647003383,28.1185835746833,27.849713502363212,27.580843430043103,27.31197335772302,27.043103285402935,26.774233213082827,26.505363140762743,26.236493068442662,25.96762299612255,25.698752923802445,25.42988285148236,25.161012779162277,24.892142706842165,24.62327263452208,24.354402562201997,24.085532489881892,23.81666241756181,23.547792345241724,23.278922272921616,23.010052200601503,22.741182128281444,22.47231205596134,22.203441983641227,21.934571911321143,21.66570183900106,21.396831766680954,21.12796169436087,20.859091622040786,20.590221549720674,20.321351477400587,20.052481405080506,19.783611332760394,19.51474126044029,19.245871188120205,18.97700111580012,18.70813104348001,18.439260971159925,18.17039089883984,17.901520826519736,17.63265075419965,17.363780681879565,17.094910609559456,16.826040537239347,16.557170464919288,16.288300392599183,16.01943032027907,15.750560247958987,15.481690175638903,15.212820103318796,14.943950030998714,14.675079958678626,14.406209886358518,14.137339814038434,13.86846974171835,13.599599669398241,13.330729597078133,13.061859524758075,12.792989452437967,12.524119380117856,12.255249307797772,11.986379235477688,11.71750916315758,11.448639090837496,11.179769018517412,10.910898946197305,10.642028873877196,10.373158801557135,10.104288729237023,9.845727802951235,9.58773957411813,9.329751345285027,9.0717631164519,8.84583752407119,8.78022511395228,8.71461270383337,8.64900029371446,8.583387883595561,8.517775473476652,8.452163063357743,8.386550653238846,8.320938243119937,8.256496389281471,8.204931651210245,8.15336691313901,8.101802175067778,8.050237436996543,7.998672698925318,7.947107960854083,7.89554322278285,7.843978484711625,7.79241374664039,7.740849008569157,7.689284270497932,7.637719532426697,7.586154794355463,7.534590056284238,7.483025318213003,7.431460580141769,7.379895842070535,7.32833110399931,7.276766365928076,7.225201627856842,7.173636889785618,7.122072151714383,7.070507413643148,7.018942675571923,6.9673779375006895,6.915813199429454,6.86424846135822,6.812683723286996,6.761118985215761,6.709554247144527,6.657989509073302,6.606424771002067,6.554860032930833,6.503295294859608,6.451730556788374,6.400165818717141,6.348601080645915,6.297036342574681,6.245471604503447,6.1939068664322114,6.142342128360988,6.090777390289753,6.039212652218518,5.987647914147294,5.936083176076059,5.884518438004825,5.832953699933601,5.781388961862366,5.729824223791132,5.678259485719897,5.626694747648672,5.575130009577439,5.523565271506205,5.472000533434979,5.420435795363744,5.368871057292511,5.317306319221286,5.265741581150051,5.214176843078817,5.162612105007593,5.111047366936358,5.059482628865124,5.007917890793889,4.956353152722665,4.906066597188865,4.869838961399414,4.8336113256099695,4.797383689820518,4.7611560540310665,4.724928418241622,4.688700782452171,4.652473146662719,4.616245510873268,4.580017875083824],[57.603893787494165,57.65814527111866,57.71239675474315,57.76664823836765,57.82089972199215,57.87515120561664,57.92940268924113,57.98365417286563,58.037905656490125,58.092157140114615,58.14640862373911,58.2006601073636,58.2549115909881,58.3091630746126,58.363414558237096,58.417666041861594,58.47191752548608,58.526169009110575,58.58042049273507,58.63467197635957,58.68892345998406,58.74317494360856,58.79742642723305,58.851677910857546,58.905929394482044,58.960180878106534,59.014432361731025,59.06868384535552,59.12293532898002,59.17718681260452,59.231438296229015,59.2856897798535,59.339941263477996,59.394192747102494,59.44844423072699,59.50269571435148,59.55694719797597,59.611198681600484,59.66545016522497,59.719701648849465,59.773953132473956,59.82820461609845,59.882456099722944,59.93670758334744,59.99095906697194,60.04521055059644,60.09946203422093,60.15371351784542,60.207965001469915,60.262216485094406,60.31653612184368,60.371196523548015,60.42585692525233,60.48051732695666,60.53517772866099,60.58983813036531,60.64449853206964,60.69915893377396,60.75381933547828,60.808479737182616,60.86314013888693,60.91780054059126,60.972460942295584,61.02712134399991,61.08178174570423,61.13644214740856,61.191102549112884,61.2457629508172,61.300423352521534,61.35508375422586,61.409744155930184,61.46440455763451,61.519064959338834,61.57372536104316,61.62838576274748,61.68304616445181,61.73770656615613,61.79236696786045,61.847027369564785,61.9016877712691,61.956348172973435,62.01100857467775,62.06566897638208,62.12032937808641,62.16651180348497,62.21099863362238,62.25548546375978,62.299972293897184,62.344459124034586,62.38894595417199,62.43343278430939,62.477919614446805,62.522406444584206,62.56689327472161,62.61138010485901,62.65586693499642,62.70035376513382,62.74484059527123,62.78932742540863,62.83381425554603,62.87830108568344,62.92278791582085,62.96727474595825,63.01176157609565,63.05624840623305,63.100735236370454,63.14522206650786,63.18970889664527,63.23419572678267,63.27868255692008,63.32316938705748,63.36765621719489,63.412143047332286,63.4566298774697,63.501116707607096,63.5456035377445,63.590090367881906,63.63479556821842,63.67971913899218,63.724642709765945,63.7695662805397,63.81448985131346,63.859413422087215,63.904336992860976,63.94926056363474,63.994184134408485,64.03910770518226,64.08403127595601,64.12895484672977,64.17387841750353,64.21880198827729,64.26372555905105,64.3086491298248,64.35357270059855,64.39849627137232,64.44341984214607,64.48834341291983,64.53326698369358,64.57819055446734,64.6231141252411,64.66803769601486,64.71296126678862,64.75788483756239,64.80280840833615,64.84773197910991,64.89265554988364,64.9375791206574,64.98250269143116,65.02742626220493,65.07234983297869,65.11727340375245,65.16219697452621,65.20712054529996,65.25204411607372,65.29696768684748,65.34189125762123,65.38681482839499,65.43173839916875,65.47666196994251,65.52158554071627,65.56650911149003,65.61143268226378,65.65635625303754,65.70127982381129,65.74620339458507,65.79112696535881,65.83605053613257,65.87765225559006,65.9175930493894,65.95753384318874,65.99747463698807,66.03741543078742,66.07735622458677,66.11729701838611,66.15723781218546,66.19717860598479,66.23711939978412,66.27706019358347,66.31700098738281,66.35694178118214,66.39688257498149,66.43682336878084,66.47676416258017,66.51670495637951,66.55664575017886,66.5965865439782,66.63652733777755,66.67646813157688,66.71640892537621,66.75634971917556,66.7962905129749,66.83623130677424,66.87617210057358,66.91611289437293,66.95605368817226,66.99599448197161,67.03593527577095,67.07587606957028,67.11581686336963,67.15575765716898,67.19569845096831,67.23563924476765,67.27558003856699,67.31552083236633,67.35546162616568,67.39540241996502,67.43534321376436,67.47528400756369,67.51522480136305,67.55516559516238,67.59510638896172,67.63504718276107,67.6749879765604,67.71492877035973,67.75486956415908,67.79481035795843,67.83475115175776,67.8746919455571,67.91463273935645,67.9545735331558,67.99512248902592,68.03583009674439,68.07653770446285,68.11724531218131,68.15795291989978,68.19866052761823,68.23936813533672,68.28007574305516,68.32078335077364,68.3614909584921,68.40219856621056,68.44290617392903,68.48361378164748,68.52432138936595,68.56502899708441,68.60573660480287,68.64644421252135,68.6871518202398,68.72785942795826,68.76856703567674,68.80927464339518,68.84998225111366,68.89068985883212,68.93139746655058,68.97210507426904,69.0128126819875,69.05352028970597,69.09422789742442,69.13493550514289,69.17564311286135,68.9711811444686,68.5215495999646,68.07191805546066,67.62228651095668,67.17265496645271,66.72302342194875,66.27339187744481,65.82376033294081,65.3741287884368,64.9244972439329,64.4748656994289,64.02523415492493,63.575602610420965,63.125971065917014,62.67633952141302,62.226707976909076,61.777076432405124,61.32744488790113,60.87781334339718,60.42818179889322,59.97855025438923,59.52891870988523,59.07928716538133,58.629655620877344,58.18002407637335,57.7303925318694,57.28076098736544,56.83112944286145,56.381497898357495,55.93186635385356,55.482234809349556,55.03260326484557,54.582971720341654,54.13334017583765,53.683708631333666,53.21359926108115,52.741548044228196,52.26949682737522,51.79744561052228,51.32539439366934,50.85334317681635,50.38129195996342,49.90924074311047,49.437189526257484,48.965138309404495,48.493087092551605,48.021035875698615,47.548984658845626,47.07693344199269,46.60488222513975,46.13283100828677,45.660779791433825,45.18872857458088,44.71667735772789,44.244626140874914,43.77257492402201,43.300523707169035,42.828472490316045,42.35642127346311,41.884370056610166,41.41231883975718,40.94026762290423,40.46821640605129,39.99616518919831,39.52411397234537,39.05206275549243,38.58001153863944,38.10796032178645,37.63590910493355,37.16385788808057,36.691806671227596,36.21975545437465,35.74770423752171,35.27565302066871,34.80360180381578,34.33155058696284,33.85949937010986,33.38744815325691,32.915396936403965,32.44334571955098,31.971294502697994,31.499243285845054,31.02719206899212,30.622867900316773,30.353997827996686,30.085127755676606,29.816257683356497,29.547387611036413,29.27851753871633,29.009647466396217,28.74077739407611,28.471907321756053,28.203037249435944,27.93416717711583,27.665297104795748,27.396427032475664,27.12755696015556,26.858686887835475,26.58981681551539,26.320946743195286,26.052076670875195,25.78320659855511,25.514336526235006,25.245466453914897,24.976596381594813,24.70772630927473,24.43885623695462,24.169986164634537,23.901116092314453,23.632246019994344,23.36337594767426,23.094505875354177,22.825635803034068,22.55676573071396,22.2878956583939,22.01902558607379,21.75015551375368,21.4812854414336,21.212415369113515,20.943545296793403,20.67467522447332,20.405805152153235,20.136935079833126,19.868065007513042,19.599194935192955,19.330324862872846,19.061454790552737,18.792584718232654,18.526291940532413,18.26830371169929,18.010315482866186,17.75232725403308,17.494339025199952,17.236350796366846,16.978362567533747,16.72037433870062,16.462386109867488,16.20439788103441,15.946409652201284,15.688421423368155,15.430433194535052,15.17244496570195,14.914456736868821,14.656468508035715,14.398480279202612,14.140492050369485,13.88250382153638,13.624515592703279,13.366527363870148,13.108539135037024,12.850550906203942,12.592562677370815,12.334574448537687,12.076586219704584,11.818597990871481,11.560609762038352,11.302621533205249,11.044633304372145,10.786645075539017,10.52865684670589,10.270668617872808,10.012680389039682,9.754692160206554,9.49670393137345,9.238715702540347,8.98072747370722,8.75480188132651,8.689189471207598,8.623577061088689,8.55796465096978,8.492352240850881,8.426739830731972,8.361127420613062,8.295515010494164,8.229902600375254,8.164290190256345,8.098677780137447,8.033065370018537,7.967452959899626,7.901840549780717,7.836228139661819,7.770615729542909,7.705003319424,7.639390909305103,7.573778499186194,7.5081660890672826,7.442553678948385,7.3769412688294755,7.311328858710565,7.2457164485916685,7.1801040384727575,7.114491628353848,7.048879218234939,6.983266808116041,6.917654397997131,6.852041987878222,6.786429577759323,6.720817167640414,6.655204757521504,6.6032058606187585,6.554434888267513,6.5056639159162675,6.456892943565022,6.408121971213785,6.35935099886254,6.310580026511295,6.261809054160059,6.213038081808812,6.164267109457567,6.115496137106331,6.066725164755086,6.017954192403841,5.969183220052604,5.920412247701359,5.871641275350113,5.822870302998868,5.7740993306476325,5.729823040724377,5.693595404934926,5.65736776914548,5.621140133356029,5.584912497566578,5.548684861777134,5.512457225987682,5.476229590198232,5.44000195440878,5.403774318619335,5.367546682829883,5.331319047040433,5.295091411250988,5.258863775461537,5.222636139672085,5.186408503882641,5.150180868093189,5.1139532323037376,5.077725596514293,5.041497960724842,5.005270324935391,4.969042689145939,4.932815053356495,4.896587417567043,4.860359781777592,4.824132145988147,4.787904510198696,4.751676874409245,4.7154492386198,4.679221602830349,4.642993967040898,4.606766331251446,4.570538695462002],[57.8410779291881,57.8953294128126,57.94958089643709,58.00383238006158,58.05808386368608,58.11233534731058,58.16658683093506,58.220838314559565,58.275089798184055,58.32934128180855,58.38359276543305,58.43784424905754,58.49209573268204,58.54634721630653,58.60059869993103,58.654850183555524,58.709101667180015,58.76335315080451,58.817604634429,58.8718561180535,58.926107601678,58.98035908530249,59.034610568926986,59.088862052551484,59.143113536175974,59.19736501980047,59.25161650342497,59.30586798704946,59.36011947067395,59.41437095429845,59.468622437922946,59.522873921547436,59.577125405171934,59.63137688879643,59.685900984362675,59.740561386067,59.795221787771325,59.84988218947565,59.904542591179975,59.9592029928843,60.013863394588626,60.06852379629295,60.123184197997276,60.177844599701594,60.23250500140592,60.28716540311025,60.34182580481457,60.3964862065189,60.45114660822321,60.505807009927544,60.560467411631876,60.615127813336194,60.669788215040526,60.72444861674485,60.77910901844917,60.83376942015349,60.88842982185782,60.94309022356215,60.99775062526646,61.052411026970795,61.10707142867513,61.161731830379445,61.21639223208378,61.2710526337881,61.32571303549242,61.380373437196745,61.43503383890108,61.489694240605395,61.54435464230972,61.599015044014045,61.65367544571838,61.708335847422696,61.76299624912702,61.81765665083135,61.87231705253567,61.926977454239996,61.98163785594433,62.03629825764864,62.09095865935298,62.14561906105729,62.20027946276162,62.25493986446595,62.309600266170264,62.364260667874596,62.41044309327315,62.45492992341055,62.49941675354796,62.54390358368536,62.588390413822765,62.632877243960166,62.67736407409757,62.72185090423498,62.766337734372385,62.81082456450979,62.85531139464719,62.8997982247846,62.944285054922,62.98877188505941,63.03325871519681,63.07774554533421,63.122232375471626,63.16671920560903,63.21120603574643,63.25569286588383,63.30017969602123,63.34466652615863,63.38915335629604,63.43364018643345,63.47812701657085,63.52261384670826,63.56710067684567,63.61158750698307,63.656074337120465,63.70056116725788,63.745047997395275,63.78953482753268,63.834021657670085,63.878508487807494,63.922995317944896,63.9674821480823,64.0119689782197,64.05645580835711,64.10094263849452,64.14542946863192,64.18991629876932,64.23440312890672,64.27888995904414,64.32337678918154,64.36786361931894,64.41235044945634,64.45683727959374,64.50132410973114,64.54581093986856,64.59029777012502,64.63522134089878,64.68014491167253,64.72506848244629,64.76999205322005,64.81491562399381,64.85983919476757,64.90476276554134,64.94968633631508,64.99460990708884,65.03953347786259,65.08445704863635,65.12938061941011,65.17430419018388,65.21922776095764,65.2641513317314,65.30907490250516,65.3539984732789,65.39892204405267,65.44384561482643,65.48876918560018,65.53369275637394,65.5786163271477,65.62353989792146,65.66846346869522,65.71338703946898,65.75831061024273,65.80323418101649,65.84815775179024,65.893081322564,65.93800489333776,65.98292846411152,66.02785203488529,66.07277560565905,66.11437732511652,66.15431811891585,66.1942589127152,66.23419970651454,66.27414050031388,66.31408129411322,66.35402208791257,66.39396288171191,66.43390367551125,66.47384446931059,66.51378526310994,66.55372605690927,66.59366685070862,66.63360764450795,66.6735484383073,66.71348923210664,66.75343002590598,66.7933708197053,66.83331161350466,66.873252407304,66.91319320110335,66.95313399490269,66.99307478870203,67.03301558250136,67.0729563763007,67.11289717010004,67.15283796389939,67.19277875769873,67.23271955149806,67.27266034529741,67.31260113909674,67.35254193289609,67.39248272669543,67.43242352049478,67.47236431429411,67.51230510809346,67.5522459018928,67.59218669569213,67.63212748949148,67.67206828329081,67.71200907709016,67.75194987088949,67.79189066468885,67.83183145848818,67.87177225228753,67.91171304608687,67.9516538398862,67.99159463368554,68.03153542748488,68.07147622128423,68.11141701508356,68.1513578088829,68.19129860268225,68.2312393964816,68.27118019028094,68.31112098408028,68.35106177787961,68.39100257167897,68.4309433654783,68.47088415927765,68.51082495307698,68.55076574687632,68.59070654067567,68.630647334475,68.67058812827435,68.71052892207368,68.75046971587302,68.79041050967237,68.8303513034717,68.87029209727105,68.9102328910704,68.95017368486972,68.99011447866907,69.03005527246842,69.06999606626775,69.1099368600671,69.14987765386644,69.18981844766577,69.22975924146512,69.27017598852328,69.31088359624174,69.35159120396021,69.39229881167867,69.18783684328591,68.73820529878192,68.28857375427796,67.83894220977402,67.38931066527002,66.92184929678236,66.44979807992942,65.97774686307643,65.50569564622346,65.03364442937055,64.56159321251758,64.08954199566459,63.61749077881164,63.145439561958696,62.67338834510572,62.20133712825278,61.729285911399835,61.25723469454685,60.78518347769391,60.313132260840966,59.841081043987984,59.369029827134995,58.8969786102821,58.424927393429115,57.952876176576126,57.48082495972319,57.00877374287024,56.536722526017265,56.064671309164325,55.59262009231138,55.120568875458396,54.648517658605414,54.17646644175252,53.70441522489953,53.232364008046545,52.7603127911936,52.28826157434066,51.81621035748767,51.34415914063473,50.87210792378179,50.4000567069288,49.928005490075876,49.45595427322292,48.98390305636994,48.51185183951695,48.03980062266406,47.56774940581107,47.09569818895808,46.62364697210515,46.151595755252195,45.67954453839921,45.20749332154628,44.735442104693334,44.263390887840345,43.79133967098736,43.319288454134465,42.84723723728149,42.3751860204285,41.90313480357555,41.431083586722615,40.95903236986962,40.486981153016686,40.01492993616375,39.542878719310764,39.070827502457824,38.59877628560487,38.12672506875189,37.654673851898906,37.18262263504601,36.71057141819303,36.238520201340044,35.7664689844871,35.294417767634165,34.822366550781176,34.35031533392823,33.87826411707529,33.4062129002223,32.93416168336936,32.46211046651642,31.990059249663435,31.518008032810453,31.045956815957517,30.57390559910457,30.169581430429226,29.900711358109138,29.631841285789058,29.362971213468946,29.094101141148865,28.825231068828785,28.556360996508673,28.287490924188564,28.018620851868505,27.749750779548393,27.480880707228287,27.212010634908204,26.948867849280468,26.690879620447344,26.432891391614238,26.17490316278113,25.916914933948007,25.658926705114904,25.400938476281798,25.14295024744867,24.884962018615546,24.626973789782436,24.368985560949334,24.11099733211621,23.853009103283103,23.59502087445,23.337032645616873,23.07904441678377,22.821056187950663,22.563067959117536,22.305079730284408,22.047091501451327,21.789103272618206,21.531115043785075,21.273126814951972,21.01513858611887,20.757150357285738,20.49916212845264,20.241173899619533,19.983185670786405,19.725197441953302,19.4672092131202,19.20922098428707,18.95123275545394,18.693244526620838,18.43525629778773,18.177268068954607,17.919279840121504,17.661291611288398,17.40330338245527,17.145315153622168,16.887326924789065,16.629338695955937,16.37135046712281,16.113362238289728,15.855374009456602,15.597385780623473,15.33939755179037,15.081409322957267,14.82342109412414,14.565432865291035,14.30744463645793,14.049456407624804,13.7914681787917,13.533479949958597,13.27549172112547,13.017503492292342,12.75951526345926,12.501527034626134,12.243538805793007,11.985550576959902,11.727562348126797,11.469574119293672,11.211585890460567,10.953597661627462,10.695609432794337,10.437621203961207,10.17963297512813,9.921644746295001,9.663656517461872,9.40566828862877,9.147680059795665,8.889691830962537,8.663766238581827,8.598153828462918,8.532541418344007,8.466929008225097,8.4013165981062,8.335704187987291,8.27009177786838,8.204479367749483,8.138866957630574,8.073254547511663,8.007642137392766,7.942029727273855,7.876417317154945,7.810804907036036,7.7583849457477,7.709613973396455,7.66084300104521,7.612072028693974,7.563301056342727,7.514530083991482,7.465759111640247,7.416988139289002,7.368217166937755,7.319446194586519,7.2706752222352735,7.2219042498840285,7.1731332775327825,7.124362305181547,7.0755913328303,7.026820360479055,6.97804938812782,6.929278415776574,6.880507443425328,6.831736471074092,6.782965498722847,6.734194526371602,6.685423554020356,6.63665258166912,6.587881609317875,6.539110636966628,6.490339664615393,6.441568692264147,6.392797719912902,6.344026747561665,6.2952557752104195,6.246484802859175,6.197713830507938,6.148942858156692,6.100171885805447,6.051400913454202,6.002629941102965,5.95385896875172,5.905087996400475,5.856317024049238,5.807546051697993,5.758775079346748,5.710004106995511,5.661233134644265,5.61246216229302,5.563691189941775,5.5149202175905385,5.4661492452392935,5.4173782728880475,5.368607300536811,5.319836328185566,5.27106535583432,5.222294383483084,5.173523411131839,5.124752438780593,5.075981466429357,5.0320187811030195,4.995791145313569,4.959563509524117,4.923335873734673,4.887108237945221,4.85088060215577,4.8146529663663244,4.778425330576874,4.742197694787423,4.705970058997978,4.669742423208526,4.633514787419076,4.597287151629624,4.56105951584018],[58.07826207088204,58.13251355450654,58.18676503813103,58.241016521755526,58.295268005380024,58.349519489004514,58.40377097262901,58.4580224562535,58.512273939878,58.5665254235025,58.620776907126995,58.675028390751486,58.729279874375976,58.783531358000474,58.83778284162498,58.89203432524947,58.94628580887396,59.000605445177335,59.05526584688167,59.109926248585985,59.16458665029032,59.219247051994635,59.27390745369896,59.328567855403286,59.38322825710762,59.43788865881194,59.492549060516254,59.547209462220586,59.60186986392491,59.656530265629236,59.71119066733357,59.76585106903788,59.82051147074221,59.875171872446536,59.92983227415086,59.98449267585519,60.039153077559504,60.09381347926384,60.14847388096816,60.20313428267249,60.257794684376805,60.31245508608113,60.36711548778546,60.42177588948979,60.476436291194105,60.53109669289843,60.58575709460276,60.640417496307094,60.695077898011405,60.74973829971574,60.804398701420055,60.85905910312439,60.913719504828705,60.96837990653303,61.02304030823736,61.07770070994168,61.13236111164601,61.18702151335033,61.241681915054656,61.29634231675899,61.351002718463306,61.40566312016764,61.46032352187196,61.51498392357629,61.569644325280606,61.62430472698494,61.67896512868926,61.73362553039358,61.788285932097914,61.84294633380223,61.897606735506564,61.95226713721089,62.00692753891521,62.06158794061954,62.11624834232386,62.17090874402819,62.225569145732514,62.28022954743683,62.33488994914117,62.38955035084548,62.444210752549814,62.49887115425413,62.55353155595846,62.60819195766279,62.65437438306134,62.69886121319875,62.74334804333614,62.78783487347356,62.83232170361096,62.87680853374836,62.92129536388576,62.96578219402316,63.01026902416057,63.05475585429797,63.09924268443539,63.14372951457278,63.1882163447102,63.23270317484759,63.277190004985,63.32167683512241,63.36616366525981,63.41065049539722,63.45513732553462,63.499624155672024,63.544110985809425,63.58859781594683,63.633084646084235,63.67757147622164,63.722058306359045,63.76654513649645,63.81103196663385,63.85551879677125,63.90000562690866,63.94449245704607,63.98897928718347,64.03346611732087,64.07795294745827,64.12243977759569,64.16692660773309,64.21141343787049,64.2559002680079,64.30038709814531,64.34487392828271,64.38936075842011,64.43384758855751,64.47833441869491,64.52282124883232,64.56730807896972,64.61179490910713,64.65628173924453,64.70076856938194,64.74525539951934,64.78974222965675,64.83422905979415,64.87871588993156,64.92320272006896,64.96768955020636,65.01217638034377,65.05666321048118,65.10115004061858,65.14563687075598,65.19012370089338,65.2346105310308,65.2790973611682,65.3235841913056,65.368071021443,65.4125578515804,65.45704468171782,65.50153151185522,65.54601834199262,65.59072354280538,65.63564711357915,65.6805706843529,65.72549425512665,65.77041782590041,65.81534139667417,65.86026496744793,65.9051885382217,65.95011210899544,65.9950356797692,66.03995925054296,66.08488282131673,66.12980639209047,66.17472996286423,66.219653533638,66.26457710441176,66.30950067518552,66.351102394643,66.39104318844232,66.43098398224168,66.47092477604102,66.51086556984035,66.5508063636397,66.59074715743904,66.63068795123837,66.67062874503772,66.71056953883706,66.75051033263641,66.79045112643574,66.83039192023509,66.87033271403442,66.91027350783376,66.95021430163311,66.99015509543246,67.03009588923179,67.07003668303113,67.10997747683047,67.14991827062981,67.18985906442916,67.22979985822849,67.26974065202783,67.30968144582718,67.34962223962651,67.38956303342586,67.4295038272252,67.46944462102454,67.50938541482388,67.54932620862323,67.58926700242256,67.6292077962219,67.66914859002125,67.70908938382058,67.74903017761993,67.78897097141927,67.8289117652186,67.86885255901794,67.9087933528173,67.94873414661663,67.98867494041598,68.02861573421532,68.06855652801465,68.108497321814,68.14833084479002,68.18735982480311,68.22638880481621,68.26541778482928,68.30444676484238,68.34347574485548,68.38250472486857,68.42153370488165,68.46056268489474,68.49959166490783,68.53862064492091,68.577649624934,68.61667860494708,68.65570758496018,68.69473656497327,68.73376554498634,68.77279452499944,68.81182350501254,68.85085248502563,68.88988146503871,68.9289104450518,68.9679394250649,69.00696840507798,69.04599738509107,69.08502636510416,69.12405534511726,69.16308432513034,69.20211330514343,69.24114228515651,69.2801712651696,69.31920024518269,69.35822922519577,69.39725820520886,69.43628718522196,69.47531616523504,69.51434514524813,69.55337412526121,69.59240310527431,69.36375531135845,68.86743074351361,68.37110617566884,67.87478160782408,67.37845703997925,66.88213247213447,66.3858079042897,65.88948333644488,65.39315876860006,64.89683420075534,64.40050963291051,63.90418506506569,63.407860497220916,62.911535929376136,62.41521136153133,61.918886793686546,61.42256222584177,60.92623765799695,60.429913090152176,59.9335885223074,59.43726395446258,58.94093938661777,58.455480105597275,57.98339346580697,57.51130682601667,57.039220186226416,56.56713354643614,56.09504690664585,55.62296026685557,55.15087362706532,54.678786987275025,54.20670034748471,53.73461370769451,53.2625270679042,52.79044042811391,52.318353788323634,51.84626714853337,51.37418050874308,50.902093868952804,50.430007229162555,49.95792058937225,49.48583394958199,49.01374730979174,48.54166067000143,48.06957403021113,47.59748739042091,47.125400750630604,46.653314110840306,46.18122747105005,45.70914083125979,45.23705419146948,44.76496755167922,44.292880911888965,43.82079427209867,43.348707632308354,42.87662099251814,42.404534352727836,41.93244771293754,41.46036107314728,40.98827443335702,40.516187793566715,40.04410115377645,39.5720145139862,39.0999278741959,38.627841234405636,38.155754594615374,37.68366795482507,37.21158131503477,36.73949467524455,36.26740803545425,35.79532139566395,35.32323475587369,34.85114811608343,34.379061476293124,33.90697483650287,33.434888196712606,32.9628015569223,32.49071491713205,32.01862827734178,31.54654163755148,31.07445499776118,30.602368357970917,30.130281718180655,29.73004931619539,29.473525389820132,29.21700146344488,28.9604775370696,28.70395361069435,28.44742968431909,28.190905757943817,27.934381831568537,27.677857905193306,27.42133397881803,27.164810052442753,26.9082861260675,26.651762199692243,26.39523827331697,26.138714346941715,25.882190420566456,25.62566649419118,25.369142567815928,25.11261864144067,24.856094715065396,24.59957078869012,24.343046862314864,24.08652293593961,23.829999009564332,23.573475083189077,23.316951156813822,23.060427230438545,22.80390330406329,22.54737937768804,22.290855451312762,22.034331524937482,21.777807598562255,21.521283672186975,21.264759745811695,21.008235819436443,20.751711893061188,20.49518796668591,20.23866404031066,19.9821401139354,19.72561618756012,19.46909226118487,19.212568334809614,18.956044408434337,18.69952048205906,18.442996555683806,18.186472629308554,17.929948702933274,17.673424776558022,17.416900850182763,17.160376923807487,16.90385299743223,16.64732907105698,16.390805144681703,16.134281218306427,15.877757291931193,15.621233365555916,15.364709439180638,15.108185512805385,14.851661586430131,14.595137660054853,14.338613733679598,14.082089807304344,13.825565880929066,13.569041954553812,13.312518028178559,13.05599410180328,12.799470175428002,12.542946249052772,12.286422322677495,12.029898396302217,11.773374469926965,11.516850543551708,11.260326617176432,11.003802690801178,10.75271553208038,10.507375881467791,10.2620362308552,10.016696580242654,9.771356929630064,9.526017279017474,9.280677628404906,9.03533797779234,8.789998327179749,8.575223448366412,8.513272428549062,8.451321408731713,8.389370388914365,8.327419369097028,8.26546834927968,8.20351732946233,8.141566309644993,8.079615289827643,8.017664270010295,7.95571325019296,7.893762230375612,7.8318112105582625,7.769860190740912,7.7079091709235765,7.645958151106228,7.584007131288879,7.522056111471541,7.460105091654193,7.398154071836844,7.336203052019506,7.274252032202158,7.221003248368918,7.172232276017681,7.123461303666437,7.074690331315191,7.025919358963945,6.977148386612709,6.928377414261463,6.879606441910218,6.8308354695589815,6.782064497207736,6.73329352485649,6.684522552505254,6.635751580154009,6.586980607802763,6.538209635451517,6.489438663100282,6.440667690749036,6.39189671839779,6.343125746046555,6.294354773695309,6.245583801344065,6.196812828992827,6.148041856641582,6.099270884290337,6.0504999119391005,6.001728939587855,5.9529579672366095,5.904186994885364,5.8554160225341265,5.8066450501828815,5.757874077831636,5.7091031054804,5.660332133129155,5.61156116077791,5.562790188426673,5.514019216075428,5.465248243724183,5.416477271372937,5.3677062990217,5.318935326670454,5.277363946536697,5.242809944048693,5.208255941560681,5.17370193907267,5.139147936584664,5.104593934096653,5.07003993160864,5.035485929120636,5.000931926632625,4.966377924144613,4.931823921656601,4.897269919168597,4.862715916680585,4.828161914192574,4.793607911704569,4.759053909216558,4.724499906728545,4.68994590424054,4.655391901752529,4.620837899264518,4.586283896776506,4.551729894288501],[58.31544621257598,58.36997030769632,58.424630709400645,58.47929111110496,58.533951512809296,58.58861191451362,58.64327231621794,58.69793271792227,58.752593119626596,58.80725352133092,58.861913923035246,58.916574324739564,58.971234726443896,59.02589512814822,59.080555529852546,59.13521593155687,59.18987633326119,59.24453673496552,59.29919713666985,59.35385753837417,59.4085179400785,59.46317834178282,59.51783874348715,59.57249914519147,59.6271595468958,59.68181994860012,59.73648035030445,59.79114075200877,59.8458011537131,59.900461555417415,59.95512195712175,60.00978235882607,60.0644427605304,60.11910316223472,60.17376356393904,60.22842396564337,60.2830843673477,60.33774476905202,60.39240517075635,60.447065572460666,60.50172597416499,60.556386375869316,60.61104677757365,60.66570717927797,60.7203675809823,60.77502798268662,60.82968838439095,60.88434878609527,60.9390091877996,60.993669589503924,61.04832999120825,61.102990392912574,61.1576507946169,61.212311196321224,61.26697159802554,61.321631999729874,61.3762924014342,61.430952803138524,61.48561320484285,61.54027360654717,61.5949340082515,61.649594409955824,61.70425481166015,61.758915213364475,61.81357561506879,61.868236016773125,61.92289641847745,61.97755682018177,62.0322172218861,62.08687762359042,62.14153802529474,62.19619842699907,62.250858828703386,62.30551923040772,62.360179632112036,62.41484003381637,62.46950043552069,62.52416083722501,62.57882123892934,62.63348164063366,62.688142042337994,62.74280244404231,62.79746284574664,62.85212324745097,62.898305672849524,62.942792502986926,62.98727933312433,63.031766163261736,63.07625299339914,63.120739823536546,63.16522665367395,63.209713483811356,63.25420031394876,63.29868714408616,63.343173974223575,63.38766080436097,63.432147634498385,63.47663446463578,63.52112129477319,63.5656081249106,63.610094955048,63.6545817851854,63.6990686153228,63.7435554454602,63.78804227559761,63.83252910573501,63.87701593587242,63.92150276600982,63.965989596147224,64.01047642628464,64.05496325642204,64.09945008655944,64.14393691669684,64.18842374683425,64.23291057697165,64.27739740710905,64.32188423724646,64.36637106738387,64.41085789752127,64.45534472765867,64.49983155779609,64.54431838793349,64.58880521807089,64.63329204820829,64.67777887834569,64.72226570848309,64.7667525386205,64.8112393687579,64.85572619889531,64.90021302903271,64.94469985917011,64.98918668930753,65.03367351944493,65.07816034958233,65.12264717971973,65.16713400985714,65.21162083999454,65.25610767013194,65.30059450026936,65.34508133040676,65.38956816054416,65.43405499068157,65.47854182081898,65.52302865095638,65.56751548109378,65.61200231123118,65.65648914136858,65.700975971506,65.7454628016434,65.7899496317808,65.8344364619182,65.87892329205562,65.92341012219302,65.96789695233042,66.01238378246782,66.05687061260522,66.10135744274262,66.14584427288004,66.19033110301744,66.23481793315484,66.27930476329225,66.32379159342966,66.36827842356706,66.41276525370446,66.45725208384187,66.50173891397927,66.54622574471196,66.58782746416945,66.62707099195333,66.66609997196642,66.7051289519795,66.74415793199259,66.78318691200569,66.82221589201876,66.86124487203185,66.90027385204493,66.93930283205803,66.97833181207112,67.01736079208422,67.0563897720973,67.09541875211039,67.13444773212348,67.17347671213656,67.21250569214965,67.25153467216273,67.29056365217582,67.32959263218892,67.36862161220202,67.4076505922151,67.44667957222819,67.48570855224128,67.52473753225436,67.56376651226745,67.60279549228053,67.64182447229364,67.6808534523067,67.7198824323198,67.7589114123329,67.79794039234599,67.83696937235908,67.87599835237216,67.91502733238525,67.95405631239834,67.99308529241144,68.03211427242452,68.07114325243761,68.11017223245071,68.14920121246378,68.18823019247688,68.22725917248997,68.26628815250305,68.30531713251614,68.34434611252922,68.38337509254231,68.4224040725554,68.4614330525685,68.50046203258158,68.53949101259467,68.57851999260775,68.61754897262084,68.65657795263392,68.69560693264702,68.73463591266011,68.7736648926732,68.81269387268628,68.85172285269937,68.89075183271247,68.92978081272554,68.96880979273864,69.00783877275173,69.04686775276483,69.08589673277791,69.124925712791,69.1639546928041,69.20298367281717,69.24201265283027,69.28104163284335,69.32007061285644,69.35909959286954,69.39812857288263,69.43715755289571,69.4761865329088,69.51521551292188,69.55424449293497,69.59327347294806,69.63230245296114,69.67133143297423,69.71036041298733,69.74938939300041,69.7884183730135,69.55977057909763,69.06344601125282,68.56712144340804,68.07079687556327,67.57447230771845,67.07814773987367,66.58182317202889,66.08549860418407,65.58917403633924,65.09284946849452,64.59652490064971,64.10020033280489,63.60387576496011,63.10755119711534,62.61122662927052,62.114902061425745,61.618577493580965,61.12225292573614,60.625928357891375,60.12960379004659,59.63327922220178,59.136954654356956,58.64063008651223,58.14430551866741,57.647980950822586,57.15165638297781,56.65533181513304,56.159007247288216,55.66268267944345,55.16635811159867,54.670033543753846,54.17370897590902,53.6773844080643,53.18105984021948,52.68473527237467,52.188410704529886,51.692086136685106,51.1957615688403,50.699437000995516,50.203112433150736,49.70678786530591,49.21046329746114,48.714138729616366,48.21781416177154,47.72148959392672,47.225165026081996,46.72884045823717,46.23251589039236,45.74287767157124,45.27079103178099,44.79870439199068,44.32661775220042,43.854531112410164,43.38244447261986,42.910357832829554,42.43827119303934,41.966184553249036,41.49409791345873,41.02201127366848,40.54992463387821,40.077837994087915,39.60575135429765,39.1336647145074,38.6615780747171,38.18949143492683,37.717404795136574,37.24531815534627,36.77323151555596,36.30114487576575,35.829058235975445,35.35697159618515,34.884884956394885,34.41279831660462,33.940711676814324,33.46862503702406,32.996538397233806,32.5244517574435,32.052365117653245,31.580278477862983,31.10819183807268,30.63610519828238,30.16401855849212,29.691931918701854,29.291699516716584,29.035175590341332,28.778651663966073,28.5221277375908,28.26560381121554,28.00907988484029,27.75255595846501,27.496032032089737,27.239508105714506,26.982984179339226,26.72646025296395,26.469936326588694,26.213412400213443,25.956888473838166,25.70036454746291,25.44384062108766,25.18731669471238,24.930792768337128,24.67426884196187,24.417744915586596,24.161220989211316,23.90469706283606,23.64817313646081,23.39164921008553,23.135125283710277,22.87860135733502,22.622077430959745,22.36555350458449,22.10902957820923,21.852505651833958,21.59598172545868,21.339457799083448,21.08293387270817,20.82640994633289,20.56988601995764,20.313362093582388,20.056838167207108,19.800314240831852,19.5437903144566,19.28726638808132,19.030742461706065,18.77421853533081,18.518937276736008,18.27359762612342,18.02825797551085,17.78291832489828,17.53757867428569,17.292239023673122,17.046899373060555,16.801559722447966,16.556220071835398,16.31088042122283,16.06554077061024,15.82020111999765,15.574861469385109,15.329521818772518,15.084182168159925,14.83884251754736,14.593502866934791,14.3481632163222,14.102823565709633,13.857483915097067,13.612144264484476,13.366804613871908,13.12146496325934,12.876125312646751,12.63078566203416,12.385446011421616,12.140106360809025,11.894766710196436,11.649427059583868,11.4040874089713,11.15874775835871,10.913408107746141,10.668068457133575,10.422728806520984,10.177389155908394,9.932049505295849,9.686709854683258,9.441370204070669,9.196030553458101,8.950690902845533,8.705351252232944,8.490576373419605,8.428625353602257,8.366674333784907,8.30472331396756,8.242772294150223,8.180821274332873,8.118870254515526,8.056919234698189,7.994968214880839,7.933017195063491,7.871066175246154,7.809115155428805,7.747164135611456,7.685213115794108,7.623262095976771,7.561311076159423,7.499360056342074,7.437409036524738,7.3754580167073875,7.313506996890039,7.2515559770727025,7.189604957255353,7.127653937438005,7.065702917620667,7.003751897803319,6.94180087798597,6.879849858168622,6.817898838351284,6.7559478185339366,6.6962896542724,6.6371717863285475,6.5780539183846845,6.518936050440821,6.45981818249697,6.400700314553106,6.341582446609243,6.28246457866538,6.223346710721527,6.164228842777664,6.105110974833801,6.045993106889949,5.9868752389460855,5.942853106876193,5.9096136432877096,5.876374179699221,5.843134716110731,5.809895252522248,5.776655788933758,5.743416325345269,5.7101768617567785,5.676937398168296,5.643697934579807,5.6104584709913174,5.577219007402834,5.543979543814345,5.510270301226842,5.475716298738837,5.441162296250825,5.406608293762815,5.372054291274803,5.3375002887867975,5.302946286298786,5.268392283810775,5.23383828132277,5.199284278834758,5.164730276346747,5.130176273858742,5.095622271370731,5.061068268882719,5.026514266394714,4.9919602639067024,4.957406261418691,4.922852258930679,4.888298256442674,4.8537442539546625,4.819190251466651,4.7846362489786465,4.750082246490635,4.715528244002623,4.680974241514618,4.646420239026607,4.611866236538596,4.577312234050583,4.542758231562579],[58.54422225365427,58.598785560051844,58.65334886644941,58.70791217284698,58.76247547924455,58.81703878564212,58.87160209203969,58.92616539843726,58.98072870483483,59.0352920112324,59.08985531762997,59.14441862402754,59.198981930425106,59.253545236822674,59.30810854322024,59.36267184961781,59.41723515601538,59.471879375286306,59.52653977699063,59.58120017869496,59.635860580399275,59.6905209821036,59.745181383807925,59.79984178551226,59.854502187216575,59.9091625889209,59.96382299062523,60.01848339232955,60.07314379403388,60.1278041957382,60.182464597442525,60.23712499914685,60.291785400851175,60.34644580255551,60.401106204259825,60.45576660596415,60.510427007668476,60.5650874093728,60.619747811077126,60.674408212781444,60.72906861448577,60.7837290161901,60.83838941789442,60.89304981959875,60.947710221303076,61.002370623007394,61.057031024711726,61.111691426416044,61.16635182812037,61.2210122298247,61.27567263152902,61.33033303323335,61.38499343493767,61.439653836641995,61.49431423834632,61.548974640050645,61.60363504175498,61.658295443459295,61.71295584516362,61.76761624686795,61.82227664857227,61.8769370502766,61.93159745198093,61.98625785368525,62.04091825538958,62.0955786570939,62.15023905879823,62.204899460502546,62.25955986220688,62.3142202639112,62.36888066561553,62.42354106731985,62.47820146902417,62.5328618707285,62.58752227243283,62.64218267413715,62.69684307584148,62.751503477545796,62.80616387925013,62.86082428095445,62.91548468265878,62.970145084363104,63.02480548606742,63.079465887771754,63.1256483131703,63.17013514330771,63.21462197344512,63.25910880358252,63.30359563371992,63.348082463857324,63.392569293994725,63.43705612413214,63.481542954269536,63.526029784406944,63.57051661454435,63.61500344468175,63.65949027481916,63.70397710495656,63.74846393509397,63.792950765231375,63.837437595368776,63.881924425506185,63.926411255643586,63.970898085780995,64.01538491591839,64.05987174605579,64.10435857619319,64.1488454063306,64.19333223646801,64.23781906660541,64.28230589674281,64.32679272688023,64.37127955701763,64.41576638715503,64.46025321729243,64.50474004742983,64.54922687756724,64.59371370770465,64.63820053784205,64.68268736797945,64.72717419811687,64.77166102825427,64.81614785839167,64.86063468852907,64.90512151866648,64.94960834880388,64.99409517894128,65.0385820090787,65.0830688392161,65.1275556693535,65.1720424994909,65.21652932962832,65.26101615976572,65.30550298990312,65.34998982004052,65.39447665017792,65.43896348031532,65.48345031045274,65.52793714059014,65.57242397072754,65.61691080086494,65.66139763100236,65.70588446113976,65.75037129127716,65.79485812141456,65.83934495155196,65.88383178168938,65.92831861182678,65.97280544196418,66.01729227210159,66.06177910223899,66.10574958245758,66.14961679179092,66.19348400112428,66.23735121045762,66.28121841979097,66.32508562912433,66.36895283845767,66.41282004779103,66.45668725712439,66.50055446645773,66.54442167579109,66.58828888512444,66.63215609445778,66.67602330379114,66.71989051312448,66.76375772245784,66.80399825536404,66.84242545005665,66.88085264474927,66.91927983944188,66.95770703413451,66.99613422882713,67.03456142351975,67.07298861821236,67.11141581290498,67.1498430075976,67.18827020229021,67.22669739698284,67.26512459167546,67.30355178636808,67.34197898106069,67.38040617575331,67.41883337044592,67.45726056513854,67.49568775983117,67.53411495452379,67.5725421492164,67.61096934390902,67.64939653860164,67.68782373329425,67.72625092798688,67.7646781226795,67.80310531737211,67.84153251206473,67.87995970675735,67.91838690144998,67.95681409614258,67.99524129083521,68.03366848552783,68.07209568022044,68.11104260012445,68.15007158013753,68.18910056015062,68.2281295401637,68.26715852017679,68.30618750018989,68.34521648020298,68.38424546021608,68.42327444022915,68.46230342024225,68.50133240025534,68.54036138026842,68.57939036028151,68.6184193402946,68.6574483203077,68.69647730032077,68.73550628033387,68.77453526034695,68.81356424036004,68.85259322037314,68.89162220038622,68.93065118039931,68.9696801604124,69.00870914042548,69.04773812043857,69.08676710045167,69.12579608046474,69.16482506047784,69.20385404049094,69.24288302050401,69.28191200051711,69.3209409805302,69.35996996054328,69.39899894055637,69.43802792056945,69.47705690058254,69.51608588059564,69.55511486060873,69.59414384062181,69.6331728206349,69.67220180064798,69.71123078066107,69.75025976067417,69.78928874068725,69.82831772070034,69.86734670071343,69.90637568072651,69.9454046607396,69.9844336407527,69.75578584683683,69.259461278992,68.76313671114724,68.26681214330246,67.77048757545764,67.27416300761287,66.77783843976809,66.28151387192327,65.78518930407844,65.28886473623372,64.79254016838891,64.29621560054407,63.79989103269931,63.30356646485454,62.8072418970097,62.31091732916493,61.81459276132017,61.31826819347534,60.82194362563057,60.3256190577858,59.82929448994097,59.332969922096154,58.836645354251424,58.34032078640661,57.843996218561784,57.34767165071702,56.85134708287224,56.355022515027414,55.858697947182634,55.36237337933786,54.866048811493044,54.36972424364822,53.8733996758035,53.377075107958674,52.88075054011385,52.384425972269085,51.888101404424305,51.39177683657948,50.895452268734715,50.399127700889935,49.90280313304511,49.40647856520034,48.910153997355565,48.41382942951074,47.91750486166592,47.42118029382119,46.92485572597637,46.42853115813155,45.93220659028678,45.435882022442,44.939557454597185,44.44323288675241,43.94690831890763,43.45058375106281,42.954259183217985,42.45793461537326,41.96161004752844,41.46528547968362,40.96896091183885,40.472636343994076,39.97631177614925,39.47998720830448,38.983662640459706,38.48733807261488,37.99101350477011,37.494688936925336,36.99836436908051,36.50203980123569,36.00571523339096,35.50939066554615,35.013066097701326,34.516741529856546,34.02041696201177,33.524092394166956,33.03027523754526,32.558188597755006,32.0861019579647,31.61401531817444,31.141928678384183,30.669842038593877,30.197755398803576,29.725668759013317,29.25358211922305,28.853349717237784,28.596825790862525,28.34030186448727,28.083777938111997,27.82725401173674,27.570730085361486,27.31420615898621,27.057682232610933,26.8011583062357,26.544634379860426,26.288110453485146,26.039819370779067,25.794479720166496,25.549140069553907,25.303800418941343,25.058460768328775,24.813121117716182,24.567781467103618,24.32244181649105,24.077102165878458,23.831762515265865,23.5864228646533,23.341083214040736,23.09574356342814,22.850403912815576,22.60506426220301,22.359724611590416,22.11438496097785,21.869045310365284,21.623705659752694,21.3783660091401,21.13302635852756,20.88768670791497,20.642347057302377,20.39700740668981,20.15166775607724,19.906328105464652,19.660988454852085,19.415648804239517,19.170309153626928,18.92496950301436,18.679629852401792,18.434290201789203,18.188950551176614,17.943610900564043,17.69827124995148,17.452931599338886,17.207591948726318,16.962252298113754,16.71691264750116,16.471572996888593,16.226233346276025,15.980893695663436,15.735554045050847,15.4902143944383,15.244874743825712,14.999535093213119,14.754195442600553,14.508855791987987,14.263516141375398,14.018176490762828,13.772836840150259,13.52749718953767,13.282157538925103,13.036817888312534,12.791478237699945,12.546138587087356,12.30079893647481,12.05545928586222,11.810119635249631,11.564779984637061,11.319440334024495,11.074100683411906,10.828761032799337,10.583421382186769,10.33808173157418,10.092742080961589,9.847402430349044,9.602062779736455,9.356723129123864,9.111383478511296,8.866043827898729,8.62070417728614,8.4059292984728,8.343978278655452,8.282027258838102,8.220076239020754,8.158125219203418,8.09617419938607,8.034223179568722,7.972272159751383,7.910321139934035,7.848370120116686,7.786573468592118,7.727455600648254,7.668337732704391,7.609219864760528,7.550101996816675,7.490984128872813,7.431866260928949,7.3727483929850965,7.313630525041234,7.254512657097371,7.195394789153518,7.136276921209655,7.0771590532657935,7.01804118532194,6.958923317378077,6.899805449434215,6.840687581490351,6.781569713546499,6.722451845602635,6.6633339776587714,6.60421610971492,6.545098241771057,6.485980373827194,6.426862505883342,6.367744637939479,6.308626769995616,6.249508902051752,6.1903910341079005,6.1312731661640365,6.072155298220174,6.013037430276322,5.953919562332459,5.909897430262566,5.876657966674083,5.8434185030855925,5.810179039497104,5.776939575908621,5.743700112320131,5.710460648731642,5.677221185143153,5.643981721554669,5.61074225796618,5.57750279437769,5.544263330789207,5.511023867200717,5.477784403612227,5.444544940023745,5.411305476435255,5.378066012846766,5.3448265492582765,5.311587085669793,5.278347622081304,5.2451081584928145,5.2118686949043305,5.178629231315842,5.145389767727352,5.1121503041388685,5.078910840550379,5.04567137696189,5.0124319133734065,4.979192449784917,4.945952986196428,4.912713522607938,4.879326593716751,4.8447725912287405,4.810218588740729,4.775664586252724,4.741110583764712,4.7065565812767005,4.672002578788695,4.6374485763006845,4.602894573812673,4.568340571324661,4.533786568836656],[58.77282493110391,58.82738823750148,58.88195154389905,58.93651485029662,58.991078156694186,59.04564146309176,59.100204769489324,59.15476807588689,59.20933138228447,59.263894688682036,59.31845799507961,59.37302130147717,59.42758460787475,59.48214791427232,59.536711220669886,59.591274527067455,59.64583783346502,59.70040113986259,59.75496444626016,59.80952775265773,59.8640910590553,59.918654365452866,59.973217671850435,60.02778097824802,60.08234428464557,60.13690759104315,60.19147089744072,60.24603420383828,60.30059751023586,60.35516081663343,60.409724123031,60.46428742942857,60.51885073582613,60.573446407427646,60.62810680913197,60.6827672108363,60.73742761254062,60.79208801424495,60.84674841594927,60.9014088176536,60.95606921935793,61.01072962106225,61.06539002276658,61.1200504244709,61.17471082617522,61.229371227879554,61.28403162958387,61.338692031288204,61.393352432992515,61.44801283469685,61.50267323640118,61.5573336381055,61.61199403980983,61.666654441514154,61.72131484321847,61.77597524492279,61.83063564662712,61.885296048331455,61.939956450035766,61.9946168517401,62.04927725344443,62.10393765514875,62.15859805685307,62.213258458557405,62.26791886026172,62.32257926196605,62.37723966367037,62.43190006537469,62.48656046707902,62.54122086878335,62.59588127048768,62.650541672192,62.705202073896324,62.75986247560065,62.814522877304974,62.8691832790093,62.92384368071363,62.97850408241794,63.03316448412228,63.08782488582659,63.142485287530924,63.19714568923524,63.25180609093957,63.3064664926439,63.35264891804246,63.39713574817986,63.441622578317265,63.486109408454666,63.53059623859207,63.57508306872948,63.61956989886688,63.66405672900429,63.70854355914169,63.75303038927909,63.797517219416505,63.8420040495539,63.88649087969131,63.93097770982871,63.975464539966126,64.01995137010353,64.06443820024093,64.10892503037833,64.15341186051575,64.19789869065315,64.24238552079055,64.28687235092795,64.33135918106535,64.37584601120275,64.42033284134016,64.46481967147756,64.50930650161497,64.55379333175237,64.59828016188978,64.64276699202718,64.68725382216459,64.731740652302,64.7762274824394,64.8207143125768,64.8652011427142,64.9096879728516,64.95417480298902,64.9986616331264,65.04314846326382,65.08763529340123,65.13212212353864,65.17660895367604,65.22109578381342,65.26558261395084,65.31006944408824,65.35455627422564,65.39904310436305,65.44352993450046,65.48801676463786,65.53250359477526,65.57678388529364,65.620651094627,65.66451830396034,65.70838551329369,65.75225272262703,65.79611993196039,65.83998714129375,65.88385435062709,65.92772155996045,65.9715887692938,66.01545597862714,66.0593231879605,66.10319039729384,66.1470576066272,66.19092481596056,66.2347920252939,66.27865923462726,66.32252644396061,66.36639365329395,66.4102608626273,66.45412807196065,66.49799528129401,66.54186249062735,66.58572969996071,66.62959690929407,66.67346411862741,66.71733132796076,66.76119853729412,66.80506574662746,66.84893295596082,66.89280016529418,66.93666737462752,66.98053458396087,67.02077511686707,67.05920231155969,67.0976295062523,67.13605670094493,67.17448389563754,67.21291109033015,67.25133828502278,67.2897654797154,67.32819267440803,67.36661986910063,67.40504706379326,67.44347425848588,67.4819014531785,67.52032864787111,67.55875584256373,67.59718303725634,67.63561023194896,67.67403742664158,67.7124646213342,67.75089181602682,67.78931901071942,67.82774620541207,67.86617340010467,67.90460059479729,67.94302778948992,67.98145498418253,68.01988217887515,68.05830937356777,68.09673656826038,68.135163762953,68.17359095764563,68.21201815233823,68.25044534703086,68.28887254172346,68.3272997364161,68.36572693110871,68.40415412580133,68.44258132049396,68.48100851518657,68.51943570987919,68.5578629045718,68.59629009926442,68.63471729395704,68.67314448864965,68.71157168334229,68.7499988780349,68.78842607272752,68.82685326742012,68.86528046211275,68.90370765680537,68.942134851498,68.98056204619061,69.01898924088322,69.05741643557585,69.09584363026846,69.13427082496108,69.17269801965371,69.21112521434631,69.24955240903893,69.28797960373156,69.32640679842417,69.36483399311679,69.4032611878094,69.44168838250204,69.48011557719464,69.51854277188727,69.55696996657987,69.5953971612725,69.63404318830865,69.67307216832175,69.71210114833482,69.75113012834792,69.79015910836101,69.8291880883741,69.86821706838718,69.90724604840028,69.94627502841337,69.98530400842645,70.02433298843954,70.06336196845263,70.10239094846573,70.1414199284788,70.1804489084919,69.95180111457603,69.4554765467312,68.95915197888642,68.46282741104166,67.96650284319684,67.47017827535207,66.97385370750729,66.47752913966247,65.98120457181766,65.48488000397292,64.9885554361281,64.49223086828327,63.995906300438506,63.49958173259373,63.0032571647489,62.506932596904136,62.01060802905936,61.51428346121453,61.01795889336976,60.52163432552499,60.02530975768017,59.52898518983535,59.03266062199063,58.5363360541458,58.040011486300976,57.54368691845621,57.04736235061143,56.55103778276661,56.05471321492183,55.55838864707706,55.06206407923224,54.56573951138742,54.06941494354269,53.56655556481144,53.06206243416338,52.557569303515365,52.05307617286736,51.5485830422193,51.04408991157129,50.53959678092328,50.03510365027523,49.53061051962722,49.0261173889792,48.521624258331144,48.017131127683086,47.51263799703512,47.00814486638707,46.50365173573901,45.999158605091,45.49466547444299,44.99017234379493,44.485679213146916,43.98118608249891,43.47669295185085,42.97219982120279,42.467706690554834,41.96321355990678,41.45872042925872,40.95422729861071,40.4497341679627,39.945241037314645,39.44074790666663,38.93625477601863,38.43176164537057,37.927268514722556,37.42277538407455,36.91828225342648,36.41378912277843,35.90929599213047,35.40480286148241,34.90030973083436,34.39581660018635,33.891323469538335,33.38683033889028,32.88233720824227,32.37784407759426,31.8733509469462,31.36885781629819,30.864364685650177,30.359871555002123,29.85537842435407,29.350885293706057,28.846392163058045,28.4285815772061,28.184136080946327,27.939690584686556,27.69524508842676,27.45079959216699,27.206354095907223,26.961908599647423,26.717463103387633,26.473017607127886,26.228572110868086,25.984126614608297,25.739681118348525,25.495235622088753,25.25079012582896,25.006344629569185,24.76189913330942,24.51745363704962,24.273008140789855,24.028562644530084,23.784117148270287,23.539671652010494,23.295226155750722,23.050780659490954,22.806335163231157,22.56188966697139,22.317444170711617,22.07299867445182,21.828553178192053,21.58410768193228,21.339662185672488,21.09521668941269,20.85077119315294,20.606325696893155,20.361880200633355,20.117434704373586,19.87298920811381,19.62854371185402,19.38409821559425,19.139652719334478,18.895207223074685,18.65076172681491,18.406316230555138,18.161870734295345,17.917425238035552,17.672979741775784,17.428534245516012,17.18408874925622,16.939643252996447,16.695197756736675,16.450752260476882,16.20630676421711,15.961861267957339,15.717415771697546,15.472970275437753,15.228524779178002,14.98407928291821,14.739633786658416,14.495188290398644,14.250742794138873,14.00629729787908,13.761851801619308,13.517406305359536,13.272960809099743,13.028515312839971,12.7840698165802,12.539624320320407,12.295178824060613,12.050733327800865,11.80628783154107,11.561842335281277,11.324187449425366,11.091201132954003,10.858214816482619,10.625228500011255,10.392242183539892,10.159255867068506,9.926269550597121,9.69328323412578,9.460296917654395,9.227310601183008,8.994324284711645,8.761337968240282,8.528351651768897,8.324432073574036,8.265846186761532,8.20726029994903,8.148674413136527,8.090088526324035,8.031502639511533,7.97291675269903,7.914330865886538,7.855744979074036,7.797159092261532,7.738573205449041,7.679987318636537,7.621401431824035,7.562815545011531,7.50422965819904,7.445643771386537,7.387057884574034,7.328471997761542,7.26988611094904,7.2113002241365365,7.152714337324044,7.094128450511542,7.035542563699039,6.976956676886546,6.918370790074045,6.8597849032615414,6.801199016449038,6.7426131296365455,6.684027242824043,6.625441356011541,6.566855469199048,6.508269582386546,6.449683695574043,6.39109780876155,6.332511921949049,6.273926035136546,6.215340148324042,6.156754261511551,6.098168374699048,6.0391996216065476,5.980081753662695,5.920963885718832,5.876941753648939,5.843702290060455,5.810462826471966,5.777350567968172,5.74439570008932,5.711440832210459,5.6784859643316,5.645531096452741,5.612576228573887,5.579621360695027,5.5466664928161675,5.513711624937314,5.480756757058454,5.447801889179595,5.414847021300742,5.381892153421882,5.348937285543022,5.315982417664163,5.283027549785309,5.250072681906449,5.21711781402759,5.184162946148737,5.151208078269877,5.118253210391018,5.085298342512164,5.052343474633305,5.019388606754445,4.986433738875592,4.953478870996731,4.920524003117872,4.887569135239012,4.854614267360159,4.8216593994813,4.78870453160244,4.755749663723586,4.7227947958447265,4.689839927965867,4.6568850600870135,4.623930192208154,4.590975324329294,4.558020456450435,4.525065588571581],[59.001427608553556,59.055990914951124,59.11055422134869,59.16511752774626,59.21968083414383,59.2742441405414,59.32880744693897,59.383370753336536,59.43793405973412,59.49249736613169,59.547060672529255,59.601623978926824,59.65618728532439,59.71075059172196,59.76531389811953,59.8198772045171,59.87444051091467,59.929003817312235,59.983567123709804,60.03813043010739,60.09269373650494,60.14725704290251,60.201820349300085,60.25638365569766,60.31094696209522,60.3655102684928,60.42007357489037,60.47463688128793,60.529200187685504,60.58376349408307,60.63832680048064,60.69289010687821,60.74745341327578,60.802016719673354,60.856580026070915,60.911143332468484,60.96570663886606,61.02026994526362,61.074833251661204,61.129396558058765,61.18395986445634,61.23852317085391,61.29308647725148,61.34764978364905,61.402213090046615,61.456776396444184,61.51133970284175,61.56590300923932,61.62046631563689,61.67502962203446,61.729673841273325,61.78433424297766,61.838994644681975,61.8936550463863,61.948315448090625,62.00297584979495,62.05763625149928,62.1122966532036,62.166957054907925,62.22161745661225,62.276277858316575,62.3309382600209,62.38559866172523,62.44025906342956,62.494919465133876,62.54957986683821,62.604240268542526,62.65890067024685,62.71356107195118,62.7682214736555,62.82288187535983,62.87754227706416,62.932202678768476,62.9868630804728,63.041523482177126,63.09618388388146,63.15084428558578,63.2055046872901,63.26016508899443,63.31482549069875,63.369485892403084,63.4241462941074,63.47880669581173,63.53346709751606,63.57964952291461,63.624136353052016,63.668623183189425,63.713110013326826,63.75759684346423,63.80208367360163,63.84657050373904,63.89105733387645,63.93554416401385,63.98003099415125,64.02451782428865,64.06900465442605,64.11349148456347,64.15797831470087,64.20246514483827,64.24695197497567,64.29143880511309,64.33592563525049,64.38041246538789,64.4248992955253,64.4693861256627,64.51387295580011,64.55835978593751,64.60284661607491,64.64733344621231,64.69182027634972,64.73630710648712,64.78079393662452,64.82528076676194,64.86976759689934,64.91425442703674,64.95874125717415,65.00322808731154,65.04771491744896,65.09168539746307,65.13555260679642,65.17941981612977,65.22328702546312,65.26715423479646,65.3110214441298,65.35488865346318,65.39875586279652,65.44262307212988,65.48649028146322,65.53035749079658,65.57422470012993,65.61809190946329,65.66195911879663,65.70582632812999,65.74969353746333,65.79356074679669,65.83742795613003,65.88129516546338,65.92516237479674,65.96902958413008,66.01289679346344,66.0567640027968,66.10063121213014,66.1444984214635,66.18836563079684,66.2322328401302,66.27610004946354,66.31996725879691,66.36383446813025,66.40770167746359,66.45156888679695,66.4954360961303,66.53930330546365,66.58317051479699,66.62703772413036,66.6709049334637,66.71477214279706,66.75863935213042,66.80250656146376,66.8463737707971,66.89024098013047,66.93410818946381,66.97797539879716,67.02184260813051,67.06570981746385,67.10957702679723,67.15344423613057,67.19731144546392,67.23755197837012,67.27597917306274,67.31440636775535,67.35283356244798,67.3912607571406,67.42968795183322,67.46811514652583,67.50654234121843,67.54496953591106,67.58339673060368,67.6218239252963,67.66025111998891,67.69867831468154,67.73710550937416,67.77553270406678,67.81395989875938,67.85238709345201,67.89081428814464,67.92924148283726,67.96766867752987,68.00609587222249,68.0445230669151,68.08295026160772,68.12137745630034,68.15980465099295,68.19823184568557,68.2366590403782,68.2750862350708,68.31351342976342,68.35194062445605,68.39036781914866,68.42879501384128,68.46722220853391,68.50564940322651,68.54407659791913,68.58250379261176,68.62093098730438,68.65935818199699,68.69778537668961,68.73621257138223,68.77463976607484,68.81306696076747,68.85149415546007,68.8899213501527,68.92834854484533,68.96677573953795,69.00520293423057,69.04363012892317,69.0820573236158,69.12048451830842,69.15891171300103,69.19733890769365,69.23576610238626,69.27419329707888,69.31262049177151,69.35104768646411,69.38947488115674,69.42790207584935,69.46632927054198,69.5047564652346,69.54318365992722,69.58161085461984,69.62003804931246,69.65846524400506,69.69689243869769,69.73465033548445,69.77173892983753,69.80882752419062,69.8459161185437,69.88300471289678,69.92009330724986,69.95718190160294,69.99427049595603,70.03135909030911,70.0684476846622,70.10553627901527,70.14262487336836,70.17971346772144,70.21680206207452,70.25389065642761,70.2909792507807,70.32806784513377,70.36515643948685,70.12467362956603,69.60661941537131,69.08856520117664,68.57051098698196,68.05245677278724,67.53440255859256,67.01634834439788,66.49829413020316,65.98023991600843,65.46218570181381,64.94413148761909,64.42607727342437,63.908023059229684,63.38996884503501,62.871914630840294,62.35386041664562,61.83580620245094,61.31775198825622,60.79969777406154,60.281643559866865,59.763589345672145,59.24553513147741,58.72748091728279,58.209426703088056,57.69137248889334,57.17852195476931,56.674028824121294,56.169535693473236,55.66504256282523,55.16054943217722,54.65605630152916,54.15156317088109,53.64707004023314,53.142576909585074,52.63808377893702,52.13359064828901,51.629097517641,51.124604386992935,50.62011125634493,50.11561812569691,49.611124995048854,49.10663186440085,48.60213873375284,48.09764560310479,47.59315247245674,47.088659341808764,46.58416621116071,46.079673080512656,45.57517994986465,45.07068681921663,44.566193688568575,44.06170055792057,43.55720742727256,43.0527142966245,42.548221165976436,42.043728035328485,41.53923490468041,41.034741774032355,40.530248643384354,40.02575551273634,39.52126238208829,39.01676925144028,38.512276120792265,38.007782990144214,37.5032898594962,36.99879672884819,36.494303598200126,35.989810467552076,35.48531733690411,34.98082420625605,34.476331075608,33.97183794495999,33.46734481431198,32.96285168366392,32.45835855301591,31.9538654223679,31.449372291719843,30.94487916107183,30.440386030423824,29.935892899775766,29.431399769127708,28.9269066384797,28.42241350783169,28.00460292197974,27.76015742571997,27.5157119294602,27.271266433200402,27.026820936940634,26.782375440680863,26.537929944421066,26.293484448161273,26.049038951901526,25.80459345564173,25.560147959381936,25.315702463122168,25.071256966862396,24.826811470602603,24.58236597434283,24.337920478083063,24.093474981823267,23.84902948556349,23.604583989303723,23.36013849304393,23.115692996784137,22.871247500524365,22.626802004264594,22.3823565080048,22.137911011745032,21.893465515485257,21.649020019225464,21.404574522965696,21.160129026705924,20.91568353044613,20.671238034186334,20.426792537926584,20.182347041666794,19.937901545406998,19.69345604914723,19.449010552887454,19.20456505662766,18.960119560367893,18.71567406410812,18.47122856784833,18.234937889784735,18.00195157331337,17.768965256841987,17.5359789403706,17.302992623899236,17.070006307427875,16.837019990956488,16.604033674485127,16.37104735801376,16.13806104154238,15.905074725071014,15.67208840859965,15.439102092128266,15.20611577565688,14.97312945918554,14.740143142714155,14.50715682624277,14.274170509771409,14.041184193300044,13.808197876828658,13.575211560357294,13.342225243885931,13.109238927414548,12.876252610943183,12.643266294471818,12.410279978000434,12.177293661529049,11.944307345057709,11.711321028586323,11.478334712114938,11.245348395643575,11.01236207917221,10.779375762700827,10.546389446229462,10.313403129758099,10.080416813286714,9.84743049681533,9.614444180343988,9.381457863872601,9.148471547401217,8.915485230929853,8.68249891445849,8.449512597987106,8.245593019792244,8.18700713297974,8.128421246167237,8.069835359354736,8.011249472542243,7.952663585729741,7.894077698917237,7.835491812104746,7.776905925292244,7.718320038479741,7.659734151667249,7.6011482648547455,7.542562378042243,7.483976491229739,7.425390604417248,7.3668047176047455,7.308218830792242,7.249632943979751,7.191047057167248,7.132461170354745,7.073875283542252,7.0152893967297505,6.956703509917246,6.8981176231047545,6.839531736292252,6.78233492345018,6.726452102063923,6.670569280677677,6.61468645929142,6.558803637905163,6.502920816518917,6.447037995132661,6.391155173746404,6.335272352360159,6.279389530973901,6.223506709587644,6.167623888201388,6.111741066815141,6.055858245428885,5.999975424042629,5.944092602656382,5.888209781270126,5.846463190653429,5.814813907729279,5.7831646248051225,5.751515341880967,5.719866058956816,5.688216776032659,5.656567493108504,5.624918210184347,5.593268927260198,5.561619644336041,5.529970361411884,5.498321078487733,5.4666717955635775,5.435022512639421,5.40337322971527,5.371723946791114,5.340074663866958,5.307573123460746,5.274618255581893,5.241663387703033,5.2087085198241745,5.17575365194532,5.142798784066461,5.109843916187602,5.076889048308748,5.043934180429888,5.0109793125510285,4.978024444672174,4.9450695767933155,4.912114708914455,4.879159841035596,4.846204973156743,4.813250105277883,4.780295237399024,4.74734036952017,4.71438550164131,4.681430633762451,4.648475765883598,4.615520898004737,4.582566030125879,4.549611162247018,4.516656294368165],[59.23003028600319,59.28459359240076,59.33915689879833,59.3937202051959,59.44828351159347,59.50284681799104,59.5574101243886,59.61197343078618,59.666536737183755,59.72110004358132,59.77566334997889,59.83022665637645,59.88478996277403,59.9393532691716,59.993916575569166,60.048479881966735,60.1030431883643,60.15760649476187,60.21216980115945,60.266733107557016,60.321296413954585,60.37585972035215,60.43042302674972,60.48498633314729,60.53954963954486,60.594112945942435,60.648676252339996,60.703239558737565,60.75780286513514,60.81236617153271,60.86692947793028,60.921492784327846,60.97605609072541,61.03061939712298,61.08518270352055,61.13974600991812,61.19430931631569,61.24887262271326,61.30343592911083,61.357999235508395,61.41256254190598,61.46712584830354,61.521689154701114,61.57625246109868,61.63081576749625,61.68537907389382,61.73994238029139,61.79450568668896,61.849068993086526,61.903632299484094,61.95819560588167,62.01275891227924,62.0673222186768,62.12188552507437,62.17644883147194,62.23101213786951,62.28557544426708,62.34013875066465,62.39470205706222,62.449265363459794,62.50382866985736,62.55839197625493,62.6129552826525,62.66751858905007,62.722081895447644,62.77664520184521,62.83124087341468,62.885901275119004,62.94056167682333,62.995222078527654,63.049882480231986,63.104542881936304,63.15920328364063,63.21386368534496,63.26852408704928,63.32318448875361,63.37784489045793,63.432505292162254,63.48716569386659,63.541826095570904,63.59648649727523,63.651146898979555,63.70580730068388,63.760467702388205,63.80665012778676,63.85113695792417,63.89562378806157,63.94011061819898,63.98459744833638,64.02908427847379,64.07357110861119,64.11805793874859,64.162544768886,64.20703159902341,64.25151842916081,64.2960052592982,64.34049208943561,64.38497891957302,64.42946574971043,64.47395257984783,64.51843940998523,64.56271970029913,64.60658690963248,64.65045411896584,64.69432132829918,64.73818853763254,64.78205574696588,64.82592295629924,64.8697901656326,64.91365737496594,64.95752458429929,65.00139179363265,65.04525900296599,65.08912621229935,65.1329934216327,65.17686063096605,65.2207278402994,65.26459504963275,65.3084622589661,65.35232946829944,65.3961966776328,65.44006388696616,65.4839310962995,65.52779830563286,65.57166551496621,65.61553272429956,65.65939993363291,65.70326714296627,65.74713435229961,65.79100156163297,65.83486877096632,65.87873598029967,65.92260318963301,65.96647039896636,66.01033760829972,66.05420481763306,66.09807202696642,66.14193923629978,66.18580644563312,66.22967365496648,66.27354086429983,66.31740807363317,66.36127528296653,66.40514249229987,66.44900970163323,66.49287691096657,66.53674412029994,66.58061132963329,66.62447853896663,66.66834574829998,66.71221295763334,66.7560801669667,66.79994737630004,66.8438145856334,66.88768179496674,66.9315490043001,66.97541621363344,67.0192834229668,67.06315063230015,67.10701784163349,67.15088505096685,67.19475226030019,67.23861946963356,67.2824866789669,67.32635388830025,67.3702210976336,67.41408830696696,67.45432883987314,67.49275603456577,67.53118322925839,67.569610423951,67.60803761864362,67.64646481333624,67.68489200802887,67.72331920272148,67.7617463974141,67.80017359210672,67.83860078679933,67.87702798149195,67.91545517618457,67.95388237087718,67.99230956556981,68.03073676026243,68.06916395495504,68.10759114964766,68.14601834434029,68.18444553903291,68.22287273372552,68.26129992841814,68.29972712311076,68.33815431780337,68.37658151249599,68.41500870718862,68.45343590188124,68.49186309657385,68.53029029126647,68.5687174859591,68.60714468065171,68.64557187534433,68.68399907003695,68.72225894152768,68.75934753588078,68.79643613023386,68.83352472458694,68.87061331894002,68.9077019132931,68.94479050764619,68.98187910199927,69.01896769635235,69.05605629070544,69.09314488505852,69.1302334794116,69.16732207376468,69.20441066811777,69.24149926247085,69.27858785682393,69.31567645117701,69.3527650455301,69.38985363988319,69.42694223423626,69.46403082858936,69.50111942294242,69.53820801729552,69.57529661164861,69.61238520600168,69.64947380035477,69.68656239470785,69.72365098906093,69.76073958341401,69.7978281777671,69.83491677212018,69.87200536647326,69.90909396082634,69.94618255517942,69.98327114953251,70.02035974388559,70.05744833823867,70.09453693259175,70.13162552694484,70.16871412129792,70.20580271565102,70.2428913100041,70.27997990435716,70.31706849871024,70.35415709306335,70.39124568741643,70.42833428176951,70.46542287612259,70.50251147047567,70.53960006482875,70.29911725490794,69.7810630407132,69.26300882651853,68.74495461232385,68.22690039812913,67.70884618393447,67.19079196973979,66.67273775554506,66.15468354135034,65.6366293271557,65.11857511296098,64.60052089876626,64.08246668457159,63.56441247037691,63.04635825618219,62.52830404198751,62.01024982779283,61.49219561359811,60.974141399403436,60.456087185208766,59.93803297101403,59.41997875681931,58.90192454262469,58.383870328429964,57.86581611423523,57.34776190004056,56.82970768584588,56.31165347165117,55.79359925745649,55.275545043261815,54.757490829067095,54.23943661487236,53.72138240067774,53.20332818648301,52.685273972288286,52.16721975809361,51.64916554389893,51.13111132970421,50.613057115509534,50.09500290131486,49.57694868712014,49.05889447292546,48.54084025873078,48.02278604453606,47.504731830341335,46.98667761614671,46.46862340195199,45.95056918775727,45.43251497356258,44.91446075936791,44.396406545173186,43.878352330978515,43.36029811678384,42.84224390258911,42.324189688394384,41.806135474199756,41.288081260005036,40.77002704581031,40.25197283161563,39.733918617420954,39.215864403226234,38.69781018903156,38.17975597483689,37.66170176064216,37.14364754644748,36.625593332252805,36.107539118058085,35.589484903863365,35.07143068966873,34.55684555102972,34.05235242038166,33.54785928973365,33.04336615908564,32.538873028437585,32.03437989778958,31.529886767141566,31.025393636493504,30.52090050584549,30.01640737519748,29.511914244549423,29.00742111390137,28.50292798325336,27.998434852605346,27.5806242667534,27.33617877049363,27.091733274233857,26.84728777797406,26.60284228171429,26.358396785454524,26.113951289194727,25.86950579293493,25.625060296675187,25.38061480041539,25.145688330144083,24.91270201367272,24.67971569720136,24.446729380729973,24.213743064258612,23.980756747787247,23.74777043131586,23.5147841148445,23.281797798373137,23.04881148190175,22.81582516543036,22.582838848959003,22.34985253248764,22.116866216016252,21.88387989954489,21.65089358307353,21.417907266602143,21.18492095013078,20.951934633659416,20.71894831718803,20.485962000716643,20.252975684245307,20.019989367773917,19.78700305130253,19.554016734831173,19.321030418359808,19.08804410188842,18.85505778541706,18.622071468945695,18.38908515247431,18.15609883600295,17.923112519531582,17.6901262030602,17.457139886588813,17.224153570117448,16.991167253646086,16.7581809371747,16.52519462070334,16.292208304231973,16.059221987760587,15.826235671289226,15.59324935481786,15.360263038346478,15.127276721875091,14.894290405403751,14.661304088932367,14.42831777246098,14.195331455989617,13.962345139518254,13.72935882304687,13.496372506575504,13.263386190104143,13.030399873632758,12.797413557161395,12.56442724069003,12.331440924218645,12.09845460774726,11.865468291275917,11.632481974804534,11.399495658333148,11.166509341861783,10.933523025390421,10.700536708919037,10.467550392447674,10.23456407597631,10.001577759504926,9.768591443033541,9.535605126562197,9.302618810090815,9.069632493619428,8.836646177148065,8.603659860676702,8.370673544205317,8.166753966010456,8.108168079197952,8.049582192385449,7.990996305572947,7.932410418760455,7.873824531947951,7.815238645135448,7.756878012061325,7.700995190675068,7.645112369288811,7.5892295479025655,7.533346726516308,7.477463905130053,7.421581083743796,7.365698262357549,7.309815440971293,7.253932619585036,7.198049798198789,7.142166976812533,7.086284155426276,7.030401334040031,6.974518512653773,6.918635691267517,6.8627528698812705,6.806870048495014,6.750987227108757,6.6951044057225015,6.639221584336255,6.583338762949998,6.5274559415637405,6.471573120177495,6.4156902987912385,6.359807477404981,6.303924656018736,6.248041834632479,6.192159013246222,6.136276191859966,6.080393370473719,6.024510549087463,5.968627727701206,5.912744906314959,5.856862084928703,5.815115494312007,5.783466211387856,5.7518169284636995,5.720167645539544,5.688518362615393,5.656869079691237,5.62521979676708,5.593570513842925,5.561921230918774,5.530271947994618,5.498622665070461,5.4669733821463105,5.435324099222154,5.403674816297999,5.372025533373847,5.340376250449692,5.308726967525535,5.2770776846013785,5.245428401677228,5.213779118753072,5.182129835828916,5.1504805529047655,5.118831269980609,5.087181987056454,5.055532704132302,5.023883421208146,4.99223413828399,4.960584855359839,4.928935572435683,4.897286289511527,4.86563700658737,4.83398772366322,4.802338440739065,4.770689157814908,4.738931075316754,4.705976207437894,4.6730213395590345,4.640066471680181,4.607111603801322,4.574156735922462,4.541201868043602,4.508247000164749],[59.45863296345283,59.5131962698504,59.56775957624796,59.62232288264553,59.6768861890431,59.73144949544068,59.78601280183824,59.84057610823581,59.895139414633384,59.94970272103095,60.00426602742853,60.05882933382609,60.11339264022366,60.16795594662123,60.222519253018795,60.27708255941637,60.33164586581394,60.38620917221151,60.44077247860908,60.495335785006645,60.549899091404214,60.60446239780179,60.65902570419935,60.71358901059693,60.76815231699449,60.822715623392064,60.87727892978963,60.9318422361872,60.98640554258477,61.04096884898234,61.09553215537991,61.15009546177749,61.204658768175044,61.25922207457263,61.31378538097018,61.36834868736775,61.42291199376533,61.477475300162894,61.53203860656047,61.58660191295804,61.64116521935561,61.695728525753175,61.750291832150744,61.80485513854831,61.85941844494588,61.91398175134345,61.96854505774102,62.023108364138594,62.07767167053616,62.13223497693373,62.186798283331306,62.241361589728875,62.29592489612644,62.350488202524005,62.405051508921574,62.45961481531915,62.51417812171672,62.568741428114286,62.623304734511855,62.67786804090942,62.73243134730699,62.78699465370456,62.841557960102136,62.896121266499705,62.95068457289727,63.00524787929484,63.05981118569241,63.11437449208997,63.16893779848755,63.223501104885116,63.278064411282685,63.33262771768025,63.38719102407783,63.4417543304754,63.496317636872966,63.550880943270535,63.6054442496681,63.66000755606567,63.71457086246325,63.769134168860816,63.823697475258385,63.878260781655946,63.93282408805352,63.98746830726036,64.03365073265891,64.07762121246856,64.1214884218019,64.16535563113526,64.20922284046861,64.25309004980195,64.29695725913531,64.34082446846865,64.38469167780201,64.42855888713535,64.47242609646871,64.51629330580207,64.56016051513542,64.60402772446876,64.64789493380212,64.69176214313546,64.73562935246882,64.77949656180218,64.82336377113552,64.86723098046888,64.91109818980222,64.95496539913557,64.99883260846892,65.04269981780227,65.08656702713563,65.13043423646897,65.17430144580233,65.21816865513568,65.26203586446903,65.30590307380238,65.34977028313574,65.39363749246908,65.43750470180244,65.48137191113578,65.52523912046914,65.56910632980248,65.61297353913584,65.6568407484692,65.70070795780254,65.74457516713589,65.78844237646925,65.83230958580259,65.87617679513595,65.92004400446929,65.96391121380265,66.007778423136,66.05164563246936,66.0955128418027,66.13938005113604,66.1832472604694,66.22711446980276,66.2709816791361,66.31484888846946,66.35871609780281,66.40258330713615,66.44645051646951,66.49031772580287,66.53418493513621,66.57805214446955,66.62191935380291,66.66578656313627,66.70965377246962,66.75352098180298,66.79738819113632,66.84125540046966,66.88512260980302,66.92898981913638,66.97285702846973,67.01672423780307,67.06059144713642,67.10445865646977,67.14832586580312,67.19219307513647,67.23606028446983,67.27992749380317,67.32379470313653,67.36766191246988,67.41152912180323,67.45539633113658,67.49926354046994,67.54313074980328,67.58699795913664,67.63086516847,67.67110570137618,67.70953289606881,67.74695614192402,67.7840447362771,67.82113333063018,67.85822192498327,67.89531051933635,67.93239911368944,67.96948770804251,68.0065763023956,68.04366489674868,68.08075349110176,68.11784208545484,68.15493067980793,68.192019274161,68.22910786851409,68.26619646286719,68.30328505722026,68.34037365157336,68.37746224592642,68.4145508402795,68.4516394346326,68.48872802898566,68.52581662333876,68.56290521769185,68.59999381204491,68.63708240639801,68.6741710007511,68.71125959510417,68.74834818945726,68.78543678381033,68.82252537816342,68.85961397251651,68.89670256686958,68.93379116122267,68.97087975557577,69.00796834992883,69.04505694428192,69.082145538635,69.11923413298808,69.15632272734118,69.19341132169426,69.23049991604734,69.26758851040043,69.3046771047535,69.34176569910659,69.37885429345967,69.41594288781275,69.45303148216584,69.49012007651892,69.527208670872,69.56429726522508,69.60138585957817,69.63847445393125,69.67556304828433,69.71265164263741,69.7497402369905,69.78682883134357,69.82391742569666,69.86100602004974,69.89809461440284,69.93518320875592,69.972271803109,70.00936039746207,70.04644899181517,70.08353758616823,70.12062618052133,70.1577147748744,70.1948033692275,70.23189196358058,70.26898055793366,70.30606915228674,70.34315774663983,70.3802463409929,70.41733493534599,70.45442352969907,70.49151212405215,70.52860071840526,70.56568931275832,70.6027779071114,70.6398665014645,70.67695509581758,70.71404369017066,70.47356088024983,69.9555066660551,69.43745245186044,68.91939823766575,68.40134402347103,67.88328980927636,67.36523559508169,66.84718138088695,66.32912716669223,65.81107295249761,65.29301873830289,64.77496452410816,64.25691030991348,63.73885609571881,63.220801881524096,62.702747667329405,62.18469345313474,61.66663923894001,61.14858502474533,60.63053081055067,60.11247659635595,59.594422382161206,59.07636816796659,58.55831395377186,58.04025973957714,57.52220552538246,57.00415131118779,56.48609709699306,55.968042882798386,55.44998866860371,54.93193445440899,54.41388024021426,53.895826026019634,53.37777181182491,52.85971759763019,52.34166338343551,51.82360916924084,51.30555495504612,50.787500740851435,50.26944652665675,49.75139231246203,49.23333809826735,48.715283884072676,48.197229669877956,47.679175455683236,47.1611212414886,46.64306702729388,46.12501281309916,45.606958598904484,45.08890438470981,44.57085017051509,44.05279595632041,43.53474174212573,43.01668752793101,42.49863331373629,41.98057909954166,41.46252488534693,40.94447067115221,40.42641645695753,39.90558903148358,39.37074180266197,38.83589457384042,38.30104734501886,37.766200116197254,37.2313528873757,36.696505658554145,36.16165842973254,35.62681120091093,35.091963972089424,34.55711674326781,34.022269514446215,33.48742228562466,32.9525750568031,32.417727827981494,31.88288059915994,31.348033370338385,30.813186141516784,30.278338912695226,29.74349168387367,29.208644455052067,28.673797226230462,28.138949997408904,27.604102768587346,27.169992274988378,26.93735525183461,26.704718228680843,26.472081205527054,26.239444182373283,26.006807159219516,25.774170136065727,25.54153311291194,25.308896089758193,25.0762590666044,24.843622043450612,24.610985020296845,24.378347997143077,24.145710973989285,23.913073950835518,23.68043692768175,23.44779990452796,23.21516288137419,22.982525858220427,22.749888835066635,22.517251811912846,22.28461478875908,22.05197776560531,21.81934074245152,21.586703719297752,21.354066696143985,21.121429672990196,20.888792649836425,20.65615562668266,20.42351860352887,20.190881580375077,19.958244557221335,19.725607534067542,19.492970510913754,19.260333487759986,19.027696464606215,18.79505944145243,18.56242241829866,18.329785395144892,18.097148371991096,17.864511348837333,17.631874325683565,17.399237302529777,17.166600279375984,16.933963256222217,16.70132623306845,16.468689209914658,16.23605218676089,16.003415163607123,15.770778140453334,15.538141117299565,15.305504094145798,15.072867070992007,14.840230047838219,14.607593024684471,14.374956001530682,14.142318978376892,13.909681955223125,13.677044932069355,13.444407908915567,13.2117708857618,12.97913386260803,12.746496839454242,12.513859816300473,12.281222793146704,12.048585769992915,11.819763509741096,11.59883694688997,11.377910384038799,11.156983821187628,10.93605725833648,10.715130695485332,10.494204132634161,10.273277569783012,10.052351006931863,9.831424444080694,9.610497881229524,9.389571318378396,9.168644755527225,8.947718192676057,8.726791629824907,8.505865066973758,8.28493850412259,8.091585962212545,8.036103525007883,7.9806210878032235,7.925138650598562,7.869656213393912,7.814173776189252,7.758691338984591,7.7032089017799406,7.64772646457528,7.5922440273706195,7.536761590165969,7.481279152961308,7.425796715756649,7.370314278551986,7.314831841347337,7.259349404142676,7.2038669669380155,7.148384529733366,7.092902092528704,7.037419655324044,6.981937218119393,6.926454780914733,6.870972343710072,6.815489906505423,6.760007469300762,6.704525032096102,6.649042594891441,6.59356015768679,6.5380777204821285,6.482595283277469,6.427112846072818,6.371630408868158,6.316147971663497,6.260665534458847,6.205183097254187,6.149700660049526,6.094218222844865,6.038735785640215,5.983284123202774,5.930387036105836,5.8774899490089085,5.824592861911971,5.784964377622728,5.754813466767554,5.724662555912375,5.6943138763403836,5.662885085567929,5.631456294795468,5.600027504023007,5.568598713250546,5.537169922478091,5.50574113170563,5.474312340933169,5.442883550160714,5.411454759388253,5.380025968615792,5.348597177843336,5.3171683870708755,5.285739596298414,5.254310805525953,5.222882014753498,5.191453223981036,5.160024433208576,5.128595642436121,5.097166851663659,5.0657380608911975,5.034309270118742,5.002880479346281,4.97145168857382,4.940022897801366,4.908594107028904,4.877165316256443,4.845736525483982,4.814307734711527,4.782878943939066,4.751450153166605,4.720021362394149,4.6885925716216885,4.657163780849228,4.625734990076772,4.594306199304311,4.56287740853185,4.531448617759389,4.500019826986934],[59.68247069133622,59.73619596363026,59.7899212359243,59.84364650821834,59.89737178051239,59.95109705280643,60.00482232510047,60.05854759739451,60.11227286968856,60.165998141982605,60.21972341427664,60.27344868657068,60.327173958864726,60.38089923115878,60.43462450345282,60.48834977574686,60.542494065417316,60.59705737181488,60.65162067821245,60.70618398461002,60.76074729100759,60.815310597405166,60.86987390380273,60.924437210200296,60.979000516597864,61.03356382299544,61.08812712939301,61.14269043579057,61.197253742188146,61.25181704858573,61.30638035498329,61.36094366138086,61.41550696777842,61.470070274175995,61.52463358057357,61.57919688697113,61.63376019336871,61.68832349976627,61.742886806163845,61.79745011256141,61.852013418958975,61.90657672535656,61.96114003175412,62.015703338151695,62.070266644549264,62.12482995094683,62.1793932573444,62.23395656374196,62.288519870139524,62.34308317653711,62.397646482934675,62.452209789332244,62.50677309572981,62.56133640212738,62.61589970852496,62.67046301492252,62.7250263213201,62.77958962771766,62.834152934115224,62.8887162405128,62.943279546910375,62.997842853307944,63.05240615970551,63.10696946610308,63.16153277250065,63.21609607889821,63.27065938529578,63.32522269169335,63.379785998090924,63.43434930448849,63.48891261088606,63.54347591728363,63.5980392236812,63.652602530078774,63.70716583647634,63.76172914287391,63.81629244927148,63.87085575566905,63.925419062066624,63.97998236846419,64.03454567486176,64.08910898125933,64.1436722876569,64.19823559405447,64.24388548623185,64.2877526955652,64.33161990489856,64.3754871142319,64.41935432356526,64.4632215328986,64.50708874223196,64.55095595156531,64.59482316089866,64.63869037023201,64.68255757956535,64.72642478889871,64.77029199823207,64.81415920756541,64.85802641689878,64.90189362623212,64.94576083556548,64.98962804489884,65.03349525423218,65.07736246356554,65.12122967289888,65.16509688223223,65.20896409156558,65.25283130089893,65.29669851023229,65.34056571956563,65.38443292889899,65.42830013823234,65.47216734756569,65.51603455689904,65.55990176623239,65.60376897556574,65.64763618489908,65.69150339423244,65.7353706035658,65.77923781289914,65.8231050222325,65.86697223156585,65.9108394408992,65.95470665023255,65.99857385956591,66.04244106889925,66.0863082782326,66.13017548756595,66.1740426968993,66.21790990623266,66.261777115566,66.30564432489936,66.3495115342327,66.39337874356606,66.43724595289942,66.48111316223277,66.52498037156612,66.56884758089947,66.61271479023281,66.65658199956619,66.70044920889953,66.74431641823287,66.78818362756623,66.83205083689958,66.87591804623293,66.91978525556627,66.96365246489962,67.00751967423298,67.05138688356632,67.09525409289968,67.13912130223302,67.18285111243928,67.22589392509384,67.2689367377484,67.31197955040297,67.35502236305753,67.39806517571209,67.44110798836664,67.4841508010212,67.52719361367576,67.57023642633033,67.61327923898489,67.65632205163945,67.69936486429403,67.74240767694857,67.78545048960315,67.8284933022577,67.8672813056568,67.90394190442818,67.94060250319956,67.97726310197092,68.0139237007423,68.05058429951367,68.08724489828505,68.12390549705643,68.16056609582779,68.19722669459915,68.23388729337054,68.2705478921419,68.30720849091328,68.34386908968466,68.38052968845602,68.4171902872274,68.45385088599878,68.49051148477015,68.52717208354153,68.56383268231289,68.60049328108427,68.63715387985565,68.67381447862702,68.71047507739839,68.74713567616976,68.78379627494112,68.82045687371252,68.85711747248388,68.89377807125526,68.93043867002663,68.967099268798,69.00375986756937,69.04042046634075,69.07708106511211,69.1137416638835,69.15040226265486,69.18706286142624,69.22372346019762,69.26038405896898,69.29704465774036,69.33370525651173,69.3703658552831,69.40702645405447,69.44368705282585,69.48034765159723,69.5170082503686,69.55366884913997,69.59038651315466,69.62747510750773,69.66456370186083,69.70165229621391,69.73874089056699,69.77582948492007,69.81291807927316,69.85000667362624,69.88709526797932,69.9241838623324,69.96127245668548,69.99836105103857,70.03544964539167,70.07253823974473,70.10962683409781,70.1467154284509,70.18380402280398,70.22089261715706,70.25798121151016,70.29506980586324,70.33215840021631,70.3692469945694,70.40633558892247,70.44342418327557,70.48051277762865,70.51760137198173,70.5546899663348,70.59177856068789,70.62886715504098,70.66595574939407,70.70304434374715,70.74013293810023,70.77722153245331,70.8143101268064,70.85139872115947,70.88848731551256,70.64800450559173,70.12995029139701,69.61189607720235,69.09384186300767,68.57578764881293,68.05773343461827,67.5396792204236,67.02162500622886,66.50357079203414,65.98551657783952,65.46746236364478,64.94940814945006,64.43135393525539,63.91329972106072,63.39524550686598,62.87719129267131,62.35913707847664,61.841082864281915,61.32302865008724,60.80497443589257,60.28692022169785,59.768866007503114,59.25081179330849,58.73275757911377,58.21470336491904,57.680164211369274,57.145316982547726,56.61046975372612,56.07562252490457,55.540775296083005,55.00592806726141,54.4710808384398,53.9362336096183,53.401386380796694,52.86653915197509,52.331691923153535,51.79684469433198,51.261997465510376,50.727150236688814,50.19230300786726,49.657455779045655,49.1226085502241,48.58776132140254,48.052914092580934,47.51806686375933,46.983219634937825,46.44837240611622,45.91352517729461,45.378677948473054,44.8438307196515,44.3089834908299,43.77413626200834,43.23928903318678,42.70444180436518,42.16959457554357,41.634747346722065,41.09990011790046,40.565052889078856,40.030205660257295,39.49535843143575,38.960511202614136,38.42566397379258,37.890816744971026,37.35596951614942,36.82112228732787,36.286275058506305,35.75142782968471,35.2165806008631,34.681733372041585,34.14688614321999,33.61203891439838,33.07719168557682,32.542344456755266,32.00749722793366,31.472649999112107,30.93780277029055,30.402955541468945,29.868108312647387,29.333261083825832,28.798413855004227,28.263566626182627,27.72871939736107,27.193872168539507,26.759761674940542,26.527124651786778,26.294487628633007,26.06185060547922,25.82921358232545,25.59657655917168,25.363939536017895,25.131302512864103,24.898665489710357,24.66602846655657,24.433391443402776,24.20075442024901,23.96811739709524,23.73548037394145,23.502843350787685,23.270206327633915,23.037569304480126,22.80493228132636,22.572295258172588,22.339658235018803,22.10702121186501,21.874384188711243,21.641747165557476,21.409110142403684,21.176473119249916,20.943836096096152,20.711199072942357,20.478562049788593,20.245925026634826,20.013288003481037,19.780650980327245,19.5480139571735,19.31537693401971,19.08273991086592,18.85010288771215,18.617465864558383,18.384828841404595,18.153078974494047,17.932152411642896,17.711225848791724,17.490299285940576,17.269372723089425,17.048446160238257,16.82751959738709,16.60659303453594,16.38566647168479,16.16473990883362,15.943813345982472,15.722886783131322,15.501960220280152,15.281033657429006,15.060107094577855,14.839180531726686,14.618253968875516,14.397327406024386,14.17640084317322,13.955474280322049,13.7345477174709,13.51362115461975,13.29269459176858,13.071768028917433,12.850841466066283,12.629914903215113,12.408988340363964,12.188061777512814,11.967135214661646,11.746208651810475,11.525282088959347,11.304355526108179,11.083428963257008,10.862502400405859,10.64157583755471,10.42064927470354,10.199722711852392,9.978796149001242,9.757869586150072,9.536943023298903,9.316016460447774,9.095089897596605,8.874163334745436,8.653236771894287,8.432310209043138,8.211383646191967,8.018031104281924,7.962548667077263,7.907066229872602,7.851583792667941,7.796101355463291,7.740618918258631,7.685136481053971,7.62965404384932,7.57417160664466,7.518689169439999,7.4632067322353475,7.407724295030687,7.3522418578260265,7.296759420621367,7.241276983416717,7.1857945462120565,7.130312109007395,7.074829671802744,7.019347234598084,6.9638647973934225,6.9083823601887735,6.852899922984113,6.799883569226562,6.746986482129634,6.694089395032697,6.64119230793576,6.5882952208388215,6.535398133741895,6.482501046644957,6.42960395954802,6.376706872451093,6.323809785354156,6.270912698257218,6.2180156111602916,6.165118524063354,6.112221436966417,6.059324349869479,6.006427262772553,5.953530175675615,5.900633088578677,5.84773600148175,5.794838914384814,5.75521043009557,5.7250595192403955,5.694908608385217,5.664757697530038,5.634606786674864,5.604455875819685,5.5743049649645044,5.544154054109327,5.514003143254152,5.483852232398974,5.453701321543794,5.42355041068862,5.39339949983344,5.36324858897826,5.333097678123088,5.302946767267908,5.2727958564127295,5.242644945557551,5.2124940347023765,5.182343123847197,5.151920282200672,5.120491491428217,5.089062700655755,5.057633909883294,5.026205119110838,4.994776328338379,4.963347537565918,4.931918746793461,4.900489956021,4.869061165248539,4.837632374476079,4.806203583703623,4.774774792931162,4.743346002158701,4.711917211386245,4.680488420613784,4.649059629841323,4.617630839068869,4.586202048296408,4.554773257523945,4.523344466751484,4.491915675979029],[59.90600100294105,59.9597262752351,60.01345154752913,60.067176819823175,60.12090209211722,60.174627364411265,60.2283526367053,60.28207790899934,60.33580318129339,60.38952845358744,60.443253725881476,60.49697899817552,60.55070427046956,60.60442954276361,60.65815481505766,60.711880087351695,60.76560535964573,60.81933063193978,60.87305590423382,60.92678117652787,60.98050644882191,61.03423172111595,61.08795699340999,61.14168226570404,61.19540753799808,61.249132810292124,61.30285808258617,61.3565833548802,61.41030862717425,61.4640338994683,61.517759171762336,61.57148444405638,61.62520971653679,61.67977302293437,61.73433632933194,61.78889963572951,61.843462942127076,61.89802624852464,61.95258955492221,62.00715286131978,62.06171616771735,62.116279474114926,62.17084278051249,62.22540608691006,62.27996939330763,62.33453269970519,62.389096006102776,62.44365931250034,62.4982226188979,62.55278592529548,62.607349231693036,62.66191253809062,62.71647584448818,62.77103915088574,62.82560245728333,62.88016576368089,62.93472907007846,62.98929237647603,63.0438556828736,63.098418989271174,63.152982295668735,63.20754560206632,63.26210890846388,63.31667221486145,63.37123552125902,63.425798827656585,63.480362134054154,63.53492544045172,63.5894887468493,63.64405205324687,63.69861535964443,63.753178666042,63.80774197243957,63.86230527883714,63.91686858523472,63.971431891632285,64.02599519802986,64.08055850442743,64.135121810825,64.18968511722257,64.24424842362014,64.29881173001769,64.35337503641526,64.40793834281283,64.45358823499022,64.49745544432358,64.54132265365693,64.58518986299028,64.62905707232363,64.67292428165698,64.71679149099033,64.76065870032369,64.80452590965703,64.84839311899039,64.89226032832374,64.93612753765709,64.97999474699044,65.02386195632378,65.06772916565714,65.1115963749905,65.15546358432384,65.1993307936572,65.24319800299055,65.2870652123239,65.33093242165724,65.3747996309906,65.41866684032394,65.46253404965731,65.50640125899065,65.550268468324,65.59413567765736,65.6380028869907,65.68187009632405,65.7257373056574,65.76960451499076,65.8134717243241,65.85733893365747,65.90120614299082,65.94507335232416,65.98894056165751,66.03280777099087,66.07667498032421,66.12054218965757,66.16440939899093,66.20827660832427,66.25214381765761,66.29601102699097,66.33987823632432,66.38374544565767,66.42761265499104,66.47147986432438,66.51534707365772,66.55921428299108,66.60308149232443,66.64694870165779,66.6902663133886,66.73330912604318,66.77635193869773,66.8193947513523,66.86243756400685,66.90548037666142,66.94852318931598,66.99156600197054,67.0346088146251,67.07765162727966,67.12069443993423,67.16373725258879,67.20678006524335,67.24982287789791,67.29286569055247,67.33590850320704,67.3789513158616,67.42199412851616,67.46503694117072,67.50807975382529,67.55112256647985,67.59416537913441,67.63720819178897,67.68025100444353,67.72329381709808,67.76633662975266,67.8093794424072,67.85242225506178,67.89546506771633,67.93850788037089,67.98155069302545,68.02459350568002,68.06338150907911,68.1000421078505,68.13670270662186,68.17336330539324,68.21002390416461,68.24668450293598,68.28334510170737,68.32000570047873,68.35666629925011,68.39332689802148,68.42998749679286,68.46664809556421,68.5033086943356,68.53996929310696,68.57662989187835,68.61329049064972,68.6499510894211,68.68661168819247,68.72327228696383,68.75993288573521,68.79659348450659,68.83325408327796,68.86991468204934,68.9065752808207,68.94323587959208,68.97989647836344,69.01655707713483,69.0532176759062,69.08987827467757,69.12653887344895,69.16319947222031,69.19986007099169,69.23652066976307,69.27318126853443,69.3098418673058,69.34650246607717,69.38316306484856,69.41982366361992,69.4564842623913,69.49314486116268,69.52980545993405,69.56646605870542,69.60312665747679,69.63978725624816,69.67644785501955,69.71310845379091,69.74976905256229,69.78642965133366,69.82309025010504,69.85975084887642,69.89641144764778,69.93307204641916,69.96973264519052,70.0063932439619,70.04305384273327,70.07971444150465,70.11637504027601,70.1530356390474,70.18969623781877,70.22635683659014,70.2630174353615,70.29967803413288,70.33633863290426,70.37299923167562,70.409659830447,70.44632042921837,70.48298102798974,70.51964162676113,70.55630222553249,70.59296282430387,70.62962342307524,70.66628402184661,70.70294462061798,70.73960521938936,70.77626581816072,70.81292641693211,70.84825263265742,70.88311472022698,70.91797680779658,70.95283889536617,70.98770098293575,71.02256307050534,71.05742515807492,70.79558970586152,70.23705671386516,69.67852372186881,69.1199907298725,68.56145773787611,68.00292474587978,67.44439175388347,66.90033315490977,66.36539349734068,65.83045383977169,65.2955141822026,64.7605745246335,64.22563486706446,63.690695209495416,63.155755551926326,62.620815894357285,62.08587623678824,61.55093657921914,61.0159969216501,60.48105726408106,59.94611760651197,59.41117794894287,58.87623829137387,58.34129863380478,57.80635897623569,57.271419318666645,56.736479661097604,56.20154000352851,55.666600345959466,55.131660688390426,54.59672103082133,54.06178137325224,53.52684171568325,52.991902058114164,52.45696240054506,51.92202274297602,51.38708308540698,50.85214342783789,50.31720377026883,49.782264112699785,49.247324455130695,48.712384797561654,48.17753072135473,47.642683492533116,47.10783626371152,46.57298903489001,46.0381418060684,45.5032945772468,44.96844734842524,44.43360011960368,43.89875289078208,43.36390566196052,42.82905843313897,42.294211204317364,41.75936397549575,41.22451674667425,40.68966951785264,40.15482228903104,39.619975060209484,39.08512783138792,38.55028060256632,38.01543337374477,37.48058614492321,36.945738916101604,36.41089168728004,35.876044458458495,35.34119722963688,34.806350000815286,34.27150277199378,33.736655543172176,33.201808314350565,32.66696108552901,32.132113856707456,31.59726662788585,31.062419399064293,30.527572170242742,29.992724941421134,29.457877712599576,28.92303048377802,28.388183254956417,27.853336026134812,27.318488797313254,26.783641568491696,26.349531074892724,26.11689405173896,25.88425702858519,25.6516200054314,25.418982982277633,25.186345959123862,24.953708935970077,24.721071912816285,24.488434889662543,24.265467876395828,24.04454131354466,23.82361475069351,23.602688187842357,23.38176162499119,23.16083506214004,22.93990849928889,22.718981936437718,22.498055373586574,22.277128810735423,22.05620224788425,21.835275685033082,21.614349122181935,21.393422559330784,21.172495996479615,20.951569433628467,20.73064287077732,20.509716307926148,20.288789745075,20.067863182223853,19.84693661937268,19.626010056521512,19.405083493670382,19.184156930819213,18.963230367968045,18.742303805116894,18.521377242265746,18.300450679414578,18.079524116563427,17.85859755371228,17.63767099086111,17.41674442800996,17.19581786515881,16.97489130230764,16.75396473945647,16.533038176605324,16.312111613754173,16.091185050903004,15.870258488051853,15.649331925200704,15.428405362349533,15.207478799498386,14.986552236647238,14.765625673796068,14.544699110944897,14.32377254809377,14.1028459852426,13.88191942239143,13.660992859540283,13.440066296689132,13.219139733837963,12.998213170986814,12.777286608135665,12.556360045284496,12.335433482433347,12.114506919582197,11.893580356731029,11.672653793879856,11.45172723102873,11.23080066817756,11.00987410532639,10.788947542475242,10.568020979624091,10.347094416772922,10.126167853921775,9.905241291070624,9.684314728219455,9.463388165368285,9.242461602517157,9.021535039665988,8.800608476814817,8.579681913963668,8.358755351112519,8.13782878826135,7.9444762463513054,7.888993809146645,7.833511371941984,7.778028934737324,7.722546497532674,7.669380102347289,7.616483015250351,7.563585928153423,7.510688841056487,7.457791753959549,7.404894666862622,7.351997579765685,7.299100492668748,7.24620340557181,7.193306318474883,7.140409231377946,7.087512144281009,7.034615057184081,6.981717970087143,6.928820882990206,6.8759237958932795,6.823026708796341,6.770129621699405,6.717232534602477,6.664335447505539,6.611438360408603,6.558541273311665,6.505644186214738,6.4527470991178015,6.399850012020863,6.3469529249239365,6.294055837826999,6.241158750730062,6.188261663633134,6.135364576536197,6.082467489439259,6.029570402342322,5.976673315245394,5.923776228148458,5.87087914105152,5.817982053954593,5.765084966857656,5.725456482568413,5.695305571713239,5.665154660858059,5.6350037500028805,5.604852839147707,5.574701928292527,5.544551017437348,5.514400106582169,5.484249195726996,5.454098284871816,5.423947374016636,5.393796463161462,5.363645552306283,5.333494641451104,5.30334373059593,5.273192819740752,5.243041908885573,5.212890998030394,5.182740087175219,5.15258917632004,5.122438265464861,5.092287354609686,5.0621364437545076,5.031985532899328,5.001834622044155,4.971683711188976,4.941532800333795,4.911381889478622,4.881230978623443,4.8510800677682635,4.820929156913085,4.790778246057911,4.760627335202732,4.730476424347552,4.700325513492379,4.670174602637199,4.64002369178202,4.609526688060964,4.578097897288504,4.546669106516043,4.515240315743582,4.4838115249711255],[60.12953131454588,60.183256586839924,60.23698185913396,60.29070713142801,60.34443240372205,60.3981576760161,60.451882948310136,60.505608220604174,60.559333492898226,60.61305876519227,60.666784037486316,60.720509309780354,60.77423458207439,60.827959854368444,60.88168512666248,60.93541039895653,60.989135671250565,61.04286094354461,61.096586215838656,61.1503114881327,61.20403676042674,61.257762032720784,61.31148730501482,61.36521257730888,61.41893784960291,61.47266312189696,61.526388394191,61.58011366648503,61.63383893877909,61.68756421107313,61.74128948336717,61.795014755661214,61.848740027955245,61.902465300249304,61.95619057254334,62.00991584483739,62.06364111713144,62.11736638942547,62.171091661719515,62.224816934013546,62.2785422063076,62.33226747860164,62.38599275089568,62.43971802318973,62.49344329548377,62.54716856777782,62.60089384007186,62.6546191123659,62.708344384659945,62.762488674053856,62.817051980451424,62.87161528684899,62.92617859324656,62.98074189964412,63.0353052060417,63.08986851243927,63.144431818836836,63.198995125234404,63.25355843163197,63.30812173802954,63.36268504442711,63.417248350824686,63.471811657222254,63.52637496361982,63.5809382700174,63.63550157641497,63.690064882812536,63.7446281892101,63.79919149560767,63.85375480200524,63.90831810840282,63.962881414800385,64.01744472119795,64.07200802759552,64.12657133399308,64.18113464039065,64.23569794678822,64.29026125318579,64.34482455958337,64.39938786598094,64.45395117237851,64.50851447877608,64.56307778517363,64.61764109157122,64.6632909837486,64.70715819308195,64.75102540241531,64.79489261174865,64.83875982108201,64.88262703041535,64.9264942397487,64.97036144908206,65.01422865841542,65.05809586774876,65.1019630770821,65.14583028641546,65.18969749574882,65.23356470508217,65.27743191441552,65.32129912374887,65.36516633308221,65.40903354241557,65.45290075174893,65.49676796108227,65.54063517041563,65.58450237974897,65.62836958908233,65.67223679841567,65.71610400774902,65.75997121708238,65.80383842641574,65.84770563574908,65.89157284508244,65.93544005441578,65.97930726374913,66.02317447308249,66.06704168241583,66.11090889174919,66.15463870168338,66.19768151433794,66.2407243269925,66.28376713964707,66.32680995230163,66.36985276495619,66.41289557761075,66.45593839026532,66.49898120291988,66.54202401557444,66.585066828229,66.62810964088357,66.67115245353811,66.71419526619269,66.75723807884724,66.80028089150181,66.84332370415638,66.88636651681094,66.92940932946549,66.97245214212006,67.01549495477461,67.05853776742917,67.10158058008373,67.1446233927383,67.18766620539286,67.23070901804742,67.27375183070198,67.31679464335654,67.3598374560111,67.40288026866567,67.44592308132023,67.4889658939748,67.53200870662936,67.57505151928392,67.61809433193848,67.66113714459304,67.7041799572476,67.74722276990217,67.79026558255671,67.83330839521128,67.87635120786585,67.9193940205204,67.96243683317496,68.00547964582952,68.04852245848409,68.09156527113865,68.13460808379321,68.17765089644777,68.22069370910233,68.25948171250144,68.2961423112728,68.33280291004418,68.36946350881556,68.40612410758692,68.44278470635831,68.47944530512967,68.51610590390105,68.55276650267243,68.58942710144379,68.62608770021518,68.66274829898654,68.6994088977579,68.73606949652928,68.77273009530066,68.80939069407204,68.84605129284341,68.88271189161478,68.91937249038615,68.95603308915753,68.99269368792889,69.02935428670027,69.06601488547165,69.10267548424302,69.1393360830144,69.17599668178576,69.21265728055714,69.24931787932852,69.28597847809989,69.32263907687125,69.35929967564263,69.39596027441401,69.43262087318539,69.46928147195675,69.50594207072812,69.5426026694995,69.57926326827088,69.61592386704224,69.6525844658136,69.68924506458498,69.72590566335637,69.76256626212773,69.79922686089911,69.83588745967049,69.87254805844185,69.90920865721323,69.94586925598459,69.98252985475598,70.01919045352736,70.05585105229872,70.0925116510701,70.12876613160738,70.16362821917699,70.19849030674656,70.23335239431616,70.26821448188574,70.30307656945531,70.3379386570249,70.3728007445945,70.40766283216408,70.44252491973369,70.47738700730326,70.51224909487284,70.54711118244242,70.58197327001201,70.6168353575816,70.6516974451512,70.68655953272078,70.72142162029036,70.75628370785995,70.79114579542953,70.82600788299912,70.86086997056871,70.8957320581383,70.93059414570787,70.96545623327745,71.00031832084706,71.03518040841664,71.07004249598621,71.10490458355581,71.13976667112539,71.17462875869498,71.20949084626457,70.94765539405117,70.3891224020548,69.83058941005847,69.27205641806214,68.71352342606576,68.15499043406945,67.5964574420731,67.03792445007673,66.47939145808036,65.92085846608408,65.3623254740877,64.80379248209132,64.245259490095,63.68672649809867,63.12819350610229,62.56966051410596,62.01112752210964,61.45259453011326,60.894061538116944,60.33552854612061,59.77699555412423,59.218462562127854,58.65992957013158,58.1013965781352,57.54286358613883,56.9843305941425,56.42579760214617,55.86726461014979,55.30873161815347,54.75019862615714,54.199481803426764,53.66454214585767,53.12960248828868,52.5946628307196,52.0597231731505,51.52478351558146,50.98984385801241,50.45490420044331,49.919964542874276,49.385024885305235,48.850085227736145,48.315145570167104,47.780205912598056,47.245266255028966,46.71032659745987,46.17538693989088,45.64044728232179,45.10550762475269,44.57056796718365,44.0356283096146,43.50068865204551,42.96574899447647,42.43080933690743,41.89586967933833,41.360930021769235,40.825990364200244,40.291050706631154,39.756111049062056,39.221171391493016,38.686231733923975,38.15129207635488,37.61635241878584,37.0814127612168,36.5464731036477,36.01153344607866,35.47659378850961,34.94165413094052,34.40671447337142,33.87177481580244,33.33683515823334,32.801895500664244,32.266955843095204,31.732016185526156,31.197076527957066,30.662136870388025,30.12719721281898,29.592257555249894,29.057317897680853,28.52237824011181,27.987438582542715,27.452498924973618,26.917559267404577,26.382619609835533,25.95604502296165,25.746200577478106,25.536356131994562,25.326511686511,25.116667241027457,24.90682279554391,24.696978350060352,24.487133904576787,24.277289459093264,24.067445013609703,23.85760056812614,23.647756122642594,23.437911677159047,23.228067231675492,23.018222786191945,22.808378340708405,22.59853389522484,22.3886894497413,22.178845004257752,21.96900055877419,21.75915611329063,21.544233534890886,21.323309505880918,21.10238547687093,20.88146144786096,20.660537418850993,20.439613389841007,20.21868936083104,19.99776533182107,19.77684130281108,19.555917273801093,19.334993244791143,19.114069215781157,18.893145186771168,18.6722211577612,18.451297128751232,18.230373099741243,18.009449070731275,17.788525041721307,17.567601012711318,17.34667698370135,17.125752954691382,16.904828925681393,16.683904896671407,16.462980867661436,16.242056838651468,16.02113280964148,15.800208780631511,15.579284751621543,15.358360722611556,15.137436693601586,14.91651266459162,14.69558863558163,14.474664606571642,14.253740577561693,14.032816548551706,13.811892519541717,13.59096849053175,13.370044461521783,13.149120432511793,12.928196403501824,12.707272374491858,12.486348345481868,12.2654243164719,12.044500287461931,11.823576258451943,11.602652229441953,11.381728200432008,11.160804171422017,10.93988014241203,10.71895611340206,10.498032084392094,10.277108055382104,10.056184026372136,9.835259997362167,9.61433596835218,9.393411939342192,9.172487910332244,8.951563881322254,8.730639852312267,8.5097158233023,8.28879179429233,8.067867765282342,7.874996175737261,7.822386783516473,7.769777391295685,7.717167999074897,7.6645586068541185,7.611949214633331,7.559339822412543,7.506730430191764,7.454121037970976,7.401511645750189,7.348902253529411,7.296292861308623,7.243683469087834,7.191074076867047,7.1384646846462685,7.08585529242548,7.033245900204692,6.980636507983916,6.928027115763127,6.875417723542338,6.822808331321561,6.770198939100774,6.717589546879985,6.664980154659206,6.6123707624384185,6.559761370217631,6.507151977996843,6.454542585776064,6.401933193555276,6.349323801334489,6.296714409113711,6.244105016892923,6.191495624672134,6.138886232451357,6.086276840230569,6.0356484922463896,5.98551896488509,5.935389437523802,5.885259910162503,5.8351303828012036,5.785000855439915,5.734871328078616,5.697204364224758,5.668439231447644,5.639674098670525,5.610908965893408,5.5821438331162945,5.5533787003391755,5.524613567562057,5.495397423538828,5.4654061002147705,5.435414776890708,5.405423453566645,5.375432130242588,5.345440806918526,5.315449483594462,5.285458160270405,5.255466836946343,5.22547551362228,5.1954841902982185,5.165492866974161,5.135501543650098,5.105510220326035,5.075518897001978,5.045527573677916,5.015536250353853,4.985544927029796,4.9555536037057335,4.92556228038167,4.895570957057613,4.865579633733551,4.835588310409488,4.805596987085425,4.775605663761368,4.745614340437306,4.715623017113244,4.685631693789186,4.6556403704651235,4.625649047141061,4.595657723817004,4.565666400492941,4.535675077168879,4.505683753844816,4.475692430520759],[60.35306162615071,60.40678689844476,60.460512170738795,60.51423744303284,60.567962715326885,60.62168798762093,60.67541325991497,60.729138532209014,60.78286380450306,60.836589076797104,60.89031434909115,60.94403962138519,60.99776489367923,61.05149016597327,61.105215438267315,61.15894071056136,61.2126659828554,61.26639125514944,61.32011652744349,61.373841799737534,61.42756707203158,61.48129234432562,61.535017616619655,61.58874288891371,61.642468161207745,61.69619343350179,61.74991870579584,61.80364397808988,61.857369250383925,61.911094522677956,61.964819794972,62.018545067266054,62.07227033956009,62.125995611854144,62.179720884148175,62.23344615644222,62.287171428736265,62.3408967010303,62.394621973324355,62.44834724561839,62.50207251791244,62.55579779020648,62.609523062500514,62.66324833479456,62.716973607088605,62.77069887938265,62.824424151676695,62.87814942397073,62.93187469626478,62.98559996855882,63.03932524085287,63.093050513146906,63.14677578544095,63.20050105773499,63.254226330029034,63.30795160232307,63.36167687461712,63.41540214691116,63.46912741920521,63.52285269149925,63.57657796379329,63.630303236087336,63.68402850838138,63.737753780675426,63.791479052969464,63.84520432526351,63.8997676315709,63.95433093796847,64.00889424436605,64.06345755076362,64.11802085716117,64.17258416355874,64.22714746995631,64.28171077635389,64.33627408275146,64.39083738914903,64.4454006955466,64.49996400194416,64.55452730834173,64.6090906147393,64.66365392113687,64.71821722753444,64.772780533932,64.82734384032958,64.87299373250697,64.91686094184033,64.96072815117367,65.00459536050703,65.04846256984037,65.09232977917372,65.13619698850707,65.18006419784044,65.22393140717378,65.26779861650714,65.31166582584048,65.35553303517383,65.39940024450718,65.44326745384053,65.48713466317389,65.53100187250723,65.57486908184059,65.61873629117395,65.6620539026327,65.70509671528727,65.74813952794185,65.7911823405964,65.83422515325096,65.87726796590552,65.9203107785601,65.96335359121464,66.0063964038692,66.04943921652377,66.09248202917833,66.13552484183289,66.17856765448745,66.22161046714201,66.26465327979658,66.30769609245114,66.3507389051057,66.39378171776026,66.43682453041482,66.47986734306939,66.52291015572395,66.56595296837851,66.60899578103306,66.65203859368762,66.69508140634218,66.73812421899675,66.78116703165132,66.82420984430587,66.86725265696043,66.910295469615,66.95333828226956,66.99638109492412,67.03942390757868,67.08246672023324,67.1255095328878,67.16855234554237,67.21159515819693,67.25463797085149,67.29768078350605,67.34072359616061,67.38376640881518,67.42680922146974,67.4698520341243,67.51289484677885,67.55593765943343,67.59898047208799,67.64202328474254,67.6850660973971,67.72810891005167,67.77115172270622,67.81419453536078,67.85723734801535,67.90028016066991,67.94332297332447,67.98636578597903,68.0294085986336,68.07245141128816,68.11549422394272,68.15853703659727,68.20157984925184,68.2446226619064,68.28766547456095,68.33070828721551,68.37375109987009,68.41679391252464,68.45558191592374,68.49224251469512,68.5289031134665,68.56556371223787,68.60222431100924,68.63888490978063,68.67554550855199,68.71220610732335,68.74886670609473,68.78552730486611,68.82218790363748,68.85884850240885,68.89550910118024,68.9321696999516,68.96883029872298,69.00549089749435,69.04215149626572,69.0788120950371,69.11547269380847,69.15213329257985,69.18879389135121,69.22545449012259,69.26211508889396,69.29877568766533,69.3354362864367,69.37209688520808,69.40875748397947,69.44414171812697,69.47900380569656,69.51386589326614,69.54872798083572,69.58359006840531,69.61845215597491,69.65331424354449,69.68817633111406,69.72303841868366,69.75790050625325,69.79276259382283,69.82762468139241,69.862486768962,69.89734885653158,69.93221094410117,69.96707303167076,70.00193511924034,70.03679720680994,70.07165929437951,70.10652138194911,70.1413834695187,70.17624555708828,70.21110764465787,70.24596973222745,70.28083181979703,70.31569390736664,70.3505559949362,70.3854180825058,70.42028017007539,70.45514225764497,70.49000434521456,70.52486643278414,70.55972852035373,70.59459060792332,70.6294526954929,70.6643147830625,70.69917687063207,70.73403895820167,70.76890104577124,70.80376313334082,70.83862522091042,70.87348730848001,70.90834939604959,70.94321148361917,70.97807357118876,71.01293565875835,71.04779774632794,71.08265983389751,71.1175219214671,71.1523840090367,71.18724609660627,71.22210818417585,71.25697027174544,71.29183235931504,71.32669444688463,71.3615565344542,71.09972108224082,70.54118809024443,69.9826550982481,69.42412210625179,68.8655891142554,68.30705612225907,67.74852313026275,67.18999013826638,66.63145714627001,66.07292415427372,65.51439116227735,64.95585817028096,64.39732517828463,63.838792186288316,63.28025919429193,62.72172620229561,62.16319321029929,61.60466021830291,61.04612722630658,60.48759423431025,59.929061242313864,59.37052825031749,58.81199525832122,58.25346226632484,57.69492927432847,57.13639628233214,56.57786329033581,56.01933029833944,55.4607973063431,54.90226431434678,54.3437313223504,53.78519833035402,53.22666533835776,52.668132346361375,52.109599354365,51.55106636236868,50.99253337037235,50.43400037837596,49.87546738637964,49.31693439438332,48.75840140238694,48.199868410390614,47.641335418394284,47.082802426397905,46.524269434401525,45.96573644240525,45.40720345040887,44.8486704584125,44.29013746641617,43.731604474419846,43.173071482423474,42.61453849042714,42.056005498430814,41.498630451943775,40.963690794374685,40.42875113680569,39.89381147923659,39.3588718216675,38.82393216409845,38.28899250652941,37.75405284896032,37.21911319139128,36.68417353382223,36.14923387625314,35.614294218684094,35.07935456111505,34.54441490354596,34.00947524597687,33.474535588407875,32.939595930838784,32.40465627326969,31.869716615700643,31.3347769581316,30.79983730056251,30.264897642993468,29.72995798542442,29.19501832785534,28.660078670286296,28.12513901271725,27.59019935514815,27.055259697579064,26.52032004001002,25.985380382440972,25.558805795567093,25.348961350083545,25.1391169046,24.92927245911644,24.7194280136329,24.509583568149353,24.299739122665795,24.089894677182226,23.880050231698704,23.670205786215142,23.460361340731584,23.250516895248037,23.04067244976449,22.83082800428093,22.620983558797388,22.411139113313844,22.201294667830282,21.99145022234674,21.781605776863195,21.571761331379633,21.36191688589607,21.152072440412528,20.942227994928984,20.732383549445423,20.52253910396188,20.312694658478335,20.102850212994774,19.89300576751123,19.683161322027683,19.473316876544125,19.263472431060563,19.053627985577037,18.843783540093476,18.63393909460991,18.424094649126367,18.214250203642827,18.004405758159262,17.79456131267572,17.584716867192178,17.374872421708613,17.165027976225073,16.95518353074153,16.745339085257967,16.535494639774402,16.32565019429086,16.115805748807315,15.905961303323755,15.69611685784021,15.486272412356666,15.276427966873106,15.066583521389562,14.847765775109867,14.626841746099878,14.405917717089888,14.18499368807994,13.964069659069953,13.743145630059963,13.522221601049996,13.301297572040028,13.080373543030039,12.85944951402007,12.638525485010103,12.417601456000114,12.196677426990146,11.975753397980178,11.754829368970189,11.5339053399602,11.312981310950253,11.092057281940264,10.871133252930276,10.650209223920308,10.429285194910339,10.208361165900351,9.987437136890382,9.766513107880414,9.545589078870426,9.324665049860437,9.103741020850489,8.8828169918405,8.661892962830514,8.440968933820544,8.220044904810576,7.999120875800588,7.8062492862555075,7.75363989403472,7.701030501813931,7.648421109593143,7.5958117173723645,7.543202325151576,7.490592932930788,7.437983540710011,7.385374148489223,7.3327647562684355,7.280155364047657,7.227545971826869,7.174936579606081,7.122327187385293,7.0697177951645145,7.017108402943727,6.964499010722939,6.91188961850216,6.859668597710963,6.809539070349665,6.759409542988376,6.709280015627077,6.659150488265778,6.609020960904488,6.55889143354319,6.508761906181891,6.458632378820592,6.408502851459303,6.358373324098005,6.308243796736705,6.258114269375415,6.207984742014117,6.15785521465282,6.10772568729153,6.057596159930232,6.007466632568933,5.957337105207634,5.907207577846345,5.857078050485047,5.806948523123748,5.756818995762458,5.7066894684011595,5.669022504547302,5.640257371770188,5.611492238993069,5.582727106215951,5.553961973438838,5.52519684066172,5.4964317078846,5.467666575107482,5.43890144233037,5.410136309553251,5.381371176776133,5.352606043999019,5.3238409112219,5.295075778444782,5.266310645667669,5.23754551289055,5.208780380113433,5.180015247336313,5.1512501145592005,5.122484981782082,5.093719849004964,5.0649547162278505,5.0361895834507315,5.007412119182128,4.977420795858071,4.947429472534008,4.917438149209945,4.887446825885888,4.857455502561825,4.8274641792377615,4.7974728559137,4.767481532589644,4.73749020926558,4.707498885941518,4.6775075626174605,4.647516239293398,4.6175249159693355,4.587533592645279,4.557542269321216,4.527550945997153,4.49755962267309,4.467568299349033],[60.57659193775556,60.630317210049604,60.68404248234364,60.73776775463769,60.79149302693173,60.84521829922577,60.89894357151981,60.95266884381385,61.0063941161079,61.060119388401944,61.11384466069599,61.16756993299003,61.22129520528407,61.27502047757812,61.32874574987216,61.38247102216621,61.436196294460245,61.48992156675428,61.54364683904833,61.597372111342374,61.65109738363642,61.70482265593046,61.7585479282245,61.81227320051855,61.865998472812585,61.91972374510663,61.97344901740068,62.02717428969471,62.080899561988765,62.13462483428281,62.18835010657685,62.242075378870894,62.295800651164924,62.34952592345898,62.403251195753015,62.45697646804706,62.510701740341105,62.56442701263514,62.618152284929195,62.671877557223226,62.72560282951728,62.77932810181132,62.83305337410536,62.88677864639941,62.940503918693445,62.99422919098749,63.047954463281535,63.10167973557558,63.15540500786962,63.20913028016366,63.26285555245771,63.316580824751746,63.37030609704579,63.424031369339836,63.47775664163388,63.53148191392792,63.58520718622196,63.638932458516,63.69265773081005,63.74638300310409,63.80010827539814,63.85383354769218,63.90755881998622,63.961284092280266,64.01500936457431,64.06873463686836,64.1224599091624,64.17618518145645,64.22991045375048,64.28363572604452,64.33736099833857,64.39108627063261,64.44481154292666,64.49853681522069,64.55226208751473,64.60598735980878,64.65971263210282,64.71343790439687,64.76716317669091,64.82088844898496,64.874613721279,64.92833899357305,64.98248328269038,65.03704658908795,65.08269648126534,65.1264262909275,65.16946910358206,65.21251191623662,65.25555472889117,65.29859754154573,65.34164035420031,65.38468316685486,65.42772597950942,65.47076879216398,65.51381160481854,65.5568544174731,65.59989723012767,65.64294004278223,65.68598285543679,65.72902566809135,65.77206848074592,65.81511129340048,65.85815410605503,65.90119691870959,65.94423973136415,65.98728254401871,66.03032535667327,66.07336816932784,66.1164109819824,66.15945379463696,66.20249660729152,66.24553941994608,66.28858223260065,66.33162504525521,66.37466785790977,66.41771067056433,66.4607534832189,66.50379629587346,66.54683910852802,66.58988192118258,66.63292473383714,66.6759675464917,66.71901035914627,66.76205317180083,66.80509598445539,66.84813879710997,66.89118160976453,66.93422442241908,66.97726723507363,67.0203100477282,67.06335286038275,67.10639567303733,67.14943848569189,67.19248129834645,67.235524111001,67.27856692365556,67.32160973631012,67.36465254896468,67.40769536161925,67.45073817427381,67.49378098692836,67.53682379958292,67.5798666122375,67.62290942489204,67.6659522375466,67.70899505020117,67.75203786285573,67.79508067551029,67.83812348816485,67.88116630081943,67.92420911347398,67.96725192612855,68.01029473878312,68.05333755143766,68.09638036409223,68.13942317674679,68.18246598940136,68.22550880205593,68.26855161471047,68.31159442736505,68.35463724001961,68.39768005267418,68.44072286532872,68.48376567798329,68.52680849063783,68.56985130329241,68.61289411594696,68.65168211934608,68.68834271811745,68.72465521707697,68.75951730464655,68.79437939221614,68.82924147978572,68.8641035673553,68.8989656549249,68.93382774249449,68.96868983006406,69.00355191763366,69.03841400520324,69.07327609277283,69.10813818034241,69.143000267912,69.17786235548158,69.21272444305117,69.24758653062075,69.28244861819034,69.31731070575992,69.35217279332952,69.3870348808991,69.42189696846867,69.45675905603827,69.49162114360786,69.52648323117745,69.56134531874703,69.59620740631661,69.6310694938862,69.6659315814558,69.70079366902537,69.73565575659497,69.77051784416454,69.80537993173414,69.84024201930372,69.87510410687331,69.9099661944429,69.94482828201248,69.97969036958206,70.01455245715165,70.04941454472123,70.08427663229082,70.11913871986042,70.15400080743,70.18886289499959,70.22372498256917,70.25858707013874,70.29344915770835,70.32831124527792,70.36317333284752,70.3980354204171,70.43289750798668,70.46775959555627,70.50262168312585,70.53748377069545,70.57234585826502,70.6072079458346,70.64207003340421,70.67693212097379,70.71179420854338,70.74665629611296,70.78151838368254,70.81638047125213,70.85124255882171,70.88610464639129,70.9209667339609,70.95582882153047,70.99069090910007,71.02555299666966,71.06041508423922,71.09527717180882,71.13013925937841,71.165001346948,71.19986343451758,71.23472552208716,71.26958760965675,71.30444969722635,71.33931178479592,71.3741738723655,71.4090359599351,71.44389804750469,71.47876013507427,71.51362222264386,71.25178677043047,70.69325377843408,70.13472078643775,69.57618779444142,69.01765480244504,68.45912181044872,67.9005888184524,67.34205582645602,66.78352283445965,66.22498984246337,65.66645685046699,65.10792385847061,64.54939086647428,63.99085787447796,63.43232488248159,62.873791890485265,62.315258898488935,61.756725906492555,61.19819291449623,60.6396599224999,60.081126930503515,59.52259393850714,58.96406094651087,58.40552795451449,57.84699496251811,57.288461970521794,56.729928978525464,56.171395986529085,55.612862994532755,55.05433000253643,54.49579701054005,53.93726401854367,53.378731026547406,52.82019803455103,52.261665042554654,51.703132050558324,51.144599058561994,50.586066066565614,50.02753307456929,49.46900008257296,48.91046709057659,48.35193409858026,47.79340110658393,47.234868114587556,46.67633512259118,46.117802130594896,45.55926913859852,45.00073614660215,44.44220315460582,43.8836701626095,43.32513717061312,42.76660417861679,42.20807118662046,41.649538194624085,41.0910052026277,40.53247221063143,39.97393921863506,39.41540622663868,38.85687323464236,38.29834024264603,37.73980725064965,37.18127425865332,36.622741266657,36.06420827466062,35.50567528266429,34.94714229066797,34.38860929867159,33.83007630667522,33.27154331467894,32.71301032268256,32.154477330686184,31.59594433868986,31.03741134669353,30.47887835469715,29.920345362700832,29.361812370704502,28.803279378708122,28.262839442891718,27.727899785322673,27.19296012775358,26.658020470184486,26.123080812615445,25.5881411550464,25.161566568172518,24.951722122688974,24.74187767720543,24.53203323172187,24.322188786238325,24.11234434075478,23.90249989527122,23.692655449787654,23.48281100430413,23.27296655882057,23.063122113337005,22.853277667853465,22.64343322236992,22.43358877688636,22.223744331402816,22.01389988591927,21.804055440435707,21.594210994952167,21.384366549468623,21.174522103985062,20.9646776585015,20.754833213017953,20.54498876753441,20.33514432205085,20.125299876567308,19.915455431083764,19.705610985600202,19.49576654011666,19.28592209463311,19.076077649149553,18.86623320366599,18.656388758182466,18.4465443126989,18.23669986721534,18.026855421731796,17.817010976248252,17.60716653076469,17.397322085281147,17.187477639797603,16.97763319431404,16.767788748830498,16.557944303346954,16.34809985786339,16.138255412379827,15.928410966896283,15.718566521412743,15.508722075929182,15.298877630445636,15.089033184962092,14.87918873947853,14.669344293994985,14.459499848511443,14.24965540302788,14.039810957544319,13.829966512060796,13.620122066577233,13.41027762109367,13.200433175610126,12.990588730126582,12.78074428464302,12.570899839159477,12.361055393675933,12.151210948192372,11.941366502708828,11.731522057225286,11.521677611741723,11.311833166258161,11.101988720774635,10.892144275291074,10.68229982980751,10.472455384323968,10.262610938840425,10.052766493356863,9.84292204787332,9.633077602389776,9.423233156906214,9.21338871142265,9.003544265939126,8.793699820455563,8.583855374972002,8.372222044338788,8.15129801532882,7.930373986318831,7.737502396773751,7.684893004552962,7.633559175814237,7.583429648452938,7.533300121091649,7.483170593730351,7.433041066369053,7.382911539007764,7.332782011646464,7.282652484285165,7.2325229569238765,7.182393429562579,7.13226390220128,7.08213437483998,7.032004847478691,6.981875320117393,6.931745792756095,6.881616265394804,6.831486738033506,6.781357210672207,6.731227683310918,6.68109815594962,6.63096862858832,6.580839101227031,6.530709573865732,6.480580046504434,6.430450519143136,6.380320991781846,6.3301914644205475,6.280061937059249,6.229932409697959,6.17980288233666,6.129673354975362,6.0795438276140725,6.029414300252774,5.979284772891475,5.929155245530177,5.879025718168888,5.828896190807589,5.77876666344629,5.728637136085002,5.678507608723703,5.640840644869844,5.612075512092731,5.583310379315613,5.554545246538494,5.525780113761381,5.497014980984263,5.468249848207144,5.439484715430025,5.410719582652913,5.381954449875793,5.353189317098676,5.324424184321562,5.295659051544444,5.266893918767325,5.238128785990212,5.209363653213094,5.180598520435975,5.151833387658856,5.123068254881743,5.094303122104625,5.065537989327506,5.036772856550393,5.008007723773274,4.979242590996156,4.950477458219043,4.921712325441924,4.892947192664806,4.8641820598876935,4.835416927110574,4.8066517943334555,4.777886661556337,4.7491215287792246,4.720356396002106,4.691591263224987,4.662826130447874,4.634060997670756,4.6052958648936375,4.576530732116525,4.547765599339406,4.519000466562287,4.489435491501364,4.459444168177307],[60.78918297964897,60.84184679158359,60.894510603518206,60.94717441545282,60.99983822738744,61.05250203932206,61.10516585125668,61.1578296631913,61.210493475125915,61.26315728706054,61.31582109899516,61.36848491092977,61.42114872286439,61.47381253479901,61.52647634673363,61.57931706826365,61.633042340557694,61.68676761285174,61.740492885145784,61.79421815743982,61.84794342973386,61.901668702027905,61.95539397432195,62.009119246615995,62.06284451891004,62.11656979120408,62.17029506349812,62.22402033579217,62.27774560808621,62.33147088038025,62.3851961526743,62.43892142496834,62.49264669726239,62.54637196955643,62.60009724185046,62.65382251414451,62.707547786438546,62.76127305873259,62.814998331026636,62.86872360332068,62.92244887561473,62.976174147908765,63.02989942020281,63.083624692496855,63.1373499647909,63.19107523708493,63.244800509378976,63.29852578167302,63.352251053967066,63.40597632626111,63.45970159855516,63.5134268708492,63.56715214314324,63.620877415437285,63.67460268773132,63.72832796002537,63.78205323231941,63.83577850461345,63.88950377690749,63.943229049201534,63.99695432149558,64.05067959378962,64.10440486608367,64.15813013837771,64.21185541067175,64.2655806829658,64.31930595525984,64.37303122755388,64.42675649984793,64.48048177214197,64.534207044436,64.58793231673005,64.64165758902409,64.69538286131814,64.74910813361218,64.80283340590623,64.85655867820026,64.91028395049432,64.96400922278835,65.0177344950824,65.07145976737644,65.12518503967048,65.17891031196453,65.23263558425857,65.27745880685305,65.32050161950761,65.36354443216217,65.40658724481673,65.44963005747128,65.49267287012586,65.5357156827804,65.57875849543497,65.62180130808953,65.6648441207441,65.70788693339865,65.75092974605322,65.79397255870778,65.83701537136234,65.8800581840169,65.92310099667147,65.96614380932603,66.00918662198059,66.05222943463515,66.09527224728971,66.13831505994428,66.18135787259882,66.2244006852534,66.26744349790795,66.31048631056252,66.35352912321707,66.39657193587163,66.43961474852621,66.48265756118076,66.52570037383532,66.56874318648988,66.61178599914444,66.654828811799,66.69787162445357,66.74091443710813,66.7839572497627,66.82700006241726,66.87004287507182,66.91308568772638,66.95612850038094,66.9991713130355,67.04221412569007,67.08525693834463,67.12829975099919,67.17134256365375,67.21438537630831,67.25742818896288,67.30047100161744,67.343513814272,67.38655662692656,67.42959943958112,67.47264225223567,67.51568506489023,67.55872787754481,67.60177069019936,67.64481350285392,67.68785631550848,67.73089912816305,67.77394194081761,67.81698475347216,67.86002756612673,67.9030703787813,67.94611319143586,67.98915600409042,68.03219881674498,68.07524162939954,68.11828444205409,68.16132725470867,68.20386785333469,68.2459062388113,68.28794462428792,68.32998300976452,68.37202139524112,68.41405978071774,68.45609816619434,68.49813655167095,68.54017493714755,68.58221332262416,68.62425170810077,68.66629009357737,68.70832847905399,68.75036686453059,68.7924052500072,68.82948229799426,68.86407867723653,68.89867505647882,68.93327143572111,68.96786781496337,69.00246419420566,69.03706057344795,69.07165695269023,69.1062533319325,69.14084971117478,69.17544609041707,69.21004246965934,69.24463884890163,69.2792352281439,69.31383160738619,69.34842798662847,69.38302436587075,69.41762074511303,69.45221712435531,69.48681350359759,69.52140988283986,69.55600626208215,69.59060264132442,69.62519902056671,69.659795399809,69.69439177905127,69.72898815829356,69.76358453753583,69.79818091677811,69.83277729602038,69.86737367526268,69.90197005450497,69.93656643374725,69.97116281298952,70.00575919223179,70.04035557147408,70.07495195071635,70.10954832995864,70.14414470920092,70.17874108844319,70.21333746768548,70.24793384692776,70.28253022617004,70.31712660541231,70.3517229846546,70.38631936389687,70.42091574313916,70.45551212238144,70.49010850162372,70.52470488086601,70.55930126010828,70.59389763935056,70.62849401859285,70.66309039783512,70.69768677707741,70.7322831563197,70.76687953556197,70.80147591480426,70.83607229404652,70.87066867328882,70.90526505253109,70.93986143177337,70.97445781101565,71.00905419025793,71.0436505695002,71.0782469487425,71.11284332798476,71.14743970722705,71.18203608646932,71.21663246571163,71.2512288449539,71.28582522419617,71.32042160343845,71.35501798268075,71.38961436192301,71.42421074116531,71.45880712040757,71.49340349964986,71.52799987889215,71.56259625813442,71.59719263737671,71.63178901661898,71.66638539586127,71.39400703375732,70.82646122087631,70.263390910208,69.70032059953971,69.13725028887134,68.57417997820303,68.01110966753474,67.44803935686639,66.88496904619804,66.32189873552979,65.75882842486143,65.19575811419307,64.63268780352476,64.06961749285647,63.506547182188115,62.94347687151981,62.38040656085151,61.81733625018315,61.25426593951485,60.69119562884655,60.12812531817819,59.56505500750984,59.00198469684159,58.43891438617323,57.87584407550487,57.31277376483657,56.74970345416827,56.18663314349991,55.62356283283161,55.06049252216331,54.49742221149496,53.9343519008266,53.371281590158354,52.808211279489996,52.245140968821644,51.68207065815334,51.11900034748504,50.555930036816676,49.992859726148374,49.42978941548007,48.86671910481172,48.30364879414341,47.74057848347511,47.17750817280675,46.6144378621384,46.05136755147015,45.4882972408018,44.92522693013344,44.36215661946514,43.79908630879684,43.23601599812848,42.67294568746018,42.10987537679188,41.546805066123525,40.98373475545516,40.42066444478691,39.85759413411856,39.294523823450206,38.7314535127819,38.168383202113596,37.60531289144524,37.04224258077694,36.479172270108634,35.91610195944028,35.35303164877198,34.78996133810368,34.22689102743532,33.66382071676696,33.10075040609871,32.53768009543036,31.97460978476201,31.411539474093704,30.848469163425403,30.285398852757048,29.722328542088743,29.159258231420438,28.596187920752083,28.033117610083778,27.470047299415477,26.906976988747125,26.343906678078774,25.78083636741047,25.217766056742164,24.77611820511709,24.57731527157848,24.378512338039876,24.179709404501253,23.980906470962644,23.782103537424035,23.583300603885412,23.384497670346786,23.1856947368082,22.98689180326957,22.788088869730945,22.589285936192343,22.390483002653735,22.191680069115108,21.9928771355765,21.794074202037894,21.595271268499268,21.396468334960662,21.197665401422057,20.99886246788343,20.800059534344804,20.6012566008062,20.40245366726759,20.19514718379446,19.9860043875557,19.77686159131694,19.56771879507816,19.358575998839402,19.14943320260064,18.94029040636186,18.73114761012308,18.52200481388434,18.312862017645557,18.10371922140678,17.89457642516802,17.68543362892926,17.47629083269048,17.26714803645172,17.05800524021296,16.84886244397418,16.63971964773542,16.43057685149666,16.22143405525788,16.0122912590191,15.803148462780339,15.59400566654158,15.3848628703028,15.175720074064039,14.96657727782528,14.757434481586497,14.548291685347738,14.339148889108976,14.130006092870197,13.92086329663142,13.711720500392676,13.502577704153898,13.293434907915117,13.084292111676358,12.875149315437596,12.666006519198817,12.456863722960058,12.247720926721298,12.038578130482517,11.829435334243758,11.620292538004996,11.411149741766218,11.202006945527437,10.992864149288696,10.783721353049916,10.574578556811137,10.365435760572376,10.156292964333616,9.947150168094836,9.738007371856076,9.528864575617316,9.319721779378536,9.110578983139757,8.901436186901016,8.692293390662236,8.483150594423456,8.274007798184696,8.064865001945936,7.855722205707156,7.673113428225915,7.623174744532134,7.573236060838354,7.523297377144576,7.473358693450806,7.423420009757026,7.373481326063246,7.3235426423694765,7.273603958675698,7.223665274981919,7.173726591288148,7.123787907594368,7.073849223900588,7.023910540206808,6.973971856513037,6.924033172819259,6.874094489125479,6.82415580543171,6.77421712173793,6.72427843804415,6.674339754350379,6.6244010706566,6.5744623869628205,6.52452370326905,6.474585019575271,6.424646335881491,6.374707652187711,6.324768968493942,6.274830284800162,6.224891601106383,6.174952917412613,6.125808812383399,6.078253861684287,6.030698910985183,5.983143960286071,5.935589009586958,5.888034058887845,5.840479108188742,5.7929241574896295,5.745369206790517,5.697814256091414,5.650259305392301,5.614412222243372,5.58692790163029,5.559443581017201,5.531959260404114,5.504474939791032,5.476990619177943,5.449506298564856,5.422021977951768,5.3945376573386845,5.367053336725598,5.339569016112509,5.311105456441977,5.282446048368586,5.253786640295196,5.225127232221811,5.196467824148421,5.167808416075031,5.139149008001641,5.110489599928256,5.081830191854866,5.053170783781476,5.024511375708091,4.995851967634701,4.967192559561311,4.938533151487927,4.909873743414536,4.881214335341146,4.852554927267761,4.82389551919437,4.795236111120981,4.766576703047591,4.737917294974206,4.709257886900817,4.6805984788274255,4.6519390707540405,4.62327966268065,4.5946202546072605,4.5659608465338755,4.537301438460486,4.5086420303870955,4.479982622313706,4.451323214240321],[61.00054489035143,61.05320870228605,61.105872514220664,61.158536326155286,61.21120013808991,61.263863950024515,61.31652776195914,61.36919157389376,61.42185538582838,61.474519197763,61.52718300969762,61.57984682163223,61.63251063356685,61.685174445501474,61.73783825743609,61.79050206937071,61.843165881305325,61.895829693239946,61.94849350517457,62.00115731710918,62.053821129043804,62.106484940978426,62.15914875291304,62.211812564847655,62.26447637678228,62.3171401887169,62.36980400065151,62.422467812586135,62.47513162452075,62.527795436455364,62.580459248389985,62.63312306032461,62.686494511859195,62.74021978415325,62.793945056447285,62.84767032874132,62.901395601035375,62.955120873329406,63.00884614562346,63.062571417917496,63.11629669021154,63.17002196250559,63.22374723479963,63.27747250709367,63.33119777938771,63.38492305168175,63.4386483239758,63.49237359626984,63.54609886856389,63.59982414085793,63.65354941315198,63.70727468544601,63.76099995774006,63.8147252300341,63.868450502328145,63.92217577462218,63.975901046916235,64.02962631921028,64.08335159150431,64.13707686379836,64.1908021360924,64.24452740838645,64.29825268068049,64.35197795297454,64.40570322526858,64.45942849756261,64.51315376985666,64.5668790421507,64.62060431444475,64.67432958673879,64.72805485903282,64.78178013132687,64.83550540362091,64.88923067591496,64.942955948209,64.99668122050305,65.0504064927971,65.10413176509114,65.15785703738517,65.21158230967922,65.26530758197326,65.3190328542673,65.37275812656134,65.4264833988554,65.47130662144987,65.51434943410442,65.557392246759,65.60043505941354,65.6434778720681,65.68652068472268,65.72956349737723,65.77260631003179,65.81564912268635,65.85869193534091,65.90173474799548,65.94477756065004,65.9878203733046,66.03086318595916,66.07390599861372,66.11694881126829,66.15999162392285,66.20303443657741,66.24607724923197,66.28912006188654,66.3321628745411,66.37520568719566,66.41824849985022,66.46129131250478,66.50433412515935,66.5473769378139,66.59041975046847,66.63346256312302,66.67650537577758,66.71954818843216,66.7625910010867,66.80563381374127,66.84867662639583,66.89171943905039,66.93476225170495,66.97780506435952,67.02084787701408,67.06389068966864,67.10693350232319,67.14997631497775,67.19301912763233,67.23606194028687,67.27910475294145,67.32214756559601,67.36519037825056,67.40823319090512,67.4512760035597,67.49431881621426,67.53736162886881,67.58040444152337,67.62344725417793,67.66649006622721,67.70852845170383,67.75056683718043,67.79260522265704,67.83464360813366,67.87668199361026,67.91872037908686,67.96075876456347,68.00279715004008,68.0448355355167,68.0868739209933,68.12891230646991,68.17095069194652,68.21298907742312,68.25502746289973,68.29706584837633,68.33910423385295,68.38114261932955,68.42318100480615,68.46521939028277,68.50725777575937,68.54929616123599,68.59133454671259,68.63337293218919,68.6754113176658,68.7174497031424,68.75948808861901,68.80152647409562,68.84356485957223,68.88560324504884,68.92764163052544,68.96968001600206,69.00675706398913,69.04135344323139,69.07594982247367,69.11054620171595,69.14514258095824,69.17973896020051,69.2143353394428,69.24893171868509,69.28352809792736,69.31812447716963,69.35272085641192,69.3873172356542,69.42191361489648,69.45650999413876,69.49110637338104,69.52570275262332,69.5602991318656,69.5948955111079,69.62949189035017,69.66408826959244,69.69868464883473,69.733281028077,69.76787740731929,69.80247378656156,69.83707016580385,69.87166654504612,69.90626292428841,69.94085930353069,69.97545568277297,70.01005206201526,70.04464844125754,70.07924482049981,70.1138411997421,70.14843757898437,70.18303395822666,70.21763033746893,70.25222671671122,70.2868230959535,70.32141947519577,70.35601585443806,70.39061223368033,70.4252086129226,70.45980499216489,70.49440137140718,70.52899775064947,70.56359412989173,70.59819050913401,70.6327868883763,70.66738326761858,70.70197964686086,70.73657602610314,70.77117240534542,70.80576878458771,70.84036516382997,70.87496154307226,70.90955792231455,70.94415430155681,70.97875068079911,71.01334706004138,71.04794343928367,71.08253981852594,71.11713619776822,71.1517325770105,71.18408667112568,71.21624857130095,71.2484104714762,71.28057237165144,71.3127342718267,71.34489617200197,71.3770580721772,71.40921997235246,71.44138187252773,71.47354377270297,71.50570567287822,71.53786757305348,71.57002947322873,71.60219137340398,71.63435327357924,71.66651517375449,71.69867707392974,71.73083897410498,71.76300087428024,71.79516277445549,71.52265628316398,70.9454814004057,70.36830651764747,69.79113163488924,69.21395675213095,68.63678186937273,68.05960698661448,67.4824321038562,66.90525722109791,66.32808233833974,65.75090745558145,65.17373257282317,64.59655769006494,64.01938280730671,63.44220792454843,62.8650330417902,62.28785815903196,61.71068327627368,61.13350839351544,60.55633351075722,59.97915862799893,59.40198374524064,58.82480886248247,58.247633979724185,57.6704590969659,57.09328421420767,56.516109331449435,55.93893444869116,55.36175956593292,54.78458468317469,54.20740980041641,53.63023491765813,53.05306003489994,52.475885152141664,51.89871026938337,51.32153538662514,50.744360503866915,50.169898050075815,49.606827739407514,49.04375742873921,48.48068711807086,47.91761680740255,47.35454649673425,46.79147618606589,46.22840587539754,45.66533556472929,45.10226525406093,44.53919494339258,43.97612463272428,43.41305432205598,42.84998401138761,42.28691370071931,41.723843390051,41.16077307938266,40.597702768714306,40.03463245804605,39.47156214737771,38.908491836709345,38.345421526041044,37.78235121537274,37.21928090470439,36.65621059403608,36.093140283367774,35.53006997269942,34.966999662031114,34.40392935136281,33.840859040694454,33.2777887300261,32.71471841935785,32.1516481086895,31.588577798021152,31.025507487352847,30.462437176684546,29.89936686601619,29.336296555347882,28.77322624467958,28.210155934011226,27.64708562334292,27.08401531267462,26.52094500200626,25.95787469133791,25.394804380669605,24.831734070001303,24.390086218376226,24.19128328483762,23.992480351299015,23.793677417760385,23.59487448422178,23.396071550683175,23.19726861714455,22.99846568360592,22.799662750067334,22.60085981652871,22.402056882990085,22.20325394945148,22.00445101591287,21.805648082374248,21.60684514883564,21.408042215297034,21.209239281758407,21.010436348219798,20.81163341468119,20.61283048114257,20.414027547603943,20.215224614065335,20.016421680526726,19.817618746988103,19.618815813449494,19.42001287991089,19.221209946372262,19.02240701283366,18.823604079295052,18.62480114575642,18.4259982122178,18.227195278679208,18.028392345140585,17.82958941160196,17.630786478063353,17.431983544524748,17.23318061098612,17.034377677447512,16.835574743908907,16.63677181037028,16.437968876831675,16.23916594329307,16.040363009754444,15.84156007621582,15.642757142677212,15.443954209138603,15.24515127559998,15.046348342061373,14.847545408522766,14.64874247498414,14.449939541445534,14.251136607906927,14.052333674368302,13.853530740829674,13.647326054441349,13.43818325820257,13.229040461963791,13.019897665725031,12.81075486948627,12.60161207324749,12.39246927700873,12.18332648076997,11.97418368453119,11.76504088829243,11.55589809205367,11.346755295814889,11.13761249957611,10.928469703337369,10.719326907098589,10.51018411085981,10.301041314621049,10.091898518382289,9.882755722143509,9.673612925904749,9.46447012966599,9.255327333427209,9.046184537188429,8.837041740949688,8.627898944710909,8.418756148472129,8.209613352233369,8.000470555994607,7.791327759755829,7.608718982274587,7.558780298580809,7.508841614887029,7.45890293119325,7.408964247499479,7.359025563805698,7.30908688011192,7.25914819641815,7.209209512724371,7.15927082903059,7.10933214533682,7.05939346164304,7.00945477794926,6.9595160942554815,6.9095774105617105,6.859986355972926,6.812431405273813,6.7648764545747095,6.717321503875597,6.669766553176485,6.62221160247738,6.574656651778268,6.527101701079157,6.479546750380053,6.43199179968094,6.384436848981828,6.336881898282716,6.289326947583612,6.2417719968845,6.194217046185388,6.146662095486284,6.099107144787172,6.051552194088059,6.003997243388956,5.956442292689843,5.90888734199073,5.861332391291619,5.8137774405925144,5.766222489893402,5.71866753919429,5.671112588495186,5.623557637796074,5.5877105546471455,5.560226234034062,5.532741913420973,5.505257592807887,5.477773272194804,5.450288951581715,5.422804630968628,5.39532031035554,5.367835989742457,5.340351669129369,5.312867348516281,5.285383027903199,5.257898707290112,5.2304143866770225,5.20293006606394,5.175445745450853,5.1479614248377645,5.120477104224677,5.092992783611594,5.0655084629985065,5.038024142385418,5.010539821772336,4.983055501159248,4.95557118054616,4.928086859933076,4.90060253931999,4.873093738396758,4.844434330323372,4.815774922249982,4.787115514176593,4.7584561061032025,4.729796698029817,4.701137289956428,4.6724778818830375,4.643818473809652,4.615159065736262,4.5864996576628725,4.557840249589487,4.529180841516098,4.500521433442707,4.471862025369317,4.443202617295933],[61.2119068010539,61.26457061298852,61.31723442492313,61.36989823685775,61.42256204879237,61.475225860726994,61.52788967266161,61.58055348459623,61.63321729653085,61.685881108465466,61.73854492040009,61.7912087323347,61.843872544269324,61.896536356203946,61.94920016813857,62.00186398007318,62.054527792007804,62.107191603942425,62.15985541587703,62.212519227811654,62.265183039746276,62.3178468516809,62.37051066361551,62.42317447555013,62.475838287484756,62.52850209941937,62.58116591135399,62.633829723288606,62.68649353522323,62.73915734715784,62.791821159092464,62.844484971027086,62.89714878296169,62.949812594896315,63.00247640683094,63.05514021876556,63.10780403070017,63.16046784263479,63.21313165456941,63.26579546650403,63.31845927843865,63.37112309037326,63.423786902307896,63.4764507142425,63.529114526177125,63.58177833811174,63.634442150046354,63.68710596198098,63.73994668316071,63.793671955454755,63.8473972277488,63.901122500042845,63.95484777233688,64.00857304463094,64.06229831692497,64.11602358921901,64.16974886151306,64.2234741338071,64.27719940610113,64.33092467839518,64.38464995068922,64.43837522298327,64.49210049527731,64.54582576757136,64.5995510398654,64.65327631215945,64.70700158445348,64.76072685674754,64.81445212904157,64.86817740133561,64.92190267362966,64.9756279459237,65.02935321821774,65.08307849051178,65.13680376280583,65.19052903509987,65.24425430739392,65.29797957968796,65.351704851982,65.40543012427605,65.45915539657008,65.51288066886413,65.56660594115816,65.62033121345222,65.66515443604669,65.70819724870125,65.75124006135582,65.79428287401038,65.83732568666494,65.8803684993195,65.92341131197405,65.96645412462863,66.00949693728317,66.05253974993775,66.0955825625923,66.13862537524687,66.18166818790142,66.22471100055598,66.26775381321055,66.31079662586512,66.35383943851967,66.39688225117423,66.4399250638288,66.48296787648336,66.52601068913792,66.56905350179248,66.61209631444704,66.65513912710159,66.69818193975617,66.74122475241073,66.78426756506529,66.82731037771985,66.8703531903744,66.91339600302898,66.95643881568353,66.99948162833809,67.04252444099265,67.08556725364721,67.12861006630177,67.17115066459635,67.21318905007296,67.25522743554957,67.29726582102617,67.33930420650279,67.38134259197939,67.423380977456,67.46541936293261,67.50745774840922,67.54949613388582,67.59153451936244,67.63357290483904,67.67561129031566,67.71764967579226,67.75968806126886,67.80172644674548,67.84376483222208,67.8858032176987,67.9278416031753,67.96987998865191,68.01191837412851,68.05395675960511,68.09599514508173,68.13803353055833,68.18007191603493,68.22211030151155,68.26414868698816,68.30618707246477,68.34822545794137,68.39026384341798,68.4323022288946,68.4743406143712,68.5163789998478,68.5584173853244,68.600455770801,68.64249415627762,68.68453254175424,68.72657092723084,68.76860931270744,68.81064769818406,68.85268608366067,68.89472446913727,68.93676285461387,68.97880124009049,69.02083962556709,69.0628780110437,69.10491639652031,69.14695478199691,69.18403182998398,69.21862820922625,69.25322458846854,69.28782096771081,69.3224173469531,69.35701372619538,69.39161010543765,69.42620648467994,69.46080286392223,69.4953992431645,69.52999562240677,69.56459200164906,69.59918838089135,69.63378476013362,69.6683811393759,69.70297751861818,69.73757389786046,69.77217027710275,69.80676665634502,69.8413630355873,69.8759594148296,69.91055579407187,69.94515217331414,69.97974855255643,70.01434493179872,70.04894131104099,70.08353769028326,70.11813406952555,70.15273044876784,70.18732682801011,70.2219232072524,70.25651958649468,70.29111596573695,70.32571234497924,70.36030872422151,70.3949051034638,70.42950148270607,70.46409786194835,70.49869424119063,70.53329062043292,70.5678869996752,70.60248337891747,70.63707975815976,70.66949791702729,70.70165981720254,70.7338217173778,70.76598361755305,70.7981455177283,70.83030741790355,70.86246931807881,70.89463121825406,70.92679311842932,70.95895501860457,70.99111691877982,71.02327881895508,71.05544071913033,71.08760261930558,71.11976451948084,71.15192641965609,71.18408831983133,71.2162502200066,71.24841212018184,71.2805740203571,71.31273592053235,71.34489782070762,71.37705972088287,71.40922162105811,71.44138352123336,71.47354542140863,71.50570732158388,71.53786922175912,71.57003112193438,71.60219302210963,71.63435492228488,71.66651682246012,71.69867872263539,71.73084062281063,71.7630025229859,71.79516442316114,71.8273263233364,71.85948822351165,71.8916501236869,71.92381202386215,71.65130553257065,71.07413064981236,70.49695576705412,69.9197808842959,69.3426060015376,68.76543111877939,68.18825623602115,67.61108135326286,67.03390647050458,66.45673158774639,65.87955670498812,65.30238182222983,64.7252069394716,64.14803205671336,63.57085717395509,62.99368229119685,62.41650740843862,61.839332525680334,61.262157642922105,60.68498276016388,60.10780787740559,59.530632994647306,58.953458111889134,58.37628322913085,57.79910834637256,57.221933463614334,56.6447585808561,56.06758369809781,55.490408815339585,54.91323393258135,54.336059049823064,53.758884167064785,53.181709284306606,52.60453440154832,52.027359518790036,51.45018463603181,50.87300975327358,50.29583487051529,49.71865998775706,49.14148510499882,48.564310222240536,47.98713533948231,47.40996045672407,46.83278557396579,46.25561069120751,45.67843580844932,45.101260925691044,44.52408604293276,43.94691116017452,43.369736277416294,42.79256139465801,42.21538651189978,41.63821162914155,41.061036746383266,40.48386186362498,39.9066869808668,39.329512098108516,38.75233721535023,38.175162332592,37.59798744983377,37.02081256707549,36.44363768431725,35.866462801559024,35.28928791880074,34.71211303604251,34.13493815328428,33.557763270525996,32.98058838776771,32.40341350500953,31.826238622251246,31.24906373949296,30.671888856734732,30.094713973976503,29.517539091218218,28.950264568607004,28.3871942579387,27.824123947270348,27.261053636602043,26.69798332593374,26.134913015265386,25.57184270459703,25.00877239392873,24.445702083260425,24.004054231635347,23.805251298096742,23.606448364558133,23.40764543101951,23.208842497480905,23.0100395639423,22.811236630403673,22.612433696865047,22.413630763326456,22.214827829787833,22.016024896249206,21.8172219627106,21.618419029171992,21.419616095633366,21.22081316209476,21.022010228556155,20.823207295017532,20.624404361478923,20.425601427940318,20.22679849440169,20.027995560863065,19.82919262732446,19.63038969378585,19.431586760247228,19.23278382670862,19.033980893170014,18.835177959631384,18.63637502609278,18.43757209255417,18.238769159015547,18.03996622547692,17.841163291938336,17.642360358399706,17.443557424861083,17.244754491322478,17.045951557783866,16.847148624245243,16.648345690706638,16.449542757168032,16.250739823629402,16.051936890090797,15.853133956552192,15.654331023013565,15.45552808947494,15.256725155936333,15.057922222397728,14.859119288859103,14.660316355320496,14.461513421781886,14.262710488243261,14.063907554704656,13.865104621166047,13.666301687627422,13.467498754088798,13.26869582055021,13.069892887011584,12.87108995347296,12.672287019934354,12.473484086395747,12.274681152857122,12.075878219318515,11.877075285779906,11.67827235224128,11.479469418702674,11.280666485164067,11.081863551625442,10.883060618086818,10.684257684548228,10.485454751009604,10.286651817470979,10.088735321320666,9.891133356319521,9.693531391318356,9.49592942631721,9.298327461316063,9.100725496314901,8.903123531313735,8.705521566312608,8.507919601311443,8.31031763631028,8.112715671309134,7.915113706307988,7.717511741306821,7.544935415563601,7.497487286109877,7.450039156656152,7.402591027202429,7.355142897748714,7.30769476829499,7.2602466388412665,7.212798509387553,7.165350379933827,7.117902250480104,7.070454121026389,7.023005991572665,6.975557862118941,6.928109732665218,6.880661603211503,6.833213473757779,6.785729737677585,6.7381747869784805,6.690619836279368,6.643064885580256,6.595509934881152,6.547954984182039,6.5004000334829275,6.452845082783824,6.405290132084711,6.357735181385599,6.310180230686488,6.262625279987383,6.215070329288271,6.167515378589159,6.119960427890055,6.072405477190943,6.0248505264918295,5.977295575792727,5.929740625093614,5.882185674394501,5.83463072369539,5.787075772996285,5.739520822297173,5.691965871598061,5.644410920898958,5.596855970199845,5.561008887050916,5.533524566437833,5.506040245824745,5.478555925211658,5.451071604598575,5.423587283985487,5.396102963372399,5.368618642759311,5.341134322146228,5.313650001533141,5.286165680920052,5.258681360306969,5.231197039693882,5.203712719080794,5.176228398467712,5.148744077854624,5.1212597572415355,5.093775436628448,5.066291116015365,5.0388067954022775,5.011322474789189,4.983838154176107,4.9563538335630195,4.928869512949932,4.901385192336848,4.873900871723761,4.846466219006621,4.8190414995638164,4.791616780121007,4.764192060678197,4.736767341235388,4.709342621792583,4.681917902349774,4.654493182906963,4.627068463464159,4.599643744021349,4.57221902457854,4.544794305135735,4.517369585692925,4.489944866250116,4.4625201468073055,4.435095427364502],[61.423268711756364,61.475932523690986,61.5285963356256,61.58126014756022,61.63392395949484,61.68658777142946,61.739251583364066,61.79191539529869,61.84457920723331,61.89724301916793,61.94990683110255,62.00257064303717,62.05523445497179,62.10789826690641,62.160562078841025,62.21322589077565,62.26588970271026,62.31855351464488,62.371217326579504,62.42388113851412,62.47654495044874,62.52920876238336,62.581872574317984,62.63453638625259,62.68720019818721,62.739864010121835,62.79252782205645,62.84519163399107,62.89785544592569,62.95051925786031,63.00318306979492,63.055846881729536,63.10851069366416,63.16117450559878,63.2138383175334,63.26650212946802,63.319165941402645,63.37182975333725,63.424493565271874,63.477157377206495,63.52982118914112,63.582485001075725,63.635148813010346,63.68781262494497,63.74047643687958,63.793140248814204,63.84580406074882,63.89846787268344,63.951131684618055,64.00379549655267,64.05645930848729,64.10912312042191,64.16178693235653,64.21445074429116,64.26711455622576,64.31977836816039,64.372442180095,64.42510599202963,64.47776980396425,64.53043361589887,64.58309742783348,64.6357612397681,64.68842505170272,64.74108886363734,64.79375267557197,64.84712412675627,64.90084939905032,64.95457467134435,65.0082999436384,65.06202521593244,65.11575048822648,65.16947576052053,65.22320103281457,65.27692630510862,65.33065157740266,65.38437684969671,65.43810212199074,65.49182739428478,65.54555266657883,65.59927793887287,65.65300321116692,65.70672848346096,65.760453755755,65.81417902804904,65.85900225064351,65.90204506329809,65.94508787595264,65.9881306886072,66.03117350126176,66.07421631391632,66.11725912657089,66.16030193922545,66.20334475188001,66.24638756453457,66.28943037718913,66.3324731898437,66.37551600249826,66.41855881515282,66.46160162780738,66.50464444046193,66.5476872531165,66.59073006577107,66.63377287748888,66.6758112629655,66.7178496484421,66.75988803391871,66.80192641939531,66.84396480487193,66.88600319034853,66.92804157582513,66.97007996130175,67.01211834677835,67.05415673225497,67.09619511773157,67.13823350320817,67.18027188868479,67.22231027416139,67.264348659638,67.3063870451146,67.34842543059122,67.39046381606784,67.43250220154442,67.47454058702102,67.51657897249764,67.55861735797426,67.60065574345086,67.64269412892747,67.68473251440409,67.72677089988068,67.76880928535729,67.81084767083391,67.85288605631051,67.89492444178711,67.93696282726371,67.97900121274033,68.02103959821694,68.06307798369355,68.10511636917016,68.14715475464675,68.18919314012336,68.23123152559998,68.27326991107658,68.31530829655318,68.3573466820298,68.39938506750642,68.441423452983,68.48346183845962,68.52550022393623,68.56753860941285,68.60957699488945,68.65161538036605,68.69365376584267,68.73569215131926,68.77773053679587,68.81976892227249,68.86180730774909,68.90384569322569,68.9458840787023,68.98792246417892,69.02996084965551,69.07199923513213,69.11403762060874,69.15607600608534,69.19811439156194,69.24015277703856,69.28219116251516,69.32422954799178,69.36130659597883,69.3959029752211,69.4304993544634,69.46509573370567,69.49969211294795,69.53428849219023,69.56888487143252,69.60348125067479,69.63807762991706,69.67267400915935,69.70727038840162,69.74186676764391,69.7764631468862,69.81105952612847,69.84565590537076,69.88025228461304,69.91484866385532,69.9494450430976,69.98404142233989,70.01863780158216,70.05323418082443,70.08783056006672,70.122426939309,70.15490916292889,70.18707106310413,70.2192329632794,70.25139486345465,70.2835567636299,70.31571866380516,70.3478805639804,70.38004246415565,70.4122043643309,70.44436626450616,70.47652816468141,70.50869006485667,70.54085196503192,70.57301386520717,70.60517576538243,70.63733766555768,70.66949956573293,70.70166146590819,70.73382336608344,70.7659852662587,70.79814716643394,70.8303090666092,70.86247096678446,70.89463286695971,70.92679476713496,70.95895666731022,70.99111856748546,71.02328046766073,71.05544236783597,71.08760426801122,71.11976616818647,71.15192806836173,71.18408996853698,71.21625186871223,71.24841376888749,71.28057566906276,71.312737569238,71.34489946941325,71.3770613695885,71.40922326976374,71.44138516993901,71.47354707011426,71.50570897028952,71.53787087046476,71.57003277064001,71.60219467081528,71.63435657099053,71.66651847116577,71.69868037134103,71.73084227151628,71.76300417169153,71.79516607186679,71.82732797204204,71.8594898722173,71.89165177239255,71.9238136725678,71.95597557274306,71.98813747291831,72.02029937309356,72.05246127326882,71.7799547819773,71.20277989921901,70.62560501646078,70.04843013370255,69.47125525094427,68.89408036818602,68.3169054854278,67.73973060266951,67.16255571991124,66.58538083715305,66.00820595439477,65.43103107163648,64.85385618887825,64.27668130612003,63.69950642336174,63.12233154060351,62.54515665784528,61.967981775087,61.39080689232876,60.813632009570526,60.23645712681224,59.65928224405396,59.08210736129579,58.504932478537505,57.92775759577922,57.350582713020984,56.773407830262755,56.19623294750447,55.61905806474624,55.041883181988005,54.46470829922972,53.887533416471435,53.31035853371326,52.73318365095498,52.1560087681967,51.578833885438456,51.001659002680235,50.42448411992195,49.847309237163714,49.27013435440547,48.69295947164719,48.11578458888896,47.53860970613073,46.96143482337244,46.38425994061416,45.80708505785598,45.2299101750977,44.652735292339415,44.07556040958118,43.49838552682295,42.921210644064665,42.34403576130643,41.76286636266504,41.1735746812296,40.58428299979416,39.99499131835884,39.40569963692341,38.816407955487975,38.22711627405259,37.63782459261721,37.04853291118177,36.4592412297464,35.86994954831101,35.28065786687558,34.6913661854402,34.10207450400482,33.512782822569385,32.92349114113395,32.334199459698624,31.744907778263187,31.155616096827753,30.566324415392376,29.977032733956992,29.38774105252156,28.79844937108618,28.209157689650795,27.61986600821536,27.030574326779984,26.441282645344604,25.851990963909167,25.262699282473733,24.67340760103835,24.084115919602972,23.628608958753677,23.440671439076567,23.252733919399454,23.064796399722326,22.876858880045216,22.68892136036811,22.50098384069098,22.313046321013854,22.12510880133676,21.937171281659637,21.749233761982506,21.561296242305396,21.373358722628286,21.185421202951158,20.99748368327405,20.80954616359694,20.621608643919814,20.4336711242427,20.24573360456559,20.057796084888466,19.869858565211338,19.681921045534228,19.493983525857118,19.30604600617999,19.117941846881774,18.92033988188063,18.72273791687946,18.525135951878312,18.327533986877167,18.12993202187601,17.93233005687484,17.734728091873713,17.53712612687255,17.33952416187139,17.14192219687024,16.944320231869092,16.74671826686793,16.549116301866782,16.351514336865634,16.15391237186447,15.956310406863325,15.75870844186218,15.561106476861013,15.363504511859851,15.165902546858705,14.968300581857555,14.770698616856393,14.573096651855248,14.375494686854102,14.177892721852935,13.98029075685179,13.782688791850646,13.585086826849484,13.387484861848314,13.189882896847191,12.992280931846025,12.794678966844863,12.597077001843717,12.39947503684257,12.201873071841403,12.004271106840257,11.806669141839112,11.609067176837945,11.411465211836799,11.213863246835654,11.016261281834492,10.818659316833324,10.6210573518322,10.423455386831032,10.225853421829871,10.028251456828725,9.830649491827579,9.633047526826413,9.435445561825267,9.23784359682412,9.040241631822957,8.842639666821793,8.645037701820666,8.4474357368195,8.249833771818338,8.052231806817192,7.854629841816045,7.657027876814879,7.484451551071658,7.437003421617934,7.389555292164211,7.342107162710487,7.294659033256772,7.247210903803047,7.199762774349323,7.1523146448956085,7.104866515441886,7.0574183859881625,7.009970256534446,6.962522127080723,6.915073997626999,6.867625868173275,6.82017773871956,6.772729609265836,6.7252814798121126,6.677833350358398,6.6303852209046745,6.58293709145095,6.535488961997235,6.488040832543511,6.440592703089788,6.393144573636073,6.345696444182349,6.298248314728625,6.250800185274901,6.203352055821186,6.15737295717076,6.11222095994782,6.067068962724887,6.021916965501946,5.976764968279005,5.931612971056073,5.886460973833131,5.84130897661019,5.7961569793872485,5.751004982164316,5.705852984941375,5.6607009877184336,5.615548990495501,5.57039699327256,5.536252810909595,5.509971353446614,5.483689895983629,5.457408438520644,5.431126981057663,5.404845523594678,5.378564066131692,5.352282608668707,5.326001151205726,5.299719693742741,5.273438236279755,5.247156778816776,5.220875321353789,5.1945938638908045,5.167710042572797,5.140285323129988,5.112860603687178,5.085435884244368,5.058011164801564,5.030586445358754,5.003161725915945,4.975737006473139,4.94831228703033,4.9208875675875206,4.893462848144717,4.8660381287019066,4.838613409259097,4.8111886898162926,4.783763970373482,4.756339250930672,4.728914531487863,4.701489812045058,4.674065092602249,4.646640373159439,4.619215653716634,4.591790934273824,4.564366214831015,4.536941495388211,4.509516775945401,4.482092056502591,4.454667337059782,4.427242617616977],[61.63463062245882,61.68729443439344,61.73995824632806,61.79262205826268,61.8452858701973,61.897949682131916,61.95061349406653,62.003277306001145,62.05594111793577,62.10860492987039,62.161268741805,62.213932553739625,62.266596365674246,62.31926017760887,62.37192398954348,62.424587801478104,62.47725161341272,62.52991542534734,62.58257923728196,62.63524304921658,62.68790686115119,62.74057067308581,62.793234485020434,62.84589829695505,62.89856210888968,62.95122592082429,63.0038897327589,63.05655354469353,63.109217356628136,63.16188116856276,63.21454498049738,63.267208792431994,63.31987260436662,63.37253641630123,63.42520022823585,63.47786404017047,63.530527852105095,63.58319166403972,63.635855475974324,63.68851928790895,63.74118309984357,63.79384691177819,63.84651072371281,63.89917453564742,63.95183834758204,64.00450215951666,64.05716597145128,64.1098297833859,64.16249359532051,64.21515740725513,64.26782121918976,64.32048503112438,64.373148843059,64.42581265499362,64.47847646692823,64.53114027886285,64.58380409079747,64.63646790273208,64.6891317146667,64.74179552660132,64.79445933853594,64.84712315047057,64.89978696240519,64.9524507743398,65.00511458627442,65.05777839820904,65.11044221014366,65.16310602207828,65.21576983401289,65.26843364594751,65.32109745788213,65.37376126981675,65.42642508175138,65.47908889368598,65.5317527056206,65.58441651755523,65.63708032948983,65.68974414142446,65.74240795335908,65.79507176529368,65.84773557722832,65.90057629805777,65.95430157035182,66.00802684264586,66.05285006524034,66.0958928778949,66.13843347585801,66.18047186133462,66.22251024681124,66.26454863228784,66.30658701776444,66.34862540324106,66.39066378871766,66.43270217419428,66.47474055967088,66.5167789451475,66.5588173306241,66.6008557161007,66.64289410157731,66.68493248705391,66.72697087253053,66.76900925800713,66.81104764348373,66.85308602896035,66.89512441443695,66.93716279991357,66.97920118539017,67.02123957086678,67.06327795634338,67.10531634182,67.1473547272966,67.1893931127732,67.23143149824982,67.27346988372642,67.31550826920304,67.35754665467964,67.39958504015624,67.44162342563286,67.48366181110947,67.52570019658607,67.56773858206267,67.60977696753929,67.65181535301589,67.6938537384925,67.73589212396911,67.77793050944572,67.81996889492233,67.86200728039893,67.90404566587553,67.94608405135214,67.98812243682875,68.03016082230536,68.07219920778196,68.11423759325857,68.15627597873518,68.1983143642118,68.24035274968838,68.282391135165,68.3244295206416,68.36646790611822,68.40850629159482,68.45054467707143,68.49258306254804,68.53462144802464,68.57665983350125,68.61869821897787,68.66073660445447,68.70277498993109,68.74481337540769,68.7868517608843,68.8288901463609,68.87092853183752,68.91296691731411,68.95500530279071,68.99704368826733,69.03908207374394,69.08112045922054,69.12315884469716,69.16519723017376,69.20723561565038,69.24927400112698,69.2913123866036,69.3333507720802,69.3753891575568,69.41742754303341,69.45946592851001,69.50150431398663,69.53858136197368,69.57317774121596,69.60777412045825,69.64032040883049,69.67248230900574,69.70464420918098,69.73680610935625,69.76896800953149,69.80112990970675,69.833291809882,69.86545371005725,69.8976156102325,69.92977751040776,69.96193941058301,69.99410131075827,70.02626321093351,70.05842511110878,70.09058701128401,70.12274891145928,70.15491081163454,70.18707271180979,70.21923461198504,70.25139651216028,70.28355841233554,70.31572031251079,70.34788221268606,70.3800441128613,70.41220601303655,70.4443679132118,70.47652981338706,70.50869171356231,70.54085361373757,70.57301551391282,70.60517741408806,70.63733931426333,70.66950121443858,70.70166311461384,70.73382501478909,70.76598691496434,70.79814881513958,70.83031071531484,70.8624726154901,70.89463451566535,70.9267964158406,70.95895831601585,70.9911202161911,71.02328211636636,71.05544401654161,71.08760591671688,71.11976781689212,71.15192971706738,71.18409161724263,71.21625351741788,71.24841541759312,71.28057731776838,71.31273921794364,71.34490111811888,71.37706301829415,71.40922491846939,71.44138681864465,71.4735487188199,71.50571061899515,71.5378725191704,71.57003441934566,71.60219631952091,71.63435821969617,71.66652011987144,71.69868202004668,71.73084392022193,71.76300582039718,71.79516772057244,71.82732962074769,71.85949152092293,71.8916534210982,71.92381532127345,71.95597722144869,71.98813912162396,72.0203010217992,72.05246292197445,72.08462482214972,72.11678672232496,72.14894862250021,72.18111052267547,71.90860403138396,71.33142914862569,70.75425426586743,70.17707938310922,69.59990450035093,69.02272961759269,68.44555473483446,67.86837985207617,67.29120496931789,66.71403008655972,66.13645577148083,65.54716409004538,64.95787240861,64.36858072717463,63.7792890457392,63.189997364303814,62.60070568286844,62.011414001433,61.42212231999762,60.832830638562235,60.2435389571268,59.65424727569137,59.06495559425604,58.47566391282061,57.886372231385174,57.2970805499498,56.70778886851442,56.11849718707898,55.529205505643596,54.93991382420822,54.35062214277278,53.76133046133736,53.172038779902024,52.58274709846659,51.99345541703116,51.40416373559578,50.814872054160396,50.22558037272496,49.63628869128958,49.0469970098542,48.45770532841876,47.868413646983385,47.279121965548,46.68983028411257,46.10053860267713,45.511246921241806,44.921955239806366,44.33266355837094,43.743371876935555,43.15408019550017,42.564788514064745,41.97549683262936,41.38620515119398,40.79691346975855,40.20762178832311,39.61833010688778,39.029038425452356,38.439746744016915,37.85045506258153,37.261163381146154,36.67187169971072,36.08258001827534,35.49328833683996,34.90399665540453,34.31470497396914,33.72541329253376,33.13612161109833,32.5468299296629,31.957538248227568,31.368246566792134,30.7789548853567,30.18966320392132,29.600371522485936,29.011079841050503,28.421788159615126,27.83249647817974,27.24320479674431,26.653913115308924,26.064621433873544,25.475329752438114,24.886038071002677,24.296746389567296,23.707454708131912,23.251947747282617,23.064010227605507,22.8760727079284,22.688135188251273,22.500197668574163,22.312260148897053,22.124322629219925,21.936385109542798,21.748447589865705,21.560510070188577,21.37257255051145,21.184635030834343,20.99669751115723,20.808759991480105,20.620822471802995,20.43288495212588,20.244947432448757,20.057009912771644,19.869072393094534,19.681134873417406,19.493197353740285,19.305259834063172,19.117322314386062,18.929384794708934,18.741447275031824,18.553509755354714,18.365572235677583,18.177634716000476,17.98969719632337,17.801759676646242,17.61382215696911,17.42588463729202,17.237947117614894,17.050009597937766,16.862072078260653,16.674134558583546,16.48619703890642,16.298259519229312,16.1103219995522,15.922384479875072,15.73444696019796,15.54650944052085,15.358571920843723,15.170634401166597,14.982696881489485,14.794759361812375,14.60682184213525,14.41888432245814,14.230946802781029,14.0430092831039,13.85507176342679,13.66713424374968,13.479196724072553,13.291259204395427,13.103321684718335,12.915384165041207,12.727446645364079,12.536593137351772,12.338991172350626,12.141389207349462,11.943787242348314,11.746185277347166,11.548583312346004,11.350981347344858,11.153379382343712,10.955777417342546,10.758175452341384,10.560573487340255,10.362971522339091,10.165369557337925,9.96776759233678,9.770165627335633,9.572563662334469,9.374961697333324,9.177359732332178,8.979757767331014,8.78215580232985,8.584553837328723,8.386951872327558,8.189349907326394,7.991747942325248,7.794145977324103,7.596544012322935,7.423967686579715,7.376519557125992,7.329071427672267,7.281623298218544,7.234175168764829,7.186727039311105,7.1392789098573814,7.091830780403667,7.044382650949943,6.996934521496218,6.9494863920425045,6.90203826258878,6.854590133135056,6.809305430785949,6.764153433563017,6.719001436340076,6.673849439117134,6.628697441894202,6.583545444671261,6.538393447448319,6.493241450225387,6.448089453002447,6.402937455779505,6.357785458556572,6.312633461333631,6.26748146411069,6.222329466887749,6.177177469664816,6.132025472441875,6.086873475218933,6.041721477996001,5.99656948077306,5.951417483550118,5.906265486327187,5.861113489104246,5.815961491881303,5.770809494658362,5.72565749743543,5.680505500212489,5.635353502989547,5.590201505766615,5.545049508543674,5.510905326180708,5.484623868717728,5.458342411254742,5.4320609537917575,5.405779496328776,5.379498038865792,5.3532165814028065,5.326935123939822,5.30065366647684,5.2743722090138565,5.24809075155087,5.2218092940878895,5.195527836624905,5.169246379161919,5.142964921698939,5.116683464235953,5.090402006772967,5.0641205493099815,5.037839091847001,5.011557634384016,4.9852761769210305,4.95899471945805,4.932713261995065,4.9064318045320805,4.880150347069099,4.8538688896061135,4.827587432143129,4.801305974680148,4.7750245172171635,4.7484864411831476,4.721061721740338,4.693637002297534,4.666212282854724,4.638787563411914,4.6113628439691094,4.5839381245263,4.556513405083491,4.529088685640686,4.501663966197876,4.474239246755067,4.446814527312257,4.419389807869452],[61.822619835424305,61.87528364735892,61.927947459293534,61.980611271228156,62.03327508316278,62.0859388950974,62.138602707032014,62.19126651896663,62.24393033090125,62.29659414283587,62.34925795477049,62.4019217667051,62.45458557863972,62.507249390574344,62.559913202508966,62.61257701444358,62.665240826378195,62.71790463831282,62.77056845024744,62.82323226218206,62.875896074116675,62.928559886051296,62.98122369798591,63.03388750992053,63.086551321855154,63.139215133789776,63.19187894572439,63.244542757659005,63.29720656959363,63.34987038152825,63.402534193462856,63.45519800539748,63.5078618173321,63.56052562926672,63.61318944120134,63.665853253135964,63.71851706507058,63.77118087700519,63.823844688939815,63.87650850087443,63.92917231280905,63.98183612474367,64.03449993667829,64.08716374861291,64.13982756054752,64.19249137248215,64.24515518441676,64.29781899635138,64.350482808286,64.40314662022061,64.45581043215525,64.50847424408985,64.56113805602448,64.6138018679591,64.6664656798937,64.71912949182834,64.77179330376295,64.82445711569757,64.87712092763219,64.92978473956681,64.98244855150143,65.03511236343604,65.08777617537068,65.14043998730529,65.1931037992399,65.24576761117453,65.29843142310914,65.35109523504376,65.40375904697837,65.45642285874415,65.50882802246417,65.5612331861842,65.61363834990422,65.66604351362423,65.71844867734427,65.7708538410643,65.82325900478432,65.87566416850433,65.92806933222435,65.98047449594439,66.03287965966442,66.08528482338443,66.13768998710445,66.19009515082449,66.23295769319509,66.27391171129582,66.31486572939654,66.35581974749728,66.396773765598,66.43772778369873,66.47868180179947,66.51963581990019,66.56058983800092,66.60154385610166,66.64249787420238,66.68345189230311,66.72440591040383,66.76535992850455,66.80703685748131,66.84907524295791,66.89111362843451,66.93315201391113,66.97519039938773,67.01722878486434,67.05926717034095,67.10130555581756,67.14334394129418,67.18538232677078,67.22742071224738,67.26945909772398,67.3114974832006,67.3535358686772,67.39557425415381,67.43761263963043,67.47965102510703,67.52168941058363,67.56372779606023,67.60576618153685,67.64780456701345,67.68984295249007,67.73188133796668,67.77391972344327,67.81595810891989,67.8579964943965,67.9000348798731,67.9420732653497,67.98411165082632,68.02615003630294,68.06818842177952,68.11022680725614,68.15226519273274,68.19430357820936,68.23634196368596,68.27838034916257,68.32041873463918,68.36245712011579,68.4044955055924,68.44653389106901,68.4885722765456,68.53061066202221,68.57264904749883,68.61468743297544,68.65672581845203,68.69876420392865,68.74080258940526,68.78284097488186,68.82487936035847,68.86691774583508,68.9089561313117,68.9509945167883,68.9930329022649,69.03507128774152,69.07710967321812,69.11914805869473,69.16118644417134,69.20322482964795,69.24526321512454,69.28730160060115,69.32933998607777,69.37137837155437,69.41341675703097,69.45545514250759,69.49749352798419,69.5395319134608,69.58157029893741,69.62360868441402,69.66564706989062,69.69875963831356,69.72740929820965,69.75605895810574,69.78470861800183,69.81335827789792,69.84200793779402,69.87065759769011,69.8993072575862,69.92795691748229,69.95660657737838,69.98525623727447,70.01390589717056,70.04255555706666,70.07120521696275,70.09985487685884,70.12850453675495,70.15848816608577,70.19069508393167,70.22290200177757,70.25510891962347,70.28731583746935,70.31952275531526,70.35172967316115,70.38393659100704,70.41614350885294,70.44835042669882,70.48055734454474,70.51276426239062,70.54497118023652,70.57717809808241,70.60938501592831,70.64159193377421,70.6737988516201,70.706005769466,70.7382126873119,70.7704196051578,70.8026265230037,70.8348334408496,70.86704035869548,70.89924727654137,70.93145419438727,70.96366111223317,70.99586803007907,71.02807494792495,71.06028186577086,71.09248878361674,71.12469570146264,71.15690261930855,71.18910953715444,71.22131645500033,71.25352337284622,71.28573029069213,71.31793720853801,71.35014412638391,71.38235104422982,71.4145579620757,71.4467648799216,71.4789717977675,71.5111787156134,71.5433856334593,71.57559255130519,71.60779946915109,71.64000638699699,71.67221330484287,71.70442022268877,71.73662714053467,71.76883405838056,71.80104097622646,71.83324789407236,71.86545481191824,71.89766172976414,71.92986864761005,71.96207556545593,71.99428248330183,72.02648940114773,72.05869631899363,72.09090323683952,72.12311015468542,72.1553170725313,72.18752399037722,72.2197309082231,72.25193782606898,72.2841447439149,72.00280902995131,71.40793068417821,70.8130523384052,70.21817399263217,69.6232956468591,69.02841730108607,68.43353895531305,67.83866060953999,67.2437822637669,66.64890391799393,66.05402557222085,65.45914722644778,64.86426888067476,64.26939053490173,63.67451218912865,63.07963384335564,62.48475549758261,61.88987715180954,61.29499880603652,60.70012046026349,60.105242114490416,59.51036376871733,58.915485422944364,58.32060707717129,57.72572873139822,57.130850385625195,56.53597203985217,55.94109369407909,55.346215348306075,54.75133700253305,54.156458656759966,53.5615803109869,52.96670196521392,52.371823619440846,51.77694527366777,51.18206692789475,50.587188582121726,49.99231023634865,49.397431890575625,48.802553544802606,48.20767519902953,47.6127968532565,47.017918507483486,46.423040161710404,45.82816181593733,45.23328347016436,44.63840512439129,44.04352677861821,43.44864843284518,42.853770087072164,42.25889174129909,41.66401339552606,41.069135049753044,40.47425670397997,39.879378358206885,39.284500012433924,38.68962166666084,38.094743320887765,37.49986497511474,36.90498662934172,36.310108283568646,35.71522993779562,35.1203515920226,34.52733544393347,33.93804376249809,33.348752081062706,32.75946039962727,32.17016871819184,31.58087703675651,30.991585355321078,30.402293673885644,29.81300199245026,29.223710311014884,28.634418629579447,28.045126948144066,27.455835266708686,26.866543585273252,26.277251903837872,25.687960222402488,25.098668540967058,24.50937685953162,23.92008517809624,23.33079349666086,22.875286535811565,22.687349016134455,22.49941149645734,22.311473976780217,22.12353645710311,21.935598937425993,21.747661417748873,21.559723898071745,21.37178637839465,21.18384885871752,20.995911339040394,20.807973819363287,20.620036299686177,20.43209878000905,20.24416126033194,20.05622374065483,19.8682862209777,19.68034870130059,19.49241118162348,19.304473661946354,19.116536142269226,18.928598622592112,18.740661102915006,18.552723583237878,18.364786063560768,18.17684854388366,17.98891102420653,17.800973504529424,17.61303598485231,17.425098465175186,17.237160945498054,17.049223425820962,16.861285906143838,16.67334838646671,16.4854108667896,16.297473347112486,16.109535827435362,15.921598307758254,15.733660788081142,15.545723268404014,15.357785748726904,15.169848229049794,14.981910709372666,14.79397318969554,14.606035670018429,14.41865983185638,14.232407283327113,14.046154734797867,13.859902186268616,13.673649637739352,13.487397089210102,13.301144540680857,13.114891992151591,12.928639443622323,12.742386895093095,12.55613434656383,12.369881798034564,12.183629249505316,11.997376700976066,11.811124152446801,11.624871603917557,11.438619055388308,11.252366506859042,11.066113958329794,10.879861409800544,10.69360886127128,10.507356312742015,10.321103764212785,10.134851215683518,9.948598667154252,9.762346118625006,9.576093570095757,9.389841021566493,9.203588473037245,9.017335924507996,8.83108337597873,8.644830827449466,8.458578278920236,8.27232573039097,8.086073181861705,7.899820633332457,7.713568084803208,7.527315536273943,7.364585295803543,7.319466595627264,7.274347895450985,7.229229195274706,7.184110495098435,7.138991794922157,7.093873094745877,7.048754394569606,7.003635694393326,6.958516994217047,6.9133982940407765,6.868279593864497,6.823160893688218,6.778042193511938,6.732923493335667,6.687804793159388,6.642686092983109,6.5975673928068375,6.552448692630559,6.507329992454279,6.462211292278009,6.41709259210173,6.37197389192545,6.326855191749178,6.2817364915729,6.23661779139662,6.191499091220342,6.146380391044071,6.1012616908677915,6.056142990691512,6.011024290515241,5.965905590338961,5.920786890162683,5.875668189986412,5.8305494898101315,5.785430789633853,5.740312089457574,5.695193389281303,5.650074689105024,5.604955988928745,5.56186425317818,5.518959935477135,5.486417673063488,5.4612768787122725,5.435854164289886,5.409591538334876,5.383328912379873,5.357066286424864,5.330803660469855,5.304541034514847,5.278278408559843,5.2520157826048335,5.225753156649826,5.199490530694821,5.173227904739813,5.146965278784804,5.1207026528298005,5.094440026874791,5.068177400919782,5.0419147749647735,5.01565214900977,4.989389523054761,4.963126897099753,4.936864271144748,4.91060164518974,4.884339019234732,4.8580763932797275,4.831813767324718,4.80555114136971,4.779288515414706,4.753025889459697,4.7267632635046875,4.70050063754968,4.674238011594675,4.647975385639667,4.621712759684658,4.5954501337296545,4.569187507774645,4.542924881819636,4.516662255864633,4.490399629909624,4.464137003954614,4.437874377999606,4.411611752044602],[62.00675942974002,62.05942324167465,62.11208705360926,62.16475086554388,62.2174146774785,62.27007848941312,62.322742301347745,62.37540611328235,62.428069925216974,62.4807337371516,62.53339754908622,62.58606136102084,62.638725172955446,62.69138898489007,62.74405279682469,62.79671660875931,62.849380420693926,62.90204423262855,62.95470804456317,63.007371856497784,63.060035668432405,63.11269948036702,63.165363292301635,63.218027104236256,63.27069091617088,63.3233547281055,63.37601854004012,63.42868235197473,63.481346163909365,63.53400997584397,63.586673787778594,63.63933759971321,63.69200141164782,63.74466522358245,63.797329035517066,63.84999284745168,63.9026566593863,63.95532047132092,64.00798428325555,64.06064809519015,64.11331190712477,64.16597571905939,64.21863953099401,64.27130334292863,64.32396715486325,64.37663096679788,64.42929477873248,64.4819585906671,64.53462240260173,64.58728621453635,64.63995002647097,64.69261383840558,64.7452776503402,64.79781213813969,64.85021730185971,64.90262246557974,64.95502762929976,65.00743279301979,65.05983795673981,65.11224312045984,65.16464828417986,65.21705344789989,65.26945861161991,65.32186377533993,65.37426893905996,65.42667410277997,65.4790792665,65.53148443022003,65.58388959394006,65.63629475766007,65.6886999213801,65.74110508510013,65.79351024882016,65.84591541254017,65.8983205762602,65.95072573998021,66.00313090370024,66.05553606742026,66.10794123114029,66.16034639486033,66.21275155858034,66.26515672230036,66.31756188602039,66.36996704974042,66.41282959211102,66.45378361021176,66.49473762831248,66.53569164641321,66.57664566451393,66.61759968261467,66.65855370071539,66.69950771881612,66.74046173691684,66.78141575501758,66.82236977311831,66.86332379121903,66.90427780931977,66.9452318274205,66.98618584552122,67.02713986362195,67.06809388172269,67.10904789982341,67.15000191792414,67.19095593602486,67.2319099541256,67.27286397222632,67.31381799032705,67.35477200842779,67.39572602652851,67.43668004462923,67.47763406272998,67.5185880808307,67.55954209893142,67.60049611703215,67.64163086291217,67.68366924838878,67.72570763386538,67.76774601934198,67.8097844048186,67.8518227902952,67.89386117577182,67.93589956124842,67.97793794672502,68.01997633220164,68.06201471767824,68.10405310315485,68.14609148863146,68.18812987410807,68.23016825958467,68.27220664506127,68.31424503053789,68.35628341601449,68.39832180149111,68.44036018696771,68.48239857244432,68.52443695792093,68.56647534339753,68.60851372887414,68.65055211435075,68.69259049982736,68.73462888530396,68.77666727078056,68.81870565625718,68.86074404173378,68.9027824272104,68.944820812687,68.98685919816361,69.02889758364023,69.07093596911682,69.11297435459343,69.15501274007005,69.19705112554665,69.23908951102325,69.28112789649987,69.32316628197647,69.36520466745307,69.40724305292969,69.4492814384063,69.49131982388289,69.5333582093595,69.57539659483612,69.61743498031272,69.65947336578932,69.70151175126594,69.74355013674254,69.78558852221916,69.82762690769576,69.86073947611871,69.88938913601478,69.91803879591089,69.94668845580698,69.97533811570305,70.00398777559917,70.03263743549525,70.06128709539134,70.08993675528743,70.11858641518353,70.1472360750796,70.17588573497571,70.20453539487181,70.2331850547679,70.26183471466399,70.29048437456008,70.31913403445617,70.34778369435226,70.37643335424835,70.40508301414445,70.43373267404053,70.46238233393663,70.49103199383272,70.51968165372881,70.54833131362491,70.57698097352099,70.60563063341709,70.63428029331317,70.66292995320927,70.69157961310536,70.72022927300145,70.74887893289755,70.77752859279364,70.80617825268972,70.83482791258582,70.86490047603161,70.89710739387752,70.9293143117234,70.96152122956929,70.9937281474152,71.0259350652611,71.05814198310699,71.09034890095288,71.12255581879877,71.15476273664467,71.18696965449058,71.21917657233647,71.25138349018236,71.28359040802826,71.31579732587414,71.34800424372004,71.38021116156594,71.41241807941182,71.44462499725773,71.47683191510363,71.50903883294953,71.54124575079543,71.57345266864132,71.6056595864872,71.6378665043331,71.670073422179,71.70228034002488,71.7344872578708,71.7666941757167,71.79890109356258,71.83110801140847,71.86331492925439,71.89552184710027,71.92772876494617,71.95993568279206,71.99214260063796,72.02434951848386,72.05655643632976,72.08876335417565,72.12097027202154,72.15317718986745,72.18538410771333,72.21759102555924,72.24979794340511,72.28200486125102,72.31421177909691,72.34641869694282,72.37862561478872,72.09728990082512,71.50241155505203,70.90753320927901,70.312654863506,69.71777651773291,69.1228981719599,68.52801982618689,67.93314148041378,67.33826313464071,66.74338478886774,66.14850644309467,65.55362809732159,64.95874975154858,64.36387140577555,63.76899306000247,63.174114714229454,62.57923636845643,61.984358022683345,61.38947967691033,60.7946013311373,60.19972298536423,59.60484463959115,59.00996629381818,58.41508794804511,57.82020960227203,57.225331256499004,56.63045291072599,56.03557456495291,55.44069621917989,54.84581787340686,54.25093952763379,53.65606118186071,53.06118283608774,52.46630449031466,51.87142614454159,51.27654779876857,50.681669452995536,50.08679110722247,49.49191276144944,48.897034415676416,48.30215606990334,47.707277724130314,47.1123993783573,46.51752103258423,45.922642686811145,45.327764341038176,44.7328859952651,44.138007649492025,43.543129303719,42.94825095794598,42.353372612172905,41.75849426639988,41.16361592062685,40.56873757485378,39.9738592290807,39.37898088330773,38.78410253753466,38.18922419176158,37.594345845988556,36.99946750021554,36.40458915444246,35.809710808669436,35.21483246289641,34.61995411712334,34.013506105986785,33.40035989393253,32.78721368187823,32.17406746982392,31.560921257769728,30.94777504571542,30.33462883366111,29.72148262160686,29.10833640955261,28.495190197498303,27.882043985444053,27.268897773389803,26.655751561335492,26.042605349281246,25.429459137226992,24.81631292517269,24.203166713118378,23.590020501064128,22.976874289009878,22.509028459329514,22.331783394396922,22.154538329464334,21.97729326453173,21.800048199599143,21.622803134666555,21.44555806973395,21.268313004801346,21.091067939868772,20.91382287493617,20.736577810003563,20.559332745070975,20.382087680138387,20.204842615205784,20.027597550273192,19.850352485340604,19.673107420408,19.49586235547541,19.318617290542825,19.14137222561022,18.964127160677613,18.786882095745025,18.60963703081244,18.432391965879834,18.255146900947246,18.077901836014657,17.900520320945198,17.71426777241595,17.528015223886705,17.341762675357437,17.155510126828172,16.96925757829894,16.783005029769676,16.59675248124041,16.41049993271116,16.224247384181915,16.03799483565265,15.8517422871234,15.665489738594154,15.479237190064888,15.29298464153564,15.106732093006395,14.920479544477129,14.734226995947862,14.547974447418614,14.361721898889366,14.175469350360103,13.989216801830853,13.802964253301603,13.616711704772339,13.43045915624309,13.244206607713844,13.057954059184578,12.871701510655312,12.685448962126081,12.499196413596817,12.312943865067552,12.126691316538302,11.940438768009054,11.75418621947979,11.567933670950543,11.381681122421295,11.19542857389203,11.00917602536278,10.822923476833532,10.636670928304268,10.450418379775002,10.264165831245773,10.077913282716509,9.89166073418724,9.705408185657994,9.519155637128744,9.33290308859948,9.146650540070231,8.960397991540985,8.774145443011719,8.587892894482453,8.401640345953222,8.215387797423958,8.029135248894692,7.842882700365445,7.656630151836196,7.470377603306931,7.307647362836531,7.262528662660252,7.2174099624839725,7.172291262307693,7.127172562131422,7.082053861955143,7.036935161778864,6.9918164616025935,6.946697761426314,6.901579061250035,6.856460361073763,6.811341660897484,6.766222960721205,6.721104260544926,6.675985560368654,6.630866860192375,6.585748160016096,6.540629459839826,6.495510759663546,6.4503920594872675,6.405273359310996,6.360154659134716,6.315035958958437,6.269917258782167,6.224798558605887,6.181317578295246,6.1384132605941994,6.0955089428931615,6.0526046251921155,6.0097003074910695,5.966795989790031,5.923891672088985,5.880987354387939,5.8380830366869,5.795178718985854,5.752274401284808,5.709370083583762,5.666465765882723,5.623561448181678,5.580657130480631,5.537752812779592,5.494848495078546,5.462306232664901,5.437165438313685,5.412024643962466,5.386883849611246,5.361743055260031,5.336602260908812,5.311461466557591,5.286320672206371,5.261179877855156,5.236039083503937,5.210898289152716,5.185757494801502,5.160616700450282,5.135475906099062,5.110335111747847,5.085194317396628,5.060053523045408,5.034433612856718,5.008170986901714,4.981908360946705,4.9556457349916965,4.929383109036692,4.9031204830816835,4.876857857126675,4.850595231171671,4.824332605216663,4.798069979261653,4.771807353306649,4.745544727351641,4.719282101396631,4.6930194754416235,4.666756849486619,4.640494223531611,4.614231597576602,4.5879689716215974,4.56170634566659,4.53544371971158,4.509181093756577,4.482918467801568,4.456655841846558,4.43039321589155,4.404130589936546],[62.19089902405574,62.24356283599036,62.296226647924975,62.3488904598596,62.40155427179422,62.45421808372883,62.50688189566345,62.55954570759807,62.61220951953268,62.664873331467305,62.71753714340193,62.77020095533655,62.82286476727117,62.87552857920579,62.9281923911404,62.98085620307502,63.03352001500964,63.08618382694426,63.13884763887888,63.19151145081349,63.244175262748115,63.29683907468274,63.34950288661735,63.40216669855197,63.45483051048659,63.50749432242121,63.56015813435583,63.612821946290445,63.66548575822507,63.71814957015968,63.7708133820943,63.823477194028925,63.87614100596354,63.92880481789816,63.98146862983277,64.0341324417674,64.08679625370202,64.13920141753523,64.19160658125526,64.24401174497527,64.2964169086953,64.34882207241532,64.40122723613536,64.45363239985537,64.50603756357539,64.55844272729541,64.61084789101545,64.66325305473546,64.71565821845549,64.76806338217551,64.82046854589554,64.87287370961556,64.92527887333559,64.97768403705561,65.03008920077563,65.08249436449566,65.13489952821568,65.18730469193571,65.23970985565572,65.29211501937576,65.34452018309578,65.3969253468158,65.44933051053583,65.50173567425585,65.55414083797588,65.6065460016959,65.65895116541591,65.71135632913595,65.76376149285596,65.816166656576,65.86857182029603,65.92097698401604,65.97338214773606,66.0257873114561,66.07819247517612,66.13059763889615,66.18300280261616,66.2354079663362,66.28781313005622,66.34021829377625,66.39262345749627,66.44502862121628,66.4974337849363,66.54983894865633,66.59270149102694,66.63365550912768,66.6746095272284,66.71556354532913,66.75651756342987,66.79747158153059,66.83842559963131,66.87937961773204,66.92033363583278,66.96128765393351,67.00224167203423,67.04319569013497,67.08414970823569,67.12510372633642,67.16605774443714,67.20701176253787,67.24796578063861,67.28891979873933,67.32987381684006,67.3708278349408,67.41178185304152,67.45273587114224,67.49368988924297,67.5346439073437,67.57559792544444,67.61655194354515,67.65750596164588,67.69845997974662,67.73941399784734,67.78036801594807,67.8213220340488,67.86227605214953,67.90323007025026,67.944184088351,67.98513810645173,68.02609212455245,68.06704614265317,68.1080001607539,68.14895417885464,68.18990819695536,68.23086221505609,68.27181623315681,68.31277025125753,68.35372426935827,68.394678287459,68.43563230555972,68.47658632366046,68.51826325381963,68.56030163929624,68.60234002477284,68.64437841024944,68.68641679572606,68.72845518120266,68.77049356667928,68.81253195215588,68.8545703376325,68.8966087231091,68.93864710858571,68.98068549406231,69.02272387953892,69.06476226501553,69.10680065049213,69.14883903596875,69.19087742144535,69.23291580692197,69.27495419239857,69.31699257787517,69.35903096335178,69.4010693488284,69.44310773430499,69.4851461197816,69.52718450525822,69.56922289073482,69.61126127621144,69.65329966168804,69.69533804716464,69.73737643264126,69.77941481811786,69.82145320359447,69.86349158907107,69.90552997454769,69.94756836002429,69.98960674550091,70.02271931392383,70.05136897381992,70.08001863371601,70.10866829361211,70.1373179535082,70.16596761340429,70.1946172733004,70.22326693319648,70.25191659309257,70.28056625298865,70.30921591288475,70.33786557278084,70.36651523267693,70.39516489257302,70.42381455246912,70.45246421236521,70.4811138722613,70.5097635321574,70.53841319205348,70.56706285194957,70.59571251184566,70.62436217174175,70.65301183163785,70.68166149153394,70.71031115143003,70.73896081132612,70.76761047122221,70.79626013111832,70.82490979101442,70.8535594509105,70.88220911080658,70.91085877070269,70.93950843059878,70.96815809049485,70.99680775039096,71.02545741028703,71.05410707018314,71.08275673007923,71.11140638997531,71.14005604987142,71.1687057097675,71.1973553696636,71.22600502955969,71.25465468945578,71.28330434935187,71.31195400924796,71.34060366914406,71.36925332904015,71.39790298893624,71.42655264883233,71.45520230872842,71.4838519686245,71.51250162852061,71.5411512884167,71.57131278597744,71.60351970382334,71.63572662166924,71.66793353951513,71.70014045736103,71.73234737520693,71.76455429305281,71.79676121089871,71.8289681287446,71.8611750465905,71.8933819644364,71.9255888822823,71.95779580012818,71.9900027179741,72.02220963581998,72.05441655366587,72.08662347151177,72.11883038935767,72.15103730720357,72.18324422504946,72.21545114289535,72.24765806074126,72.27986497858714,72.31207189643304,72.34427881427895,72.37648573212485,72.40869264997073,72.44089956781664,72.47310648566253,72.19177077169894,71.59689242592586,71.00201408015283,70.4071357343798,69.81225738860674,69.2173790428337,68.62250069706069,68.0276223512876,67.43274400551454,66.83786565974157,66.24298731396848,65.64810896819542,65.05323062242239,64.45835227664936,63.86347393087628,63.26859558510327,62.673717239330244,62.07883889355716,61.48396054778414,60.889082202011124,60.29420385623804,59.69932551046496,59.104447164692,58.50956881891892,57.91469047314584,57.31981212737282,56.7249337815998,56.130055435826726,55.53517709005369,54.940298744280675,54.3454203985076,53.75054205273453,53.155663706961555,52.56078536118848,51.965907015415404,51.37102866964238,50.77615032386935,50.18127197809628,49.58639363232325,48.97446528718425,48.36131907512994,47.7481728630757,47.13502665102144,46.521880438967145,45.90873422691283,45.29558801485864,44.68244180280433,44.06929559075002,43.45614937869577,42.84300316664152,42.22985695458721,41.616710742532966,41.00356453047871,40.39041831842441,39.7772721063701,39.1641258943159,38.550979682261605,37.937833470207295,37.32468725815304,36.71154104609879,36.098394834044484,35.48524862199023,34.872102409935984,34.25895619788167,33.64580998582743,33.03266377377317,32.41951756171886,31.80637134966456,31.193225137610362,30.58007892555606,29.966932713501752,29.3537865014475,28.74064028939325,28.127494077338945,27.51434786528469,26.90120165323044,26.288055441176134,25.674909229121884,25.061763017067634,24.448616805013323,23.83547059295902,23.222324380904766,22.609178168850516,22.141332339170148,21.964087274237563,21.786842209304975,21.609597144372373,21.43235207943978,21.255107014507196,21.077861949574586,20.900616884641984,20.723371819709413,20.546126754776804,20.3688816898442,20.191636624911613,20.014391559979025,19.837146495046422,19.659901430113834,19.482656365181242,19.305411300248643,19.12816623531605,18.950921170383463,18.77367610545086,18.59643104051825,18.419185975585663,18.241940910653078,18.06469584572047,17.887450780787884,17.710205715855295,17.53296065092269,17.355715585990104,17.178470521057516,17.00122545612491,16.823980391192308,16.64673532625973,16.46949026132713,16.292245196394525,16.115000131461937,15.937755066529348,15.760510001596742,15.583264936664154,15.406019871731568,15.228774806798961,15.051529741866371,14.874284676933787,14.697039612001179,14.519794547068576,14.342549482135988,14.165304417203398,13.988059352270795,13.810814287338205,13.633569222405617,13.456324157473013,13.279079092540425,13.101834027607836,12.924588962675232,12.747343897742628,12.570098832810055,12.392853767877453,12.215608702944847,12.038363638012259,11.86111857307967,11.683873508147066,11.506628443214478,11.324743189454285,11.138490640925019,10.95223809239577,10.76598554386652,10.579732995337256,10.393480446807992,10.207227898278763,10.020975349749497,9.834722801220229,9.648470252690984,9.462217704161734,9.27596515563247,9.08971260710322,8.903460058573975,8.717207510044707,8.530954961515443,8.344702412986212,8.158449864456946,7.972197315927681,7.785944767398433,7.599692218869185,7.413439670339921,7.250709429869521,7.205590729693242,7.160472029516963,7.1153533293406825,7.070234629164412,7.025115928988133,6.979997228811854,6.934878528635583,6.889759828459303,6.8446411282830235,6.800770903412319,6.757866585711273,6.714962268010228,6.672057950309181,6.629153632608143,6.586249314907096,6.543344997206051,6.5004406795050125,6.457536361803966,6.4146320441029205,6.371727726401883,6.328823408700837,6.28591909099979,6.243014773298752,6.200110455597706,6.157206137896659,6.114301820195613,6.071397502494575,6.02849318479353,5.985588867092483,5.942684549391444,5.899780231690398,5.856875913989352,5.813971596288314,5.771067278587267,5.728162960886221,5.6852586431851755,5.642354325484137,5.599450007783091,5.556545690082045,5.513641372381007,5.47073705467996,5.438194792266314,5.413053997915099,5.38791320356388,5.36277240921266,5.337631614861445,5.3124908205102255,5.287350026159006,5.262209231807785,5.23706843745657,5.2119276431053505,5.18678684875413,5.161646054402915,5.136505260051695,5.1113644657004755,5.08622367134926,5.06108287699804,5.03594208264682,5.010801288295601,4.985660493944385,4.960519699593165,4.9353789052419454,4.910238110890731,4.885097316539511,4.859956522188291,4.834815727837076,4.809674933485856,4.784534139134637,4.759393344783421,4.734252550432201,4.709111756080982,4.683970961729761,4.658830167378547,4.633013061423554,4.6067504354685465,4.580487809513542,4.5542251835585335,4.527962557603525,4.5016999316485204,4.475437305693513,4.449174679738503,4.422912053783494,4.396649427828491],[62.375038618371455,62.42770243030608,62.48036624224069,62.53303005417531,62.585693866109935,62.63835767804455,62.691021489979164,62.743685301913786,62.79634911384841,62.84901292578303,62.90167673771765,62.95434054965226,63.00700436158688,63.0596681735215,63.112331985456116,63.16499579739074,63.21765960932535,63.270323421259974,63.322987233194596,63.37565104512921,63.428185533210744,63.480590696930776,63.53299586065079,63.58540102437081,63.637806188090835,63.690211351810866,63.742616515530884,63.79502167925091,63.84742684297093,63.899832006690964,63.95223717041099,64.004642334131,64.05704749785103,64.10945266157105,64.1618578252911,64.2142629890111,64.26666815273113,64.31907331645115,64.37147848017118,64.4238836438912,64.47628880761123,64.52869397133125,64.58109913505128,64.6335042987713,64.68590946249131,64.73831462621135,64.79071978993137,64.8431249536514,64.89553011737142,64.94793528109145,65.00034044481147,65.0527456085315,65.1051507722515,65.15755593597154,65.20996109969157,65.26236626341158,65.3147714271316,65.36717659085164,65.41958175457165,65.47198691829168,65.5243920820117,65.57679724573174,65.62920240945175,65.68160757317177,65.7340127368918,65.78641790061184,65.83882306433185,65.89122822805187,65.9436333917719,65.99603855549192,66.04844371921195,66.10084888293197,66.153254046652,66.20565921037202,66.25806437409204,66.31046953781207,66.36287470153209,66.4152798652521,66.46768502897213,66.52009019269215,66.57249535641219,66.62490052013221,66.67730568385223,66.72971084757226,66.77257338994286,66.8135274080436,66.85448142614433,66.89543544424505,66.93638946234577,66.9773434804465,67.01829749854724,67.05925151664796,67.1002055347487,67.14115955284942,67.18211357095015,67.22306758905088,67.2640216071516,67.30497562525234,67.34592964335306,67.3868836614538,67.42783767955453,67.46879169765526,67.50974571575598,67.55069973385672,67.59165375195744,67.63260777005817,67.6735617881589,67.71451580625961,67.75546982436035,67.79642384246108,67.83737786056182,67.87833187866254,67.91928589676326,67.96023991486399,68.00119393296472,68.04214795106544,68.08310196916618,68.12405598726691,68.16501000536763,68.20596402346837,68.2469180415691,68.28787205966984,68.32882607777054,68.36978009587128,68.41073411397201,68.45168813207275,68.49264215017347,68.53359616827419,68.57455018637492,68.61550420447566,68.65645822257638,68.69741224067711,68.73836625877784,68.77932027687856,68.82027429497928,68.86122831308002,68.90218233118075,68.94313634928147,68.98409036738221,69.02504438548294,69.06599840358366,69.10695242168438,69.14790643978513,69.18886045788585,69.22981447598657,69.2707684940873,69.31172251218804,69.35285725925048,69.3948956447271,69.4369340302037,69.47897241568032,69.52101080115692,69.56304918663352,69.60508757211014,69.64712595758675,69.68916434306335,69.73120272853996,69.77324111401657,69.81527949949317,69.85731788496977,69.89935627044639,69.94139465592299,69.9834330413996,70.02547142687621,70.06750981235282,70.10954819782943,70.15158658330603,70.18469915172898,70.21334881162505,70.24199847152116,70.27064813141723,70.29929779131334,70.32794745120943,70.35659711110551,70.38524677100162,70.41389643089771,70.4425460907938,70.47119575068989,70.49984541058598,70.52849507048207,70.55714473037816,70.58579439027424,70.61444405017035,70.64309371006644,70.67174336996253,70.70039302985863,70.72904268975472,70.7576923496508,70.7863420095469,70.814991669443,70.84364132933908,70.87229098923517,70.90094064913126,70.92959030902736,70.95823996892345,70.98688962881954,71.01553928871563,71.0441889486117,71.07283860850781,71.10148826840391,71.13013792829999,71.15878758819609,71.18743724809218,71.21608690798828,71.24473656788436,71.27338622778045,71.30203588767654,71.33068554757263,71.35933520746872,71.38798486736482,71.41663452726091,71.445284187157,71.47393384705309,71.5025835069492,71.53123316684528,71.55988282674137,71.58853248663748,71.61718214653357,71.64583180642964,71.67448146632574,71.70313112622182,71.73178078611792,71.76043044601401,71.7890801059101,71.81772976580619,71.8463794257023,71.87502908559838,71.90367874549447,71.93232840539056,71.96097806528667,71.98962772518274,72.01827738507883,72.04692704497494,72.07557670487103,72.10422636476711,72.1328760246632,72.1615256845593,72.19017534445538,72.21882500435149,72.24747466424756,72.27772509592327,72.30993201376916,72.34213893161507,72.37434584946097,72.40655276730685,72.43875968515275,72.47096660299866,72.50317352084454,72.53538043869045,72.56758735653634,72.28625164257274,71.69137329679967,71.09649495102664,70.50161660525362,69.90673825948055,69.31185991370752,68.7169815679345,68.12210322216143,67.52722487638835,66.93234653061538,66.3374681848423,65.74258983906921,65.1477114932962,64.54857068043597,63.93542446838166,63.32227825632742,62.70913204427316,62.09598583221886,61.482839620164604,60.86969340811036,60.25654719605605,59.643400984001744,59.03025477194755,58.41710855989324,57.80396234783893,57.19081613578468,56.57766992373044,55.96452371167613,55.351377499621876,54.73823128756762,54.12508507551332,53.51193886345901,52.89879265140482,52.28564643935051,51.672500227296204,51.05935401524195,50.4462078031877,49.83306159113339,49.21991537907915,48.60676916702489,47.99362295497059,47.380476742916336,46.76733053086208,46.15418431880778,45.54103810675347,44.92789189469927,44.31474568264497,43.70159947059066,43.08845325853641,42.47530704648216,41.862160834427854,41.24901462237361,40.635868410319354,40.02272219826505,39.40957598621074,38.79642977415654,38.18328356210223,37.57013735004793,36.956991137993676,36.34384492593943,35.73069871388512,35.11755250183087,34.504406289776625,33.891260077722315,33.27811386566806,32.664967653613814,32.051821441559504,31.438675229505193,30.825529017451004,30.212382805396697,29.59923659334239,28.986090381288136,28.37294416923389,27.75979795717958,27.14665174512533,26.53350553307108,25.92035932101677,25.307213108962518,24.694066896908268,24.080920684853965,23.467774472799654,22.854628260745404,22.241482048691154,21.773636219010786,21.5963911540782,21.419146089145613,21.241901024213007,21.06465595928042,20.887410894347834,20.710165829415228,20.532920764482622,20.355675699550048,20.178430634617445,20.00118556968484,19.82394050475225,19.646695439819663,19.46945037488706,19.29220530995447,19.114960245021884,18.937715180089278,18.76047011515669,18.5832250502241,18.4059799852915,18.228734920358892,18.051489855426304,17.874244790493712,17.69699972556111,17.51975466062852,17.34250959569593,17.16526453076333,16.98801946583074,16.81077440089815,16.633529335965548,16.456284271032942,16.279039206100375,16.1030354367678,15.927941922092494,15.7528484074172,15.57775489274191,15.402661378066604,15.22756786339131,15.052474348716022,14.877380834040714,14.702287319365427,14.527193804690132,14.352100290014825,14.177006775339517,14.001913260664228,13.826819745988935,13.651726231313628,13.476632716638338,13.301539201963047,13.12644568728774,12.951352172612449,12.776258657937158,12.60116514326185,12.426071628586545,12.25097811391127,12.075884599235962,11.900791084560655,11.725697569885364,11.550604055210073,11.375510540534766,11.200417025859476,11.025323511184185,10.850229996508876,10.675136481833587,10.500042967158297,10.324949452482988,10.14985593780768,9.974762423132406,9.799668908457098,9.624575393781793,9.4494818791065,9.27438836443121,9.099294849755903,8.924201335080612,8.749107820405321,8.574014305730014,8.398920791054707,8.223827276379431,8.048733761704124,7.873640247028816,7.6985467323535275,7.523453217678235,7.348359703002929,7.195631927585547,7.1547328484576,7.113833769329653,7.072934690201706,7.032035611073766,6.991136531945819,6.948680544154625,6.905777412966293,6.862874281777952,6.819971150589612,6.77706801940128,6.734164888212939,6.6912617570245985,6.648358625836258,6.605455494647927,6.562552363459588,6.519649232271247,6.476746101082914,6.433842969894574,6.390939838706235,6.3480367075179025,6.3051335763295615,6.2622304451412205,6.219327313952889,6.176424182764549,6.133521051576208,6.090617920387869,6.047714789199537,6.004811658011197,5.961908526822857,5.9190053956345245,5.876102264446184,5.833199133257844,5.790296002069512,5.747392870881171,5.704489739692832,5.661586608504491,5.618683477316159,5.575780346127819,5.532877214939479,5.489974083751147,5.4470709525628065,5.414528492397044,5.389386511533122,5.364244530669197,5.33910254980527,5.313960568941349,5.288818588077422,5.2636766072134975,5.238534626349572,5.2133926454856505,5.188250664621724,5.163108683757798,5.137966702893877,5.112824722029952,5.0876827411660255,5.062540760302104,5.0373987794381785,5.012256798574253,4.987114817710327,4.961972836846406,4.93683085598248,4.911688875118554,4.886546894254633,4.861404913390707,4.836262932526782,4.81112095166286,4.785978970798935,4.760836989935009,4.735695009071088,4.710553028207161,4.685411047343236,4.66026906647931,4.635127085615388,4.609985104751463,4.584843123887537,4.5597011430236165,4.534559162159691,4.509817911005882,4.48570400550408,4.461590100002274,4.437476194500467,4.413362288998661,4.3892483834968585],[62.55917821268718,62.6118420246218,62.664505836556415,62.71716964849103,62.76957481260629,62.82197997632632,62.874385140046336,62.92679030376635,62.979195467486385,63.03160063120641,63.08400579492644,63.13641095864645,63.188816122366475,63.241221286086514,63.29362644980654,63.346031613526556,63.39843677724657,63.450841940966605,63.503247104686636,63.55565226840665,63.60805743212667,63.660462595846695,63.71286775956672,63.765272923286744,63.81767808700677,63.87008325072679,63.922488414446825,63.974893578166835,64.02729874188688,64.07970390560689,64.13210906932692,64.18451423304694,64.23691939676695,64.28932456048699,64.34172972420701,64.39413488792704,64.44654005164706,64.49894521536709,64.55135037908713,64.60375554280714,64.65616070652715,64.70856587024718,64.76097103396721,64.81337619768723,64.86578136140724,64.91818652512728,64.9705916888473,65.02299685256733,65.07540201628734,65.12780718000738,65.18021234372739,65.23261750744743,65.28502267116744,65.33742783488748,65.38983299860749,65.44223816232751,65.49464332604754,65.54704848976758,65.59945365348759,65.65185881720761,65.70426398092764,65.75666914464766,65.80907430836768,65.86147947208771,65.91388463580773,65.96628979952774,66.01869496324777,66.0711001269678,66.12350529068783,66.17591045440784,66.22831561812787,66.28072078184789,66.33312594556793,66.38553110928794,66.43793627300796,66.49034143672799,66.54274660044801,66.59515176416804,66.64755692788806,66.69996209160809,66.75236725532811,66.80477241904813,66.85717758276816,66.90958274648818,66.9524452888588,66.99339930695953,67.03435332506025,67.07530734316099,67.1162613612617,67.15721537936244,67.19816939746318,67.2391234155639,67.28007743366462,67.32103145176535,67.36198546986608,67.4029394879668,67.44389350606755,67.48484752416827,67.525801542269,67.56675556036973,67.60770957847046,67.6486635965712,67.68961761467192,67.73057163277264,67.77152565087337,67.8124796689741,67.85343368707483,67.89438770517556,67.93534172327628,67.97629574137702,68.01724975947774,68.05820377757847,68.09915779567919,68.14011181377992,68.18106583188066,68.22201984998138,68.26297386808211,68.30392788618283,68.34488190428357,68.3858359223843,68.42678994048504,68.46774395858574,68.50869797668648,68.54965199478721,68.59060601288795,68.63156003098867,68.67251404908939,68.71346806719012,68.75442208529086,68.79537610339158,68.83633012149231,68.87728413959304,68.91823815769376,68.9591921757945,69.00014619389523,69.04110021199595,69.08205423009667,69.12300824819741,69.16396226629814,69.20491628439886,69.2458703024996,69.28682432060033,69.32777833870105,69.36873235680179,69.40968637490252,69.45064039300324,69.49159441110396,69.53254842920471,69.57350244730543,69.61445646540615,69.65541048350688,69.6963645016076,69.73731851970834,69.77827253780907,69.8192265559098,69.86018057401051,69.90113459211126,69.94208861021198,69.9830426283127,70.02399664641345,70.06495066451417,70.10590468261489,70.14685870071564,70.18781271881636,70.22948965015796,70.27152803563457,70.31356642111118,70.34667898953411,70.3753286494302,70.40397830932629,70.43262796922238,70.46127762911847,70.48992728901456,70.51857694891066,70.54722660880674,70.57587626870284,70.60452592859895,70.63317558849502,70.66182524839111,70.69047490828721,70.7191245681833,70.7477742280794,70.77642388797548,70.80507354787157,70.83372320776768,70.86237286766377,70.89102252755985,70.91967218745593,70.94832184735203,70.97697150724812,71.0048829384931,71.03242523430892,71.05996753012474,71.08750982594056,71.11505212175638,71.1425944175722,71.17013671338802,71.19767900920382,71.22522130501964,71.25276360083546,71.28030589665127,71.3078481924671,71.33539048828293,71.36293278409873,71.39047507991457,71.41801737573037,71.44555967154619,71.47310196736201,71.50064426317785,71.52818655899365,71.55572885480947,71.5832711506253,71.6108134464411,71.63835574225692,71.66589803807275,71.69344033388856,71.7209826297044,71.7485249255202,71.77606722133602,71.80360951715184,71.83115181296766,71.85869410878348,71.8862364045993,71.91377870041512,71.94132099623096,71.96886329204676,71.99640558786258,72.0239478836784,72.05149017949421,72.07903247531004,72.10657477112585,72.13411706694167,72.16165936275749,72.18920165857331,72.21674395438913,72.24428625020496,72.27182854602077,72.29937084183659,72.32691313765241,72.35445543346823,72.38199772928405,72.40954002509986,72.43708232091568,72.4646246167315,72.49216691254733,72.51970920836312,72.54725150417896,72.57479379999477,72.6023360958106,72.62987839162642,72.33098559051376,71.70565769247264,71.08032979443159,70.45500189639051,69.8296739983494,69.20434610030834,68.57901820226728,67.95369030422616,67.32836240618504,66.70303450814401,66.07770661010291,65.45237871206179,64.82705081402072,64.20172291597966,63.57639501793854,62.95967912232255,62.34656820099363,61.73345727966468,61.120346358335766,60.507235437006855,59.89412451567789,59.28101359434892,58.66790267302007,58.054791751691106,57.441680830362145,56.828569909033234,56.21545898770433,55.60234806637536,54.98923714504645,54.37612622371754,53.763015302388574,53.149904381059606,52.53679345973076,51.923682538401785,51.31057161707283,50.69746069574392,50.08434977441501,49.47123885308604,48.85812793175714,48.24501701042823,47.63190608909926,47.01879516777036,46.40568424644144,45.792573325112485,45.17946240378351,44.56635148245466,43.953240561125696,43.34012963979673,42.72701871846782,42.11390779713891,41.50079687580995,40.88768595448104,40.27457503315213,39.661464111823165,39.0483531904942,38.43524226916534,37.82213134783638,37.209020426507415,36.595909505178504,35.9827985838496,35.36968766252063,34.75657674119172,34.14346581986281,33.530354898533844,32.91724397720494,32.30413305587603,31.691022134547065,31.077911213218098,30.464800291889247,29.85168937056028,29.23857844923132,28.62546752790241,28.012356606573498,27.39924568524453,26.786134763915623,26.173023842586716,25.55991292125775,24.946801999928844,24.333691078599934,23.720580157270966,23.107469235942006,22.494358314613095,21.881247393284184,21.416923621050557,21.250174147007503,21.083424672964448,20.916675198921375,20.74992572487832,20.583176250835262,20.416426776792193,20.24967730274912,20.08292782870608,19.91617835466301,19.749428880619938,19.58267940657688,19.415929932533828,19.249180458490756,19.0824309844477,18.915681510404646,18.74893203636157,18.582182562318515,18.41543308827546,18.24868361423239,18.081934140189315,17.91518466614626,17.748435192103205,17.581685718060136,17.414936244017078,17.248186769974023,17.081437295930954,16.914687821887895,16.74793834784484,16.574663401575954,16.399569886900647,16.224476372225368,16.049382857550068,15.874289342874757,15.69919582819947,15.524102313524178,15.34900879884887,15.173915284173578,14.998821769498285,14.823728254822978,14.648634740147688,14.473541225472399,14.298447710797092,14.123354196121785,13.948260681446492,13.773167166771202,13.598073652095895,13.422980137420602,13.247886622745312,13.072793108070005,12.897699593394716,12.722606078719425,12.547512564044117,12.372419049368808,12.197325534693533,12.022232020018226,11.847138505342919,11.672044990667631,11.49695147599234,11.321857961317033,11.14676444664174,10.97167093196645,10.796577417291143,10.62148390261585,10.446390387940562,10.271296873265253,10.096203358589948,9.921109843914671,9.746016329239364,9.570922814564057,9.395829299888765,9.220735785213474,9.04564227053817,8.870548755862881,8.695455241187588,8.520361726512279,8.345268211836972,8.170174697161697,7.995081182486389,7.819987667811082,7.6448941531357955,7.4698006384605025,7.294707123785194,7.141979348367814,7.101080269239866,7.060181190111918,7.019282110983973,6.9783830318560325,6.937483952728085,6.896584873600137,6.855685794472198,6.814786715344251,6.773887636216303,6.732988557088364,6.692089477960416,6.651190398832468,6.610291319704521,6.569392240576581,6.528493161448635,6.487594082320688,6.4466950031927475,6.405795924064801,6.364896844936853,6.3239977658089135,6.282147840986514,6.239244709798175,6.196341578609842,6.153438447421502,6.110535316233162,6.067632185044822,6.02472905385649,5.9818259226681505,5.9389227914798095,5.8960196602914765,5.853116529103137,5.810213397914797,5.767310266726465,5.724407135538124,5.681504004349785,5.638600873161444,5.595697741973113,5.552794610784771,5.509891479596432,5.466988348408099,5.424085217219759,5.391542757053997,5.3664007761900745,5.341258795326149,5.316116814462223,5.290974833598302,5.265832852734376,5.24069087187045,5.215548891006525,5.190406910142603,5.165264929278677,5.140122948414752,5.11498096755083,5.089838986686905,5.064697005822978,5.039555024959057,5.014413044095132,4.989271063231206,4.96412908236728,4.938987101503359,4.913845120639433,4.888703139775507,4.864272797913147,4.84015889241134,4.816044986909534,4.791931081407732,4.767817175905925,4.743703270404119,4.719589364902317,4.695475459400511,4.671361553898704,4.647247648396897,4.623133742895095,4.599019837393288,4.574905931891482,4.550792026389679,4.526678120887873,4.502564215386067,4.4784503098842645,4.454336404382459,4.430222498880651,4.406108593378844,4.381994687877043],[62.72808399644214,62.78048916016216,62.83289432388219,62.88529948760222,62.937704651322235,62.99010981504226,63.04251497876229,63.094920142482316,63.14732530620233,63.19973046992236,63.25213563364238,63.304540797362414,63.35694596108244,63.409351124802456,63.46175628852248,63.514161452242504,63.566566615962536,63.61897177968255,63.67137694340258,63.7237821071226,63.77618727084263,63.82859243456265,63.88099759828267,63.9334027620027,63.985807925722725,64.03821308944273,64.09061825316277,64.14302341688278,64.19542858060282,64.24783374432285,64.30023890804286,64.35264407176288,64.40504923548292,64.45745439920293,64.50985956292295,64.56226472664298,64.614669890363,64.66707505408303,64.71948021780305,64.77188538152308,64.8242905452431,64.87669570896313,64.92910087268315,64.98150603640318,65.0339112001232,65.08631636384322,65.13872152756325,65.19112669128327,65.2435318550033,65.29593701872332,65.34834218244335,65.40074734616337,65.4531525098834,65.50555767360342,65.55796283732344,65.61036800104347,65.6627731647635,65.71517832848352,65.76758349220354,65.81998865592357,65.87239381964359,65.92479898336362,65.97720414708364,66.02960931080366,66.08201447452369,66.1344196382437,66.18682480196372,66.23922996568376,66.29163512940379,66.3440402931238,66.39635301304585,66.44848084413044,66.50060867521505,66.55273650629965,66.60486433738426,66.65699216846886,66.70911999955345,66.76124783063806,66.81337566172266,66.86550349280726,66.91763132389187,66.96975915497647,67.02188698606106,67.07401481714567,67.11683113741037,67.1577851555111,67.19873917361183,67.23969319171256,67.28064720981328,67.32160122791402,67.36255524601474,67.40350926411547,67.4444632822162,67.48541730031693,67.52637131841766,67.56732533651838,67.60827935461911,67.64923337271985,67.69018739082057,67.7311414089213,67.77209542702202,67.81304944512276,67.85400346322349,67.89495748132421,67.93591149942495,67.97686551752567,68.0178195356264,68.05877355372712,68.09972757182786,68.14068158992858,68.18163560802931,68.22258962613004,68.26354364423077,68.3044976623315,68.34545168043223,68.38640569853295,68.42735971663369,68.46831373473441,68.50926775283514,68.55022177093588,68.5911757890366,68.63212980713733,68.67308382523805,68.71403784333879,68.75499186143952,68.79594587954024,68.83689989764096,68.8778539157417,68.91880793384243,68.95976195194315,69.00071597004388,69.0416699881446,69.08262400624534,69.12357802434607,69.16453204244681,69.20548606054753,69.24644007864825,69.28739409674898,69.32834811484972,69.36930213295045,69.41025615105117,69.45121016915189,69.49216418725263,69.53311820535336,69.5740722234541,69.61502624155482,69.65598025965554,69.69693427775627,69.737888295857,69.77884231395772,69.81979633205844,69.86075035015918,69.90170436825991,69.94249031954176,69.98243592770098,70.0223815358602,70.06232714401942,70.10227275217862,70.14221836033785,70.18216396849706,70.22210957665628,70.2620551848155,70.30200079297471,70.34194640113392,70.38189200929314,70.42183761745235,70.46178322561157,70.48991191677672,70.51213214944482,70.53435238211293,70.55657261478103,70.57879284744915,70.60101308011726,70.62323331278536,70.64545354545346,70.6676737781216,70.6898940107897,70.71211424345779,70.7343344761259,70.75655470879401,70.77877494146213,70.80099517413024,70.82321540679834,70.84543563946644,70.86765587213456,70.88987610480267,70.91661203547963,70.94415433129545,70.97169662711127,70.99923892292708,71.02678121874291,71.05432351455873,71.08186581037455,71.10940810619036,71.13695040200619,71.164492697822,71.19203499363783,71.21957728945364,71.24711958526947,71.27466188108528,71.3022041769011,71.32974647271692,71.35728876853273,71.38483106434856,71.41237336016437,71.43991565598019,71.467457951796,71.49500024761184,71.52254254342765,71.55008483924347,71.57762713505929,71.60516943087512,71.63271172669093,71.66025402250675,71.68779631832257,71.71533861413837,71.74288090995421,71.77042320577002,71.79796550158584,71.82550779740166,71.85305009321748,71.8805923890333,71.90813468484912,71.93567698066494,71.96321927648076,71.99076157229658,72.0183038681124,72.04584616392822,72.07338845974402,72.10093075555986,72.12847305137566,72.15601534719148,72.1835576430073,72.21109993882312,72.23864223463895,72.26618453045477,72.29372682627059,72.3212691220864,72.34881141790221,72.37635371371803,72.40389600953385,72.43143830534967,72.45898060116549,72.48652289698131,72.51406519279713,72.54160748861295,72.56914978442877,72.5966920802446,72.6242343760604,72.65177667187623,72.35288387076358,71.72755597272244,71.1022280746814,70.47690017664033,69.85157227859922,69.22624438055816,68.60091648251708,67.97558858447596,67.35026068643485,66.72493278839384,66.09960489035272,65.47427699231162,64.84894909427054,64.22362119622946,63.598293298188345,62.972965400147295,62.34763750210624,61.722309604065124,61.09698170602405,60.47165380798298,59.84632590994187,59.22099801190075,58.59567011385975,57.970342215818626,57.3450143177775,56.71968641973643,56.094358521695376,55.469030623654255,54.8437027256132,54.21837482757213,53.593046929531006,52.967719031489885,52.342391133448885,51.717063235407764,51.09173533736665,50.46640743932558,49.841079541284515,49.2157516432434,48.59042374520233,47.965095847161265,47.33976794912015,46.71444005107909,46.08911215303802,45.46378425499691,44.83845635695578,44.21312845891478,43.595110744336864,42.9819998230079,42.368888901678986,41.75577798035008,41.142667059021115,40.529556137692204,39.9164452163633,39.30333429503433,38.690223373705365,38.07711245237651,37.46400153104755,36.85089060971858,36.23777968838968,35.62466876706077,35.0115578457318,34.39844692440289,33.78533600307398,33.17222508174502,32.55911416041611,31.9460032390872,31.332892317758233,30.71978139642927,30.10667047510042,29.49355955377145,28.880448632442487,28.267337711113576,27.654226789784666,27.041115868455705,26.428004947126794,25.814894025797884,25.201783104468923,24.588672183140012,23.9755612618111,23.362450340482138,22.749339419153173,22.136228497824263,21.523117576495356,21.058793804261725,20.89204433021867,20.725294856175616,20.558545382132543,20.391795908089488,20.225046434046433,20.05829696000336,19.891547485960288,19.72479801191725,19.55804853787418,19.391299063831106,19.22454958978805,19.057800115744996,18.891050641701923,18.72430116765887,18.557551693615814,18.39080221957274,18.224052745529686,18.057303271486628,17.890553797443555,17.723804323400486,17.55705484935743,17.390305375314377,17.223555901271304,17.05680642722825,16.890056953185194,16.72330747914212,16.556558005099063,16.38980853105601,16.22305905701294,16.056309582969867,15.889560108926826,15.722810634883755,15.556061160840683,15.389311686797628,15.222562212754571,15.0558127387115,14.889063264668446,14.722313790625389,14.555564316582315,14.38881484253926,14.222065368496203,14.055315894453132,13.888566420410061,13.721816946367005,13.55506747232395,13.388317998280877,13.22156852423782,13.054819050194766,12.888069576151695,12.721320102108638,12.554570628065584,12.387821154022511,12.22107167997944,12.0543222059364,11.887572731893329,11.720823257850258,11.554073783807201,11.387324309764146,11.220574835721074,11.053825361678019,10.887075887634962,10.720326413591891,10.553576939548837,10.386827465505778,10.217644294047522,10.042550779372213,9.867457264696938,9.692363750021634,9.517270235346324,9.342176720671034,9.167083205995743,8.991989691320438,8.816896176645145,8.641802661969853,8.466709147294548,8.29161563261924,8.116522117943965,7.941428603268658,7.766335088593351,7.5912415739180625,7.41614805924277,7.241054544567462,7.088326769150081,7.047427690022133,7.006528610894186,6.965629531766239,6.924730452638299,6.883831373510352,6.842932294382404,6.802033215254465,6.761134136126518,6.720235056998571,6.679335977870631,6.638436898742683,6.597537819614736,6.556638740486789,6.5157396613588485,6.474840582230902,6.433941503102955,6.393042423975016,6.352143344847069,6.311244265719122,6.270345186591181,6.229446107463234,6.188547028335287,6.147647949207347,6.106748870079399,6.065849790951452,6.0249507118235055,5.984051632695565,5.943152553567618,5.902253474439671,5.86135439531173,5.820455316183784,5.779556237055837,5.738657157927896,5.69775807879995,5.656858999672002,5.615615137818398,5.572712006630066,5.529808875441725,5.486905744253386,5.444002613065053,5.401099481876713,5.36855702171095,5.343415040847028,5.318273059983103,5.293131079119176,5.267989098255256,5.24284711739133,5.218727684820407,5.1946137793186,5.170499873816799,5.146385968314992,5.122272062813186,5.098158157311383,5.074044251809577,5.049930346307771,5.025816440805969,5.001702535304162,4.977588629802355,4.953474724300549,4.929360818798747,4.90524691329694,4.881133007795134,4.857019102293332,4.8329051967915255,4.808791291289719,4.784677385787917,4.76056348028611,4.736449574784303,4.712335669282501,4.688221763780694,4.6641078582788875,4.639993952777082,4.6158800472752795,4.591766141773473,4.567652236271666,4.543538330769865,4.519424425268058,4.495310519766251,4.471196614264449,4.447082708762642,4.4229688032608365,4.39885489775903,4.374740992257228],[62.893604486717194,62.94600965043722,62.99841481415724,63.05081997787727,63.10322514159729,63.15563030531732,63.20803546903734,63.260440632757366,63.31284579647739,63.365250960197415,63.41765612391744,63.47006128763746,63.52246645135749,63.57487161507751,63.62727677879754,63.67968194251756,63.732087106237586,63.78449226995761,63.836897433677635,63.88930259739766,63.941707761117684,63.99411292483771,64.04651808855772,64.09892325227776,64.15132841599777,64.2037335797178,64.25613874343783,64.30854390715785,64.36094907087788,64.4133542345979,64.46575939831791,64.51816456203795,64.57056972575796,64.622974889478,64.67538005319801,64.72778521691804,64.78019038063806,64.83259554435809,64.88500070807811,64.93740587179813,64.98981103551816,65.04221619923818,65.09462136295821,65.14702652667823,65.19943169039826,65.25183685411828,65.3042420178383,65.35664718155833,65.40905234527835,65.46145750899838,65.5138626727184,65.56626783643843,65.61867300015845,65.67107816387848,65.72325221743705,65.77538004852164,65.82750787960626,65.87963571069085,65.93176354177545,65.98389137286006,66.03601920394465,66.08814703502927,66.14027486611386,66.19240269719846,66.24453052828306,66.29665835936765,66.34878619045226,66.40091402153686,66.45304185262147,66.50516968370606,66.55729751479066,66.60942534587527,66.66155317695987,66.71368100804446,66.76580883912906,66.81793667021367,66.87006450129827,66.92219233238288,66.97432016346747,67.02644799455207,67.07857582563669,67.13070365672128,67.18283148780587,67.23495931889049,67.27777563915518,67.31872965725591,67.35968367535665,67.40063769345737,67.44159171155809,67.48254572965882,67.52349974775956,67.56445376586029,67.60540778396101,67.64636180206175,67.68731582016247,67.72826983826319,67.76922385636394,67.81017787446466,67.85113189256539,67.89208591066611,67.93303992876685,67.97399394686758,68.0149479649683,68.05590198306902,68.09685600116975,68.13781001927049,68.17876403737122,68.21971805547194,68.26067207357266,68.3016260916734,68.34258010977413,68.38353412787487,68.42448814597557,68.46544216407631,68.50639618217704,68.54735020027778,68.5883042183785,68.62925823647922,68.67021225457997,68.71116627268069,68.75212029078142,68.79307430888214,68.83402832698286,68.8749823450836,68.91593636318433,68.95689038128506,68.99784439938578,69.0387984174865,69.07975243558724,69.12070645368797,69.16166047178871,69.20261448988943,69.24356850799015,69.28452252609088,69.32547654419162,69.36643056229235,69.40738458039306,69.4476663265378,69.487611934697,69.52755754285621,69.56750315101544,69.60744875917464,69.64739436733386,69.68733997549309,69.7272855836523,69.7672311918115,69.80717679997073,69.84712240812995,69.88706801628916,69.92701362444838,69.96695923260759,70.00690484076681,70.04685044892602,70.08679605708522,70.12674166524445,70.16668727340367,70.20663288156288,70.2465784897221,70.28652409788131,70.32646970604053,70.36641531419974,70.40636092235896,70.44630653051817,70.48625213867737,70.5261977468366,70.56614335499582,70.60608896315503,70.63421765432017,70.65643788698829,70.67865811965639,70.7008783523245,70.72309858499261,70.74531881766072,70.76753905032882,70.78975928299693,70.81197951566503,70.83419974833315,70.85641998100127,70.87864021366936,70.90086044633748,70.92308067900558,70.94530091167368,70.96752114434179,70.9897413770099,71.01196160967801,71.03418184234611,71.05640207501423,71.07862230768234,71.10084254035044,71.12306277301855,71.14528300568666,71.16750323835477,71.18972347102287,71.21194370369099,71.2341639363591,71.2563841690272,71.27860440169532,71.30082463436342,71.32304486703151,71.34526509969965,71.36748533236774,71.38970556503585,71.41192579770396,71.43414603037206,71.45636626304018,71.47858649570827,71.50080672837639,71.52302696104451,71.54524719371261,71.57198311949327,71.5995254153091,71.62706771112492,71.65461000694073,71.68215230275655,71.70969459857238,71.73723689438819,71.76477919020402,71.79232148601983,71.81986378183564,71.84740607765147,71.87494837346728,71.90249066928311,71.93003296509893,71.95757526091475,71.98511755673057,72.01265985254639,72.0402021483622,72.06774444417803,72.09528673999384,72.12282903580967,72.15037133162548,72.17791362744131,72.20545592325712,72.23299821907294,72.26054051488876,72.28808281070458,72.3156251065204,72.34316740233622,72.37070969815203,72.39825199396786,72.42579428978368,72.45333658559949,72.48087888141531,72.50842117723113,72.53596347304695,72.56350576886277,72.59104806467857,72.61859036049441,72.64613265631021,72.67367495212604,72.37478215101339,71.74945425297227,71.1241263549312,70.49879845689014,69.87347055884902,69.24814266080797,68.6228147627669,67.99748686472579,67.37215896668467,66.74683106864364,66.12150317060252,65.49617527256142,64.87084737452035,64.24551947647929,63.62019157843817,62.9948636803971,62.369535782356046,61.744207884314925,61.11887998627386,60.493552088232796,59.86822419019168,59.242896292150554,58.617568394109554,57.99224049606843,57.36691259802731,56.74158469998625,56.11625680194518,55.49092890390407,54.865601005863006,54.24027310782194,53.61494520978082,52.9896173117397,52.36428941369869,51.73896151565758,51.11363361761646,50.48830571957539,49.86297782153432,49.237649923493215,48.612322025452144,47.98699412741108,47.36166622936996,46.73633833132891,46.11101043328784,45.485682535246724,44.86035463720559,44.235026739164596,43.609698841123475,42.984370943082354,42.35904304504129,41.733715147000225,41.108387248959104,40.48305935091805,39.85773145287698,39.23240355483586,38.60707565679474,37.981747758753734,37.35641986071261,36.73109196267149,36.10576406463043,35.48043616658937,34.85510826854825,34.229780370507186,33.60445247246612,32.979124574425,32.35379667638394,31.728468778342876,31.10314088030176,30.477812982260634,29.85248508421963,29.22715718617851,28.601829288137388,27.976501390096324,27.351173492055263,26.725845594014142,26.100517695973082,25.475189797932014,24.849861899890897,24.23054236635118,23.61743144502227,23.00432052369331,22.39120960236434,21.778098681035434,21.164987759706523,20.700663987472897,20.533914513429842,20.367165039386787,20.200415565343715,20.033666091300656,19.866916617257605,19.700167143214532,19.533417669171463,19.366668195128423,19.19991872108535,19.033169247042277,18.86641977299922,18.699670298956164,18.532920824913095,18.366171350870037,18.19942187682698,18.03267240278391,17.865922928740854,17.6991734546978,17.53242398065473,17.365674506611658,17.198925032568603,17.032175558525545,16.865426084482472,16.700891605678855,16.53673531454187,16.372579023404864,16.208422732267874,16.044266441130887,15.880110149993879,15.715953858856878,15.551797567719904,15.387641276582903,15.223484985445896,15.05932869430891,14.895172403171918,14.731016112034915,14.566859820897927,14.402703529760938,14.238547238623934,14.074390947486945,13.910234656349957,13.746078365212952,13.581922074075948,13.417765782938961,13.25360949180197,13.089453200664966,12.92529690952798,12.761140618390991,12.596984327253987,12.432828036116996,12.268671744980008,12.104515453843003,11.940359162706,11.776202871569026,11.612046580432022,11.447890289295021,11.28373399815803,11.11957770702104,10.95542141588404,10.79126512474705,10.62710883361006,10.462952542473056,10.298796251336068,10.134639960199081,9.970483669062075,9.806327377925072,9.642171086788098,9.478014795651093,9.31385850451409,9.149702213377102,8.985545922240114,8.821389631103111,8.65723333996612,8.493077048829132,8.328920757692128,8.164764466555123,8.00060817541815,7.836451884281146,7.672295593144143,7.508139302007153,7.343983010870165,7.179826719733161,7.036214908896398,6.995325499560663,6.954436090224929,6.913546680889193,6.872657271553466,6.831767862217732,6.790878452881997,6.74998904354627,6.709099634210535,6.6682102248748,6.627320815539072,6.586431406203338,6.545541996867604,6.504652587531868,6.46376317819614,6.422873768860406,6.381984359524671,6.341094950188943,6.300205540853209,6.259316131517473,6.218426722181746,6.177537312846011,6.136647903510276,6.095758494174548,6.054869084838814,6.013979675503078,5.973090266167345,5.932200856831617,5.891311447495881,5.850422038160147,5.80953262882442,5.768643219488684,5.727753810152951,5.691238939730315,5.660292775873344,5.6293466120163735,5.598400448159403,5.567454284302438,5.536508120445467,5.505561956588497,5.474615792731532,5.44366962887456,5.4127234650175895,5.381777301160625,5.350831137303653,5.319884973446683,5.288938809589718,5.257992645732747,5.227046481875777,5.1961003180188055,5.16515415416184,5.139172946161682,5.115058827895303,5.090944709628927,5.066830591362548,5.042716473096167,5.018602354829792,4.994488236563412,4.970374118297032,4.946260000030652,4.922145881764276,4.8980317634978965,4.873917645231517,4.849803526965142,4.825689408698762,4.801575290432382,4.7774611721660065,4.753347053899627,4.729232935633247,4.705118817366872,4.681004699100491,4.656890580834111,4.6327764625677315,4.608662344301356,4.584548226034976,4.560434107768597,4.536319989502221,4.512205871235841,4.488091752969462,4.4639776347030855,4.439863516436706,4.415749398170326,4.391635279903946,4.367521161637571],[63.05912497699226,63.111530140712276,63.1639353044323,63.216340468152325,63.26874563187235,63.321150795592374,63.3735559593124,63.42596112303242,63.47836628675245,63.53077145047247,63.583176614192496,63.63558177791251,63.687986941632545,63.74039210535257,63.792797269072594,63.84520243279262,63.897607596512636,63.95001276023267,64.00241792395269,64.05482308767272,64.10722825139274,64.15963341511275,64.21203857883279,64.26444374255281,64.31684890627284,64.36925406999285,64.42165923371289,64.4740643974329,64.52646956115294,64.57887472487295,64.63127988859299,64.683685052313,64.73609021603303,64.78849537975306,64.84090054347307,64.8933057071931,64.94571087091313,64.99802359074366,65.05015142182825,65.10227925291285,65.15440708399744,65.20653491508206,65.25866274616665,65.31079057725125,65.36291840833586,65.41504623942046,65.46717407050505,65.51930190158966,65.57142973267426,65.62355756375885,65.67568539484347,65.72781322592806,65.77994105701266,65.83206888809727,65.88419671918186,65.93632455026648,65.98845238135107,66.04058021243567,66.09270804352028,66.14483587460487,66.19696370568947,66.24909153677407,66.30121936785868,66.35334719894328,66.40547503002787,66.45760286111248,66.50973069219708,66.56185852328167,66.61398635436629,66.6661141854509,66.71824201653548,66.77036984762009,66.82249767870469,66.8746255097893,66.92675334087389,66.97888117195849,67.0310090030431,67.08313683412769,67.1352646652123,67.1873924962969,67.2395203273815,67.2916481584661,67.34377598955069,67.3959038206353,67.43872014089999,67.47967415900072,67.52062817710146,67.56158219520219,67.60253621330291,67.64349023140363,67.68444424950437,67.7253982676051,67.76635228570584,67.80730630380656,67.8482603219073,67.88921434000802,67.93016835810874,67.97112237620948,68.01207639431021,68.05303041241093,68.09398443051167,68.13493844861239,68.17589246671312,68.21684648481386,68.25780050291458,68.2987545210153,68.33970853911603,68.38066255721677,68.4216165753175,68.46257059341822,68.50352461151894,68.54447862961968,68.58543264772041,68.62638666582114,68.66734068392186,68.70829470202258,68.74924872012332,68.79020273822405,68.83115675632479,68.87211077442551,68.9128967253746,68.95284233353381,68.99278794169302,69.03273354985224,69.07267915801145,69.11262476617067,69.1525703743299,69.1925159824891,69.23246159064831,69.27240719880753,69.31235280696674,69.35229841512596,69.39224402328517,69.43218963144437,69.4721352396036,69.51208084776282,69.55202645592203,69.59197206408125,69.63191767224046,69.67186328039968,69.71180888855889,69.7517544967181,69.79170010487732,69.83164571303654,69.87159132119575,69.91153692935497,69.95148253751418,69.99142814567341,70.03137375383261,70.07131936199183,70.11126497015104,70.15121057831027,70.19115618646947,70.23110179462869,70.2710474027879,70.31099301094712,70.35093861910633,70.39088422726554,70.43082983542476,70.47077544358397,70.51072105174319,70.5506666599024,70.59061226806162,70.63055787622085,70.67050348438005,70.71044909253928,70.75039470069848,70.77852339186363,70.80074362453173,70.82296385719985,70.84518408986796,70.86740432253606,70.88962455520416,70.91184478787227,70.93406502054037,70.95628525320849,70.9785054858766,71.00072571854471,71.02294595121282,71.04516618388094,71.06738641654904,71.08960664921715,71.11182688188525,71.13404711455335,71.15626734722147,71.17848757988958,71.20070781255768,71.22292804522579,71.2451482778939,71.26736851056201,71.28958874323013,71.31180897589823,71.33402920856634,71.35624944123444,71.37846967390254,71.40068990657066,71.42291013923877,71.44513037190688,71.46735060457499,71.4895708372431,71.5117910699112,71.5340113025793,71.5562315352474,71.57845176791552,71.60067200058363,71.62289223325175,71.64511246591985,71.66733269858796,71.68955293125607,71.71177316392418,71.73399339659228,71.75621362926039,71.7784338619285,71.80065409459661,71.82287432726471,71.84509455993282,71.86731479260092,71.88953502526904,71.91175525793714,71.93397549060526,71.95619572327337,71.97841595594147,72.00063618860958,72.02285642127768,72.0450766539458,72.06729688661392,72.08951711928202,72.11173735195013,72.13395758461823,72.15617781728633,72.17839804995445,72.20061828262256,72.22735420350693,72.25489649932275,72.28243879513857,72.3099810909544,72.33752338677021,72.36506568258602,72.39260797840184,72.42015027421766,72.44769257003348,72.4752348658493,72.50277716166512,72.53031945748094,72.55786175329676,72.58540404911258,72.6129463449284,72.64048864074421,72.66803093656003,72.69557323237585,72.3966804312632,71.77135253322207,71.14602463518102,70.52069673713996,69.89536883909884,69.27004094105779,68.64471304301671,68.01938514497559,67.39405724693448,66.76872934889347,66.14340145085235,65.51807355281122,64.89274565477017,64.2674177567291,63.64208985868798,63.016761960646924,62.39143406260586,61.76610616456474,61.14077826652367,60.51545036848261,59.89012247044149,59.26479457240036,58.63946667435937,58.014138776318255,57.38881087827713,56.76348298023607,56.138155082195006,55.51282718415388,54.88749928611282,54.26217138807175,53.636843490030635,53.01151559198951,52.3861876939485,51.76085979590738,51.135531897866265,50.51020399982521,49.884876101784144,49.259548203743016,48.63422030570196,48.008892407660895,47.38356450961978,46.75804209842239,46.12561454543644,45.49318699245043,44.86075943946442,44.22833188647853,43.59590433349252,42.96347678050651,42.33104922752056,41.698621674534614,41.066194121548605,40.43376656856266,39.8013390155767,39.1689114625907,38.53648390960469,37.904056356618796,37.27162880363279,36.63920125064678,36.006773697660826,35.37434614467488,34.74191859168887,34.10949103870292,33.47706348571697,32.84463593273097,32.21220837974501,31.57978082675906,30.947353273773054,30.314925720787038,29.68249816780115,29.05007061481514,28.417643061829136,27.78521550884318,27.152787955857235,26.520360402871223,25.887932849885274,25.255505296899322,24.623077743913317,23.990650190927365,23.358222637941417,22.725795084955404,22.0933675319694,21.460939978983447,20.828512425997495,20.354728303667212,20.198231042648253,20.041733781629297,19.885236520610324,19.728739259591368,19.57224199857241,19.415744737553435,19.259247476534465,19.10275021551552,18.94625295449655,18.789755693477577,18.633258432458618,18.476761171439662,18.32026391042069,18.16376664940173,18.007269388382774,17.850772127363804,17.694274866344845,17.537777605325886,17.381280344306916,17.224783083287942,17.068285822268987,16.911788561250027,16.755291300231058,16.5987940392121,16.44229677819314,16.28579951717417,16.129302256155214,15.972804995136253,15.81630773411728,15.65981047309831,15.501203058301586,15.337046767164585,15.172890476027579,15.00873418489059,14.844577893753598,14.680421602616596,14.516265311479607,14.352109020342619,14.187952729205616,14.023796438068626,13.859640146931639,13.695483855794633,13.53132756465763,13.367171273520643,13.203014982383653,13.038858691246649,12.87470240010966,12.710546108972672,12.546389817835667,12.382233526698679,12.21807723556169,12.053920944424686,11.889764653287681,11.725608362150709,11.561452071013704,11.397295779876703,11.233139488739713,11.068983197602726,10.904826906465718,10.74067061532873,10.576514324191741,10.412358033054737,10.24820174191775,10.084045450780762,9.919889159643756,9.755732868506751,9.591576577369779,9.427420286232774,9.263263995095773,9.099107703958785,8.934951412821796,8.770795121684792,8.606638830547801,8.442482539410813,8.278326248273807,8.114169957136806,7.950013665999833,7.785857374862828,7.6217010837258234,7.457544792588833,7.293388501451844,7.129232210314843,6.98562039947808,6.944730990142345,6.90384158080661,6.8629521714708766,6.822062762135149,6.781173352799414,6.7402839434636785,6.699394534127952,6.658505124792216,6.617615715456482,6.576726306120754,6.535836896785019,6.494947487449284,6.454058078113549,6.413168668777821,6.372279259442088,6.331389850106352,6.290500440770626,6.24961103143489,6.212620929715848,6.181674765858882,6.150728602001912,6.119782438144941,6.088836274287975,6.057890110431004,6.026943946574033,5.995997782717064,5.965051618860098,5.934105455003127,5.9031592911461575,5.872213127289191,5.841266963432221,5.81032079957525,5.779374635718284,5.748428471861314,5.717482308004343,5.6865361441473725,5.655589980290407,5.624643816433435,5.5936976525764655,5.5627514887195,5.531805324862529,5.500859161005558,5.469912997148594,5.438966833291623,5.408020669434652,5.377074505577688,5.346128341720716,5.315182177863745,5.284236014006774,5.25328985014981,5.222343686292839,5.191397522435868,5.160451358578904,5.129505194721933,5.098559030864961,5.0676128670079965,5.036666703151026,5.005720539294055,4.974774375437084,4.943828211580119,4.912882047723148,4.881935883866177,4.850989720009212,4.820043556152241,4.794388881565146,4.7702747632987705,4.74616064503239,4.722046526766011,4.697932408499635,4.673818290233255,4.649704171966874,4.6255900537004955,4.60147593543412,4.57736181716774,4.553247698901361,4.529133580634985,4.505019462368605,4.480905344102226,4.4567912258358495,4.43267710756947,4.408562989303089,4.38444887103671,4.360334752770335],[63.22464546726731,63.27705063098733,63.32945579470736,63.38186095842738,63.434266122147406,63.48667128586743,63.539076449587455,63.59148161330747,63.643886777027504,63.69629194074753,63.74869710446755,63.80110226818758,63.8535074319076,63.905912595627626,63.95831775934765,64.01072292306768,64.0631280867877,64.11553325050772,64.16793841422775,64.22034357794777,64.2727487416678,64.32492279513484,64.37705062621944,64.42917845730406,64.48130628838865,64.53343411947324,64.58556195055786,64.63768978164245,64.68981761272705,64.74194544381166,64.79407327489625,64.84620110598087,64.89832893706546,64.95045676815006,65.00258459923467,65.05471243031926,65.10684026140387,65.15896809248846,65.21109592357307,65.26322375465766,65.31535158574226,65.36747941682688,65.41960724791147,65.47173507899606,65.52386291008068,65.57599074116527,65.62811857224987,65.68024640333448,65.73237423441907,65.78450206550367,65.83662989658828,65.88875772767288,65.94088555875749,65.99301338984208,66.04514122092668,66.09726905201128,66.14939688309589,66.2015247141805,66.2536525452651,66.30578037634969,66.35790820743429,66.41003603851888,66.4621638696035,66.51429170068809,66.5664195317727,66.61854736285729,66.67067519394189,66.7228030250265,66.7749308561111,66.8270586871957,66.8791865182803,66.9313143493649,66.98344218044952,67.0355700115341,67.08769784261871,67.13982567370331,67.19195350478792,67.24408133587251,67.29620916695711,67.34833699804172,67.40046482912632,67.45259266021093,67.50472049129552,67.55684832238012,67.59966464264483,67.64061866074556,67.68157267884628,67.72252669694701,67.76348071504773,67.80443473314847,67.8453887512492,67.88634276934992,67.92729678745064,67.96825080555138,68.00920482365211,68.05015884175283,68.09111285985358,68.13206687795429,68.17302089605504,68.21397491415576,68.25492893225649,68.29588295035721,68.33683696845794,68.37779098655867,68.4180727323706,68.45801834052983,68.49796394868905,68.53790955684825,68.57785516500746,68.61780077316669,68.65774638132591,68.69769198948511,68.73763759764434,68.77758320580355,68.81752881396275,68.85747442212198,68.8974200302812,68.9373656384404,68.97731124659961,69.01725685475884,69.05720246291806,69.09714807107727,69.13709367923649,69.1770392873957,69.21698489555492,69.25693050371413,69.29687611187336,69.33682172003256,69.37676732819178,69.41671293635099,69.4566585445102,69.49660415266942,69.53654976082863,69.57649536898784,69.61644097714706,69.65638658530628,69.6963321934655,69.73627780162471,69.77622340978391,69.81616901794314,69.85611462610235,69.89606023426157,69.93600584242078,69.97595145058,70.01589705873923,70.05584266689843,70.09578827505764,70.13573388321686,70.17567949137607,70.21562509953529,70.2555707076945,70.29551631585372,70.33546192401292,70.37540753217215,70.41535314033135,70.45529874849058,70.49524435664979,70.535189964809,70.57513557296822,70.61508118112744,70.65502678928665,70.69497239744587,70.73491800560508,70.7748636137643,70.81480922192351,70.85475483008273,70.89470043824194,70.92282912940709,70.9450493620752,70.9672695947433,70.9894898274114,71.01171006007952,71.03393029274763,71.05615052541573,71.07837075808385,71.10059099075195,71.12281122342006,71.14503145608816,71.16725168875627,71.1894719214244,71.2116921540925,71.23391238676061,71.25613261942871,71.27835285209682,71.30057308476493,71.32279331743304,71.34501355010114,71.36723378276926,71.38945401543737,71.41167424810547,71.43389448077357,71.45611471344168,71.47833494610978,71.50055517877792,71.522775411446,71.54499564411411,71.56721587678223,71.58943610945033,71.61165634211844,71.63387657478656,71.65609680745466,71.67831704012276,71.70053727279087,71.72275750545899,71.74497773812709,71.7671979707952,71.78941820346331,71.81163843613142,71.83385866879952,71.85607890146763,71.87829913413574,71.90051936680385,71.92273959947195,71.94495983214006,71.96718006480819,71.9894002974763,72.0116205301444,72.0338407628125,72.0560609954806,72.07828122814871,72.10050146081682,72.12272169348493,72.14494192615305,72.16716215882116,72.18938239148926,72.21160262415738,72.23382285682548,72.25604308949357,72.27826332216169,72.3004835548298,72.3227037874979,72.34492402016602,72.36714425283412,72.38936448550224,72.41158471817035,72.43380495083845,72.45602518350657,72.47824541617466,72.49925204820416,72.51752810322638,72.53580415824861,72.55408021327084,72.57235626829305,72.59063232331528,72.6089083783375,72.62718443335973,72.64546048838196,72.66373654340418,72.68201259842641,72.70028865344861,72.39104473312064,71.7542808374424,71.11751694176421,70.48075304608604,69.8439891504078,69.20722525472964,68.57046135905146,67.93369746337322,67.29693356769499,66.66016967201686,66.02340577633863,65.38664188066039,64.75125459497137,64.11882704198543,63.48639948899941,62.85397193601346,62.221544383027506,61.589116830041505,60.95668927705556,60.32426172406961,59.69183417108359,59.05940661809759,58.4269790651117,57.79455151212568,57.16212395913968,56.529696406153725,55.89726885316778,55.264841300181764,54.63241374719582,53.99998619420987,53.36755864122386,52.73513108823785,52.10270353525196,51.47027598226595,50.83784842927994,50.205420876293985,49.57299332330805,48.94056577032203,48.30813821733609,47.67571066435014,47.04328311136412,46.410855558378174,45.77842800539223,45.14600045240621,44.5135728994202,43.881145346434316,43.24871779344831,42.61629024046229,41.983862687476346,41.351435134490394,40.71900758150439,40.08658002851844,39.45415247553248,38.82172492254648,38.189297369560464,37.556869816574576,36.92444226358857,36.292014710602565,35.65958715761661,35.02715960463066,34.39473205164465,33.7623044986587,33.12987694567275,32.49744939268675,31.865021839700795,31.232594286714843,30.600166733728834,29.967739180742825,29.335311627756933,28.70288407477092,28.070456521784916,27.438028968798967,26.80560141581302,26.173173862827007,25.540746309841055,24.908318756855106,24.275891203869097,23.64346365088315,23.011036097897197,22.378608544911188,21.74618099192518,21.11375343893923,20.481325885953282,20.007541763622996,19.851044502604033,19.694547241585077,19.538049980566107,19.381552719547148,19.225055458528193,19.06855819750922,18.912060936490246,18.755563675471304,18.59906641445233,18.44256915343336,18.2860718924144,18.129574631395442,17.973077370376473,17.816580109357513,17.660082848338558,17.503585587319584,17.34708832630063,17.19059106528167,17.034093804262696,16.877596543243726,16.721099282224767,16.56460202120581,16.408104760186838,16.251607499167882,16.095110238148923,15.938612977129951,15.782115716110994,15.625618455092036,15.469121194073065,15.312623933054091,15.15612667203515,14.999629411016176,14.843132149997205,14.686634888978247,14.53013762795929,14.373640366940318,14.217143105921359,14.060645844902403,13.904148583883428,13.74765132286447,13.591154061845513,13.434656800826541,13.278159539807568,13.121662278788609,12.965165017769653,12.808667756750681,12.652170495731724,12.495673234712765,12.339175973693795,12.182678712674836,12.026181451655878,11.869684190636907,11.713186929617933,11.556689668598992,11.40019240758002,11.243695146561047,11.08719788554209,10.930700624523132,10.77420336350416,10.617706102485203,10.461208841466245,10.304711580447272,10.148214319428314,9.991717058409357,9.835219797390385,9.678722536371414,9.522225275352469,9.365728014333497,9.209230753314525,9.048513194540462,8.884356903403475,8.72020061226647,8.556044321129482,8.391888029992492,8.22773173885549,8.063575447718485,7.899419156581511,7.735262865444506,7.571106574307504,7.406950283170515,7.242793992033526,7.078637700896523,6.935025890059761,6.8941364807240255,6.8532470713882905,6.812357662052556,6.771468252716828,6.734002919701388,6.703056755844417,6.672110591987452,6.641164428130482,6.61021826427351,6.579272100416546,6.548325936559575,6.517379772702603,6.486433608845633,6.455487444988668,6.424541281131697,6.393595117274726,6.362648953417762,6.33170278956079,6.30075662570382,6.269810461846855,6.238864297989885,6.207918134132913,6.176971970275948,6.146025806418978,6.115079642562006,6.084133478705036,6.053187314848071,6.0222411509911,5.991294987134129,5.960348823277164,5.929402659420193,5.898456495563222,5.867510331706257,5.836564167849286,5.805618003992316,5.774671840135344,5.7437256762783795,5.71277951242141,5.681833348564438,5.650887184707472,5.6199410208505025,5.588994856993532,5.558048693136566,5.5271025292795954,5.496156365422625,5.465210201565659,5.434264037708688,5.403317873851718,5.372371709994747,5.341425546137781,5.310479382280811,5.27953321842384,5.248587054566875,5.217640890709904,5.186694726852934,5.155748562995969,5.124802399138998,5.0938562352820265,5.062910071425057,5.031963907568091,5.00101774371112,4.9700715798541495,4.939125415997185,4.908179252140213,4.877233088283242,4.846286924426278,4.815340760569307,4.784394596712336,4.753448432855371,4.722502268998401,4.69155610514143,4.660609941284459,4.629663777427494,4.598717613570523,4.567771449713552,4.536825285856587,4.505879121999616,4.474932958142645,4.4496048169686135,4.425490698702234,4.401376580435853,4.377262462169473,4.353148343903098],[63.390165957542365,63.44257112126239,63.49497628498241,63.54738144870243,63.599694168441445,63.65182199952604,63.70394983061065,63.75607766169524,63.80820549277985,63.86033332386445,63.91246115494905,63.96458898603365,64.01671681711825,64.06884464820286,64.12097247928746,64.17310031037205,64.22522814145665,64.27735597254126,64.32948380362586,64.38161163471045,64.43373946579506,64.48586729687966,64.53799512796427,64.59012295904887,64.64225079013346,64.69437862121806,64.74650645230267,64.79863428338727,64.85076211447188,64.90288994555647,64.95501777664107,65.00714560772568,65.05927343881027,65.11140126989488,65.16352910097947,65.21565693206408,65.26778476314868,65.31991259423327,65.37204042531789,65.42416825640248,65.47629608748707,65.52842391857169,65.58055174965628,65.63267958074088,65.68480741182549,65.73693524291009,65.7890630739947,65.84119090507929,65.89331873616389,65.9454465672485,65.99757439833309,66.0497022294177,66.1018300605023,66.1539578915869,66.2060857226715,66.2582135537561,66.31034138484071,66.3624692159253,66.4145970470099,66.46672487809451,66.5188527091791,66.5709805402637,66.62310837134831,66.67523620243291,66.7273640335175,66.77949186460211,66.83161969568671,66.88374752677132,66.93587535785592,66.98800318894051,67.04013102002511,67.09225885110972,67.14438668219432,67.19651451327891,67.24864234436352,67.30077017544812,67.35289800653273,67.40502583761733,67.45715366870192,67.50928149978654,67.56140933087114,67.61353716195573,67.66566499304034,67.71779282412494,67.76060914438965,67.80156316249038,67.8425171805911,67.88330313120741,67.92324873936663,67.96319434752584,68.00313995568507,68.04308556384427,68.08303117200349,68.1229767801627,68.16292238832192,68.20286799648113,68.24281360464035,68.28275921279956,68.32270482095878,68.36265042911799,68.4025960372772,68.44254164543642,68.48248725359564,68.52243286175485,68.56237846991407,68.60232407807328,68.6422696862325,68.68221529439171,68.72216090255093,68.76210651071014,68.80205211886937,68.84199772702857,68.88194333518778,68.921888943347,68.96183455150621,69.00178015966543,69.04172576782466,69.08167137598386,69.12161698414307,69.16156259230229,69.2015082004615,69.24145380862072,69.28139941677995,69.32134502493915,69.36129063309838,69.40123624125758,69.44118184941681,69.48112745757601,69.52107306573522,69.56101867389444,69.60096428205367,69.64090989021288,69.6808554983721,69.7208011065313,69.76074671469053,69.80069232284973,69.84063793100896,69.88058353916816,69.92052914732739,69.96047475548659,70.0004203636458,70.04036597180502,70.08031157996423,70.12025718812345,70.16020279628268,70.20014840444188,70.2400940126011,70.2800396207603,70.31998522891953,70.35993083707874,70.39987644523796,70.43982205339717,70.47976766155638,70.5197132697156,70.55965887787481,70.59960448603402,70.63955009419324,70.67949570235245,70.71944131051168,70.75938691867088,70.79933252683011,70.83927813498931,70.87922374314854,70.91916935130774,70.95911495946696,70.99906056762619,71.03900617578539,71.06713486695054,71.08935509961864,71.11157533228676,71.13379556495488,71.15601579762298,71.17823603029107,71.2004562629592,71.2226764956273,71.2448967282954,71.26711696096352,71.28933719363162,71.31155742629973,71.33377765896785,71.35326731482893,71.37154336985115,71.38981942487338,71.4080954798956,71.42637153491782,71.44464758994005,71.46292364496227,71.4811996999845,71.49947575500673,71.51775181002894,71.53602786505117,71.5543039200734,71.57257997509564,71.59085603011785,71.60913208514006,71.62740814016229,71.64568419518451,71.66396025020674,71.68223630522898,71.7005123602512,71.71878841527342,71.73706447029564,71.75534052531788,71.7736165803401,71.79189263536233,71.81016869038453,71.82844474540677,71.84672080042898,71.86499685545121,71.88327291047344,71.90154896549566,71.91982502051789,71.93810107554012,71.95637713056234,71.97465318558456,71.9929292406068,72.01120529562903,72.02948135065124,72.04775740567347,72.06603346069569,72.0843095157179,72.10258557074013,72.12086162576236,72.13913768078459,72.15741373580681,72.17568979082904,72.19396584585127,72.21224190087348,72.23051795589572,72.24879401091793,72.26707006594015,72.28534612096237,72.3036221759846,72.32189823100683,72.34017428602907,72.35845034105128,72.3767263960735,72.39500245109573,72.41327850611796,72.43155456114017,72.4498306161624,72.46810667118463,72.48638272620686,72.50465878122908,72.5229348362513,72.54121089127354,72.55948694629575,72.57776300131798,72.59603905634019,72.61431511136243,72.30507119103441,71.66830729535619,71.03154339967801,70.39477950399983,69.7580156083216,69.12125171264341,68.48448781696526,67.84772392128701,67.21096002560878,66.57419612993067,65.93743223425243,65.3006683385742,64.66390444289601,64.02714054721784,63.39037665153961,62.75361275586143,62.11684886018326,61.48008496450501,60.843321068826846,60.206557173148674,59.56979327747044,58.9330293817922,58.29626548611408,57.65950159043586,57.022737694757616,56.38597379907944,55.749209903401265,55.11244600772303,54.47568211204485,53.838918216366686,53.20215432068845,52.56539042501021,51.92862652933209,51.291862633653864,50.65509873797562,50.01833484229745,49.38157094661928,48.74480705094105,48.10804315526286,47.47127925958468,46.83451536390645,46.197751468228276,45.560987572550104,44.92422367687187,44.28745978119363,43.65069588551551,43.013931989837275,42.377168094159046,41.740404198480874,41.103640302802695,40.46687640712446,39.83011251144629,39.19334861576811,38.55658472008987,37.919820824411644,37.28305692873353,36.646293033055294,36.00952913737706,35.37276524169888,34.73600134602071,34.09923745034247,33.46247355466429,32.82570965898612,32.188945763307885,31.55218186762971,30.915417971951534,30.278654076273302,29.641890180595066,29.005126284916948,28.368362389238715,27.73159849356048,27.094834597882304,26.45841487576881,25.825987322782805,25.193559769796853,24.561132216810904,23.928704663824895,23.296277110838943,22.663849557852995,22.031422004866986,21.398994451880977,20.76656689889503,20.134139345909077,19.66035522357879,19.503857962559827,19.347360701540875,19.190863440521902,19.034366179502943,18.877868918483983,18.721371657465014,18.564874396446044,18.408377135427095,18.251879874408125,18.095382613389155,17.9388853523702,17.782388091351237,17.62589083033227,17.469393569313308,17.312896308294356,17.156399047275382,16.999901786256427,16.844956307831968,16.69145745531121,16.53795860279045,16.384459750269706,16.23096089774896,16.0774620452282,15.923963192707454,15.77046434018671,15.61696548766595,15.463466635145206,15.309967782624462,15.156468930103701,15.002970077582942,14.849471225062212,14.695972372541453,14.542473520020692,14.388974667499948,14.235475814979203,14.081976962458445,13.928478109937698,13.774979257416952,13.621480404896195,13.467981552375448,13.314482699854704,13.160983847333943,13.007484994813186,12.853986142292442,12.700487289771694,12.546988437250937,12.39348958473019,12.239990732209446,12.086491879688687,11.93299302716794,11.779494174647196,11.625995322126437,11.472496469605678,11.318997617084948,11.16549876456419,11.011999912043429,10.858501059522682,10.70500220700194,10.551503354481179,10.398004501960434,10.24450564943969,10.091006796918931,9.937507944398186,9.78400909187744,9.63051023935668,9.47701138683592,9.32351253431519,9.17001368179443,9.016514829273671,8.863015976752926,8.709517124232182,8.556018271711421,8.402519419190678,8.249020566669932,8.095521714149173,7.942022861628413,7.788524009107682,7.635025156586924,7.481526304066164,7.328027451545419,7.174528599024674,7.021029746503915,6.888187380356518,6.858627446075767,6.829067511795015,6.799507577514262,6.769947643233516,6.740387708952764,6.710827774672012,6.681267840391266,6.651707906110514,6.622147971829762,6.592588037549015,6.563028103268263,6.533468168987511,6.50390823470676,6.474348300426012,6.444788366145261,6.4152284318645085,6.3856684975837625,6.35610856330301,6.3264597661110304,6.295513602254066,6.264567438397096,6.233621274540123,6.202675110683159,6.171728946826189,6.140782782969216,6.109836619112247,6.078890455255281,6.047944291398311,6.01699812754134,5.986051963684375,5.955105799827404,5.924159635970433,5.893213472113468,5.862267308256497,5.831321144399527,5.800374980542555,5.769428816685591,5.738482652828619,5.707536488971649,5.676590325114684,5.645644161257712,5.614697997400742,5.5837518335437775,5.552805669686807,5.521859505829836,5.49091334197287,5.4599671781159,5.429021014258929,5.398074850401958,5.367128686544993,5.336182522688023,5.305236358831051,5.274290194974086,5.2433440311171156,5.212397867260145,5.18145170340318,5.1505055395462085,5.119559375689239,5.088613211832268,5.057667047975302,5.0267208841183315,4.995774720261361,4.964828556404395,4.933882392547425,4.902936228690454,4.871990064833489,4.841043900976518,4.8100977371195475,4.779151573262583,4.748205409405611,4.71725924554864,4.68631308169167,4.655366917834705,4.624420753977734,4.593474590120763,4.562528426263798,4.531582262406827,4.500636098549856,4.469689934692891,4.43874377083592,4.40779760697895,4.3768514431219785,4.345905279265014],[63.54629949275878,63.59842732384338,63.65055515492798,63.702682986012576,63.75481081709718,63.806938648181784,63.85906647926639,63.911194310350986,63.96332214143559,64.01544997252019,64.06757780360479,64.1197056346894,64.171833465774,64.22396129685859,64.2760891279432,64.3282169590278,64.38034479011239,64.43247262119701,64.4846004522816,64.5367282833662,64.5888561144508,64.64098394553541,64.69311177662,64.7452396077046,64.7973674387892,64.84949526987381,64.90162310095842,64.95375093204301,65.00587876312761,65.05800659421222,65.1101344252968,65.16226225638141,65.214390087466,65.26651791855062,65.31864574963522,65.37077358071981,65.42290141180442,65.47502924288902,65.52715707397363,65.57928490505822,65.63141273614282,65.68354056722742,65.73566839831203,65.78779622939663,65.83992406048122,65.89205189156584,65.94417972265043,65.99630755373502,66.04843538481964,66.10056321590423,66.15269104698883,66.20481887807344,66.25694670915804,66.30907454024263,66.36120237132724,66.41333020241184,66.46545803349645,66.51758586458105,66.56971369566564,66.62184152675025,66.67396935783485,66.72609718891945,66.77822502000406,66.83035285108865,66.88248068217325,66.93460851325786,66.98673634434246,67.03886417542707,67.09099200651166,67.14311983759626,67.19524766868086,67.24695237691252,67.29844552308253,67.34993866925257,67.40143181542258,67.45292496159261,67.50441810776263,67.55591125393266,67.60740440010268,67.6588975462727,67.71039069244273,67.76188383861275,67.81337698478278,67.8648701309528,67.90591786480684,67.9448765161977,67.98383516758854,68.02279381897938,68.06175247037024,68.10071112176108,68.13966977315192,68.17862842454278,68.21758707593364,68.25654572732448,68.29550437871532,68.33446303010618,68.37342168215551,68.41336729031471,68.45331289847392,68.49325850663315,68.53320411479235,68.57314972295157,68.61309533111078,68.65304093927,68.69298654742921,68.73293215558843,68.77287776374764,68.81282337190686,68.85276898006607,68.89271458822529,68.9326601963845,68.97260580454372,69.01255141270293,69.05249702086215,69.09244262902136,69.13238823718058,69.17233384533981,69.21227945349901,69.25222506165822,69.29217066981744,69.33211627797665,69.37206188613587,69.41200749429508,69.4519531024543,69.49189871061351,69.53184431877273,69.57178992693196,69.61173553509116,69.65168114325037,69.69162675140959,69.73157235956882,69.77151796772802,69.81146357588725,69.85140918404645,69.89135479220568,69.93130040036488,69.9712460085241,70.0111916166833,70.05113722484253,70.09108283300174,70.13102844116096,70.17097404932017,70.2109196574794,70.2508652656386,70.29081087379782,70.33075648195702,70.37070209011625,70.41064769827547,70.45059330643468,70.4905389145939,70.53048452275311,70.57043013091231,70.61037573907154,70.65032134723074,70.69026695538997,70.73021256354917,70.7701581717084,70.8101037798676,70.85004938802682,70.88999499618603,70.92994060434525,70.96988621250446,71.00983182066368,71.04977742882289,71.08972303698212,71.12966864514132,71.16961425330054,71.19025677950016,71.20124776471997,71.21223874993977,71.22322973515958,71.2342207203794,71.2452117055992,71.25620269081901,71.26719367603883,71.27818466125862,71.28917564647844,71.30016663169825,71.31115761691805,71.32214860213787,71.33313958735768,71.34413057257748,71.35512155779729,71.36611254301711,71.37710352823692,71.38809451345672,71.39908549867653,71.41007648389633,71.42106746911615,71.43205845433596,71.45005432296497,71.46833037798719,71.48660643300943,71.50488248803164,71.52315854305385,71.5414345980761,71.55971065309832,71.57798670812053,71.59626276314276,71.614538818165,71.63281487318721,71.65109092820944,71.66936698323167,71.6876430382539,71.70591909327611,71.72419514829834,71.74247120332058,71.76074725834279,71.779023313365,71.79729936838723,71.81557542340946,71.83385147843168,71.85212753345391,71.87040358847614,71.88867964349836,71.90695569852059,71.92523175354282,71.94350780856503,71.96178386358726,71.98005991860948,71.9983359736317,72.01661202865392,72.03488808367615,72.05316413869838,72.0714401937206,72.08971624874283,72.10799230376506,72.12626835878729,72.14454441380951,72.16282046883173,72.18109652385394,72.19937257887618,72.2176486338984,72.23592468892062,72.25420074394285,72.27247679896507,72.2907528539873,72.30902890900953,72.32730496403175,72.34558101905397,72.3638570740762,72.38213312909842,72.40040918412065,72.41868523914287,72.4369612941651,72.45523734918731,72.47351340420954,72.49178945923177,72.510065514254,72.52834156927622,72.2190976489482,71.58233375326998,70.9455698575918,70.30880596191363,69.67204206623539,69.0352781705572,68.39851427487903,67.7617503792008,67.12498648352258,66.48822258784446,65.85145869216623,65.21469479648799,64.5779309008098,63.94116700513164,63.3044031094534,62.667639213775225,62.03087531809705,61.39411142241882,60.757347526740645,60.120583631062466,59.48381973538423,58.847055839706,58.21029194402788,57.573528048349644,56.936764152671415,56.30000025699324,55.663236361315064,55.02647246563683,54.38970856995866,53.75294467428048,53.11618077860224,52.47941688292401,51.8426529872459,51.20588909156766,50.56912519588942,49.93236130021125,49.29559740453307,48.65883350885484,48.02206961317666,47.38530571749848,46.74854182182025,46.11177792614207,45.475014030463896,44.83825013478566,44.201486239107425,43.56472234342931,42.927958447751074,42.29119455207284,41.654430656394666,41.01766676071649,40.38090286503826,39.74413896936008,39.1073750736819,38.470611178003665,37.833847282325436,37.197083386647314,36.560319490969086,35.92355559529085,35.28679169961268,34.6500278039345,34.00503274177514,33.35964570073665,32.71425865969816,32.06887161865961,31.423484577621117,30.778097536582628,30.13271049554408,29.487323454505532,28.841936413467103,28.19654937242855,27.551162331390003,26.905775290351514,26.260388249313028,25.61500120827447,24.969614167235985,24.324227126197496,23.678840085158946,23.033453044120456,22.388066003081967,21.742678962043417,21.097291921004867,20.451904879966378,19.80651783892789,19.32740584043053,19.180843927015435,19.03428201360034,18.88772010018523,18.741158186770136,18.59459627335504,18.448034359939932,18.30147244652482,18.15491053310974,18.00834861969463,17.86178670627952,17.715224792864426,17.568662879449327,17.42210096603422,17.275539052619123,17.12897713920403,16.98241522578892,16.83585331237382,16.689291398958726,16.542729485543617,16.39616757212851,16.249605658713413,16.10304374529832,15.956481831883208,15.809919918468111,15.663358005053016,15.516796091637906,15.37023417822281,15.223672264807716,15.077110351392607,14.930548437977496,14.783986524562414,14.637424611147305,14.490862697732197,14.341234437234768,14.187735584714023,14.034236732193264,13.88073787967252,13.727239027151773,13.573740174631014,13.420241322110268,13.266742469589525,13.113243617068765,12.959744764548006,12.806245912027261,12.652747059506515,12.499248206985758,12.34574935446501,12.192250501944265,12.038751649423508,11.885252796902762,11.731753944382017,11.578255091861257,11.424756239340498,11.271257386819768,11.117758534299007,10.964259681778248,10.810760829257504,10.65726197673676,10.503763124215999,10.350264271695256,10.19676541917451,10.04326656665375,9.889767714133004,9.73626886161226,9.582770009091501,9.429271156570742,9.27577230405001,9.122273451529251,8.968774599008492,8.815275746487746,8.661776893967001,8.508278041446243,8.354779188925496,8.201280336404752,8.047781483883993,7.894282631363232,7.740783778842503,7.587284926321744,7.433786073800984,7.280287221280239,7.1267883687594935,6.973289516238735,6.840447150091338,6.810887215810586,6.781327281529834,6.751767347249082,6.722207412968336,6.692647478687584,6.6630875444068325,6.633527610126086,6.603967675845334,6.574407741564581,6.544847807283835,6.515287873003083,6.485727938722331,6.4561680044415795,6.426608070160833,6.39704813588008,6.367488201599329,6.337928267318583,6.30836833303783,6.278808398757079,6.249248464476332,6.2196885301955795,6.190128595914827,6.160568661634081,6.131008727353329,6.101448793072578,6.071888858791825,6.042328924511079,6.012768990230327,5.983209055949575,5.953649121668829,5.924089187388077,5.894529253107324,5.864969318826578,5.835409384545826,5.805849450265074,5.776289515984322,5.746729581703576,5.717169647422824,5.687609713142071,5.658049778861326,5.6284898445805736,5.598929910299821,5.5693699760190745,5.539810041738322,5.510250107457571,5.480690173176824,5.451130238896073,5.4215703046153205,5.390801860862605,5.3598556970056395,5.328909533148669,5.297963369291699,5.267017205434732,5.236071041577762,5.205124877720792,5.174178713863826,5.1432325500068545,5.112286386149885,5.081340222292914,5.050394058435948,5.019447894578978,4.988501730722007,4.957555566865042,4.926609403008071,4.895663239151101,4.864717075294136,4.833770911437164,4.8028247475801935,4.771878583723229,4.740932419866258,4.709986256009287,4.6790400921523165,4.648093928295351,4.61714776443838,4.5862016005814095,4.555255436724444,4.524309272867473,4.493363109010503,4.462416945153538,4.431470781296567,4.400524617439596,4.369578453582625,4.338632289725661],[63.69975104006746,63.75187887115206,63.804006702236656,63.85613453332127,63.90826236440587,63.96039019549047,64.01251802657507,64.06464585765966,64.11677368874427,64.16890151982886,64.22102935091348,64.27315718199807,64.32528501308268,64.37741284416728,64.42954067525187,64.48166850633649,64.53379633742108,64.58592416850568,64.63805199959029,64.69017983067488,64.74230766175948,64.79443549284409,64.84656332392868,64.8986911550133,64.95081898609789,65.00294681718249,65.0550746482671,65.10720247935168,65.1593303104363,65.2114581415209,65.2635859726055,65.3157138036901,65.36784163477469,65.41996946585931,65.4720972969439,65.5242251280285,65.57635295911311,65.6284807901977,65.68060862128232,65.73273645236691,65.78486428345151,65.8369921145361,65.8891199456207,65.94124777670531,65.99337560778991,66.04550343887452,66.09763126995911,66.14975910104371,66.20188693212832,66.25401476321292,66.30614259429751,66.35827042538213,66.41039825646673,66.46252608755132,66.51454813813557,66.56604128430557,66.61753443047562,66.66902757664562,66.72052072281564,66.77201386898568,66.82350701515568,66.87500016132572,66.92649330749573,66.97798645366575,67.02947959983578,67.08097274600581,67.13246589217583,67.18395903834585,67.23545218451588,67.28694533068591,67.33843847685593,67.38993162302594,67.44142476919598,67.492917915366,67.54441106153602,67.59590420770604,67.64739735387607,67.69889050004609,67.75038364621611,67.80187679238614,67.85336993855616,67.90486308472617,67.9563562308962,68.00784937706622,68.04889711092028,68.08785576231112,68.12681441370196,68.16577306509282,68.20473171648366,68.2436903678745,68.28264901926536,68.3216076706562,68.36056632204705,68.3995249734379,68.43848362482876,68.47744227621959,68.51640092761046,68.55535957900129,68.59431823039216,68.633276881783,68.67223553317385,68.7111941845647,68.75015283595555,68.78911148734639,68.82807013873725,68.86702879012809,68.90598744151893,68.94494609290979,68.98390474430065,69.02286339569147,69.06182204708233,69.10078069847319,69.13973934986403,69.17919148013468,69.21913708829389,69.25908269645312,69.29902830461234,69.33897391277154,69.37891952093076,69.41886512908998,69.45881073724918,69.4987563454084,69.53870195356762,69.57864756172683,69.61859316988604,69.65853877804525,69.69848438620448,69.73842999436368,69.7783756025229,69.81832121068211,69.85826681884133,69.89821242700054,69.93815803515977,69.97810364331899,70.0180492514782,70.0579948596374,70.09794046779662,70.13788607595583,70.17783168411506,70.21777729227426,70.25772290043349,70.29766850859271,70.33761411675192,70.37755972491112,70.41750533307035,70.45745094122955,70.49739654938878,70.537342157548,70.57728776570721,70.61723337386643,70.65717898202564,70.69712459018484,70.73707019834407,70.77701580650327,70.8169614146625,70.85690702282172,70.89685263098093,70.93679823914013,70.97674384729935,71.01668945545856,71.05663506361778,71.09658067177699,71.13652627993622,71.17647188809542,71.21641749625465,71.25636310441385,71.29630871257308,71.31695123877267,71.3279422239925,71.3389332092123,71.3499241944321,71.36091517965193,71.37190616487173,71.38289715009154,71.39388813531134,71.40487912053116,71.41587010575097,71.42686109097077,71.43785207619058,71.4488430614104,71.45983404663019,71.47082503185001,71.48181601706983,71.49280700228962,71.50379798750944,71.51478897272924,71.52577995794906,71.53677094316886,71.54776192838868,71.55875291360849,71.56974389882829,71.5807348840481,71.59172586926792,71.60271685448772,71.61370783970753,71.62469882492734,71.63568981014714,71.64668079536695,71.65767178058678,71.66866276580657,71.6796537510264,71.6906447362462,71.70163572146599,71.71262670668582,71.72361769190562,71.73460867712542,71.74559966234523,71.75659064756505,71.76758163278485,71.77857261800466,71.78956360322448,71.80055458844429,71.81154557366409,71.8225365588839,71.83352754410372,71.84451852932352,71.85550951454333,71.86650049976313,71.87749148498294,71.89408637652326,71.9123624315455,71.93063848656772,71.94891454158996,71.96719059661216,71.9854666516344,72.00374270665662,72.02201876167884,72.04029481670106,72.0585708717233,72.07684692674552,72.09512298176774,72.11339903678997,72.13167509181218,72.14995114683441,72.16822720185664,72.18650325687886,72.20477931190109,72.22305536692332,72.24133142194555,72.25960747696776,72.27788353199,72.29615958701221,72.31443564203444,72.33271169705667,72.3509877520789,72.36926380710109,72.38753986212335,72.40581591714556,72.42409197216779,72.44236802719001,72.13312410686201,71.49636021118377,70.8595963155056,70.22283241982743,69.58606852414918,68.94930462847101,68.31254073279283,67.6757768371146,67.03901294143637,66.40224904575825,65.76548515008001,65.12872125440178,64.4919573587236,63.85519346304543,63.21842956736719,62.58166567168902,61.944901776010845,61.30813788033261,60.67137398465444,60.03461008897626,59.39784619329802,58.76108229761979,58.12431840194167,57.487554506263436,56.85079061058521,56.214026714907035,55.57726281922886,54.94049892355062,54.30373502787244,53.66697113219426,53.030207236516034,52.38736795449885,51.741980913460424,51.09659387242187,50.451206831383324,49.805819790344835,49.160432749306345,48.5150457082678,47.8696586672293,47.22427162619081,46.57888458515227,45.93349754411378,45.288110503075295,44.64272346203675,43.99733642099819,43.35194937995976,42.70656233892121,42.06117529788266,41.41578825684417,40.770401215805684,40.12501417476714,39.47962713372864,38.83424009269015,38.188853051651606,37.54346601061306,36.89807896957463,36.25269192853608,35.60730488749753,34.96191784645904,34.316530805420555,33.671143764382,33.02575672334351,32.380369682305016,31.734982641266473,31.08959560022798,30.44420855918949,29.79882151815094,29.153434477112395,28.508047436073966,27.862660395035412,27.217273353996866,26.571886312958377,25.926499271919887,25.281112230881334,24.635725189842848,23.99033814880436,23.34495110776581,22.69956406672732,22.05417702568883,21.408789984650284,20.76340294361173,20.11801590257324,19.47262886153475,18.993516863037392,18.846954949622297,18.700393036207203,18.553831122792094,18.407269209377,18.2607072959619,18.114145382546795,17.967583469131686,17.821021555716605,17.674459642301493,17.52789772888638,17.38133581547129,17.234773902056194,17.088211988641085,16.941650075225986,16.79508816181089,16.648526248395783,16.501964334980688,16.355402421565593,16.20884050815048,16.062278594735368,15.915716681320275,15.76915476790518,15.62259285449007,15.476030941074974,15.329469027659878,15.182907114244768,15.036345200829674,14.889783287414577,14.743221373999468,14.596659460584359,14.450097547169277,14.30353563375417,14.156973720339058,14.010411806923962,13.863849893508867,13.717287980093758,13.570726066678663,13.424164153263565,13.277602239848456,13.13104032643336,12.984478413018264,12.837916499603157,12.691354586188044,12.54479267277295,12.398230759357855,12.251668845942746,12.10510693252765,11.958545019112552,11.811983105697445,11.665421192282349,11.518859278867254,11.372297365452143,11.225735452037034,11.079173538621951,10.932611625206844,10.786049711791732,10.639487798376638,10.492925884961542,10.346363971546431,10.199802058131336,10.053240144716241,9.90667823130113,9.760116317886036,9.613554404470941,9.46699249105583,9.320430577640721,9.173868664225639,9.027306750810528,8.88074483739542,8.734182923980324,8.587621010565229,8.44105909715012,8.294497183735025,8.147935270319929,8.00004125361881,7.846542401098052,7.693043548577321,7.539544696056561,7.386045843535803,7.232546991015058,7.079048138494311,6.925549285973553,6.7927069198261565,6.763146985545405,6.733587051264652,6.704027116983901,6.674467182703154,6.6449072484224025,6.61534731414165,6.585787379860904,6.556227445580152,6.526667511299401,6.497107577018653,6.467547642737902,6.4379877084571495,6.408427774176397,6.37886783989565,6.3493079056149,6.319747971334148,6.290188037053401,6.260628102772649,6.2310681684918965,6.20150823421115,6.171948299930397,6.142388365649646,6.1128284313689,6.083268497088147,6.053708562807396,6.0241486285266435,5.994588694245897,5.965028759965144,5.935468825684394,5.905908891403646,5.876348957122895,5.846789022842143,5.817229088561396,5.787669154280644,5.758109219999893,5.72854928571914,5.698989351438394,5.669429417157642,5.63986948287689,5.610309548596144,5.580749614315391,5.551189680034639,5.521629745753893,5.492069811473141,5.462509877192389,5.432949942911643,5.403390008630891,5.373830074350138,5.344270140069387,5.314710205788639,5.285150271507888,5.255590337227136,5.22603040294639,5.1964704686656376,5.166910534384885,5.1373506001041385,5.107790665823387,5.078230731542636,5.048670797261884,5.019110862981137,4.9895509287003845,4.959990994419632,4.930431060138886,4.900871125858134,4.871311191577382,4.841751257296636,4.812191323015884,4.782631388735132,4.7530714544543855,4.723511520173634,4.693951585892881,4.66439165161213,4.634831717331383,4.605271783050632,4.5757118487698785,4.5461519144891325,4.51659198020838,4.486090119471149,4.455143955614184,4.424197791757214,4.393251627900242,4.3623054640432715,4.331359300186307],[63.85320258737614,63.905330418460736,63.95745824954534,64.00958608062994,64.06171391171455,64.11384174279914,64.16596957388374,64.21809740496835,64.27022523605295,64.32235306713756,64.37448089822215,64.42660872930675,64.47873656039135,64.53086439147596,64.58299222256056,64.63512005364515,64.68724788472976,64.73937571581436,64.79150354689897,64.84363137798357,64.89575920906816,64.94788704015276,65.00001487123735,65.05214270232196,65.10427053340656,65.15639836449117,65.20852619557577,65.26065402666036,65.31278185774498,65.36490968882957,65.41703751991417,65.46916535099878,65.52129318208337,65.57342101316799,65.62554884425258,65.67767667533718,65.72980450642179,65.78193233750638,65.8336370455286,65.88513019169862,65.93662333786864,65.98811648403867,66.03960963020869,66.09110277637872,66.14259592254874,66.19408906871875,66.24558221488878,66.2970753610588,66.34856850722883,66.40006165339885,66.45155479956888,66.5030479457389,66.55454109190893,66.60603423807895,66.65752738424898,66.709020530419,66.76051367658903,66.81200682275905,66.86349996892906,66.9149931150991,66.96648626126911,67.01797940743914,67.06947255360916,67.12096569977918,67.17245884594921,67.22395199211923,67.27544513828926,67.32693828445927,67.37843143062929,67.42992457679932,67.48141772296934,67.53291086913937,67.58440401530939,67.63589716147942,67.68739030764944,67.73888345381945,67.79037659998949,67.8418697461595,67.89336289232952,67.94485603849955,67.99634918466958,68.04784233083959,68.09933547700962,68.15082862317965,68.19187635703369,68.23083500842453,68.26979365981538,68.30875231120623,68.34771096259709,68.38666961398792,68.42562826537878,68.46458691676963,68.50354556816048,68.54250421955132,68.58146287094218,68.62042152233302,68.65938017372387,68.69833882511472,68.73729747650557,68.77625612789642,68.81521477928726,68.85417343067812,68.89313208206896,68.93209073345982,68.97104938485066,69.0100080362415,69.04896668763234,69.0879253390232,69.12688399041406,69.1658426418049,69.20480129319574,69.2437599445866,69.28271859597744,69.3216772473683,69.36063589875914,69.39959455015,69.43855320154084,69.47751185293168,69.51647050432254,69.55542915571338,69.59438780710424,69.63334645849507,69.67230510988593,69.71126376127678,69.75022241266763,69.78918106405848,69.82813971544931,69.86709836684017,69.90605701823102,69.94501566995464,69.98496127811386,70.02490688627307,70.06485249443229,70.1047981025915,70.14474371075072,70.18468931890992,70.22463492706915,70.26458053522836,70.30452614338758,70.34447175154679,70.384417359706,70.42436296786522,70.46430857602444,70.50425418418365,70.54419979234287,70.58414540050208,70.6240910086613,70.66403661682051,70.70398222497973,70.74392783313894,70.78387344129816,70.82381904945737,70.86376465761658,70.9037102657758,70.94365587393501,70.98360148209423,71.02354709025344,71.06349269841266,71.10343830657187,71.14338391473109,71.1833295228903,71.22327513104952,71.26322073920873,71.30316634736795,71.34311195552716,71.38305756368638,71.4230031718456,71.44364569804522,71.45463668326502,71.46562766848483,71.47661865370463,71.48760963892444,71.49860062414426,71.50959160936407,71.52058259458387,71.53157357980368,71.5425645650235,71.5535555502433,71.56454653546311,71.57553752068291,71.58652850590272,71.59751949112254,71.60851047634235,71.61950146156215,71.63049244678197,71.64148343200178,71.65247441722158,71.66346540244139,71.67445638766121,71.68544737288101,71.69643835810082,71.70742934332063,71.71842032854043,71.72941131376025,71.74040229898006,71.75139328419988,71.76238426941967,71.77337525463949,71.7843662398593,71.7953572250791,71.8063482102989,71.81733919551871,71.82833018073852,71.83932116595834,71.85031215117814,71.86130313639794,71.87229412161777,71.88328510683758,71.89427609205738,71.90526707727719,71.916258062497,71.9272490477168,71.93824003293662,71.94923101815642,71.96022200337623,71.97121298859605,71.98220397381586,71.99319495903566,72.00418594425547,72.01517692947529,72.0261679146951,72.0371588999149,72.0481498851347,72.05914087035453,72.07013185557432,72.08112284079414,72.09211382601396,72.10310481123375,72.11409579645357,72.12508678167337,72.13607776689318,72.14706875211299,72.1580597373328,72.16905072255261,72.18004170777242,72.19103269299224,72.20202367821203,72.21301466343184,72.22400564865166,72.23499663387146,72.24598761909127,72.25697860431107,72.26796958953089,72.2789605747507,72.28995155997052,72.30094254519032,72.31193353041012,72.32292451562994,72.33811843008158,72.3563944851038,72.04715056477579,71.41038666909758,70.76970316722263,70.12431612618415,69.47892908514561,68.83354204410712,68.18815500306863,67.54276796203007,66.89738092099152,66.2519938799531,65.60660683891454,64.961219797876,64.31583275683751,63.67044571579902,63.025058674760466,62.379671633721976,61.73428459268349,61.08889755164493,60.443510510606444,59.798123469567955,59.15273642852941,58.50734938749086,57.86196234645243,57.21657530541388,56.57118826437534,55.92580122333685,55.28041418229836,54.63502714125981,53.989640100221315,53.344253059182826,52.69886601814428,52.053478977105726,51.4080919360673,50.76270489502875,50.1173178539902,49.47193081295171,48.82654377191322,48.181156730874676,47.53576968983619,46.89038264879769,46.244995607759144,45.599608566720654,44.954221525682165,44.30883448464362,43.663447443605065,43.01806040256664,42.372673361528086,41.72728632048954,41.08189927945105,40.43651223841256,39.791125197374015,39.14573815633552,38.500351115297036,37.85496407425848,37.20957703321994,36.564189992181504,35.91880295114295,35.273415910104404,34.628028869065915,33.982641828027425,33.33725478698888,32.69186774595039,32.0464807049119,31.401093663873347,30.755706622834857,30.110319581796368,29.464932540757818,28.81954549971927,28.174158458680843,27.528771417642293,26.88338437660374,26.237997335565254,25.592610294526764,24.94722325348821,24.30183621244972,23.656449171411236,23.011062130372686,22.365675089334193,21.720288048295707,21.074901007257154,20.42951396621861,19.784126925180114,19.13873988414163,18.659627885644273,18.513065972229175,18.36650405881408,18.21994214539897,18.073380231983876,17.92681831856878,17.78025640515367,17.63369449173856,17.48713257832348,17.34057066490837,17.19400875149326,17.047446838078162,16.900884924663067,16.75432301124796,16.609892053210793,16.4666787603353,16.32346546745979,16.1802521745843,16.037038881708806,15.893825588833298,15.750612295957794,15.607399003082298,15.464185710206806,15.3209724173313,15.177759124455807,15.034545831580314,14.891332538704809,14.748119245829315,14.604905952953821,14.461692660078313,14.318479367202809,14.175266074327329,14.032052781451823,13.888839488576316,13.745626195700824,13.602412902825328,13.459199609949824,13.315986317074332,13.172773024198836,13.02955973132333,12.886346438447838,12.743133145572344,12.59991985269684,12.456706559821331,12.31349326694584,12.170279974070347,12.027066681194839,11.883853388319345,11.740640095443853,11.597426802568345,11.454213509692854,11.31100021681736,11.167786923941854,11.024573631066346,10.881360338190868,10.738147045315362,10.594933752439854,10.45172045956436,10.308507166688868,10.165293873813361,10.02208058093787,9.878867288062375,9.735653995186869,9.592440702311377,9.449227409435883,9.306014116560377,9.16280082368487,9.01958753080939,8.876374237933884,8.73316094505838,8.589947652182886,8.44673435930739,8.303521066431886,8.160307773556392,8.0170944806809,7.8738811878053925,7.730667894929885,7.5874546020544065,7.444241309178899,7.301028016303393,7.1578147234279,7.014601430552408,6.8713881376769015,6.7471170712338795,6.717557136953127,6.687997202672376,6.658437268391623,6.628877334110877,6.599317399830125,6.569757465549374,6.5401975312686265,6.510637596987875,6.481077662707123,6.451517728426376,6.421957794145624,6.392397859864872,6.36283792558412,6.333277991303373,6.303718057022622,6.27415812274187,6.244598188461124,6.215038254180371,6.1854783198996195,6.155918385618873,6.12635845133812,6.096798517057369,6.067238582776622,6.03767864849587,6.008118714215119,5.978558779934366,5.94899884565362,5.919438911372867,5.889878977092116,5.860319042811369,5.830759108530618,5.801199174249866,5.771639239969119,5.742079305688367,5.712519371407616,5.682959437126863,5.653399502846117,5.623839568565365,5.594279634284613,5.564719700003867,5.535159765723114,5.505599831442362,5.476039897161615,5.446479962880864,5.416920028600112,5.387360094319366,5.357800160038613,5.328240225757861,5.29868029147711,5.269120357196362,5.239560422915611,5.210000488634859,5.180440554354112,5.150880620073361,5.121320685792608,5.091760751511862,5.06220081723111,5.032640882950358,5.003080948669607,4.97418086047397,4.945907627555939,4.9176343946379095,4.889361161719885,4.861087928801855,4.832814695883825,4.8045414629658,4.776268230047769,4.74799499712974,4.719721764211714,4.691448531293684,4.663175298375655,4.6349020654576245,4.6066288325396,4.5783555996215695,4.550082366703539,4.521809133785514,4.493535900867485,4.465262667949454,4.436989435031429,4.4087162021134,4.38044296919537,4.3521697362773395,4.323896503359315],[64.00665413468482,64.05878196576941,64.11090979685402,64.16303762793862,64.21516545902321,64.26729329010783,64.31942112119242,64.37154895227702,64.42367678336163,64.47580461444622,64.52793244553084,64.58006027661543,64.63218810770003,64.68431593878464,64.73644376986924,64.78857160095383,64.84069943203843,64.89282726312304,64.94495509420763,64.99708292529225,65.04921075637685,65.10123280675163,65.15272595292166,65.20421909909167,65.25571224526169,65.30720539143172,65.35869853760174,65.41019168377176,65.46168482994179,65.5131779761118,65.56467112228184,65.61616426845185,65.66765741462187,65.7191505607919,65.77064370696193,65.82213685313195,65.87362999930197,65.925123145472,65.97661629164202,66.02810943781203,66.07960258398207,66.13109573015208,66.18258887632211,66.23408202249213,66.28557516866215,66.33706831483218,66.3885614610022,66.44005460717224,66.49154775334225,66.54304089951228,66.59453404568231,66.64602719185231,66.69752033802234,66.74901348419237,66.80050663036239,66.85199977653241,66.90349292270244,66.95498606887247,67.00647921504249,67.0579723612125,67.10946550738254,67.16095865355256,67.21245179972257,67.2639449458926,67.31543809206262,67.36693123823265,67.41842438440267,67.4699175305727,67.52141067674272,67.57290382291274,67.62439696908277,67.67589011525278,67.72738326142282,67.77887640759283,67.83036955376286,67.88186269993288,67.9333558461029,67.98484899227293,68.03634213844295,68.08783528461298,68.139328430783,68.19082157695301,68.24231472312304,68.29380786929306,68.3348556031471,68.37381425453796,68.4127729059288,68.45173155731966,68.4906902087105,68.52964886010135,68.56860751149219,68.60756616288305,68.64652481427389,68.68548346566475,68.72444211705559,68.76340076844643,68.80235941983729,68.84131807122814,68.88027672261899,68.91923537400984,68.95819402540069,68.99715267679153,69.03611132818239,69.07506997957323,69.11402863096407,69.15298728235493,69.19194593374577,69.23090458513661,69.26986323652747,69.30882188791831,69.34778053930917,69.38673919070001,69.42569784209086,69.46465649348171,69.50361514487255,69.54257379626341,69.58153244765425,69.6204910990451,69.65944975043595,69.6984084018268,69.73736705321767,69.7763257046085,69.81528435599935,69.85424300739021,69.89320165878104,69.9321603101719,69.97111896156274,70.0100776129536,70.04903626434444,70.0879949157353,70.12695356712614,70.16591221851698,70.20487086990782,70.24382952129868,70.28278817268954,70.32174682408038,70.36070547547122,70.39966412686208,70.43862277825292,70.47758142964378,70.51654008103462,70.55549873242548,70.59445738381632,70.63341603520716,70.67237468659802,70.71133333798886,70.75078546793382,70.79073107609304,70.83067668425225,70.87062229241147,70.91056790057068,70.95051350872988,70.99045911688911,71.03040472504833,71.07035033320754,71.11029594136676,71.15024154952597,71.19018715768519,71.2301327658444,71.27007837400362,71.31002398216283,71.34996959032205,71.38991519848126,71.42986080664048,71.46980641479969,71.5097520229589,71.54969763111812,71.57034015731773,71.58133114253754,71.59232212775736,71.60331311297716,71.61430409819697,71.62529508341677,71.6362860686366,71.6472770538564,71.6582680390762,71.66925902429601,71.68025000951583,71.69124099473564,71.70223197995544,71.71322296517525,71.72421395039507,71.73520493561487,71.74619592083468,71.7571869060545,71.76817789127429,71.77916887649411,71.7901598617139,71.80115084693372,71.81214183215354,71.82313281737335,71.83412380259315,71.84511478781295,71.85610577303277,71.86709675825257,71.87808774347239,71.8890787286922,71.900069713912,71.91106069913181,71.92205168435162,71.93304266957144,71.94403365479126,71.95502464001105,71.96601562523087,71.97700661045069,71.98799759567046,71.9989885808903,72.00997956611009,72.0209705513299,72.0319615365497,72.04295252176952,72.05394350698933,72.06493449220915,72.07592547742895,72.08691646264876,72.09108909527318,72.092988938899,72.09488878252483,72.09678862615067,72.09868846977649,72.10058831340231,72.10248815702815,72.10438800065397,72.10628784427979,72.10818768790563,72.11008753153145,72.11198737515728,72.1138872187831,72.11578706240893,72.11768690603478,72.11958674966058,72.12148659328642,72.12338643691224,72.12528628053806,72.1271861241639,72.12908596778972,72.13098581141554,72.13288565504138,72.13478549866721,72.13668534229303,72.13858518591886,72.14048502954469,72.14238487317051,72.14428471679634,72.14618456042217,72.14808440404799,72.14998424767381,72.15188409129965,72.15378393492547,72.15568377855129,71.83207913862094,71.1829700151344,70.53386089164793,69.88475176816145,69.23564264467491,68.58653352118844,67.93742439770196,67.28831527421544,66.6392061507289,65.99009702724248,65.34098790375594,64.6918787802694,64.04276965678292,63.393660533296455,62.74455140980992,62.09544228632345,61.446333162836964,60.79722403935043,60.14811491586396,59.49900579237748,58.84989666889094,58.2007875454044,57.55167842191799,56.90256929843146,56.25346017494493,55.6055423165601,54.9601393479062,54.31473637925225,53.66933341059837,53.02393044194447,52.378527473290525,51.73312450463657,51.087721535982745,50.4423185673288,49.79691559867486,49.15151263002096,48.50610966136708,47.86070669271313,47.21530372405923,46.56990075540534,45.9244977867514,45.279094818097505,44.63369184944362,43.988288880789675,43.34288591213571,42.69748294348189,42.05207997482794,41.40667700617399,40.7612740375201,40.11587106886621,39.470468100212265,38.82506513155838,38.17966216290449,37.53425919425054,36.88885622559659,36.243453256942765,35.59805028828881,34.95264731963486,34.30724435098097,33.66184138232708,33.016438413673136,32.37103544501925,31.725632476365355,31.08022950771141,30.434826539057518,29.78942357040363,29.14402060174968,28.498617633095733,27.853214664441904,27.20781169578796,26.56240872713401,25.91700575848012,25.27160278982623,24.62619982117228,23.98079685251839,23.335393883864505,22.689990915210554,22.044587946556664,21.399184977902777,20.753782009248823,20.108379040594876,19.46297607194099,18.8175731032871,18.341634222512422,18.204623517496152,18.06761281247989,17.93060210746361,17.793591402447348,17.65658069743108,17.5195699924148,17.38255928739853,17.245548582382273,17.108537877365993,16.971527172349717,16.83451646733345,16.697505762317185,16.560495057300905,16.423484352284643,16.28647364726838,16.1494629422521,16.012452237235834,15.875441532219568,15.73843082720329,15.601420122187013,15.46440941717075,15.32739871215448,15.190388007138203,15.05337730212194,14.916366597105675,14.779355892089395,14.642345187073131,14.505334482056865,14.368323777040587,14.231313072024307,14.094302367008057,13.957291661991778,13.8202809569755,13.683270251959234,13.54625954694297,13.409248841926692,13.270915890103801,13.127702597228309,12.9844893043528,12.84127601147731,12.698062718601813,12.55484942572631,12.411636132850802,12.26842283997531,12.125209547099816,11.98199625422431,11.838782961348816,11.695569668473325,11.552356375597817,11.409143082722327,11.26592978984683,11.122716496971325,10.979503204095819,10.836289911220339,10.69307661834483,10.549863325469326,10.406650032593832,10.26343673971834,10.120223446842832,9.977010153967342,9.833796861091844,9.69058356821634,9.547370275340846,9.404156982465356,9.260943689589848,9.11773039671434,8.97451710383886,8.831303810963357,8.688090518087847,8.544877225212357,8.401663932336861,8.258450639461358,8.115237346585863,7.972024053710371,7.828810760834862,7.685597467959356,7.5423841750838765,7.399170882208372,7.255957589332865,7.112744296457372,6.969531003581877,6.826317710706375,6.702046644263351,6.672486709982599,6.642926775701847,6.6133668414210955,6.583806907140348,6.5542469728595965,6.524687038578845,6.495127104298098,6.465567170017346,6.436007235736595,6.406447301455847,6.376887367175096,6.347327432894343,6.317767498613592,6.288207564332845,6.258647630052094,6.229087695771342,6.199527761490595,6.169967827209843,6.14040789292909,6.110847958648344,6.081288024367591,6.05172809008684,6.022168155806094,5.992608221525342,5.96304828724459,5.933488352963837,5.903928418683091,5.874368484402339,5.844808550121587,5.815248615840841,5.786595970590571,5.75832273767254,5.730049504754515,5.7017762718364855,5.673503038918456,5.645229806000425,5.616956573082401,5.588683340164371,5.56041010724634,5.532136874328315,5.503863641410286,5.475590408492256,5.447317175574232,5.4190439426562005,5.39077070973817,5.362497476820145,5.334224243902116,5.305951010984086,5.277677778066055,5.249404545148031,5.221131312230001,5.192858079311971,5.164584846393946,5.1363116134759155,5.108038380557885,5.07976514763986,5.05149191472183,5.023218681803801,4.994945448885771,4.966672215967746,4.938398983049716,4.9101257501316855,4.881852517213661,4.8535792842956305,4.8253060513776,4.797032818459575,4.768759585541545,4.740486352623516,4.71221311970549,4.68393988678746,4.65566665386943,4.6273934209514005,4.599120188033375,4.5708469551153454,4.542573722197315,4.51430048927929,4.486027256361261,4.45775402344323,4.429480790525205,4.401207557607176,4.372934324689146,4.3446610917711155,4.316387858853091],[64.1601056819935,64.2122335130781,64.2643613441627,64.3164891752473,64.36861700633192,64.42032171414468,64.4718148603147,64.52330800648471,64.57480115265474,64.62629429882476,64.67778744499479,64.72928059116481,64.78077373733484,64.83226688350486,64.88376002967489,64.9352531758449,64.98674632201492,65.03823946818495,65.08973261435497,65.14122576052499,65.19271890669502,65.24421205286504,65.29570519903507,65.34719834520509,65.39869149137512,65.45018463754514,65.50167778371517,65.55317092988518,65.6046640760552,65.65615722222523,65.70765036839525,65.75914351456527,65.8106366607353,65.86212980690533,65.91362295307535,65.96511609924536,66.0166092454154,66.06810239158541,66.11959553775544,66.17108868392546,66.22258183009548,66.27407497626551,66.32556812243553,66.37706126860556,66.42855441477558,66.48004756094561,66.53154070711562,66.58303385328566,66.63452699945567,66.6860201456257,66.73751329179572,66.78900643796574,66.84049958413577,66.89199273030579,66.94348587647582,66.99497902264584,67.04647216881587,67.09796531498588,67.1494584611559,67.20095160732593,67.25244475349595,67.30393789966598,67.355431045836,67.40692419200602,67.45841733817605,67.50991048434607,67.5614036305161,67.61289677668611,67.66438992285615,67.71588306902616,67.7673762151962,67.81886936136621,67.87036250753623,67.92185565370626,67.97334879987628,68.0248419460463,68.07633509221633,68.12782823838634,68.17932138455637,68.23081453072639,68.28230767689642,68.33380082306644,68.38529396923646,68.43678711540649,68.47783484926052,68.51679350065137,68.55575215204222,68.59471080343307,68.63366945482392,68.67262810621477,68.71158675760562,68.75054540899647,68.78950406038732,68.82846271177817,68.86742136316902,68.90638001455986,68.94533866595071,68.98429731734156,69.02325596873241,69.06221462012326,69.1011732715141,69.14013192290496,69.17909057429581,69.21804922568666,69.2570078770775,69.29596652846836,69.33492517985918,69.37388383125004,69.4128424826409,69.45180113403174,69.49075978542258,69.52971843681344,69.56867708820428,69.60763573959514,69.64659439098598,69.68555304237684,69.72451169376767,69.76347034515852,69.80242899654938,69.84138764794022,69.88034629933108,69.91930495072192,69.95826360211278,69.99722225350362,70.03618090489447,70.07513955628532,70.11409820767616,70.15305685906701,70.19201551045786,70.2309741618487,70.26993281323955,70.3088914646304,70.34785011602125,70.38680876741209,70.42576741880295,70.4647260701938,70.50368472158465,70.54264337297549,70.58160202436635,70.62056067575719,70.65951932714805,70.69847797853889,70.73743662992975,70.77639528132059,70.81535393271143,70.85431258410229,70.89327123549313,70.93222988688397,70.97118853827483,71.01014718966567,71.04910584105653,71.08806449244737,71.12702314383823,71.16598179522907,71.20494044661991,71.24389909801077,71.28285774940161,71.32181640079246,71.36077505218331,71.39973370357416,71.438692354965,71.47765100635586,71.51660965775379,71.55655526591299,71.5965008740722,71.63644648223143,71.67639209039064,71.69703461659026,71.70802560181006,71.71901658702987,71.73000757224969,71.74099855746948,71.75198954268932,71.76298052790912,71.77397151312893,71.78496249834873,71.79595348356854,71.80058066982257,71.8024805134484,71.80438035707422,71.80628020070006,71.80818004432588,71.8100798879517,71.81197973157752,71.81387957520336,71.81577941882918,71.81767926245502,71.81957910608084,71.82147894970666,71.8233787933325,71.82527863695833,71.82717848058415,71.82907832420997,71.83097816783581,71.83287801146163,71.83477785508745,71.83667769871329,71.83857754233912,71.84047738596495,71.84237722959077,71.8442770732166,71.84617691684242,71.84807676046825,71.84997660409408,71.8518764477199,71.85377629134572,71.85567613497156,71.85757597859738,71.85947582222322,71.86137566584904,71.86327550947486,71.8651753531007,71.86707519672652,71.86897504035234,71.87087488397817,71.872774727604,71.87467457122983,71.87657441485564,71.87847425848148,71.88037410210731,71.88227394573313,71.88417378935895,71.88607363298479,71.88797347661061,71.88987332023645,71.89177316386227,71.8936730074881,71.89557285111394,71.89747269473975,71.89937253836558,71.9012723819914,71.90317222561724,71.90507206924306,71.9069719128689,71.90887175649472,71.91077160012054,71.91267144374638,71.9145712873722,71.91647113099803,71.91837097462385,71.92027081824969,71.92217066187551,71.92407050550133,71.92597034912717,71.92787019275299,71.92977003637881,71.93166988000463,71.93356972363047,71.93546956725629,71.93736941088213,71.61376477095176,70.96465564746522,70.31554652397875,69.66643740049228,69.01732827700573,68.36821915351928,67.71911003003278,67.07000090654626,66.42089178305972,65.7717826595733,65.12267353608677,64.47356441260023,63.82445528911376,63.175346165627275,62.52623704214074,61.87712791865427,61.22801879516779,60.57890967168125,59.929800548194784,59.2806914247083,58.63158230122177,57.98247317773523,57.33336405424882,56.68425493076228,56.03514580727574,55.38603668378927,54.736927560302796,54.08781843681625,53.43870931332978,52.7896001898433,52.140491066356766,51.49138194287024,50.842272819383815,50.19316369589728,49.544054572410744,48.894945448924275,48.2458363254378,47.59672720195126,46.947618078464785,46.2985089549783,45.64939983149178,45.000290708005295,44.35118158451882,43.70207246103228,43.05296333754575,42.40385421405933,41.7547450905728,41.10563596708626,40.45652684359978,39.80741772011331,39.158308596626775,38.5091994731403,37.860884525733056,37.21548155707911,36.57007858842516,35.92467561977133,35.27927265111739,34.633869682463434,33.988466713809544,33.34306374515565,32.697660776501706,32.05225780784782,31.40685483919393,30.76145187053998,30.11604890188609,29.470645933232202,28.82524296457825,28.1798399959243,27.534437027270474,26.889034058616524,26.243631089962577,25.598228121308686,24.9528251526548,24.307422184000846,23.662019215346962,23.016616246693072,22.37121327803912,21.72581030938523,21.08040734073134,20.435004372077394,19.789601403423447,19.144198434769557,18.498795466115666,18.02285658534099,17.885845880324723,17.748835175308457,17.61182447029218,17.474813765275915,17.33780306025965,17.200792355243372,17.063781650227092,16.92677094521084,16.789760240194564,16.652749535178287,16.51573883016202,16.378728125145756,16.241717420129476,16.104706715113213,15.967696010096947,15.830685305080667,15.693674600064401,15.556663895048137,15.419653190031859,15.282642485015582,15.145631779999317,15.00862107498305,14.871610369966774,14.734599664950508,14.597588959934244,14.460578254917964,14.3235675499017,14.186556844885434,14.049546139869157,13.912535434852877,13.775524729836626,13.63851402482035,13.501503319804069,13.364492614787803,13.227481909771537,13.09047120475526,12.953460499738995,12.816449794722729,12.679439089706449,12.542428384690185,12.405417679673919,12.26840697465764,12.131396269641364,11.994385564625098,11.857374859608832,11.720364154592556,11.58335344957629,11.446342744560024,11.309332039543746,11.172321334527481,11.035310629511217,10.898299924494939,10.761289219478659,10.624278514462407,10.487267809446129,10.35025710442985,10.213246399413585,10.07623569439732,9.939224989381042,9.802214284364776,9.665203579348512,9.528192874332234,9.391182169315968,9.254171464299704,9.117160759283426,8.980150054267147,8.843139349250894,8.706128644234617,8.569117939218339,8.432107234202073,8.295096529185807,8.15808582416953,8.021075119153265,7.884064414136999,7.747053709120721,7.610043004104443,7.4730322990881906,7.336021594071911,7.199010889055634,7.062000184039368,6.924460576611349,6.781247283735844,6.656976217292821,6.62741628301207,6.599011080707172,6.570737847789141,6.5424646148711165,6.514191381953086,6.485918149035056,6.457644916117031,6.429371683199002,6.401098450280971,6.372825217362946,6.344551984444917,6.316278751526887,6.288005518608856,6.259732285690831,6.231459052772801,6.203185819854772,6.174912586936747,6.146639354018716,6.118366121100686,6.090092888182661,6.061819655264632,6.0335464223466015,6.005273189428577,5.9769999565105465,5.948726723592516,5.920453490674486,5.892180257756461,5.863907024838431,5.835633791920402,5.807360559002377,5.779087326084346,5.750814093166316,5.722540860248291,5.694267627330262,5.665994394412231,5.637721161494202,5.609447928576177,5.581174695658147,5.552901462740117,5.524628229822092,5.496354996904062,5.4680817639860315,5.439808531068007,5.4115352981499765,5.383262065231947,5.354988832313922,5.326715599395892,5.298442366477862,5.270169133559832,5.241895900641807,5.213622667723776,5.1853494348057465,5.157076201887722,5.1288029689696915,5.100529736051661,5.072256503133636,5.043983270215606,5.015710037297577,4.987436804379546,4.959163571461522,4.930890338543492,4.9026171056254615,4.874343872707437,4.846070639789406,4.817797406871376,4.789524173953351,4.761250941035322,4.732977708117292,4.704704475199266,4.676431242281237,4.648158009363206,4.6198847764451765,4.591611543527152,4.563338310609121,4.535065077691091,4.506791844773066,4.478518611855037,4.450245378937006,4.421972146018981,4.393698913100952,4.365425680182922,4.337152447264891,4.308879214346866],[64.30533895850617,64.35609713645842,64.40685531441068,64.45761349236292,64.50837167031517,64.55912984826743,64.60988802621968,64.66064620417194,64.71140438212419,64.76216256007643,64.8129207380287,64.86367891598094,64.91443709393319,64.96580774528427,65.01730089145428,65.0687940376243,65.12028718379433,65.17178032996435,65.22327347613438,65.2747666223044,65.32625976847442,65.37775291464445,65.42924606081448,65.4807392069845,65.53223235315451,65.58372549932454,65.63521864549456,65.68671179166458,65.73820493783461,65.78969808400463,65.84119123017466,65.89268437634468,65.94417752251469,65.99567066868472,66.04716381485476,66.09865696102477,66.15015010719479,66.20164325336482,66.25313639953484,66.30462954570486,66.35612269187489,66.4076158380449,66.45910898421494,66.51060213038495,66.56209527655497,66.613588422725,66.66508156889503,66.71657471506505,66.76806786123507,66.8195610074051,66.87105415357512,66.92254729974515,66.97404044591516,67.02553359208518,67.07702673825523,67.12851988442523,67.18001303059526,67.23150617676528,67.28299932293531,67.33449246910533,67.38598561527535,67.43747876144538,67.48897190761541,67.54046505378541,67.59195819995544,67.64345134612547,67.69494449229549,67.74643763846552,67.79793078463554,67.84942393080556,67.90091707697559,67.9524102231456,68.00390336931564,68.05539651548565,68.10688966165569,68.1583828078257,68.20987595399572,68.26136910016575,68.31286224633577,68.3643553925058,68.41584853867582,68.46734168484583,68.51883483101587,68.57032797718588,68.61137571103993,68.65033436243078,68.68929301382163,68.72825166521248,68.76721031660333,68.80616896799417,68.84512761938501,68.88408627077587,68.92304492216672,68.96200357355757,69.00096222494841,69.03992087633927,69.07887952773012,69.11783817912097,69.15679683051181,69.19575548190267,69.23471413329351,69.27367278468435,69.31263143607521,69.35159008746605,69.3905487388569,69.42950739024775,69.46846604163859,69.50742469302944,69.54638334442029,69.58534199581113,69.62430064720199,69.66325929859283,69.70221794998369,69.74117660137453,69.78013525276538,69.81909390415623,69.85805255554708,69.89701120693792,69.93596985832878,69.97492850971963,70.01388716111049,70.05284581250132,70.09180446389217,70.13076311528303,70.16972176667386,70.20868041806472,70.24763906945556,70.28659772084642,70.32555637223726,70.36451502362812,70.40347367501896,70.4424323264098,70.48139097780064,70.5203496291915,70.55930828058236,70.5982669319732,70.63722558336404,70.6761842347549,70.71514288614574,70.7541015375366,70.79306018892744,70.8320188403183,70.87097749170914,70.90993614309998,70.94889479449084,70.98785344588168,71.02681209727253,71.06577074866338,71.10472940005423,71.14368805144508,71.18264670283592,71.22160535422678,71.26056400561762,71.29952265700847,71.33848130839932,71.37642557334904,71.41416696124108,71.45190834913312,71.48964973702516,71.5273911249172,71.56513251280924,71.60287390070128,71.64061528859332,71.67835667648535,71.71609806437739,71.75383945226943,71.79158084016147,71.79994717412298,71.7936259811192,71.78730478811546,71.7809835951117,71.77466240210794,71.7683412091042,71.76202001610044,71.75569882309668,71.74937763009291,71.74305643708915,71.7367352440854,71.73041405108164,71.72409285807788,71.71777166507412,71.71145047207037,71.70512927906661,71.69880808606285,71.6924868930591,71.68616570005534,71.67984450705157,71.67352331404781,71.66720212104406,71.6608809280403,71.65455973503654,71.64823854203279,71.64191734902903,71.63559615602527,71.62927496302152,71.62295377001776,71.61836333104411,71.62026317466993,71.62216301829577,71.62406286192157,71.62596270554741,71.62786254917324,71.62976239279907,71.63166223642489,71.63356208005071,71.63546192367654,71.63736176730237,71.6392616109282,71.64116145455402,71.64306129817984,71.64496114180568,71.64686098543152,71.64876082905732,71.65066067268316,71.652560516309,71.6544603599348,71.65636020356064,71.65826004718646,71.6601598908123,71.66205973443812,71.66395957806395,71.66585942168979,71.66775926531561,71.66965910894143,71.67155895256727,71.67345879619309,71.67535863981891,71.67725848344475,71.67915832707055,71.6810581706964,71.68295801432222,71.68485785794806,71.68675770157388,71.6886575451997,71.69055738882554,71.69245723245136,71.69435707607718,71.69625691970302,71.69815676332885,71.70005660695467,71.7019564505805,71.70385629420633,71.70575613783215,71.70765598145798,71.70955582508381,71.71145566870963,71.71335551233545,71.71525535596129,71.71715519958711,71.71905504321293,71.39545040328258,70.74634127979604,70.09723215630956,69.44812303282309,68.79901390933655,68.14990478585008,67.5007956623636,66.85168653887706,66.20257741539054,65.55346829190411,64.90435916841759,64.25525004493105,63.60614092144456,62.95703179795809,62.307922674471556,61.65881355098508,61.00970442749861,60.36059530401207,59.7114861805256,59.06237705703912,58.41326793355258,57.76415881006605,57.115049686579624,56.4659405630931,55.81683143960656,55.167722316120084,54.51861319263361,53.86950406914706,53.220394945660594,52.57128582217412,51.922176698687586,51.273067575201054,50.623958451714635,49.974849328228096,49.325740204741564,48.67663108125509,48.027521957768606,47.378412834282074,46.7293037107956,46.08019458730912,45.43108546382259,44.781976340336115,44.13286721684963,43.4837580933631,42.834648969876554,42.18553984639015,41.53643072290361,40.88732159941707,40.238212475930595,39.58910335244412,38.93999422895759,38.290885105471105,37.64177598198464,36.9926668584981,36.343557735011565,35.69444861152515,35.045339488038614,34.39623036455208,33.7471212410656,33.098012117579124,32.44890299409259,31.79979387060611,31.150684747119634,30.5015756236331,29.852466500146626,29.20335737666015,28.554248253173615,27.90513912968708,27.25603000620066,26.606920882714128,25.957811759227592,25.308702635741113,24.659593512254638,24.010484388768102,23.361375265281627,22.71226614179515,22.063157018308612,21.41404789482214,20.76493877133566,20.11622673490595,19.470823766252003,18.825420797598113,18.180017828944226,17.70407894816955,17.56706824315328,17.430057538137014,17.293046833120737,17.15603612810447,17.01902542308821,16.88201471807193,16.74500401305565,16.607993308039397,16.47098260302312,16.33397189800684,16.19713125173347,16.060342362258755,15.923553472784027,15.786764583309312,15.649975693834595,15.513186804359869,15.376397914885153,15.239609025410438,15.102820135935708,14.966031246460982,14.829242356986265,14.692453467511552,14.555664578036822,14.418875688562109,14.282086799087391,14.145297909612665,14.00850902013795,13.871720130663235,13.734931241188507,13.598142351713777,13.461353462239074,13.324564572764348,13.187775683289619,13.050986793814904,12.914197904340188,12.77740901486546,12.640620125390747,12.503831235916032,12.367042346441302,12.230253456966585,12.09346456749187,11.956675678017142,11.819886788542416,11.683097899067699,11.546309009592983,11.409520120118255,11.27273123064354,11.135942341168825,10.999153451694099,10.862364562219383,10.725575672744666,10.588786783269938,10.451997893795209,10.315209004320508,10.17842011484578,10.041631225371052,9.904842335896337,9.768053446421622,9.631264556946894,9.494475667472178,9.357686777997463,9.220897888522735,9.08410899904802,9.021414109225494,8.993140876307463,8.964867643389434,8.93659441047141,8.908321177553379,8.880047944635347,8.85177471171732,8.823501478799294,8.795228245881264,8.766955012963235,8.738681780045209,8.710408547127178,8.68213531420915,8.653862081291125,8.625588848373093,8.597315615455063,8.569042382537036,8.54076914961901,8.512495916700978,8.484222683782953,8.455949450864924,8.427676217946894,8.399402985028864,8.37112975211084,8.342856519192809,8.314583286274779,8.286310053356754,8.258036820438724,8.229763587520694,8.201490354602669,8.173217121684639,8.144943888766608,8.116670655848578,8.088397422930553,8.060124190012523,8.031850957094493,8.003577724176468,7.975304491258439,7.947031258340408,7.918758025422383,7.890484792504354,7.862211559586323,7.8339383266682985,7.805665093750267,7.777391860832239,7.749118627914209,7.720845394996184,7.692572162078154,7.664298929160124,7.636025696242099,7.6077524633240685,7.579479230406038,7.5512059974880135,7.522932764569983,7.494659531651953,7.466386298733923,7.438113065815898,7.409839832897869,7.3815665999798385,7.353293367061814,7.325020134143783,7.296746901225754,7.2684736683077285,7.238464883834917,7.1563888177023145,7.074312751569728,6.992236685437126,6.910160619304523,6.82808455317192,6.746008487039333,6.663932420906731,6.5818563547741284,6.499780288641541,6.417704222508938,6.335628156376336,6.253552090243749,6.171476024111147,6.089399957978544,6.0073238918459415,5.925247825713354,5.843626637571756,5.762382791901043,5.681138946230345,5.599895100559632,5.51865125488892,5.437407409218222,5.3561635635475096,5.275953304844519,5.1959232611768735,5.115893217509213,5.0854693852912085,5.228667293146984,5.371865201002732,5.515063108858508,5.658261016714283,5.623173871944038,5.331376779299816,5.046587174071487,4.7776064280892685,4.540342901582143,4.372787553115399,null,null],[64.44764517969995,64.49840335765221,64.54916153560447,64.59991971355672,64.65067789150896,64.70143606946122,64.75219424741347,64.80295242536572,64.85371060331798,64.90446878127023,64.95522695922247,65.00598513717473,65.05674331512698,65.10750149307923,65.15825967103149,65.20901784898373,65.259776026936,65.31053420488824,65.3612923828405,65.41205056079275,65.462808738745,65.51356691669724,65.5643250946495,65.61508327260175,65.665841450554,65.71659962850626,65.76735780645852,65.81811598441077,65.86887416236301,65.91987732948392,65.97137047565396,66.02286362182397,66.07435676799399,66.12584991416402,66.17734306033405,66.22883620650407,66.28032935267409,66.33182249884412,66.38331564501414,66.43480879118415,66.48630193735418,66.5377950835242,66.58928822969423,66.64078137586425,66.69227452203427,66.7437676682043,66.79526081437433,66.84675396054435,66.89824710671436,66.9497402528844,67.00123339905441,67.05272654522444,67.10421969139446,67.15571283756448,67.20720598373453,67.25869912990453,67.31019227607456,67.36168542224458,67.4131785684146,67.46467171458463,67.51616486075464,67.56765800692469,67.61915115309469,67.67064429926471,67.72213744543474,67.77363059160477,67.82512373777479,67.8766168839448,67.92811003011484,67.97960317628485,68.03109632245489,68.0825894686249,68.13408261479493,68.18557576096495,68.23706890713497,68.288562053305,68.34005519947502,68.39154834564505,68.44304149181507,68.4945346379851,68.54602778415511,68.59752093032513,68.64901407649516,68.70050722266518,68.74155495651922,68.78051360791007,68.81947225930092,68.85843091069177,68.89738956208262,68.93634821347347,68.97530686486431,69.01426551625516,69.05322416764602,69.09218281903686,69.1311414704277,69.17010012181856,69.2090587732094,69.24801742460026,69.2869760759911,69.32593472738195,69.3648933787728,69.40385203016365,69.4428106815545,69.48176933294535,69.52072798433619,69.55968663572705,69.59864528711789,69.63760393850873,69.67656258989959,69.71552124129043,69.75447989268129,69.79343854407213,69.83239719546297,69.87135584685383,69.91031449824467,69.94927314963553,69.98823180102639,70.02719045241723,70.06614910380807,70.10510775519893,70.14406640658977,70.18302505798061,70.22198370937147,70.26094236076231,70.29990101215316,70.33885966354401,70.37781831493486,70.41677696632571,70.45573561771656,70.49469426910741,70.53365292049826,70.5726115718891,70.61157022327994,70.6505288746708,70.68948752606165,70.7284461774525,70.76740482884334,70.8063634802342,70.84491637673247,70.88265776462453,70.92039915251655,70.95814054040859,70.99588192830063,71.03362331619266,71.0713647040847,71.10910609197674,71.14684747986878,71.18458886776082,71.22233025565286,71.2600716435449,71.29781303143693,71.33555441932897,71.37329580722101,71.41103719511305,71.4487785830051,71.48651997089712,71.52426135878916,71.5620027466812,71.59974413457324,71.63748552246528,71.67522691035732,71.71296829824936,71.7507096861414,71.78845107403343,71.82619246192547,71.86393384981751,71.90167523770955,71.91004157167106,71.9037203786673,71.89739918566355,71.89107799265977,71.88475679965603,71.87843560665226,71.8721144136485,71.86579322064476,71.85947202764098,71.85315083463723,71.84682964163348,71.84050844862972,71.83418725562596,71.8278660626222,71.82154486961845,71.81522367661468,71.80890248361092,71.80258129060716,71.79626009760341,71.78993890459965,71.7836177115959,71.77729651859215,71.77097532558838,71.76465413258461,71.75833293958087,71.75201174657711,71.74569055357335,71.7393693605696,71.73304816756584,71.72672697456207,71.72040578155833,71.71408458855456,71.7077633955508,71.70144220254704,71.69512100954329,71.68879981653953,71.68247862353577,71.67615743053202,71.66983623752824,71.6635150445245,71.65719385152074,71.65087265851699,71.64455146551323,71.63823027250947,71.6319090795057,71.62558788650196,71.61926669349819,71.61294550049443,71.60662430749068,71.60030311448692,71.59398192148316,71.58766072847939,71.58133953547565,71.57501834247188,71.56869714946814,71.56237595646438,71.55605476346061,71.54973357045687,71.5434123774531,71.53709118444934,71.53076999144558,71.52444879844182,71.51812760543807,71.51180641243431,71.50548521943054,71.4991640264268,71.49284283342304,71.48652164041927,71.48020044741551,71.476042708408,71.47794255203384,71.47984239565967,71.4817422392855,71.48364208291132,71.48554192653714,71.48744177016297,71.48934161378881,71.49124145741463,71.49314130104045,71.49504114466627,71.4969409882921,71.49884083191793,71.50074067554377,71.1771360356134,70.52802691212685,69.8789177886404,69.22980866515391,68.58069954166737,67.9315904181809,67.28248129469442,66.63337217120788,65.98426304772136,65.33515392423494,64.6860448007484,64.03693567726187,63.38782655377539,62.738717430288915,62.089608306802376,61.4404991833159,60.791390059829425,60.1422809363429,59.49317181285642,58.84406268936994,58.1949535658834,57.54584444239687,56.896735318910444,56.24762619542392,55.59763562775301,54.94731451185465,54.296993395956285,53.64667228005786,52.99635116415949,52.34603004826113,51.69570893236269,51.04538781646427,50.39506670056596,49.74474558466754,49.09442446876911,48.44410335287075,47.793782236972376,47.14346112107395,46.49314000517558,45.84281888927722,45.19249777337879,44.542176657480425,43.89185554158207,43.24153442568364,42.5912133097852,41.940892193886896,41.290571077988474,40.64024996209004,39.98992884619168,39.33960773029331,38.68928661439489,38.03896549849652,37.38864438259816,36.73832326669972,36.0880021508013,35.437681034902994,34.78735991900457,34.137038803106144,33.48671768720778,32.83639657130941,32.186075455410986,31.535754339512618,30.88543322361425,30.235112107715825,29.584790991817457,28.934469875919092,28.284148760020663,27.63382764412224,26.983506528223934,26.333185412325506,25.682864296427077,25.032543180528712,24.382222064630348,23.73190094873192,23.081579832833555,22.431258716935186,21.78093760103676,21.130616485138397,20.480295369240025,19.829974253341604,19.179653137443175,18.529332021544807,17.879010905646442,17.399867198555963,17.263078309081248,17.126289419606533,16.989500530131803,16.85271164065709,16.715922751182376,16.579133861707646,16.44234497223292,16.305556082758216,16.168767193283486,16.03197830380876,15.895189414334045,15.75840052485933,15.621611635384602,15.484822745909886,15.34803385643517,15.211244966960443,15.074456077485728,14.937667188011012,14.800878298536283,14.664089409061557,14.527300519586841,14.390511630112126,14.253722740637398,14.116933851162681,13.980144961687968,13.84335607221324,13.706567182738523,13.56977829326381,13.43298940378908,13.296200514314354,13.159411624839649,13.022622735364921,12.885833845890193,12.749044956415478,12.612256066940764,12.475467177466035,12.338678287991321,12.201889398516606,12.065100509041876,11.92831161956716,11.791522730092444,11.654733840617716,11.527279582368614,11.499006349450585,11.470733116532557,11.442459883614529,11.4141866506965,11.385913417778474,11.357640184860443,11.329366951942415,11.301093719024388,11.272820486106358,11.244547253188328,11.216274020270303,11.188000787352273,11.159727554434243,11.131454321516216,11.103181088598188,11.07490785568016,11.04663462276213,11.018361389844102,10.990088156926072,10.961814924008046,10.933541691090019,10.905268458171987,10.876995225253957,10.848721992335932,10.820448759417904,10.792175526499872,10.763902293581845,10.735629060663818,10.707355827745788,10.67908259482776,10.650809361909733,10.622536128991703,10.594262896073673,10.565989663155648,10.537716430237618,10.509443197319587,10.48116996440156,10.452896731483534,10.424623498565502,10.396350265647477,10.368077032729447,10.339803799811419,10.311530566893387,10.238132425583888,10.156056359451286,10.073980293318684,9.991904227186097,9.909828161053493,9.827752094920893,9.745676028788306,9.663599962655702,9.581523896523102,9.499447830390498,9.417371764257911,9.335295698125307,9.253219631992707,9.171143565860117,9.089067499727516,9.006991433594914,8.924915367462326,8.842839301329724,8.760763235197121,8.678687169064535,8.596611102931933,8.514535036799328,8.432458970666726,8.35038290453414,8.268306838401537,8.186230772268935,8.104154706136349,8.022078640003745,7.940002573871144,7.857926507738556,7.775850441605954,7.693774375473351,7.611698309340749,7.529720455000595,7.448476609329882,7.367232763659171,7.2859889179884725,7.2047450723177615,7.123501226647047,7.04225738097635,6.961013535305638,6.879769689634925,6.798525843964228,6.717281998293514,6.636038152622802,6.55479430695209,6.473550461281392,6.39282075904063,6.312790715372971,6.232760671705326,6.152730628037666,6.072700584370005,5.99267054070236,5.912640497034702,5.832610453367042,5.975808361222795,6.119006269078543,6.262204176934318,6.405402084790094,6.548599992645842,6.6917979005016175,6.834995808357393,6.978193716213142,7.121391624068917,7.1977326195397335,6.904132174348784,6.611794075972269,6.321529832949165,6.035527562922169,5.754514278381497,5.482332040969956,5.221338355940828,4.976080279365322,4.754212948574585,4.567548628168086,4.429433836907141,4.342201081490034,null,null,null],[64.58995140089374,64.64070957884599,64.69146775679823,64.7422259347505,64.79298411270275,64.843742290655,64.89450046860725,64.94525864655951,64.99601682451176,65.046775002464,65.09753318041626,65.14829135836851,65.19904953632076,65.24980771427302,65.30056589222526,65.35132407017753,65.40208224812977,65.45284042608202,65.50359860403428,65.55435678198653,65.60511495993879,65.65587313789104,65.70663131584328,65.75738949379554,65.80814767174779,65.85890584970005,65.9096640276523,65.96042220560454,66.0111803835568,66.06193856150905,66.1126967394613,66.16345491741356,66.2142130953658,66.26497127331805,66.31572945127031,66.36648762922256,66.41724580717482,66.46800398512707,66.51876216307932,66.56952034103158,66.62027851898382,66.67103669693608,66.72179487488833,66.77255305284058,66.82331123079283,66.8740694087451,66.92544005985361,66.97693320602363,67.02842635219366,67.0799194983637,67.13141264453371,67.18290579070373,67.23439893687376,67.28589208304378,67.33738522921381,67.38887837538383,67.44037152155386,67.49186466772386,67.54335781389389,67.59485096006392,67.64634410623394,67.69783725240397,67.74933039857399,67.800823544744,67.85231669091404,67.90380983708405,67.95530298325409,68.0067961294241,68.05828927559412,68.10978242176415,68.16127556793418,68.2127687141042,68.26426186027422,68.31575500644425,68.36724815261427,68.41874129878428,68.47023444495431,68.52172759112433,68.57322073729435,68.62471388346438,68.67620702963441,68.72770017580443,68.77919332197445,68.83068646814448,68.87173420199852,68.91069285338938,68.94965150478022,68.98861015617106,69.02756880756192,69.06652745895276,69.1054861103436,69.14444476173446,69.1834034131253,69.22236206451615,69.261320715907,69.30027936729785,69.33923801868869,69.37819667007955,69.4171553214704,69.45611397286125,69.49507262425209,69.53403127564295,69.5729899270338,69.61194857842465,69.65090722981549,69.68986588120634,69.72882453259717,69.76778318398803,69.80674183537889,69.84570048676972,69.88465913816059,69.92361778955143,69.96257644094227,70.00153509233311,70.04049374372397,70.07945239511483,70.11841104650567,70.15736969789651,70.19632834928737,70.23528700067821,70.27424565206906,70.31320430345991,70.35114856800793,70.38888995589997,70.42663134379201,70.46437273168405,70.50211411957608,70.53985550746812,70.57759689536016,70.6153382832522,70.65307967114424,70.69082105903628,70.72856244692832,70.76630383482035,70.80404522271239,70.84178661060443,70.87952799849647,70.91726938638851,70.95501077428055,70.9927521621726,71.03049355006462,71.06823493795666,71.1059763258487,71.14371771374074,71.18145910163278,71.21920048952481,71.25694187741686,71.29468326530889,71.33242465320093,71.37016604109297,71.40790742898501,71.44564881687705,71.4833902047691,71.52113159266112,71.55887298055316,71.5966143684452,71.63435575633724,71.67209714422928,71.70983853212132,71.74757992001335,71.78532130790539,71.82306269579743,71.86080408368947,71.8985454715815,71.93628685947355,71.97402824736558,72.01176963525764,72.02013596921913,72.01381477621537,72.00749358321161,72.00117239020786,71.9948511972041,71.98853000420036,71.98220881119659,71.97588761819283,71.96956642518907,71.96324523218532,71.95692403918156,71.9506028461778,71.94428165317404,71.93796046017029,71.93163926716653,71.92531807416276,71.91899688115902,71.91267568815525,71.90635449515149,71.90003330214773,71.89371210914399,71.88739091614022,71.88106972313646,71.8747485301327,71.86842733712895,71.86210614412519,71.85578495112144,71.84946375811768,71.84314256511391,71.83682137211017,71.8305001791064,71.82417898610264,71.8178577930989,71.81153660009514,71.80521540709137,71.79889421408761,71.79257302108385,71.7862518280801,71.77993063507634,71.77360944207257,71.76728824906883,71.76096705606506,71.75464586306128,71.74832467005754,71.74200347705379,71.73568228405003,71.72936109104627,71.72303989804252,71.71671870503876,71.710397512035,71.70407631903124,71.69775512602749,71.69143393302372,71.68511274001996,71.6787915470162,71.67247035401246,71.66614916100869,71.65982796800495,71.65350677500118,71.64718558199743,71.64086438899366,71.6345431959899,71.62822200298615,71.62190080998239,71.61557961697864,71.5938175179612,71.57082011867787,71.54782271939453,71.52482532011122,71.50182792082789,71.47883052154455,71.45583312226124,71.4328357229779,71.40983832369456,71.38684092441125,71.36384352512792,71.34084612584459,71.31784872656127,71.29485132727793,71.2718539279946,71.24885652871127,71.22585912942793,71.2028617301446,70.86680811001588,70.21769826904175,69.56858842806768,68.91947858709361,68.27036874611947,67.62125890514541,66.97214906417133,66.32303922319721,65.67392938222306,65.02481954124906,64.37570970027492,63.72659985930079,63.07749001832672,62.42838017735264,61.77927033637852,61.13016049540444,60.48105065443037,59.83194081345624,59.182830972482165,58.53372113150809,57.884611290533954,57.235501449559834,56.58639160858582,55.93728176761169,55.288171926637546,54.639062085663475,53.989952244689405,53.34084240371527,52.6917325627412,52.042622721767124,51.393512880793004,50.743445979064845,50.09312486316654,49.44280374726811,48.79248263136969,48.142161515471315,47.49184039957295,46.84151928367453,46.19119816777616,45.54087705187779,44.890555935979364,44.240234820081,43.589913704182635,42.93959258828421,42.289271472385785,41.63895035648748,40.98862924058905,40.33830812469062,39.687987008792255,39.03766589289389,38.38734477699546,37.7370236610971,37.086702545198726,36.4363814293003,35.786060313401876,35.13573919750357,34.48541808160515,33.83509696570672,33.18477584980835,32.53445473390998,31.884133618011557,31.233812502113192,30.583491386214824,29.9331702703164,29.28284915441803,28.632528038519663,27.982206922621238,27.331885806722813,26.68156469082451,26.03124357492608,25.38092245902765,24.73060134312929,24.080280227230922,23.429959111332494,22.77963799543413,22.12931687953576,21.478995763637336,20.82867464773897,20.178353531840603,19.528032415942178,18.87771130004375,18.22739018414538,17.577069068247013,17.097925361156538,16.961136471681822,16.824347582207107,16.687558692732377,16.550769803257666,16.41398091378295,16.27719202430822,16.14040313483349,16.00361424535879,15.86682535588406,15.730036466409334,15.593247576934619,15.456458687459902,15.319669797985174,15.18288090851046,15.046092019035745,14.909303129561017,14.772514240086302,14.635725350611585,14.498936461136859,14.36214757166213,14.225358682187416,14.0885697927127,14.004871822593708,13.976598589675682,13.948325356757653,13.920052123839623,13.891778890921595,13.863505658003568,13.835232425085538,13.806959192167508,13.778685959249483,13.750412726331454,13.722139493413422,13.693866260495396,13.665593027577367,13.637319794659339,13.60904656174131,13.580773328823282,13.552500095905252,13.524226862987225,13.495953630069199,13.467680397151168,13.439407164233138,13.41113393131511,13.382860698397083,13.319876033465446,13.237799967332853,13.155723901200258,13.073647835067655,12.99157176893506,12.909495702802467,12.827419636669866,12.745343570537262,12.663267504404676,12.581191438272072,12.499115372139471,12.417039306006874,12.33496323987428,12.252887173741676,12.170811107609083,12.08873504147649,12.006658975343885,11.92458290921129,11.842506843078699,11.760430776946095,11.678354710813492,11.596278644680904,11.514202578548304,11.432126512415701,11.350050446283106,11.267974380150513,11.185898314017908,11.103822247885313,11.021746181752716,10.939670115620114,10.85759404948751,10.775517983354927,10.693441917222325,10.61136585108972,10.529289784957125,10.447213718824532,10.365137652691928,10.28306158655934,10.200985520426737,10.118909454294137,10.036833388161533,9.954757322028946,9.872681255896344,9.790605189763742,9.708529123631155,9.626453057498551,9.544376991365949,9.462300925233363,9.38022485910076,9.298148792968158,9.216072726835556,9.134570426758723,9.053326581088012,8.972082735417297,8.8908388897466,8.809595044075888,8.728351198405177,8.647107352734478,8.565863507063765,8.484619661393053,8.403375815722354,8.322131970051645,8.24088812438093,8.159644278710218,8.07840043303952,7.997156587368808,7.9159127416980954,7.834668896027397,7.753425050356686,7.672181204685973,7.590937359015275,7.509693513344562,7.429658169569082,7.349628125901422,7.269598082233779,7.189568038566119,7.109537994898458,7.029507951230814,6.949477907563153,6.869447863895495,6.789417820227849,6.709387776560189,6.62935773289253,6.722949429298578,6.866147337154354,7.009345245010129,7.1525431528659045,7.295741060721653,7.438938968577428,7.5821368764332036,7.725334784288952,7.868532692144727,8.011730600000503,8.154928507856251,8.298126415712026,8.441324323567802,8.584522231423577,8.727720139279326,8.478690921944477,8.185090476753476,7.892211372644722,7.6019471296216174,7.31210556155874,7.026208960318353,6.7425204673621835,6.462441382691454,6.189866991615673,5.923585831095461,5.665070283792437,5.4175269260825925,5.184598340745408,4.968082995567027,4.774966059686992,4.61447658329897,4.486506866326096,4.3959246131532845,null,null,null,null,null],[64.73225762208753,64.78301580003978,64.83377397799202,64.88453215594427,64.93529033389653,64.98604851184878,65.03680668980104,65.08756486775329,65.13832304570555,65.1890812236578,65.23983940161006,65.2905975795623,65.34135575751455,65.3921139354668,65.44287211341906,65.4936302913713,65.54438846932356,65.59514664727581,65.64590482522806,65.69666300318032,65.74742118113258,65.79817935908483,65.84893753703707,65.89969571498933,65.95045389294158,66.00121207089383,66.05197024884608,66.10272842679834,66.15348660475058,66.20424478270283,66.25500296065509,66.30576113860735,66.3565193165596,66.40727749451185,66.4580356724641,66.50879385041635,66.55955202836861,66.61031020632086,66.66106838427311,66.71182656222537,66.76258474017762,66.81334291812986,66.86410109608212,66.91485927403437,66.96561745198662,67.01637562993888,67.06713380789112,67.11789198584339,67.16865016379563,67.21940834174788,67.27016651970014,67.32092469765239,67.37168287560465,67.4224410535569,67.47319923150914,67.52395740946139,67.57471558741365,67.62547376536591,67.67623194331817,67.7269901212704,67.77774829922267,67.82850647717491,67.87950964405329,67.9310027902233,67.98249593639333,68.03398908256335,68.08548222873338,68.1369753749034,68.18846852107343,68.23996166724345,68.29145481341348,68.3429479595835,68.39444110575351,68.44593425192355,68.49742739809356,68.54892054426358,68.60041369043361,68.65190683660363,68.70339998277366,68.75489312894368,68.80638627511371,68.85787942128373,68.90937256745374,68.96086571362378,69.00191344747782,69.04087209886868,69.07983075025952,69.11878940165036,69.15774805304122,69.19670670443205,69.2356653558229,69.27462400721376,69.3135826586046,69.35254130999544,69.3914999613863,69.43045861277714,69.46941726416799,69.50837591555884,69.5473345669497,69.58629321834054,69.6252518697314,69.66421052112224,69.7031691725131,69.74212782390394,69.78108647529479,69.81963937139136,69.8573807592834,69.89512214717544,69.93286353506748,69.97060492295952,70.00834631085155,70.0460876987436,70.08382908663563,70.12157047452769,70.15931186241971,70.19705325031175,70.2347946382038,70.27253602609582,70.31027741398788,70.3480188018799,70.38576018977194,70.42350157766398,70.46124296555601,70.49898435344807,70.53672574134009,70.57446712923213,70.61220851712417,70.6499499050162,70.68769129290826,70.72543268080028,70.76317406869232,70.80091545658436,70.8386568444764,70.87639823236844,70.91413962026049,70.95188100815253,70.98962239604455,71.0273637839366,71.06510517182863,71.10284655972067,71.14058794761272,71.17832933550476,71.2160707233968,71.25381211128882,71.29155349918088,71.3292948870729,71.36703627496495,71.40477766285699,71.44251905074901,71.48026043864107,71.5180018265331,71.55574321442514,71.59348460231718,71.63122599020922,71.66896737810124,71.70670876599328,71.74445015388532,71.78219154177737,71.8199329296694,71.85767431756145,71.89541570545349,71.93315709334553,71.97089848123755,72.0086398691296,72.04638125702164,72.08412264491368,72.12186403280572,72.13023036676722,72.12390917376347,72.11758798075971,72.11126678775595,72.1049455947522,72.09862440174844,72.09230320874468,72.08598201574091,72.07966082273717,72.0733396297334,72.06701843672965,72.06069724372588,72.05437605072213,72.04805485771837,72.04173366471461,72.03541247171086,72.02909127870709,72.02277008570333,72.01644889269957,72.01012769969581,72.00380650669207,71.9974853136883,71.99116412068454,71.98484292768079,71.97852173467703,71.97220054167327,71.96587934866952,71.95955815566576,71.953236962662,71.94691576965825,71.94059457665449,71.93427338365072,71.92795219064698,71.9216309976432,71.91530980463945,71.90898861163569,71.90204978521226,71.87905238592893,71.8560549866456,71.83305758736228,71.81006018807895,71.78706278879562,71.76406538951228,71.74106799022896,71.71807059094564,71.6950731916623,71.67207579237898,71.64907839309565,71.62608099381232,71.60308359452901,71.58008619524566,71.55708879596233,71.53409139667902,71.51109399739568,71.48809659811235,71.46509919882902,71.4421017995457,71.41910440026237,71.39610700097904,71.37310960169572,71.35011220241239,71.32711480312906,71.30411740384574,71.2811200045624,71.25812260527908,71.23512520599574,71.21212780671242,71.18913040742909,71.16613300814575,71.14313560886244,71.1201382095791,71.09714081029577,71.07414341101246,71.05114601172912,71.02814861244579,71.00515121316246,70.98215381387914,70.95915641459581,70.93615901531248,70.91316161602914,70.89016421674582,70.86716681746249,70.84416941817916,70.50811579805044,69.8590059570763,69.20989611610223,68.56078627512815,67.91167643415403,67.26256659317995,66.61345675220588,65.96434691123176,65.31523707025762,64.6661272292836,64.01701738830948,63.367907547335335,62.71879770636127,62.069687865387195,61.42057802441307,60.77146818343899,60.12235834246492,59.473248501490794,58.824138660516724,58.175028819542646,57.525918978568505,56.87680913759438,56.22769929662036,55.578589455646224,54.929479614672104,54.28036977369803,53.631259932723964,52.98215009174982,52.33304025077575,51.683930409801675,51.03482056882755,50.38571072785341,49.7366008868794,49.08749104590527,48.43838120493114,47.78927136395706,47.14016152298299,46.491051682008866,45.84194184103479,45.19283200006071,44.543722159086585,43.89461231811251,43.24550247713843,42.5963926361643,41.94728279519017,41.29817295421616,40.64906311324202,39.9999532722679,39.350843431293825,38.70173359031975,38.05262374934562,37.40351390837155,36.75440406739747,36.10529422642334,35.456184385449205,34.8070745444752,34.157964703501065,33.50885486252694,32.85974502155286,32.210635180578784,31.56152533960466,30.912415498630583,30.263305657656506,29.614195816682383,28.965085975708313,28.315976134734235,27.6668662937601,27.017756452785974,26.36864661181196,25.719536770837824,25.0704269298637,24.421317088889623,23.77220724791555,23.12309740694142,22.47398756596735,21.824877724993275,21.17576788401914,20.526658043045067,19.876411694441167,19.22609057854274,18.575769462644313,17.92544834674595,17.27512723084758,16.7959835237571,16.659194634282386,16.52240574480767,16.482464062818877,16.45419082990085,16.401619641347015,16.31954357521441,16.23746750908181,16.155391442949217,16.07331537681662,15.991239310684014,15.909163244551422,15.827087178418823,15.745011112286225,15.662935046153628,15.580858980021038,15.498782913888428,15.416706847755838,15.334630781623241,15.252554715490637,15.170478649358039,15.088402583225438,15.006326517092848,14.924250450960242,14.842174384827649,14.760098318695054,14.678022252562453,14.595946186429856,14.513870120297264,14.43179405416466,14.349717988032058,14.267641921899473,14.18556585576687,14.103489789634265,14.021413723501674,13.939337657369078,13.857261591236474,13.775185525103879,13.693109458971282,13.61103339283868,13.528957326706086,13.44688126057349,13.364805194440887,13.282729128308285,13.200653062175691,13.118576996043098,13.036500929910494,12.9544248637779,12.872348797645305,12.790272731512703,12.708196665380108,12.626120599247514,12.544044533114914,12.46196846698231,12.379892400849721,12.297816334717119,12.215740268584518,12.133664202451921,12.051588136319328,11.969512070186724,11.88743600405413,11.805359937921535,11.723283871788933,11.641207805656338,11.559131739523744,11.477055673391142,11.39497960725854,11.312903541125952,11.230827474993351,11.148751408860747,11.066675342728153,10.984599276595558,10.902523210462956,10.820664244187546,10.73942039851684,10.65817655284613,10.576932707175416,10.495688861504718,10.414445015834005,10.333201170163296,10.251957324492588,10.170713478821883,10.089469633151172,10.008225787480471,9.92698194180976,9.84573809613905,9.764494250468335,9.683250404797636,9.602006559126927,9.520762713456214,9.439518867785514,9.358275022114803,9.27703117644409,9.195787330773394,9.11454348510268,9.03329963943197,8.952055793761254,8.870811948090559,8.789568102419846,8.708324256749131,8.627080411078435,8.546525623765186,8.466495580097526,8.386465536429881,8.306435492762219,8.226405449094562,8.146375405426916,8.066345361759254,7.986315318091597,7.9062852744239365,7.826255230756292,7.7462251870886325,7.666195143420973,7.5861650997533285,7.506135056085668,7.426105012418009,7.470090497374489,7.613288405230266,7.7564863130860395,7.899684220941816,8.042882128797563,8.18608003665334,8.329277944509116,8.472475852364864,8.61567376022064,8.758871668076416,8.902069575932163,9.045267483787939,9.188465391643714,9.331663299499462,9.474861207355238,9.618059115211013,9.761257023066788,9.904454930922538,10.047652838778314,10.190850746634087,10.0532496695402,9.759649224349197,9.46604877915819,9.172628669317142,8.882364426294043,8.592100183270933,8.30278695895484,8.016890357714454,7.730993756474013,7.450447571672111,7.170524834969546,6.898263139313984,6.629302699042775,6.365335248605577,6.108802211644024,5.860311947411379,5.621501680044753,5.39564180620948,5.181953042559453,4.986452605144508,4.814477764360257,4.666418695044309,4.543579895745043,4.449070444840334,null,null,null,null,null,null,null],[64.87456384328131,64.92532202123357,64.97608019918582,65.02683837713806,65.07759655509032,65.12835473304258,65.17911291099482,65.22987108894708,65.28062926689933,65.33138744485159,65.38214562280383,65.4329038007561,65.48366197870834,65.53442015666059,65.58517833461285,65.6359365125651,65.68669469051734,65.7374528684696,65.78821104642185,65.8389692243741,65.88972740232636,65.94048558027862,65.99124375823087,66.04200193618311,66.09276011413537,66.14351829208762,66.19427647003987,66.24503464799213,66.29579282594437,66.34655100389662,66.39730918184888,66.44806735980113,66.49882553775339,66.54958371570564,66.60034189365788,66.65110007161014,66.70185824956239,66.75261642751465,66.8033746054669,66.85413278341916,66.9048909613714,66.95564913932365,67.0064073172759,67.05716549522816,67.10792367318041,67.15868185113266,67.20944002908492,67.26019820703716,67.31095638498942,67.36171456294167,67.41247274089393,67.46323091884618,67.51398909679844,67.56474727475069,67.61550545270293,67.66626363065518,67.71702180860746,67.7677799865597,67.81853816451195,67.8692963424642,67.92005452041644,67.9708126983687,68.02157087632095,68.07232905427321,68.12308723222546,68.1738454101777,68.22460358812995,68.27536176608221,68.32611994403446,68.37687812198672,68.42763629993898,68.47839447789123,68.52915265584348,68.57991083379572,68.63066901174798,68.68142718970023,68.73218536765249,68.78294354560474,68.833701723557,68.88507237442298,68.93656552059299,68.98805866676301,69.03955181293304,69.09104495910306,69.1320926929571,69.17105134434796,69.2100099957388,69.24896864712966,69.2879272985205,69.32587156266683,69.36361295055887,69.40135433845091,69.43909572634294,69.47683711423498,69.51457850212702,69.55231989001906,69.5900612779111,69.62780266580315,69.66554405369519,69.70328544158723,69.74102682947925,69.77876821737131,69.81650960526333,69.85425099315538,69.89199238104742,69.92973376893946,69.96747515683148,70.00521654472354,70.04295793261556,70.0806993205076,70.11844070839965,70.15618209629169,70.19392348418371,70.23166487207575,70.2694062599678,70.30714764785984,70.34488903575188,70.38263042364392,70.42037181153596,70.45811319942798,70.49585458732003,70.53359597521205,70.5713373631041,70.60907875099613,70.64682013888817,70.68456152678021,70.72230291467227,70.7600443025643,70.79778569045634,70.83552707834838,70.8732684662404,70.91100985413246,70.94875124202449,70.98649262991653,71.02423401780857,71.06197540570061,71.09971679359265,71.13745818148467,71.17519956937673,71.21294095726876,71.2506823451608,71.28842373305284,71.32616512094488,71.36390650883692,71.40164789672896,71.43938928462099,71.47713067251303,71.51487206040507,71.55261344829711,71.59035483618914,71.62809622408118,71.66583761197322,71.70357899986526,71.7413203877573,71.77906177564934,71.81680316354137,71.8545445514334,71.89228593932545,71.93002732721749,71.96776871510953,72.00551010300157,72.04325149089361,72.08099287878565,72.11873426667768,72.15647565456972,72.19421704246176,72.2319584303538,72.2403247643153,72.23400357131155,72.22768237830779,72.22136118530403,72.21503999230028,72.2087187992965,72.20239760629275,72.19607641328899,72.18728465318,72.16428725389669,72.14128985461336,72.11829245533004,72.0952950560467,72.07229765676338,72.04930025748004,72.02630285819671,72.00330545891339,71.98030805963006,71.95731066034674,71.93431326106341,71.91131586178008,71.88831846249674,71.86532106321343,71.84232366393009,71.81932626464676,71.79632886536344,71.77333146608011,71.75033406679678,71.72733666751346,71.70433926823013,71.68134186894679,71.65834446966346,71.63534707038013,71.61234967109681,71.58935227181348,71.56635487253016,71.54335747324683,71.5203600739635,71.49736267468016,71.47436527539683,71.45136787611352,71.42837047683018,71.40537307754686,71.38237567826353,71.3593782789802,71.33638087969686,71.31338348041353,71.29038608113022,71.26738868184688,71.24439128256357,71.22139388328023,71.1983964839969,71.17539908471358,71.15240168543025,71.12940428614692,71.1064068868636,71.08340948758025,71.06041208829693,71.0374146890136,71.01441728973029,70.99141989044695,70.96842249116362,70.9454250918803,70.92242769259695,70.89943029331363,70.8764328940303,70.85343549474698,70.83043809546365,70.80744069618032,70.784443296897,70.76144589761367,70.73844849833034,70.71545109904702,70.69245369976369,70.66945630048036,70.64645890119702,70.62346150191371,70.60046410263037,70.57746670334704,70.5544693040637,70.53147190478039,70.50847450549705,70.48547710621374,70.149423486085,69.50031364511088,68.85120380413679,68.20209396316272,67.55298412218859,66.90387428121451,66.25476444024045,65.60565459926632,64.95654475829218,64.30743491731818,63.658325076344035,63.00921523536991,62.36010539439583,61.71099555342175,61.06188571244763,60.412775871473556,59.76366603049948,59.114556189525345,58.46544634855128,57.8163365075772,57.16722666660307,56.51811682562895,55.86900698465492,55.2198971436808,54.57078730270666,53.921677461732585,53.272567620758515,52.62345777978439,51.974347938810325,51.32523809783625,50.67612825686211,50.02701841588798,49.37790857491396,48.728798733939826,48.079688892965706,47.43057905199163,46.78146921101755,46.132359370043424,45.483249529069354,44.83413968809528,44.18502984712114,43.53592000614708,42.886810165173,42.23770032419886,41.588590483224735,40.93948064225073,40.29037080127659,39.64126096030246,38.99215111932839,38.34304127835431,37.693931437380186,37.044821596406116,36.39571175543204,35.746601914457905,35.09894086243534,34.452093514577186,33.8052461667189,33.15839881886063,32.51155147100242,31.8647041231442,31.217856775285927,30.57100942742771,29.924162079569502,29.277314731711222,28.630467383853006,27.983620035994793,27.33677268813652,26.689925340278243,26.043077992420088,25.39623064456181,24.749383296703538,24.102535948845325,23.45568860098711,22.80884125312883,22.161993905270617,21.5151465574124,20.868299209554124,20.22145186169591,19.574604513837695,18.927757165979422,18.280909818121145,17.634062470262933,16.987215122404717,16.52862486845505,16.446548802322457,16.364472736189864,16.28239667005726,16.200320603924666,16.118244537792073,16.03616847165947,15.954092405526866,15.872016339394277,15.789940273261676,15.707864207129072,15.62578814099648,15.543712074863883,15.461636008731281,15.379559942598688,15.297483876466098,15.215407810333486,15.133331744200897,15.051255678068301,14.969179611935695,14.887103545803095,14.805027479670498,14.722951413537906,14.640875347405302,14.558799281272707,14.476723215140112,14.394647149007511,14.312571082874914,14.230495016742323,14.148418950609718,14.066342884477116,13.98426681834453,13.902190752211927,13.820114686079323,13.738038619946732,13.655962553814135,13.573886487681532,13.491810421548937,13.40973435541634,13.327658289283738,13.245582223151144,13.16350615701855,13.081430090885945,12.999354024753343,12.91727795862075,12.835201892488156,12.753125826355552,12.671049760222958,12.588973694090365,12.50689762795776,12.425514215945674,12.344270370274966,12.26302652460426,12.181782678933544,12.100538833262844,12.019294987592136,11.938051141921422,11.856807296250715,11.775563450580012,11.694319604909298,11.613075759238592,11.53183191356789,11.450588067897177,11.36934422222647,11.288100376555768,11.206856530885055,11.12561268521434,11.04436883954364,10.963124993872931,10.881881148202218,10.800637302531511,10.719393456860807,10.638149611190098,10.556905765519389,10.475661919848685,10.394418074177976,10.313174228507261,10.231930382836563,10.150686537165848,10.069442691495139,9.988198845824433,9.906955000153726,9.825711154483017,9.744467308812316,9.663393077961299,9.583363034293638,9.503332990625978,9.423302946958332,9.343272903290671,9.263242859623015,9.18321281595537,9.103182772287708,9.023152728620051,8.943122684952403,8.863092641284744,8.783062597617086,8.703032553949424,8.62300251028178,8.54297246661412,8.462942422946458,8.382912379278817,8.302882335611157,8.222852291943497,8.217231565450302,8.360429473306077,8.50362738116185,8.646825289017599,8.790023196873378,8.933221104729151,9.076419012584925,9.219616920440673,9.362814828296452,9.506012736152226,9.649210644007976,9.792408551863751,9.935606459719523,10.078804367575273,10.222002275431048,10.365200183286824,10.508398091142599,10.651595998998348,10.794793906854125,10.9379918147099,11.081189722565647,11.224387630421422,11.367585538277199,11.510783446132947,11.653981353988723,11.627808417135894,11.334207971944942,11.040607526753938,10.747007081562936,10.453406636371945,10.162781722966491,9.872517479943387,9.58225323692028,9.293468356351028,9.007571755110586,8.721675153870146,8.43845376065284,8.158374675982124,7.878920982667884,7.60665928701232,7.335019566990166,7.070556489168281,6.809067176457139,6.552534139495631,6.304187496247458,6.062948326762022,5.830648071130696,5.608124110973457,5.395823089551896,5.198111541579969,5.01990613567445,4.860696015754667,4.720379238321925,4.600652925164018,4.5038572136941175,4.426774037222506,null,null,null,null,null,null,null,null],[65.00577384906519,65.05628168246963,65.10678951587408,65.15729734927852,65.20780518268296,65.25831301608741,65.30882084949185,65.35932868289629,65.40983651630074,65.46034434970518,65.51085218310963,65.56136001651407,65.61199302194638,65.66275119989862,65.71350937785088,65.76426755580312,65.81502573375538,65.86578391170764,65.91654208965988,65.96730026761213,66.01805844556439,66.06881662351665,66.11957480146889,66.17033297942115,66.2210911573734,66.27184933532564,66.3226075132779,66.37336569123016,66.42412386918241,66.47488204713466,66.52564022508692,66.57639840303915,66.62715658099141,66.67791475894367,66.72867293689592,66.77943111484817,66.83018929280043,66.88094747075269,66.93170564870493,66.98246382665718,67.03322200460943,67.08398018256167,67.13473836051395,67.1854965384662,67.23625471641844,67.28701289437069,67.33777107232294,67.3885292502752,67.43928742822746,67.4900456061797,67.54080378413195,67.5915619620842,67.64232014003646,67.69307831798871,67.74383649594097,67.79459467389322,67.84535285184548,67.89611102979772,67.94686920774997,67.99762738570223,68.04838556365448,68.09914374160672,68.14990191955899,68.20066009751123,68.2514182754635,68.30217645341574,68.35293463136799,68.40369280932025,68.4544509872725,68.50520916522476,68.555967343177,68.60672552112925,68.65748369908151,68.70824187703376,68.75900005498602,68.80975823293826,68.86051641089051,68.91127458884277,68.96203276679502,69.01279094474728,69.06354912269953,69.11430730065177,69.16506547860402,69.2158236565563,69.25573450945835,69.29347589735039,69.33121728524243,69.36895867313447,69.40670006102651,69.44444144891855,69.48218283681058,69.51992422470262,69.55766561259466,69.59540700048669,69.63314838837874,69.67088977627077,69.70863116416282,69.74637255205485,69.7841139399469,69.82185532783893,69.85959671573097,69.89733810362301,69.93507949151505,69.97282087940708,70.01056226729912,70.04830365519116,70.0860450430832,70.12378643097524,70.16152781886728,70.19926920675931,70.23701059465135,70.27475198254339,70.31249337043542,70.35023475832747,70.3879761462195,70.42571753411156,70.46345892200358,70.50120030989562,70.53894169778766,70.5766830856797,70.61442447357175,70.65216586146377,70.68990724935581,70.72764863724785,70.76539002513988,70.80313141303193,70.84087280092398,70.87861418881602,70.91635557670804,70.95409696460008,70.99183835249212,71.02957974038416,71.0673211282762,71.10506251616825,71.14280390406027,71.18054529195231,71.21828667984435,71.2560280677364,71.29376945562844,71.33151084352048,71.36925223141252,71.40699361930454,71.44473500719658,71.48247639508863,71.52021778298067,71.55795917087269,71.59570055876473,71.63344194665677,71.67118333454881,71.70892472244087,71.74666611033288,71.78440749822492,71.82214888611696,71.85989027400902,71.89763166190104,71.9350641792042,71.97095235449129,72.00684052977837,72.04272870506546,72.07861688035256,72.11450505563963,72.15039323092672,72.1862814062138,72.22216958150088,72.25805775678796,72.29394593207505,72.32983410736213,72.3217182587106,72.29160039808978,72.26148253746895,72.23136467684813,72.2012468162273,72.17112895560648,72.14101109498564,72.11089323436482,72.08077537374399,72.05065751312317,72.02053965250234,71.99042179188152,71.96030393126068,71.93018607063986,71.90006821001903,71.86995034939821,71.83983248877738,71.80971462815656,71.77959676753574,71.7494789069149,71.71936104629407,71.68924318567323,71.65912532505243,71.62900746443158,71.59888960381076,71.56877174318993,71.53865388256911,71.50853602194829,71.47841816132744,71.44830030070662,71.4181824400858,71.38806457946497,71.35794671884416,71.32782885822331,71.29771099760248,71.26759313698166,71.23747527636084,71.20735741574,71.17723955511919,71.14712169449835,71.11700383387753,71.0868859732567,71.05676811263587,71.02665025201506,71.00068596701476,70.97768856773143,70.95469116844811,70.93169376916478,70.90869636988144,70.88569897059813,70.86270157131479,70.83970417203146,70.81670677274815,70.79370937346481,70.77071197418148,70.74771457489815,70.72471717561481,70.7017197763315,70.67872237704816,70.65572497776483,70.63272757848151,70.60973017919818,70.58673277991485,70.56373538063153,70.5407379813482,70.51774058206487,70.49474318278155,70.47174578349822,70.4487483842149,70.42575098493157,70.40275358564823,70.3797561863649,70.35675878708159,70.33376138779825,70.31076398851492,70.28776658923158,70.26476918994825,70.24177179066493,70.2187743913816,70.19577699209827,70.17277959281495,70.14978219353162,70.1267847942483,69.79073117411956,69.14162133314544,68.49251149217136,67.84340165119728,67.19429181022316,66.54518196924909,65.89607212827502,65.24696228730087,64.59785244632674,63.948742605352734,63.2996327643786,62.65052292340447,62.0014130824304,61.352303241456326,60.70319340048219,60.054083559508115,59.40497371853405,58.75586387755992,58.10675403658585,57.45764419561176,56.808534354637644,56.161528238202266,55.51468089034411,54.86783354248584,54.220986194627564,53.57413884676935,52.92729149891113,52.280444151052855,51.63359680319464,50.98674945533643,50.33990210747815,49.693054759619876,49.04620741176172,48.399360063903444,47.752512716045175,47.10566536818696,46.45881802032874,45.81197067247047,45.16512332461225,44.51827597675404,43.87142862889577,43.22458128103755,42.57773393317934,41.93088658532106,41.284039237462785,40.63719188960462,39.99034454174635,39.343497193888076,38.69664984602986,38.04980249817165,37.402955150313375,36.75610780245516,36.10926045459694,35.46241310673867,34.815565758880396,34.16871841102224,33.521871063163964,32.87502371530569,32.228176367447475,31.581329019589262,30.934481671730982,30.287634323872773,29.640786976014557,28.993939628156284,28.347092280298064,27.70024493243985,27.05339758458157,26.406550236723298,25.759702888865146,25.112855541006873,24.466008193148596,23.819160845290376,23.172313497432164,22.525466149573887,21.878618801715675,21.231771453857462,20.584924105999185,19.93807675814097,19.291229410282753,18.644382062424484,17.997534714566207,17.35068736670799,16.703840018849775,16.24524976490011,16.163173698767515,16.081097632634922,15.999021566502321,15.916945500369723,15.83486943423713,15.752793368104523,15.670717301971926,15.588641235839335,15.506565169706734,15.424489103574128,15.342413037441538,15.260336971308941,15.178260905176339,15.096184839043746,15.014108772911154,14.932032706778546,14.849956640645955,14.76788057451336,14.685804508380754,14.603728442248153,14.521652376115556,14.439576309982964,14.35750024385036,14.275424177717765,14.19334811158517,14.111608033374509,14.030364187703803,13.949120342033098,13.867876496362387,13.786632650691674,13.705388805020974,13.624144959350263,13.542901113679552,13.461657268008846,13.380413422338139,13.299169576667428,13.217925730996722,13.136681885326015,13.055438039655304,12.974194193984598,12.892950348313892,12.811706502643183,12.730462656972469,12.649218811301765,12.567974965631063,12.486731119960346,12.40548727428964,12.324243428618939,12.242999582948224,12.161755737277518,12.080511891606811,11.999268045936105,11.91802420026539,11.836780354594687,11.755536508923981,11.674292663253265,11.59304881758256,11.51180497191186,11.430561126241143,11.349317280570437,11.268073434899735,11.186829589229022,11.105585743558315,11.024341897887613,10.9430980522169,10.861854206546186,10.780610360875484,10.700230488489751,10.620200444822093,10.540170401154437,10.460140357486784,10.380110313819126,10.300080270151472,10.220050226483822,10.140020182816162,10.059990139148502,9.979960095480855,9.899930051813195,9.819900008145538,9.739869964477885,9.659839920810231,9.579809877142571,9.499779833474927,9.41974978980727,9.339719746139611,9.25968970247195,9.179659658804304,9.099629615136642,9.019599571468985,8.96437263352611,9.107570541381886,9.250768449237661,9.393966357093406,9.537164264949185,9.680362172804958,9.823560080660734,9.966757988516484,10.109955896372258,10.253153804228035,10.396351712083783,10.539549619939557,10.682747527795335,10.825945435651084,10.96914334350686,11.112341251362631,11.255539159218383,11.398737067074158,11.541934974929934,11.685132882785707,11.828330790641456,11.971528698497234,12.114726606353008,12.257924514208757,12.401122422064532,12.544320329920305,12.687518237776056,12.830716145631833,12.973914053487604,13.11711196134338,13.202367164731639,12.908766719540637,12.615166274349633,12.321565829158693,12.027965383967679,11.734364938776677,11.443199019638948,11.152934776615844,10.862670533592741,10.572406290569685,10.284149753747155,9.998253152506713,9.712356551266273,9.42645995002589,9.14638086496281,8.866301780292076,8.587317130366262,8.315055434710699,8.042793739055137,7.776273357115672,7.511810279293787,7.25279910430875,6.9962660673471895,6.748063045083531,6.504394973479339,6.267213078912525,6.040132793734128,5.820606415737429,5.609693136544335,5.410657032788314,5.228074155945182,5.061406900552412,4.910364332146947,4.775155982179863,4.657725954582973,4.559332592364925,4.479504461556123,null,null,null,null,null,null,null,null,null,null],[65.13215941456794,65.18266724797238,65.23317508137681,65.28368291478125,65.3341907481857,65.38469858159016,65.43520641499458,65.48571424839903,65.53622208180349,65.58672991520793,65.63723774861236,65.6877455820168,65.73825341542124,65.7887612488257,65.83926908223015,65.88977691563458,65.94028474903902,65.99079258244348,66.04130041584791,66.09180824925235,66.1423160826568,66.19282391606124,66.24333174946568,66.29383958287013,66.34434741627457,66.39485524967901,66.44536308308346,66.49587091648789,66.54637874989234,66.59713692755724,66.64789510550949,66.69865328346174,66.74941146141398,66.80016963936626,66.8509278173185,66.90168599527075,66.95244417322301,67.00320235117526,67.05396052912752,67.10471870707977,67.15547688503202,67.20623506298426,67.25699324093651,67.30775141888878,67.35850959684103,67.40926777479328,67.46002595274554,67.51078413069777,67.56154230865003,67.6123004866023,67.66305866455454,67.7138168425068,67.76457502045905,67.81533319841128,67.86609137636356,67.91684955431579,67.96760773226805,68.0183659102203,68.06912408817256,68.11988226612482,68.17064044407707,68.22139862202931,68.27215679998156,68.3229149779338,68.37367315588608,68.42443133383833,68.47518951179057,68.52594768974282,68.57670586769508,68.62746404564734,68.67822222359958,68.72898040155184,68.77973857950408,68.83049675745634,68.88125493540859,68.93201311336085,68.9827712913131,69.03352946926535,69.08428764721761,69.13504582516987,69.1858040031221,69.23656218107435,69.28732035902661,69.33807853697886,69.37798938988094,69.41573077777298,69.453472165665,69.49121355355706,69.52895494144909,69.56669632934113,69.60443771723317,69.6421791051252,69.67992049301725,69.71766188090928,69.75540326880133,69.79314465669336,69.83088604458541,69.86862743247744,69.90636882036948,69.94411020826152,69.98185159615355,70.0195929840456,70.05733437193763,70.09507575982967,70.13281714772171,70.17055853561374,70.20829992350578,70.24604131139782,70.28378269928986,70.3215240871819,70.35926547507394,70.39700686296598,70.43474825085801,70.47248963875006,70.51023102664209,70.54797241453413,70.58571380242617,70.6234551903182,70.66119657821025,70.69893796610228,70.73667935399432,70.77442074188636,70.8121621297784,70.84990351767044,70.88764490556247,70.92538629345451,70.96312768134655,71.00086906923859,71.03861045713063,71.07635184502267,71.1140932329147,71.15183462080674,71.18957600869878,71.22731739659082,71.26505878448286,71.3028001723749,71.34054156026694,71.37828294815897,71.41602433605101,71.45253024674591,71.488418422033,71.52430659732008,71.56019477260718,71.59608294789425,71.63197112318134,71.66785929846841,71.70374747375551,71.73963564904258,71.77552382432967,71.81141199961677,71.84730017490384,71.88318835019092,71.919076525478,71.95496470076509,71.99085287605217,72.02674105133926,72.06262922662636,72.09851740191343,72.13440557720051,72.1702937524876,72.20618192777468,72.24207010306176,72.27795827834885,72.31384645363593,72.34973462892302,72.3856228042101,72.42151097949719,72.41339513084567,72.38327727022484,72.35315940960402,72.32304154898318,72.29292368836236,72.26280582774153,72.23268796712071,72.20257010649988,72.17245224587904,72.14233438525822,72.1122165246374,72.08209866401657,72.05198080339574,72.02186294277492,71.9917450821541,71.96162722153326,71.93150936091243,71.90139150029161,71.87127363967079,71.84115577904996,71.81103791842912,71.7809200578083,71.75080219718747,71.72068433656665,71.69056647594581,71.66044861532498,71.63033075470416,71.60021289408334,71.57009503346251,71.53997717284167,71.50985931222085,71.47974145160002,71.4496235909792,71.41950573035837,71.38938786973755,71.35927000911673,71.3291521484959,71.29903428787506,71.26891642725423,71.2387985666334,71.20868070601259,71.17856284539175,71.14844498477092,71.11832712415011,71.08820926352928,71.05809140290845,71.02797354228763,70.99785568166679,70.96773782104597,70.93761996042514,70.90750209980432,70.87738423918348,70.84726637856267,70.81714851794183,70.787030657321,70.75691279670018,70.72679493607936,70.69667707545852,70.66655921483769,70.63644135421687,70.60632349359605,70.57620563297522,70.54608777235438,70.51596991173356,70.48585205111273,70.45573419049191,70.42561632987108,70.39549846925026,70.36538060862944,70.3352627480086,70.30514488738777,70.27502702676695,70.24490916614612,70.2147913055253,70.1839068304766,70.12772545546147,70.07154408044636,70.01536270543124,69.95918133041611,69.902999955401,69.84681858038589,69.79063720537076,69.73445583035564,69.38759742824027,68.75006199902464,68.11252656980909,67.47499114059352,66.8374557113779,66.19992028216234,65.56238485294678,64.92484942373116,64.28731399451553,63.6467361271133,62.99977505965066,62.352813992188025,61.70585292472545,61.05889185726287,60.41193078980023,59.764969722337646,59.11800865487508,58.47104758741243,57.82408651994986,57.17712545248728,56.53016438502464,55.883203317562,55.23624225009949,54.589281182636846,53.94232011517421,53.29535904771163,52.64839798024905,52.00143691278642,51.35447584532384,50.70751477786126,50.06055371039862,49.41359264293599,48.76663157547347,48.119670508010834,47.47270944054819,46.82574837308562,46.17878730562304,45.5318262381604,44.884865170697815,44.23790410323524,43.59094303577261,42.94398196831003,42.29702090084745,41.650059833384816,41.003098765922175,40.35613769845965,39.709176630997014,39.06221556353438,38.415254496071796,37.76829342860922,37.121332361146585,36.47437129368401,35.82741022622143,35.18044915875879,34.53348809129615,33.88652702383364,33.239565956371,32.59260488890836,31.94564382144578,31.298682753983208,30.651721686520567,30.00476061905799,29.357799551595413,28.710838484132772,28.063877416670195,27.416916349207618,26.77002248102663,26.12317513316836,25.476327785310204,24.829480437451927,24.182633089593654,23.535785741735438,22.888938393877226,22.24209104601895,21.595243698160733,20.94839635030252,20.301549002444244,19.654701654586027,19.007854306727815,18.361006958869538,17.71415961101126,17.06731226315305,16.420464915294833,15.961874661345167,15.879798595212574,15.797722529079977,15.716458005132633,15.635214159461931,15.553970313791224,15.472726468120513,15.3914826224498,15.310238776779101,15.228994931108387,15.14775108543768,15.066507239766972,14.985263394096267,14.904019548425554,14.822775702754848,14.741531857084142,14.660288011413435,14.579044165742728,14.497800320072022,14.416556474401307,14.335312628730595,14.254068783059893,14.172824937389183,14.091581091718478,14.010337246047769,13.929093400377063,13.847849554706352,13.766605709035646,13.68536186336494,13.60411801769423,13.522874172023519,13.441630326352819,13.360386480682106,13.279142635011397,13.19789878934069,13.116654943669982,13.03541109799927,12.954167252328567,12.87292340665786,12.791679560987149,12.710435715316443,12.629191869645737,12.547948023975025,12.466704178304314,12.385460332633606,12.304216486962908,12.222972641292191,12.141728795621484,12.060484949950782,11.979241104280069,11.897997258609362,11.817097942685864,11.737067899018207,11.657037855350545,11.577007811682899,11.496977768015238,11.41694772434758,11.336917680679925,11.256887637012275,11.17685759334461,11.096827549676963,11.01679750600931,10.936767462341649,10.856737418673996,10.776707375006342,10.696677331338682,10.616647287671022,10.53661724400338,10.456587200335724,10.376557156668063,10.296527113000408,10.216497069332755,10.136467025665096,10.056436981997443,9.976406938329795,9.896376894662135,9.816346850994472,9.736316807326828,9.854711609457702,9.997909517313474,10.141107425169237,10.284305333024998,10.427503240880775,10.570701148736521,10.713899056592297,10.857096964448074,11.000294872303847,11.143492780159596,11.286690688015373,11.429888595871148,11.573086503726898,11.716284411582674,11.859482319438447,12.002680227294194,12.145878135149973,12.289076043005748,12.432273950861521,12.57547185871727,12.718669766573045,12.86186767442882,13.005065582284569,13.148263490140344,13.291461397996121,13.434659305851872,13.577857213707645,13.72105512156342,13.864253029419169,14.007450937274944,14.15064884513072,14.293846752986495,14.437044660842242,14.58024256869802,14.723440476553794,14.483325467136392,14.189725021945378,13.896124576754376,13.602524131563424,13.308923686372431,13.015323241181429,12.723616316311336,12.433352073288292,12.143087830265188,11.852823587242082,11.562559344219029,11.274831151143292,10.98893454990285,10.703037948662459,10.41714134742201,10.134387053943481,9.854307969272813,9.574228884602089,9.295713278064596,9.02345158240904,8.751189886753524,8.481990225063008,8.217527147241125,7.953064069419292,7.69653103216036,7.439997995198801,7.191938593919609,6.945841620196655,6.708369727441477,6.476697801515957,6.251056356033139,6.033088720501405,5.823563183536779,5.624384596485437,5.437966085312247,5.265071388262671,5.10723133817319,4.961927987974793,4.8306809099965635,4.714798984001945,4.6156097350375065,4.53158283444689,4.455673632867041,null,null,null,null,null,null,null,null,null,null,null],[65.25854498007067,65.3090528134751,65.35956064687954,65.410068480284,65.46057631368843,65.51108414709289,65.56159198049733,65.61209981390176,65.66260764730622,65.71311548071066,65.76362331411511,65.81413114751953,65.86463898092398,65.91514681432844,65.96565464773288,66.01616248113731,66.06667031454175,66.1171781479462,66.16768598135064,66.2181938147551,66.26870164815954,66.31920948156397,66.36971731496841,66.42022514837288,66.4707329817773,66.52124081518176,66.57174864858621,66.62225648199063,66.67276431539509,66.72327214879952,66.77377998220396,66.82428781560841,66.87479564901285,66.92530348241729,66.97581131582174,67.02631914922618,67.07682698263062,67.12733481603507,67.17784264943953,67.22835048284395,67.2788583162484,67.32936614965284,67.37987398305728,67.43038181646173,67.48088964986617,67.53152265521587,67.58228083316811,67.63303901112037,67.68379718907262,67.73455536702488,67.78531354497713,67.83607172292938,67.88682990088162,67.93758807883388,67.98834625678613,68.03910443473839,68.08986261269064,68.1406207906429,68.19137896859515,68.2421371465474,68.29289532449965,68.3436535024519,68.39441168040415,68.44516985835641,68.49592803630865,68.54668621426092,68.59744439221316,68.64820257016541,68.69896074811766,68.74971892606992,68.80047710402216,68.85123528197443,68.90199345992667,68.95275163787893,69.00350981583118,69.05426799378343,69.10502617173569,69.15578434968793,69.20654252764018,69.25730070559244,69.30805888354469,69.35881706149695,69.4095752394492,69.46033341740146,69.50024427030353,69.53798565819557,69.5757270460876,69.61346843397965,69.65120982187167,69.68895120976372,69.72669259765576,69.7644339855478,69.80217537343982,69.83991676133186,69.8776581492239,69.91539953711595,69.95314092500799,69.99088231290003,70.02862370079207,70.06636508868411,70.10410647657613,70.14184786446818,70.17958925236022,70.21733064025226,70.2550720281443,70.29281341603634,70.33055480392838,70.3682961918204,70.40603757971245,70.44377896760449,70.48152035549653,70.51926174338855,70.5570031312806,70.59474451917264,70.63248590706468,70.67022729495672,70.70796868284874,70.74571007074078,70.78345145863283,70.82119284652487,70.8589342344169,70.89667562230895,70.93410813900054,70.96999631428763,71.00588448957471,71.0417726648618,71.07766084014888,71.11354901543598,71.14943719072305,71.18532536601013,71.22121354129723,71.25710171658432,71.2929898918714,71.32887806715847,71.36476624244555,71.40065441773264,71.43654259301972,71.47243076830681,71.50831894359389,71.54420711888098,71.58009529416806,71.61598346945514,71.65187164474223,71.68775982002931,71.7236479953164,71.75953617060348,71.79542434589058,71.83131252117765,71.86720069646474,71.90308887175183,71.9389770470389,71.97486522232599,72.01075339761307,72.04664157290016,72.08252974818724,72.11841792347431,72.15430609876141,72.19019427404848,72.22608244933558,72.26197062462265,72.29785879990973,72.33374697519682,72.3696351504839,72.405523325771,72.44141150105808,72.47729967634515,72.51318785163224,72.50507200298074,72.4749541423599,72.44483628173907,72.41471842111824,72.38460056049743,72.3544826998766,72.32436483925576,72.29424697863493,72.26412911801411,72.23401125739329,72.20389339677246,72.17377553615162,72.14365767553082,72.11353981490998,72.08342195428915,72.05330409366832,72.0231862330475,71.99306837242668,71.96295051180584,71.93283265118501,71.90271479056419,71.87259692994337,71.84247906932254,71.8123612087017,71.78224334808087,71.75212548746006,71.72200762683923,71.6918897662184,71.66177190559756,71.63165404497676,71.60153618435592,71.57141832373509,71.54130046311427,71.51118260249343,71.48106474187261,71.45094688125178,71.42082902063095,71.39071116001013,71.3605932993893,71.33047543876847,71.30035757814764,71.2702397175268,71.24012185690599,71.21000399628517,71.17988613566433,71.14976827504351,71.1196504144227,71.08953255380186,71.05941469318103,71.02929683256019,70.99917897193937,70.96906111131855,70.92974431697104,70.87356294195591,70.8173815669408,70.76120019192567,70.70501881691055,70.64883744189544,70.59265606688031,70.5364746918652,70.48029331685008,70.42411194183495,70.36793056681984,70.31174919180472,70.2555678167896,70.19938644177448,70.14320506675935,70.08702369174422,70.0308423167291,69.97466094171399,69.91847956669888,69.86229819168375,69.80611681666863,69.74993544165352,69.69375406663839,69.63757269162328,69.58139131660815,69.52520994159303,69.4690285665779,69.41284719156279,69.35666581654768,69.30048444153255,69.24430306651743,68.89744466440206,68.25990923518644,67.62237380597088,66.9848383767553,66.34730294753969,65.70976751832413,65.07223208910857,64.43469665989295,63.79716123067732,63.159625801461814,62.5220903722462,61.88455494303057,61.24701951381502,60.60948408459945,59.97194865538383,59.334413226168266,58.696877796952705,58.059342367737074,57.42180693852152,56.78427150930596,56.146736080090335,55.50920065087471,54.87166522165921,54.23412979244359,53.59659436322796,52.959058934012404,52.321523504796836,51.68398807558122,51.04645264636565,50.40891721715009,49.77138178793447,49.13384635871884,48.49631092950334,47.85591202934266,47.20895096188003,46.56198989441745,45.915028826954874,45.26806775949223,44.62110669202965,43.97414562456708,43.327184557104445,42.68022348964186,42.033262422179284,41.38630135471665,40.739340287254,40.09237921979149,39.445418152328855,38.79845708486621,38.15149601740364,37.50453494994106,36.85757388247842,36.21061281501584,35.56365174755326,34.916690680090625,34.269729612627984,33.62276854516547,32.97580747770283,32.328846410240196,31.681885342777615,31.034924275315042,30.3879632078524,29.741002140389824,29.094041072927247,28.44708000546461,27.80011893800203,27.153157870539452,26.506196803076815,25.859235735614178,25.212274668151657,24.565313600689016,23.918352533226383,23.271391465763806,22.624430398301225,21.977469330838588,21.33050826337601,20.683547195913434,20.036586128450793,19.389625060988216,18.74266399352564,18.095702926062998,17.448741858600364,16.801780791137787,16.154819723675207,15.696431063476593,15.615187217805886,15.53394337213518,15.452699526464466,15.371455680793765,15.290211835123058,15.208967989452347,15.127724143781636,15.046480298110936,14.965236452440221,14.883992606769514,14.802748761098806,14.7215049154281,14.64026106975739,14.559017224086682,14.477773378415977,14.39652953274527,14.315285687074562,14.234041841403855,14.152797995733142,14.071554150062433,13.990310304391723,13.90906645872102,13.82782261305031,13.746578767379605,13.665334921708897,13.584091076038188,13.50284723036748,13.421603384696775,13.340359539026066,13.259115693355353,13.177871847684653,13.09662800201394,13.015384156343229,12.934140310672523,12.853935353214304,12.773905309546645,12.693875265878992,12.61384522221134,12.533815178543678,12.453785134876025,12.373755091208377,12.293725047540713,12.213695003873053,12.133664960205405,12.053634916537751,11.973604872870094,11.893574829202441,11.813544785534782,11.733514741867127,11.65348469819948,11.573454654531826,11.493424610864167,11.413394567196507,11.33336452352886,11.2533344798612,11.17330443619354,11.093274392525887,11.013244348858237,10.933214305190575,10.853184261522923,10.773154217855271,10.693124174187611,10.613094130519958,10.533064086852304,10.601852677533607,10.745050585389386,10.888248493245134,11.031446401100908,11.174644308956685,11.317842216812448,11.461040124668209,11.60423803252398,11.747435940379743,11.890633848235506,12.03383175609128,12.17702966394706,12.320227571802809,12.463425479658586,12.606623387514357,12.749821295370118,12.893019203225881,13.036217111081656,13.179415018937403,13.32261292679318,13.465810834648956,13.609008742504729,13.752206650360478,13.895404558216255,14.038602466072032,14.18180037392778,14.324998281783555,14.46819618963933,14.611394097495076,14.754592005350855,14.89778991320663,15.040987821062405,15.184185728918152,15.327383636773927,15.470581544629702,15.613779452485453,15.756977360341228,15.900175268197003,16.043373176052754,16.186571083908525,16.057884214732045,15.764283769541105,15.470683324350102,15.177082879159101,14.883482433968096,14.589881988777144,14.296281543586144,14.004033612983765,13.713769369960701,13.423505126937616,13.133240883914503,12.842976640891457,12.552712397868355,12.265512548539402,11.979615947298942,11.693719346058561,11.40782274481812,11.12239324292415,10.842314158253465,10.562235073582741,10.282155988912018,10.004109425762966,9.731847730107402,9.459586034451839,9.187707093010378,8.923244015188484,8.658780937366599,8.396795996973449,8.140262960011942,7.883729923050389,7.635814142755616,7.388329224908754,7.149816374158768,6.9132628092978035,6.686182524119417,6.463538660797099,6.246110702890531,6.0374332305292056,5.83811216018254,5.649625021747661,5.473014231932607,5.308336036744581,5.155320204884144,5.015081158646151,4.886205837813279,4.771872013420895,4.672063265821567,4.584954451393704,4.5113469929549925,null,null,null,null,null,null,null,null,null,null,null,null,null],[65.3849305455734,65.43543837897784,65.48594621238229,65.53645404578673,65.58696187919116,65.63746971259562,65.68797754600006,65.7384853794045,65.78899321280895,65.8395010462134,65.89000887961784,65.94051671302228,65.99102454642671,66.04153237983115,66.0920402132356,66.14254804664006,66.19305588004448,66.24356371344894,66.29407154685339,66.34457938025781,66.39508721366226,66.44559504706672,66.49610288047114,66.5466107138756,66.59711854728003,66.64762638068447,66.69813421408892,66.74864204749336,66.79914988089782,66.84965771430225,66.9001655477067,66.95067338111114,67.00118121451558,67.05168904792004,67.10219688132446,67.15270471472891,67.20321254813337,67.25372038153779,67.30422821494226,67.35473604834668,67.40524388175113,67.45575171515557,67.50625954856002,67.55676738196446,67.6072752153689,67.65778304877335,67.70829088217779,67.75879871558223,67.80930654898668,67.85981438239112,67.91032221579556,67.96083004920001,68.01133788260445,68.06184571600889,68.11235354941334,68.16286138281778,68.21336921622222,68.26387704962667,68.31438488303112,68.36489271643555,68.41540054984,68.46590838324445,68.51666656082674,68.56742473877898,68.61818291673124,68.66894109468349,68.71969927263574,68.770457450588,68.82121562854024,68.87197380649249,68.92273198444475,68.973490162397,69.02424834034925,69.0750065183015,69.12576469625375,69.17652287420601,69.22728105215826,69.27803923011052,69.32879740806277,69.37955558601502,69.43031376396728,69.48107194191952,69.53183011987177,69.58258829782403,69.6224991507261,69.66024053861814,69.69798192651018,69.73572331440222,69.77346470229426,69.81120609018629,69.84894747807833,69.88668886597037,69.9244302538624,69.96217164175445,69.99991302964649,70.03765441753852,70.07539580543056,70.1131371933226,70.15087858121464,70.18861996910668,70.22636135699872,70.26410274489076,70.3018441327828,70.33958552067485,70.37732690856687,70.41506829645891,70.45157420654226,70.48746238182933,70.52335055711643,70.5592387324035,70.59512690769058,70.63101508297767,70.66690325826475,70.70279143355185,70.73867960883892,70.774567784126,70.81045595941309,70.84634413470017,70.88223230998726,70.91812048527434,70.95400866056143,70.98989683584851,71.0257850111356,71.0616731864227,71.09756136170978,71.13344953699686,71.16933771228395,71.20522588757103,71.2411140628581,71.2770022381452,71.31289041343227,71.34877858871937,71.38466676400644,71.42055493929352,71.45644311458061,71.49233128986769,71.52821946515478,71.56410764044186,71.59999581572895,71.63588399101603,71.67177216630311,71.70766034159021,71.74354851687728,71.77943669216437,71.81532486745145,71.85121304273854,71.88710121802562,71.92298939331272,71.9588775685998,71.99476574388689,72.03065391917397,72.06654209446106,72.10243026974813,72.1383184450352,72.1742066203223,72.21009479560936,72.24598297089646,72.28187114618355,72.31775932147062,72.35364749675772,72.38953567204479,72.42542384733188,72.46131202261897,72.49720019790604,72.53308837319314,72.56897654848021,72.6048647237673,72.5967488751158,72.56663101449496,72.53651315387413,72.5063952932533,72.47627743263249,72.44615957201165,72.41604171139082,72.38592385076998,72.35580599014916,72.32568812952834,72.29557026890751,72.26545240828669,72.23533454766587,72.20521668704504,72.1750988264242,72.14498096580337,72.11486310518255,72.08474524456173,72.0546273839409,72.02450952332006,71.99439166269924,71.96427380207841,71.93415594145759,71.90403808083676,71.87392022021594,71.8438023595951,71.81368449897428,71.78356663835346,71.75344877773263,71.72333091711181,71.67558180346549,71.61940042845036,71.56321905343525,71.50703767842013,71.450856303405,71.39467492838989,71.33849355337478,71.28231217835965,71.22613080334453,71.1699494283294,71.11376805331429,71.05758667829917,71.00140530328405,70.94522392826893,70.88904255325382,70.83286117823869,70.77667980322357,70.72049842820844,70.66431705319333,70.6081356781782,70.55195430316309,70.49577292814797,70.43959155313286,70.38341017811773,70.32722880310261,70.27104742808748,70.21486605307237,70.15868467805724,70.10250330304214,70.046321928027,69.99014055301188,69.93395917799677,69.87777780298165,69.82159642796653,69.76541505295141,69.70923367793628,69.65305230292117,69.59687092790604,69.54068955289092,69.48450817787581,69.42832680286068,69.37214542784557,69.31596405283045,69.25978267781532,69.20360130280021,69.14741992778508,69.09123855276997,69.03505717775484,68.97887580273972,68.92269442772461,68.86651305270948,68.81033167769435,68.75415030267924,68.40729190056388,67.76975647134826,67.13222104213268,66.49468561291712,65.8571501837015,65.21961475448593,64.58207932527039,63.94454389605475,63.307008466839136,62.66947303762363,62.031937608408015,61.39440217919239,60.75686674997682,60.11933132076127,59.48179589154564,58.844260462330084,58.206725033114516,57.56918960389889,56.93165417468333,56.29411874546776,55.65658331625215,55.01904788703652,54.38151245782102,53.7439770286054,53.10644159938977,52.46890617017421,51.83137074095865,51.19383531174303,50.55629988252746,49.918764453311894,49.28122902409628,48.64369359488066,48.006158165665155,47.36862273644953,46.73108730723391,46.093551878018346,45.456016448802785,44.81848101958716,44.1809455903716,43.54341016115603,42.905874731940415,42.268339302724854,41.63080387350928,40.99326844429366,40.355733015078044,39.71819758586254,39.08066215664692,38.44312672743129,37.805591298215745,37.16805586900017,36.530520439784546,35.89298501056899,35.255449581353425,34.6179141521378,33.980378722922175,33.34284329370668,32.70530786449105,32.06508793157204,31.41812686410946,30.771165796646887,30.124204729184243,29.47724366172167,28.830282594259092,28.18332152679645,27.53636045933387,26.889399391871297,26.242438324408656,25.595477256946022,24.948516189483502,24.301555122020865,23.654594054558228,23.007632987095647,22.36067191963307,21.71371085217043,21.066749784707856,20.419788717245275,19.772827649782638,19.12586658232006,18.478905514857484,17.831944447394847,17.184983379932206,16.53802231246963,15.891061245007052,15.432672584808437,15.35142873913773,15.270184893467025,15.18894104779631,15.10769720212561,15.026453356454903,14.945209510784192,14.863965665113477,14.782721819442777,14.701477973772066,14.620234128101359,14.538990282430651,14.457746436759944,14.376502591089233,14.295258745418527,14.214014899747822,14.132771054077114,14.051527208406407,13.970802807410415,13.890772763742756,13.810742720075094,13.73071267640745,13.650682632739795,13.570652589072136,13.49062254540448,13.410592501736831,13.330562458069167,13.250532414401517,13.170502370733864,13.090472327066205,13.010442283398547,12.930412239730899,12.850382196063238,12.770352152395578,12.690322108727926,12.610292065060277,12.530262021392616,12.450231977724963,12.370201934057311,12.29017189038965,12.210141846721996,12.130111803054348,12.050081759386684,11.970051715719023,11.890021672051375,11.809991628383722,11.729961584716065,11.649931541048414,11.569901497380753,11.4898714537131,11.40984141004545,11.329811366377797,11.348993745609421,11.492191653465195,11.635389561320945,11.778587469176719,11.9217853770325,12.06498328488826,12.208181192744025,12.351379100599797,12.494577008455558,12.63777491631132,12.780972824167094,12.924170732022857,13.067368639878618,13.210566547734395,13.353764455590172,13.49696236344592,13.640160271301696,13.78335817915747,13.926556087013232,14.069753994868995,14.212951902724766,14.35614981058053,14.499347718436288,14.642545626292065,14.785743534147846,14.928941442003596,15.07213934985937,15.215337257715142,15.358535165570904,15.501733073426667,15.64493098128244,15.78812888913819,15.931326796993964,16.07452470484974,16.217722612705515,16.360920520561262,16.50411842841704,16.647316336272816,16.790514244128566,16.93371215198434,17.076910059840113,17.220107967695863,17.363305875551642,17.506503783407414,17.64970169126319,17.632442962327783,17.3388425171368,17.045242071945797,16.751641626754843,16.458041181563832,16.16444073637285,15.870840291181885,15.577239845990896,15.284450909656222,14.99418666663316,14.703922423610054,14.41365818058696,14.123393937563845,13.833129694540792,13.542865451517699,13.256193945935529,12.970297344695128,12.684400743454697,12.398504142214248,12.112607540973855,11.830320347234146,11.550241262563437,11.270162177892706,10.99008309322202,10.712505573461296,10.440243877805734,10.167982182150226,9.895720486494655,9.628960883135836,9.364497805314002,9.100034727492103,8.840527924825066,8.583994887863552,8.327461850901994,8.079689691591689,7.832204773744788,7.59126302087609,7.353791128120907,7.122747531901241,6.895667246722854,6.676020965561079,6.45998074988297,6.251303277521686,6.051839723879656,5.861283958183088,5.681182252203337,5.512000524454842,5.353766660591681,5.206252080994896,5.069041701923794,4.941730765629977,4.828945042839848,4.72851679660565,4.63900342399873,4.563096438703814,4.4845732285115885,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[65.51131611107613,65.56182394448058,65.612331777885,65.66283961128946,65.71334744469391,65.76385527809835,65.81436311150279,65.86487094490724,65.91537877831169,65.96588661171612,66.01639444512057,66.066902278525,66.11741011192944,66.1679179453339,66.21842577873835,66.26893361214279,66.31944144554723,66.36994927895167,66.42045711235612,66.47096494576056,66.52147277916501,66.57198061256945,66.62248844597389,66.67299627937834,66.72350411278276,66.77401194618722,66.82451977959167,66.87502761299609,66.92553544640054,66.976043279805,67.02655111320944,67.07705894661387,67.12756678001833,67.17807461342278,67.2285824468272,67.27909028023166,67.3295981136361,67.38010594704053,67.43061378044499,67.48112161384942,67.53162944725386,67.58213728065832,67.63264511406275,67.68315294746719,67.73366078087165,67.78416861427608,67.83467644768052,67.88518428108497,67.93569211448941,67.98619994789385,68.0367077812983,68.08721561470274,68.13772344810718,68.18823128151163,68.23873911491607,68.28924694832051,68.33975478172496,68.3902626151294,68.44077044853385,68.49127828193829,68.54178611534275,68.59229394874718,68.64280178215162,68.69330961555606,68.74381744896051,68.79432528236495,68.84483311576939,68.89534094917383,68.94584878257828,68.99635661598272,69.04686444938717,69.09737228279161,69.14788011619606,69.19838794960049,69.24889578300494,69.29940361640938,69.34991144981383,69.40041928321827,69.45105228848534,69.5018104664376,69.55256864438986,69.60332682234211,69.65408500029436,69.70484317824662,69.74475403114869,69.78249541904073,69.82023680693277,69.85797819482481,69.89571958271685,69.93315209879688,69.96904027408395,70.00492844937105,70.04081662465812,70.07670479994522,70.11259297523229,70.14848115051939,70.18436932580647,70.22025750109356,70.25614567638064,70.29203385166772,70.32792202695481,70.3638102022419,70.39969837752898,70.43558655281606,70.47147472810315,70.50736290339023,70.54325107867732,70.5791392539644,70.61502742925148,70.65091560453857,70.68680377982565,70.72269195511274,70.75858013039982,70.7944683056869,70.83035648097399,70.86624465626107,70.90213283154816,70.93802100683524,70.97390918212233,71.00979735740941,71.0456855326965,71.08157370798358,71.11746188327065,71.15335005855775,71.18923823384483,71.22512640913192,71.261014584419,71.29690275970609,71.33279093499317,71.36867911028025,71.40456728556734,71.44045546085442,71.47634363614151,71.51223181142858,71.54811998671568,71.58400816200275,71.61989633728983,71.65578451257691,71.691672687864,71.72756086315108,71.76344903843818,71.79933721372527,71.83522538901234,71.87111356429942,71.9070017395865,71.94288991487359,71.97877809016069,72.01466626544777,72.05055444073484,72.08644261602194,72.12233079130903,72.15821896659611,72.19410714188318,72.22999531717026,72.26588349245735,72.30177166774443,72.33765984303152,72.3735480183186,72.40943619360569,72.44532436889277,72.48121254417985,72.51710071946694,72.55298889475402,72.58887707004111,72.62476524532819,72.66065342061528,72.69654159590236,72.68842574725085,72.65830788663001,72.62819002600918,72.59807216538836,72.56795430476754,72.5378364441467,72.50771858352589,72.47760066497507,72.42141928995996,72.36523791494483,72.3090565399297,72.2528751649146,72.19669378989947,72.14051241488436,72.08433103986923,72.0281496648541,71.971968289839,71.91578691482387,71.85960553980875,71.80342416479363,71.7472427897785,71.6910614147634,71.63488003974827,71.57869866473314,71.52251728971802,71.46633591470291,71.4101545396878,71.35397316467267,71.29779178965754,71.24161041464242,71.18542903962731,71.1292476646122,71.07306628959705,71.01688491458194,70.96070353956682,70.90452216455171,70.84834078953656,70.79215941452146,70.73597803950634,70.67979666449122,70.6236152894761,70.56743391446098,70.51125253944585,70.45507116443073,70.39888978941562,70.3427084144005,70.28652703938539,70.23034566437026,70.17416428935515,70.11798291434002,70.06180153932489,70.00562016430979,69.94943878929466,69.89325741427953,69.83707603926442,69.7808946642493,69.72471328923419,69.66853191421906,69.61235053920393,69.55616916418882,69.4999877891737,69.44380641415859,69.38762503914346,69.33144366412834,69.27526228911321,69.2190809140981,69.16289953908299,69.10671816406786,69.05053678905273,68.99435541403761,68.9381740390225,68.88199266400738,68.82581128899226,68.76962991397714,68.71344853896201,68.6572671639469,68.60108578893177,68.54490441391665,68.48872303890153,68.43254166388643,68.37636028887128,68.32017891385618,68.26399753884105,67.9171391367257,67.27960370751006,66.6420682782945,66.00453284907894,65.36699741986331,64.72946199064776,64.09192656143219,63.45439113221657,62.816855703000954,62.17932027378545,61.54178484456982,60.9042494153542,60.26671398613864,59.62917855692307,58.991643127707455,58.35410769849189,57.71657226927633,57.0790368400607,56.44150141084514,55.80396598162959,55.16643055241395,54.52889512319834,53.89135969398283,53.25382426476722,52.61628883555158,51.978753406336025,51.341217977120465,50.70368254790485,50.06614711868928,49.42861168947371,48.791076260258095,48.15354083104247,47.516005401826966,46.87846997261135,46.24093454339572,45.603399114180164,44.965863684964596,44.32832825574897,43.69079282653341,43.05325739731784,42.41572196810223,41.778186538886665,41.1406511096711,40.50311568045548,39.865580251239855,39.228044822024344,38.59050939280873,37.95297396359311,37.31543853437755,36.67790310516199,36.04036767594636,35.402832246730796,34.765296817515235,34.12776138829962,33.490225959084,32.85269052986849,32.215155100652865,31.577619671437244,30.94008424222168,30.302548813006116,29.665013383790495,29.027477954574938,28.389942525359373,27.752407096143752,27.114871666928188,26.477336237712624,25.839800808497003,25.20226537928138,24.56472995006588,23.927194520850257,23.289659091634636,22.652123662419072,22.014588233203504,21.377052803987887,20.73951737477232,20.101981945556762,19.46444651634114,18.826911087125573,18.189375657910006,17.55184022869438,16.91430479947876,16.274263833801474,15.627302766338893,15.168914106140281,15.08767026160652,15.00764021793887,14.927610174271212,14.847580130603552,14.767550086935904,14.687520043268245,14.607489999600586,14.527459955932937,14.447429912265278,14.367399868597618,14.287369824929968,14.20733978126231,14.127309737594652,14.047279693927004,13.96724965025935,13.887219606591689,13.807189562924034,13.727159519256388,13.647129475588727,13.567099431921068,13.487069388253417,13.407039344585765,13.327009300918107,13.246979257250452,13.166949213582804,13.086919169915138,13.00688912624749,12.926859082579835,12.846829038912178,12.76679899524452,12.68676895157687,12.60673890790921,12.52670886424155,12.446678820573897,12.366648776906247,12.286618733238587,12.206588689570935,12.126558645903282,12.096134813685234,12.239332721540993,12.382530629396756,12.525728537252533,12.668926445108307,12.812124352964068,12.95532226081983,13.098520168675604,13.241718076531363,13.384915984387131,13.528113892242907,13.671311800098668,13.81450970795443,13.957707615810206,14.100905523665979,14.244103431521726,14.387301339377503,14.530499247233283,14.673697155089043,14.816895062944806,14.960092970800579,15.10329087865634,15.246488786512103,15.389686694367878,15.532884602223639,15.676082510079402,15.819280417935179,15.962478325790956,16.105676233646705,16.24887414150248,16.392072049358255,16.535269957214016,16.678467865069777,16.82166577292555,16.964863680781313,17.108061588637074,17.25125949649285,17.39445740434863,17.537655312204375,17.680853220060154,17.824051127915926,17.967249035771687,18.110446943627448,18.253644851483223,18.396842759338973,18.54004066719475,18.683238575050524,18.8264364829063,18.96963439076205,19.11283229861782,19.207001709923496,18.913401264732535,18.619800819541553,18.326200374350528,18.032599929159588,17.738999483968584,17.44539903877758,17.15179859358658,16.858198148395616,16.56486820632866,16.274603963305577,15.984339720282511,15.694075477259409,15.403811234236304,15.113546991213259,14.823282748190136,14.53301850516705,14.246875343331707,13.960978742091264,13.675082140850826,13.389185539610367,13.103288938370003,12.818326536214832,12.538247451544109,12.258168366873424,11.978089282202717,11.698010197531993,11.420901721159693,11.148640025504115,10.876378329848567,10.604116634192987,10.33467775108322,10.070214673261333,9.805751595439448,9.541288517617616,9.284259852676673,9.027726815715118,8.771193778753604,8.52356524042776,8.276080322580867,8.032709667593402,7.795237774838224,7.559312539683107,7.332232254504684,7.106470905856777,6.888503270325051,6.673850796875409,6.465173324514124,6.265567287576772,6.072942894618521,5.88947956547997,5.717954307920075,5.555265172936737,5.401855527302645,5.257815736822769,5.123002245201409,4.9982485468442786,4.886018072258823,4.784970327389717,4.69398693852534,4.614786691358517,4.540246588599528,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[65.62788234757703,65.67839018098147,65.7288980143859,65.77940584779034,65.8299136811948,65.88042151459925,65.93092934800367,65.98143718140813,66.03194501481258,66.08245284821702,66.13296068162146,66.1834685150259,66.23397634843035,66.28448418183478,66.33499201523924,66.38549984864368,66.43600768204811,66.48651551545257,66.537023348857,66.58753118226144,66.6380390156659,66.68854684907033,66.73905468247477,66.78956251587923,66.84007034928366,66.8905781826881,66.94108601609256,66.991593849497,67.04210168290143,67.09260951630588,67.14311734971032,67.19362518311476,67.24413301651921,67.29464084992367,67.34514868332809,67.39565651673254,67.446164350137,67.49667218354142,67.54718001694587,67.59768785035031,67.64819568375475,67.6987035171592,67.74921135056364,67.79971918396808,67.85022701737253,67.90073485077698,67.95124268418141,68.00175051758586,68.0522583509903,68.10276618439475,68.15327401779919,68.20378185120364,68.25428968460807,68.30479751801252,68.35530535141696,68.40581318482141,68.45632101822585,68.5068288516303,68.55733668503474,68.60784451843918,68.65835235184363,68.70886018524807,68.75936801865251,68.80987585205695,68.8603836854614,68.91089151886584,68.96139935227028,69.01190718567472,69.06241501907917,69.1129228524836,69.16343068588806,69.21393851929251,69.26444635269695,69.31458703610718,69.36454414562854,69.4145012551499,69.46445836467126,69.5144154741926,69.56437258371398,69.61432969323532,69.66428680275668,69.71424391227804,69.7642010217994,69.81415813132074,69.85096689959339,69.8851459996163,69.9193250996392,69.95350419966209,69.987683299685,70.02186239970791,70.05604149973081,70.0902205997537,70.12439969977662,70.15857879979953,70.19275789982242,70.22864607281674,70.26453424810383,70.30042242339091,70.336310598678,70.37219877396508,70.40808694925218,70.44397512453925,70.47986329982633,70.51575147511342,70.55163965040052,70.5875278256876,70.62341600097469,70.65930417626176,70.69519235154885,70.73108052683592,70.76696870212301,70.8028568774101,70.83874505269718,70.87463322798428,70.91052140327135,70.94640957855843,70.98229775384551,71.01818592913261,71.0540741044197,71.08996227970678,71.12585045499387,71.16173863028095,71.19762680556802,71.23351498085512,71.2694031561422,71.30529133142929,71.34117950671636,71.37706768200344,71.41295585729053,71.44884403257761,71.4847322078647,71.5206203831518,71.55650855843886,71.59239673372595,71.62828490901303,71.66417308430012,71.7000612595872,71.7359494348743,71.77183761016138,71.80772578544847,71.84361396073554,71.87950213602262,71.91539031130971,71.95127848659679,71.98716666188388,72.02305483717096,72.05894301245804,72.09483118774513,72.13071936303221,72.1666075383193,72.20249571360638,72.23838388889345,72.27427206418055,72.31016023946765,72.34604841475472,72.38193659004182,72.41782476532887,72.45371294061596,72.48960111590306,72.52548929119014,72.56137746647723,72.59726564176431,72.6331538170514,72.66904199233848,72.70493016762556,72.74081834291265,72.77670651819973,72.7487367492815,72.68883800826062,72.62893926723974,72.56904052621887,72.509141785198,72.44924304417711,72.38934430315624,72.32944556213536,72.26954682111447,72.20964808009359,72.14974933907273,72.08985059805184,72.02995185703097,71.97005311601009,71.9101543749892,71.85025563396833,71.79035689294744,71.73045815192657,71.6705594109057,71.61066066988482,71.55076192886392,71.49086318784306,71.43096444682219,71.3710657058013,71.31116696478043,71.25126822375954,71.19136948273866,71.13147074171778,71.07157200069692,71.01167325967603,70.95177451865514,70.89187577763428,70.8319770366134,70.77207829559251,70.71217955457163,70.65228081355076,70.59238207252989,70.53248333150901,70.47258459048811,70.41268584946724,70.35278710844636,70.29288836742549,70.23298962640462,70.17309088538373,70.11319214436286,70.05329340334197,69.9933946623211,69.93349592130022,69.87359718027933,69.81369843925846,69.75379969823759,69.6939009572167,69.63400221619582,69.57410347517495,69.51420473415406,69.45430599313319,69.3944072521123,69.33450851109143,69.27460977007055,69.21471102904968,69.1548122880288,69.09491354700792,69.03501480598703,68.97511606496616,68.91521732394528,68.85531858292441,68.79541984190352,68.73552110088265,68.67562235986178,68.61572361884089,68.55582487782002,68.49592613679914,68.43602739577825,68.37612865475738,68.31622991373649,68.25633117271562,68.19643243169473,68.13653369067386,68.07663494965298,68.01673620863211,67.95683746761124,67.87829894018978,67.78200823322153,67.4209391442284,66.79509167321037,66.1692442021924,65.54339673117441,64.91445440287762,64.27932236002339,63.644190317169155,63.00905827431486,62.373926231460565,61.73879418860638,61.1036621457521,60.4685301028978,59.83339806004357,59.198266017189326,58.56313397433504,57.9280019314808,57.29286988862657,56.657737845772274,56.02260580291804,55.3874737600638,54.752341717209504,54.117209674355216,53.48207763150104,52.84694558864673,52.21181354579244,51.576681502938214,50.941549460083976,50.30641741722969,49.671285374375444,49.03615333152121,48.40102128866692,47.765889245812616,47.13075720295844,46.49562516010415,45.86049311724986,45.22536107439563,44.590229031541384,43.955096988687096,43.31996494583286,42.68483290297862,42.04970086012433,41.41456881727009,40.779436774415856,40.144304731561554,39.50917268870727,38.87404064585309,38.23890860299879,37.6037765601445,36.968644517290265,36.33351247443603,35.69838043158174,35.0632483887275,34.42811634587327,33.79298430301897,33.157852260164674,32.5227202173105,31.887588174456212,31.25245613160191,30.617324088747683,29.982192045893445,29.347060003039154,28.711927960184905,28.076795917330674,27.44166387447638,26.806531831622145,26.171399788767907,25.536267745913612,24.901135703059325,24.266003660205143,23.630871617350856,22.995739574496554,22.360607531642323,21.725475488788085,21.090343445933794,20.455211403079556,19.82007936022532,19.184947317371027,18.54981527451679,17.91468323166255,17.279551188808263,16.644419145953968,16.00928710309973,15.374155060245494,14.92405701712014,14.844026973452483,14.763996929784833,14.683966886117172,14.603936842449514,14.523906798781866,14.443876755114207,14.363846711446547,14.2838166677789,14.20378662411124,14.12375658044358,14.04372653677593,13.963696493108273,13.883666449440614,13.803636405772965,13.723606362105311,13.643576318437653,13.563546274769998,13.483516231102348,13.40348618743469,13.323456143767029,13.24342610009938,13.163396056431727,13.083366012764067,13.003335969096415,12.923305925428766,12.8432758817611,12.986473789616904,13.129671697472666,13.272869605328445,13.416067513184217,13.559265421039969,13.70246332889574,13.845661236751516,13.988859144607275,14.132057052463038,14.275254960318813,14.418452868174576,14.561650776030337,14.704848683886118,14.848046591741877,14.99124449959764,15.134442407453413,15.277640315309188,15.420838223164951,15.564036131020714,15.707234038876486,15.850431946732247,15.993629854588015,16.13682776244379,16.28002567029955,16.423223578155316,16.566421486011087,16.709619393866863,16.85281730172261,16.996015209578385,17.139213117434167,17.282411025289925,17.42560893314569,17.56880684100146,17.712004748857222,17.855202656712986,17.99840056456876,18.141598472424523,18.284796380280284,18.42799428813606,18.571192195991838,18.714390103847588,18.85758801170336,19.000785919559135,19.1439838274149,19.287181735270657,19.430379643126432,19.573577550982197,19.716775458837954,19.85997336669373,20.00317127454951,20.146369182405262,20.289567090261038,20.43276499811681,20.57596290597257,20.71916081382833,20.4879600123282,20.19435956713726,19.900759121946255,19.607158676755255,19.313558231564247,19.019957786373308,18.726357341182283,18.4327568959913,18.139156450800343,17.845556005609357,17.555021259977984,17.264757016954924,16.974492773931836,16.684228530908733,16.393964287885627,16.103700044862585,15.81343580183946,15.523453341968198,15.237556740727815,14.951660139487357,14.665763538246916,14.379866937006533,14.093970335766095,13.808073734525653,13.526253640524827,13.246174555854084,12.966095471183362,12.686016386512636,12.40593730184197,12.129297868857993,11.857036173202427,11.584774477546906,11.312512781891359,11.04039461903054,10.775931541208692,10.511468463386823,10.247005385564922,9.984524817489753,9.727991780528253,9.4714587435667,9.21492570711068,8.967440789263824,8.719955871416918,8.474156314310655,8.236684421555514,7.999212528800337,7.768797262286531,7.541716977108134,7.318953210620741,7.100985575089007,6.8877208438678394,6.679043371506555,6.479294851273874,6.2846018310539336,6.10113850191539,5.926122328190798,5.758929660646984,5.600301983010198,5.450576174015023,5.309783078970382,5.177778989014422,5.054868159025511,4.94309110167777,4.841697086618316,4.74946231719616,4.667241055740488,4.595919948687465,4.5134728241561195,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[65.73931232202312,65.78982015542755,65.840327988832,65.89083582223644,65.94134365564088,65.99185148904533,66.04235932244977,66.09286715585422,66.14337498925866,66.1938828226631,66.24439065606755,66.29489848947199,66.34540632287644,66.3959141562809,66.44642198968532,66.49692982308977,66.54743765649421,66.59794548989865,66.6484533233031,66.69896115670754,66.74946899011198,66.79997682351643,66.85048465692086,66.90099249032532,66.95150032372975,67.0020081571342,67.05251599053865,67.10302382394309,67.15353165734753,67.20403949075197,67.25454732415642,67.30505515756086,67.3555629909653,67.40607082436975,67.45657865777419,67.50708649117863,67.55759432458308,67.60810215798752,67.65860999139197,67.70911782479641,67.75962565820085,67.8101334916053,67.86064132500974,67.91114915841418,67.96165699181861,68.01216482522307,68.0626726586275,68.11318049203196,68.1636883254364,68.21419615884083,68.26470399224527,68.31521182564973,68.36571965905416,68.41622749245862,68.46673532586306,68.5172431592675,68.56765920491955,68.61761631444091,68.66757342396225,68.71753053348363,68.76748764300497,68.81744475252634,68.86740186204769,68.91735897156904,68.9673160810904,69.01727319061176,69.0672303001331,69.11718740965446,69.16714451917582,69.21710162869718,69.26705873821854,69.3170158477399,69.36697295726124,69.4169300667826,69.46688717630396,69.51684428582531,69.56680139534666,69.61675850486802,69.66671561438937,69.71667272391073,69.76662983343209,69.81658694295345,69.8665440524748,69.91650116199615,69.9533099302688,69.9874890302917,70.02166813031461,70.0558472303375,70.09002633036042,70.12420543038331,70.15838453040622,70.19256363042912,70.22674273045203,70.26092183047493,70.29510093049784,70.32928003052074,70.36345913054365,70.39763823056654,70.43181733058944,70.46599643061235,70.50017553063526,70.53435463065816,70.56853373068105,70.60271283070396,70.63689193072686,70.67107103074977,70.70525013077267,70.73942923079558,70.77360833081849,70.80778743084137,70.84196653086428,70.87700016715834,70.91288834244543,70.94877651773251,70.9846646930196,71.02055286830668,71.05644104359376,71.09232921888085,71.12821739416793,71.16410556945502,71.1999937447421,71.23588192002919,71.27177009531626,71.30765827060335,71.34354644589044,71.37943462117752,71.41532279646461,71.45121097175169,71.48709914703878,71.52298732232586,71.55887549761295,71.59476367290003,71.63065184818711,71.6665400234742,71.70242819876128,71.73831637404837,71.77420454933545,71.81009272462254,71.84598089990962,71.8818690751967,71.91775725048379,71.95364542577087,71.98953360105796,72.02542177634504,72.06130995163213,72.09719812691921,72.1330863022063,72.16897447749338,72.20486265278046,72.24075082806755,72.27663900335463,72.31252717864172,72.3484153539288,72.38430352921588,72.42019170450297,72.45607987979005,72.49196805507714,72.52785623036422,72.56374440565129,72.59963258093839,72.63552075622547,72.67140893151256,72.70729710679964,72.74318528208673,72.77907345737381,72.8149616326609,72.85084980794798,72.82288003902974,72.76298129800887,72.703082556988,72.6431838159671,72.58328507494625,72.52338633392536,72.46348759290449,72.4035888518836,72.34369011086272,72.28379136984185,72.22389262882098,72.16399388780007,72.1040951467792,72.04419640575833,71.98429766473745,71.92439892371658,71.86450018269569,71.8046014416748,71.74470270065393,71.68480395963306,71.62490521861218,71.5650064775913,71.50510773657044,71.44520899554955,71.38531025452866,71.32541151350779,71.26551277248691,71.20561403146604,71.14571529044515,71.08581654942428,71.02591780840339,70.96601906738252,70.90612032636164,70.84622158534076,70.78632284431988,70.726424103299,70.66652536227812,70.60662662125725,70.54672788023636,70.48682913921549,70.4269303981946,70.36703165717373,70.30713291615285,70.24723417513198,70.1873354341111,70.12743669309022,70.06753795206934,70.00763921104846,69.94774047002758,69.8878417290067,69.82794298798582,69.76804424696495,69.70814550594406,69.64824676492319,69.58834802390231,69.52844928288144,69.46855054186055,69.40865180083968,69.3487530598188,69.28885431879792,69.22895557777704,69.16905683675617,69.10827049737598,69.01197979040771,68.91568908343947,68.81939837647121,68.72310766950295,68.6268169625347,68.53052625556646,68.4342355485982,68.33794484162995,68.24165413466169,68.14536342769344,68.04907272072518,67.95278201375693,67.85649130678868,67.76020059982042,67.66390989285216,67.56761918588391,67.47132847891565,67.3750377719474,67.27874706497914,67.1824563580109,66.82138726901776,66.19553979799971,65.56969232698174,64.94384485596377,64.31799738494573,63.69214991392776,63.06630244290978,62.440454971891754,61.81460750087371,61.1887600298558,60.56291255883776,59.93706508781973,59.311217616801756,58.68537014578378,58.059522674765745,57.43367520374777,56.80782773272979,56.18198026171176,55.55613279069378,54.93028531967581,54.30443784865777,53.678590377639736,53.052742906621816,52.42689543560379,51.80104796458575,51.17520049356778,50.549353022549795,49.92350555153176,49.29765808051379,48.67181060949581,48.04596313847778,47.420115667459754,46.794268196441834,46.1684207254238,45.54257325440576,44.916725783387776,44.29087831236981,43.66503084135178,43.0391833703338,42.41333589931582,41.78748842829778,41.16164095727981,40.53579348626184,39.90066144340753,39.265529400553234,38.63039735769906,37.995265314844765,37.36013327199047,36.72500122913624,36.08986918628201,35.454737143427714,34.819605100573476,34.18447305771924,33.54934101486495,32.91420897201065,32.279076929156474,31.643944886302176,31.008812843447885,30.373680800593647,29.738548757739416,29.10341671488512,28.468284672030883,27.83315262917665,27.198020586322354,26.56288854346812,25.92775650061388,25.292624457759587,24.6574924149053,24.022360372051118,23.387228329196827,22.752096286342532,22.116964243488297,21.481832200634056,20.846700157779768,20.211568114925527,19.576436072071296,18.941304029217,18.306171986362767,17.67103994350853,17.035907900654237,16.40077585779994,15.765643814945705,15.130511772091468,14.68041372896611,14.600383685298453,14.520353641630804,14.440323597963145,14.360293554295486,14.280263510627837,14.200233466960178,14.120203423292518,14.040173379624871,13.960143335957211,13.880113292289552,13.800083248621902,13.720053204954244,13.640023161286585,13.733614857692714,13.876812765548477,14.020010673404252,14.163208581260015,14.306406489115776,14.449604396971552,14.592802304827327,14.736000212683088,14.87919812053885,15.022396028394626,15.165593936250389,15.308791844106148,15.451989751961923,15.595187659817688,15.738385567673447,15.881583475529228,16.024781383384997,16.167979291240755,16.311177199096523,16.4543751069523,16.59757301480806,16.74077092266382,16.883968830519596,17.027166738375357,17.17036464623112,17.3135625540869,17.45676046194266,17.599958369798422,17.743156277654197,17.886354185509973,18.029552093365734,18.172750001221498,18.315947909077266,18.45914581693303,18.6023437247888,18.74554163264457,18.888739540500335,19.031937448356093,19.17513535621187,19.318333264067643,19.461531171923394,19.60472907977917,19.747926987634948,19.89112489549071,20.034322803346473,20.177520711202245,20.320718619058006,20.46391652691377,20.607114434769542,20.750312342625303,20.893510250481068,21.036708158336843,21.17990606619262,21.32310397404837,21.466301881904144,21.60949978975992,21.75269769761568,21.89589560547144,22.039093513327213,22.182291421182974,22.062518759923954,21.768918314732954,21.475317869541954,21.18171742435099,20.888116979160007,20.594516533969003,20.30091608877803,20.00731564358704,19.713715198396038,19.420114753205095,19.12651430801409,18.835438556650445,18.545174313627342,18.254910070604275,17.96464582758119,17.674381584558066,17.384117341535024,17.09385309851192,16.803588855488815,16.514134739364373,16.228238138123935,15.942341536883493,15.656444935643052,15.370548334402653,15.084651733162229,14.798755131921789,14.514259829505496,14.234180744834774,13.954101660164065,13.674022575493382,13.393943490822657,13.113864406151915,12.837694016556371,12.565432320900808,12.293170625245246,12.020908929589696,11.748647233934175,11.48164840915604,11.217185331334154,10.952722253512322,10.688259175690435,10.42825674534137,10.171723708379856,9.915190671418301,9.658801255946754,9.411316338099848,9.163831420252992,8.916346502406086,8.67813106827279,8.44065917551766,8.205362270068395,7.978281984889963,7.751201699711565,7.531435515384723,7.313467879852979,7.1015908908603205,6.8929134184989955,6.693022414971006,6.496408527078694,6.312797438350816,6.134290348461528,5.9628943839075035,5.802194309128907,5.648390849721161,5.50213982984287,5.363743622248022,5.233303916831151,5.111487771206726,5.000164131096727,4.89860599800591,4.804937695866968,4.720838457947061,4.646688415851522,4.56914618424406,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[65.8507422964692,65.90125012987366,65.95175796327808,66.00226579668254,66.05277363008697,66.10328146349143,66.15378929689587,66.20429713030032,66.25480496370476,66.3053127971092,66.35582063051365,66.40632846391809,66.45683629732252,66.50734413072698,66.55785196413142,66.60835979753585,66.6588676309403,66.70937546434476,66.75988329774918,66.81039113115364,66.86089896455807,66.91140679796251,66.96191463136697,67.01242246477142,67.06293029817584,67.1134381315803,67.16394596498475,67.21445379838917,67.26496163179362,67.31546946519808,67.3659772986025,67.41648513200695,67.4669929654114,67.51750079881585,67.56800863222028,67.61851646562474,67.66902429902918,67.7195321324336,67.77003996583807,67.82054779924249,67.87068848325326,67.92064559277462,67.97060270229598,68.02055981181734,68.0705169213387,68.12047403086004,68.17043114038141,68.22038824990275,68.27034535942411,68.32030246894547,68.37025957846683,68.42021668798819,68.47017379750953,68.52013090703089,68.57008801655225,68.62004512607359,68.67000223559496,68.71995934511631,68.76991645463767,68.81987356415904,68.86983067368038,68.91978778320174,68.96974489272309,69.01970200224444,69.06965911176582,69.11961622128716,69.16957333080852,69.21953044032988,69.26948754985123,69.31944465937258,69.36940176889394,69.4193588784153,69.46931598793665,69.51927309745801,69.56923020697937,69.61918731650073,69.66914442602207,69.71910153554343,69.76905864506479,69.81901575458613,69.86897286410749,69.91892997362885,69.96888708315021,70.01884419267157,70.0556529609442,70.08983206096711,70.12401116099002,70.15819026101292,70.19236936103582,70.22654846105873,70.26072756108162,70.29490666110453,70.32908576112743,70.36326486115034,70.39744396117324,70.43162306119615,70.46580216121905,70.49998126124196,70.53416036126485,70.56833946128776,70.60251856131066,70.63669766133357,70.67087676135647,70.70505586137938,70.73923496140227,70.77341406142517,70.80759316144808,70.841772261471,70.87595136149389,70.91013046151679,70.9443095615397,70.97848866156261,71.0126677615855,71.0468468616084,71.08102596163131,71.11520506165422,71.14938416167712,71.18356326170002,71.21774236172293,71.25192146174582,71.28610056176872,71.32027966179163,71.35445876181454,71.38863786183744,71.42281696186033,71.45699606188325,71.49117516190616,71.52535426192905,71.56124243678703,71.5971306120741,71.6330187873612,71.66890696264828,71.70479513793536,71.74068331322243,71.77657148850952,71.8124596637966,71.84834783908369,71.88423601437077,71.92012418965786,71.95601236494494,71.99190054023204,72.02778871551911,72.0636768908062,72.09956506609328,72.13545324138038,72.17134141666745,72.20722959195453,72.24311776724161,72.2790059425287,72.3148941178158,72.35078229310287,72.38667046838995,72.42255864367704,72.45844681896412,72.4943349942512,72.53022316953829,72.56611134482539,72.60199952011246,72.63788769539954,72.67377587068663,72.70966404597371,72.7455522212608,72.78144039654788,72.81732857183496,72.85321674712205,72.88910492240913,72.92499309769622,72.89702332877799,72.83712458775712,72.77722584673623,72.71732710571536,72.65742836469448,72.5975296236736,72.53763088265272,72.47773214163185,72.41783340061096,72.35793465959009,72.29803591856921,72.23813717754834,72.17823843652745,72.11833969550658,72.0584409544857,71.99854221346482,71.93864347244394,71.87874473142307,71.81884599040218,71.7589472493813,71.69904850836042,71.63914976733955,71.57925102631867,71.51935228529778,71.45945354427691,71.39955480325602,71.33965606223515,71.27975732121428,71.2198585801934,71.15995983917253,71.10006109815164,71.04016235713077,70.9802636161099,70.920364875089,70.86046613406812,70.80056739304725,70.74066865202637,70.6807699110055,70.6208711699846,70.56097242896374,70.50107368794285,70.44117494692198,70.3812762059011,70.32137746488021,70.2419513475939,70.14566064062565,70.0493699336574,69.95307922668914,69.85678851972088,69.76049781275262,69.66420710578436,69.56791639881612,69.47162569184786,69.3753349848796,69.27904427791135,69.1827535709431,69.08646286397484,68.9901721570066,68.89388145003835,68.79759074307009,68.70130003610186,68.60500932913358,68.50871862216533,68.41242791519707,68.31613720822882,68.21984650126056,68.12355579429232,68.02726508732405,67.9309743803558,67.83468367338756,67.7383929664193,67.64210225945104,67.54581155248279,67.44952084551454,67.35323013854628,67.25693943157802,67.16064872460979,67.06435801764152,66.96806731067326,66.87177660370503,66.77548589673677,66.6791951897685,66.58290448280025,66.22183539380711,65.59598792278908,64.9701404517711,64.34429298075312,63.71844550973509,63.092598038717114,62.46675056769914,61.8409030966811,61.21505562566307,60.589208154645156,59.96336068362712,59.33751321260908,58.711665741591105,58.08581827057313,57.4599707995551,56.834123328537125,56.20827585751915,55.582428386501114,54.956580915483144,54.33073344446517,53.704885973447126,53.0790385024291,52.45319103141118,51.827343560393146,51.20149608937511,50.575648618357135,49.94980114733916,49.323953676321125,48.69810620530315,48.07225873428517,47.44641126326714,46.820563792249104,46.19471632123119,45.56886885021315,44.943021379195116,44.31717390817714,43.69132643715916,43.06547896614113,42.43963149512316,41.813784024105175,41.18793655308714,40.562089082069164,39.93624161105119,39.310394140033154,38.68454666901512,38.0586991979972,37.43285172697917,36.80700425596113,36.181156784943155,35.55530931392518,34.929461842907145,34.30361437188917,33.6777669008712,33.051919429853164,32.42607195883513,31.80022448781721,31.174377016799177,30.548529545781143,29.922682074763166,29.29683460374519,28.670987132727156,28.045139661709186,27.41929219069121,26.793444719673168,26.16759724865519,25.541749777637214,24.915902306619188,24.290054835601154,23.664207364583234,23.0383598935652,22.412512422547167,21.78666495152919,21.160817480511213,20.53497000949318,19.909122538475206,19.28327506745723,18.657427596439195,18.03158012542122,17.405732654403238,16.779885183385204,16.15403771236717,15.522000526791675,14.886868483937441,14.436770440812083,14.480755925768523,14.623953833624286,14.767151741480065,14.910349649335828,15.05354755719159,15.19674546504736,15.339943372903136,15.483141280758883,15.62633918861466,15.76953709647044,15.912735004326203,16.055932912181962,16.199130820037738,16.342328727893502,16.48552663574926,16.62872454360504,16.771922451460803,16.91512035931656,17.05831826717234,17.201516175028114,17.344714082883872,17.487911990739637,17.631109898595412,17.774307806451173,17.917505714306934,18.06070362216271,18.20390153001847,18.347099437874235,18.490297345730013,18.63349525358578,18.776693161441536,18.919891069297307,19.063088977153082,19.206286885008847,19.349484792864605,19.492682700720383,19.635880608576144,19.779078516431905,19.922276424287684,20.065474332143445,20.20867223999921,20.35187014785498,20.495068055710757,20.63826596356652,20.781463871422282,20.924661779278054,21.067859687133815,21.211057594989583,21.35425550284536,21.49745341070112,21.64065131855688,21.783849226412656,21.927047134268427,22.070245042124178,22.213442949979953,22.356640857835735,22.499838765691496,22.643036673547257,22.78623458140303,22.929432489258794,23.07263039711455,23.21582830497033,23.35902621282609,23.502224120681852,23.645422028537627,23.63707750751965,23.343477062328713,23.049876617137706,22.756276171946702,22.46267572675573,22.169075281564762,21.875474836373737,21.581874391182765,21.28827394599179,20.99467350080079,20.70107305560979,20.407472610418825,20.11585585332288,19.825591610299796,19.535327367276707,19.24506312425363,18.954798881230545,18.66453463820748,18.374270395184375,18.084006152161272,17.79374190913817,17.504816136760514,17.218919535520055,16.93302293427963,16.647126333039232,16.361229731798808,16.07533313055835,15.789436529317967,15.503539928077528,15.22218693381546,14.942107849144737,14.662028764474051,14.381949679803345,14.10187059513262,13.821791510461935,13.54609016425471,13.273828468599149,13.00156677294364,12.729305077288078,12.457043381632513,12.187365277103439,11.922902199281538,11.658439121459667,11.393976043637766,11.129512965815934,10.871988673192975,10.615455636231422,10.358922599269908,10.102676804782838,9.85519188693592,9.607706969089064,9.360222051242157,9.1195777149901,8.882105822234934,8.644633929479793,8.414846992671828,8.187766707493395,7.961885455680419,7.7439178201486945,7.52595018461696,7.315460937852759,7.106783465491434,6.906749978668122,6.710136090775857,6.524456374786243,6.342458368732258,6.1710624041782385,6.005858796839164,5.846837305428699,5.69647971643212,5.553703485670747,5.417704165525638,5.28882884464785,5.168107383387969,5.057237160515697,4.955514909393484,4.8605092861676145,4.7748874305521,4.697990548270131,4.624819544332,4.542372419800655,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[65.9621722709153,66.01268010431974,66.06318793772418,66.11369577112863,66.16420360453307,66.21471143793752,66.26521927134196,66.3157271047464,66.36623493815085,66.41674277155529,66.46725060495974,66.51775843836418,66.56826627176862,66.61877410517307,66.66928193857751,66.71978977198195,66.77029760538639,66.82080543879084,66.87131327219528,66.92182110559973,66.97232893900417,67.02283677240861,67.07334460581306,67.12376065206563,67.17371776158699,67.22367487110836,67.2736319806297,67.32358909015106,67.37354619967242,67.42350330919378,67.47346041871512,67.52341752823648,67.57337463775784,67.6233317472792,67.67328885680055,67.72324596632191,67.77320307584326,67.82316018536461,67.87311729488597,67.92307440440733,67.97303151392867,68.02298862345003,68.07294573297139,68.12290284249275,68.17285995201411,68.22281706153545,68.27277417105682,68.32273128057817,68.37268839009953,68.42264549962088,68.47260260914223,68.5225597186636,68.57251682818494,68.6224739377063,68.67243104722766,68.72238815674902,68.77234526627038,68.82230237579174,68.87225948531308,68.92221659483445,68.97217370435578,69.02213081387715,69.0720879233985,69.12204503291986,69.17200214244122,69.22195925196257,69.27191636148393,69.32187347100529,69.37183058052665,69.42178769004799,69.47174479956936,69.52170190909072,69.57165901861205,69.62161612813343,69.67157323765477,69.72153034717613,69.77148745669749,69.82144456621884,69.8714016757402,69.92135878526155,69.97131589478292,70.02127300430426,70.0712301138256,70.12118722334698,70.15799599161961,70.19217509164253,70.22635419166542,70.26053329168832,70.29471239171123,70.32889149173413,70.36307059175704,70.39724969177993,70.43142879180284,70.46560789182574,70.49978699184865,70.53396609187155,70.56814519189446,70.60232429191736,70.63650339194027,70.67068249196316,70.70486159198607,70.73904069200898,70.77321979203188,70.80739889205478,70.84157799207767,70.87575709210059,70.9099361921235,70.94411529214639,70.9782943921693,71.0124734921922,71.04665259221511,71.08083169223801,71.11501079226092,71.14918989228381,71.18336899230671,71.21754809232962,71.25172719235252,71.28590629237543,71.32008539239834,71.35426449242124,71.38844359244413,71.42262269246704,71.45680179248996,71.49098089251285,71.52515999253575,71.55933909255866,71.59351819258156,71.62769729260447,71.66187639262736,71.69605549265027,71.73023459267317,71.76441369269608,71.79859279271898,71.83277189274189,71.86695099276479,71.9011300927877,71.93530919281059,71.9694882928335,72.00366739285639,72.0378464928793,72.07202559290221,72.1062046929251,72.140383792948,72.17456289297093,72.2095965311286,72.2454847064157,72.28137288170277,72.31726105698986,72.35314923227695,72.38903740756403,72.42492558285112,72.4608137581382,72.49670193342527,72.53259010871237,72.56847828399945,72.60436645928654,72.64025463457362,72.6761428098607,72.71203098514779,72.74791916043486,72.78380733572195,72.81969551100903,72.85558368629611,72.8914718615832,72.92736003687028,72.96324821215737,72.99913638744447,72.97116661852624,72.91126787750537,72.85136913648448,72.7914703954636,72.73157165444272,72.67167291342184,72.61177417240097,72.5518754313801,72.49197669035921,72.43207794933834,72.37217920831745,72.31228046729657,72.2523817262757,72.19248298525481,72.13258424423394,72.07268550321305,72.01278676219218,71.9528880211713,71.89298928015043,71.83309053912954,71.77319179810867,71.7132930570878,71.65339431606691,71.59349557504603,71.53359683402516,71.47192290478007,71.37563219781183,71.27934149084356,71.18305078387532,71.08676007690705,70.99046936993881,70.89417866297055,70.7978879560023,70.70159724903405,70.60530654206579,70.50901583509753,70.41272512812928,70.31643442116103,70.22014371419277,70.12385300722451,70.02756230025626,69.93127159328802,69.83498088631976,69.73869017935151,69.64239947238326,69.546108765415,69.44981805844675,69.35352735147849,69.25723664451023,69.16094593754198,69.06465523057372,68.96836452360547,68.87207381663723,68.77578310966896,68.67949240270072,68.58320169573247,68.48691098876421,68.39062028179596,68.2943295748277,68.19803886785944,68.10174816089119,68.00545745392293,67.9091667469547,67.81287603998643,67.71658533301817,67.62029462604993,67.52400391908168,67.42771321211342,67.33142250514517,67.23513179817692,67.13884109120866,67.0425503842404,66.94625967727214,66.84996897030389,66.75367826333564,66.65738755636738,66.56109684939912,66.46480614243087,66.36851543546263,66.27222472849436,66.1759340215261,66.07964331455786,65.98335260758961,65.62228351859646,64.99643604757843,64.37058857656046,63.74474110554249,63.118893634524454,62.49304616350648,61.8671986924885,61.24135122147047,60.61550375045243,59.98965627943451,59.36380880841648,58.737961337398445,58.11211386638047,57.48626639536249,56.86041892434445,56.23457145332648,55.608723982308504,54.98287651129046,54.3570290402725,53.73118156925452,53.10533409823648,52.47948662721845,51.85363915620053,51.227791685182495,50.60194421416447,49.976096743146485,49.350249272128515,48.72440180111048,48.0985543300925,47.47270685907453,46.846859388056494,46.22101191703845,45.59516444602055,44.969316975002506,44.34346950398447,43.7176220329665,43.09177456194852,42.46592709093049,41.840079619912515,41.21423214889453,40.5883846778765,39.96253720685852,39.336689735840544,38.71084226482251,38.08499479380448,37.459147322786556,36.83236615728484,36.20448152950947,35.576596901734156,34.94871227395885,34.320827646183474,33.692943018408165,33.065058390632856,32.4371737628575,31.809289135082125,31.181404507306873,30.553519879531507,29.92563525175614,29.297750623980825,28.669865996205516,28.04198136843015,27.41409674065484,26.786212112879532,26.158327485104166,25.53044285732885,24.90255822955354,24.274673601778176,23.64678897400281,23.018904346227554,22.391019718452185,21.76313509067682,21.1330091142414,20.50126512388769,19.869521133533922,19.23777714318021,18.6060331528265,17.971627223720994,17.335890325321014,16.69823989979082,16.373480256690467,16.516678164546246,16.65987607240201,16.803073980257768,16.94627188811354,17.089469795969304,17.23266770382506,17.375865611680844,17.519063519536605,17.66226142739237,17.805459335248138,17.948657243103916,18.09185515095966,18.23505305881544,18.378250966671217,18.52144887452698,18.664646782382743,18.807844690238515,18.95104259809428,19.09424050595004,19.237438413805815,19.38063632166158,19.523834229517337,19.667032137373116,19.81023004522889,19.953427953084653,20.096625860940414,20.23982376879619,20.38302167665195,20.52621958450771,20.669417492363486,20.81261540021925,20.95581330807501,21.09901121593079,21.242209123786562,21.385407031642316,21.528604939498084,21.67180284735386,21.815000755209624,21.958198663065385,22.10139657092116,22.24459447877692,22.387792386632682,22.53099029448846,22.674188202344222,22.817386110199983,22.960584018055762,23.103781925911534,23.2469798337673,23.39017774162306,23.533375649478828,23.676573557334592,23.81977146519036,23.962969373046136,24.106167280901893,24.249365188757658,24.392563096613436,24.535761004469208,24.678958912324955,24.822156820180734,24.96535472803651,25.108552635892273,25.211636255115405,24.918035809924405,24.624435364733408,24.330834919542433,24.037234474351436,23.74363402916046,23.45003358396949,23.15643313877849,22.862832693587485,22.569232248396546,22.275631803205542,21.982031358014538,21.688430912823566,21.396273149995345,21.106008906972235,20.815744663949182,20.525480420926087,20.23521617790298,19.94495193487988,19.654687691856836,19.36442344883371,19.074159205810624,18.783894962787535,18.49549753415663,18.209600932916207,17.923704331675808,17.637807730435366,17.351911129194928,17.066014527954504,16.780117926714105,16.494221325473646,16.21019312279613,15.93011403812548,15.650034953454739,15.369955868784015,15.089876784113333,14.809797699442624,14.529718614771898,14.254486311953036,13.982224616297541,13.709962920641964,13.437701224986418,13.165439529330893,12.893177833675331,12.62861906722888,12.364155989407035,12.099692911585164,11.835229833763265,11.572253638006131,11.31572060104459,11.059187564083038,10.802654527121472,10.54655235361891,10.299067435772004,10.051582517925098,9.80409760007823,9.561024361707421,9.323552468952244,9.086080576197103,8.851412000453692,8.624331715275261,8.397251430096837,8.174367760444401,7.956400124912667,7.738432489380932,7.529330984845206,7.32065351248388,7.120477542365239,6.9238636544729735,6.736115311221676,6.552651982083095,6.379230424448996,6.209523284549423,6.04912344532106,5.894926172139662,5.746463922863009,5.605267141498592,5.471664708803252,5.3443537724645696,5.224726995569181,5.114310189934654,5.012423820781077,4.916962816951695,4.828936403157124,4.750444912652108,4.6795119258351745,4.598045779888595,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[66.0736022453614,66.12411007876584,66.17461791217028,66.22512574557473,66.27563357897917,66.32614141238362,66.37664924578806,66.42678993039935,66.47674703992072,66.52670414944208,66.57666125896343,66.62661836848478,66.67657547800614,66.7265325875275,66.77648969704885,66.8264468065702,66.87640391609156,66.92636102561292,66.97631813513426,67.02627524465564,67.07623235417698,67.12618946369834,67.1761465732197,67.22610368274105,67.27606079226241,67.32601790178376,67.37597501130512,67.42593212082647,67.47588923034783,67.52584633986918,67.57580344939055,67.62576055891189,67.67571766843325,67.72567477795461,67.77563188747595,67.82558899699731,67.87554610651867,67.92550321604003,67.97546032556139,68.02541743508274,68.07537454460409,68.12533165412546,68.17528876364682,68.22524587316816,68.27520298268952,68.32516009221087,68.37511720173224,68.42507431125358,68.47503142077494,68.5249885302963,68.57494563981766,68.62490274933901,68.67485985886036,68.72481696838172,68.77477407790307,68.82473118742442,68.87468829694579,68.92464540646714,68.9746025159885,69.02455962550985,69.07451673503121,69.12447384455257,69.17443095407391,69.22438806359527,69.27434517311663,69.32430228263799,69.37425939215935,69.42421650168069,69.47417361120206,69.5241307207234,69.57408783024476,69.62404493976612,69.67400204928748,69.72395915880884,69.7739162683302,69.82387337785154,69.8738304873729,69.92378759689426,69.97374470641562,70.02370181593696,70.07365892545832,70.12361603497968,70.17357314450103,70.22353025402238,70.26033902229503,70.29451812231794,70.32869722234084,70.36287632236375,70.39705542238664,70.43123452240954,70.46541362243245,70.49959272245536,70.53377182247826,70.56795092250115,70.60213002252407,70.63630912254696,70.67048822256987,70.70466732259277,70.7388464226157,70.77302552263859,70.80720462266149,70.84138372268438,70.87556282270731,70.9097419227302,70.9439210227531,70.978100122776,71.01227922279891,71.0464583228218,71.08063742284472,71.11481652286761,71.14899562289052,71.18317472291344,71.21735382293633,71.25153292295923,71.28571202298214,71.31989112300504,71.35407022302795,71.38824932305084,71.42242842307375,71.45660752309665,71.49078662311956,71.52496572314246,71.55914482316537,71.59332392318827,71.62750302321118,71.66168212323407,71.69586122325697,71.73004032327988,71.76421942330279,71.79839852332569,71.83257762334858,71.8667567233715,71.9009358233944,71.9351149234173,71.9692940234402,72.0034731234631,72.037652223486,72.07183132350892,72.10601042353181,72.14018952355472,72.17436862357762,72.20854772360053,72.24272682362343,72.27690592364632,72.31108502366924,72.34526412369215,72.37944322371504,72.41362232373794,72.44780142376085,72.48198052378376,72.51615962380666,72.55033872382957,72.58451782385247,72.61869692387536,72.65287602389827,72.68705512392118,72.72123422394408,72.75541332396698,72.78959242398989,72.82377152401278,72.85795062547021,72.8938388007573,72.92972697604438,72.96561515133146,73.00150332661855,73.03739150190563,73.0732796771927,73.04530990827449,72.9854111672536,72.92551242623274,72.86561368521184,72.80571494419097,72.7458162031701,72.68591746214922,72.60560375499797,72.50931304802971,72.41302234106146,72.3167316340932,72.22044092712495,72.12415022015671,72.02785951318845,71.9315688062202,71.83527809925195,71.7389873922837,71.64269668531544,71.54640597834718,71.45011527137893,71.35382456441069,71.25753385744241,71.16124315047418,71.0649524435059,70.96866173653765,70.87237102956941,70.77608032260115,70.6797896156329,70.58349890866464,70.48720820169639,70.39091749472814,70.29462678775988,70.19833608079163,70.10204537382337,70.00575466685513,69.90946395988686,69.81317325291862,69.71688254595037,69.62059183898212,69.52430113201386,69.42801042504561,69.33171971807735,69.23542901110909,69.13913830414083,69.04284759717258,68.94655689020433,68.85026618323609,68.75397547626783,68.65768476929958,68.56139406233132,68.46510335536306,68.36881264839482,68.27252194142656,68.1762312344583,68.07994052749004,67.98364982052179,67.88735911355354,67.79106840658528,67.69477769961703,67.59848699264877,67.50219628568053,67.40590557871228,67.30961487174402,67.21332416477577,67.11703345780752,67.02074275083926,66.92445204387101,66.82816133690275,66.73187062993449,66.63557992296624,66.53928921599798,66.44299850902974,66.34670780206147,66.25041709509323,66.15412638812496,66.05783568115672,65.96154497418846,65.86525426722021,65.76896356025196,65.67267285328371,65.57638214631545,65.4800914393472,65.38380073237894,65.0227316433858,64.39688417236776,63.77103670134979,63.145189230331816,62.51934175931378,61.893494288295805,61.26764681727783,60.63978341476536,60.01189878699,59.38401415921475,58.756129531439385,58.12824490366401,57.50036027588871,56.872475648113394,56.24459102033802,55.61670639256272,54.98882176478742,54.360937137012044,53.73305250923673,53.10516788146141,52.47728325368605,51.84939862591068,51.22151399813543,50.59362937036007,49.965744742584704,49.337860114809395,48.70997548703407,48.08209085925871,47.454206231483404,46.82632160370809,46.19843697593272,45.57055234815735,44.94266772038211,44.31478309260674,43.68689846483137,43.059013837056064,42.431129209280755,41.80324458150538,41.17535995373007,40.547475325954764,39.91959069817939,39.291706070404096,38.66382144262877,38.03593681485341,37.40805218707804,36.78016755930279,36.152282931527424,35.52439830375206,34.89651367597675,34.26862904820143,33.64074442042607,33.01285979265075,32.38497516487545,31.757090537100083,31.129205909324714,30.50132128154946,29.873436653774085,29.245552025998723,28.615266899916467,27.983522909562755,27.351778919208986,26.720034928855277,26.088290938501565,25.456546948147796,24.824802957794088,24.193058967440372,23.561314977086603,22.929570986732838,22.295929132566215,21.660192234166175,21.024455335766135,20.388718437366155,19.75251059326897,19.113397757011995,18.474284920755075,18.409402495468278,18.552600403324046,18.695798311179807,18.838996219035568,18.982194126891347,19.12539203474713,19.26858994260289,19.411787850458655,19.554985758314423,19.698183666170184,19.84138157402595,19.984579481881728,20.127777389737492,20.27097529759325,20.414173205449025,20.557371113304796,20.700569021160543,20.843766929016322,20.9869648368721,21.130162744727862,21.273360652583623,21.416558560439398,21.55975646829516,21.702954376150924,21.8461522840067,21.98935019186246,22.13254809971822,22.275746007574,22.41894391542977,22.562141823285536,22.705339731141297,22.848537638997072,22.991735546852833,23.134933454708595,23.27813136256437,23.421329270420134,23.564527178275892,23.707725086131674,23.850922993987446,23.9941209018432,24.137318809698968,24.280516717554747,24.423714625410504,24.56691253326627,24.71011044112204,24.853308348977805,24.99650625683357,25.139704164689345,25.282902072545106,25.42609998040087,25.569297888256642,25.71249579611242,25.855693703968175,25.99889161182394,26.142089519679715,26.28528742753548,26.42848533539124,26.57168324324702,26.71488115110278,26.492594557520107,26.198994112329128,25.9053936671381,25.61179322194716,25.318192776756156,25.02459233156516,24.730991886374184,24.437391441183212,24.143790995992212,23.850190550801212,23.556590105610248,23.26298966041924,22.96938921522827,22.676690446667767,22.386426203644668,22.096161960621565,21.805897717598498,21.515633474575413,21.225369231552285,20.935104988529215,20.64484074550614,20.354576502483035,20.06431225945998,19.774048016436886,19.48617893155274,19.2002823303123,18.914385729071917,18.62848912783148,18.342592526591034,18.056695925350624,17.770799324110197,17.484902722869773,17.19900612162937,16.918120227106122,16.638041142435398,16.35796205776466,16.077882973094006,15.797803888423283,15.517724803752543,15.237645719081891,14.962882459651404,14.690620763995858,14.418359068340333,14.146097372684755,13.873835677029208,13.60157398137363,13.334335935176242,13.069872857354369,12.80540977953247,12.540946701710638,12.276483623888753,12.015985565857672,11.759452528896158,11.50291949193462,11.246386454973067,10.990427902454961,10.742942984608067,10.495458066761149,10.247973148914255,10.002471008424713,9.764999115669536,9.527527222914358,9.290055330159229,9.060896723057107,8.833816437878685,8.606736152700286,8.386850065208364,8.168882429676621,7.951878504198914,7.74320103183763,7.534523559476295,7.33420510606234,7.137591218170075,6.9477742476570885,6.764310918518508,6.587398444719719,6.416002480165689,6.252787933031307,6.09337262784722,5.943015038850641,5.798027578690846,5.658445542572224,5.525625252080885,5.399878700281265,5.281346607750393,5.171383219353618,5.0693327321686485,4.973416347735756,4.884116663356576,4.8028992770340935,4.730280392999215,4.653719139976531,4.571272015445188,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[66.17590726063412,66.22484797162568,66.27378868261725,66.32272939360882,66.37167010460038,66.42061081559194,66.46955152658352,66.51849223757509,66.56743294856665,66.61637365955822,66.6653143705498,66.71510208127866,66.76505919080003,66.81501630032137,66.86497340984273,66.91493051936408,66.96488762888544,67.0148447384068,67.06480184792815,67.11475895744951,67.16471606697087,67.21467317649221,67.26463028601357,67.31458739553493,67.36454450505629,67.41450161457765,67.46445872409899,67.51441583362035,67.5643729431417,67.61433005266306,67.66428716218442,67.71424427170578,67.76420138122714,67.81415849074848,67.86411560026984,67.9140727097912,67.96402981931256,68.0139869288339,68.06394403835526,68.11390114787662,68.16385825739798,68.21381536691933,68.26377247644069,68.31372958596205,68.36368669548341,68.41364380500475,68.46360091452611,68.51355802404746,68.56351513356881,68.61347224309017,68.66342935261153,68.71338646213289,68.76334357165425,68.81330068117559,68.86325779069696,68.9132149002183,68.96317200973967,69.01312911926102,69.06308622878237,69.11304333830374,69.16300044782508,69.21295755734644,69.2629146668678,69.31287177638914,69.36282888591052,69.41278599543188,69.46274310495322,69.51270021447459,69.56265732399594,69.61261443351728,69.66257154303865,69.71252865256,69.76248576208135,69.81244287160271,69.86239998112407,69.91235709064543,69.96231420016679,70.01227130968813,70.06222841920949,70.11218552873085,70.1621426382522,70.21209974777355,70.26205685729491,70.31201396681627,70.34882273508892,70.38300183511181,70.41718093513472,70.45136003515762,70.48553913518052,70.51971823520343,70.55389733522634,70.58807643524923,70.62225553527213,70.65643463529504,70.69061373531795,70.72479283534085,70.75897193536376,70.79315103538664,70.82733013540957,70.86150923543246,70.89568833545538,70.92986743547827,70.96404653550118,70.99822563552408,71.03240473554698,71.06658383556989,71.1007629355928,71.1349420356157,71.16912113563859,71.2033002356615,71.2374793356844,71.27165843570731,71.3058375357302,71.3400166357531,71.37419573577601,71.40837483579892,71.44255393582182,71.47673303584472,71.51091213586764,71.54509123589052,71.57927033591344,71.61344943593633,71.64762853595924,71.68180763598215,71.71598673600505,71.75016583602795,71.78434493605086,71.81852403607377,71.85270313609666,71.88688223611956,71.92106133614246,71.95524043616538,71.98941953618828,72.02359863621118,72.05777773623409,72.09195683625698,72.1261359362799,72.16031503630279,72.19449413632569,72.2286732363486,72.2628523363715,72.2970314363944,72.3312105364173,72.36538963644021,72.39956873646311,72.43374783648602,72.46792693650892,72.50210603653181,72.53628513655474,72.57046423657765,72.60464333660053,72.63882243662344,72.67300153664635,72.70718063666924,72.74135973669215,72.77553883671506,72.80971793673797,72.84273987431057,72.87553037781518,72.9083208813198,72.94111138482441,72.97390188832904,73.00669239183367,73.03948289533827,73.0722733988429,73.10506390234752,73.13785440585214,73.06049691376022,72.92806542387007,72.79563393397991,72.66320244408973,72.53077095419958,72.39833946430942,72.26590797441926,72.1334764845291,72.00104499463895,71.86861350474878,71.73618201485861,71.60375052496845,71.47229010790446,71.37578719711607,71.27928428632768,71.18278137553929,71.08627846475089,70.9897755539625,70.89327264317413,70.79676973238573,70.70026682159735,70.60376391080895,70.50726100002058,70.41075808923217,70.31425517844379,70.2177522676554,70.12124935686701,70.02474644607862,69.92824353529022,69.83174062450183,69.73523771371345,69.63873480292506,69.54223189213667,69.44572898134828,69.3492260705599,69.2527231597715,69.15622024898312,69.05971733819473,68.96321442740634,68.86671151661794,68.77020860582955,68.67370569504118,68.57720278425278,68.48069987346439,68.384196962676,68.28769405188763,68.19119114109922,68.09468823031084,67.99818531952245,67.90168240873405,67.80517949794566,67.70867658715727,67.61217367636888,67.5156707655805,67.41916785479211,67.32266494400372,67.22616203321533,67.12965912242694,67.03315621163856,66.93665330085015,66.84015039006178,66.74364747927339,66.64714456848499,66.5506416576966,66.45413874690823,66.35763583611983,66.26113292533142,66.16463001454305,66.06812710375465,65.97162419296626,65.87512128217789,65.77861837138948,65.6821154606011,65.58561254981271,65.48910963902432,65.39260672823593,65.29610381744754,65.19960090665916,65.10309799587077,65.00659508508238,64.91009217429398,64.8135892635056,64.7170863527172,64.35489258343533,63.72700795565996,63.099123327884655,62.47123870010934,61.84335407233397,61.215469444558664,60.58758481678336,59.95970018900798,59.33181556123262,58.70393093345736,58.076046305682006,57.44816167790663,56.82027705013132,56.19239242235601,55.564507794580635,54.93662316680534,54.30873853903002,53.68085391125465,53.05296928347934,52.42508465570403,51.79720002792867,51.169315400153295,50.54143077237805,49.913546144602684,49.28566151682732,48.65777688905201,48.02989226127669,47.40200763350133,46.77412300572601,46.14623837795071,45.518353750175336,44.89046912239997,44.262584494624726,43.634699866849346,43.00681523907398,42.37893061129868,41.751045983523355,41.123161355747996,40.49527672797269,39.86739210019738,39.239507472422005,38.611622844646696,37.98373821687139,37.35585358909602,36.727968961320656,36.097524685591615,35.46578069523785,34.83403670488407,34.202292714530365,33.57054872417666,32.93880473382288,32.30706074346917,31.675316753115464,31.043572762761695,30.41182877240793,29.780084782054274,29.148340791700505,28.516596801346736,27.884852810993024,27.253108820639316,26.620231041411344,25.98449414301136,25.34875724461138,24.713020346211344,24.077283447811364,23.441546549411385,22.805809651011348,22.16766845049017,21.528555614233312,20.88944277797633,20.302126826390243,20.445324734246007,20.588522642101765,20.73172054995755,20.87491845781331,21.01811636566907,21.161314273524837,21.3045121813806,21.447710089236356,21.590907997092142,21.734105904947917,21.87730381280368,22.020501720659443,22.163699628515214,22.306897536370975,22.450095444226736,22.59329335208252,22.73649125993828,22.87968916779404,23.022887075649813,23.166084983505588,23.309282891361335,23.45248079921711,23.59567870707289,23.738876614928653,23.882074522784414,24.02527243064019,24.16847033849595,24.311668246351715,24.45486615420749,24.59806406206325,24.741261969919012,24.884459877774788,25.027657785630563,25.170855693486324,25.314053601342085,25.457251509197864,25.60044941705362,25.743647324909386,25.886845232765165,26.030043140620922,26.173241048476683,26.316438956332465,26.459636864188234,26.60283477204399,26.746032679899763,26.889230587755534,27.032428495611295,27.175626403467056,27.31882431132283,27.462022219178596,27.605220127034357,27.748418034890136,27.891615942745894,28.034813850601658,28.178011758457437,28.06715330511582,27.77355285992485,27.479952414733837,27.186351969542834,26.892751524351862,26.599151079160908,26.305550633969887,26.011950188778933,25.718349743587943,25.42474929839696,25.131148853205936,24.837548408014996,24.543947962823992,24.250347517632996,23.957107743340195,23.666843500317103,23.376579257293997,23.086315014270923,22.79605077124787,22.505786528224764,22.215522285201672,21.925258042178598,21.634993799155495,21.344729556132386,21.054465313109326,20.76420107008624,20.476860328948877,20.190963727708464,19.905067126468037,19.61917052522761,19.333273923987186,19.047377322746772,18.76148072150633,18.475584120265893,18.189687519025508,17.906126416086796,17.626047331416085,17.34596824674537,17.06588916207468,16.785810077403955,16.505730992733287,16.225651908062563,15.945572823391839,15.671278607349763,15.399016911694222,15.126755216038674,14.854493520383096,14.58223182472759,14.309970129072028,14.040052803123572,13.775589725301755,13.511126647479854,13.246663569657981,12.982200491836084,12.717737414014252,12.459717493709292,12.203184456747726,11.946651419786223,11.690118382824673,11.434303451290996,11.18681853344414,10.939333615597223,10.691848697750327,10.444363779903458,10.206445762386846,9.968973869631668,9.731501976876492,9.497461730838983,9.27038144566055,9.043301160482116,8.81730000550406,8.599332369972336,8.381364734440602,8.165748551191395,7.957071078830069,7.748393606468742,7.547932669759457,7.351318781867192,7.159433184092515,6.975969854953934,6.795566464990449,6.624170500436424,6.456452420741565,6.29605258151323,6.141461494558179,5.991103905561601,5.849591234518725,5.7124060858498655,5.580401995849015,5.455403628097964,5.337966219931633,5.228456248772575,5.126241643556222,5.029869878519839,4.939592042027384,4.8567224645004305,4.7811944051817585,4.709392500064488,4.626945375533129,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[66.2725278735828,66.32146858457438,66.37040929556593,66.41935000655751,66.46829071754907,66.51723142854064,66.5661721395322,66.61511285052377,66.66405356151533,66.7129942725069,66.76193498349848,66.81087569449004,66.85981640548161,66.90875711647317,66.95769782746474,67.0066385384563,67.05557924944787,67.10451996043943,67.153460671431,67.20240138242258,67.25134209341415,67.30028280440571,67.34922351539728,67.39816422638884,67.44710493738042,67.49604564837198,67.54498635936355,67.59426587065983,67.64422298018118,67.69418008970254,67.74413719922389,67.79409430874524,67.84405141826662,67.89400852778796,67.94396563730932,67.99392274683068,68.04387985635204,68.09383696587338,68.14379407539474,68.1937511849161,68.24370829443745,68.2936654039588,68.34362251348016,68.39357962300153,68.44353673252287,68.49349384204422,68.54345095156559,68.59340806108693,68.64336517060829,68.69332228012965,68.74327938965101,68.79323649917237,68.84319360869371,68.89315071821507,68.94310782773643,68.99306493725778,69.04302204677914,69.0929791563005,69.14293626582185,69.1928933753432,69.24285048486456,69.29280759438592,69.34276470390728,69.39272181342864,69.44267892295,69.49263603247134,69.5425931419927,69.59255025151406,69.64250736103541,69.69246447055677,69.74242158007812,69.79237868959947,69.84233579912083,69.89229290864219,69.94225001816355,69.9922071276849,70.04216423720626,70.09212134672761,70.14207845624897,70.19203556577033,70.24199267529167,70.29194978481303,70.34190689433439,70.39186400385574,70.42867277212838,70.46285187215129,70.49703097217419,70.5312100721971,70.56538917222001,70.5995682722429,70.6337473722658,70.66792647228871,70.70210557231161,70.73628467233452,70.77046377235743,70.80464287238033,70.83882197240322,70.87300107242613,70.90718017244905,70.94135927247194,70.97553837249484,71.00971747251774,71.04389657254066,71.07807567256356,71.11225477258645,71.14643387260935,71.18061297263226,71.21479207265517,71.24897117267807,71.28315027270096,71.31732937272388,71.35150847274679,71.38568757276968,71.41986667279258,71.45404577281548,71.4882248728384,71.5224039728613,71.5565830728842,71.5907621729071,71.62494127293,71.65912037295291,71.69329947297581,71.7274785729987,71.76165767302163,71.79583677304453,71.83001587306742,71.86419497309033,71.89837407311325,71.93255317313613,71.96673227315904,72.00091137318195,72.03509047320486,72.06926957322774,72.10344867325065,72.13762777327356,72.17180687329646,72.20598597331936,72.24016507334227,72.27434417336518,72.30852327338808,72.34223950899072,72.37503001249533,72.40782051599994,72.44061101950457,72.47340152300919,72.5061920265138,72.53898253001842,72.57177303352304,72.60456353702766,72.63735404053229,72.6701445440369,72.70293504754152,72.73572555104613,72.76851605455074,72.80130655805537,72.83409706155999,72.8668875650646,72.89967806856922,72.93246857207384,72.96525907557846,72.99804957908307,73.0308400825877,73.06363058609232,73.09642108959693,73.12921159310156,73.16200209660617,73.19479260011079,73.1174351080189,72.98500361812873,72.85257212823856,72.7201406383484,72.58770914845825,72.45527765856808,72.32284616867793,72.19041467878776,72.0579831888976,71.92555169900744,71.79312020911728,71.66068871922711,71.52825722933696,71.39582573944679,71.26339424955663,71.13096275966647,70.99853126977631,70.86609977988614,70.73366828999598,70.60123680010582,70.46880531021566,70.3363738203255,70.20394233043534,70.07151084054517,69.93907935065502,69.80664786076485,69.67421637087469,69.54178488098454,69.40935339109436,69.2769219012042,69.14449041131405,69.01205892142389,68.87962743153372,68.7656457555909,68.66914284480251,68.5726399340141,68.47613702322573,68.37963411243734,68.28313120164896,68.18662829086055,68.09012538007217,67.99362246928378,67.89711955849539,67.800616647707,67.70411373691861,67.60761082613023,67.51110791534184,67.41460500455345,67.31810209376505,67.22159918297666,67.12509627218827,67.02859336139988,66.9320904506115,66.83558753982311,66.73908462903472,66.64258171824633,66.54607880745795,66.44957589666956,66.35307298588116,66.25657007509277,66.16006716430438,66.063564253516,65.9670613427276,65.87055843193923,65.77405552115083,65.67755261036244,65.58104969957405,65.48454678878566,65.38804387799726,65.29154096720887,65.1950380564205,65.0985351456321,65.00203223484371,64.90552932405532,64.80902641326693,64.71252350247855,64.61602059169016,64.51951768090177,64.42301477011338,64.326511859325,64.2300089485366,64.1335060377482,64.0370031269598,63.674809357677944,63.04692472990257,62.41904010212727,61.79115547435195,61.16327084657659,60.53538621880127,59.90750159102597,59.2796169632506,58.65173233547523,58.02384770769997,57.395963079924606,56.76807845214925,56.14019382437393,55.512309196598615,54.88442456882325,54.25653994104795,53.62865531327263,53.00077068549727,52.372886057721956,51.74500142994664,51.11711680217128,50.48923217439591,49.861347546620664,49.2334629188453,48.60557829106993,47.97769366329462,47.34980903551929,46.72192440774394,46.094039779968625,45.46615515219332,44.83827052441795,44.210385896642585,43.579782471266704,42.948038480912935,42.316294490559166,41.68455050020546,41.05280650985175,40.42106251949798,39.78931852914427,39.157574538790556,38.52583054843679,37.894086558083075,37.262342567729355,36.6305985773756,35.99885458702183,35.36711059666818,34.73536660631441,34.10362261596064,33.47187862560693,32.84013463525322,32.20839064489944,31.576646654545733,30.944532950256587,30.308796051856547,29.673059153456506,29.037322255056587,28.401585356656554,27.765848458256514,27.13011155985653,26.494374661456554,25.858637763056517,25.221939143968406,24.582826307711485,23.943713471454508,23.304600635197588,22.665487798940674,22.33804906516795,22.48124697302372,22.624444880879473,22.76764278873525,22.910840696591027,23.05403860444678,23.197236512302545,23.340434420158324,23.48363232801409,23.626830235869853,23.770028143725614,23.913226051581375,24.05642395943714,24.199621867292922,24.3428197751487,24.486017683004466,24.629215590860223,24.772413498715995,24.915611406571756,25.058809314427517,25.2020072222833,25.345205130139057,25.48840303799482,25.63160094585059,25.77479885370637,25.917996761562115,26.06119466941789,26.20439257727367,26.347590485129434,26.490788392985195,26.63398630084097,26.777184208696735,26.920382116552492,27.063580024408267,27.206777932264032,27.349975840119793,27.49317374797557,27.636371655831347,27.7795695636871,27.922767471542866,28.06596537939864,28.209163287254405,28.352361195110166,28.49555910296594,28.638757010821703,28.781954918677467,28.925152826533246,29.068350734389014,29.211548642244768,29.354746550100536,29.497944457956315,29.641142365812076,29.64171205271156,29.348111607520536,29.054511162329582,28.760910717138614,28.467310271947607,28.17370982675664,27.880109381565624,27.586508936374663,27.29290849118366,26.99930804599269,26.705707600801674,26.41210715561067,26.118506710419698,25.824906265228744,25.531305820037723,25.237705374846772,24.947260796989582,24.656996553966458,24.366732310943352,24.07646806792029,23.786203824897225,23.4959395818741,23.205675338851023,22.915411095827935,22.625146852804832,22.334882609781754,22.044618366758698,21.754354123735595,21.467541726345043,21.181645125104616,20.895748523864192,20.609851922623747,20.32395532138333,20.038058720142907,19.75216211890247,19.466265517662055,19.180368916421628,18.8944723151812,18.614053520396787,18.333974435726077,18.053895351055367,17.773816266384625,17.49373718171398,17.213658097043236,16.933579012372526,16.653499927701816,16.379674755048125,16.10741305939256,15.835151363737053,15.562889668081489,15.290627972425911,15.01836627677038,14.746104581114842,14.481306593249084,14.216843515427215,13.952380437605367,13.687917359783494,13.423454281961583,13.159982458522435,12.903449421560882,12.64691638459933,12.390383347637803,12.133850310676287,11.87817900012708,11.630694082280163,11.383209164433307,11.135724246586388,10.888239328739495,10.647892409104157,10.41042051634898,10.172948623593815,9.935476730838673,9.706946453442415,9.479866168263982,9.252785883085549,9.029782310268054,8.8118146747363,8.593847039204576,8.379618598183841,8.170941125822516,7.962263653461182,7.76166023345662,7.565046345564316,7.371092120527941,7.187628791389353,7.004165462250816,6.832338520707147,6.660942556153129,6.499717069223482,6.339907950265717,6.189550361269143,6.042351671710982,5.90115489034657,5.766366629127477,5.6359269236657425,5.510928555914692,5.394585832112849,5.285529278191532,5.183150554943817,5.086323409303903,4.9950674206981915,4.910771437105472,4.8336487695637365,4.763103902982868,4.682618735621083,4.600171611089723,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[66.3691484865315,66.41808919752307,66.46702990851463,66.5159706195062,66.56491133049776,66.61385204148934,66.6627927524809,66.71173346347247,66.76067417446403,66.8096148854556,66.85855559644718,66.90749630743873,66.95643701843031,67.00537772942187,67.05431844041344,67.10325915140501,67.15219986239657,67.20114057338814,67.2500812843797,67.29902199537128,67.34796270636284,67.39690341735441,67.44584412834598,67.49478483933754,67.54372555032911,67.59266626132069,67.64160697231225,67.6905476833038,67.73948839429538,67.78842910528695,67.83736981627851,67.88631052727008,67.93525123826166,67.98419194925322,68.03313266024479,68.08207337123635,68.13101408222792,68.1799547932195,68.22889550421107,68.27783621520263,68.32677692619419,68.37571763718576,68.42465834817732,68.4735990591689,68.52338676956236,68.57334387908371,68.62330098860507,68.67325809812642,68.72321520764777,68.77317231716913,68.8231294266905,68.87308653621184,68.9230436457332,68.97300075525456,69.02295786477592,69.07291497429726,69.12287208381862,69.17282919333998,69.22278630286134,69.2727434123827,69.32270052190404,69.3726576314254,69.42261474094676,69.47257185046811,69.52252895998947,69.57248606951083,69.62244317903217,69.67240028855355,69.72235739807489,69.77231450759625,69.82227161711761,69.87222872663897,69.92218583616031,69.97214294568167,70.02210005520303,70.07205716472438,70.12201427424574,70.17197138376709,70.22192849328846,70.2718856028098,70.32184271233116,70.37179982185252,70.42175693137386,70.47171404089522,70.50852280916787,70.54270190919078,70.57688100921368,70.61106010923658,70.64523920925949,70.6794183092824,70.7135974093053,70.74777650932819,70.7819556093511,70.816134709374,70.85031380939691,70.8844929094198,70.91867200944272,70.95285110946561,70.98703020948852,71.02120930951142,71.05538840953433,71.08956750955724,71.12374660958014,71.15792570960303,71.19210480962593,71.22628390964884,71.26046300967175,71.29464210969465,71.32882120971756,71.36300030974046,71.39717940976335,71.43135850978626,71.46553760980918,71.49971670983207,71.53389580985497,71.56807490987788,71.60225400990078,71.63643310992367,71.6706122099466,71.70479130996948,71.73897040999239,71.7731495100153,71.8073286100382,71.8415077100611,71.87452964717548,71.90732015068009,71.94011065418472,71.97290115768934,72.00569166119394,72.03848216469858,72.07127266820318,72.1040631717078,72.13685367521244,72.16964417871704,72.20243468222166,72.23522518572628,72.2680156892309,72.30080619273551,72.33359669624014,72.36638719974475,72.39917770324936,72.43196820675398,72.4647587102586,72.49754921376322,72.53033971726785,72.56313022077246,72.59592072427708,72.62871122778171,72.66150173128631,72.69429223479094,72.72708273829556,72.75987324180018,72.7926637453048,72.82545424880941,72.85824475231402,72.89103525581864,72.92382575932326,72.95661626282788,72.98940676633251,73.02219726983712,73.05498777334174,73.08777827684636,73.12056878035098,73.1533592838556,73.18614978736022,73.21894029086482,73.25173079436945,73.17437330227754,73.04194181238739,72.90951032249723,72.77707883260706,72.64464734271691,72.51221585282673,72.37978436293658,72.24735287304642,72.11492138315626,71.9824898932661,71.85005840337594,71.71762691348577,71.58519542359562,71.45276393370546,71.32033244381529,71.18790095392512,71.05546946403497,70.92303797414479,70.79060648425464,70.65817499436449,70.52574350447432,70.39331201458415,70.26088052469402,70.12844903480384,69.99601754491368,69.86358605502352,69.73115456513335,69.5987230752432,69.46629158535302,69.33386009546288,69.2014286055727,69.06899711568255,68.9365656257924,68.80413413590222,68.67170264601206,68.5392711561219,68.40683966623175,68.27440817634158,68.14197668645141,68.00954519656126,67.8771137066711,67.74468221678094,67.61225072689078,67.47981923700061,67.34738774711045,67.2149562572203,67.08252476733014,66.95009327743998,66.81766178754981,66.68523029765964,66.55279880776948,66.42036731787934,66.28793582798916,66.15550433809899,66.0590014032773,65.96249849248892,65.86599558170053,65.76949267091213,65.67298976012374,65.57648684933535,65.47998393854697,65.38348102775859,65.28697811697019,65.1904752061818,65.09397229539341,64.99746938460503,64.90096647381664,64.80446356302824,64.70796065223985,64.61145774145147,64.51495483066307,64.41845191987468,64.3219490090863,64.22544609829791,64.12894318750952,64.03244027672113,63.93593736593273,63.83943445514435,63.74293154435596,63.64642863356758,63.549925722779186,63.45342281199079,63.3569199012024,62.99472613192053,62.36684150414516,61.738956876369855,61.11107224859454,60.48318762081917,59.855302993043864,59.227418365268555,58.599533737493175,57.971649109717816,57.34376448194256,56.715879854167206,56.08799522639184,55.46011059861652,54.8322259708412,54.204341343065835,53.57645671529054,52.94857208751523,52.32068745973986,51.69280283196454,51.06204025694177,50.430296266588,49.798552276234226,49.166808285880585,48.53506429552681,47.90332030517304,47.271576314819335,46.63983232446562,46.00808833411185,45.376344343758134,44.74460035340443,44.11285636305066,43.48111237269689,42.84936838234323,42.21762439198947,41.58588040163569,40.95413641128199,40.322392420928274,39.69064843057451,39.0589044402208,38.42716044986708,37.79541645951332,37.16367246915961,36.53192847880589,35.90018448845213,35.268440498098364,34.63309796070176,33.99736106230173,33.361624163901695,32.72588726550171,32.09015036710173,31.4544134687017,30.818676570301708,30.182939671901735,29.547202773501695,28.911465875101655,28.275728976701732,27.637097001189638,26.99798416493266,26.35887132867574,25.719758492418816,25.080645656161842,24.44153281990492,24.37397130394576,24.517169211801523,24.660367119657284,24.80356502751305,24.94676293536883,25.089960843224596,25.23315875108035,25.37635665893613,25.519554566791903,25.66275247464766,25.805950382503422,25.949148290359208,26.09234619821497,26.23554410607073,26.378742013926495,26.521939921782256,26.665137829638017,26.8083357374938,26.951533645349578,27.094731553205342,27.2379294610611,27.38112736891687,27.524325276772636,27.667523184628394,27.810721092484176,27.953919000339937,28.097116908195698,28.24031481605147,28.38351272390725,28.52671063176299,28.669908539618767,28.813106447474546,28.95630435533031,29.099502263186075,29.24270017104185,29.385898078897608,29.529095986753372,29.672293894609147,29.815491802464912,29.95868971032067,30.101887618176445,30.24508552603222,30.388283433887985,30.531481341743746,30.67467924959952,30.817877157455282,30.961075065311043,31.104272973166818,31.21627080030727,30.92267035511624,30.62906990992528,30.335469464734278,30.041869019543295,29.74826857435229,29.45466812916133,29.161067683970334,28.867467238779366,28.57386679358834,28.28026634839739,27.98666590320642,27.69306545801541,27.399465012824447,27.105864567633432,26.81226412244247,26.518663677251464,26.227678093661964,25.937413850638904,25.647149607615802,25.356885364592706,25.066621121569614,24.77635687854655,24.486092635523455,24.19582839250038,23.905564149477257,23.615299906454155,23.32503566343109,23.034771420408028,22.7445071773849,22.458223123741135,22.172326522500743,21.886429921260262,21.600533320019874,21.31463671877944,21.028740117539023,20.742843516298606,20.45694691505818,20.171050313817755,19.885153712577313,19.602059709377464,19.321980624706732,19.04190154003601,18.7618224553653,18.48174337069462,18.201664286023878,17.921585201353203,17.641506116682486,17.36142703201178,17.08807090274644,16.815809207090933,16.54354751143537,16.271285815779805,15.99902412012424,15.72676242446872,15.454500728813157,15.187023461196446,14.922560383374588,14.658097305552703,14.39363422773079,14.129171149908956,13.86470807208707,13.603714386374007,13.347181349412478,13.090648312450924,12.834115275489372,12.577582238527857,12.322054548963145,12.074569631116216,11.827084713269308,11.579599795422451,11.332114877575556,11.089339055821423,10.851867163066293,10.614395270311116,10.376923377555928,10.143511461224271,9.916431176045839,9.689350890867406,9.46227060568902,9.242264615032,9.024296979500281,8.806329343968528,8.593488645176265,8.384811172814938,8.176133700453612,7.975387797153715,7.77877390926141,7.582751056963355,7.399287727824811,7.215824398686229,7.040506540977871,6.869110576423847,6.70338155693374,6.542981717705372,6.387996816976666,6.237639227980116,6.093915327538829,5.95314746289645,5.820327172405114,5.691451851482438,5.567089928391938,5.451205444294084,5.3426023076105,5.240059466331388,5.142776940087963,5.050542799369008,4.964820409710492,4.886103133945706,4.813872370146925,4.738292095709019,4.655844971177659,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[66.4657690994802,66.51470981047176,66.56365052146333,66.61259123245489,66.66153194344646,66.71047265443804,66.7594133654296,66.80835407642115,66.85729478741274,66.9062354984043,66.95517620939587,67.00411692038743,67.053057631379,67.10199834237056,67.15093905336214,67.19987976435371,67.24882047534527,67.29776118633683,67.34670189732842,67.39564260831997,67.44458331931153,67.4935240303031,67.54246474129468,67.59140545228624,67.64034616327781,67.68928687426937,67.73822758526094,67.7871682962525,67.83610900724408,67.88504971823565,67.93399042922721,67.98293114021877,68.03187185121034,68.08081256220191,68.12975327319349,68.17869398418505,68.22763469517662,68.27657540616818,68.32551611715975,68.37445682815132,68.42339753914288,68.47233825013446,68.52127896112601,68.57021967211759,68.61916038310915,68.66810109410072,68.7170418050923,68.76598251608387,68.81492322707543,68.863863938067,68.91280464905856,68.96174536005012,69.01068607104169,69.05962678203325,69.10856749302482,69.1575082040164,69.20644891500795,69.25538962599953,69.30433033699109,69.35327104798266,69.40255055894353,69.45250766846488,69.50246477798623,69.55242188750759,69.60237899702895,69.65233610655031,69.70229321607167,69.75225032559301,69.80220743511437,69.85216454463573,69.90212165415709,69.95207876367844,70.00203587319979,70.05199298272115,70.1019500922425,70.15190720176386,70.20186431128522,70.25182142080658,70.30177853032794,70.35173563984928,70.40169274937064,70.451649858892,70.50160696841334,70.5515640779347,70.58837284620735,70.62255194623026,70.65673104625316,70.69091014627605,70.72508924629896,70.75926834632186,70.79344744634477,70.82762654636767,70.86180564639058,70.89598474641348,70.93016384643639,70.96434294645928,70.9985220464822,71.03270114650509,71.066880246528,71.10105934655091,71.13523844657381,71.1694175465967,71.20359664661962,71.23777574664251,71.27195484666542,71.30613394668832,71.34031304671123,71.37402928185561,71.40681978536023,71.43961028886486,71.47240079236947,71.50519129587408,71.5379817993787,71.57077230288334,71.60356280638794,71.63635330989257,71.66914381339718,71.70193431690181,71.73472482040643,71.76751532391104,71.80030582741566,71.83309633092028,71.8658868344249,71.89867733792951,71.93146784143413,71.96425834493874,71.99704884844338,72.02983935194798,72.06262985545261,72.09542035895723,72.12821086246184,72.16100136596647,72.19379186947108,72.2265823729757,72.25937287648031,72.29216337998493,72.32495388348954,72.35774438699417,72.3905348904988,72.42332539400341,72.45611589750803,72.48890640101264,72.52169690451726,72.55448740802188,72.58727791152651,72.62006841503111,72.65285891853574,72.68564942204036,72.71843992554497,72.7512304290496,72.7840209325542,72.81681143605884,72.84960193956346,72.88239244306807,72.91518294657268,72.94797345007731,72.98076395358191,73.01355445708654,73.04634496059116,73.07913546409577,73.1119259676004,73.144716471105,73.17750697460964,73.21029747811426,73.24308798161887,73.27587848512349,73.30866898862811,73.23131149653621,73.09888000664604,72.96644851675588,72.83401702686572,72.70158553697556,72.5691540470854,72.43672255719524,72.30429106730507,72.17185957741492,72.03942808752475,71.90699659763459,71.77456510774444,71.64213361785427,71.50970212796412,71.37727063807395,71.24483914818379,71.11240765829362,70.97997616840345,70.8475446785133,70.71511318862315,70.58268169873297,70.45025020884282,70.31781871895265,70.18538722906248,70.05295573917233,69.92052424928217,69.78809275939201,69.65566126950185,69.52322977961168,69.39079828972153,69.25836679983136,69.12593530994121,68.99350382005105,68.86107233016088,68.72864084027071,68.59620935038055,68.4637778604904,68.33134637060024,68.19891488071008,68.06648339081991,67.93405190092976,67.8016204110396,67.66918892114944,67.53675743125928,67.40432594136911,67.27189445147894,67.13946296158879,67.00703147169862,66.87459998180847,66.7421684919183,66.60973700202814,66.47730551213799,66.34487402224782,66.21244253235766,66.0800110424675,65.94757955257735,65.81514806268719,65.68271657279702,65.55028508290685,65.41785359301669,65.28542210312654,65.15299061323637,65.02055912334622,64.88812763345605,64.7556961435659,64.62326465367573,64.49083316378557,64.3584016738954,64.22597018400523,64.09353869411508,63.96110720422492,63.828675714334764,63.6962442244446,63.56381273455443,63.448859961752134,63.35235705096375,63.255854140175344,63.159351229386964,63.062848318598576,62.96634540781019,62.8698424970218,62.773339586233405,62.67683667544501,62.31464290616314,61.686758278387764,61.05887365061247,60.43098902283715,59.80310439506179,59.17521976728647,58.54429804261686,57.91255405226308,57.28081006190933,56.64906607155568,56.01732208120189,55.38557809084813,54.75383410049442,54.12209011014072,53.49034611978694,52.85860212943324,52.226858139079525,51.59511414872575,50.96337015837203,50.33162616801833,49.69988217766456,49.06813818731078,48.43639419695714,47.80465020660338,47.1729062162496,46.54116222589589,45.90941823554218,45.27767424518841,44.645930254834695,44.01418626448099,43.38244227412722,42.750698283773445,42.11895429341979,41.48721030306603,40.85546631271225,40.223722322358554,39.591978332004835,38.95739986954689,38.321662971146914,37.68592607274694,37.0501891743469,36.41445227594692,35.778715377546945,35.1429784791469,34.507241580746864,33.871504682346945,33.235767783946905,32.60003088554687,31.96429398714689,31.328557088746912,30.691367694667818,30.052254858410897,29.413142022153984,28.774029185897,28.134916349640022,27.49580351338316,26.85669067712618,26.266695634867723,26.409893542723488,26.553091450579245,26.69628935843503,26.83948726629079,26.982685174146553,27.125883082002318,27.269080989858082,27.412278897713836,27.55547680556962,27.698674713425387,27.841872621281144,27.985070529136923,28.128268436992695,28.271466344848456,28.414664252704217,28.55786216056,28.70106006841576,28.84425797627152,28.987455884127286,29.130653791983047,29.27385169983881,29.417049607694594,29.56024751555037,29.703445423406134,29.846643331261895,29.989841239117663,30.133039146973427,30.276237054829192,30.419434962684967,30.56263287054073,30.705830778396493,30.84902868625226,30.99222659410804,31.135424501963787,31.278622409819558,31.421820317675344,31.565018225531105,31.708216133386866,31.85141404124264,31.994611949098402,32.13780985695416,32.28100776480994,32.42420567266571,32.567403580521464,32.710601488377236,32.497229102712,32.203628657520966,31.910028212330012,31.616427767139008,31.322827321948054,31.029226876757065,30.73562643156606,30.442025986375107,30.14842554118407,29.854825095993114,29.56122465080211,29.26762420561113,28.974023760420128,28.680423315229163,28.38682287003817,28.093222424847202,27.799621979656177,27.508095390334397,27.217831147311344,26.92756690428824,26.63730266126515,26.347038418242086,26.056774175218948,25.76650993219588,25.476245689172792,25.185981446149732,24.89571720312663,24.605452960103534,24.31518871708044,24.024924474057375,23.734801122377693,23.448904521137266,23.16300791989686,22.877111318656418,22.591214717416037,22.30531811617556,22.019421514935118,21.733524913694726,21.44762831245433,21.161731711213854,20.875835109973465,20.590065898358162,20.309986813687438,20.029907729016728,19.749828644346014,19.469749559675286,19.189670475004597,18.909591390333897,18.62951230566317,18.34943322099245,18.069354136321735,17.79646705044482,17.524205354789288,17.251943659133737,16.979681963478185,16.707420267822624,16.43515857216706,16.162896876511553,15.892740329143804,15.628277251321919,15.363814173500044,15.099351095678173,14.834888017856287,14.570424940034453,14.305961862212595,14.047446314225583,13.790913277264028,13.534380240302529,13.277847203340974,13.02131416637945,12.765930097799215,12.518445179952288,12.270960262105378,12.023475344258522,11.77599042641164,11.530785702538731,11.293313809783555,11.055841917028426,10.818370024273227,10.580898131518072,10.352996183827704,10.125915898649271,9.898835613470839,9.672714555327705,9.45474691979597,9.236779284264252,9.018811648732544,8.807358692168703,8.598681219807377,8.39000374744605,8.189115360850831,7.9925014729585415,7.795887585066238,7.610946664260236,7.427483335121655,7.248674561248599,7.077278596694609,6.907046044643998,6.7466462054156295,6.586443272684203,6.436085683687654,6.28667576473109,6.145478983366674,6.007108006174089,5.874287715682728,5.746976779299137,5.623709540573168,5.507825056475292,5.3996753370294535,5.296968377718975,5.199230470872045,5.106018178039822,5.01886938231552,4.938557498448778,4.864640837310965,4.793965455796959,4.711518331265615,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[66.56238971242888,66.61133042342044,66.660271134412,66.70921184540357,66.75815255639515,66.8070932673867,66.85603397837828,66.90497468936984,66.95391540036141,67.00285611135298,67.05179682234456,67.10073753333612,67.14967824432767,67.19861895531925,67.24755966631082,67.29650037730238,67.34544108829395,67.39438179928551,67.44332251027708,67.49226322126864,67.54120393226022,67.59014464325179,67.63908535424335,67.68802606523492,67.7369667762265,67.78590748721805,67.83484819820963,67.88378890920119,67.93272962019276,67.98167033118432,68.03061104217589,68.07955175316746,68.12849246415902,68.1774331751506,68.22637388614217,68.27531459713373,68.32425530812529,68.37319601911688,68.42213673010843,68.4710774411,68.52001815209157,68.56895886308314,68.6178995740747,68.66684028506627,68.71578099605783,68.7647217070494,68.81366241804096,68.86260312903254,68.91154384002411,68.96048455101567,69.00942526200724,69.0583659729988,69.10730668399037,69.15624739498193,69.2051881059735,69.25412881696508,69.30306952795664,69.35201023894821,69.40095094993978,69.44989166093134,69.4988323719229,69.54777308291447,69.59671379390605,69.6456545048976,69.69459521588918,69.74353592688075,69.79247663787231,69.84141734886389,69.89035805985544,69.93929877084702,69.98823948183858,70.03718019283015,70.08612090382171,70.13506161481328,70.18400232580485,70.23294303679643,70.28188374778799,70.33167145784606,70.3816285673674,70.43158567688876,70.48154278641013,70.53149989593147,70.58145700545282,70.63141411497418,70.66822288324683,70.70240198326974,70.73658108329263,70.77076018331555,70.80493928333844,70.83911838336134,70.87329748338425,70.90631942004039,70.939109923545,70.97190042704962,71.00469093055423,71.03748143405886,71.07027193756348,71.10306244106809,71.1358529445727,71.16864344807733,71.20143395158195,71.23422445508656,71.26701495859118,71.2998054620958,71.33259596560042,71.36538646910503,71.39817697260966,71.43096747611426,71.46375797961889,71.4965484831235,71.52933898662812,71.56212949013275,71.59491999363736,71.62771049714199,71.6605010006466,71.69329150415122,71.72608200765583,71.75887251116046,71.79166301466508,71.82445351816969,71.85724402167432,71.89003452517893,71.92282502868355,71.95561553218816,71.98840603569279,72.0211965391974,72.05398704270203,72.08677754620663,72.11956804971126,72.15235855321589,72.1851490567205,72.21793956022512,72.25073006372973,72.28352056723435,72.31631107073898,72.3491015742436,72.3818920777482,72.41468258125283,72.44747308475745,72.48026358826206,72.51305409176669,72.54584459527129,72.57863509877592,72.61142560228055,72.64421610578516,72.67700660928978,72.7097971127944,72.74258761629902,72.77537811980363,72.80816862330826,72.84095912681288,72.87374963031749,72.90654013382209,72.93933063732672,72.97212114083133,73.00491164433595,73.03770214784058,73.07049265134519,73.1032831548498,73.13607365835443,73.16886416185905,73.20165466536368,73.23444516886829,73.2672356723729,73.30002617587753,73.33281667938213,73.36560718288676,73.28824969079487,73.1558182009047,73.02338671101454,72.89095522112437,72.75852373123422,72.62609224134405,72.4936607514539,72.36122926156374,72.22879777167357,72.09636628178342,71.96393479189325,71.83150330200309,71.69907181211293,71.56664032222277,71.4342088323326,71.30177734244245,71.16934585255228,71.03691436266212,70.90448287277195,70.77205138288178,70.63961989299165,70.50718840310148,70.37475691321131,70.24232542332115,70.10989393343098,69.97746244354083,69.84503095365068,69.71259946376051,69.58016797387035,69.4477364839802,69.31530499409003,69.18287350419986,69.0504420143097,68.91801052441954,68.78557903452939,68.65314754463921,68.51241719257476,68.37064950866976,68.22888182476478,68.08711414085978,67.94534645695481,67.80357877304981,67.66181108914482,67.52004340523982,67.37827572133483,67.23650803742983,67.09474035352484,66.95297266961985,66.81120498571487,66.66943730180986,66.52766961790488,66.38590193399989,66.2441342500949,66.1023665661899,65.96059888228493,65.81883119837993,65.67706351447494,65.53529583056995,65.39352814666495,65.25176046275996,65.10999277885497,64.96822509494997,64.826457411045,64.68468972713998,64.54292204323501,64.40115435933002,64.25938667542503,64.11761899152003,63.97585130761503,63.83408362371005,63.692315939805056,63.55054825590007,63.408780571995074,63.26701288809008,63.12524520418509,62.983477520280104,62.8417098363751,62.699942152470115,62.55817446856512,62.41640678466014,62.274639100755145,62.13287141685015,61.991103732945156,61.60434789581579,60.97260390546204,60.34085991510833,59.70911592475461,59.07737193440084,58.44562794404714,57.81388395369343,57.182139963339644,56.55039597298589,55.918651982632234,55.28690799227845,54.65516400192469,54.023420011570984,53.39167602121728,52.7599320308635,52.128188040509784,51.49644405015608,50.86470005980231,50.23295606944859,49.60121207909489,48.969468088741124,48.33772409838734,47.7059801080337,47.07423611767994,46.44249212732616,45.81074813697245,45.17900414661874,44.54726015626497,43.91551616591126,43.28170177839214,42.64596487999209,42.01022798159207,41.37449108319215,40.738754184792114,40.103017286392074,39.46728038799208,38.831543489592114,38.19580659119207,37.56006969279209,36.924332794392114,36.288595895992074,35.6528589975921,35.01712209919212,34.38138520079208,33.745638388146,33.106525551889135,32.46741271563216,31.828299879375177,31.189187043118253,30.550074206861343,29.910961370604355,29.27184853434744,28.632735698090528,28.302617873645428,28.445815781501192,28.589013689356953,28.73221159721272,28.8754095050685,29.018607412924265,29.161805320780022,29.305003228635808,29.44820113649157,29.591399044347327,29.734596952203095,29.877794860058856,30.020992767914613,30.1641906757704,30.30738858362617,30.45058649148192,30.5937843993377,30.73698230719347,30.880180215049233,31.023378122904994,31.166576030760776,31.309773938616537,31.4529718464723,31.596169754328063,31.739367662183827,31.882565570039592,32.02576347789537,32.168961385751146,32.31215929360691,32.455357201462675,32.59855510931844,32.741753017174204,32.88495092502996,33.02814883288575,33.171346740741505,33.31454464859727,33.45774255645304,33.60094046430882,33.744138372164564,33.88733628002034,34.03053418787612,34.17373209573188,34.07178785030773,33.778187405116725,33.48458695992574,33.190986514734746,32.89738606954378,32.603785624352746,32.3101851791618,32.016584733970795,31.72298428877983,31.4293838435888,31.135783398397848,30.842182953206844,30.54858250801589,30.2549820628249,29.9613816176339,29.667781172442947,29.37418072725191,29.080580282060954,28.78851268700683,28.49824844398378,28.207984200960716,27.917719957937575,27.627455714914518,27.337191471891423,27.04692722886832,26.75666298584523,26.46639874282217,26.17613449979907,25.885870256775977,25.59560601375292,25.305341770729775,25.015077527706715,24.72548251977385,24.43958591853342,24.15368931729298,23.867792716052552,23.581896114812153,23.29599951357171,23.010102912331288,22.724206311090853,22.43830970985045,22.15241310861001,21.86651650736963,21.58061990612915,21.29799300266811,21.0179139179974,20.73783483332672,20.457755748655995,20.177676663985316,19.8975975793146,19.61751849464388,19.337439409973168,19.057360325302454,18.777281240631726,18.504863198143145,18.232601502487636,17.960339806832074,17.68807811117651,17.41581641552099,17.14355471986544,16.871293024209905,16.599031328554354,16.333994119269303,16.069531041447416,15.805067963625529,15.540604885803699,15.276141807981814,15.011678730159929,14.747711279038725,14.491178242077186,14.23464520511566,13.978112168154158,13.721579131192605,13.465046094231026,13.209805646635239,12.962320728788383,12.714835810941452,12.467350893094546,12.219865975247714,11.972381057400787,11.734760456500867,11.497288563745736,11.259816670990562,11.022344778235384,10.789561191609524,10.562480906431135,10.335400621252703,10.10832033607427,9.885196860091677,9.667229224559943,9.449261589028225,9.231293953496515,9.021228739161142,8.812551266799815,8.603873794438531,8.402842924547963,8.206229036655643,8.009615148763354,7.822605600695676,7.639142271557081,7.456842581519342,7.285446616965351,7.114050652411315,6.950310693125887,6.789910853897552,6.634532139395191,6.4841745503986115,6.338239420558937,6.197042639194547,6.061068549451704,5.928248258960343,5.802501707115861,5.680329152754391,5.564444668656515,5.456748366448427,5.353877289106555,5.255684001656115,5.161862368081817,5.074246388187799,4.9926064710538025,4.916852626475351,4.846695880130576,4.767191691353555,4.684744566822194,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[66.64846887130173,66.6974095822933,66.74635029328486,66.79529100427644,66.84423171526801,66.89317242625957,66.94211313725114,66.9910538482427,67.03999455923427,67.08893527022585,67.1378759812174,67.18681669220896,67.23575740320055,67.28469811419211,67.33363882518368,67.38257953617524,67.43152024716682,67.48046095815837,67.52940166914995,67.57834238014152,67.62728309113308,67.67622380212464,67.72516451311621,67.77410522410779,67.82304593509934,67.87198664609092,67.92092735708249,67.96986806807405,68.01880877906562,68.06774949005718,68.11669020104875,68.16563091204031,68.21457162303189,68.26351233402346,68.31245304501502,68.36139375600659,68.41033446699817,68.45927517798972,68.5082158889813,68.55715659997286,68.60609731096443,68.655038021956,68.70397873294756,68.75291944393913,68.8018601549307,68.85080086592227,68.89974157691384,68.9486822879054,68.99762299889696,69.04656370988853,69.0955044208801,69.14444513187166,69.19338584286324,69.2423265538548,69.29126726484637,69.34020797583793,69.3891486868295,69.43808939782107,69.48703010881263,69.5359708198042,69.58491153079576,69.63385224178734,69.68279295277891,69.73173366377047,69.78067437476204,69.82961508575362,69.87855579674518,69.92749650773675,69.97643721872831,70.02537792971987,70.07431864071144,70.123259351703,70.17220006269457,70.22114077368614,70.26995613095289,70.31852078063238,70.36708543031189,70.4156500799914,70.4642147296709,70.5127793793504,70.56134402902991,70.6099086787094,70.65847332838892,70.70703797806841,70.74074327235773,70.77147669556902,70.80221011878031,70.83294354199158,70.86367696520287,70.89441038841414,70.92514381162543,70.95587723483672,70.986610658048,71.01802977494127,71.0508202784459,71.08361078195051,71.11640128545513,71.14919178895974,71.18198229246438,71.214772795969,71.2475632994736,71.28035380297823,71.31314430648284,71.34593480998747,71.37872531349208,71.4115158169967,71.44430632050131,71.47709682400593,71.50988732751055,71.54267783101517,71.57546833451978,71.6082588380244,71.64104934152903,71.67383984503365,71.70663034853825,71.73942085204288,71.7722113555475,71.80500185905213,71.83779236255674,71.87058286606135,71.90337336956597,71.9361638730706,71.96895437657521,72.00174488007983,72.03453538358445,72.06732588708907,72.10011639059368,72.1329068940983,72.16569739760293,72.19848790110754,72.23127840461217,72.26406890811677,72.2968594116214,72.32964991512601,72.36244041863063,72.39523092213526,72.42802142563987,72.46081192914448,72.49360243264911,72.52639293615373,72.55918343965834,72.59197394316297,72.62476444666758,72.6575549501722,72.69034545367683,72.72313595718144,72.75592646068606,72.78871696419067,72.82150746769528,72.85429797119991,72.88708847470454,72.91987897820914,72.95266948171377,72.98545998521838,73.01825048872301,73.05104099222763,73.08383149573224,73.11662199923686,73.14941250274148,73.1822030062461,73.21499350975071,73.24778401325533,73.28057451675994,73.31336502026457,73.34615552376918,73.37894602727381,73.41173653077843,73.30790249786536,73.13575619674344,72.96360989562154,72.79146359449962,72.61931729337772,72.4471709922558,72.2750246911339,72.10287839001198,71.93073208889007,71.75858578776815,71.58643948664624,71.41429318552434,71.24214688440243,71.07000058328052,70.90089214956113,70.75912446565614,70.61735678175114,70.47558909784615,70.33382141394117,70.19205373003618,70.05028604613119,69.90851836222619,69.7667506783212,69.6249829944162,69.48321531051121,69.34144762660623,69.19967994270124,69.05791225879625,68.91614457489126,68.77437689098626,68.63260920708127,68.49084152317627,68.34907383927128,68.2073061553663,68.06553847146131,67.92377078755631,67.78200310365132,67.64023541974633,67.49846773584134,67.35670005193634,67.21493236803137,67.07316468412637,66.93139700022138,66.78962931631638,66.64786163241139,66.50609394850639,66.3643262646014,66.22255858069643,66.08079089679143,65.93902321288644,65.79725552898144,65.65548784507645,65.51372016117148,65.37195247726646,65.23018479336147,65.08841710945649,64.9466494255515,64.80488174164651,64.6631140577415,64.52134637383651,64.37957868993153,64.23781100602653,64.09604332212155,63.954275638216544,63.81250795431157,63.670740270406576,63.52897258650158,63.38720490259659,63.24543721869159,63.10366953478661,62.96190185088162,62.82013416697662,62.67836648307163,62.53659879916664,62.39483111526165,62.25306343135666,62.11129574745166,61.969528063546676,61.82776037964169,61.685992695736694,61.5442250118317,61.402457327926705,61.260689644021724,60.87393380689236,60.2421898165386,59.61044582618489,58.97870183583117,58.3469578454774,57.7152138551237,57.08346986476999,56.4517258744162,55.81998188406245,55.188237893708795,54.55649390335501,53.92474991300124,53.29300592264754,52.66126193229384,52.029517941940064,51.39777395158636,50.76602996123265,50.13428597087887,49.50254198052515,48.870797990171454,48.239053999817685,47.606003687237276,46.97026678883735,46.3345298904373,45.698792992037276,45.06305609363728,44.427319195237324,43.79158229683728,43.155845398437286,42.52010850003732,41.88437160163727,41.248634703237244,40.612897804837324,39.97716090643729,39.34142400803725,38.70568710963726,38.06995021123729,37.434213312837244,36.798476414437275,36.160796245367315,35.52168340911034,34.88257057285342,34.24345773659649,33.60434490033951,32.96523206408254,32.32611922782568,31.687006391568694,31.047893555311717,30.408780719054796,30.33854011242313,30.48173802027891,30.624935928134672,30.768133835990433,30.911331743846215,31.054529651701984,31.19772755955774,31.34092546741351,31.48412337526929,31.62732128312505,31.770519190980814,31.913717098836592,32.05691500669236,32.200112914548114,32.343310822403886,32.486508730259644,32.62970663811541,32.77290454597119,32.91610245382696,33.05930036168271,33.202498269538495,33.34569617739426,33.488894085250024,33.63209199310579,33.77528990096156,33.918487808817325,34.06168571667308,34.204883624528854,34.34808153238462,34.491279440240376,34.634477348096155,34.77767525595194,34.9208731638077,35.06407107166346,35.20726897951923,35.35046688737499,35.49366479523076,35.636862703086535,35.64634659790342,35.35274615271246,35.05914570752146,34.76554526233046,34.471944817139516,34.17834437194851,33.88474392675747,33.59114348156652,33.297543036375565,33.00394259118457,32.71034214599357,32.416741700802575,32.123141255611614,31.829540810420585,31.535940365229635,31.24233992003863,30.94873947484767,30.655139029656635,30.361538584465684,30.068929983679304,29.77866574065621,29.48840149763312,29.198137254610057,28.90787301158696,28.6176087685639,28.327344525540763,28.037080282517657,27.74681603949461,27.456551796471548,27.166287553448406,26.876023310425346,26.585759067402254,26.29549482437915,26.005230581356052,25.71616391717001,25.430267315929576,25.144370714689146,24.858474113448715,24.572577512208273,24.286680910967867,24.000784309727436,23.71488770848701,23.42899110724657,23.143094506006143,22.857197904765744,22.571301303525306,22.28599919164883,22.005920106978113,21.72584102230739,21.445761937636664,21.165682852966,20.885603768295272,20.60552468362455,20.325445598953838,20.04536651428316,19.76528742961243,19.485521041497076,19.21325934584155,18.940997650185988,18.66873595453044,18.39647425887492,18.124212563219324,17.85195086756376,17.579689171908257,17.30742747625269,17.039710987216633,16.77524790939479,16.510784831572916,16.24632175375103,15.981858675929157,15.717395598107313,15.452932520285426,15.191443206890316,14.934910169928816,14.678377132967261,14.42184409600571,14.165311059044168,13.908778022082629,13.653681195471313,13.406196277624456,13.158711359777527,12.911226441930644,12.663741524083736,12.416256606236882,12.176207103218177,11.938735210463024,11.701263317707872,11.463791424952696,11.226319532197516,10.999045914213,10.771965629034568,10.544885343856135,10.317805058677703,10.097679164855666,9.879711529323934,9.661743893792181,9.443776258514925,9.235098786153598,9.026421313792273,8.817743841430987,8.61657048824508,8.419956600352776,8.22334271246051,8.034264537131088,7.850801207992522,7.667337878853926,7.493614637236081,7.322218672682044,7.153975180836146,6.99357534160781,6.833175502379442,6.6826210061061495,6.5322634171096,6.389803076386819,6.248606295022393,6.115029092729319,5.983025002683611,5.8580266349325605,5.736948764935607,5.621064280837754,5.513821395867382,5.41078620049413,5.312137532440192,5.218315898865881,5.129721766858607,5.0466554436588416,4.9693069908573415,4.89746434729462,4.822865051441495,4.740417926910149,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[66.72678064254269,66.77572135353427,66.82466206452582,66.87360277551738,66.92254348650896,66.97148419750053,67.02042490849209,67.06936561948366,67.11830633047524,67.1672470414668,67.21618775245837,67.26512846344993,67.3140691744415,67.36300988543306,67.41195059642465,67.4608913074162,67.50983201840776,67.55877272939932,67.60771344039091,67.65665415138247,67.70559486237404,67.7545355733656,67.80347628435717,67.85241699534875,67.9013577063403,67.95029841733188,67.99923912832344,68.04817983931501,68.09712055030658,68.14606126129814,68.1950019722897,68.24394268328128,68.29288339427285,68.34182410526442,68.39076481625598,68.43970552724755,68.48864623823911,68.53758694923067,68.58652766022226,68.63546837121382,68.68440908220538,68.73334979319695,68.78229050418851,68.83123121518008,68.88017192617164,68.92911263716321,68.97805334815479,69.02699405914636,69.07593477013792,69.1248754811295,69.17381619212105,69.22275690311263,69.27169761410418,69.32063832509574,69.36957903608733,69.41851974707889,69.46746045807046,69.51640116906202,69.56502849561069,69.6135931452902,69.66215779496969,69.71072244464919,69.7592870943287,69.8078517440082,69.85641639368771,69.90498104336721,69.95354569304672,70.00211034272621,70.05067499240572,70.09923964208522,70.14780429176473,70.19636894144423,70.24493359112374,70.29349824080325,70.34206289048274,70.39062754016224,70.43919218984175,70.48775683952125,70.53632148920076,70.58488613888025,70.63345078855977,70.68201543823926,70.73058008791877,70.77914473759827,70.81285003188758,70.84358345509887,70.87431687831015,70.90505030152144,70.93578372473272,70.966517147944,70.99725057115529,71.02798399436656,71.05871741757785,71.08945084078914,71.12018426400041,71.1509176872117,71.18165111042299,71.21238453363426,71.24311795684555,71.27385138005684,71.30458480326811,71.3353182264794,71.36605164969069,71.39678507290196,71.42751849611325,71.45825191932454,71.48898534253583,71.5197187657471,71.55045218895839,71.58118561216966,71.61363326887019,71.6464237723748,71.67921427587942,71.71200477938405,71.74479528288866,71.77758578639327,71.8103762898979,71.84316679340252,71.87595729690713,71.90874780041175,71.94153830391636,71.97432880742099,72.0071193109256,72.03990981443022,72.07270031793485,72.10549082143946,72.13828132494409,72.1710718284487,72.20386233195332,72.23665283545793,72.26944333896255,72.30223384246717,72.33502434597179,72.36781484947642,72.40060535298103,72.43339585648565,72.46618635999026,72.49897686349487,72.5317673669995,72.56455787050412,72.59734837400873,72.63013887751336,72.66292938101797,72.69571988452259,72.72851038802722,72.76130089153183,72.79409139503645,72.82688189854107,72.85967240204569,72.8924629055503,72.92525340905493,72.95804391255953,72.99083441606416,73.02362491956879,73.0564154230734,73.08920592657802,73.12199643008263,73.15478693358725,73.18757743709187,73.22036794059649,73.2531584441011,73.28594894760573,73.31873945111035,73.35152995461496,73.38432045811959,73.4171109616242,73.44990146512882,73.34606743221575,73.17392113109385,73.00177482997194,72.82962852885001,72.65748222772811,72.4853359266062,72.31318962548428,72.14104332436239,71.96889702324046,71.79675072211856,71.62460442099665,71.45245811987473,71.28031181875284,71.10816551763091,70.93601921650901,70.7638729153871,70.59172661426518,70.41958031314327,70.24743401202136,70.07528771089946,69.90314140977755,69.73099510865563,69.55884880753374,69.38670250641181,69.21455620528991,69.04240990416798,68.87026360304608,68.69811730192417,68.52597100080224,68.35382469968035,68.18167839855843,68.00953209743653,67.83738579631462,67.66523949519271,67.4930931940708,67.32094689294888,67.14880059182697,66.97665429070506,66.80450798958316,66.63236168846123,66.4845182791079,66.3427505952029,66.20098291129791,66.05921522739291,65.91744754348792,65.77567985958294,65.63391217567795,65.49214449177296,65.35037680786796,65.20860912396297,65.06684144005797,64.92507375615298,64.783306072248,64.641538388343,64.49977070443802,64.35800302053303,64.21623533662803,64.07446765272304,63.93269996881804,63.790932284913055,63.64916460100807,63.50739691710307,63.36562923319808,63.22386154929308,63.0820938653881,62.94032618148311,62.798558497578114,62.656790813673126,62.51502312976813,62.37325544586315,62.23148776195815,62.08972007805316,61.94795239414817,61.80618471024317,61.664417026338185,61.5226493424332,61.380881658528196,61.23911397462321,61.09734629071822,60.95557860681323,60.81381092290823,60.672043239003244,60.53027555509824,60.143519717968886,59.51177572761513,58.880031737261426,58.24828774690771,57.61654375655393,56.98479976620023,56.35305577584652,55.72131178549274,55.08956779513898,54.45782380478533,53.826079814431544,53.19433582407778,52.56259183372408,51.930305596082476,51.29456869768246,50.65883179928247,50.02309490088248,49.38735800248246,48.751621104082474,48.115884205682505,47.48014730728246,46.84441040888243,46.2086735104825,45.57293661208245,44.93719971368242,44.30146281528243,43.66572591688247,43.029989018482425,42.394252120082434,41.758515221682465,41.12277832328242,40.48704142488239,39.85130452648247,39.21506693884545,38.57595410258849,37.93684126633156,37.29772843007465,36.65861559381766,36.019502757560744,35.38038992130383,34.741277085046846,34.10216424878993,33.463051412533005,32.82393857627603,32.231264443345204,32.37446235120094,32.517660259056726,32.66085816691249,32.804056074768255,32.94725398262401,33.0904518904798,33.233649798335556,33.37684770619132,33.5200456140471,33.663243521902864,33.80644142975862,33.94963933761439,34.09283724547017,34.236035153325936,34.3792330611817,34.52243096903747,34.66562887689324,34.808826784749,34.95202469260476,35.095222600460524,35.23842050831629,35.38161841617207,35.52481632402784,35.668014231883596,35.81121213973937,35.95441004759514,36.097607955450904,36.24080586330667,36.38400377116245,36.527201679018205,36.67039958687398,36.813597494729734,36.9567954025855,37.099993310441256,37.220905345499105,36.92730490030811,36.633704455117154,36.340104009926165,36.04650356473516,35.75290311954421,35.45930267435321,35.165702229162214,34.87210178397122,34.57850133878027,34.28490089358926,33.99130044839826,33.697700003207316,33.40409955801632,33.11049911282528,32.81689866763433,32.52329822244337,32.22969777725237,31.93609733206138,31.642496886870386,31.349347280351715,31.05908303732866,30.768818794305567,30.47855455128246,30.188290308259358,29.8980260652363,29.60776182221321,29.317497579190103,29.027233336167008,28.736969093143916,28.446704850120852,28.156440607097757,27.8661763640747,27.57591212105156,27.285647878028456,26.99538363500541,26.706845314566067,26.42094871332563,26.13505211208523,25.849155510844838,25.56325890960436,25.277362308363976,24.991465707123574,24.705569105883136,24.41967250464271,24.133775903402277,23.847879302161836,23.561982700921433,23.276086099681002,22.993926295958758,22.713847211288034,22.43376812661732,22.15368904194664,21.873609957275914,21.59353087260524,21.31345178793452,21.0333727032638,20.753293618593077,20.47321453392241,20.19391718919541,19.921655493539852,19.649393797884304,19.37713210222878,19.104870406573216,18.83260871091767,18.560347015262145,18.288085319606584,18.015823623951032,17.745427855163992,17.48096477734211,17.21650169952025,16.952038621698392,16.68757554387653,16.42311246605462,16.158649388232774,15.8941863104109,15.6351751347419,15.37864209778036,15.122109060818847,14.865576023857267,14.60904298689574,14.352509949934241,14.097556744307363,13.850071826460455,13.602586908613587,13.355101990766695,13.107617072919789,12.86013215507293,12.617653749935489,12.380181857180292,12.142709964425112,11.905238071669984,11.667766178914807,11.435610921994824,11.208530636816416,10.981450351637983,10.754370066459572,10.528129105151354,10.31016146961962,10.092193834087887,9.874226198556153,9.657646305507331,9.448968833146004,9.240291360784695,9.03161388842341,8.830298051942181,8.63368416404986,8.437070276157597,8.245923473566517,8.062460144427922,7.878996815289392,7.701782657506786,7.530386692952774,7.35899072839875,7.197239829318068,7.0368399900897,6.881067461813678,6.730709872817129,6.582563513579064,6.4413667322146555,6.301809926498313,6.168989636006961,6.038549930500302,5.9135515627492605,5.79356837711684,5.677683893018964,5.570894425286328,5.467695111881717,5.3687081612664445,5.274769429649946,5.185197145529427,5.100704416263861,5.02176135523931,4.948232814458675,4.878538411529448,4.796091286998086,4.713644162466727,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[66.80509241378365,66.85403312477521,66.90297383576677,66.95191454675835,67.00085525774992,67.04979596874148,67.09873667973305,67.14767739072461,67.19661810171618,67.24555881270776,67.29449952369932,67.34344023469089,67.39238094568245,67.44132165667402,67.4902623676656,67.53920307865715,67.58814378964873,67.63708450064028,67.68602521163186,67.73496592262342,67.783906633615,67.83284734460656,67.88178805559812,67.9307287665897,67.97966947758125,68.02861018857283,68.0775508995644,68.12649161055596,68.17543232154753,68.22437303253909,68.27331374353066,68.32225445452224,68.3711951655138,68.42013587650537,68.46907658749693,68.5180172984885,68.56695800948006,68.61589872047163,68.66483943146321,68.71378014245477,68.76272085344634,68.81153621058898,68.86010086026847,68.90866550994798,68.95723015962749,69.00579480930698,69.0543594589865,69.10292410866599,69.1514887583455,69.20005340802501,69.2486180577045,69.29718270738402,69.3457473570635,69.39431200674301,69.44287665642253,69.49144130610202,69.54000595578154,69.58857060546102,69.63713525514052,69.68569990482004,69.73426455449953,69.78282920417905,69.83139385385854,69.87995850353805,69.92852315321755,69.97708780289706,70.02565245257657,70.07421710225606,70.12278175193556,70.17134640161507,70.21991105129457,70.26847570097408,70.31704035065357,70.36560500033309,70.41416965001258,70.46273429969209,70.5112989493716,70.5598635990511,70.6084282487306,70.6569928984101,70.70555754808962,70.7541221977691,70.80268684744861,70.85125149712812,70.88495679141744,70.91569021462871,70.94642363784,70.97715706105129,71.00789048426256,71.03862390747385,71.06935733068512,71.10009075389641,71.1308241771077,71.16155760031899,71.19229102353026,71.22302444674155,71.25375786995284,71.28449129316411,71.3152247163754,71.34595813958668,71.37669156279796,71.40742498600925,71.43815840922053,71.46889183243181,71.4996252556431,71.53035867885438,71.56109210206566,71.59182552527695,71.62255894848823,71.65329237169952,71.6840257949108,71.71475921812208,71.74549264133336,71.77622606454464,71.80695948775593,71.8376929109672,71.8684263341785,71.89915975738977,71.92989318060106,71.96062660381234,71.99136002702362,72.02209345023492,72.0528268734462,72.08356029665748,72.11429371986877,72.14502714308004,72.17644625929448,72.2092367627991,72.24202726630371,72.27481776980834,72.30760827331295,72.34039877681758,72.3731892803222,72.4059797838268,72.43877028733142,72.47156079083604,72.50435129434067,72.53714179784528,72.5699323013499,72.60272280485451,72.63551330835914,72.66830381186375,72.70109431536837,72.73388481887298,72.76667532237761,72.79946582588222,72.83225632938685,72.86504683289147,72.89783733639608,72.93062783990071,72.96341834340532,72.99620884690994,73.02899935041455,73.06178985391918,73.0945803574238,73.12737086092841,73.16016136443304,73.19295186793765,73.22574237144227,73.25853287494688,73.29132337845151,73.32411388195612,73.35690438546075,73.38969488896535,73.42248539246998,73.4552758959746,73.48806639947921,73.38423236656614,73.21208606544424,73.03993976432233,72.86779346320041,72.69564716207852,72.52350086095659,72.35135455983469,72.17920825871278,72.00706195759086,71.83491565646895,71.66276935534704,71.49062305422513,71.31847675310323,71.1463304519813,70.9741841508594,70.8020378497375,70.62989154861557,70.45774524749366,70.28559894637175,70.11345264524985,69.94130634412794,69.76916004300602,69.59701374188411,69.4248674407622,69.2527211396403,69.08057483851839,68.90842853739647,68.73628223627458,68.56413593515265,68.39198963403074,68.21984333290884,68.04769703178692,67.87555073066503,67.7034044295431,67.53125812842119,67.35911182729927,67.18696552617736,67.01481922505546,66.84267292393355,66.67052662281164,66.49838032168974,66.32623402056782,66.15408771944591,65.981941418324,65.80979511720207,65.63764881608017,65.46550251495827,65.29335621383636,65.12120991271445,64.94906361159254,64.77691731047062,64.60477100934871,64.4326247082268,64.2604784071049,64.08833210598299,63.91618580486107,63.74403950373916,63.57189320261725,63.399746901495334,63.22760060037342,63.05545429925152,62.88330799812961,62.7111616970077,62.539015395885784,62.36686909476387,62.20991209255966,62.06814440865468,61.92637672474968,61.784609040844686,61.6428413569397,61.50107367303471,61.359305989129716,61.21753830522473,61.075770621319734,60.934002937414746,60.79223525350975,60.65046756960476,60.50869988569977,60.36693220179478,60.22516451788978,60.08339683398479,59.9416291500798,59.79986146617481,59.41310562904545,58.781361638691685,58.14961764833798,57.51787365798426,56.88612966763049,56.254385677276794,55.618870606527686,54.98313370812767,54.34739680972761,53.71165991132769,53.075923012927674,52.44018611452761,51.80444921612765,51.16871231772766,50.532975419327634,49.897238520927644,49.26150162252765,48.625764724127635,47.99002782572765,47.35429092732768,46.718554028927635,46.0828171305276,45.44708023212768,44.81134333372763,44.175606435327595,43.539869536927604,42.90413263852765,42.2683957401276,41.63022479606672,40.99111195980979,40.35199912355284,39.71288628729585,39.073773451038996,38.434660614782,37.795547778525034,37.156434942268106,36.51732210601119,35.8782092697542,35.23909643349729,34.599983597240374,34.267186682122905,34.41038458997867,34.55358249783443,34.6967804056902,34.839978313545984,34.98317622140172,35.1263741292575,35.26957203711327,35.412769944969035,35.55596785282479,35.69916576068057,35.842363668536336,35.985561576392094,36.12875948424788,36.271957392103644,36.415155299959395,36.55835320781517,36.70155111567095,36.84474902352671,36.987946931382474,37.13114483923826,37.27434274709401,37.417540654949775,37.56073856280555,37.70393647066131,37.84713437851706,37.990332286372855,38.13353019422861,38.27672810208436,38.419926009940156,38.56312391779592,38.706321825651685,38.50186364790384,38.208263202712885,37.91466275752189,37.6210623123309,37.32746186713989,37.03386142194894,36.740260976757995,36.44666053156695,36.153060086375945,35.85945964118499,35.565859195994,35.272258750803,34.97865830561204,34.68505786042105,34.39145741523005,34.09785697003906,33.80425652484811,33.5106560796571,33.2170556344661,32.92345518927516,32.629854744084156,32.33950033400109,32.049236090978,31.7589718479549,31.468707604931794,31.178443361908702,30.888179118885688,30.597914875862546,30.307650632839486,30.01738638981639,29.72712214679329,29.436857903770186,29.146593660747133,28.856329417724037,28.56606517470093,28.27580093167784,27.985536688654747,27.697526711962226,27.41163011072179,27.125733509481368,26.83983690824096,26.553940307000524,26.26804370576014,25.98214710451966,25.696250503279224,25.410353902038825,25.124457300798433,24.83856069955796,24.552664098317564,24.266767497077172,23.981932484939463,23.701853400268753,23.42177431559807,23.141695230927347,22.861616146256623,22.581537061585912,22.3014579769152,22.021378892244474,21.741299807573764,21.461220722903082,21.181141638232358,20.902313336893783,20.630051641238232,20.35778994558267,20.08552824992714,19.8132665542716,19.541004858616034,19.268743162960476,18.996481467304925,18.724219771649402,18.451958075993844,18.18668164528948,17.922218567467638,17.657755489645748,17.393292411823875,17.128829334002003,16.864366256180116,16.59990317835826,16.3354401005364,16.0789070625935,15.822374025631976,15.565840988670438,15.309307951708897,15.052774914747344,14.796241877785803,14.541432293143437,14.293947375296531,14.046462457449625,13.798977539602769,13.55149262175586,13.304007703908956,13.059100396652768,12.821628503897603,12.584156611142426,12.346684718387294,12.109212825632142,11.872175929776688,11.645095644598257,11.418015359419847,11.190935074241436,10.963854789063003,10.740611409915328,10.522643774383592,10.30467613885186,10.086708503320168,9.871516352499786,9.66283888013846,9.454161407777118,9.245483935415832,9.044025615639299,8.847411727746994,8.650797839854729,8.45758241000193,8.274119080863361,8.090655751724805,7.909950677777528,7.738554713223503,7.567158748669511,7.400904317028326,7.240504477799947,7.080104638571591,6.929156328524677,6.778798739528087,6.634127169406909,6.49293038804252,6.355770469775928,6.222950179284568,6.094074858317027,5.969076490565977,5.850187989298055,5.734303505200186,5.627967454705303,5.524604023269292,5.425617072654024,5.331222960434028,5.240672524200235,5.154753388868889,5.074441505002152,5.000056483386979,4.930287857278269,4.851764647086042,4.769317522554684,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[66.8834041850246,66.93234489601616,66.98128560700773,67.03022631799931,67.07916702899087,67.12810773998244,67.177048450974,67.22598916196557,67.27492987295713,67.3238705839487,67.37281129494028,67.42175200593184,67.47069271692341,67.51963342791498,67.56857413890654,67.6175148498981,67.66645556088967,67.71539627188125,67.7643369828728,67.81327769386438,67.86221840485595,67.91115911584751,67.96009982683907,68.00904053783066,68.05798124882222,68.10660857524677,68.15517322492627,68.20373787460578,68.25230252428528,68.30086717396479,68.34943182364428,68.3979964733238,68.44656112300329,68.4951257726828,68.5436904223623,68.59225507204181,68.64081972172131,68.6893843714008,68.73794902108031,68.78651367075982,68.83507832043932,68.88364297011883,68.93220761979832,68.98077226947782,69.02933691915733,69.07790156883684,69.12646621851634,69.17503086819583,69.22359551787534,69.27216016755486,69.32072481723435,69.36928946691386,69.41785411659336,69.46641876627285,69.51498341595237,69.56354806563186,69.61211271531137,69.66067736499087,69.70924201467037,69.75780666434989,69.80637131402938,69.8549359637089,69.90350061338839,69.95206526306788,70.0006299127474,70.04919456242689,70.09775921210641,70.1463238617859,70.19488851146542,70.24345316114491,70.29201781082442,70.34058246050392,70.38914711018342,70.43771175986294,70.48627640954243,70.53484105922195,70.58340570890144,70.63197035858093,70.68053500826045,70.72909965793994,70.77766430761946,70.82622895729895,70.87479360697846,70.92335825665796,70.95706355094728,70.98779697415856,71.01853039736983,71.04926382058112,71.0799972437924,71.11073066700368,71.14146409021498,71.17219751342626,71.20293093663753,71.23366435984882,71.2643977830601,71.29513120627138,71.32586462948268,71.35659805269395,71.38733147590524,71.41806489911653,71.4487983223278,71.47953174553909,71.51026516875038,71.54099859196165,71.57173201517294,71.60246543838423,71.6331988615955,71.66393228480678,71.69466570801806,71.72539913122935,71.75613255444064,71.78686597765193,71.8175994008632,71.84833282407449,71.87906624728578,71.90979967049705,71.94053309370834,71.97126651691963,72.0019999401309,72.03273336334219,72.06346678655346,72.09420020976475,72.12493363297602,72.15566705618733,72.1864004793986,72.21713390260989,72.24786732582116,72.27860074903245,72.30933417224374,72.34006759545503,72.3708010186663,72.40153444187759,72.43226786508886,72.46300128830015,72.49373471151142,72.52446813472272,72.555201557934,72.58593498114529,72.61666840435657,72.64740182756785,72.67813525077914,72.70886867399041,72.7396020972017,72.77204975322338,72.80484025672801,72.83763076023263,72.87042126373724,72.90321176724186,72.93600227074649,72.9687927742511,73.00158327775571,73.03437378126033,73.06716428476494,73.09995478826957,73.13274529177419,73.1655357952788,73.19832629878343,73.23111680228804,73.26390730579266,73.29669780929729,73.3294883128019,73.36227881630651,73.39506931981114,73.42785982331576,73.46065032682037,73.49344083032499,73.52623133382961,73.42239730091654,73.25025099979463,73.07810469867272,72.9059583975508,72.7338120964289,72.56166579530698,72.38951949418508,72.21737319306317,72.04522689194125,71.87308059081936,71.70093428969743,71.52878798857553,71.35664168745362,71.1844953863317,71.01234908520979,70.8402027840879,70.66805648296597,70.49591018184407,70.32376388072214,70.15161757960026,69.97947127847834,69.80732497735643,69.63517867623452,69.4630323751126,69.29088607399069,69.11873977286878,68.94659347174687,68.77444717062497,68.60230086950304,68.43015456838114,68.25800826725923,68.08586196613732,67.9137156650154,67.74156936389349,67.56942306277159,67.39727676164968,67.22513046052777,67.05298415940585,66.88083785828394,66.70869155716204,66.53654525604013,66.36439895491822,66.1922526537963,66.02010635267439,65.84796005155249,65.67581375043056,65.50366744930867,65.33152114818675,65.15937484706484,64.98722854594293,64.81508224482101,64.64293594369911,64.4707896425772,64.29864334145529,64.12649704033338,63.95435073921147,63.78220443808956,63.61005813696765,63.437911835845725,63.26576553472381,63.09361923360191,62.92147293248,62.7493266313581,62.577180330236175,62.405034029114276,62.23288772799236,62.06074142687045,61.888595125748544,61.716448824626625,61.54114140579991,61.3521359066868,61.163130407573675,60.97412490846057,60.78511940934746,60.59611391023435,60.407108411121236,60.21810291200812,60.029097412895005,59.8400919137819,59.65108641466878,59.46208091555567,59.27307541644255,59.08406991732944,58.67169871857288,58.03596182017282,57.40022492177285,56.76448802337288,56.12875112497282,55.49301422657285,54.85727732817287,54.221540429772844,53.58580353137279,52.95006663297287,52.314329734572844,51.67859283617279,51.04285593777283,50.40711903937284,49.77138214097281,49.13564524257282,48.49990834417284,47.86417144577281,47.22843454737283,46.59269764897286,45.95696075057282,45.321223852172785,44.68449548954496,44.04538265328797,43.406269817031,42.76715698077408,42.12804414451717,41.48893130826019,40.849818472003264,40.21070563574634,39.57159279948937,38.932479963232396,38.29336712697554,37.65425429071854,37.01514145446158,36.37602861820465,36.30310892090061,36.4463068287564,36.58950473661215,36.73270264446791,36.8759005523237,37.01909846017946,37.16229636803522,37.30549427589099,37.44869218374678,37.591890091602515,37.73508799945829,37.878285907314066,38.02148381516983,38.16468172302559,38.30787963088137,38.45107753873713,38.59427544659289,38.73747335444867,38.88067126230444,39.02386917016019,39.16706707801597,39.31026498587175,39.453462893727504,39.59666080158326,39.73985870943905,39.88305661729481,40.02625452515057,40.169452433006335,40.07642239549956,39.782821950308616,39.48922150511762,39.1956210599266,38.90202061473567,38.60842016954467,38.31481972435367,38.02121927916271,37.727618833971675,37.43401838878072,37.14041794358972,36.84681749839873,36.55321705320773,36.25961660801677,35.96601616282583,35.67241571763478,35.37881527244378,35.08521482725282,34.79161438206184,34.498013936870834,34.20441349167988,33.91081304648888,33.61991763067353,33.32965338765047,33.03938914462737,32.749124901604276,32.45886065858113,32.16859641555808,31.878332172535018,31.588067929511915,31.297803686488823,31.007539443465728,30.71727520044262,30.427010957419526,30.136746714396516,29.84648247137337,29.556218228350314,29.26595398532722,28.975689742304116,28.688208109358378,28.402311508117947,28.116414906877523,27.83051830563708,27.54462170439665,27.25872510315626,26.972828501915817,26.686931900675386,26.401035299434955,26.115138698194553,25.829242096954115,25.54334549571373,25.257448894473253,24.971552293232815,24.68985958924942,24.40978050457874,24.129701419908017,23.849622335237335,23.569543250566625,23.2894641658959,23.00938508122519,22.72930599655451,22.449226911883784,22.16914782721306,21.88906874254235,21.61070948459215,21.338447788936588,21.066186093281008,20.793924397625485,20.521662701969923,20.249401006314407,19.977139310658853,19.70487761500329,19.432615919347757,19.160354223692217,18.89239851323685,18.627935435414965,18.36347235759312,18.099009279771245,17.83454620194936,17.57008312412749,17.30562004630564,17.041156968483758,16.77917202740665,16.522638990445135,16.266105953483553,16.009572916522004,15.7530398795605,15.496506842598947,15.23997380563742,14.985307841979472,14.737822924132601,14.490338006285695,14.242853088438824,13.99536817059193,13.747883252745027,13.500547043370062,13.263075150614913,13.025603257859757,12.78813136510458,12.550659472349416,12.313187579594253,12.08166065238012,11.854580367201732,11.627500082023301,11.400419796844867,11.173339511666434,10.953093714679317,10.735126079147582,10.51715844361583,10.299190808084138,10.085386399492222,9.876708927130899,9.668031454769613,9.459353982408286,9.257753179336415,9.061139291444125,8.864525403551859,8.669241346437369,8.485778017298788,8.302314688160244,8.118851359021651,7.94672273349423,7.775326768940229,7.604568804738584,7.444168965510215,7.2837691262818804,7.127602784232213,6.977245195235634,6.826887606599171,6.685690825234792,6.544494043870365,6.409731013053552,6.276910722562217,6.149599786133733,6.024601418382675,5.906807601479294,5.791029803893846,5.685040484124255,5.581512934656866,5.482525984041618,5.387676491218093,5.296147902871042,5.208900734348207,5.128490477607175,5.052510847768954,4.981056324442326,4.907438007173983,4.8249908826426235,4.742543758111277,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[66.96171595626555,67.01065666725712,67.05959737824868,67.10853808924026,67.15747880023181,67.20641951122339,67.25536022221496,67.30430093320653,67.35311629022506,67.40168093990458,67.45024558958407,67.49881023926358,67.54737488894308,67.59593953862257,67.64450418830208,67.69306883798158,67.74163348766109,67.7901981373406,67.8387627870201,67.8873274366996,67.9358920863791,67.9844567360586,68.03302138573811,68.08158603541762,68.13015068509712,68.17871533477663,68.22727998445613,68.27584463413564,68.32440928381513,68.37297393349463,68.42153858317414,68.47010323285363,68.51866788253315,68.56723253221264,68.61579718189215,68.66436183157165,68.71292648125116,68.76149113093066,68.81005578061016,68.85862043028966,68.90718507996917,68.95574972964867,69.00431437932818,69.05287902900768,69.10144367868718,69.15000832836668,69.19857297804619,69.24713762772569,69.29570227740518,69.3442669270847,69.3928315767642,69.4413962264437,69.4899608761232,69.5385255258027,69.58709017548222,69.63565482516171,69.68421947484123,69.73278412452072,69.78134877420023,69.82991342387973,69.87847807355922,69.92704272323874,69.97560737291823,70.02417202259774,70.07273667227724,70.12130132195675,70.16986597163626,70.21843062131575,70.26699527099527,70.31555992067476,70.36412457035428,70.41268922003377,70.46125386971327,70.50981851939278,70.55838316907227,70.60694781875178,70.65551246843128,70.70407711811079,70.7526417677903,70.8012064174698,70.84977106714929,70.8983357168288,70.9469003665083,70.99546501618781,71.02917031047713,71.05990373368842,71.09063715689969,71.12137058011098,71.15210400332225,71.18283742653354,71.21357084974483,71.2443042729561,71.27503769616739,71.30577111937868,71.33650454258996,71.36723796580124,71.39797138901253,71.4287048122238,71.4594382354351,71.49017165864637,71.52090508185766,71.55163850506895,71.58237192828022,71.6131053514915,71.64383877470279,71.67457219791407,71.70530562112536,71.73603904433664,71.76677246754792,71.79750589075921,71.82823931397049,71.85897273718177,71.88970616039305,71.92043958360435,71.95117300681562,71.98190643002691,72.01263985323818,72.04337327644947,72.07410669966076,72.10484012287205,72.13557354608332,72.1663069692946,72.19704039250588,72.22777381571717,72.25850723892846,72.28924066213975,72.31997408535102,72.35070750856231,72.38144093177358,72.41217435498487,72.44290777819616,72.47364120140743,72.50437462461872,72.53510804783001,72.56584147104128,72.59657489425257,72.62730831746386,72.65804174067515,72.68877516388642,72.7195085870977,72.75024201030898,72.78097543352027,72.81170885673156,72.84244227994283,72.87317570315412,72.90390912636539,72.9346425495767,72.96537597278797,72.99610939599924,73.02684281921054,73.05757624242182,73.08830966563309,73.11904308884439,73.14977651205567,73.18050993526695,73.21124335847824,73.2419767816895,73.2727102049008,73.30344362811208,73.33486274364768,73.3676532471523,73.40044375065692,73.43323425416155,73.46602475766615,73.49881526117079,73.5316057646754,73.56439626818002,73.46056223526693,73.28841593414504,73.11626963302311,72.94412333190121,72.7719770307793,72.59983072965738,72.42768442853547,72.25553812741356,72.08339182629166,71.91124552516975,71.73909922404783,71.56695292292592,71.39480662180401,71.22266032068211,71.05051401956021,70.87836771843828,70.70622141731637,70.53407511619446,70.36192881507255,70.18978251395065,70.01763621282873,69.84548991170682,69.66280658576136,69.47380108664822,69.28479558753513,69.095790088422,68.9067845893089,68.71777909019579,68.52877359108267,68.33976809196956,68.15076259285644,67.96175709374333,67.77275159463022,67.58374609551711,67.39474059640399,67.20573509729088,67.01672959817778,66.82772409906467,66.63871859995155,66.44971310083844,66.26070760172533,66.07170210261222,65.88269660349911,65.69369110438598,65.50468560527287,65.31568010615976,65.12667460704665,64.93766910793354,64.74866360882042,64.5596581097073,64.37065261059419,64.18164711148108,63.992641612367976,63.80363611325485,63.614630614141745,63.42562511502864,63.236619615915515,63.04761411680241,62.858608617689285,62.66960311857617,62.48059761946307,62.29159212034996,62.102586621236846,61.91358112212373,61.72457562301062,61.535570123897514,61.34656462478439,61.15755912567128,60.96855362655817,60.779548127445054,60.590542628331946,60.40153712921883,60.212531630105715,60.02352613099261,59.83452063187949,59.64551513276638,59.45650963365326,59.267504134540154,59.07849863542704,58.88949313631393,58.70048763720082,58.5114821380877,58.32247663897459,57.91010544021802,57.274368541817964,56.638631643417995,56.002894745018025,55.36715784661797,54.731420948218,54.09568404981801,53.459947151418,52.824210253017945,52.18847335461802,51.552736456218,50.91699955781794,50.28126265941797,49.645525761017986,49.00978886261796,48.374051964217976,47.73831506581798,47.09965334676613,46.46054051050922,45.82142767425227,45.182314837995314,44.54320200173834,43.90408916548147,43.26497632922448,42.62586349296752,41.98675065671059,41.347637820453684,40.70852498419671,40.06941214793978,39.43029931168285,38.79118647542589,38.195833251822684,38.33903115967843,38.482229067534206,38.62542697538998,38.768624883245735,38.9118227911015,39.05502069895728,39.19821860681304,39.3414165146688,39.48461442252458,39.62781233038035,39.7710102382361,39.91420814609188,40.05740605394765,40.20060396180339,40.34380186965918,40.486999777514946,40.63019768537071,40.77339559322647,40.91659350108225,41.05979140893801,41.20298931679377,41.346187224649555,41.48938513250532,41.63258304036108,41.6509811430953,41.3573806979043,41.063780252713315,40.77017980752236,40.47657936233136,40.182978917140325,39.88937847194937,39.59577802675837,39.30217758156737,39.008577136376424,38.71497669118542,38.421376245994416,38.12777580080348,37.83417535561248,37.54057491042147,37.24697446523052,36.95337402003948,36.65977357484853,36.366173129657525,36.072572684466536,35.77897223927553,35.485371794084585,35.19177134889363,34.90033492734594,34.610070684322835,34.319806441299775,34.02954219827669,33.73927795525358,33.44901371223048,33.15874946920743,32.868485226184326,32.578220983161266,32.28795674013818,31.99769249711507,31.70742825409193,31.417164011068884,31.12689976804582,30.83663552502271,30.54637128199962,30.256107038976527,29.96584279595342,29.678889506754484,29.392992905514088,29.10709630427365,28.821199703033216,28.535303101792792,28.249406500552347,27.96350989931194,27.677613298071513,27.391716696831086,27.105820095590644,26.819923494350213,26.534026893109818,26.248130291869384,25.96223369062895,25.67786577823011,25.397786693559418,25.117707608888693,24.837628524218026,24.55754943954727,24.27747035487655,23.99739127020583,23.717312185535157,23.43723310086443,23.15715401619375,22.87707493152304,22.596995846852316,22.319105632290466,22.04684393663491,21.77458224097938,21.50232054532382,21.230058849668268,20.957797154012745,20.685535458357183,20.413273762701603,20.14101206704608,19.86875037139052,19.598115381184197,19.333652303362353,19.069189225540438,18.804726147718554,18.540263069896724,18.275799992074838,18.01133691425295,17.746873836431106,17.48241075860923,17.222903955258218,16.966370918296676,16.709837881335133,16.45330484437361,16.19677180741207,15.940238770450554,15.683705733488976,15.429183390815533,15.181698472968653,14.934213555121747,14.686728637274864,14.43924371942795,14.191758801581077,13.944273883734173,13.704521797332214,13.467049904577049,13.229578011821873,12.992106119066694,12.754634226311545,12.518225660161967,12.291145374983536,12.064065089805114,11.836984804626713,11.609904519448282,11.38354365497499,11.165576019443256,10.947608383911538,10.729640748379804,10.511673112848113,10.299256446484648,10.09057897412334,9.881901501762053,9.67322402940071,9.471480743033515,9.274866855141251,9.078252967248947,8.881639079356642,8.6974369537342,8.513973624595657,8.330510295457078,8.154890753764949,7.983494789210959,7.812098824656934,7.647833453220475,7.487433613992127,7.32703377476376,7.175691650943162,7.025334061946603,6.8784512624270455,6.737254481062629,6.596511846822511,6.463691556331176,6.330871265839823,6.2051247139504255,6.080126346199391,5.963427213660504,5.848102833312801,5.742113513543231,5.638421846044453,5.539434895429187,5.444130022002152,5.351623281541863,5.264376113019016,5.182539450212195,5.10496521215094,5.031824791606367,4.963111367261917,4.880664242730574,4.798217118199215,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[67.03386863598935,67.08191093252714,67.1299532290649,67.17799552560268,67.22603782214046,67.27408011867823,67.322122415216,67.37016471175379,67.41820700829156,67.46633636331906,67.51490101299855,67.56346566267806,67.61203031235756,67.66059496203707,67.70915961171657,67.75772426139606,67.80628891107557,67.85485356075507,67.90341821043458,67.95198286011409,68.00054750979358,68.04911215947308,68.0976768091526,68.1462414588321,68.1948061085116,68.2433707581911,68.29193540787061,68.34050005755012,68.38906470722961,68.43762935690911,68.48619400658862,68.53475865626812,68.58332330594763,68.63188795562714,68.68045260530664,68.72901725498613,68.77758190466564,68.82614655434514,68.87471120402465,68.92327585370415,68.97184050338365,69.02040515306315,69.06896980274266,69.11753445242216,69.16609910210167,69.21466375178117,69.26322840146068,69.31179305114017,69.36035770081968,69.40892235049918,69.45748700017869,69.5060516498582,69.55461629953768,69.60318094921719,69.6517455988967,69.7003102485762,69.7488748982557,69.7974395479352,69.8460041976147,69.89456884729421,69.94313349697372,69.99169814665322,70.04026279633271,70.08882744601223,70.13739209569172,70.18595674537124,70.23452139505073,70.28308604473024,70.33165069440975,70.38021534408925,70.42877999376876,70.47734464344825,70.52590929312777,70.57447394280726,70.62303859248676,70.67160324216627,70.72016789184576,70.76873254152528,70.81729719120477,70.86586184088428,70.91442649056378,70.96299114024329,71.0115557899228,71.06012043960229,71.0938257338916,71.1245591571029,71.15529258031418,71.18602600352546,71.21675942673674,71.24749284994803,71.2782262731593,71.3089596963706,71.33969311958187,71.37042654279315,71.40115996600444,71.43189338921573,71.46262681242702,71.49336023563829,71.52409365884958,71.55482708206085,71.58556050527214,71.61629392848343,71.6470273516947,71.67776077490599,71.70849419811728,71.73922762132855,71.76996104453984,71.80069446775113,71.8314278909624,71.8621613141737,71.89289473738498,71.92362816059625,71.95436158380754,71.98509500701883,72.0158284302301,72.0465618534414,72.07729527665266,72.10802869986395,72.13876212307524,72.16949554628653,72.2002289694978,72.23096239270907,72.26169581592036,72.29242923913165,72.32316266234294,72.35389608555423,72.3846295087655,72.41536293197679,72.44609635518808,72.47682977839935,72.50756320161064,72.53829662482191,72.5690300480332,72.59976347124449,72.63049689445577,72.66123031766705,72.69196374087834,72.72269716408962,72.7534305873009,72.78416401051219,72.81489743372346,72.84563085693475,72.87636428014603,72.90709770335731,72.9378311265686,72.96856454977987,72.99929797299117,73.03003139620246,73.06076481941373,73.09149824262502,73.1222316658363,73.15296508904758,73.18369851225887,73.21443193547016,73.24516535868145,73.27589878189272,73.306632205104,73.33736562831528,73.36698043030356,73.39547661421456,73.42397279812556,73.45246898203656,73.48096516594757,73.50946134985858,73.53795753376957,73.56645371768057,73.59494990159158,73.46262946687237,73.24990072283806,73.03717197880373,72.82444323476942,72.61171449073511,72.3989857467008,72.18625700266648,71.97352825863216,71.76079951459785,71.54807077056356,71.33534202652922,71.12261328249491,70.9098845384606,70.69715579442628,70.48442705039197,70.27169830635766,70.05896956232334,69.84624081828903,69.65723530385898,69.46822980474586,69.27922430563275,69.09021880651963,68.90121330740654,68.7122078082934,68.5232023091803,68.3341968100672,68.14519131095406,67.95618581184097,67.76718031272785,67.57817481361474,67.38916931450163,67.2001638153885,67.01115831627541,66.82215281716229,66.63314731804917,66.44414181893606,66.25513631982295,66.06613082070984,65.87712532159672,65.68811982248361,65.4991143233705,65.3101088242574,65.12110332514428,64.93209782603115,64.74309232691805,64.55408682780494,64.36508132869183,64.1760758295787,63.9870703304656,63.79806483135248,63.60905933223937,63.42005383312626,63.231048334013146,63.042042834900045,62.85303733578691,62.664031836673814,62.47502633756069,62.286020838447584,62.09701533933447,61.908009840221354,61.71900434110825,61.52999884199513,61.34099334288203,61.15198784376891,60.9629823446558,60.773976845542684,60.584971346429576,60.39596584731646,60.20696034820334,60.017954849090245,59.82894934997712,59.639943850864015,59.45093835175089,59.261932852637784,59.072927353524676,58.883921854411554,58.694916355298446,58.505910856185324,58.31690535707222,58.12789985795911,57.938894358846,57.74988885973288,57.56088336061976,57.148512161863195,56.51277526346314,55.87703836506318,55.2413014666632,54.60556456826315,53.96982766986318,53.33409077146319,52.69835387306317,52.062616974663115,51.426880076263195,50.79114317786318,50.15392404024431,49.5148112039874,48.87569836773047,48.236585531473494,47.59747269521657,46.95835985895966,46.319247022702676,45.68013418644577,45.041021350188814,44.40190851393186,43.76279567767488,43.12368284141802,42.484570005161025,41.84545716890406,41.206344332647134,40.56723149639023,40.23175549060038,40.374953398456135,40.5181513063119,40.66134921416768,40.80454712202346,40.9477450298792,41.09094293773499,41.23414084559075,41.377338753446516,41.52053666130227,41.66373456915806,41.80693247701382,41.950130384869574,42.09332829272536,42.23652620058112,42.37972410843688,42.52292201629265,42.66611992414843,42.809317832004176,42.952515739859955,43.09571364771573,43.22553989069099,42.931939445500035,42.63833900030899,42.34473855511804,42.051138109927095,41.757537664736084,41.46393721954504,41.17033677435414,40.87673632916314,40.58313588397213,40.289535438781144,39.99593499359019,39.70233454839919,39.408734103208154,39.11513365801721,38.8215332128262,38.52793276763521,38.23433232244426,37.940731877253256,37.647131432062245,37.35353098687131,37.05993054168031,36.76633009648931,36.47272965129835,36.18075222401841,35.89048798099527,35.600223737972215,35.309959494949155,35.01969525192605,34.729431008902964,34.43916676587987,34.148902522856766,33.85863827983366,33.5683740368106,33.278109793787515,32.987845550764405,32.69758130774131,32.40731706471826,32.117052821695154,31.826788578672097,31.536524335649005,31.246260092625896,30.955995849602754,30.66957090415065,30.383674302910173,30.09777770166973,29.811881100429336,29.525984499188947,29.24008789794847,28.954191296708075,28.668294695467683,28.38239809422724,28.09650149298681,27.81060489174638,27.52470829050594,27.238811689265535,26.952915088025104,26.667018486784677,26.385792882540095,26.10571379786941,25.8256347131987,25.54555562852798,25.26547654385726,24.98539745918655,24.70531837451586,24.425239289845138,24.145160205174466,23.86508112050371,23.58500203583299,23.304922951162272,23.027501779988828,22.755240084333266,22.482978388677743,22.210716693022196,21.938454997366634,21.666193301711083,21.393931606055528,21.1216699104,20.849408214744436,20.577146519088885,20.304884823433365,20.039369171309655,19.774906093487807,19.510443015665935,19.24597993784408,18.981516860022207,18.71705378220036,18.452590704378448,18.18812762655656,17.92366454873473,17.66663588310982,17.410102846148266,17.153569809186752,16.89703677222521,16.64050373526366,16.383970698302118,16.12743766134058,15.873058939651607,15.625574021804713,15.37808910395782,15.130604186110938,14.883119268264029,14.63563435041715,14.388149432570243,14.14596844404949,13.908496551294347,13.67102465853918,13.433552765784025,13.196080873028862,12.958608980273699,12.727710382765398,12.500630097586967,12.273549812408579,12.046469527230146,11.819389242051715,11.596025959738949,11.378058324207228,11.16009068867551,10.9421230531438,10.724155417612067,10.513126493477086,10.30444902111576,10.095771548754474,9.887094076393149,9.685208306730633,9.488594418838368,9.291980530946077,9.095366643053758,8.909095890169663,8.725632561031084,8.542169231892501,8.363058774035677,8.191662809481688,8.020266844927663,7.851497940930721,7.691098101702384,7.530698262474017,7.374138106650699,7.22378051765414,7.073422928657571,6.930014918254891,6.788818136890502,6.650472390100161,6.517652099608799,6.385648009518176,6.260649641767149,6.135931309939602,6.020046825841726,5.9051758627317685,5.799186542962177,5.695330757432028,5.59634380681678,5.500583552786234,5.40709866021267,5.319851491689823,5.236588422817235,5.1574195765329165,5.083260340298592,5.013879834425971,4.936337602818513,4.853890478287154,4.771443353755808,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[67.10067568991397,67.14871798645174,67.19676028298952,67.24480257952729,67.29284487606508,67.34088717260283,67.38892946914062,67.4369717656784,67.48501406221617,67.53305635875394,67.58109865529173,67.6291409518295,67.67718324836727,67.72522554490504,67.77326784144283,67.8213101379806,67.86935243451838,67.91739473105615,67.96543702759392,68.01347932413171,68.06152162066948,68.10956391720725,68.15760621374503,68.2056485102828,68.25369080682057,68.30173310335836,68.35012363487053,68.39868828455003,68.44725293422954,68.49581758390904,68.54438223358855,68.59294688326804,68.64151153294756,68.69007618262705,68.73864083230656,68.78720548198606,68.83577013166556,68.88433478134507,68.93289943102457,68.98146408070407,69.03002873038358,69.07859338006307,69.12715802974259,69.17572267942208,69.22428732910159,69.27285197878109,69.3214166284606,69.3699812781401,69.4185459278196,69.4671105774991,69.5156752271786,69.56423987685811,69.61280452653762,69.66136917621712,69.70993382589663,69.75849847557612,69.80706312525562,69.85562777493513,69.90419242461464,69.95275707429414,70.00132172397365,70.04988637365314,70.09845102333264,70.14701567301216,70.19558032269165,70.24414497237116,70.29270962205067,70.34127427173016,70.38983892140966,70.43840357108917,70.48696822076867,70.53553287044818,70.58409752012768,70.63266216980719,70.68122681948668,70.72979146916619,70.77835611884569,70.8269207685252,70.8754854182047,70.9240500678842,70.97261471756372,71.0211793672432,71.06974401692271,71.11830866660222,71.15201396089154,71.18274738410281,71.2134808073141,71.24421423052539,71.27494765373666,71.30568107694795,71.33641450015924,71.36714792337051,71.3978813465818,71.42861476979309,71.45934819300437,71.49008161621565,71.52081503942694,71.55154846263821,71.58228188584951,71.61301530906078,71.64374873227206,71.67448215548335,71.70521557869463,71.73594900190591,71.7666824251172,71.79741584832848,71.82814927153976,71.85888269475105,71.88961611796233,71.92034954117361,71.9510829643849,71.98181638759618,72.01254981080746,72.04328323401874,72.07401665723003,72.1047500804413,72.1354835036526,72.16621692686388,72.19695035007517,72.22768377328644,72.25841719649773,72.289150619709,72.3198840429203,72.35061746613158,72.38135088934285,72.41208431255414,72.44281773576543,72.4735511589767,72.50428458218799,72.53501800539928,72.56575142861057,72.59648485182184,72.62721827503313,72.65795169824442,72.68868512145569,72.71941854466698,72.75015196787825,72.78088539108954,72.81161881430083,72.8423522375121,72.87308566072339,72.90381908199265,72.93231526590365,72.96081144981466,72.98930763372567,73.01780381763666,73.04630000154768,73.07479618545867,73.10329236936968,73.13178855328069,73.16028473719169,73.18878092110268,73.2172771050137,73.2457732889247,73.2742694728357,73.3027656567467,73.3312618406577,73.35975802456869,73.38825420847971,73.41675039239071,73.44524657630171,73.47374276021272,73.50223894412372,73.53073512803473,73.55923131194572,73.58772749585673,73.61622367976773,73.48390324504852,73.27117450101422,73.05844575697989,72.84571701294558,72.63298826891128,72.42025952487695,72.20753078084263,71.99480203680831,71.782073292774,71.56934454873969,71.35661580470537,71.14388706067106,70.93115831663675,70.71842957260245,70.50570082856814,70.29297208453382,70.0802433404995,69.86751459646518,69.65478585243088,69.44205710839655,69.22932836436225,69.01659962032792,68.80387087629363,68.5911421322593,68.378413388225,68.16568464419068,67.95295590015637,67.74022715612206,67.52749841208774,67.31476966805343,67.10204092401911,66.88931217998478,66.67658343595048,66.46385469191617,66.25112594788186,66.03839720384755,65.82566845981322,65.61293971577892,65.4002109717446,65.18748222771029,64.97475348367598,64.76202473964166,64.54929599560735,64.33656725157303,64.12383850753872,63.9111097635044,63.69838101947009,63.48565227543578,63.27292353140146,63.06019478736714,62.84746605388454,62.65846055477144,62.46945505565832,62.280449556545214,62.09144405743209,61.90243855831899,61.713433059205876,61.52442756009276,61.33542206097965,61.14641656186652,60.95741106275342,60.76840556364031,60.5794000645272,60.390394565414084,60.201389066300976,60.01238356718786,59.823378068074746,59.63437256896164,59.44536706984852,59.256361570735415,59.0673560716223,58.87835057250919,58.68934507339607,58.50033957428296,58.31133407516985,58.12232857605673,57.93332307694362,57.74431757783051,57.5553120787174,57.366306579604284,57.177301080491176,56.98829558137806,56.79929008226494,56.38691888350838,55.75118198510832,55.11544508670835,54.479708188308386,53.84397128990833,53.20819473372253,52.56908189746562,51.92996906120863,51.29085622495167,50.65174338869481,50.01263055243783,49.37351771618086,48.73440487992394,48.095292043667015,47.45617920741004,46.8170663711531,46.177953534896204,45.53884069863922,44.899727862382306,44.26061502612536,43.6215021898684,42.982389353611424,42.34327651735456,42.26767772937808,42.410875637233865,42.55407354508962,42.69727145294539,42.84046936080116,42.983667268656916,43.12686517651268,43.27006308436846,43.41326099222424,43.55645890007998,43.69965680793577,43.84285471579153,43.986052623647296,44.129250531503054,44.27244843935883,44.41564634721459,44.55884425507036,44.70204216292614,44.50649819309576,44.21289774790481,43.91929730271377,43.62569685752277,43.332096412331815,43.03849596714082,42.74489552194982,42.451295076758825,42.15769463156787,41.864094186376825,41.57049374118588,41.276893295994924,40.98329285080393,40.689692405612874,40.39609196042198,40.10249151523097,39.80889107003998,39.51529062484899,39.221690179658026,38.92808973446702,38.63448928927599,38.34088884408504,38.04728839889404,37.75368795370304,37.461169520690845,37.17090527766774,36.88064103464465,36.590376791621566,36.30011254859849,36.00984830557539,35.7195840625523,35.42931981952924,35.1390555765061,34.84879133348304,34.55852709045999,34.26826284743688,33.977998604413784,33.687734361390696,33.39747011836759,33.10720587534449,32.81694163232143,32.52667738929834,32.23641314627523,31.94614890325214,31.660252301546766,31.374355700306324,31.088459099065894,30.80256249782547,30.51666589658506,30.230769295344622,29.94487269410424,29.65897609286376,29.37307949162332,29.087182890382927,28.801286289142535,28.51538968790206,28.229493086661666,27.94359648542127,27.657699884180833,27.37379907152077,27.093719986850093,26.81364090217937,26.53356181750864,26.25348273283793,25.973403648167253,25.693324563496525,25.413245478825846,25.133166394155136,24.853087309484415,24.573008224813698,24.292929140142984,24.012850055472295,23.735897927687155,23.463636232031647,23.19137453637608,22.919112840720523,22.646851145065,22.37458944940945,22.102327753753887,21.830066058098364,21.557804362442816,21.285542666787254,21.013280971131707,20.74508603925704,20.48062296143518,20.216159883613297,19.95169680579142,19.68723372796958,19.422770650147665,19.158307572325818,18.89384449450395,18.62938141668209,18.366900847922967,18.110367810961424,17.85383477399987,17.59730173703832,17.340768700076815,17.084235663115265,16.827702626153712,16.5711695891922,16.31693448848768,16.06944957064077,15.82196465279388,15.57447973494701,15.326994817100104,15.07950989925321,14.832024981406317,14.587415090766802,14.349943198011621,14.112471305256491,13.874999412501337,13.63752751974614,13.400055626990996,13.164275390547266,12.937195105368833,12.710114820190434,12.483034535012013,12.25595424983358,12.028873964655148,11.80850826450295,11.590540628971217,11.372572993439464,11.15460535790776,10.936637722376037,10.726996540469543,10.518319068108257,10.309641595746914,10.100964123385587,9.898935870427763,9.702321982535484,9.505708094643179,9.309094206750876,9.12075482660509,8.93729149746651,8.75382816832793,8.57122679430644,8.39983082975243,8.228434865198393,8.057038900644368,7.894762589412654,7.734362750184285,7.573962910955908,7.422226973361688,7.271869384365109,7.122775355447153,6.9815785740827545,6.840381792718347,6.704432933377776,6.57161264288644,6.441172937334899,6.316174569583849,6.192550922120811,6.076666438022958,5.962248892150727,5.856259572381137,5.752239668819621,5.65325271820436,5.557037083570299,5.463215449996007,5.375326870360648,5.290637395422258,5.210325511555506,5.135714704680582,5.064648301590019,4.992010962906453,4.90956383837511,4.82711671384375,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[67.16748274383858,67.21552504037636,67.26356733691412,67.31160963345191,67.35965192998968,67.40769422652745,67.45573652306524,67.503778819603,67.55182111614079,67.59986341267856,67.64790570921633,67.69594800575412,67.74399030229188,67.79203259882966,67.84007489536744,67.88811719190522,67.936159488443,67.98420178498075,68.03224408151854,68.08028637805631,68.12832867459409,68.17637097113187,68.22441326766963,68.27245556420742,68.32049786074519,68.36854015728296,68.41658245382075,68.46462475035852,68.5126670468963,68.56070934343407,68.60875163997184,68.65679393650963,68.70483623304739,68.75287852958517,68.80092082612295,68.84896312266073,68.8970054191985,68.94504771573628,68.99309001227405,69.04113230881183,69.0891746053496,69.13721690188738,69.1853462567425,69.23391090642201,69.28247555610152,69.33104020578102,69.37960485546051,69.42816950514003,69.47673415481952,69.52529880449903,69.57386345417854,69.62242810385803,69.67099275353755,69.71955740321704,69.76812205289654,69.81668670257605,69.86525135225554,69.91381600193506,69.96238065161455,70.01094530129406,70.05950995097356,70.10807460065307,70.15663925033257,70.20520390001207,70.25376854969159,70.30233319937108,70.35089784905058,70.39946249873009,70.4480271484096,70.4965917980891,70.5451564477686,70.5937210974481,70.6422857471276,70.69085039680711,70.73941504648661,70.78797969616612,70.83654434584562,70.88510899552512,70.93367364520462,70.98223829488413,71.03080294456363,71.07936759424314,71.12793224392263,71.17649689360215,71.21020218789145,71.24093561110274,71.27166903431402,71.30240245752532,71.33313588073659,71.36386930394787,71.39460272715915,71.42533615037044,71.45606957358173,71.486802996793,71.51753642000429,71.54826984321556,71.57900326642687,71.60973668963814,71.64047011284943,71.67120353606072,71.70193695927199,71.73267038248328,71.76340380569457,71.79413722890584,71.82487065211713,71.85560407532842,71.88633749853969,71.91707092175098,71.94780434496225,71.97853776817354,72.00927119138481,72.0400046145961,72.07073803780739,72.10147146101868,72.13220488422996,72.16293830744124,72.19367173065251,72.2244051538638,72.25513857707509,72.28587200028637,72.31660542349766,72.34733884670894,72.37807226992021,72.4088056931315,72.43953911634279,72.46915391759276,72.49765010150377,72.52614628541477,72.55464246932577,72.58313865323677,72.61163483714778,72.64013102105878,72.6686272049698,72.69712338888078,72.72561957279179,72.75411575670279,72.78261194061379,72.8111081245248,72.83960430843581,72.8681004923468,72.89659667625781,72.9250928601688,72.95358904407982,72.98208522799082,73.01058141190182,73.03907759581283,73.06757377972383,73.09606996363483,73.12456614754583,73.15306233145684,73.18155851536784,73.21005469927884,73.23855088318984,73.26704706710085,73.29554325101185,73.32403943492285,73.35253561883385,73.38103180274487,73.40952798665586,73.43802417056686,73.46652035447786,73.49501653838887,73.52351272229988,73.55200890621089,73.58050509012187,73.60900127403289,73.63749745794388,73.50517702322468,73.29244827919037,73.07971953515604,72.86699079112172,72.65426204708741,72.44153330305312,72.2288045590188,72.01607581498446,71.80334707095015,71.59061832691584,71.37788958288154,71.16516083884723,70.9524320948129,70.7397033507786,70.52697460674429,70.31424586270998,70.10151711867564,69.88878837464134,69.67605963060703,69.46333088657272,69.2506021425384,69.03787339850409,68.82514465446978,68.61241591043546,68.39968716640115,68.18695842236683,67.97422967833252,67.76150093429821,67.54877219026389,67.33604344622958,67.12331470219527,66.91058595816094,66.69785721412664,66.48512847009232,66.27239972605801,66.0596709820237,65.84694223798938,65.63421349395507,65.42148474992075,65.20875600588644,64.99602726185213,64.78329851781783,64.57056977378349,64.3578410297492,64.14511228571487,63.93238354168056,63.71965479764624,63.506926053611934,63.29419730957761,63.0814685655433,62.86873982150898,62.65601107747468,62.443282333440365,62.23055358940605,62.017824845371734,61.805096101337426,61.59236735730311,61.3796386132688,61.16690986923448,60.95418112520017,60.74145238116586,60.52872363713154,60.31599489309722,60.10326614906292,59.8905374050286,59.67780866099428,59.46507991695997,59.25235117292565,59.039622428891334,58.82689368485703,58.61416494082272,58.401436196788396,58.18870745275409,57.97597870871977,57.76324996468547,57.550521220651156,57.33779247661684,57.12506373258252,56.91233498854821,56.699606244513895,56.48687750047958,56.274148756445264,56.06142001241095,55.623352590943824,54.98423975468682,54.34512691842991,53.706014082172985,53.06690124591601,52.42778840965908,51.788675573402166,51.149562737145175,50.51044990088821,49.871337064631355,49.23222422837438,48.5931113921174,47.95399855586049,47.31488571960356,46.67577288334658,46.036660047089654,45.39754721083274,44.75843437457576,44.16040206030005,44.303599968155815,44.44679787601158,44.58999578386736,44.7331936917231,44.87639159957888,45.01958950743466,45.162787415290424,45.30598532314619,45.44918323100195,45.59238113885772,45.735579046713475,45.87877695456926,46.02197486242504,46.16517277028078,46.08105694069149,45.787456495500486,45.49385605030953,45.2002556051185,44.9066551599275,44.61305471473654,44.31945426954555,44.02585382435455,43.732253379163595,43.43865293397265,43.1450524887816,42.851452043590605,42.55785159839966,42.26425115320866,41.97065070801765,41.67705026282666,41.38344981763571,41.08984937244467,40.796248927253714,40.50264848206277,40.209048036871756,39.91544759168072,39.62184714648981,39.328246701298816,39.03464625610781,38.74158681736328,38.45132257434019,38.16105833131708,37.870794088294026,37.58052984527093,37.290265602247864,37.00000135922477,36.70973711620168,36.41947287317858,36.129208630155475,35.838944387132386,35.548680144109326,35.25841590108622,34.96815165806313,34.67788741504007,34.38762317201693,34.09735892899387,33.80709468597081,33.516830442947715,33.22656619992462,32.936830300183324,32.650933698942886,32.36503709770248,32.07914049646205,31.793243895221625,31.507347293981184,31.221450692740788,30.93555409150036,30.64965749025992,30.36376088901949,30.077864287779065,29.791967686538655,29.506071085298217,29.220174484057832,28.934277882817355,28.648381281576913,28.362484680336518,28.0817261758308,27.801647091160035,27.52156800648936,27.241488921818647,26.961409837147926,26.681330752477212,26.401251667806534,26.12117258313581,25.841093498465085,25.561014413794368,25.280935329123697,25.00085624445297,24.72077715978229,24.444294075385567,24.172032379730005,23.89977068407445,23.627508988418935,23.35524729276337,23.08298559710778,22.81072390145227,22.538462205796705,22.266200510141143,21.99393881448562,21.721677118830073,21.450802907204398,21.186339829382526,20.92187675156068,20.657413673738766,20.392950595916925,20.12848751809505,19.86402444027319,19.599561362451308,19.33509828462943,19.070635206807587,18.81063277577453,18.554099738813015,18.2975667018515,18.041033664889948,17.78450062792841,17.527967590966867,17.271434554005314,17.014901517043764,16.76081003732375,16.513325119476846,16.265840201629942,16.01835528378305,15.770870365936178,15.52338544808927,15.275900530242378,15.028861737484112,14.791389844728956,14.553917951973792,14.316446059218649,14.078974166463452,13.841502273708272,13.60403038095314,13.373760113150698,13.146679827972264,12.919599542793865,12.692519257615443,12.465438972437012,12.238958204798646,12.020990569266925,11.80302293373519,11.585055298203455,11.367087662671764,11.14954405982329,10.94086658746198,10.732189115100667,10.52351164273937,10.314834170378045,10.112663434124904,9.916049546232616,9.719435658340311,9.522821770448008,9.332413763040517,9.14895043390195,8.965487104763355,8.782023775624813,8.607998850023147,8.436602885469123,8.265206920915132,8.098427077122901,7.9380272378945325,7.777627398666177,7.620673429069225,7.470315840072647,7.319958251076068,7.174339011275027,7.033142229910619,6.891945448546193,6.758393476655417,6.625573186164047,6.4966978651515985,6.371699497400565,6.249170534302056,6.133286050204174,6.0193219215696745,5.913332601800105,5.809148580207196,5.710161629591928,5.613490614354381,5.51966898078007,5.430802249031456,5.344686368027298,5.264374484160545,5.188169069062558,5.115416768754063,5.046703344409626,4.965237198463051,4.882790073931689,4.8003429494003464,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[67.2342897977632,67.28233209430098,67.33037439083876,67.37841668737653,67.4264589839143,67.47450128045207,67.52254357698985,67.57058587352762,67.6186281700654,67.66667046660318,67.71471276314095,67.76275505967874,67.81079735621651,67.85883965275428,67.90688194929206,67.95492424582983,68.00296654236762,68.05100883890539,68.09905113544316,68.14709343198093,68.19513572851871,68.2431780250565,68.29122032159427,68.33926261813204,68.38730491466981,68.43534721120758,68.48338950774536,68.53143180428314,68.57947410082092,68.62751639735869,68.67555869389646,68.72360099043425,68.77164328697202,68.8196855835098,68.86772788004757,68.91577017658534,68.96381247312313,69.01185476966089,69.05989706619867,69.10793936273646,69.15598165927423,69.204023955812,69.25206625234978,69.30010854888755,69.34815084542532,69.39619314196311,69.44423543850087,69.49227773503866,69.54032003157644,69.5883623281142,69.63640462465199,69.68444692118976,69.73248921772753,69.7805315142653,69.82857381080308,69.87661610734087,69.92465840387864,69.97270070041642,70.0207429969542,70.06913352829397,70.1176981779735,70.166262827653,70.21482747733249,70.263392127012,70.31195677669149,70.36052142637101,70.4090860760505,70.45765072573,70.50621537540951,70.55478002508902,70.60334467476852,70.65190932444803,70.70047397412753,70.74903862380702,70.79760327348653,70.84616792316604,70.89473257284554,70.94329722252505,70.99186187220455,71.04042652188406,71.08899117156355,71.13755582124305,71.18612047092256,71.23468512060207,71.26839041489137,71.29912383810266,71.32985726131395,71.36059068452523,71.39132410773651,71.4220575309478,71.45279095415907,71.48352437737037,71.51425780058165,71.54499122379293,71.57572464700422,71.6064580702155,71.63719149342678,71.66792491663806,71.69865833984935,71.72939176306065,71.7601251862719,71.79085860948321,71.82159203269447,71.85232545590577,71.88305887911704,71.91379230232833,71.94452572553962,71.9752591487509,72.00599256928187,72.03448875319287,72.06298493710388,72.09148112101488,72.11997730492588,72.14847348883688,72.17696967274789,72.20546585665889,72.23396204056988,72.2624582244809,72.2909544083919,72.3194505923029,72.34794677621392,72.3764429601249,72.40493914403591,72.43343532794691,72.46193151185791,72.49042769576891,72.51892387967992,72.54742006359092,72.57591624750194,72.60441243141292,72.63290861532393,72.66140479923493,72.68990098314595,72.71839716705693,72.74689335096795,72.77538953487894,72.80388571878996,72.83238190270096,72.86087808661196,72.88937427052296,72.91787045443397,72.94636663834497,72.97486282225597,73.00335900616697,73.03185519007798,73.06035137398898,73.08884755789998,73.117343741811,73.14583992572199,73.17433610963299,73.20283229354399,73.231328477455,73.25982466136601,73.288320845277,73.316817029188,73.34531321309902,73.37380939701,73.40230558092102,73.43080176483203,73.45929794874301,73.48779413265402,73.51629031656503,73.54478650047602,73.57328268438704,73.60177886829804,73.63027505220904,73.65877123612003,73.52645080140083,73.31372205736653,73.10099331333221,72.8882645692979,72.67553582526358,72.46280708122926,72.25007833719495,72.03734959316063,71.82462084912632,71.61189210509201,71.39916336105769,71.18643461702338,70.97370587298906,70.76097712895475,70.54824838492044,70.33551964088613,70.12279089685182,69.9100621528175,69.69733340878318,69.48460466474887,69.27187592071456,69.05914717668024,68.84641843264593,68.63368968861161,68.42096094457732,68.20823220054298,67.99550345650867,67.78277471247436,67.57004596844004,67.35731722440573,67.14458848037143,66.9318597363371,66.7191309923028,66.50640224826849,66.29367350423416,66.08094476019986,65.86821601616553,65.65548727213124,65.44275852809692,65.2300297840626,65.01730104002829,64.80457229599398,64.59184355195966,64.37911480792535,64.16638606389103,63.95365731985671,63.74092857582241,63.52819983178809,63.31547108775378,63.10274233744545,62.865720258268226,62.62869817909102,62.39167609991381,62.15465402073659,61.91763194155938,61.68060986238218,61.44358778320495,61.20656570402774,60.969543624850516,60.7325215456733,60.4954994664961,60.25847738731888,60.02145530814167,59.784433228964446,59.547411149787244,59.31038907061002,59.07336699143281,58.83634491225559,58.599322833078375,58.362300753901174,58.12527867472396,57.888256595546736,57.65123451636952,57.414212437192305,57.1771903580151,56.94016827883789,56.703146199660665,56.46612412048345,56.22910204130624,55.992079962129026,55.75505788295181,55.518035803774595,55.28101372459738,54.84294626688033,54.203833430623334,53.56472059436642,52.9256077581095,52.28649492185252,51.64738208559559,51.008269249338674,50.36915641308169,49.73004357682473,49.09093074056787,48.451817904310886,47.812705068053916,47.173592231797,46.534479395540075,46.196324299077865,46.33952220693362,46.48272011478939,46.62591802264517,46.76911593050093,46.91231383835669,47.05551174621246,47.19870965406824,47.34190756192399,47.48510546977976,47.62830337763555,47.655615688287135,47.36201524309619,47.068414797905184,46.774814352714195,46.48121390752324,46.18761346233224,45.89401301714124,45.60041257195025,45.30681212675929,45.013211681568286,44.71961123637735,44.42601079118631,44.132410345995304,43.83880990080435,43.54520945561335,43.25160901042236,42.9580085652314,42.664408120040456,42.37080767484941,42.077207229658406,41.78360678446746,41.49000633927646,41.19640589408546,40.90280544889446,40.609205003703515,40.31560455851247,40.02200411403569,39.731739871012635,39.441475627989526,39.15121138496642,38.86094714194334,38.57068289892023,38.28041865589714,37.99015441287408,37.69989016985098,37.40962592682788,37.11936168380482,36.82909744078173,36.53883319775866,36.24856895473557,35.95830471171248,35.66804046868937,35.37777622566627,35.087511982643186,34.79724773962012,34.506983496597016,34.21671925357393,33.927511697579455,33.64161509633902,33.355718495098586,33.06982189385819,32.78392529261775,32.498028691377314,32.21213209013689,31.92623548889645,31.640338887656046,31.354442286415615,31.068545685175188,30.782649083934743,30.49675248269435,30.210855881453924,29.924959280213482,29.639062678973055,29.353166077732624,29.06973236481144,28.789653280140715,28.50957419547005,28.22949511079929,27.9494160261286,27.669336941457885,27.38925785678721,27.10917877211645,26.829099687445773,26.549020602775062,26.268941518104338,25.988862433433624,25.708783348762942,25.42870426409222,25.152690223083866,24.880428527428315,24.608166831772763,24.335905136117233,24.06364344046168,23.791381744806163,23.519120049150597,23.246858353495046,22.974596657839527,22.702334962183965,22.43007326652837,22.157811570872862,21.892056697329902,21.62759361950799,21.363130541686143,21.098667463864267,20.834204386042384,20.569741308220514,20.305278230398667,20.04081515257675,19.77635207475491,19.51188899693303,19.254364703626138,18.997831666664585,18.741298629703046,18.484765592741528,18.228232555779954,17.971699518818433,17.715166481856922,17.45863344489537,17.20468558615979,16.957200668312893,16.709715750466014,16.462230832619085,16.214745914772227,15.967260996925319,15.719776079078416,15.47229116123152,15.232836491446246,14.995364598691069,14.757892705935905,14.52042081318074,14.282948920425586,14.045477027670422,13.810325120932546,13.58324483575411,13.356164550575677,13.129084265397292,12.90200398021886,12.674923695040423,12.4514405095626,12.233472874030877,12.015505238499143,11.79753760296744,11.579569967435717,11.36341410681573,11.154736634454387,10.946059162093121,10.737381689731777,10.528704217370464,10.326390997821994,10.129777109929718,9.933163222037397,9.736549334145131,9.544072699475944,9.360609370337349,9.177146041198782,8.993682712060224,8.816166870293863,8.644770905739852,8.47337494118586,8.302091564833159,8.14169172560479,7.9812918863764555,7.820892047148076,7.668762295780175,7.518404706783606,7.368047117787047,7.225902667102863,7.084705885738456,6.945174310424385,6.812354019933023,6.679533729441663,6.552222792968315,6.427224425217263,6.305790146483266,6.189905662385412,6.076394950988648,5.970405631219059,5.86605749159477,5.767070540979522,5.669944145138441,5.576122511564135,5.486277627702275,5.399030459179428,5.318423456765564,5.240623433444549,5.166464197210219,5.097471811573667,5.020910558550986,4.938463434019641,4.856016309488282,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[67.30109685168782,67.34913914822559,67.39718144476336,67.44522374130115,67.49326603783892,67.5413083343767,67.58935063091447,67.63739292745224,67.68543522399001,67.7334775205278,67.78151981706557,67.82956211360334,67.87760441014112,67.92564670667889,67.97368900321668,68.02173129975445,68.06977359629222,68.11781589283,68.16585818936777,68.21390048590555,68.26194278244333,68.3099850789811,68.35802737551887,68.40606967205665,68.45411196859442,68.50215426513219,68.55019656166998,68.59823885820775,68.64628115474552,68.69432345128331,68.74236574782108,68.79040804435886,68.83845034089663,68.8864926374344,68.93453493397217,68.98257723050996,69.03061952704773,69.07866182358552,69.12670412012329,69.17474641666107,69.22278871319884,69.27083100973661,69.31887330627438,69.36691560281217,69.41495789934994,69.46300019588773,69.5110424924255,69.55908478896328,69.60712708550105,69.65516938203882,69.7032116785766,69.75125397511437,69.79929627165215,69.84733856818993,69.8953808647277,69.94342316126549,69.99146545780326,70.03950775434103,70.0875500508788,70.13559234741658,70.18363464395435,70.23167694049212,70.27971923702991,70.32776153356768,70.37580383010545,70.42384612664324,70.47188842318101,70.51993071971877,70.56797301625656,70.61601531279433,70.66405760933212,70.71209990586989,70.76014220240766,70.80818449894544,70.85622679548321,70.90435615016597,70.95292079984546,71.00148544952498,71.05005009920447,71.09861474888397,71.14717939856348,71.19574404824297,71.24430869792249,71.29287334760198,71.32657864189132,71.3573120651026,71.38804548831388,71.41877891152515,71.44951233473644,71.48024575794773,71.510979181159,71.54171260437029,71.57132740488197,71.59982358879297,71.62831977270397,71.65681595661498,71.68531214052598,71.71380832443698,71.74230450834798,71.77080069225899,71.79929687616999,71.827793060081,71.856289243992,71.88478542790301,71.91328161181401,71.94177779572502,71.97027397963602,71.99877016354702,72.02726634745802,72.05576253136903,72.08425871528003,72.11275489919103,72.14125108310203,72.16974726701304,72.19824345092404,72.22673963483504,72.25523581874604,72.28373200265705,72.31222818656805,72.34072437047905,72.36922055439007,72.39771673830106,72.42621292221207,72.45470910612306,72.48320529003408,72.51170147394507,72.54019765785608,72.56869384176707,72.59719002567809,72.62568620958908,72.65418239350008,72.68267857741108,72.7111747613221,72.73967094523309,72.7681671291441,72.79666331305509,72.82515949696611,72.85365568087711,72.88215186478811,72.91064804869912,72.93914423261012,72.96764041652112,72.99613660043212,73.02463278434313,73.05312896825413,73.08162515216513,73.11012133607613,73.13861751998714,73.16711370389814,73.19560988780914,73.22410607172014,73.25260225563115,73.28109843954215,73.30959462345317,73.33809080736415,73.36658699127516,73.39508317518617,73.42357935909718,73.45207554300818,73.48057172691918,73.50906791083017,73.53756409474119,73.56606027865219,73.59455646256319,73.62305264647419,73.6515488303852,73.68004501429618,73.54772457957698,73.33499583554267,73.12226709150836,72.90953834747404,72.69680960343973,72.48408085940542,72.2713521153711,72.0586233713368,71.84589462730247,71.63316588326816,71.42043713923384,71.20770839519955,70.99497965116522,70.7822509071309,70.5695221630966,70.35679341906229,70.14406462623005,69.90704254705284,69.67002046787562,69.43299838869841,69.1959763095212,68.95895423034398,68.72193215116678,68.48491007198955,68.24788799281234,68.01086591363513,67.7738438344579,67.53682175528071,67.29979967610349,67.06277759692627,66.82575551774906,66.58873343857184,66.35171135939463,66.11468928021742,65.8776672010402,65.64064512186299,65.40362304268578,65.16660096350856,64.92957888433135,64.69255680515414,64.45553472597692,64.21851264679971,63.981490567622494,63.74446848844528,63.50744640926806,63.27042433009085,63.03340225091363,62.796380171736416,62.55935809255921,62.32233601338199,62.08531393420477,61.84829185502757,61.61126977585035,61.37424769667313,61.137225617495915,60.90020353831871,60.6631814591415,60.42615937996428,60.18913730078705,59.95211522160985,59.71509314243264,59.47807106325542,59.24104898407821,59.00402690490098,58.76700482572379,58.52998274654657,58.29296066736935,58.055938588192134,57.818916509014926,57.58189442983771,57.344872350660495,57.10785027148329,56.870828192306064,56.633806113128855,56.39678403395165,56.159761954774424,55.922739875597216,55.68571779641999,55.448695717242785,55.21167363806557,54.974651558888354,54.73762947971114,54.50060740053392,54.062539942816876,53.423427106559885,52.78431427030297,52.14520143404604,51.506088597789066,50.86697576153213,50.227862925275225,49.588750089018234,48.94963725276127,48.31052441650441,48.23224653785557,48.37544444571134,48.51864235356712,48.661840261422874,48.805038169278646,48.9482360771344,49.091433984990175,49.23017443588291,48.936573990691926,48.64297354550092,48.34937310030996,48.055772655118965,47.762172209927975,47.46857176473697,47.174971319545975,46.88137087435498,46.587770429164024,46.29416998397302,46.00056953878203,45.70696909359108,45.41336864840008,45.11976820320907,44.82616775801809,44.532567312827126,44.23896686763613,43.945366422445176,43.65176597725414,43.35816553206314,43.064565086872186,42.770964641681196,42.47736419649019,42.18376375129924,41.89016330610829,41.596562860917246,41.30296241572625,41.012157167685075,40.721892924661965,40.43162868163886,40.14136443861581,39.85110019559272,39.560835952569605,39.270571709546516,38.98030746652346,38.69004322350035,38.39977898047725,38.10951473745417,37.81925049443107,37.52898625140796,37.238722008384904,36.948457765361816,36.658193522338706,36.367929279315646,36.07766503629256,35.78740079326949,35.497136550246395,35.20687230722331,34.91819309497558,34.63229649373513,34.34639989249475,34.060503291254314,33.77460669001387,33.48871008877347,33.20281348753305,32.916916886292604,32.63102028505217,32.345123683811785,32.05922708257134,31.773330481330913,31.487433880090485,31.20153727885004,30.915640677609638,30.62974407636921,30.34384747512878,30.057950873888338,29.777659469121435,29.49758038445072,29.217501299779993,28.937422215109283,28.657343130438573,28.377264045767877,28.097184961097156,27.81710587642649,27.537026791755732,27.256947707085036,26.976868622414326,26.696789537743648,26.416710453072888,26.136631368402213,25.861086370782246,25.58882467512668,25.31656297947116,25.04430128381561,24.772039588160048,24.499777892504483,24.22751619684893,23.955254501193384,23.68299280553785,23.4107311098823,23.13846941422678,22.866207718571218,22.597773565277244,22.33331048745537,22.068847409633488,21.804384331811626,21.539921253989768,21.275458176167913,21.010995098345997,20.74653202052415,20.48206894270228,20.217605864880397,19.954629668439278,19.69809663147774,19.44156359451619,19.185030557554647,18.928497520593105,18.671964483631584,18.415431446670027,18.15889840970849,17.902365372746974,17.648561134995823,17.401076217148958,17.153591299302086,16.906106381455157,16.658621463608288,16.411136545761394,16.16365162791451,15.916166710067582,15.674283138163558,15.436811245408379,15.199339352653205,14.96186745989806,14.724395567142897,14.486923674387718,14.249451781632555,14.019809843535976,13.792729558357543,13.565649273179144,13.338568988000723,13.11148870282229,12.884408417643856,12.663922814326602,12.445955178794868,12.227987543263115,12.010019907731413,11.79205227219969,11.57728415380817,11.368606681446856,11.159929209085558,10.951251736724233,10.74257426436289,10.540118561519122,10.343504673626834,10.14689078573453,9.950276897842237,9.755731635911356,9.57226830677279,9.38880497763423,9.205341648495665,9.024334890564607,8.85293892601058,8.681542961456579,8.510146996902554,8.34535621331505,8.184956374086703,8.024556534858347,7.867208751487713,7.716851162491163,7.5664935734945935,7.418663104295126,7.27746632293071,7.13626954156632,6.999134853702,6.866314563210638,6.7334942727193035,6.607747720785014,6.482749353033963,6.362409758664504,6.246525274566628,6.133467980407596,6.027478660638026,5.922966402982357,5.823979452367096,5.72639767592251,5.632576042348212,5.541753006373089,5.4545058378502365,5.3724724293706085,5.29307779782652,5.2189185615921945,5.148240278737728,5.076583918638942,4.994136794107582,4.911689669576221,4.8292425450448775,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[67.36311773599539,67.41001170998855,67.45690568398173,67.50379965797491,67.55069363196807,67.59758760596125,67.64448157995442,67.6913755539476,67.73826952794077,67.78612043603675,67.83416273257453,67.88220502911231,67.93024732565007,67.97828962218784,68.02633191872563,68.0743742152634,68.12241651180118,68.17045880833896,68.21850110487674,68.26654340141451,68.31458569795228,68.36262799449005,68.41067029102784,68.45871258756561,68.50675488410339,68.55479718064116,68.60283947717893,68.65088177371672,68.69892407025449,68.74696636679226,68.79500866333004,68.84305095986782,68.8910932564056,68.93913555294337,68.98717784948114,69.03522014601893,69.0832624425567,69.13130473909447,69.17934703563225,69.22738933217002,69.27543162870779,69.32347392524557,69.37151622178335,69.41955851832113,69.4676008148589,69.51564311139668,69.56368540793446,69.61172770447223,69.65977000101,69.70781229754778,69.75585459408555,69.80389689062334,69.8519391871611,69.89998148369888,69.94802378023667,69.99606607677443,70.04410837331221,70.09215066984999,70.14019296638776,70.18823526292555,70.2362775594633,70.28431985600109,70.33236215253886,70.38040444907664,70.42844674561442,70.4764890421522,70.52453133868997,70.57257363522774,70.62061593176551,70.6686582283033,70.71670052484107,70.76474282137886,70.81278511791663,70.8608274144544,70.90886971099218,70.95691200752995,71.00495430406772,71.0529966006055,71.10103889714327,71.14908119368106,71.19712349021883,71.2451657867566,71.29320808329439,71.34125037983216,71.37300424918095,71.40150043309195,71.42999661700296,71.45849280091396,71.48698898482496,71.51548516873598,71.54398135264697,71.57247753655797,71.60097372046897,71.62946990437999,71.65796608829099,71.68646227220198,71.714958456113,71.74345464002398,71.771950823935,71.800447007846,71.828943191757,71.85743937566801,71.88593555957901,71.91443174349001,71.94292792740102,71.97142411131202,71.99992029522302,72.02841647913402,72.05691266304503,72.08540884695603,72.11390503086703,72.14240121477803,72.17089739868905,72.19939358260004,72.22788976651104,72.25638595042204,72.28488213433305,72.31337831824405,72.34187450215506,72.37037068606605,72.39886686997707,72.42736305388806,72.45585923779907,72.48435542171008,72.51285160562107,72.54134778953207,72.56984397344308,72.59834015735409,72.62683634126509,72.65533252517609,72.6838287090871,72.7123248929981,72.7408210769091,72.7693172608201,72.7978134447311,72.82630962864211,72.85480581255311,72.88330199646411,72.91179818037511,72.94029436428612,72.96879054819712,72.99728673210812,73.02578291601912,73.05427909993013,73.08277528384113,73.11127146775215,73.13976765166313,73.16826383557414,73.19676001948514,73.22525620339616,73.25375238730716,73.28224857121816,73.31074475512916,73.33924093904017,73.36773712295117,73.39623330686217,73.42472949077317,73.45322567468416,73.48172185859518,73.50857525399535,73.53510009447653,73.56162493495773,73.58814977543892,73.61467461592011,73.6411994564013,73.66772429688248,73.69424913736368,73.53402895024583,73.28043624932847,73.02684354841112,72.77325084749376,72.51965814657642,72.26606544565905,72.0124727447417,71.75888004382432,71.50528734290697,71.25169464198962,70.99810194107226,70.74450924015491,70.49091653923755,70.23732383832018,69.98373113740284,69.73013843648548,69.47654573556812,69.22295303465076,68.9693603337334,68.71576763281605,68.46217493189869,68.20858223098134,67.95498953006398,67.70450374792608,67.46748166874889,67.23045958957168,66.99343751039446,66.75641543121725,66.51939335204003,66.28237127286282,66.04534919368561,65.80832711450839,65.57130503533118,65.33428295615397,65.09726087697675,64.86023879779952,64.62321671862232,64.38619463944511,64.14917256026789,63.91215048109067,63.675128401913476,63.438106322736246,63.20108424355903,62.96406216438183,62.72704008520461,62.49001800602739,62.252995926850176,62.01597384767297,61.778951768495745,61.541929689318536,61.30490761014131,61.06788553096411,60.8308634517869,60.593841372609674,60.356819293432466,60.11979721425526,59.882775135078035,59.645753055900826,59.408730976723604,59.171708897546395,58.93468681836919,58.697664739191964,58.46064266001475,58.22362058083753,57.986598501660325,57.749576422483116,57.512554343305894,57.275532264128685,57.03851018495146,56.801488105774254,56.56446602659704,56.32744394741982,56.090421868242615,55.85339978906539,55.61637770988819,55.37935563071097,55.14233355153375,54.90531147235654,54.66828939317933,54.43126731400211,54.194245234824905,53.95722315564768,53.72020107647046,53.28213361875342,52.64302078249642,52.00390794623951,51.36479510998259,50.7256822737256,50.12497086877752,50.26816877663329,50.41136668448905,50.55456459234483,50.69776250020057,50.51113273828764,50.21753229309659,49.92393184790569,49.630331402714695,49.33673095752369,49.043130512332695,48.74953006714175,48.455929621950744,48.162329176759755,47.86872873156875,47.5751282863778,47.2815278411868,46.98792739599581,46.6943269508048,46.400726505613804,46.10712606042281,45.81352561523186,45.51992517004086,45.22632472484987,44.93272427965891,44.63912383446791,44.34552338927691,44.05192294408592,43.75832249889496,43.46472205370396,43.17112160851302,42.87752116332198,42.583920718130976,42.292574464357536,42.00231022133444,41.712045978311295,41.42178173528825,41.131517492265154,40.841253249242044,40.55098900621894,40.2607247631959,39.97046052017279,39.68019627714969,39.38993203412664,39.09966779110354,38.80940354808043,38.519139305057344,38.22887506203429,37.93861081901118,37.64834657598808,37.358082332965,37.067818089941895,36.77755384691879,36.48728960389573,36.19702536087264,35.908874492371694,35.6229778911313,35.33708128989087,35.05118468865043,34.76528808740999,34.479391486169604,34.193494884929166,33.90759828368872,33.62170168244835,33.3358050812079,33.04990847996746,32.76401187872707,32.47811527748664,32.1922186762462,31.906322075005768,31.620425473765376,31.33452887252493,31.048632271284504,30.76566565810215,30.485586573431394,30.20550748876067,29.92542840408996,29.645349319419275,29.365270234748554,29.085191150077875,28.80511206540716,28.525032980736437,28.244953896065724,27.964874811395013,27.684795726724317,27.404716642053597,27.12463755738293,26.844558472712173,26.569482518480598,26.297220822825047,26.02495912716953,25.752697431513937,25.480435735858382,25.208174040202866,24.9359123445473,24.66365064889178,24.39138895323623,24.11912725758067,23.846865561925103,23.574603866269555,23.30349043322459,23.03902735540273,22.774564277580886,22.51010119975901,22.245638121937127,21.981175044115254,21.716711966293378,21.452248888471495,21.187785810649636,20.923322732827774,20.65885965500592,20.398361596290847,20.141828559329305,19.885295522367816,19.62876248540624,19.37222944844472,19.115696411483185,18.859163374521632,18.602630337560093,18.34609730059855,18.0924366838319,17.84495176598499,17.59746684813812,17.34998193029125,17.102497012444324,16.855012094597452,16.607527176750583,16.360042258903654,16.115729784880834,15.87825789212569,15.640785999370515,15.403314106615337,15.165842213860207,14.928370321105028,14.690898428349852,14.456374851317829,14.229294566139409,14.002214280960995,13.775133995782577,13.548053710604155,13.320973425425723,13.094372754622295,12.876405119090554,12.658437483558838,12.440469848027105,12.222502212495414,12.00453457696368,11.791154200800625,11.582476728439294,11.373799256077996,11.16512178371667,10.956444311355355,10.753846125216253,10.55723223732395,10.360618349431661,10.164004461539365,9.967390573647076,9.783927243208215,9.600463914069646,9.417000584931078,9.233537255792509,9.061106946281344,8.889710981727307,8.718315017173294,8.549020701025306,8.388620861796971,8.228221022568603,8.067821183340236,7.9152976181987,7.764940029202131,7.614582440205542,7.470226760123008,7.329029978758593,7.1878331973941645,7.053095396979614,6.92027510648828,6.788271016352764,6.663272648601721,6.538274280850687,6.419029370845713,6.303144886747845,6.190541009826576,6.084551690056985,5.979875314369938,5.880888363754689,5.782851206706592,5.689029573132281,5.597228385043897,5.509981216521066,5.426521401975627,5.3462095181088785,5.271372925974185,5.199008745901768,5.130295321557322,5.049810154195537,4.9673630296641775,4.884915905132817,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[67.42025477546761,67.46714874946078,67.51404272345395,67.56093669744712,67.6078306714403,67.65472464543348,67.70161861942664,67.74851259341982,67.79540656741298,67.84230054140616,67.88919451539932,67.9360884893925,67.98298246338567,68.02987643737885,68.07677041137202,68.12366438536519,68.17055835935837,68.21745233335153,68.26434630734471,68.31124028133787,68.35813425533105,68.40502822932423,68.4519222033174,68.49881617731056,68.54571015130375,68.59298689875351,68.64102919529128,68.68907149182905,68.73711378836683,68.7851560849046,68.83319838144239,68.88124067798017,68.92928297451793,68.97732527105572,69.02536756759349,69.07340986413126,69.12145216066904,69.16949445720681,69.2175367537446,69.26557905028235,69.31362134682014,69.36166364335791,69.4097059398957,69.45774823643347,69.50579053297125,69.55383282950902,69.60187512604679,69.64991742258456,69.69795971912235,69.74600201566012,69.7940443121979,69.84208660873568,69.89012890527344,69.93817120181123,69.986213498349,70.03425579488677,70.08229809142455,70.13034038796232,70.17838268450011,70.22642498103788,70.27446727757567,70.32250957411344,70.37055187065121,70.41859416718899,70.46663646372676,70.51467876026453,70.56272105680232,70.61076335334009,70.65880564987786,70.70684794641564,70.75489024295342,70.8029325394912,70.85097483602897,70.89901713256674,70.94705942910451,70.99510172564229,71.04314402218007,71.09118631871785,71.13922861525562,71.18727091179339,71.23531320833118,71.28335550486895,71.33139780140672,71.3794400979445,71.4111939672933,71.4396901512043,71.46818633511529,71.49668251902631,71.52517870293731,71.55367488684831,71.58217107075932,71.61066725467032,71.63916343858132,71.66765962249232,71.69615580640334,71.72465199031433,71.75314817422534,71.78164435813633,71.81014054204735,71.83863672595834,71.86713290986935,71.89562909378034,71.92412527769136,71.95262146160235,71.98111764551336,72.00961382942437,72.03811001333536,72.06660619724636,72.09510238115737,72.12359856506838,72.15209474897938,72.18059093289038,72.20908711680138,72.23758330071239,72.26607948462339,72.29457566853439,72.3230718524454,72.3515680363564,72.3800642202674,72.4085604041784,72.43705658808942,72.4655527720004,72.49404895591141,72.52254513982243,72.55104132373341,72.57953750764442,72.60803369155542,72.63652987546642,72.66502605937742,72.69352224328844,72.72201842719943,72.75051461111045,72.77901079502145,72.80750697893244,72.83600316284345,72.86449934675446,72.89299553066544,72.92149171457646,72.94998789848746,72.97848408239845,73.00698026630947,73.03547645022047,73.06331551841035,73.08984035889154,73.11636519937272,73.14289003985392,73.16941488033511,73.1959397208163,73.22246456129749,73.24898940177869,73.27551424225987,73.30203908274108,73.32856392322225,73.35508876370344,73.38161360418462,73.40813844466582,73.43466328514701,73.4611881256282,73.48771296610938,73.51423780659059,73.54076264707177,73.56728748755296,73.59381232803416,73.62033716851535,73.64686200899654,73.67338684947772,73.69991168995891,73.53969150284107,73.28609880192371,73.03250610100636,72.77891340008901,72.52532069917166,72.27172799825428,72.01813529733694,71.76454259641959,71.51094989550221,71.25735719458487,71.0037644936675,70.75017179275015,70.49657909183279,70.24298639091543,69.98939368999808,69.73580098908073,69.48220828816336,69.22861558724601,68.97502288632865,68.7214301854113,68.46783748449394,68.21424478357658,67.96065208265922,67.70705938174186,67.4534666808245,67.19987397990715,66.94628127898979,66.69268857807243,66.43909587715508,66.18550317623772,65.93191047532036,65.67831777440301,65.42472507348566,65.1711323725683,64.91753967165093,64.66394697073358,64.41035426981622,64.15676156889887,63.903168867981506,63.649576167064154,63.3959834661468,63.14239076522944,62.888798064312084,62.63520536339473,62.381612662477366,62.128019961560014,61.87442726064266,61.62083455972531,61.367241858807944,61.11364915789059,60.860056456973226,60.606463756055874,60.352871055138515,60.099278354221155,59.84568565330379,59.59209295238645,59.338500251469085,59.08490755055173,58.83131484963437,58.577722148717015,58.32412944779966,58.0705367468823,57.816944045964945,57.56335134504759,57.30975864413024,57.05616594321288,56.80257324229552,56.54898054137816,56.2953878404608,56.04179513954345,55.788202438626094,55.54703762335634,55.31001554417912,55.0729934650019,54.8359713858247,54.598949306647484,54.36192722747026,54.12490514829305,53.887883069115844,53.650860989938636,53.41383891076141,53.1768168315842,52.93979475240698,52.501727294689935,52.16089310755533,52.08569148588334,51.7920910406923,51.498490595501345,51.20489015031035,50.91128970511944,50.617689259928355,50.3240888147374,50.030488369546454,49.73688792435546,49.4432874791644,49.14968703397349,48.8560865887825,48.56248614359151,48.26888569840051,47.975285253209556,47.68168480801855,47.388084362827556,47.09448391763656,46.800883472445605,46.5072830272546,46.21368258206361,45.92008213687261,45.626481691681605,45.33288124649062,45.03928080129967,44.745680356108664,44.45207991091767,44.15847946572672,43.86487902053572,43.572991761029904,43.28272751800685,42.99246327498371,42.70219903196061,42.411934788937515,42.121670545914455,41.831406302891345,41.54114205986834,41.25087781684525,40.9606135738221,40.67034933079905,40.38008508777596,40.08982084475284,39.79955660172974,39.5092923587067,39.21902811568359,38.92876387266049,38.63849962963744,38.34823538661435,38.05797114359123,37.76770690056814,37.47744265754509,37.18717841452198,36.899555889767775,36.6136592885274,36.32776268728696,36.041866086046554,35.75596948480609,35.4700728835657,35.184176282325254,34.898279681084865,34.612383079844435,34.326486478604,34.04058987736356,33.75469327612317,33.46879667488273,33.18290007364228,32.897003472401906,32.61110687116147,32.32521026992102,32.03931366868063,31.753671847082792,31.473592762412036,31.193513677741358,30.913434593070676,30.63335550839995,30.35327642372924,30.073197339058563,29.793118254387803,29.51303916971708,29.23296008504637,28.95288100037569,28.672801915704962,28.392722831034284,28.112643746363574,27.832564661692846,27.552485577022136,27.277878666178925,27.005616970523388,26.73335527486783,26.46109357921229,26.18883188355676,25.91657018790119,25.644308492245642,25.372046796590123,25.099785100934525,24.827523405278978,24.55526170962346,24.283000013967897,24.010738318312374,23.74474422335009,23.480281145528206,23.21581806770632,22.951354989884447,22.686891912062574,22.422428834240712,22.15796575641887,21.893502678597,21.629039600775116,21.364576522953236,21.100113445131367,20.842093524142456,20.5855604871809,20.32902745021937,20.07249441325782,19.815961376296265,19.559428339334726,19.30289530237324,19.046362265411663,18.789829228450145,18.53631223266797,18.28882731482104,18.041342396974173,17.793857479127304,17.546372561280375,17.298887643433467,17.0514027255866,16.80391780773973,16.557176431598133,16.31970453884297,16.082232646087807,15.84476075333263,15.607288860577466,15.369816967822322,15.132345075067144,14.894873182311967,14.665859573921276,14.438779288742843,14.211699003564409,13.984618718385988,13.757538433207568,13.530458148029155,13.306855059386233,13.08888742385451,12.870919788322794,12.65295215279109,12.43498451725935,12.217016881727634,12.005024247793031,11.796346775431747,11.58766930307042,11.37899183070911,11.17031435834778,10.96757368891337,10.770959801021052,10.574345913128775,10.377732025236483,10.181118137344178,9.995586179643627,9.812122850505084,9.628659521366503,9.445196192227922,9.269274966552038,9.097879001998038,8.926483037444013,8.75508707289002,8.592285349507229,8.431885510278851,8.271485671050483,8.113744073906227,7.963386484909659,7.81302889591307,7.662987197315262,7.5217904159508455,7.380593634586429,7.239876230748608,7.107055940257256,6.974235649765886,6.843795944169456,6.718797576418437,6.593799208667378,6.475648983026929,6.359764498929076,6.247614039245523,6.141624719475933,6.03678422575752,5.937797275142259,5.839304737490652,5.745483103916358,5.652703763714716,5.565456595191868,5.4805703745806476,5.4002584907139095,5.323827290356161,5.249777213065809,5.181063788721373,5.105483514283474,5.023036389752114,4.940589265220771,4.85814214068941,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[67.4773918149398,67.52428578893299,67.57117976292616,67.61807373691933,67.6649677109125,67.71186168490567,67.75875565889885,67.80564963289203,67.85254360688519,67.89943758087837,67.94633155487153,67.99322552886471,68.04011950285788,68.08701347685106,68.13390745084423,68.18080142483741,68.22769539883058,68.27458937282375,68.32148334681692,68.3683773208101,68.41527129480326,68.46216526879644,68.50905924278962,68.55595321678278,68.60284719077595,68.64974116476913,68.6966351387623,68.74352911275547,68.79042308674865,68.83731706074181,68.88421103473499,68.93110500872817,68.97799898272133,69.0248929567145,69.07178693070767,69.11868090470084,69.16557487869402,69.2124688526872,69.25936282668036,69.30625680067352,69.3531507746667,69.4000447486599,69.44789565800804,69.49593795454582,69.54398025108358,69.59202254762137,69.64006484415914,69.68810714069691,69.73614943723469,69.78419173377247,69.83223403031023,69.88027632684802,69.92831862338579,69.97636091992356,70.02440321646135,70.07244551299912,70.1204878095369,70.16853010607467,70.21657240261246,70.26461469915021,70.312656995688,70.36069929222577,70.40874158876355,70.45678388530132,70.5048261818391,70.5528684783769,70.60091077491465,70.64895307145242,70.69699536799021,70.74503766452798,70.79307996106576,70.84112225760353,70.8891645541413,70.93720685067909,70.98524914721686,71.03329144375463,71.08133374029241,71.12937603683018,71.17741833336797,71.22546062990574,71.27350292644351,71.32154522298129,71.36958751951906,71.41762981605683,71.44938368540564,71.47787986931664,71.50637605322765,71.53487223713864,71.56336842104965,71.59186460496065,71.62036078887165,71.64885697278265,71.67735315669366,71.70584934060466,71.73434552451567,71.76284170842666,71.79133789233768,71.81983407624867,71.84833026015968,71.87682644407069,71.90532262798169,71.93381881189269,71.9623149958037,71.9908111797147,72.0193073636257,72.0478035475367,72.0762997314477,72.10479591535871,72.13329209926971,72.16178828318073,72.19028446709171,72.21878065100272,72.24727683491373,72.27577301882472,72.30426920273572,72.33276538664674,72.36126157055773,72.38975775446873,72.41825393837975,72.44675012229074,72.47524630620175,72.50374249011276,72.53223867402376,72.56073485793476,72.58923104184575,72.61772722575677,72.64458062330657,72.67110546378774,72.69763030426893,72.72415514475011,72.75067998523132,72.7772048257125,72.8037296661937,72.83025450667486,72.85677934715608,72.88330418763726,72.90982902811845,72.93635386859964,72.96287870908084,72.98940354956203,73.01592839004321,73.0424532305244,73.0689780710056,73.09550291148678,73.12202775196798,73.14855259244916,73.17507743293037,73.20160227341155,73.22812711389274,73.25465195437393,73.28117679485513,73.30770163533631,73.3342264758175,73.36075131629869,73.38727615677988,73.41380099726106,73.44032583774225,73.46685067822345,73.49337551870464,73.51990035918583,73.54642519966701,73.57295004014821,73.5994748806294,73.62599972111059,73.65252456159178,73.67904940207296,73.70557424255415,73.5453540554363,73.29176135451895,73.03816865360162,72.78457595268425,72.5309832517669,72.27739055084952,72.02379784993218,71.77020514901481,71.51661244809746,71.26301974718011,71.00942704626274,70.75583434534539,70.50224164442803,70.24864894351067,69.99505624259332,69.74146354167596,69.4878708407586,69.23427813984125,68.98068543892389,68.72709273800653,68.47350003708918,68.21990733617181,67.96631463525446,67.7127219343371,67.45912923341976,67.20553653250239,66.95194383158503,66.69835113066769,66.44475842975031,66.19116572883297,65.93757302791562,65.68398032699825,65.4303876260809,65.17679492516355,64.92320222424618,64.66960952332883,64.41601682241146,64.16242412149413,63.90883142057676,63.655238719659394,63.40164601874205,63.14805331782468,62.89446061690734,62.64086791598997,62.387275215072606,62.133682514155254,61.88008981323791,61.62649711232055,61.372904411403184,61.11931171048583,60.865719009568465,60.61212630865111,60.358533607733754,60.104940906816395,59.851348205899036,59.59775550498169,59.34416280406433,59.09057010314697,58.83697740222962,58.583384701312255,58.3297920003949,58.07619929947754,57.822606598560185,57.56901389764283,57.307200779122724,57.02278169835547,56.73836261758822,56.45394353682097,56.16952445605372,55.885105375286486,55.600686294519235,55.316267213751985,55.031848132984734,54.747429052217484,54.46300997145025,54.178590890683,53.89417180991575,53.6097527291485,53.325333648381246,53.04091456761401,52.75649548684676,52.472076406079495,52.18765732531226,51.898647562333124,51.60504711714216,51.31144667195117,51.017846226760135,50.72424578156918,50.43064533637818,50.13704489118727,49.843444445996184,49.54984400080523,49.25624355561428,48.962643110423286,48.66904266523223,48.37544222004133,48.08184177485033,47.788241329659336,47.49464088446834,47.20104043927739,46.90743999408638,46.6138395488954,46.320239103704395,46.02663865851344,45.73303821332244,45.43943776813145,45.145837322940444,44.853409057702336,44.56314481467925,44.27288057165623,43.98261632863312,43.69235208561003,43.40208784258694,43.111823599563834,42.821559356540725,42.53129511351768,42.24103087049454,41.95076662747143,41.660502384448336,41.37023814142528,41.07997389840218,40.78970965537916,40.499445412356074,40.20918116933292,39.918916926309876,39.62865268328678,39.33838844026367,39.04812419724057,38.75785995421753,38.46759571119442,38.17733146817131,37.89023728716395,37.60434068592355,37.31844408468307,37.032547483442684,36.74665088220225,36.46075428096185,36.17485767972137,35.888961078480996,35.60306447724055,35.31716787600015,35.03127127475968,34.745374673519294,34.45947807227884,34.17358147103845,33.88768486979802,33.601788268557584,33.31589166731715,33.029995066076765,32.74409846483632,32.461598951392745,32.18151986672207,31.901440782051314,31.62136169738066,31.34128261270991,31.061203528039233,30.781124443368473,30.501045358697798,30.220966274027116,29.940887189356392,29.660808104685678,29.380729020015004,29.10064993534424,28.82057085067352,28.540491766002805,28.260412681332127,27.98627481387731,27.714013118221757,27.441751422566206,27.169489726910644,26.897228031255093,26.62496633559954,26.35270463994401,26.080442944288446,25.80818124863291,25.53591955297738,25.26365785732181,24.991396161666263,24.719134466010743,24.45046109129742,24.185998013475544,23.9215349356537,23.657071857831845,23.39260878000997,23.128145702188096,22.863682624366213,22.599219546544326,22.334756468722453,22.07029339090058,21.805830313078722,21.542358488955543,21.285825451994086,21.029292415032508,20.77275937807099,20.51622634110945,20.2596933041479,20.003160267186345,19.746627230224817,19.490094193263264,19.233561156301715,18.980187781504032,18.73270286365714,18.485217945810206,18.23773302796334,17.990248110116468,17.74276319226954,17.49527827442267,17.247793356575798,17.000308438728872,16.76115118556029,16.523679292805102,16.28620740004996,16.048735507294783,15.811263614539618,15.573791721784453,15.336319829029277,15.10242458170313,14.875344296524688,14.648264011346257,14.421183726167843,14.194103440989457,13.967023155811024,13.73994287063259,13.519337364150223,13.301369728618502,13.083402093086764,12.865434457555043,12.647466822023322,12.429499186491604,12.2188942947855,12.010216822424184,11.801539350062859,11.592861877701532,11.384184405340246,11.181301252610488,10.98468736471817,10.78807347682589,10.591459588933613,10.394845701041294,10.207245116079067,10.02378178694051,9.840318457801931,9.65685512866335,9.477442986822776,9.306047022268764,9.134651057714741,8.963255093160727,8.795949837217487,8.635549997989107,8.475150158760771,8.314750319532415,8.161832940617197,8.011475351620609,7.861117762624059,7.714550853143107,7.57335407177869,7.432157290414302,7.293836774026223,7.161016483534862,7.028196193043527,6.899320871986188,6.774322504235137,6.649324136484077,6.532268595208167,6.4163841111102915,6.304687068664476,6.198697748894907,6.093693137145099,5.994706186529832,5.895758268274735,5.801936634700423,5.708179142385523,5.620931973862689,5.534619347185691,5.454307463318938,5.376281654738137,5.302122418503826,5.23183225588542,5.161156874371411,5.078709749840067,4.996262625308708,4.913815500777348,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[67.53452885441203,67.58142282840521,67.62831680239837,67.67521077639154,67.72210475038472,67.7689987243779,67.81589269837106,67.86278667236422,67.9096806463574,67.95657462035058,68.00346859434376,68.05036256833692,68.0972565423301,68.14415051632326,68.19104449031644,68.23793846430962,68.28483243830279,68.33172641229595,68.37862038628913,68.4255143602823,68.47240833427549,68.51930230826865,68.56619628226181,68.61309025625499,68.65998423024817,68.70687820424135,68.75377217823451,68.80066615222769,68.84756012622086,68.89445410021403,68.9413480742072,68.98824204820038,69.03513602219354,69.08202999618672,69.1289239701799,69.17581794417306,69.22271191816624,69.2696058921594,69.31649986615258,69.36339384014575,69.41028781413893,69.45718178813209,69.50407576212527,69.55096973611845,69.59786371011161,69.64475768410477,69.69165165809797,69.73854563209113,69.7854396060843,69.83233358007747,69.87922755407065,69.92612152806382,69.973015502057,70.01990947605016,70.06680345004334,70.11369742403652,70.16059139802968,70.20748537202286,70.25476212072479,70.30280441726256,70.35084671380034,70.39888901033812,70.44693130687588,70.49497360341367,70.54301589995144,70.59105819648923,70.63910049302699,70.68714278956477,70.73518508610255,70.78322738264032,70.83126967917809,70.87931197571588,70.92735427225365,70.97539656879142,71.0234388653292,71.07148116186698,71.11952345840476,71.16756575494253,71.2156080514803,71.26365034801807,71.31169264455585,71.35973494109363,71.40777723763141,71.45581953416918,71.48757340351798,71.51606958742899,71.54456577133999,71.57306195525099,71.601558139162,71.630054323073,71.658550506984,71.687046690895,71.715542874806,71.74403905871701,71.77253524262801,71.801031426539,71.82952761045001,71.85802379436102,71.88651997827202,71.91501616218302,71.94351234609404,71.97200853000503,72.00050471391604,72.02900089782705,72.05749708173803,72.08599326564905,72.11448944956004,72.14298563347104,72.17148181738206,72.19932088772156,72.22584572820274,72.25237056868393,72.27889540916512,72.30542024964632,72.3319450901275,72.35846993060869,72.3849947710899,72.41151961157108,72.43804445205227,72.46456929253345,72.49109413301466,72.51761897349584,72.54414381397703,72.57066865445822,72.5971934949394,72.6237183354206,72.65024317590179,72.676768016383,72.70329285686417,72.72981769734537,72.75634253782655,72.78286737830774,72.80939221878894,72.83591705927012,72.86244189975132,72.8889667402325,72.91549158071369,72.9420164211949,72.96854126167608,72.99506610215727,73.02159094263845,73.04811578311964,73.07464062360084,73.10116546408202,73.12769030456322,73.15421514504442,73.1807399855256,73.20726482600679,73.23378966648798,73.26031450696917,73.28683934745037,73.31336418793157,73.33988902841274,73.36641386889393,73.39293870937513,73.41946354985632,73.44598839033749,73.47251323081869,73.49903807129988,73.52556291178107,73.55208775226225,73.57861259274344,73.60513743322464,73.63166227370584,73.65818711418702,73.68471195466822,73.7112367951494,73.55101660803156,73.29742390711421,73.04383120619686,72.79023850527949,72.53664580436215,72.28305310344477,72.02946040252742,71.77586770161007,71.5222750006927,71.26868229977535,71.01508959885798,70.76149689794063,70.50790419702328,70.25431149610591,70.00071879518856,69.74712609427121,69.49353339335384,69.23994069243649,68.98634799151914,68.73275529060179,68.47916258968442,68.22556988876707,67.97197718784972,67.71838448693234,67.464791786015,67.21119908509763,66.95760638418028,66.70401368326293,66.45042098234556,66.19682828142821,65.94323558051084,65.68964287959349,65.43605017867614,65.18245747775879,64.92886477684142,64.67527207592406,64.4216793750067,64.16808667408935,63.914493973172,63.64343298437174,63.359013903604506,63.074594822837255,62.79017574207,62.50575666130275,62.2213375805355,61.93691849976825,61.65249941900101,61.36808033823377,61.08366125746652,60.79924217669926,60.51482309593201,60.23040401516478,59.945984934397515,59.66156585363027,59.37714677286303,59.09272769209578,58.80830861132854,58.523889530561284,58.23947044979403,57.95505136902679,57.67063228825954,57.386213207492304,57.10179412672505,56.81737504595779,56.53295596519057,56.24853688442331,55.96411780365605,55.67969872288881,55.39527964212155,55.11086056135432,54.826441480587064,54.542022399819814,54.25760331905257,53.97318423828531,53.688765157518084,53.40434607675083,53.119926995983576,52.835507915216326,52.5510888344491,52.26666975368184,51.98225067291459,51.69783159214734,51.41341251138009,51.12440274840096,50.83080230321,50.53720185801901,50.24360141282797,49.95000096763701,49.65640052244601,49.36280007725511,49.06919963206402,48.775599186873066,48.481998741682126,48.188398296491116,47.89479785130007,47.601197406109165,47.30759696091817,47.01399651572717,46.72039607053618,46.42679562534523,46.13382635437481,45.84356211135172,45.55329786832866,45.263033625305525,44.972769382282415,44.68250513925937,44.39224089623627,44.101976653213164,43.811712410190076,43.52144816716705,43.231183924143956,42.94091968112086,42.650655438097765,42.36039119507466,42.07012695205156,41.779862709028514,41.48959846600536,41.19933422298226,40.90906997995917,40.61880573693611,40.32854149391301,40.03827725089,39.7480130078669,39.45774876484376,39.167484521820704,38.880918684560115,38.59502208331971,38.30912548207924,38.02322888083885,37.73733227959838,37.451435678358,37.16553907711754,36.87964247587715,36.59374587463667,36.30784927339628,36.02195267215585,35.736056070915446,35.45015946967496,35.16426286843459,34.878366267194146,34.59246966595374,34.30657306471327,34.02067646347288,33.73477986223244,33.44960514037345,33.16952605570278,32.889446971032015,32.60936788636134,32.329288801690595,32.04920971701994,31.769130632349178,31.489051547678507,31.20897246300775,30.928893378337097,30.648814293666348,30.368735208995666,30.08865612432491,29.80857703965423,29.528497954983553,29.24841887031283,28.96833978564212,28.69467096157566,28.422409265920095,28.150147570264565,27.877885874609014,27.605624178953462,27.333362483297932,27.06110078764238,26.78883909198683,26.516577396331268,26.244315700675717,25.972054005020166,25.699792309364632,25.427530613709067,25.156177959244804,24.89171488142295,24.62725180360103,24.362788725779158,24.098325647957346,23.83386257013543,23.569399492313558,23.30493641449171,23.040473336669855,22.77601025884798,22.51154718102611,22.247084103204227,21.98609041680716,21.729557379845623,21.473024342884084,21.21649130592253,20.95995826896099,20.703425231999528,20.44689219503795,20.190359158076433,19.933826121114894,19.677293084153344,19.424063330340093,19.17657841249321,18.92909349464628,18.681608576799402,18.434123658952526,18.186638741105636,17.939153823258707,17.691668905411838,17.444183987564966,17.202597832277576,16.965125939522437,16.72765404676725,16.49018215401207,16.25271026125694,16.015238368501752,15.77776647574661,15.540294582991434,15.311909304306543,15.084829019128142,14.857748733949709,14.63066844877131,14.403588163592866,14.176507878414434,13.949787304445879,13.731819668914225,13.513852033382474,13.29588439785072,13.077916762319036,12.859949126787315,12.641981491255578,12.432764341777936,12.22408686941664,12.015409397055315,11.806731924694,11.598054452332685,11.395028816307605,11.198414928415284,11.00180104052302,10.805187152630731,10.60857326473841,10.418904052514492,10.235440723375937,10.051977394237342,9.868514065098788,9.685611007093518,9.514215042539506,9.342819077985459,9.171423113431468,9.000027148877455,8.839214485699388,8.678814646471032,8.518414807242674,8.360279396324735,8.209921807328174,8.059564218331607,7.909206629335028,7.766114508970963,7.624917727606565,7.483720946242148,7.347797317303847,7.2149770268125035,7.082156736321142,6.954845799802878,6.82984743205186,6.704849064300809,6.5888882073893775,6.473003723291509,6.361760098083451,6.255770778313861,6.150602048532674,6.051615097917426,5.952628147302159,5.858390165484488,5.764568531910195,5.676407352533501,5.5891601840106535,5.508356435923977,5.428736019120123,5.354576782885802,5.282600723049461,5.213887298705025,5.134383109928009,5.051935985396649,4.969488860865305,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[67.59166589388424,67.6385598678774,67.68545384187058,67.73234781586376,67.77924178985693,67.8261357638501,67.87302973784327,67.91992371183645,67.96681768582961,68.01371165982279,68.06060563381597,68.10749960780913,68.15439358180231,68.20128755579549,68.24818152978867,68.29507550378182,68.341969477775,68.38886345176817,68.43575742576135,68.48265139975452,68.52954537374768,68.57643934774086,68.62333332173404,68.67022729572722,68.71712126972037,68.76401524371354,68.81090921770672,68.85780319169989,68.90469716569308,68.95159113968623,68.99848511367941,69.04537908767259,69.09227306166575,69.13916703565893,69.1860610096521,69.23295498364527,69.27984895763845,69.32674293163161,69.37363690562479,69.42053087961796,69.46742485361113,69.51431882760431,69.56121280159748,69.60810677559064,69.65500074958382,69.701894723577,69.74878869757016,69.79568267156334,69.84257664555652,69.88947061954968,69.93636459354286,69.98325856753603,70.03015254152919,70.07704651552237,70.12394048951555,70.17083446350871,70.2177284375019,70.26462241149507,70.31151638548823,70.35841035948141,70.40530433347459,70.45219830746775,70.49909228146093,70.5459862554541,70.59288022944727,70.63977420344045,70.68666817743362,70.73356215142678,70.78045612541997,70.82735009941314,70.8742440734063,70.92113804739947,70.96803202139266,71.01492599538582,71.061819969379,71.1096708799793,71.15771317651709,71.20575547305486,71.25379776959264,71.30184006613042,71.3498823626682,71.39792465920597,71.44596695574374,71.49400925228151,71.52576312163032,71.55425930554132,71.58275548945232,71.61125167336333,71.63974785727433,71.66824404118533,71.69674022509633,71.72523640900734,71.75373259291834,71.78058599261774,71.80711083309895,71.83363567358013,71.86016051406133,71.88668535454251,71.91321019502371,71.9397350355049,71.9662598759861,71.99278471646727,72.01930955694847,72.04583439742967,72.07235923791085,72.09888407839205,72.12540891887323,72.15193375935442,72.17845859983561,72.2049834403168,72.231508280798,72.25803312127917,72.28455796176037,72.31108280224157,72.33760764272276,72.36413248320395,72.39065732368513,72.41718216416632,72.44370700464752,72.4702318451287,72.4967566856099,72.52328152609108,72.54980636657228,72.57633120705346,72.60285604753466,72.62938088801585,72.65590572849703,72.68243056897823,72.70895540945942,72.73548024994061,72.76200509042181,72.788529930903,72.81505477138418,72.84157961186537,72.86810445234656,72.89462929282774,72.92115413330895,72.94767897379013,72.97420381427132,73.0007286547525,73.02725349523371,73.0537783357149,73.08030317619608,73.10682801667727,73.13335285715846,73.15987769763964,73.18640253812084,73.21292737860203,73.23945221908323,73.26597705956442,73.29250190004561,73.3190267405268,73.34555158100798,73.37207642148917,73.39860126197036,73.42512610245156,73.45165094293274,73.47817578341393,73.50470062389512,73.53122546437632,73.5577503048575,73.5842751453387,73.61079998581988,73.63732482630108,73.66384966678227,73.69037450726346,73.71689934774466,73.5566791606268,73.30308645970945,73.0494937587921,72.79590105787473,72.54230835695738,72.28871565604,72.03512295512266,71.78153025420531,71.52793755328794,71.2743448523706,71.02075215145322,70.76715945053589,70.51356674961852,70.25997404870117,69.97966518962077,69.69524610885351,69.41082702808626,69.12640794731902,68.84198886655177,68.55756978578454,68.27315070501729,67.98873162425002,67.7043125434828,67.41989346271552,67.1354743819483,66.85105530118103,66.56663622041378,66.28221713964655,65.99779805887928,65.71337897811206,65.4289598973448,65.14454081657755,64.86012173581031,64.57570265504306,64.29128357427581,64.00686449350856,63.722445412741315,63.43802633197407,63.15360725120683,62.869188170439585,62.58476908967234,62.300350008905085,62.01593092813784,61.73151184737059,61.44709276660333,61.16267368583608,60.87825460506884,60.593835524301596,60.30941644353435,60.0249973627671,59.740578281999845,59.4561592012326,59.17174012046536,58.887321039698115,58.60290195893086,58.31848287816362,58.03406379739637,57.74964471662912,57.46522563586188,57.18080655509462,56.896387474327376,56.611968393560126,56.32754931279288,56.04313023202563,55.758711151258396,55.474292070491146,55.189872989723895,54.905453908956645,54.621034828189394,54.33661574742216,54.05219666665491,53.76777758588766,53.48335850512041,53.198939424353156,52.91452034358591,52.63010126281867,52.34568218205142,52.06126310128417,51.77684402051692,51.49242493974968,51.20800585898243,50.92358677821518,50.639167697447924,50.3501579344688,50.056557489277836,49.76295704408684,49.46935659889581,49.17575615370485,48.88215570851385,48.588555263322945,48.294954818131856,48.0013543729409,47.707753927749955,47.41424365104721,47.12397940802414,46.83371516500102,46.54345092197796,46.25318667895482,45.96292243593183,45.67265819290875,45.38239394988564,45.09212970686254,44.80186546383949,44.51160122081635,44.22133697779325,43.9310727347702,43.640808491747094,43.35054424872399,43.060280005700896,42.77001576267788,42.479751519654776,42.18948727663168,41.89922303360859,41.60895879058549,41.31869454756238,41.028430304539334,40.73816606151619,40.44790181849309,40.15763757546999,39.87160008195623,39.58570348071582,39.29980687947536,39.013910278234974,38.72801367699453,38.44211707575413,38.1562204745137,37.8703238732733,37.584427272032826,37.29853067079244,37.01263406955197,36.7267374683116,36.44084086707113,36.154944265830736,35.869047664590255,35.583151063349874,35.297254462109436,35.01135786086903,34.72546125962855,34.43956465838818,34.15753224468341,33.87745316001265,33.59737407534198,33.3172949906713,33.03721590600057,32.757136821329894,32.47705773665921,32.19697865198846,31.91689956731778,31.636820482647032,31.356741397976375,31.076662313305615,30.79658322863495,30.516504143964188,30.236425059293534,29.956345974622785,29.676266889952107,29.403067109274012,29.13080541361843,28.85854371796291,28.586282022307376,28.31402032665183,28.041758630996277,27.76949693534071,27.497235239685182,27.22497354402963,26.95271184837408,26.680450152718546,26.408188457062998,26.135926761407447,25.863665065751885,25.59743174937026,25.332968671548475,25.068505593726556,24.804042515904644,24.539579438082814,24.275116360260956,24.010653282439037,23.746190204617164,23.481727126795356,23.217264048973433,22.952800971151564,22.688337893329717,22.42982234465877,22.173289307697253,21.91675627073569,21.660223233774165,21.403690196812605,21.14715715985107,20.89062412288953,20.634091085927977,20.377558048966435,20.121025012004974,19.867938879176165,19.620453961329293,19.372969043482374,19.12548412563547,18.87799920778859,18.630514289941708,18.383029372094775,18.135544454247896,17.888059536401023,17.64404447899489,17.40657258623973,17.169100693484545,16.931628800729403,16.694156907974225,16.456685015219083,16.219213122463895,15.98174122970872,15.748474312088396,15.521394026909997,15.294313741731555,15.067233456553122,14.840153171374723,14.613072886196322,14.38599260101789,14.162269609209883,13.944301973678181,13.726334338146462,13.50836670261469,13.290399067083039,13.072431431551284,12.855311861131687,12.646634388770359,12.437956916409062,12.229279444047751,12.020601971686439,11.81192449932514,11.608756380004706,11.412142492112428,11.215528604220165,11.018914716327847,10.822300828435527,10.630562988949931,10.447099659811363,10.2636363306728,10.080173001534215,9.896709672395659,9.722383062810211,9.550987098256234,9.379591133702208,9.208195169148196,9.042878973409634,8.882479134181299,8.72207929495292,8.561679455724574,8.408368263035692,8.258010674039156,8.107653085042566,7.958874946163253,7.817678164798826,7.6764813834344,7.535284602070002,7.401757860581479,7.2689375700901175,7.136117279598764,7.010370727619609,6.885372359868559,6.761392303668476,6.645507819570621,6.529623335472753,6.418833127502417,6.312843807732807,6.207510959920273,6.108524009305,6.009537058689732,5.914843696268571,5.821022062694265,5.731882731204304,5.644635562681474,5.5624054085289965,5.482093524662248,5.407031147267796,5.3333691902135225,5.264655765869069,5.19005647001595,5.1076093454846045,5.025162220953245,4.9427150964218844,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[67.64142735785283,67.68832133184601,67.73521530583918,67.78210927983235,67.82900325382553,67.8758972278187,67.92279120181186,67.96968517580504,68.01657914979822,68.0634731237914,68.11036709778458,68.15726107177774,68.2041550457709,68.25104901976408,68.29794299375726,68.34483696775042,68.39173094174359,68.43862491573677,68.48551888972995,68.53241286372312,68.57930683771629,68.62620081170945,68.67309478570263,68.71998875969581,68.76688273368897,68.81377670768215,68.86067068167533,68.9075646556685,68.95445862966167,69.00135260365485,69.04824657764802,69.09514055164118,69.14203452563436,69.18892849962754,69.2358224736207,69.28271644761386,69.32961042160704,69.37650439560022,69.4233983695934,69.47029234358656,69.51718631757974,69.5640802915729,69.61097426556609,69.65786823955926,69.70476221355243,69.75165618754559,69.79855016153877,69.84544413553195,69.89233810952513,69.93923208351829,69.98612605751147,70.03302003150463,70.07991400549781,70.12680797949098,70.17370195348416,70.22059592747732,70.2674899014705,70.31438387546368,70.36127784945684,70.40817182345002,70.4550657974432,70.50195977143636,70.54885374542954,70.5957477194227,70.64264169341588,70.68953566740905,70.73642964140222,70.78332361539539,70.83021758938857,70.87711156338173,70.92400553737491,70.97089951136807,71.01779348536125,71.06468745935443,71.1115814333476,71.15847540734077,71.20500158043882,71.25079214768583,71.29658271493282,71.34237328217985,71.38816384942685,71.43395441667386,71.47974498392087,71.52553555116788,71.55357417732085,71.57806241525505,71.60255065318923,71.62703889112342,71.65152712905761,71.67601536699178,71.70050360492597,71.7256707128742,71.75219555335539,71.77872039383658,71.80524523431777,71.83177007479895,71.85829491528015,71.88481975576134,71.91134459624253,71.93786943672372,71.96439427720492,71.9909191176861,72.01744395816729,72.04396879864849,72.07049363912968,72.09701847961087,72.12354332009205,72.15006816057324,72.17659300105443,72.20311784153563,72.22964268201682,72.256167522498,72.28269236297919,72.30921720346039,72.33574204394158,72.36226688442277,72.38879172490395,72.41531656538514,72.44184140586634,72.46836624634753,72.49489108682872,72.5214159273099,72.5479407677911,72.57446560827229,72.60099044875348,72.62751528923467,72.65404012971587,72.68056497019705,72.70708981067824,72.73361465115943,72.76013949164062,72.78666433212182,72.81318917260299,72.83971401308419,72.86623885356538,72.89276369404658,72.91928853452777,72.94581337500895,72.97233821549014,72.99886305597133,73.02538789645251,73.05191273693372,73.0784375774149,73.10496241789609,73.13148725837729,73.15801209885848,73.18453693933967,73.21106177982085,73.23758662030204,73.26411146078324,73.29063630126443,73.31716114174563,73.3436859822268,73.370210822708,73.39673566318919,73.42326050367038,73.44978534415156,73.47631018463275,73.50283502511394,73.52935986559514,73.55588470607633,73.58240954655753,73.60893438703872,73.63545922751989,73.66198406800109,73.68850890848228,73.71503374896348,73.52822829143958,73.23475768491318,72.94128707838676,72.64781647186034,72.35434586533393,72.0608752588075,71.7674046522811,71.47393404575467,71.18046343922825,70.88699283270185,70.59352222617542,70.30005161964901,70.00658101312258,69.71311040659617,69.41963980006976,69.12616919354335,68.83269858701692,68.53922798049051,68.24575737396408,67.95228676743768,67.65881616091126,67.36534555438485,67.07187494785843,66.778404341332,66.4849337348056,66.19146312827917,65.89799252175276,65.60452191522634,65.31105130869992,65.01758070217352,64.72411009564709,64.43063948912067,64.13716888259427,63.84369827606784,63.55022766954143,63.256757063014994,62.96328645648859,62.66981584996219,62.37936243727463,62.09494335650738,61.81052427574015,61.5261051949729,61.24168611420565,60.9572670334384,60.672847952671134,60.38842887190388,60.104009791136654,59.819590710369404,59.535171629602154,59.2507525488349,58.96633346806765,58.68191438730042,58.39749530653316,58.11307622576592,57.828657144998665,57.54423806423143,57.25981898346418,56.97539990269693,56.69098082192968,56.40656174116242,56.122142660395184,55.837723579627934,55.55330449886068,55.26888541809343,54.9844663373262,54.70004725655895,54.415628175791696,54.131209095024445,53.846790014257195,53.56237093348996,53.27795185272271,52.99353277195546,52.709113691188215,52.42469461042096,52.14027552965372,51.85585644888648,51.57143736811922,51.28701828735198,51.00259920658473,50.71818012581749,50.43376104505023,50.14934196428299,49.86492288351573,49.575913120536605,49.28231267534564,48.98871223015465,48.695111784963615,48.404396704696595,48.11413246167354,47.823868218650404,47.533603975627344,47.243339732604205,46.95307548958115,46.662811246558014,46.37254700353495,46.08228276051181,45.792018517488756,45.50175427446562,45.21149003144264,44.92122578841954,44.630961545396445,44.34069730237335,44.05043305935029,43.76016881632715,43.46990457330405,43.179640330281,42.889376087257894,42.59911184423479,42.3088476012117,42.01858335818868,41.728319115165576,41.43805487214249,41.1481780805928,40.862281479352326,40.57638487811192,40.29048827687154,40.00459167563113,39.71869507439066,39.43279847315027,39.1469018719098,38.861005270669395,38.57510866942893,38.28921206818854,38.003315466948095,37.7174188657077,37.43152226446727,37.14562566322686,36.85972906198639,36.57383246074601,36.28793585950553,36.00203925826516,35.7161426570247,35.43024605578431,35.14553843366413,34.865459348993376,34.5853802643227,34.30530117965194,34.025222094981245,33.745143010310585,33.465063925639825,33.184984840969065,32.90490575629839,32.62482667162771,32.344747586956984,32.0646685022863,31.784589417615624,31.504510332944868,31.22443124827419,30.944352163603448,30.664273078932787,30.38419399426203,30.11146325697237,29.839201561316774,29.566939865661244,29.29467817000572,29.02241647435014,28.750154778694608,28.47789308303903,28.20563138738351,27.933369691727975,27.661107996072424,27.388846300416873,27.11658460476131,26.844322909105777,26.57206121345023,26.30314861731761,26.038685539495752,25.774222461673908,25.509759383852057,25.245296306030145,24.980833228208247,24.71637015038646,24.45190707256454,24.18744399474263,23.9229809169208,23.658517839098945,23.394054761277026,23.130087309471836,22.873554272510376,22.617021235548847,22.36048819858728,22.103955161625766,21.847422124664188,21.590889087702674,21.334356050741107,21.077823013779582,20.821289976818026,20.564756939856487,20.31181442801224,20.064329510165262,19.81684459231839,19.569359674471524,19.32187475662464,19.07438983877777,18.826904920930854,18.57942000308395,18.331935085237067,18.085491125712156,17.848019232957,17.610547340201848,17.37307544744666,17.13560355469152,16.89813166193636,16.660659769181173,16.423187876426034,16.185715983670857,15.957959034691818,15.730878749513419,15.503798464335006,15.276718179156553,15.049637893978154,14.822557608799714,14.59547732362128,14.374751913973874,14.156784278442135,13.938816642910417,13.720849007378678,13.502881371846977,13.284913736315257,13.069181908124111,12.860504435762829,12.651826963401483,12.443149491040174,12.234472018678847,12.025794546317547,11.822483943701808,11.62587005580953,11.429256167917254,11.232642280024935,11.036028392132657,10.842221925385342,10.658758596246802,10.47529526710821,10.291831937969638,10.108368608831071,9.930551083080953,9.759155118526927,9.587759153972927,9.41636318941889,9.246543461119892,9.086143621891546,8.925743782663167,8.765343943434809,8.606814718743252,8.456457129746681,8.306099540750093,8.155741951753512,8.01043860199108,7.869241820626673,7.728045039262284,7.588538694350449,7.455718403859095,7.322898113367742,7.190894023187353,7.065895655436309,6.940897287685251,6.818011915849722,6.702127431751839,6.5862429476539575,6.475906156921372,6.369916837151788,6.264419871307837,6.1654329206925755,6.066445970077327,5.971297227052634,5.8774755934783185,5.787358109875124,5.700110941352282,5.61645438113402,5.536142497267283,5.459485511649756,5.385326275415435,5.315424233033131,5.245729830103901,5.16328270557254,5.080835581041182,4.9983884565098355,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[67.6823381284008,67.72923210239398,67.77612607638714,67.82302005038032,67.86991402437349,67.91680799836666,67.96370197235984,68.010595946353,68.05748992034619,68.10438389433935,68.15127786833253,68.1981718423257,68.24506581631887,68.29195979031205,68.33885376430521,68.38574773829839,68.43264171229156,68.47953568628473,68.5264296602779,68.57332363427108,68.62021760826426,68.66711158225743,68.7140055562506,68.76089953024378,68.80779350423694,68.85468747823012,68.9015814522233,68.94847542621645,68.99536940020963,69.0422633742028,69.08915734819598,69.13605132218916,69.18294529618231,69.22983927017549,69.27673324416867,69.32362721816183,69.37052119215501,69.41741516614817,69.46430914014135,69.51120311413452,69.5580970881277,69.60499106212087,69.65188503611405,69.69877901010722,69.7456729841004,69.79256695809356,69.83946093208674,69.8863549060799,69.93324888007308,69.98014285406624,70.02703682805942,70.0739308020526,70.12082477604577,70.16771875003894,70.21461272403211,70.26150669802529,70.30840067201846,70.35529464601163,70.40218862000481,70.44908259399797,70.49505706354087,70.5408476307879,70.58663819803489,70.6324287652819,70.67821933252891,70.72400989977592,70.76980046702292,70.81559103426994,70.86138160151694,70.90717216876395,70.95296273601096,70.99875330325797,71.04454387050498,71.09033443775199,71.13612500499899,71.181915572246,71.22770613949301,71.27349670674002,71.31928727398702,71.36507784123404,71.41086840848104,71.45665897572806,71.50244954297506,71.54824011022207,71.57627873637506,71.60076697430924,71.62525521224342,71.64974345017761,71.67423168811179,71.69871992604597,71.72320816398016,71.74769640191434,71.77218463984853,71.79667287778273,71.8211611157169,71.84564935365108,71.87013759158526,71.89462582951944,71.91911406745363,71.94360230538783,71.968090543322,71.99257878125619,72.01706701919036,72.04155525712456,72.06604349505875,72.09053173299291,72.11501997092711,72.1395082088613,72.16569361774698,72.19221845822818,72.21874329870937,72.24526813919056,72.27179297967176,72.29831782015295,72.32484266063413,72.35136750111532,72.3778923415965,72.4044171820777,72.4309420225589,72.45746686304008,72.48399170352127,72.51051654400247,72.53704138448366,72.56356622496484,72.59009106544603,72.61661590592723,72.64314074640842,72.66966558688961,72.6961904273708,72.72271526785198,72.74924010833317,72.77576494881437,72.80228978929556,72.82881462977674,72.85533947025795,72.88186431073912,72.90838915122032,72.9349139917015,72.96143883218271,72.9879636726639,73.01448851314508,73.04101335362627,73.06753819410747,73.09406303458864,73.12058787506984,73.14711271555103,73.17363755603222,73.2001623965134,73.2266872369946,73.2532120774758,73.279736917957,73.30626175843818,73.33278659891937,73.35931143940056,73.38583627988174,73.41236112036293,73.43888596084412,73.4654108013253,73.49193564180649,73.5184604822877,73.54498532276888,73.57151016325008,73.59803500373127,73.62455984421246,73.65108468469364,73.67760952517483,73.70413436565603,73.51732890813214,73.22385830160573,72.9303876950793,72.63691708855289,72.34344648202648,72.04997587550005,71.75650526897365,71.46303466244723,71.1695640559208,70.8760934493944,70.58262284286798,70.28915223634155,69.99568162981515,69.70221102328873,69.40874041676231,69.1152698102359,68.82179920370947,68.52832859718306,68.23485799065665,67.94138738413022,67.6479167776038,67.3544461710774,67.06097556455099,66.76750495802455,66.47403435149815,66.18056374497172,65.88709313844531,65.59362253191891,65.30015192539247,65.00668131886607,64.71321071233965,64.41974010581322,64.12626949928682,63.832798892760394,63.539328286233975,63.245857679707555,62.95238707318114,62.65891646665473,62.36544586012831,62.07197525360189,61.77850464707548,61.48503404054907,61.19156343402264,60.89809282749623,60.60462222096981,60.31115161444339,60.01768100791698,59.724210401390565,59.43073979486414,59.137269188337726,58.843798581811306,58.550327975284894,58.256857368758475,57.963386762232055,57.66991615570563,57.37644554917923,57.08297494265281,56.78950433612639,56.49603372959997,56.20256312307355,55.90909251654714,55.61562191002073,55.32215130349431,55.02868069696789,54.73521009044148,54.44173948391506,54.148268877388645,53.85479827086222,53.561327664335806,53.267857057809394,52.974386451282975,52.68091584475656,52.387445238230136,52.0900719309204,51.76050155859314,51.43093118626585,51.10136081393857,50.77179044161129,50.442220069284026,50.112649696956744,49.78307932462946,49.45350895230217,49.1239385799749,48.81402127229974,48.5237570292766,48.23349278625355,47.94322854323057,47.65296430020743,47.36270005718437,47.07243581416124,46.78217157113817,46.49190732811503,46.20164308509199,45.91137884206884,45.62111459904577,45.330850356022644,45.04058611299959,44.750321869976446,44.46005762695347,44.169793383930376,43.879529140907266,43.589264897884185,43.29900065486112,43.00873641183799,42.71847216881488,42.428207925791824,42.138859477988916,41.85296287674852,41.567066275508054,41.28116967426765,40.995273073027185,40.70937647178679,40.423479870546394,40.13758326930592,39.85168666806551,39.56579006682514,39.27989346558473,38.99399686434425,38.70810026310386,38.42220366186339,38.13630706062299,37.85041045938252,37.56451385814213,37.27861725690169,36.992720655661294,36.70682405442086,36.42092745318046,36.13503085193999,35.85346553797406,35.573386453303364,35.29330736863262,35.01322828396193,34.73314919929119,34.453070114620566,34.17299102994981,33.89291194527914,33.61283286060838,33.33275377593769,33.05267469126702,32.77259560659627,32.4925165219255,32.21243743725483,31.93235835258415,31.652279267913425,31.372200183242747,31.092121100326256,30.819859404670723,30.547597709015143,30.27533601335962,30.00307431770403,29.730812622048504,29.458550926392988,29.186289230737394,28.914027535081864,28.641765839426345,28.369504143770758,28.09724244811523,27.82498075245965,27.55271905680413,27.280457361148596,27.008865485265037,26.74440240744314,26.47993932962122,26.215476251799366,25.951013173977522,25.68655009615562,25.422087018333766,25.157623940511918,24.893160862690074,24.628697784868155,24.364234707046254,24.09977162922447,23.835308551402555,23.573819237323455,23.317286200361952,23.060753163400378,22.804220126438846,22.547687089477282,22.29115405251582,22.034621015554293,21.778087978592726,21.521554941631216,21.265021904669634,21.008488867708117,20.755689976848288,20.50820505900136,20.260720141154472,20.013235223307607,19.765750305460738,19.51826538761376,19.27078046976689,19.02329555192002,18.77581063407314,18.528325716226266,18.289465879674335,18.051993986919136,17.814522094163937,17.577050201408806,17.33957830865365,17.1021064158985,16.864634523143312,16.62716263038817,16.39452404247369,16.167443757295295,15.940363472116893,15.71328318693844,15.486202901759999,15.259122616581601,15.032042331403186,14.805201854269516,14.587234218737846,14.369266583206105,14.15129894767439,13.933331312142686,13.715363676610949,13.497396041079229,13.283051955116598,13.074374482755267,12.865697010393959,12.657019538032614,12.448342065671332,12.239664593309985,12.036211507398955,11.839597619506648,11.64298373161437,11.44636984372205,11.249755955829775,11.053880861820799,10.870417532682206,10.68695420354365,10.503490874405065,10.320027545266527,10.138719103351685,9.967323138797692,9.795927174243682,9.624531209689643,9.453135245135616,9.289808109601804,9.129408270373448,8.96900843114508,8.808608591916732,8.65490358545422,8.50454599645763,8.354188407461082,8.203830818464514,8.062002257818936,7.920805476454518,7.77960869509012,7.642499237628072,7.509678947136738,7.376858656645368,7.24641895100406,7.121420583253001,6.996422215501974,6.874631528030918,6.758747043933049,6.642862559835209,6.532979186340333,6.426989866570736,6.32132878269543,6.222341832080156,6.123354881464896,6.027750757836694,5.933929124262413,5.842833488545938,5.755586320023085,5.6705033537390594,5.590191469872302,5.511939876031736,5.437780639797426,5.366192700197163,5.297479275852725,5.218956065660496,5.1365089411291365,5.054061816597775,4.971614692066417,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[67.72324889894877,67.77014287294193,67.81703684693511,67.86393082092829,67.91082479492145,67.95771876891463,68.0046127429078,68.05150671690097,68.09840069089414,68.14529466488732,68.19218863888048,68.23908261287366,68.28597658686684,68.33287056086002,68.37976453485318,68.42665850884634,68.47355248283952,68.5204464568327,68.56734043082587,68.61423440481903,68.66112837881221,68.70802235280539,68.75491632679855,68.80181030079173,68.8487042747849,68.89559824877807,68.94249222277125,68.98938619676441,69.0362801707576,69.08317414475076,69.13006811874394,69.17696209273711,69.22385606673028,69.27075004072346,69.31764401471663,69.3645379887098,69.41143196270298,69.45832593669614,69.50521991068932,69.55211388468248,69.59900785867566,69.64590183266883,69.69279580666202,69.73932197939594,69.78511254664294,69.83090311388993,69.87669368113696,69.92248424838395,69.96827481563096,70.01406538287797,70.05985595012498,70.10564651737201,70.15143708461899,70.197227651866,70.24301821911301,70.28880878636002,70.33459935360703,70.38038992085404,70.42618048810104,70.47197105534806,70.51776162259506,70.56355218984208,70.60934275708908,70.65513332433608,70.7009238915831,70.74671445883011,70.79250502607712,70.83829559332413,70.88408616057114,70.92987672781815,70.97566729506516,71.02145786231216,71.06724842955916,71.11303899680618,71.15882956405318,71.20462013130019,71.2504106985472,71.29620126579421,71.34199183304122,71.38778240028823,71.43357296753524,71.47936353478224,71.52515410202926,71.57094466927626,71.59898329542925,71.62347153336344,71.64795977129762,71.6724480092318,71.69693624716598,71.72142448510017,71.74591272303435,71.77040096096854,71.79488919890272,71.8193774368369,71.8438656747711,71.86835391270527,71.89284215063945,71.91733038857365,71.94181862650782,71.966306864442,71.99079510237621,72.01528334031039,72.03977157824457,72.06425981617875,72.08874805411293,72.11323629204712,72.1377245299813,72.16221276791548,72.18670100584967,72.21118924378385,72.23567748171804,72.26016571965222,72.2846539575864,72.3091421955206,72.33363043345477,72.35811867138895,72.38260690932314,72.40709514725732,72.43158338519152,72.4560716231257,72.48055986105987,72.50504809899407,72.52953633692825,72.55402457486244,72.57919168213859,72.60571652261979,72.63224136310097,72.65876620358216,72.68529104406335,72.71181588454454,72.73834072502574,72.76486556550692,72.79139040598811,72.8179152464693,72.84444008695048,72.87096492743169,72.89748976791287,72.92401460839406,72.95053944887525,72.97706428935645,73.00358912983764,73.03011397031882,73.05663881080001,73.08316365128121,73.1096884917624,73.13621333224359,73.16273817272477,73.18926301320596,73.21578785368716,73.24231269416835,73.26883753464953,73.29536237513072,73.32188721561192,73.34841205609311,73.3749368965743,73.40146173705548,73.42798657753667,73.45451141801787,73.48103625849906,73.50756109898025,73.53408593946143,73.56061077994264,73.58713562042382,73.61366046090501,73.6401853013862,73.66671014186738,73.69323498234857,73.50642952482468,73.21295891829828,72.91948831177186,72.62601770524543,72.33254709871903,72.0390764921926,71.7456058856662,71.45213527913978,71.15866467261336,70.86519406608696,70.57172345956052,70.27825285303412,69.98478224650769,69.69131163998128,69.39784103345488,69.10437042692845,68.81089982040203,68.51742921387562,68.22395860734919,67.93048800082278,67.63701739429635,67.34354678776994,67.05007618124354,66.7566055747171,66.4631349681907,66.16966436166427,65.87619375513786,65.58272314861145,65.28925254208502,64.99578193555863,64.70231132903218,64.40884072250577,64.11537011597937,63.82189950945295,63.528428902926535,63.2349582964001,62.941487689873696,62.648017083347284,62.35454647682086,62.06107587029444,61.76760526376803,61.47413465724162,61.180664050715194,60.887193444188775,60.593722837662355,60.30025223113594,60.00678162460954,59.71331101808312,59.41984041155669,59.12636980503027,58.83289919850385,58.53942859197745,58.24595798545103,57.93004697297681,57.600476600649536,57.27090622832226,56.941335855994986,56.61176548366771,56.28219511134042,55.95262473901313,55.62305436668587,55.29348399435859,54.96391362203131,54.63434324970402,54.304772877376756,53.975202505049474,53.64563213272219,53.31606176039491,52.98649138806763,52.656921015740366,52.32735064341308,51.9977802710858,51.66820989875852,51.33863952643123,51.00906915410397,50.67949878177668,50.3499284094494,50.02035803712212,49.690787664794854,49.36121729246757,49.03164692014029,48.70207654781301,48.372506175485725,48.062588867810575,47.77232462478743,47.48206038176437,47.1917961387414,46.90153189571826,46.6112676526952,46.32100340967207,46.030739166649006,45.74047492362586,45.45021068060281,45.15994643757968,44.8696821945566,44.57941795153347,44.28915370851042,43.998889465487274,43.7086252224643,43.4183609794412,43.12954087538504,42.843644274144644,42.55774767290418,42.271851071663775,41.98595447042337,41.700057869182984,41.41416126794251,41.12826466670211,40.84236806546164,40.55647146422125,40.27057486298077,39.98467826174038,39.69878166049998,39.41288505925951,39.1269884580191,38.84109185677872,38.55519525553832,38.269298654297835,37.983402053057446,37.69750545181698,37.41160885057658,37.12571224933612,36.8414717269548,36.56139264228404,36.281313557613366,36.001234472942684,35.721155388271924,35.44107630360117,35.1609972189305,34.88091813425981,34.600839049589055,34.32075996491837,34.04068088024763,33.760601795577,33.48052271090626,33.20044362623558,32.92036454156482,32.64028545689413,32.360206372223466,32.080127287552706,31.80051724802461,31.528255552369025,31.255993856713506,30.983732161057976,30.711470465402396,30.439208769746873,30.16694707409134,29.89468537843576,29.622423682780237,29.350161987124647,29.07790029146912,28.805638595813612,28.533376900158014,28.26111520450248,27.98885350884696,27.71659181319138,27.4501192753905,27.185656197568594,26.921193119746754,26.656730041924895,26.392266964103047,26.12780388628115,25.86334080845923,25.59887773063738,25.334414652815532,25.06995157499363,24.805488497171773,24.54102541934993,24.276562341528084,24.01755116517508,23.761018128213568,23.504485091252004,23.247952054290472,22.991419017328894,22.734885980367395,22.478352943405817,22.22181990644429,21.96528686948272,21.708753832521264,21.452220795559732,21.199565525684324,20.952080607837456,20.70459568999053,20.457110772143654,20.20962585429679,19.96214093644986,19.714656018602973,19.467171100756104,19.219686182909236,18.97220126506226,18.73091252639161,18.49344063363647,18.255968740881272,18.01849684812613,17.781024955370984,17.543553062615786,17.306081169860587,17.06860927710546,16.8311373843503,16.604008765077126,16.37692847989868,16.14984819472028,15.92276790954187,15.69568762436347,15.46860733918507,15.24152705400662,15.017684159033534,14.799716523501832,14.581748887970079,14.363781252438327,14.14581361690666,13.92784598137492,13.709878345843203,13.496922002109004,13.288244529747708,13.079567057386397,12.870889585025099,12.66221211266377,12.453534640302461,12.24993907109607,12.053325183203777,11.856711295311484,11.660097407419197,11.46348351952689,11.266869631634613,11.082076469117627,10.898613139979073,10.715149810840519,10.531686481701925,10.348223152563367,10.175491159068423,10.004095194514386,9.832699229960374,9.661303265406385,9.493472597312063,9.333072758083706,9.17267291885536,9.012273079626992,8.853350041161756,8.702992452165176,8.552634863168619,8.40227727417205,8.254762695011198,8.11356591364681,7.972369132282383,7.831172350917976,7.696459780905703,7.563639490414358,7.430819199922989,7.301943878820767,7.176945511069724,7.0519471433186816,6.931251140212138,6.8153666561142865,6.699482172016403,6.59005221575928,6.48406289598971,6.378237694082999,6.2792507434677365,6.180263792852489,6.084204288620777,5.990382655046471,5.89830886721675,5.811061698693919,5.724552326344089,5.64424044247734,5.564394240413726,5.4902350041794055,5.416961167361212,5.348247743016774,5.274629425748436,5.192182301217076,5.1097351766857315,5.027288052154372,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[67.76415966949672,67.81105364348988,67.85794761748306,67.90484159147624,67.95173556546942,67.99862953946258,68.04552351345575,68.09241748744893,68.1393114614421,68.18620543543528,68.23309940942845,68.27999338342161,68.32688735741479,68.37378133140797,68.42067530540113,68.46756927939431,68.51446325338748,68.56135722738065,68.60825120137383,68.655145175367,68.70203914936016,68.74893312335335,68.7958270973465,68.84272107133968,68.88961504533286,68.93650901932604,68.9834029933192,69.02937746249798,69.07516802974499,69.120958596992,69.16674916423901,69.21253973148602,69.25833029873301,69.30412086598004,69.34991143322705,69.39570200047405,69.44149256772107,69.48728313496807,69.53307370221508,69.57886426946209,69.6246548367091,69.6704454039561,69.7162359712031,69.76202653845012,69.80781710569713,69.85360767294412,69.89939824019115,69.94518880743814,69.99097937468515,70.03676994193216,70.08256050917916,70.12835107642618,70.17414164367318,70.2199322109202,70.26572277816722,70.31151334541421,70.35730391266124,70.40309447990823,70.44888504715524,70.49467561440225,70.54046618164925,70.58625674889628,70.63204731614327,70.67783788339028,70.72362845063729,70.7694190178843,70.8152095851313,70.86100015237832,70.90679071962532,70.95258128687234,70.99837185411934,71.04416242136635,71.08995298861336,71.13574355586036,71.18153412310738,71.22732469035438,71.27311525760139,71.3189058248484,71.36469639209541,71.41048695934242,71.45627752658943,71.50206809383644,71.54785866108344,71.59364922833045,71.62168785448344,71.64617609241762,71.6706643303518,71.69515256828599,71.71964080622017,71.74412904415436,71.76861728208854,71.79310552002272,71.81759375795691,71.84208199589109,71.86657023382529,71.89105847175946,71.91554670969366,71.94003494762782,71.96452318556203,71.98901142349621,72.01349966143039,72.03798789936457,72.06247613729875,72.08696437523295,72.11145261316713,72.13594085110131,72.16042908903549,72.18491732696967,72.20940556490386,72.23389380283805,72.25838204077223,72.28287027870641,72.3073585166406,72.33184675457477,72.35633499250896,72.38082323044316,72.40531146837733,72.42979970631151,72.4542879442457,72.47877618217989,72.50326442011408,72.52775265804826,72.55224089598244,72.57672913391663,72.60121737185081,72.625705609785,72.65019384771917,72.67468208565336,72.69917032358755,72.72365856152172,72.74814679945591,72.7726350373901,72.79712327532428,72.82161151325846,72.84609975119265,72.87058798912685,72.89507622706101,72.9195644649952,72.94405270292938,72.96854094086358,72.99302917879776,73.01921458701138,73.04573942749256,73.07226426797375,73.09878910845494,73.12531394893614,73.15183878941733,73.17836362989851,73.2048884703797,73.2314133108609,73.25793815134209,73.28446299182329,73.31098783230446,73.33751267278566,73.36403751326685,73.39056235374804,73.41708719422923,73.44361203471043,73.47013687519161,73.4966617156728,73.52318655615399,73.54971139663519,73.57623623711638,73.60276107759756,73.62928591807875,73.65581075855994,73.68233559904112,73.49553014151724,73.20205953499084,72.90858892846441,72.615118321938,72.32164771541159,72.02817710888516,71.73470650235875,71.44123589583234,71.14776528930591,70.8542946827795,70.56082407625307,70.26735346972666,69.97388286320025,69.68041225667382,69.38694165014742,69.093471043621,68.80000043709458,68.50652983056817,68.21305922404174,67.91958861751533,67.62611801098892,67.33264740446249,67.0391767979361,66.74570619140965,66.45223558488325,66.15876497835683,65.86529437183042,65.57182376530402,65.27835315877758,64.98488255225116,64.69141194572474,64.39794133919833,64.09959238736049,63.77002201503319,63.440451642705916,63.110881270378634,62.78131089805135,62.45174052572409,62.1221701533968,61.79259978106952,61.46302940874226,61.13345903641496,60.80388866408769,60.47431829176041,60.14474791943313,59.81517754710583,59.48560717477857,59.1560368024513,58.826466430124,58.496896057796725,58.16732568546944,57.837755313142175,57.5081849408149,57.17861456848761,56.849044196160335,56.51947382383307,56.18990345150578,55.8603330791785,55.53076270685122,55.20119233452394,54.87162196219667,54.54205158986939,54.212481217542106,53.88291084521482,53.553340472887555,53.22377010056027,52.894199728233,52.56462935590571,52.235058983578426,51.905488611251165,51.575918238923876,51.2463478665966,50.91677749426931,50.58720712194203,50.25763674961476,49.92806637728748,49.5984960049602,49.268925632632914,48.93935526030565,48.609784887978364,48.28021451565108,47.95064414332381,47.62107377099652,47.31115646332137,47.02089222029823,46.73062797727517,46.440363734252195,46.15009949122906,45.85983524820599,45.569571005182866,45.2793067621598,44.98904251913665,44.69877827611361,44.40851403309047,44.12022227278113,43.83432567154081,43.548429070300344,43.26253246905994,42.97663586781948,42.69073926657909,42.4048426653386,42.11894606409822,41.833049462857744,41.54715286161734,41.26125626037694,40.97535965913656,40.68946305789607,40.403566456655675,40.11766985541521,39.83177325417481,39.54587665293434,39.259980051693944,38.97408345045355,38.688186849213075,38.402290247972665,38.116393646732284,37.83049704549189,37.54939883126469,37.269319746594014,36.98924066192327,36.70916157725264,36.4290824925819,36.149003407911216,35.868924323240456,35.58884523856978,35.3087661538991,35.02868706922833,34.74860798455759,34.46852889988691,34.188449815216224,33.908370730545464,33.62829164587479,33.34821256120404,33.06813347653342,32.788054391862666,32.50891339572297,32.23665170006737,31.964390004411843,31.69212830875633,31.419866613100737,31.147604917445204,30.875343221789628,30.603081526134105,30.33081983047857,30.05855813482299,29.78629643916747,29.51403474351194,29.241773047856356,28.969511352200833,28.697249656545242,28.424987960889712,28.155836143337797,27.891373065515992,27.62690998769408,27.36244690987218,27.097983832050392,26.83352075422848,26.56905767640658,26.304594598584735,26.040131520762877,25.77566844294103,25.51120536511913,25.246742287297213,24.98227920947536,24.717816131653514,24.46128309302669,24.204750056065116,23.9482170191036,23.691683982142088,23.435150945180506,23.17861790821899,22.92208487125743,22.665551834295897,22.40901879733432,22.152485760372816,21.89595272341124,21.64344107452034,21.395956156673467,21.1484712388266,20.900986320979715,20.653501403132797,20.406016485285928,20.158531567439,19.91104664959213,19.66356173174526,19.416076813898332,19.172359173108866,18.934887280353724,18.697415387598582,18.459943494843426,18.222471602088238,17.984999709333096,17.7475278165779,17.510055923822755,17.272584031067613,17.040573772858952,16.81349348768054,16.58641320250215,16.35933291732374,16.13225263214529,15.905172346966845,15.678092061788444,15.451011776610033,15.230166463797525,15.012198828265785,14.794231192734033,14.576263557202326,14.358295921670624,14.140328286138873,13.922360650607121,13.710792049101425,13.502114576740126,13.293437104378818,13.084759632017487,12.876082159656189,12.66740468729488,12.463666634793185,12.267052746900875,12.07043885900859,11.873824971116298,11.677211083224002,11.480597195331711,11.293735405553042,11.110272076414486,10.926808747275933,10.743345418137338,10.559882088998783,10.383659179339137,10.212263214785102,10.0408672502311,9.8694712856771,9.698075321123063,9.536737245793953,9.376337406565593,9.215937567337239,9.055537728108881,8.901438907872706,8.751081318876146,8.60072372987958,8.450366140882998,8.306326350839061,8.165129569474654,8.023932788110228,7.88324061467468,7.750420324183327,7.617600033691959,7.484779743200614,7.357468806637467,7.232470438886409,7.107472071135382,6.987870752393372,6.871986268295503,6.75610178419762,6.647125245178259,6.541135925408662,6.435146605639066,6.336159654855324,6.237172704240051,6.140657819404842,6.046836185830548,5.95378424588757,5.866537077364717,5.779289908841875,5.698289415082366,5.617977531215617,5.542689368561373,5.4685301323270625,5.399016210180818,5.330302785836365,5.247855661305027,5.1654085367736675,5.082961412242307,5.000514287710963,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[67.80507044004469,67.85196441403785,67.89885838803103,67.9457523620242,67.99264633601737,68.03954031001055,68.08643428400372,68.13332825799688,68.18022223199006,68.22711620598324,68.27364237835302,68.31943294560004,68.36522351284704,68.41101408009405,68.45680464734107,68.50259521458807,68.54838578183508,68.59417634908209,68.6399669163291,68.68575748357611,68.73154805082311,68.77733861807012,68.82312918531713,68.86891975256414,68.91471031981115,68.96050088705816,69.00629145430517,69.05208202155217,69.09787258879919,69.14366315604619,69.1894537232932,69.23524429054021,69.28103485778722,69.32682542503423,69.37261599228123,69.41840655952824,69.46419712677525,69.50998769402226,69.55577826126927,69.60156882851628,69.64735939576329,69.69314996301028,69.73894053025731,69.7847310975043,69.83052166475132,69.87631223199833,69.92210279924534,69.96789336649235,70.01368393373934,70.05947450098635,70.10526506823336,70.15105563548038,70.19684620272737,70.24263676997438,70.2884273372214,70.3342179044684,70.38000847171543,70.42579903896242,70.47158960620942,70.51738017345644,70.56317074070344,70.60896130795047,70.65475187519746,70.70054244244446,70.74633300969148,70.79212357693851,70.8379141441855,70.8837047114325,70.92949527867952,70.97528584592652,71.02107641317355,71.06686698042054,71.11265754766754,71.15844811491456,71.20423868216156,71.25002924940858,71.2958198166556,71.34161038390259,71.38740095114962,71.43319151839661,71.47898208564362,71.52477265289063,71.57056322013763,71.61635378738464,71.64439241353763,71.66888065147181,71.693368889406,71.71785712734018,71.74234536527436,71.76683360320855,71.79132184114273,71.81581007907691,71.8402983170111,71.86478655494528,71.88927479287948,71.91376303081364,71.93825126874785,71.96273950668201,71.9872277446162,72.01171598255038,72.03620422048458,72.06069245841876,72.08518069635295,72.10966893428713,72.13415717222131,72.15864541015549,72.18313364808968,72.20762188602386,72.23211012395805,72.25659836189223,72.28108659982641,72.3055748377606,72.3300630756948,72.35455131362897,72.37903955156315,72.40352778949733,72.42801602743151,72.4525042653657,72.4769925032999,72.50148074123408,72.52596897916825,72.55045721710245,72.57494545503663,72.59943369297082,72.623921930905,72.64841016883918,72.67289840677336,72.69738664470755,72.72187488264174,72.74636312057592,72.7708513585101,72.7953395964443,72.81982783437847,72.84431607231267,72.86880431024684,72.89329254818102,72.9177807861152,72.9422690240494,72.96675726198357,72.99124549991777,73.01573373785195,73.04022197578612,73.06471021372032,73.0891984516545,73.11368668958868,73.13817492752287,73.16266316545705,73.18715140339123,73.21163964132542,73.23612787925961,73.26061611719378,73.28510435512797,73.30959259306216,73.33408083099633,73.35856906893052,73.38305730686471,73.40754554479888,73.43271265140298,73.45923749188417,73.48576233236535,73.51228717284654,73.53881201332774,73.56533685380893,73.59186169429012,73.6183865347713,73.64491137525249,73.67143621573369,73.48463075820979,73.19116015168339,72.89768954515696,72.60421893863055,72.31074833210414,72.01727772557771,71.7238071190513,71.43033651252487,71.13686590599846,70.84339529947206,70.54992469294562,70.25645408641923,69.93956742941687,69.60999705708959,69.28042668476233,68.95085631243505,68.62128594010777,68.29171556778047,67.9621451954532,67.63257482312594,67.30300445079864,66.97343407847137,66.6438637061441,66.3142933338168,65.98472296148954,65.65515258916226,65.32558221683497,64.9960118445077,64.66644147218041,64.33687109985314,64.00730072752586,63.67773035519858,63.34815998287131,63.018589610544026,62.689019238216744,62.35944886588946,62.02987849356218,61.70030812123491,61.37073774890763,61.04116737658035,60.711597004253086,60.3820266319258,60.05245625959852,59.72288588727123,59.39331551494395,59.06374514261667,58.7341747702894,58.40460439796212,58.075034025634835,57.74546365330757,57.41589328098027,57.086322908653,56.75675253632573,56.42718216399844,56.09761179167116,55.768041419343895,55.438471047016606,55.10890067468932,54.77933030236204,54.449759930034766,54.1201895577075,53.79061918538021,53.46104881305294,53.13147844072565,52.80190806839839,52.4723376960711,52.142767323743826,51.813196951416536,51.48362657908926,51.15405620676199,50.8244858344347,50.49491546210743,50.165345089780146,49.835774717452864,49.506204345125596,49.176633972798314,48.847063600471024,48.51749322814375,48.187922855816474,47.8583524834892,47.52878211116192,47.199211738834634,46.869641366507345,46.559724058832195,46.26945981580906,45.979195572786,45.68893132976302,45.398667086739884,45.11090367017733,44.82500706893694,44.53911046769647,44.25321386645599,43.9673172652156,43.6814206639752,43.39552406273472,43.1096274614944,42.82373086025393,42.53783425901353,42.25193765777307,41.966041056532674,41.680144455292194,41.394247854051805,41.10835125281134,40.82245465157093,40.53655805033053,40.250661449090146,39.96476484784966,39.67886824660926,39.39297164536879,39.1070750441284,38.82117844288793,38.53740502024543,38.257325935574755,37.977246850904,37.697167766233235,37.417088681562575,37.137009596891886,36.85693051222112,36.57685142755045,36.2967723428797,36.016693258209074,35.73661417353833,35.456535088867646,35.176456004196886,34.89637691952621,34.61629783485553,34.33621875018477,34.05613966551402,33.77606058084335,33.495981496172654,33.21730954342126,32.945047847765736,32.67278615211022,32.40052445645462,32.1282627607991,31.856001065143584,31.58373936948799,31.31147767383246,31.03921597817695,30.766954282521354,30.494692586865824,30.222430891210244,29.950169195554718,29.67790749989919,29.40564580424361,29.133384108588086,28.861553011285157,28.597089933463312,28.332626855641468,28.068163777819553,27.803700699997695,27.539237622175808,27.274774544354006,27.01031146653209,26.74584838871019,26.481385310888403,26.216922233066487,25.952459155244586,25.687996077422746,25.423532999600887,25.16154805783978,24.905015020878267,24.648481983916685,24.391948946955157,24.13541590999365,23.878882873032133,23.622349836070555,23.36581679910904,23.109283762147527,22.852750725185945,22.596217688224435,22.339684651262868,22.087316623356433,21.83983170550955,21.592346787662695,21.344861869815766,21.097376951968833,20.849892034121968,20.602407116275096,20.354922198428213,20.107437280581294,19.859952362734425,19.6138058198262,19.376333927071055,19.13886203431587,18.901390141560714,18.663918248805516,18.426446356050374,18.188974463295235,17.951502570540075,17.714030677784887,17.477138780640836,17.250058495462422,17.02297821028398,16.79589792510558,16.56881763992713,16.341737354748716,16.11465706957033,15.887576784391916,15.660616404093162,15.442648768561497,15.224681133029758,15.006713497498005,14.788745861966337,14.570778226434598,14.352810590902845,14.13484295537114,13.924662096093876,13.715984623732567,13.507307151371258,13.298629679009926,13.08995220664863,12.88127473428732,12.6773941984903,12.480780310598025,12.284166422705704,12.087552534813426,11.89093864692112,11.69432475902883,11.505394341988495,11.32193101284995,11.138467683711355,10.955004354572761,10.771541025434207,10.591827199609869,10.420431235055856,10.249035270501832,10.077639305947827,9.906243341393793,9.74040173350422,9.580001894275851,9.419602055047495,9.25920221581914,9.099885363580274,8.949527774583684,8.799170185587116,8.648812596590535,8.499086788031324,8.357890006666917,8.2166932253025,8.075496443938102,7.937201157952286,7.804380867460934,7.671560576969597,7.538740286478245,7.412993734454158,7.287995366703139,7.162996998952089,7.044490364574594,6.928605880476741,6.812721396378858,6.704198274597207,6.598208954827623,6.492219635058053,6.3930685662429045,6.294081615627631,6.197111350188923,6.1032897166146185,6.009468083040302,5.922012456035542,5.834765287512699,5.752338387687393,5.6720265038206374,5.595143732943371,5.520984496709042,5.449784677344867,5.38107125300043,5.303529021392967,5.221081896861609,5.1386347723302634,5.056187647798903,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[67.83972265332471,67.88438651082765,67.92905036833059,67.97371422583353,68.01837808333646,68.0630419408394,68.10770579834232,68.15255744125525,68.19834800850226,68.24413857574928,68.28992914299627,68.3357197102433,68.38151027749029,68.4273008447373,68.47309141198431,68.51888197923132,68.56467254647833,68.61046311372533,68.65625368097234,68.70204424821935,68.74783481546636,68.79362538271337,68.83941594996038,68.8852065172074,68.93099708445439,68.9767876517014,69.02257821894841,69.06836878619542,69.11415935344243,69.15994992068943,69.20574048793645,69.25153105518345,69.29732162243046,69.34311218967747,69.38890275692448,69.43469332417149,69.4804838914185,69.52627445866551,69.57206502591251,69.61785559315953,69.66364616040653,69.70943672765354,69.75522729490055,69.80101786214756,69.84680842939457,69.89259899664158,69.93838956388859,69.98418013113559,70.0299706983826,70.07576126562961,70.12155183287662,70.16734240012363,70.21313296737064,70.25892353461765,70.30471410186465,70.35050466911167,70.39629523635867,70.44208580360569,70.48787637085269,70.53366693809969,70.57945750534671,70.6252480725937,70.67103863984073,70.71682920708773,70.76261977433474,70.80841034158175,70.85420090882874,70.89999147607577,70.94578204332277,70.99157261056979,71.03736317781679,71.0831537450638,71.12894431231081,71.1747348795578,71.22052544680483,71.26631601405182,71.31210658129883,71.35789714854585,71.40368771579286,71.44947828303987,71.49526885028688,71.54105941753387,71.58684998478088,71.6326405520279,71.65893087564658,71.68132115053959,71.70371142543257,71.72610170032559,71.7484919752186,71.77088225011161,71.79327252584747,71.81776076378165,71.84224900171584,71.86673723965004,71.89122547758421,71.9157137155184,71.94020195345257,71.96469019138677,71.98917842932094,72.01366666725514,72.03815490518932,72.0626431431235,72.08713138105767,72.11161961899187,72.13610785692606,72.16059609486022,72.18508433279442,72.2095725707286,72.23406080866279,72.25854904659697,72.28303728453116,72.30752552246534,72.33201376039952,72.35650199833371,72.38099023626789,72.40547847420207,72.42996671213626,72.45445495007044,72.47894318800462,72.50343142593881,72.527919663873,72.55240790180719,72.57689613974136,72.60138437767554,72.62587261560974,72.6503608535439,72.6748490914781,72.69933732941227,72.72382556734647,72.74831380528065,72.77280204321482,72.79729028114902,72.82177851908321,72.84626675701739,72.87075499495157,72.89524323288576,72.91973147081995,72.94421970875412,72.96870794668831,72.99319618462249,73.01768442255667,73.04217266049086,73.06666089842504,73.09114913635923,73.11563737429341,73.14012561222759,73.16461385016179,73.18910208809598,73.21359032603016,73.23807856396434,73.26256680189852,73.28705503983271,73.3115432777669,73.33603151570107,73.36051975363526,73.38500799156945,73.40949622950362,73.43398446743781,73.458472705372,73.48296094330618,73.50744918124036,73.53193741917454,73.55642565710873,73.58091389504291,73.60540213297709,73.62989037091128,73.65437860884546,73.41766980346614,73.0503624764301,72.68305514939402,72.31574782235796,71.94844049532192,71.58113316828583,71.21382584124979,70.84651853816409,70.51687772000237,70.18723690184063,69.85759608367889,69.52795526551716,69.19831444735544,68.8686736291937,68.53903281103197,68.20939199287024,67.8797511747085,67.55011035654677,67.22046953838503,66.89082872022331,66.56118790206158,66.23154708389984,65.90190626573812,65.57226544757637,65.24262462941465,64.91298381125291,64.58334299309116,64.25370217492946,63.924061356767695,63.59442053860597,63.26477972044424,62.9351389022825,62.60549808412078,62.27585726595904,61.94621644779731,61.61657562963558,61.286934811473834,60.95729399331212,60.62765317515037,60.298012356988636,59.96837153882693,59.63873072066518,59.30908990250345,58.97944908434171,58.649808266179974,58.32016744801824,57.99052662985651,57.66088581169478,57.33124499353304,57.0016041753713,56.67196335720956,56.34232253904784,56.01268172088612,55.68304090272438,55.35340008456264,55.023759266400916,54.69411844823918,54.364477630077445,54.03483681191571,53.70519599375397,53.375555175592254,53.04591435743051,52.71627353926877,52.38663272110705,52.05699190294532,51.727351084783585,51.39771026662185,51.06806944846011,50.73842863029837,50.40878781213665,50.079146993974916,49.74950617581318,49.419865357651446,49.090224539489704,48.76058372132798,48.43094290316625,48.10130208500451,47.77166126684277,47.44202044868105,47.112379630519314,46.78273881235758,46.45309799419584,46.12345717603411,45.81568846633298,45.529791865092584,45.24389526385212,44.95799866261179,44.67210206137132,44.386205460130924,44.10030885889053,43.814412257650055,43.528515656409574,43.24261905516919,42.95672245392879,42.67082585268832,42.384929251447986,42.099032650207526,41.813136048967124,41.52723944772666,41.24134284648627,40.95544624524579,40.6695496440054,40.383653042764934,40.097756441524524,39.81185984028412,39.52596323904374,39.245332124555354,38.96525303988474,38.68517395521399,38.40509487054331,38.125015785872556,37.844936701201874,37.56485761653119,37.28477853186044,37.00469944718968,36.72462036251902,36.44454127784832,36.16446219317756,35.88438310850689,35.60430402383614,35.32422493916551,35.04414585449477,34.76406676982408,34.48398768515333,34.20390860048265,33.9257056911197,33.6534439954641,33.38118229980858,33.10892060415306,32.83665890849747,32.56439721284188,32.29213551718636,32.019873821530844,31.747612125875246,31.47535043021972,31.203088734564204,30.93082703890861,30.65856534325308,30.386303647597572,30.114041951941974,29.841780256286448,29.56951856063086,29.302806801410686,29.03834372358877,28.77388064576698,28.509417567945082,28.244954490123167,27.980491412301323,27.71602833447948,27.451565256657563,27.187102178835705,26.922639101013818,26.658176023192013,26.3937129453701,26.1292498675482,25.864786789726413,25.6052799856914,25.348746948729836,25.092213911768322,24.83568087480679,24.579147837845227,24.322614800883713,24.066081763922135,23.809548726960603,23.553015689999096,23.296482653037575,23.039949616076,22.783416579114487,22.531192172192483,22.2837072543456,22.03622233649873,21.788737418651863,21.541252500804934,21.293767582958047,21.046282665111193,20.798797747264267,20.551312829417334,20.303827911570465,20.056342993723597,19.817780573788333,19.58030868103319,19.34283678827805,19.10536489552285,18.867893002767705,18.63042111001252,18.392949217257364,18.155477324502165,17.918005431747023,17.686623503244267,17.459543218065814,17.232462932887415,17.005382647709016,16.778302362530603,16.55122207735216,16.324141792173762,16.09706150699531,15.873098708857174,15.655131073325482,15.43716343779373,15.219195802261979,15.001228166730307,14.78326053119857,14.565292895666818,14.347325260135152,14.13853214308635,13.929854670725042,13.721177198363742,13.51249972600238,13.30382225364107,13.095144781279757,12.891121762187415,12.694507874295141,12.49789398640282,12.301280098510544,12.104666210618266,11.908052322725947,11.717053278423908,11.533589949285352,11.350126620146781,11.166663291008218,10.983199961869671,10.799995219880596,10.628599255326561,10.457203290772584,10.285807326218558,10.114411361664548,9.944066221214477,9.783666381986132,9.623266542757753,9.462866703529407,9.302466864301039,9.147974230291222,8.997616641294652,8.847259052298103,8.696901463301515,8.55065044385918,8.40945366249478,8.268256881130363,8.127060099765957,7.9911617012299185,7.858341410738575,7.725521120247205,7.593517030021925,7.468518662270898,7.343520294519855,7.21852192676878,7.101109976755826,6.985225492657964,6.869341008560081,6.761271304016182,6.655281984246583,6.549292664476999,6.449977477630473,6.350990527015226,6.2535648809729825,6.159743247398678,6.0659216138243846,5.977487834706355,5.8902406661835025,5.806387360292433,5.7260754764256765,5.647598097325343,5.573438861091022,5.500553144508925,5.431839720164471,5.35920238148091,5.2767552569495635,5.194308132418204,5.111861007886846,5.029413883355501,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[67.86552129674712,67.91018515425006,67.95484901175298,67.99951286925592,68.04417672675886,68.0888405842618,68.13350444176473,68.17816829926767,68.22283215677061,68.26749601427355,68.31215987177647,68.3568237292794,68.40148758678234,68.44615144428528,68.49081530178822,68.53547915929116,68.58014301679408,68.62480687429702,68.66947073179996,68.7141345893029,68.75879844680583,68.80346230430877,68.84812616181169,68.89279001931463,68.93820501691368,68.9839955841607,69.0297861514077,69.0755767186547,69.12136728590173,69.16715785314872,69.21294842039573,69.25873898764276,69.30452955488975,69.35032012213676,69.39611068938378,69.44190125663077,69.4876918238778,69.53348239112479,69.5792729583718,69.62506352561883,69.67085409286582,69.71664466011282,69.76243522735984,69.80822579460686,69.85401636185385,69.89980692910086,69.94559749634787,69.99138806359488,70.0371786308419,70.0829691980889,70.1287597653359,70.17455033258292,70.22034089982992,70.26613146707693,70.31192203432394,70.35771260157095,70.40350316881796,70.44929373606497,70.49508430331198,70.54087487055898,70.58666543780599,70.632456005053,70.6782465723,70.72403713954702,70.76982770679402,70.81561827404104,70.86140884128804,70.90719940853505,70.95298997578206,70.99878054302907,71.04457111027608,71.09036167752308,71.1361522447701,71.1819428120171,71.22773337926411,71.27352394651112,71.31931451375813,71.36510508100514,71.41089564825214,71.45668621549916,71.50247678274616,71.54826734999317,71.59405791724018,71.63984848448719,71.66613880810587,71.68852908299887,71.71091935789188,71.7333096327849,71.75569990767791,71.77809018257092,71.80048045746392,71.82287073235693,71.84526100724995,71.86765128214296,71.89004155703597,71.91243183192898,71.934822106822,71.95721238171501,71.97960265660802,72.00199293150104,72.02438320639403,72.04677348128705,72.06916375618006,72.09155403107307,72.11394430596609,72.13633458085909,72.1587248557521,72.18216411266238,72.20665235059656,72.23114058853074,72.25562882646493,72.28011706439911,72.3046053023333,72.32909354026748,72.35358177820166,72.37807001613585,72.40255825407002,72.42704649200421,72.4515347299384,72.47602296787258,72.50051120580676,72.52499944374094,72.54948768167513,72.57397591960932,72.5984641575435,72.62295239547768,72.64744063341188,72.67192887134607,72.69641710928023,72.72090534721443,72.7453935851486,72.76988182308278,72.79437006101698,72.81885829895117,72.84334653688535,72.86783477481953,72.89232301275372,72.91681125068789,72.94129948862208,72.96578772655627,72.99027596449045,73.01476420242463,73.03925244035882,73.063740678293,73.0882289162272,73.11271715416137,73.13720539209555,73.16169363002975,73.18618186796392,73.21067010589812,73.23515834383228,73.25964658176648,73.28413481970067,73.30862305763483,73.33311129556903,73.35759953350322,73.3820877714374,73.40657600937158,73.43106424730577,73.45555248523995,73.48004072317414,73.50452896110832,73.5290171990425,73.55350543697669,73.57799367491087,73.60248191284505,73.62697015077924,73.39026134539992,73.02295401836386,72.65564669132779,72.28833936429173,71.92103203725569,71.5537247102196,71.18641738318355,70.81911005614748,70.45180272911142,70.08449540207538,69.71718807503927,69.34988074800324,68.98257342096717,68.6152660939311,68.24795876689505,67.880651439859,67.51334411282292,67.14603678578686,66.7787294587508,66.41142213171474,66.04411480467867,65.67680747764263,65.30950015060657,64.94219282357048,64.57488549653443,64.20757816949836,63.85864478304477,63.529003964883046,63.199363146721296,62.86972232855957,62.540081510397826,62.21044069223609,61.88079987407438,61.551159055912635,61.22151823775091,60.891877419589164,60.56223660142743,60.23259578326571,59.902954965103966,59.57331414694223,59.24367332878052,58.914032510618775,58.58439169245704,58.254750874295304,57.92511005613356,57.59546923797183,57.265828419810106,56.93618760164838,56.60654678348663,56.2769059653249,55.94726514716316,55.617624329001444,55.28798351083971,54.95834269267796,54.62870187451623,54.2990610563545,53.969420238192775,53.63977942003104,53.3101386018693,52.98049778370756,52.65085696554584,52.321216147384106,51.99157532922237,51.661934511060636,51.33229369289891,51.00265287473718,50.673012056575445,50.3433712384137,50.01373042025197,49.68408960209024,49.354448783928504,49.02480796576677,48.695167147605034,48.3655263294433,48.03588551128158,47.70624469311984,47.37660387495811,47.04696305679637,46.71732223863464,46.38768142047291,46.058040602311166,45.72839978414944,45.398758965987696,45.09099025628658,44.80509365504618,44.51919705380571,44.23330045256539,43.947403851324914,43.66150725008452,43.37561064884412,43.08971404760365,42.803817446363176,42.51792084512279,42.23202424388239,41.946127642641905,41.66023104140159,41.37433444016112,41.08843783892071,40.80254123768025,40.51664463643986,40.233338313536095,39.95325922886541,39.673180144194674,39.393101059523985,39.113021974853226,38.83294289018256,38.5528638055118,38.27278472084118,37.99270563617043,37.712626551499746,37.43254746682899,37.15246838215831,36.87238929748763,36.59231021281688,36.31223112814612,36.03215204347545,35.75207295880476,35.471993874134,35.191914789463326,34.91183570479258,34.634101838818,34.36184014316242,34.08957844750696,33.81731675185136,33.54505505619585,33.27279336054032,33.000531664884726,32.728269969229196,32.45600827357369,32.183746577918086,31.911484882262503,31.639223186606976,31.36696149095146,31.09469979529587,30.822438099640344,30.55017640398483,30.27791470832923,30.008523669358045,29.744060591536208,29.479597513714296,29.21513443589244,28.95067135807059,28.686208280248692,28.42174520242678,28.157282124604997,27.89281904678309,27.628355968961177,27.36389289113933,27.09942981331749,26.834966735495573,26.570503657673715,26.306040579851828,26.04901191354303,25.792478876581455,25.535945839619938,25.279412802658374,25.022879765696842,24.766346728735282,24.50981369177377,24.253280654812237,23.996747617850673,23.74021458088916,23.483681543927577,23.227148506966053,22.975067721028566,22.727582803181697,22.480097885334814,22.232612967487896,21.98512804964098,21.7376431317941,21.490158213947232,21.24267329610036,20.99518837825343,20.747703460406544,20.500218542559693,20.259227220505622,20.021755327750466,19.784283434995324,19.546811542240185,19.309339649484983,19.07186775672984,18.8343958639747,18.5969239712195,18.359452078464358,18.123188511026157,17.896108225847705,17.669027940669288,17.44194765549089,17.214867370312447,16.987787085134,16.760706799955596,16.533626514777197,16.306546229598784,16.085581013621194,15.867613378089455,15.649645742557702,15.431678107025986,15.213710471494295,14.995742835962542,14.777775200430789,14.561079662440086,14.35240219007879,14.143724717717479,13.93504724535615,13.72636977299485,13.517692300633541,13.309014828272245,13.104849325884576,12.908235437992257,12.71162155009997,12.51500766220766,12.318393774315382,12.121779886423065,11.928712214859361,11.745248885720779,11.561785556582212,11.378322227443629,11.194858898305073,11.011395569166506,10.836767275597316,10.665371311043325,10.49397534648929,10.32257938193525,10.151183417381274,9.98733086969639,9.826931030468012,9.666531191239667,9.506131352011318,9.34642068599876,9.196063097002199,9.045705508005643,8.895347919009055,8.744990330012484,8.602214099687036,8.461017318322646,8.319820536958218,8.178623755593822,8.045122244507551,7.912301954016183,7.779481663524837,7.649041957838648,7.524043590087604,7.399045222336547,7.27404685458552,7.157729588937056,7.04184510483916,6.9259606207413125,6.818344333435141,6.712355013665544,6.606365693895974,6.506886389018078,6.407899438402806,6.310018411757053,6.216196778182761,6.122375144608443,6.032963213377158,5.945716044854327,5.860436332897453,5.780124449030705,5.700052461707333,5.625893225473012,5.551733989238683,5.48260818732852,5.413894762984082,5.332428617037503,5.249981492506143,5.167534367974797,5.0850872434434375,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[67.89131994016952,67.93598379767246,67.98064765517539,68.02531151267833,68.06997537018125,68.1146392276842,68.15930308518713,68.20396694269007,68.248630800193,68.29329465769594,68.33795851519888,68.3826223727018,68.42728623020474,68.47195008770768,68.51661394521062,68.56127780271356,68.60594166021649,68.65060551771943,68.69526937522235,68.73993323272529,68.78459709022823,68.82926094773117,68.8739248052341,68.91858866273704,68.96325252023998,69.0079163777429,69.05258023524586,69.09724409274878,69.14190795025172,69.18657180775466,69.23123566525759,69.27589952276053,69.32056338026347,69.36522723776639,69.40989109526933,69.45455495277227,69.4992188102752,69.54388266777813,69.58854652528107,69.63321038278401,69.67806202532512,69.72385259257213,69.76964315981914,69.81543372706614,69.86122429431316,69.90701486156016,69.95280542880718,69.99859599605418,70.04438656330119,70.0901771305482,70.13596769779521,70.18175826504222,70.22754883228922,70.27333939953623,70.31912996678324,70.36492053403025,70.41071110127726,70.45650166852427,70.50229223577128,70.54808280301827,70.5938733702653,70.6396639375123,70.6854545047593,70.73124507200632,70.77703563925333,70.82282620650034,70.86861677374735,70.91440734099436,70.96019790824135,71.00598847548838,71.05177904273538,71.09756960998239,71.1433601772294,71.18915074447641,71.23494131172342,71.28073187897041,71.32652244621742,71.37231301346444,71.41810358071145,71.46389414795846,71.50968471520545,71.55547528245246,71.60126584969947,71.64705641694648,71.67334674056517,71.69573701545818,71.71812729035119,71.74051756524419,71.7629078401372,71.7852981150302,71.80768838992321,71.83007866481623,71.85246893970924,71.87485921460225,71.89724948949527,71.91963976438828,71.94203003928129,71.9644203141743,71.98681058906732,72.00920086396033,72.03159113885334,72.05398141374636,72.07637168863937,72.09876196353237,72.12115223842537,72.14354251331838,72.16593278821139,72.1883230631044,72.21071333799742,72.23310361289043,72.25549388778344,72.27788416267646,72.30027443756947,72.32266471246248,72.3450549873555,72.36744526224851,72.38983553714151,72.41222581203452,72.43461608692752,72.45700636182053,72.47939663671355,72.50178691160656,72.52417718649957,72.5465674615431,72.57105569947728,72.59554393741146,72.62003217534564,72.64452041327984,72.66900865121401,72.69349688914821,72.71798512708239,72.74247336501656,72.76696160295076,72.79144984088494,72.81593807881913,72.84042631675331,72.86491455468749,72.88940279262167,72.91389103055586,72.93837926849005,72.96286750642423,72.98735574435841,73.01184398229259,73.03633222022678,73.06082045816098,73.08530869609515,73.10979693402933,73.13428517196353,73.1587734098977,73.18326164783188,73.20774988576606,73.23223812370026,73.25672636163443,73.28121459956861,73.3057028375028,73.330191075437,73.35467931337118,73.37916755130536,73.40365578923954,73.42814402717373,73.45263226510792,73.47712050304209,73.50160874097628,73.52609697891047,73.55058521684465,73.57507345477883,73.59956169271302,73.36285288733369,72.99554556029764,72.62823823326157,72.2609309062255,71.89362357918945,71.52631625215338,71.15900892511732,70.79170159808126,70.4243942710452,70.05708694400914,69.68977961697306,69.32247228993701,68.95516496290095,68.58785763586488,68.22055030882882,67.85324298179276,67.4859356547567,67.11862832772064,66.75132100068457,66.38401367364852,66.01670634661244,65.64939901957639,65.28209169254035,64.91478436550426,64.5474770384682,64.18016971143213,63.81286238439608,63.445555057360025,63.07824773032394,62.71094040328789,62.34363307625182,61.97632574921576,61.60901842217971,61.241711095143636,60.874403768107584,60.5070964410715,60.13978911403545,59.7724817869994,59.40517445996332,59.03786713292726,58.670559805891216,58.30325247885514,57.935945151819084,57.56863782478301,57.201330497746945,56.87077102792539,56.54113020976367,56.21148939160193,55.881848573440195,55.55220775527846,55.222566937116724,54.892926118955,54.56328530079326,54.23364448263153,53.90400366446979,53.57436284630807,53.244722028146334,52.91508120998459,52.585440391822864,52.25579957366112,51.92615875549941,51.596517937337666,51.26687711917593,50.937236301014195,50.607595482852474,50.27795466469074,49.948313846529004,49.61867302836726,49.289032210205534,48.959391392043806,48.62975057388207,48.300109755720335,47.9704689375586,47.64082811939686,47.31118730123514,46.9815464830734,46.651905664911666,46.32226484674993,45.99262402858821,45.662983210426475,45.33334239226473,45.003701574103005,44.67406075594126,44.36629204624014,44.08039544499974,43.79449884375927,43.50860224251895,43.22270564127847,42.93680904003808,42.65091243879768,42.36501583755721,42.07911923631673,41.793222635076354,41.50732603383595,41.22142943259547,40.941265417846,40.66118633317532,40.38110724850462,40.101028163833945,39.82094907916327,39.54086999449251,39.26079090982183,38.98071182515108,38.700632740480394,38.42055365580964,38.14047457113897,37.860395486468214,37.58031640179759,37.30023731712684,37.02015823245616,36.74007914778541,36.46000006311473,36.179920978444045,35.899841893773285,35.61976280910253,35.342497986516356,35.07023629086081,34.79797459520522,34.5257128995497,34.25345120389419,33.981189508238586,33.708927812583006,33.43666611692755,33.16440442127195,32.89214272561644,32.619881029960915,32.347619334305314,32.075357638649784,31.803095942994275,31.530834247338685,31.258572551683095,30.98631085602757,30.714240537305347,30.44977745948355,30.185314381661648,29.9208513038398,29.656388226017945,29.391925148196034,29.127462070374197,28.862998992552285,28.59853591473043,28.33407283690858,28.06960975908668,27.805146681264766,27.54068360344298,27.276220525621078,27.011757447799162,26.7492768783561,26.492743841394585,26.236210804433004,25.97967776747143,25.72314473050998,25.466611693548447,25.210078656586873,24.95354561962536,24.697012582663792,24.440479545702267,24.1839465087407,23.927413471779186,23.670880434817654,23.418943269864645,23.17145835201773,22.923973434170847,22.676488516323914,22.429003598477046,22.181518680630177,21.93403376278329,21.686548844936375,21.43906392708946,21.19157900924258,20.94409409139571,20.70067386722294,20.46320197446778,20.225730081712584,19.988258188957452,19.750786296202257,19.513314403447097,19.275842510691955,19.038370617936817,18.800898725181614,18.56342683242647,18.332673233629528,18.105592948451115,17.878512663272712,17.651432378094317,17.42435209291586,17.19727180773745,16.97019152255905,16.743111237380607,16.516030953916818,16.298063318385115,16.08009568285341,15.862128047321656,15.64416041178999,15.426192776258251,15.208225140726498,14.990257505194782,14.774949709432523,14.566272237071212,14.357594764709903,14.148917292348573,13.940239819987276,13.731562347625967,13.522884875264635,13.31857688958165,13.12196300168933,12.925349113797054,12.728735225904806,12.532121338012486,12.335507450120197,12.140371151294772,11.956907822156218,11.773444493017623,11.589981163879068,11.406517834740484,11.223054505601917,11.044935295868044,10.873539331314044,10.702143366760005,10.530747402205993,10.359351437652002,10.190995357406639,10.03059551817828,9.870195678949914,9.709795839721567,9.54939600049319,9.394509552709726,9.244151963713168,9.09379437471658,8.94343678572002,8.79497453687929,8.6537777555149,8.512580974150474,8.371384192786067,8.231903078276535,8.099082787785166,7.9662624972938225,7.833442206802461,7.704566885655332,7.579568517904313,7.454570150153263,7.330233685216127,7.214349201118258,7.098464717020404,6.982580232922536,6.875417362854082,6.769428043084504,6.663438723314927,6.56379530040563,6.464808349790381,6.36647194254113,6.272650308966824,6.1788286753925075,6.088438592047988,6.001191423525135,5.9144853055024775,5.8341734216357395,5.753861537768983,5.678347589854988,5.604188353620669,5.5333766544925655,5.464663230148119,5.388101977125441,5.305654852594097,5.223207728062736,5.140760603531376,5.058313479000031,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[67.91711858359191,67.96178244109485,68.00644629859778,68.05111015610072,68.09577401360366,68.1404378711066,68.18510172860952,68.22976558611246,68.2744294436154,68.31909330111834,68.36375715862128,68.40842101612421,68.45308487362715,68.49774873113009,68.54241258863303,68.58707644613595,68.63174030363888,68.67640416114183,68.72106801864476,68.7657318761477,68.81039573365064,68.85505959115358,68.8997234486565,68.94438730615944,68.98905116366238,69.0337150211653,69.07837887866825,69.12304273617119,69.16770659367411,69.21237045117707,69.25703430867999,69.30169816618292,69.34636202368586,69.3910258811888,69.43568973869174,69.48035359619467,69.5250174536976,69.56968131120054,69.61434516870348,69.6590090262064,69.70367288370934,69.74833674121228,69.79300059871521,69.83766445621815,69.88232831372109,69.92699217122401,69.97165602872695,70.0163198862299,70.06098374373283,70.10564760123577,70.15031145873871,70.19497531624165,70.23963917374458,70.2843030312475,70.32896688875044,70.37363074625338,70.41829460375632,70.46370960098356,70.50950016823057,70.55529073547757,70.6010813027246,70.6468718699716,70.6926624372186,70.73845300446561,70.78424357171262,70.83003413895963,70.87582470620664,70.92161527345365,70.96740584070065,71.01319640794767,71.05898697519467,71.10477754244168,71.15056810968868,71.1963586769357,71.24214924418271,71.28793981142971,71.33373037867672,71.37952094592373,71.42531151317074,71.47110208041775,71.51689264766476,71.56268321491176,71.60847378215877,71.65426434940578,71.68055467302446,71.70294494791747,71.72533522281049,71.74772549770348,71.7701157725965,71.79250604748951,71.81489632238252,71.83728659727554,71.85967687216855,71.88206714706155,71.90445742195458,71.92684769684757,71.94923797174059,71.9716282466336,71.99401852152661,72.01640879641963,72.03879907131264,72.06118934620565,72.08357962109866,72.10596989599166,72.12836017088468,72.15075044577769,72.1731407206707,72.19553099556371,72.21792127045673,72.24031154534973,72.26270182024274,72.28509209513575,72.30748237002877,72.32987264492178,72.35226291981479,72.3746531947078,72.3970434696008,72.41943374449382,72.44182401938683,72.46421429427983,72.48660456917285,72.50899484406585,72.53138511895887,72.55377539385188,72.57616566874489,72.5985559436379,72.62094621853092,72.64333649342393,72.66572676831694,72.68811704320994,72.71050731810296,72.73289759299597,72.75528786788898,72.777678142782,72.800068417675,72.82245869256802,72.84484896746103,72.86723924235403,72.88962951724704,72.91201979214006,72.935459048358,72.95994728629219,72.98443552422637,73.00892376216055,73.03341200009474,73.05790023802892,73.0823884759631,73.1068767138973,73.13136495183147,73.15585318976565,73.18034142769983,73.20482966563402,73.2293179035682,73.2538061415024,73.27829437943657,73.30278261737075,73.32727085530495,73.35175909323914,73.37624733117332,73.4007355691075,73.42522380704169,73.44971204497587,73.47420028291005,73.49868852084424,73.5231767587784,73.5476649967126,73.57215323464679,73.33544442926745,72.96813710223141,72.60082977519535,72.23352244815928,71.86621512112323,71.49890779408716,71.1316004670511,70.76429314001504,70.39698581297897,70.02967848594292,69.66237115890684,69.29506383187078,68.92775650483472,68.56044917779866,68.1931418507626,67.82583452372654,67.45852719669048,67.09121986965441,66.72391254261834,66.35660521558229,65.98929788854622,65.62199056151016,65.25468323447411,64.88737590743803,64.52006858040198,64.15276125336591,63.78545392632984,63.418146599293806,63.05083927225772,62.68353194522167,62.31622461818559,61.94891729114953,61.58160996411349,61.21430263707741,60.84699531004135,60.47968798300528,60.112380655969226,59.74507332893317,59.3777660018971,59.01045867486104,58.64315134782498,58.275844020788924,57.90853669375286,57.54122936671678,57.17392203968072,56.80661471264466,56.4393073856086,56.07200005857254,55.70469273153647,55.33738540450041,54.97007807746434,54.60277075042829,54.23546342339223,53.86815609635616,53.500848769320086,53.13354144228404,52.76623411524798,52.39892678821191,52.03161946117585,51.66431213413978,51.29700480710373,50.92969748006766,50.5623901530316,50.21253809096779,49.88289727280606,49.553256454644334,49.22361563648259,48.89397481832086,48.56433400015912,48.2346931819974,47.90505236383566,47.57541154567392,47.24577072751219,46.91612990935045,46.58648909118873,46.25684827302699,45.92720745486526,45.597566636703526,45.2679258185418,44.93828500038006,44.608644182218335,44.27900336405659,43.94936254589485,43.641593836193735,43.35569723495333,43.069800633712866,42.78390403247254,42.49800743123207,42.21211082999167,41.929271606826745,41.64919252215599,41.3691134374853,41.089034352814636,40.808955268143876,40.528876183473116,40.248797098802434,39.96871801413177,39.688638929461064,39.40855984479039,39.12848076011971,38.848401675448955,38.568322590778266,38.28824350610753,38.00816442143683,37.728085336766085,37.44800625209541,37.16792716742465,36.887848082754026,36.60776899808328,36.327689913412605,36.05089413421471,35.778632438559185,35.50637074290366,35.23410904724801,34.961847351592475,34.68958565593697,34.41732396028144,34.14506226462584,33.87280056897033,33.600538873314804,33.32827717765921,33.05601548200363,32.78375378634817,32.51149209069257,32.239230395037055,31.966968699381535,31.69470700372594,31.422445308070408,31.155494327430873,30.891031249609018,30.6265681717871,30.362105093965255,30.09764201614335,29.833178938321552,29.56871586049965,29.304252782677803,29.03978970485595,28.775326627034037,28.5108635492122,28.246400471390288,27.981937393568433,27.717474315746585,27.453011237924684,27.193008806207715,26.936475769246154,26.679942732284637,26.42340969532306,26.166876658361545,25.910343621400028,25.65381058443845,25.397277547476875,25.140744510515425,24.884211473553897,24.62767843659232,24.371145399630805,24.114612362669238,23.862818818700674,23.61533390085381,23.367848983006937,23.120364065160004,22.872879147313135,22.625394229466224,22.377909311619337,22.130424393772408,21.88293947592554,21.63545455807867,21.387969640231788,21.142120513940252,20.90464862118511,20.66717672842991,20.429704835674727,20.192232942919585,19.954761050164425,19.717289157409226,19.4798172646541,19.2423453718989,19.004873479143743,18.7692382414114,18.542157956233,18.31507767105455,18.087997385876147,17.86091710069771,17.633836815519295,17.406756530340893,17.179676245162497,16.95259595998404,16.728513258680824,16.510545623149085,16.292577987617378,16.074610352085628,15.856642716553925,15.638675081022221,15.420707445490466,15.2027398099588,14.988819756424958,14.780142284063649,14.571464811702306,14.362787339341022,14.154109866979711,13.945432394618399,13.736754922257072,13.532304453278762,13.335690565386475,13.139076677494167,12.94246278960189,12.74584890170957,12.549235013817292,12.352621125925044,12.168566758591643,11.985103429453051,11.801640100314495,11.61817677117594,11.434713442037346,11.25310331613877,11.081707351584745,10.910311387030733,10.73891542247673,10.567519457922732,10.396123493368695,10.234260005888538,10.073860166660202,9.913460327431823,9.753060488203467,9.592956008417264,9.442598419420706,9.292240830424117,9.141883241427559,8.991525652431001,8.846538192707143,8.705341411342745,8.564144629978326,8.422947848613937,8.285863621554142,8.153043331062792,8.020223040571455,7.887402750080085,7.760091813472063,7.635093445721013,7.510095077969956,7.386853297397359,7.270968813299498,7.155084329201614,7.039199845103746,6.9324903922730545,6.826501072503471,6.720511752733874,6.620704211793227,6.521717261177961,6.4229254733252,6.329103839750907,6.23528220617659,6.14391397071879,6.056666802195948,5.969419633673118,5.888222394240758,5.807910510374009,5.730801954236971,5.656642718002642,5.584145121656613,5.515431697312176,5.443775337213397,5.361328212682036,5.278881088150675,5.196433963619332,5.113986839087971,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[67.94291722701433,67.98758108451726,68.0322449420202,68.07690879952314,68.12157265702606,68.166236514529,68.21090037203194,68.25556422953487,68.30022808703782,68.34489194454075,68.38955580204369,68.43421965954661,68.47888351704955,68.52354737455249,68.56821123205543,68.61287508955837,68.6575389470613,68.70220280456424,68.74686666206716,68.7915305195701,68.83619437707304,68.88085823457598,68.92552209207891,68.97018594958186,69.01484980708477,69.05951366458771,69.10417752209065,69.14884137959359,69.19350523709653,69.23816909459946,69.2828329521024,69.32749680960534,69.37216066710826,69.4168245246112,69.46148838211414,69.50615223961708,69.55081609712002,69.59547995462295,69.64014381212588,69.68480766962881,69.72947152713175,69.77413538463469,69.81879924213763,69.86346309964057,69.9081269571435,69.95279081464642,69.99745467214936,70.0421185296523,70.08678238715524,70.13144624465818,70.17611010216112,70.22077395966406,70.26543781716698,70.31010167466991,70.35476553217285,70.39942938967579,70.44409324717873,70.48875710468167,70.5334209621846,70.57808481968753,70.62274867719047,70.66741253469341,70.71207639219634,70.75674024969928,70.80140410720222,70.84606796470516,70.89073182220808,70.93539567971102,70.98005953721396,71.0247233947169,71.06938725221983,71.11405110972275,71.15871496722569,71.20356660939498,71.24935717664201,71.295147743889,71.340938311136,71.38672887838302,71.43251944563004,71.47831001287703,71.52410058012404,71.56989114737105,71.61568171461806,71.66147228186507,71.68776260548375,71.71015288037675,71.73254315526977,71.75493343016278,71.77732370505579,71.7997139799488,71.82210425484182,71.84449452973482,71.86688480462783,71.88927507952084,71.91166535441387,71.93405562930687,71.95644590419988,71.9788361790929,72.00122645398591,72.02361672887892,72.04600700377193,72.06839727866493,72.09078755355794,72.11317782845096,72.13556810334397,72.15795837823698,72.18034865312998,72.202738928023,72.22512920291601,72.24751947780902,72.26990975270203,72.29230002759505,72.31469030248806,72.33708057738107,72.35947085227409,72.38186112716708,72.4042514020601,72.42664167695311,72.44903195184612,72.47142222673912,72.49381250163215,72.51620277652515,72.53859305141816,72.56098332631119,72.58337360120419,72.6057638760972,72.62815415099021,72.65054442588323,72.67293470077622,72.69532497566924,72.71771525056225,72.74010552545526,72.76249580034828,72.78488607524129,72.8072763501343,72.8296666250273,72.85205689992033,72.87444717481333,72.89683744970634,72.91922772459935,72.94161799949235,72.96400827438538,72.98639854927838,73.00878882417139,73.0311790990644,73.05356937395742,73.07595964885043,73.09834992374344,73.12074019863645,73.14313047352945,73.16552074842247,73.18791102331548,73.21030129820849,73.2326915731015,73.25508184799452,73.27747212288753,73.29986239778053,73.32435063517289,73.34883887310708,73.37332711104128,73.39781534897546,73.42230358690963,73.44679182484381,73.471280062778,73.49576830071219,73.52025653864636,73.54474477658056,73.30803597120124,72.94072864416518,72.57342131712912,72.20611399009306,71.83880666305701,71.47149933602093,71.10419200898488,70.73688468194881,70.36957735491274,70.00227002787669,69.63496270084062,69.26765537380456,68.9003480467685,68.53304071973243,68.16573339269638,67.79842606566032,67.43111873862425,67.06381141158818,66.69650408455212,66.32919675751607,65.96188943048,65.59458210344394,65.22727477640788,64.85996744937181,64.49266012233576,64.12535279529968,63.75804546826362,63.390738141227565,63.02343081419149,62.65612348715545,62.28881616011937,61.92150883308331,61.554201506047264,61.186894179011176,60.81958685197513,60.45227952493905,60.084972197902985,59.71766487086695,59.350357543830874,58.983050216794815,58.61574288975876,58.2484355627227,57.88112823568663,57.51382090865056,57.14651358161449,56.779206254578426,56.41189892754238,56.044591600506315,55.67728427347025,55.309976946434176,54.94266961939811,54.57536229236207,54.208054965326,53.84074763828993,53.47344031125387,53.106132984217815,52.73882565718175,52.37151833014569,52.00421100310962,51.63690367607356,51.269596349037506,50.90228902200144,50.53498169496537,50.167674367929315,49.80036704089326,49.43305971385719,49.065752386821124,48.69844505978505,48.331137732749,47.96383040571295,47.59652307867688,47.22921575164081,46.86190842460475,46.494601097568676,46.12729377053264,45.759986443496565,45.3926791164605,45.02537178942443,44.658064462388374,44.290757135352315,43.923449808316256,43.55614248128018,43.224664335848445,42.917277795807415,42.63719871113672,42.357119626466044,42.07704054179536,41.79696145712462,41.51688237245393,41.236803287783175,40.95672420311243,40.67664511844173,40.396566033771066,40.11648694910031,39.83640786442955,39.55632877975887,39.2762496950882,38.9961706104175,38.71609152574682,38.436012441076144,38.155933356405384,37.8758542717347,37.59577518706396,37.31569610239327,37.035617017722515,36.75929028191308,36.487028586257544,36.21476689060196,35.942505194946435,35.67024349929091,35.39798180363532,35.1257201079798,34.85345841232428,34.58119671666863,34.30893502101309,34.03667332535759,33.76441162970206,33.49214993404646,33.21988823839094,32.94762654273542,32.67536484707983,32.40310315142425,32.13084145576879,31.86121119537823,31.59674811755633,31.332285039734543,31.06782196191263,30.803358884090713,30.538895806268883,30.274432728447028,30.00996965062511,29.745506572803265,29.481043494981364,29.216580417159562,28.95211733933766,28.687654261515814,28.42319118369396,28.158728105872047,27.89426502805021,27.63674073405935,27.380207697097774,27.123674660136256,26.867141623174692,26.610608586213164,26.3540755492516,26.097542512290083,25.841009475328505,25.58447643836699,25.327943401405474,25.071410364443896,24.81487732748232,24.55834429052087,24.306694367536775,24.05920944968984,23.811724531842923,23.564239613996058,23.316754696149175,23.069269778302303,22.821784860455438,22.574299942608505,22.326815024761633,22.079330106914718,21.831845189067835,21.584360271220906,21.346095267902392,21.108623375147204,20.871151482392047,20.633679589636905,20.39620769688176,20.15873580412656,19.921263911371376,19.683792018616234,19.446320125861075,19.20884823310588,18.978722964014846,18.75164267883644,18.524562393658023,18.29748210847958,18.070401823301182,17.84332153812273,17.616241252944327,17.38916096776589,17.162080682587476,16.94099556344481,16.723027927913105,16.50506029238135,16.287092656849637,16.069125021317898,15.851157385786191,15.633189750254438,15.415222114722738,15.202689803417432,14.99401233105612,14.785334858694792,14.57665738633346,14.36797991397215,14.159302441610807,13.950624969249525,13.746032016975912,13.549418129083591,13.352804241191315,13.156190353299007,12.95957646540672,12.76296257751441,12.566348689622135,12.38022569502707,12.196762365888516,12.01329903674996,11.829835707611366,11.646372378472773,11.462909049334218,11.289875371855498,11.118479407301487,10.947083442747461,10.775687478193435,10.604291513639422,10.437924493598805,10.277524654370437,10.11712481514208,9.956724975913726,9.79632513668539,9.641044875128244,9.490687286131656,9.340329697135097,9.189972108138539,9.03961451914195,8.898101848535006,8.756905067170608,8.615708285806182,8.474511504441784,8.339824164831782,8.207003874340412,8.07418358384906,7.941363293357707,7.8156167412887605,7.690618373537704,7.565620005786684,7.443472909578588,7.3275884254807195,7.211703941382844,7.095819457284984,6.989563421692003,6.883574101922418,6.777584782152848,6.6776131231808025,6.57862617256554,6.479639221950286,6.385557370534977,6.29173573696066,6.199389349389615,6.112142180866773,6.02489501234392,5.942271366845787,5.861959482979049,5.783256318618951,5.709097082384622,5.6349378461503115,5.566200164476224,5.497486740131771,5.417001572769987,5.334554448238631,5.2521073237072695,5.16966019917591,5.087213074644565,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[67.96354277199393,68.00820662949687,68.0528704869998,68.09753434450273,68.14219820200567,68.18686205950861,68.23152591701154,68.27618977451448,68.32085363201742,68.36551748952036,68.4101813470233,68.45484520452622,68.49950906202916,68.5441729195321,68.58883677703504,68.63350063453797,68.6781644920409,68.72282834954385,68.76749220704677,68.81215606454971,68.85681992205264,68.90148377955558,68.94614763705852,68.99081149456146,69.03547535206438,69.08013920956732,69.12480306707026,69.16946692457319,69.21413078207614,69.25879463957907,69.303458497082,69.34812235458494,69.39278621208788,69.43745006959081,69.48211392709374,69.52677778459667,69.57144164209961,69.61610549960255,69.6607693571055,69.70543321460842,69.75009707211136,69.7947609296143,69.83942478711722,69.88408864462016,69.9287525021231,69.97341635962604,70.01808021712897,70.06274407463191,70.10740793213485,70.15207178963777,70.19673564714071,70.24139950464365,70.28606336214659,70.33072721964952,70.37539107715246,70.4200549346554,70.46471879215832,70.50938264966126,70.5540465071642,70.59871036466714,70.64337422217007,70.688038079673,70.73270193717595,70.77736579467887,70.82202965218181,70.86669350968475,70.91135736718769,70.95602122469062,71.00068508219356,71.04534893969651,71.09001279719944,71.13467665470236,71.1793405122053,71.22400436970824,71.26866822721118,71.31333208471412,71.35799594221704,71.40265979923959,71.44618863227373,71.48971746530788,71.53324629834202,71.57677513137618,71.62030396441033,71.66383279744448,71.68788356735071,71.70803872463136,71.728193881912,71.74834903919266,71.76850419647332,71.78865935375396,71.81030458849682,71.83269486338982,71.85508513828283,71.87747541317584,71.89986568806886,71.92225596296187,71.94464623785488,71.96703651274788,71.98942678764091,72.01181706253391,72.03420733742692,72.05659761231993,72.07898788721295,72.10137816210596,72.12376843699897,72.14615871189199,72.168548986785,72.190939261678,72.21332953657101,72.23571981146402,72.25811008635704,72.28050036125003,72.30289063614305,72.32528091103606,72.34767118592907,72.37006146082209,72.3924517357151,72.41484201060811,72.43723228550111,72.45962256039414,72.48201283528715,72.50440311018015,72.52679338507316,72.54918365996618,72.57157393485919,72.59396420975219,72.6163544846452,72.63874475953821,72.66113503443123,72.68352530932424,72.70591558421725,72.72830585911026,72.75069613400328,72.77308640889629,72.7954766837893,72.81786695868232,72.84025723357531,72.86264750846833,72.88503778336134,72.90742805825435,72.92981833314737,72.95220860804037,72.97459888293338,72.99698915782639,73.0193794327194,73.04176970761242,73.06415998250543,73.08655025739844,73.10894053229144,73.13133080718445,73.15372108207747,73.17611135697048,73.1985016318635,73.2208919067565,73.24328218164952,73.26567245654252,73.28806273143553,73.31045300632856,73.33284328122156,73.35523355611457,73.37762383100758,73.4000141059006,73.4224043807936,73.44479465568661,73.46718493057963,73.48957520547263,73.51196548036565,73.25226037261747,72.85150757354873,72.45075477447998,72.0500019754112,71.64924917634248,71.2484963772737,70.84774357820494,70.4469907791362,70.05564112397781,69.68395263934858,69.3122641547193,68.94057567009008,68.56888718546082,68.19719870083158,67.82551021620236,67.4538217315731,67.08213324694387,66.71044476231461,66.33875627768536,65.96706779305613,65.59537930842689,65.22369082379764,64.85200233916841,64.48031385453915,64.10862536990992,63.73693688528066,63.36524840065142,62.99355991602219,62.62187143139292,62.2501829467637,61.87849446213444,61.506805977505195,61.13511749287597,60.763429008246725,60.39174052361747,60.02005203898823,59.64836355435898,59.27667506972975,58.90498658510051,58.53329810047126,58.161609615842025,57.78992113121278,57.41823264658353,57.04654416195428,56.674855677325034,56.30316719269579,55.93147870806655,55.559790223437304,55.18810173880806,54.81641325417882,54.444724769549566,54.073036284920335,53.70134780029109,53.32965931566185,52.9579708310326,52.586282346403365,52.21459386177412,51.842905377144874,51.47121689251563,51.09952840788638,50.72783992325714,50.356151438627904,49.98446295399865,49.61277446936941,49.241085984740174,48.869397500110935,48.497709015481675,48.126020530852436,47.75433204622318,47.38264356159396,47.01095507696471,46.63926659233546,46.267578107706214,45.89588962307697,45.52420113844774,45.15251265381849,44.780824169189245,44.40913568456,44.03744719993077,43.665758715301514,43.29407023067226,42.92238174604302,42.55069326141377,42.22480947676383,41.944730392093135,41.66465130742246,41.38457222275178,41.104493138081025,40.824414053410344,40.54433496873959,40.264255884068845,39.98417679939814,39.70409771472748,39.42401863005672,39.14393954538597,38.86386046071528,38.58378137604461,38.30370229137391,38.02362320670323,37.74354412203256,37.46768642961142,37.19542473395589,36.92316303830031,36.65090134264478,36.378639646989186,36.10637795133368,35.83411625567815,35.56185456002255,35.28959286436704,35.01733116871151,34.74506947305592,34.4728077774004,34.200546081744875,33.928284386089224,33.656022690433694,33.383760994778186,33.111499299122656,32.839237603467055,32.56697590781154,32.30246498550373,32.038001907681824,31.773538829859977,31.509075752038132,31.24461267421622,30.98014959639432,30.71568651857253,30.451223440750613,30.186760362928702,29.922297285106865,29.65783420728501,29.393371129463098,29.128908051641247,28.86444497381935,28.59998189599755,28.337005698872417,28.08047266191085,27.823939624949325,27.5674065879878,27.310873551026294,27.05434051406477,26.79780747710319,26.541274440141674,26.28474140318011,26.028208366218582,25.771675329257018,25.5151422922955,25.258609255333923,25.002076218372412,24.750569916372804,24.50308499852587,24.25560008067899,24.008115162832134,23.760630244985247,23.513145327138318,23.265660409291403,23.018175491444534,22.77069057359765,22.523205655750786,22.275720737903917,22.02823582005698,21.78754191461966,21.550070021864517,21.312598129109315,21.075126236354162,20.83765434359902,20.600182450843835,20.36271055808868,20.125238665333534,19.887766772578395,19.650294879823193,19.415287971796698,19.1882076866183,18.96112740143985,18.734047116261394,18.506966831083005,18.279886545904596,18.05280626072618,17.82572597554774,17.59864569036934,17.37156540519089,17.153477868208764,16.93551023267706,16.717542597145307,16.499574961613604,16.2816073260819,16.063639690550147,15.845672055018433,15.627704419486692,15.416559850409856,15.207882378048545,14.999204905687215,14.790527433325918,14.581849960964608,14.373172488603279,14.164495016241945,13.959759580673014,13.763145692780691,13.566531804888427,13.36991791699614,13.173304029103821,12.976690141211543,12.780076253319237,12.591884631462456,12.4084213023239,12.224957973185344,12.041494644046779,11.858031314908223,11.674567985769666,11.498043392126219,11.326647427572182,11.15525146301818,10.983855498464177,10.812459533910166,10.641588981309054,10.481189142080707,10.32078930285233,10.160389463623982,9.999989624395614,9.839589785167256,9.689133741839184,9.538776152842654,9.388418563846065,9.238060974849477,9.090862285727262,8.949665504362862,8.808468722998436,8.667271941634038,8.526604998600751,8.393784708109383,8.260964417618037,8.128144127126692,7.99614003685652,7.871141669105446,7.746143301354435,7.621144933603375,7.500092521759806,7.38420803766193,7.268323553564068,7.152625770880553,7.0466364511109765,6.940647131341387,6.834657811571789,6.734522034568378,6.63553508395313,6.536548133337856,6.442010901319032,6.348189267744731,6.254864728060424,6.167617559537571,6.080370391014741,5.996320339450822,5.916008455584073,5.835710683000919,5.761551446766608,5.687392210532287,5.616968631640269,5.548255207295832,5.472674932857929,5.39022780832657,5.307780683795222,5.225333559263866,5.142886434732504,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[67.9754998825567,68.02016374005964,68.06482759756257,68.10949145506551,68.15415531256845,68.19881917007137,68.24348302757431,68.28814688507725,68.3328107425802,68.37747460008313,68.42213845758606,68.46680231508898,68.51146617259192,68.55613003009486,68.6007938875978,68.64545774510074,68.69012160260367,68.73478546010661,68.77944931760955,68.82411317511249,68.86877703261541,68.91344089011835,68.95810474762129,69.00276860512422,69.04743246262716,69.0920963201301,69.13676017763304,69.18142403513596,69.2260878926389,69.27075175014184,69.31541560764478,69.3600794651477,69.40474332265063,69.44940718015359,69.49407103765651,69.53873489515945,69.58339875266239,69.62806261016532,69.67272646766827,69.7173903251712,69.76205418267412,69.80671804017706,69.85138189768,69.89604575518294,69.94070961268588,69.9853734701888,70.03003732769174,70.07470118519468,70.11936504269761,70.16402890020055,70.20869275770349,70.25335661520643,70.29802047270935,70.34268433021228,70.38734818771522,70.43201204521816,70.4766759027211,70.52133976022404,70.56600361772698,70.6106674752299,70.65533133273284,70.6994276773337,70.74295651036785,70.786485343402,70.83001417643615,70.87354300947031,70.91707184250444,70.96060067553859,71.00412950857275,71.0476583416069,71.09118717464105,71.1347160076752,71.17824484070935,71.2217736737435,71.26530250677764,71.3088313398118,71.35236017284595,71.3958890058801,71.43941783891424,71.4829466719484,71.52647550498256,71.5700043380167,71.61353317105085,71.657062004085,71.68111277399123,71.70126793127189,71.72142308855254,71.74157824583318,71.76173340311384,71.78188856039449,71.80204371767513,71.82219887495579,71.84235403223644,71.86250918951708,71.88266434679774,71.9028195040784,71.92297466135904,71.94312981863969,71.96328497592035,71.98344013320099,72.00359529048164,72.0237504477623,72.04390560504295,72.06406076232359,72.08421591960425,72.1043710768849,72.12489875245278,72.14728902734579,72.1696793022388,72.19206957713182,72.21445985202482,72.23685012691783,72.25924040181084,72.28163067670386,72.30402095159687,72.32641122648988,72.3488015013829,72.3711917762759,72.39358205116892,72.41597232606192,72.43836260095495,72.46075287584793,72.48314315074094,72.50553342563397,72.52792370052697,72.55031397541998,72.572704250313,72.59509452520601,72.61748480009902,72.63987507499203,72.66226534988505,72.68465562477806,72.70704589967107,72.72943617456407,72.75182644945708,72.7742167243501,72.79660699924311,72.81899727413611,72.84138754902912,72.86377782392215,72.88616809881515,72.90855837370816,72.93094864860117,72.95333892349419,72.9757291983872,72.99811947328021,73.02050974817323,73.04290002306622,73.06529029795924,73.08768057285225,73.11007084774526,73.13246112263828,73.15485139753129,73.1772416724243,73.1996319473173,73.22202222221031,73.24441249710334,73.26680277199634,73.28919304688935,73.31158332178236,73.33397359667538,73.35636387156838,73.3787541464614,73.40114442135442,73.42353469624743,73.44592497114043,73.46831524603344,73.20861013828527,72.80785733921653,72.40710454014777,72.006351741079,71.60559894201027,71.20484614294149,70.80409334387274,70.403340544804,70.00258774573524,69.6018349466665,69.2010821475977,68.80032934852898,68.39957654946022,67.99882375039147,67.59807095132273,67.19731815225397,66.79656535318522,66.39581255411645,65.99505975504769,65.59430695597895,65.1935541569102,64.79280135784143,64.3920485587727,63.99129575970392,63.590542960635176,63.18979016156642,62.789037362497666,62.38828456342892,61.98753176436015,61.58677896529141,61.18602616622266,60.814337658461646,60.44264917383241,60.07096068920316,59.699272204573916,59.32758371994467,58.955895235315424,58.58420675068619,58.21251826605695,57.84082978142769,57.46914129679847,57.09745281216921,56.72576432753997,56.35407584291072,55.98238735828147,55.610698873652225,55.239010389022994,54.86732190439375,54.4956334197645,54.12394493513526,53.75225645050601,53.38056796587678,53.00887948124753,52.63719099661828,52.26550251198903,51.89381402735981,51.522125542730556,51.1504370581013,50.778748573472065,50.407060088842826,50.03537160421359,49.66368311958434,49.291994634955095,48.92030615032584,48.54861766569661,48.176929181067365,47.80524069643812,47.43355221180887,47.06186372717963,46.690175242550396,46.31848675792115,45.946798273291904,45.57510978866266,45.203421304033405,44.831732819404166,44.46004433477493,44.088355850145675,43.71666736551643,43.344978880887204,42.97329039625796,42.601601911628705,42.22991342699946,41.858224942370214,41.53234115772027,41.25226207304957,40.9721829883789,40.692103903708215,40.41202481903746,40.13194573436678,39.851866649696035,39.571787565025275,39.291708480354586,39.01162939568392,38.73155031101316,38.451471226342406,38.176082577309785,37.903820881654205,37.63155918599867,37.359297490343145,37.087035794687566,36.814774099032036,36.542512403376506,36.27025070772093,35.9979890120654,35.72572731640981,35.4534656207543,35.181203925098764,34.90894222944318,34.636680533787654,34.36441883813213,34.09215714247654,33.81989544682102,33.5476337511655,33.27537205550985,33.00818185345109,32.74371877562921,32.479255697807346,32.21479261998549,31.95032954216359,31.685866464341743,31.42140338651983,31.156940308697987,30.892477230876143,30.628014153054227,30.36355107523233,30.09908799741054,29.834624919588624,29.570161841766712,29.305698763944875,29.041235686123024,28.780737626723987,28.52420458976247,28.26767155280095,28.011138515839377,27.754605478877863,27.498072441916296,27.241539404954768,26.985006367993247,26.72847333103174,26.471940294070215,26.21540725710864,25.95887422014712,25.702341183185553,25.445808146224028,25.194445465208887,24.946960547361964,24.699475629515085,24.45199071166817,24.2045057938213,23.95702087597437,23.70953595812749,23.46205104028063,23.214566122433748,22.967081204586815,22.7195962867399,22.47211136889303,22.22898856133698,21.99151666858179,21.75404477582665,21.516572883071493,21.27910099031631,21.04162909756117,20.804157204805968,20.56668531205081,20.32921341929567,20.091741526540485,19.85426963378533,19.624772694400132,19.397692409221737,19.17061212404328,18.943531838864878,18.71645155368648,18.48937126850803,18.262290983329574,18.035210698151186,17.808130412972776,17.583927808504477,17.365960172972734,17.14799253744103,16.930024901909277,16.712057266377577,16.494089630845874,16.27612199531412,16.058154359782417,15.840186724250714,15.630429897402294,15.421752425040951,15.213074952679655,15.004397480318357,14.795720007957046,14.587042535595717,14.37836506323442,14.173487144370101,13.976873256477823,13.780259368585575,13.583645480693257,13.387031592800936,13.190417704908668,12.993803817016383,12.803543567897911,12.620080238759328,12.43661690962077,12.253153580482177,12.069690251343623,11.886226922205068,11.706211412396922,11.534815447842947,11.36341948328892,11.192023518734908,11.020627554180871,10.849231589626871,10.684853629790966,10.524453790562589,10.36405395133424,10.203654112105893,10.043254272877515,9.88758019754675,9.737222608550193,9.586865019553603,9.436507430557015,9.286149841560485,9.142425941555125,9.0012291601907,8.8600323788263,8.718835597461903,8.580565541878357,8.447745251387015,8.31492496089567,8.182104670404302,8.05166496467322,7.9266665969221854,7.801668229171142,7.676669861420068,7.556712133941044,7.440827649843161,7.324943165745292,7.209698800299508,7.103709480529931,6.9977201607603465,6.891730840990769,6.7914309459559705,6.692443995340709,6.593457044725437,6.498464432103114,6.404642798528797,6.310821164954492,6.22309293820839,6.135845769685554,6.05036931205585,5.970057428189113,5.8897455443223565,5.814005811148588,5.739846574914258,5.667737098804318,5.599023674459866,5.52834829294587,5.445901168414525,5.363454043883165,5.281006919351805,5.198559794820458,5.116112670289102,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[67.98745699311947,68.0321208506224,68.07678470812533,68.12144856562827,68.16611242313121,68.21077628063415,68.25544013813708,68.30010399564,68.34476785314295,68.38943171064588,68.43409556814882,68.47875942565176,68.5234232831547,68.56808714065764,68.61275099816056,68.6574148556635,68.70207871316643,68.74674257066937,68.79140642817231,68.83607028567525,68.88073414317817,68.92539800068111,68.97006185818405,69.01472571568699,69.05938957318992,69.10405343069286,69.1487172881958,69.19338114569872,69.23804500320168,69.28270886070459,69.32737271820753,69.37203657571047,69.41670043321339,69.46136429071635,69.50602814821927,69.55069200572221,69.59535586322515,69.64001972072808,69.68468357823103,69.72934743573396,69.77401129323688,69.81867515073982,69.86333900824276,69.9080028657457,69.95266672239367,69.99619555542782,70.03972438846198,70.08325322149611,70.12678205453027,70.17031088756443,70.21383972059856,70.25736855363272,70.30089738666688,70.344426219701,70.38795505273517,70.43148388576932,70.47501271880347,70.51854155183761,70.56207038487176,70.60559921790593,70.64912805094006,70.69265688397424,70.73618571700837,70.77971455004251,70.82324338307667,70.86677221611083,70.91030104914498,70.95382988217912,70.99735871521327,71.04088754824743,71.08441638128157,71.12794521431573,71.17147404734988,71.21500288038402,71.25853171341817,71.30206054645232,71.34558937948647,71.38911821252063,71.43264704555477,71.47617587858892,71.51970471162308,71.56323354465722,71.60676237769137,71.65029121072553,71.67434198063175,71.6944971379124,71.71465229519305,71.7348074524737,71.75496260975436,71.775117767035,71.79527292431565,71.81542808159631,71.83558323887696,71.85573839615762,71.87589355343826,71.89604871071892,71.91620386799957,71.93635902528021,71.95651418256087,71.97666933984152,71.99682449712216,72.01697965440282,72.03713481168347,72.05728996896411,72.07744512624477,72.09760028352542,72.11775544080608,72.13791059808673,72.15806575536737,72.17822091264803,72.19837606992868,72.21853122720933,72.23868638449,72.25884154177064,72.27899669905129,72.29915185633195,72.3193070136126,72.33946217089324,72.3596173281739,72.37977248545455,72.39992764273518,72.42008280001585,72.44023795729649,72.46188319130175,72.48427346619476,72.50666374108778,72.52905401598079,72.5514442908738,72.57383456576682,72.59622484065983,72.61861511555283,72.64100539044584,72.66339566533885,72.68578594023187,72.70817621512488,72.73056649001788,72.7529567649109,72.7753470398039,72.79773731469692,72.82012758958993,72.84251786448294,72.86490813937596,72.88729841426897,72.90968868916198,72.932078964055,72.95446923894801,72.976859513841,72.99924978873402,73.02164006362703,73.04403033852005,73.06642061341306,73.08881088830606,73.11120116319907,73.13359143809208,73.1559817129851,73.17837198787811,73.20076226277112,73.22315253766413,73.24554281255715,73.26793308745016,73.29032336234316,73.31271363723617,73.33510391212918,73.35749418702221,73.37988446191521,73.40227473680821,73.42466501170124,73.16495990395305,72.7642071048843,72.36345430581555,71.9627015067468,71.56194870767806,71.16119590860927,70.76044310954053,70.35969031047179,69.95893751140304,69.5581847123343,69.15743191326551,68.75667911419677,68.35592631512802,67.95517351605926,67.55442071699052,67.15366791792175,66.752915118853,66.35216231978424,65.95140952071547,65.55065672164673,65.14990392257798,64.74915112350922,64.3483983244405,63.94764552537171,63.54689272630297,63.146139927234216,62.74538712816546,62.34463432909672,61.943881530027944,61.543128730959204,61.14237593189044,60.74162313282169,60.340870333752946,59.940117534684184,59.539364735615436,59.13861193654667,58.73785913747792,58.337106338409185,57.93635353934042,57.53560074027166,57.13484794120293,56.734095142134166,56.33334234306541,55.93258954399664,55.53183674492789,55.13108394585913,54.73033114679039,54.32957834772163,53.92882554865288,53.52807274958411,53.127319950515364,52.726567151446616,52.32581435237787,51.94472267757472,51.57303419294547,51.201345708316246,50.82965722368699,50.45796873905775,50.08628025442851,49.714591769799256,49.34290328517003,48.971214800540785,48.59952631591153,48.22783783128228,47.856149346653055,47.48446086202381,47.112772377394556,46.74108389276531,46.369395408136064,45.99770692350683,45.62601843887759,45.254329954248334,44.882641469619095,44.51095298498984,44.13926450036061,43.76757601573137,43.39588753110212,43.02419904647287,42.65251056184364,42.280822077214395,41.90913359258515,41.537445107955904,41.16575662332666,40.839872838676705,40.55979375400601,40.27971466933534,39.99963558466466,39.71955649999391,39.43947741532322,39.15939833065248,38.88447872500815,38.61221702935255,38.33995533369704,38.06769363804152,37.795431942385854,37.5231702467304,37.25090855107482,36.978646855419285,36.70638515976376,36.43412346410818,36.16186176845265,35.88960007279712,35.61733837714155,35.34507668148602,35.072814985830426,34.80055329017492,34.52829159451939,34.256029898863794,33.98376820320827,33.713898721398415,33.44943564357657,33.18497256575472,32.92050948793282,32.65604641011097,32.3915833322891,32.12712025446722,31.862657176645357,31.598194098823498,31.3337310210016,31.069267943179756,30.80480486535784,30.540341787535997,30.275878709714153,30.011415631892238,29.74695255407034,29.48248947624855,29.224469554575613,28.96793651761408,28.71140348065258,28.454870443691004,28.19833740672943,27.941804369767908,27.685271332806398,27.428738295844816,27.172205258883302,26.915672221921735,26.65913918496021,26.402606147998686,26.146073111037182,25.889540074075654,25.638321014044873,25.390836096198008,25.143351178351136,24.895866260504256,24.648381342657384,24.400896424810462,24.153411506963582,23.905926589116667,23.658441671269802,23.410956753422862,23.163471835575983,22.915986917729132,22.67043520805427,22.432963315299112,22.19549142254397,21.958019529788782,21.72054763703363,21.48307574427844,21.245603851523303,21.008131958768146,20.770660066012958,20.53318817325782,20.295716280502614,20.061337702182005,19.834257417003563,19.607177131825164,19.38009684664671,19.153016561468313,18.925936276289914,18.698855991111458,18.471775705933055,18.244695420754656,18.017615135576204,17.796410113268447,17.578442477736758,17.360474842205004,17.14250720667329,16.92453957114155,16.706571935609844,16.48860430007809,16.27063666454639,16.052977416756043,15.844299944394733,15.635622472033404,15.426944999672106,15.218267527310795,15.009590054949454,14.800912582588156,14.59223511022686,14.387214708067216,14.19060082017494,13.993986932282663,13.797373044390344,13.600759156498066,13.40414526860582,13.2075313807135,13.015202504333335,12.831739175194791,12.648275846056196,12.464812516917632,12.281349187779046,12.097885858640492,11.914422529501898,11.74298346811365,11.571587503559673,11.400191539005611,11.228795574451636,11.057399609897612,10.888518117501226,10.728118278272868,10.5677184390445,10.407318599816152,10.246918760587775,10.086518921359428,9.935669064257727,9.785311475261139,9.63495388626458,9.484596297268022,9.335186378747387,9.193989597382961,9.052792816018592,8.911596034654165,8.770399253289739,8.63452608515599,8.501705794664646,8.368885504173278,8.236065213681933,8.107189892489936,7.982191524738893,7.857193156987842,7.732194789236808,7.613331746122266,7.497447262024384,7.38156277792653,7.266771829718475,7.16078250994889,7.0547931901793,6.948803870409723,6.848339857343552,6.749352906728285,6.65036595611303,6.554917962887183,6.461096329312866,6.367274695738573,6.2785683168792,6.191321148356357,6.104418284660875,6.024106400794133,5.943794516927384,5.866460175530578,5.792300939296248,5.718505565968368,5.649792141623914,5.5810787172794765,5.501574528502465,5.419127403971104,5.3366802794397605,5.2542331549084,5.17178603037704,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[67.99941410368224,68.04407796118517,68.0887418186881,68.13340567619105,68.17806953369399,68.22273339119693,68.26739724869984,68.31206110620278,68.35672496370572,68.40138882120866,68.4460526787116,68.49071653621452,68.53538039371746,68.5800442512204,68.62470810872334,68.66937196622628,68.7140358237292,68.75869968123214,68.80336353873508,68.84802739623802,68.89269125374095,68.93735511124387,68.98201896874681,69.02668282624977,69.07134668375268,69.11601054125563,69.16067439875856,69.2053382562615,69.24943460048779,69.29296343352195,69.33649226655609,69.38002109959024,69.42354993262438,69.46707876565856,69.5106075986927,69.55413643172685,69.59766526476099,69.64119409779515,69.6847229308293,69.72825176386345,69.77178059689759,69.81530942993174,69.8588382629659,69.90236709600005,69.94589592903421,69.98942476206834,70.0329535951025,70.07648242813664,70.12001126117079,70.16354009420495,70.20706892723909,70.25059776027325,70.2941265933074,70.33765542634154,70.3811842593757,70.42471309240985,70.468241925444,70.51177075847815,70.5552995915123,70.59882842454645,70.6423572575806,70.68588609061476,70.72941492364889,70.77294375668305,70.8164725897172,70.86000142275135,70.9035302557855,70.94705908881964,70.9905879218538,71.03411675488795,71.07764558792209,71.12117442095624,71.16470325399041,71.20823208702456,71.2517609200587,71.29528975309285,71.33881858612699,71.38234741916115,71.4258762521953,71.46940508522945,71.5129339182636,71.55646275129774,71.5999915843319,71.64352041736603,71.66757118727229,71.68772634455294,71.70788150183358,71.72803665911424,71.7481918163949,71.76834697367553,71.78850213095619,71.80865728823684,71.82881244551749,71.84896760279814,71.8691227600788,71.88927791735944,71.9094330746401,71.92958823192075,71.9497433892014,71.96989854648206,71.9900537037627,72.01020886104335,72.03036401832401,72.05051917560465,72.0706743328853,72.09082949016596,72.1109846474466,72.13113980472725,72.15129496200791,72.17145011928856,72.19160527656922,72.21176043384986,72.23191559113052,72.25207074841117,72.27222590569181,72.29238106297247,72.31253622025312,72.33269137753376,72.35284653481442,72.37300169209507,72.39315684937571,72.41331200665637,72.43346716393702,72.45362232121767,72.47377747849832,72.49393263577898,72.51408779305963,72.53424295034027,72.55439810762093,72.57455326490158,72.59470842218222,72.61486357946288,72.63501873674353,72.65517389402417,72.67532905130483,72.69548420858548,72.71563936586612,72.73579452314678,72.75594968042743,72.77647735525773,72.79886763015074,72.82125790504375,72.84364817993676,72.86603845482976,72.88842872972279,72.91081900461579,72.93320927950879,72.95559955440181,72.97798982929483,73.00038010418784,73.02277037908084,73.04516065397385,73.06755092886686,73.08994120375988,73.11233147865289,73.13472175354589,73.15711202843892,73.17950230333192,73.20189257822494,73.22428285311794,73.24667312801095,73.26906340290395,73.29145367779698,73.31384395269,73.336234227583,73.358624502476,73.38101477736902,73.12130966962084,72.7205568705521,72.31980407148336,71.91905127241458,71.51829847334585,71.11754567427707,70.71679287520833,70.31604007613957,69.91528727707082,69.51453447800208,69.1137816789333,68.71302887986457,68.31227608079581,67.91152328172704,67.51077048265832,67.11001768358955,66.70926488452079,66.30851208545202,65.90775928638328,65.50700648731453,65.10625368824577,64.70550088917702,64.30474809010828,63.90399529103951,63.50324249197077,63.10248969290201,62.70173689383324,62.30098409476451,61.90023129569574,61.499478496627,61.098725697558244,60.697972898489475,60.29722009942074,59.89646730035198,59.49571450128323,59.094961702214476,58.69420890314571,58.29345610407697,57.89270330500821,57.49195050593944,57.09119770687071,56.69044490780195,56.2896921087332,55.88893930966444,55.48818651059568,55.08743371152691,54.68668091245818,54.28592811338943,53.88517531432067,53.48442251525191,53.08366971618315,52.68291691711441,52.28216411804566,51.8814113189769,51.48065851990815,51.079905720839406,50.679152921770644,50.27840012270188,49.87764732363313,49.47689452456437,49.07614172549563,48.675388926426876,48.274636127358114,47.87388332828935,47.47313052922061,47.072377730151864,46.6716249310831,46.27087213201435,45.870119332945585,45.469366533876844,45.06861373480809,44.667860935739334,44.26710813667058,43.86635533760182,43.46560253853308,43.0751076966878,42.703419212058556,42.3317307274293,41.960042242800085,41.58835375817083,41.21666527354159,40.844976788912334,40.47328830428309,40.14740451963315,39.86732543496245,39.592874872706524,39.32061317705093,39.04835148139541,38.77608978573983,38.5038280900843,38.231566394428775,37.959304698773174,37.687043003117665,37.414781307462135,37.142519611806485,36.87025791615102,36.597996220495446,36.32573452483991,36.053472829184386,35.781211133528814,35.50894943787328,35.236687742217754,34.964426046562174,34.69216435090664,34.41990265525105,34.155152511523944,33.890689433702086,33.62622635588018,33.361763278058326,33.097300200236425,32.832837122414574,32.56837404459272,32.30391096677082,32.03944788894897,31.774984811127112,31.51052173330522,31.246058655483363,30.98159557766151,30.717132499839607,30.45266942201776,30.188206344195848,29.924734519388753,29.66820148242719,29.41166844546566,29.15513540850415,28.898602371542637,28.64206933458106,28.385536297619527,28.129003260658028,27.87247022369645,27.615937186734875,27.359404149773354,27.102871112811844,26.846338075850262,26.58980503888875,26.33327200192718,26.082196562880966,25.834711645034087,25.587226727187225,25.339741809340346,25.092256891493367,24.844771973646502,24.597287055799626,24.349802137952747,24.10231722010588,23.854832302258956,23.607347384412076,23.35986246656516,23.112377548718293,22.87440996201644,22.63693806926124,22.39946617650611,22.161994283750914,21.924522390995758,21.68705049824062,21.449578605485428,21.212106712730275,20.97463481997509,20.73716292721995,20.499691034464792,20.27082242478545,20.043742139607048,19.816661854428595,19.589581569250182,19.362501284071744,19.135420998893345,18.90834071371489,18.68126042853649,18.45418014335809,18.227099858179642,18.00889241803243,17.790924782500692,17.57295714696897,17.35498951143726,17.137021875905567,16.919054240373814,16.7010866048421,16.48311896931036,16.266847463748515,16.058169991387203,15.849492519025874,15.640815046664542,15.432137574303232,15.223460101941903,15.014782629580605,14.806105157219294,14.60094227176436,14.404328383872055,14.207714495979777,14.011100608087457,13.814486720195182,13.617872832302904,13.421258944410585,13.226861440768802,13.043398111630216,12.859934782491653,12.676471453353058,12.493008124214512,12.309544795075919,12.126081465937354,11.951151488384403,11.779755523830374,11.608359559276366,11.436963594722338,11.265567630168361,11.0941716656143,10.931782765983135,10.771382926754788,10.61098308752641,10.450583248298052,10.290183409069686,10.134115519965267,9.983757930968679,9.833400341972117,9.68304275297556,9.532685163978972,9.38675003457525,9.245553253210852,9.104356471846426,8.963159690482,8.82196290911763,8.688486628433623,8.55566633794227,8.42284604745091,8.290025756959565,8.162714820306629,8.037716452555609,7.912718084804558,7.787719717053514,7.669951358303483,7.554066874205622,7.4381823901077535,7.323844859137421,7.217855539367852,7.111866219598267,7.0058768998286824,6.905248768731136,6.806261818115869,6.70727486750061,6.611371493671248,6.517549860096949,6.423728226522643,6.334043695550012,6.246796527027181,6.159549358504329,6.07815537339916,5.997843489532409,5.918914539912558,5.8447553036782285,5.770596067443918,5.7005606087879706,5.631847184443524,5.5572478885904015,5.474800764059058,5.392353639527698,5.309906514996339,5.227459390464994,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[68.011371214245,68.05603507174794,68.10069892925087,68.14536278675381,68.19002664425675,68.23469050175969,68.27935435926261,68.32401821676555,68.36868207426849,68.41334593177143,68.45800978927437,68.50267364554776,68.54620247858192,68.58973131161606,68.63326014465022,68.67678897768437,68.72031781071851,68.76384664375266,68.80737547678683,68.85090430982098,68.8944331428551,68.93796197588927,68.98149080892343,69.02501964195757,69.06854847499172,69.11207730802587,69.15560614106002,69.19913497409416,69.24266380712832,69.28619264016247,69.32972147319663,69.37325030623077,69.41677913926492,69.46030797229906,69.50383680533321,69.54736563836737,69.59089447140151,69.63442330443567,69.67795213746982,69.72148097050396,69.76500980353812,69.80853863657227,69.85206746960641,69.89559630264057,69.93912513567471,69.98265396870886,70.02618280174302,70.06971163477716,70.11324046781132,70.15676930084547,70.20029813387961,70.24382696691377,70.2873557999479,70.33088463298206,70.37441346601622,70.41794229905037,70.46147113208453,70.50499996511866,70.5485287981528,70.59205763118698,70.6355864642211,70.67911529725527,70.72264413028941,70.76617296332357,70.80970179635771,70.85323062939187,70.89675946242602,70.94028829546016,70.98381712849432,71.02734596152848,71.07087479456263,71.11440362759677,71.15793246063092,71.20146129366506,71.24499012669922,71.28851895973337,71.33204779276751,71.37557662580167,71.41910545883582,71.46263429186996,71.50616312490412,71.54969195793826,71.59322079097241,71.63674962400657,71.6608003939128,71.68095555119345,71.7011107084741,71.72126586575476,71.7414210230354,71.76157618031606,71.78173133759671,71.80188649487735,71.822041652158,71.84219680943866,71.8623519667193,71.88250712399997,71.90266228128061,71.92281743856127,71.94297259584192,71.96312775312256,71.98328291040322,72.00343806768387,72.02359322496451,72.04374838224517,72.06390353952582,72.08405869680647,72.10421385408712,72.12436901136778,72.14452416864843,72.16467932592907,72.18483448320973,72.20498964049037,72.22514479777104,72.24529995505168,72.26545511233233,72.28561026961299,72.30576542689363,72.32592058417428,72.34607574145494,72.36623089873558,72.38638605601624,72.40654121329689,72.42669637057755,72.4468515278582,72.46700668513884,72.4871618424195,72.50731699970014,72.5274721569808,72.54762731426145,72.5677824715421,72.58793762882274,72.60809278610341,72.62824794338405,72.64840310066471,72.66855825794536,72.688713415226,72.70886857250666,72.7290237297873,72.74917888706796,72.76933404434861,72.78948920162925,72.8096443589099,72.82979951619056,72.8499546734712,72.87010983075186,72.89026498803251,72.91042014531315,72.93057530259381,72.95073045987448,72.97088561715512,72.99104077443577,73.01119593171641,73.03135108899707,73.05150624627771,73.07166140355837,73.09181656083902,73.1134617941067,73.13585206899971,73.15824234389272,73.18063261878574,73.20302289367874,73.22541316857175,73.24780344346478,73.27019371835779,73.29258399325079,73.3149742681438,73.33736454303681,73.07765943528862,72.6769066362199,72.27615383715114,71.87540103808237,71.47464823901365,71.07389543994486,70.67314264087611,70.27238984180737,69.87163704273861,69.47088424366987,69.07013144460109,68.66937864553235,68.26862584646359,67.86787304739484,67.4671202483261,67.06636744925734,66.66561465018859,66.26486185111982,65.86410905205106,65.46335625298232,65.06260345391357,64.66185065484481,64.26109785577607,63.860345056707295,63.459592257638555,63.0588394585698,62.65808665950104,62.2573338604323,61.85658106136352,61.45582826229479,61.055075463226025,60.65432266415726,60.25356986508854,59.85281706601977,59.45206426695101,59.05131146788226,58.6505586688135,58.24980586974475,57.849053070676,57.44830027160724,57.047547472538504,56.64679467346974,56.24122553329368,55.83084013200903,55.420454730724394,55.01006932943975,54.59968392815513,54.18929852687049,53.77891312558585,53.36852772430122,52.958142323016574,52.547756921731946,52.13737152044732,51.72698611916267,51.31660071787803,50.90621531659341,50.49582991530877,50.08544451402413,49.67505911273949,49.26467371145485,48.85428831017023,48.44390290888558,48.03351750760095,47.623132106316305,47.212746705031684,46.80236130374704,46.391975902462406,45.98159050117776,45.57120509989313,45.160819698608506,44.750434297323864,44.34004889603922,43.929663494754585,43.51927809346995,43.10889269218532,42.698507290900686,42.28812188961605,41.8777364883314,41.46735108704679,41.056965685762144,40.64658028447751,40.236194883192866,39.825809481908216,39.484485933438165,39.21222423778263,38.93996254212711,38.667700846471526,38.395439150815996,38.123177455160416,37.85091575950489,37.57865406384936,37.30639236819377,37.034130672538254,36.76186897688273,36.48960728122707,36.21734558557161,35.945083889916035,35.672822194260505,35.400560498604975,35.1282988029494,34.86086937947128,34.59640630164938,34.331943223827594,34.06748014600568,33.80301706818377,33.53855399036193,33.274090912540075,33.00962783471817,32.745164756896315,32.480701679074414,32.21623860125256,31.95177552343071,31.687312445608814,31.42284936778696,31.158386289965094,30.89392321214321,30.62946013432135,30.3684664472403,30.111933410278784,29.85540037331727,29.598867336355692,29.342334299394174,29.08580126243261,28.829268225471083,28.572735188509572,28.316202151548055,28.059669114586477,27.80313607762495,27.546603040663445,27.29007000370187,27.033536966740293,26.777003929778775,26.52607211171704,26.278587193870113,26.031102276023244,25.783617358176375,25.536132440329443,25.288647522482563,25.041162604635705,24.793677686788826,24.546192768941847,24.298707851094978,24.051222933248106,23.803738015401226,23.556253097554357,23.315856608733753,23.078384715978558,22.840912823223373,22.603440930468228,22.36596903771307,22.128497144957876,21.891025252202745,21.653553359447546,21.41608146669239,21.178609573937248,20.94113768118206,20.707387432567263,20.480307147388864,20.253226862210425,20.026146577032005,19.79906629185361,19.57198600667521,19.344905721496755,19.117825436318345,18.890745151139903,18.663664865961504,18.439342358328126,18.221374722796387,18.003407087264648,17.78543945173293,17.567471816201227,17.349504180669488,17.13153654513777,16.913568909606056,16.695601274074363,16.480717510740938,16.272040038379593,16.0633625660183,15.854685093656999,15.64600762129569,15.43733014893436,15.228652676573029,15.019975204211717,14.814669835461475,14.618055947569198,14.42144205967688,14.22482817178459,14.028214283892284,13.831600396000006,13.634986508107687,13.438520377204187,13.25505704806563,13.071593718927062,12.88813038978851,12.704667060649925,12.52120373151136,12.337740402372765,12.159319508655134,11.987923544101095,11.816527579547085,11.645131614993081,11.473735650439057,11.302339685885045,11.135447253693382,10.975047414465013,10.814647575236656,10.65424773600831,10.493847896779965,10.333448057551585,10.182204386676204,10.031846797679645,9.881489208683087,9.731131619686497,9.580774030689938,9.438313690403106,9.29711690903868,9.155920127674282,9.014723346309884,8.87526746220259,8.742447171711238,8.609626881219885,8.476806590728533,8.34398630023718,8.21823974812335,8.093241380372298,7.968243012621242,7.8432446448702215,7.726570970484692,7.610686486386825,7.494802002288963,7.380917888556402,7.274928568786818,7.168939249017208,7.0629499292476385,6.962157680118707,6.863170729503434,6.7641837788881904,6.667825024455319,6.574003390881003,6.480181757306703,6.389519074220832,6.30227190569798,6.2150247371751375,6.132204346004187,6.051892462137438,5.97158057827069,5.897209668060209,5.8230504318258935,5.7513290759520155,5.682615651607579,5.612921248678357,5.530474124146997,5.448026999615637,5.365579875084293,5.283132750552933,5.200685626021573,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[68.01861358698837,68.06109112599712,68.10356866500588,68.14604620401465,68.1885237430234,68.23100128203217,68.27400446699022,68.31753330002437,68.3610621330585,68.40459096609266,68.4481197991268,68.49164863216096,68.5351774651951,68.57870629822926,68.62223513126341,68.66576396429757,68.70929279733171,68.75282163036586,68.79635046340002,68.83987929643416,68.88340812946831,68.92693696250245,68.97046579553661,69.01399462857076,69.05752346160492,69.10105229463906,69.1445811276732,69.18810996070737,69.23163879374151,69.27516762677567,69.31869645980981,69.36222529284396,69.4057541258781,69.44928295891226,69.49281179194641,69.53634062498057,69.57986945801471,69.62339829104886,69.66692712408302,69.71045595711716,69.7539847901513,69.79751362318547,69.84104245621961,69.88457128925376,69.92810012228792,69.97162895532206,70.0151577883562,70.05868662139036,70.10221545442451,70.14574428745865,70.18927312049281,70.23280195352696,70.27633078656112,70.31985961959526,70.36338845262941,70.40691728566355,70.45044611869773,70.49397495173186,70.537503784766,70.58103261780016,70.6245614508343,70.66809028386847,70.71161911690261,70.75514794993676,70.79867678297092,70.84220561600506,70.88573444903922,70.92926328207336,70.97279211510752,71.01632094814167,71.05984978117581,71.10337861420996,71.1469074472441,71.19043628027826,71.23396511331242,71.27749394634657,71.32102277938071,71.36455161241487,71.40808044544902,71.45160927848316,71.49513811151732,71.53866694455147,71.58219577758561,71.62572461061977,71.649775380526,71.66993053780665,71.69008569508729,71.71024085236795,71.7303960096486,71.75055116692926,71.7707063242099,71.79086148149055,71.8110166387712,71.83117179605186,71.85132695333252,71.87148211061316,71.89163726789381,71.91179242517445,71.93194758245511,71.95210273973576,71.97225789701642,71.99241305429706,72.01256821157772,72.03272336885837,72.05287852613901,72.07303368341967,72.09318884070032,72.11334399798096,72.13349915526163,72.15365431254227,72.17380946982291,72.19396462710358,72.21411978438422,72.23427494166488,72.25443009894553,72.27458525622617,72.29474041350682,72.31489557078748,72.33505072806814,72.35520588534878,72.37536104262944,72.39551619991008,72.41567135719073,72.43582651447139,72.45598167175203,72.4761368290327,72.49629198631334,72.516447143594,72.53660230087465,72.55675745815529,72.57691261543594,72.5970677727166,72.61722292999724,72.6373780872779,72.65753324455855,72.67768840183919,72.69784355911985,72.7179987164005,72.73815387368114,72.7583090309618,72.77846418824245,72.79861934552311,72.81877450280376,72.8389296600844,72.85908481736506,72.87923997464571,72.89939513192635,72.91955028920701,72.93970544648766,72.9598606037683,72.98001576104896,73.00017091832962,73.02032607561027,73.04048123289093,73.06063639017158,73.08079154745222,73.10094670473286,73.12110186201352,73.14125701929417,73.16141217657483,73.18156733385548,73.20131953821063,73.21905699261164,73.23679444701266,73.25453190141366,73.27226935581469,73.29000681021569,73.00825424173316,72.57675666180887,72.14525908188455,71.71376150196025,71.28226392203595,70.85076634211163,70.41926876218734,69.98777118226303,69.55627360233873,69.13103144510728,68.72064604382263,68.310260642538,67.89987524125337,67.48948983996873,67.0791044386841,66.66871903739946,66.25833363611481,65.84794823483018,65.43756283354554,65.02717743226091,64.61679203097628,64.20640662969164,63.79602122840703,63.385635827122364,62.97525042583774,62.56486502455311,62.154479623268465,61.74409422198384,61.33370882069919,60.92332341941456,60.51293801812992,60.10255261684527,59.69216721556066,59.281781814276016,58.87139641299138,58.461011011706745,58.0506256104221,57.640240209137474,57.22985480785284,56.819469406568196,56.409084005283574,55.99869860399893,55.588313202714296,55.177927801429654,54.76754240014501,54.35715699886037,53.94677159757575,53.53638619629112,53.12600079500647,52.71561539372183,52.30522999243719,51.89484459115256,51.484459189867934,51.07407378858329,50.66368838729865,50.25330298601403,49.842917584729385,49.43253218344475,49.022146782160114,48.61176138087547,48.20137597959085,47.79099057830621,47.38060517702157,46.97021977573692,46.55983437445231,46.14944897316767,45.73906357188303,45.32867817059839,44.918292769313744,44.50790736802912,44.09752196674449,43.687136565459845,43.27675116417521,42.86636576289057,42.45598036160594,42.0455949603213,41.63520955903667,41.224824157752025,40.814438756467396,40.40405335518276,39.993667953898125,39.58328255261348,39.17289715132884,38.83157360285878,38.55931190720325,38.28705021154773,38.01478851589215,37.74252682023662,37.47026512458103,37.19800342892551,36.92574173326998,36.653480037614386,36.38121834195888,36.10895664630335,35.83669495064769,35.566586247418655,35.302123169596754,35.03766009177484,34.77319701395305,34.50873393613121,34.24427085830929,33.97980778048739,33.715344702665604,33.45088162484369,33.18641854702177,32.92195546919994,32.657492391378085,32.39302931355618,32.128566235734326,31.864103157912428,31.59964008009057,31.335177002268722,31.07071392444682,30.81219837509193,30.555665338130403,30.29913230116885,30.042599264207325,29.78606622724574,29.52953319028423,29.273000153322716,29.016467116361138,28.759934079399617,28.503401042438057,28.24686800547653,27.990334968515015,27.7338019315535,27.477268894591923,27.220735857630395,26.969947660553093,26.72246274270621,26.47497782485933,26.227492907012458,25.98000798916554,25.73252307131861,25.485038153471745,25.237553235624873,24.99006831777794,24.74258339993106,24.495098482084202,24.247613564237323,24.000128646390348,23.75730325545103,23.519831362695847,23.282359469940648,23.044887577185506,22.807415684430406,22.56994379167521,22.332471898920023,22.09500000616488,21.85752811340972,21.620056220654526,21.382584327899394,21.145112435144195,20.916872155170694,20.689791869992295,20.462711584813892,20.235631299635443,20.008551014457044,19.781470729278603,19.554390444100186,19.327310158921787,19.10022987374339,18.873149588564935,18.65182466309206,18.43385702756036,18.215889392028622,17.99792175649694,17.7799541209652,17.56198648543346,17.34401884990174,17.12605121437004,16.9080835788383,16.694587557733374,16.485910085372034,16.27723261301075,16.06855514064944,15.859877668288098,15.6512001959268,15.442522723565501,15.233845251204192,15.028397399158596,14.831783511266316,14.635169623374026,14.438555735481719,14.241941847589441,14.045327959697122,13.848714071804833,13.652100183912527,13.466715984501057,13.283252655362489,13.09978932622391,12.916325997085353,12.732862667946785,12.54939933880823,12.36748752892586,12.196091564371851,12.02469559981781,11.853299635263824,11.681903670709785,11.510507706155774,11.339111741601773,11.178711902175294,11.018312062946915,10.85791222371857,10.6975123844902,10.537112545261841,10.380650842383751,10.230293253387213,10.079935664390625,9.929578075394037,9.779220486397477,9.631074127595369,9.489877346230942,9.348680564866545,9.207483783502147,9.06628700213772,8.929228005480223,8.796407714988879,8.663587424497509,8.530767134006156,8.398763043691108,8.27376467594005,8.148766308188993,8.023767940437972,7.8990750667638,7.783190582665916,7.667306098568055,7.551421614470179,7.437990917975348,7.332001598205772,7.226012278436196,7.120022958666611,7.019066591506286,6.920079640891039,6.821092690275766,6.724278555239389,6.63045692166509,6.53663528809078,6.444994452891635,6.3577472843687985,6.2705001158459615,6.186253318609224,6.1059414347424585,6.0256295508757205,5.949664032442194,5.875504796207865,5.8020975431160675,5.733384118771626,5.664670694427173,5.586147484234954,5.503700359703592,5.421253235172232,5.338806110640872,5.256358986109529,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[68.01642648716162,68.05890402617038,68.10138156517914,68.1438591041879,68.18633664319665,68.22881418220541,68.27129172121417,68.31376926022293,68.35624679923168,68.39872433824046,68.4412018772492,68.48367941625796,68.52615695526671,68.56863449427549,68.61111203328424,68.65358957229299,68.69606711130176,68.73854465031052,68.78102218931927,68.82349972832803,68.86597726733677,68.90845480634555,68.9509323453543,68.99446117789823,69.03799001093238,69.08151884396653,69.12504767700068,69.16857651003484,69.21210534306898,69.25563417610313,69.29916300913729,69.34269184217143,69.38622067520558,69.42974950823972,69.47327834127388,69.51680717430803,69.56033600734219,69.60386484037633,69.64739367341048,69.69092250644462,69.73445133947878,69.77798017251293,69.82150900554709,69.86503783858123,69.90856667161538,69.95209550464953,69.99562433768368,70.03915317071784,70.08268200375198,70.12621083678613,70.16973966982027,70.21326850285443,70.25679733588858,70.30032616892274,70.34385500195688,70.38738383499103,70.43091266802517,70.47444150105933,70.51797033409348,70.56149916712764,70.60502800016178,70.64855683319593,70.69208566623008,70.73561449926423,70.77914333229839,70.82267216533253,70.86620099836668,70.90972983140082,70.95325866443498,70.99678749746914,71.04031633050329,71.08384516353743,71.12737399657158,71.17090282960574,71.21443166263988,71.25796049567404,71.30148932870819,71.34501816174233,71.38854699477648,71.43207582781064,71.47560466084478,71.51913349387893,71.56266232691308,71.60619115994723,71.63024192985347,71.65039708713411,71.67055224441476,71.69070740169542,71.71086255897607,71.73101771625673,71.75117287353737,71.77132803081801,71.79148318809867,71.81163834537932,71.83179350265998,71.85194865994063,71.87210381722127,71.89225897450193,71.91241413178258,71.93256928906322,71.9527244463439,71.97287960362453,71.99303476090518,72.01318991818584,72.03334507546649,72.05350023274713,72.0736553900278,72.09381054730844,72.11396570458909,72.13412086186973,72.15427601915039,72.17443117643104,72.1945863337117,72.21474149099234,72.234896648273,72.25505180555365,72.27520696283429,72.29536212011494,72.3155172773956,72.33567243467624,72.3558275919569,72.37598274923755,72.3961379065182,72.41629306379886,72.4364482210795,72.45660337836017,72.4767585356408,72.49691369292147,72.51706885020212,72.53722400748276,72.55737916476342,72.57753432204407,72.59768947932471,72.61784463660537,72.63799979388602,72.65815495116667,72.67831010844732,72.69846526572798,72.71862042300862,72.73877558028927,72.75893073756993,72.77908589485057,72.79924105213122,72.81939620941186,72.83955136669252,72.85809472092603,72.87583217532705,72.89356962972806,72.91130708412909,72.92904453853009,72.94678199293111,72.96451944733212,72.98225690173312,72.99999435613415,73.01773181053515,73.03546926493617,73.05320671933718,73.0709441737382,73.08868162813921,73.10641908254023,73.12415653694124,73.14189399134226,73.15963144574327,73.17736890014429,73.1951063545453,73.21284380894632,73.23058126334732,72.94882869486477,72.51733111494049,72.08583353501618,71.65433595509188,71.22283837516758,70.79134079524324,70.35984321531896,69.92834563539466,69.49684805547037,69.06535047554607,68.63385289562173,68.20235531569745,67.77085773577315,67.33936015584882,66.90786257592454,66.47636499600023,66.04486741607593,65.61336983615162,65.18187225622731,64.75037467630303,64.31887709637871,63.88737951645441,63.455881936530126,63.02438435660579,62.5928867766815,62.16138919675719,61.72989161683289,61.298394036908604,60.866896456984264,60.43539887705998,60.00390129713567,59.57240371721137,59.14090613728708,58.70940855736278,58.27791097743847,57.846413397514155,57.41491581758984,56.98732787855809,56.576942477273455,56.16655707598881,55.7561716747042,55.34578627341955,54.93540087213492,54.52501547085028,54.114630069565635,53.70424466828099,53.293859266996364,52.883473865711736,52.47308846442709,52.06270306314245,51.65231766185781,51.24193226057319,50.83154685928855,50.42116145800391,50.01077605671927,49.60039065543465,49.19000525415001,48.77961985286537,48.36923445158072,47.958849050296095,47.54846364901147,47.138078247726824,46.72769284644219,46.317307445157546,45.906922043872925,45.49653664258828,45.08615124130364,44.67576584001901,44.26538043873437,43.85499503744975,43.444609636165104,43.03422423488047,42.623838833595826,42.213453432311184,41.80306803102656,41.39268262974193,40.982297228457284,40.57191182717264,40.16152642588802,39.751141024603385,39.34075562331874,38.9303702220341,38.519984820749464,38.178661272279406,37.90639957662387,37.63413788096835,37.36187618531277,37.089614489657244,36.81735279400166,36.545091098346134,36.27282940269061,36.00784003754411,35.743376959722276,35.47891388190037,35.21445080407851,34.949987726256666,34.685524648434765,34.42106157061285,34.15659849279106,33.89213541496922,33.6276723371473,33.3632092593254,33.098746181503614,32.8342831036817,32.569820025859784,32.305356948037954,32.040893870216095,31.776430792394184,31.512463339905025,31.255930302943508,30.999397265981983,30.74286422902047,30.48633119205895,30.229798155097377,29.973265118135846,29.716732081174296,29.460199044212768,29.203666007251186,28.947132970289676,28.69059993332816,28.434066896366584,28.177533859405063,27.9210008224435,27.664467785481975,27.413823209389175,27.166338291542303,26.918853373695377,26.671368455848448,26.42388353800159,26.17639862015471,25.928913702307828,25.681428784460955,25.43394386661404,25.18645894876711,24.938974030920242,24.69148911307337,24.44400419522644,24.198749902168313,23.961278009413178,23.723806116657983,23.486334223902826,23.24886233114768,23.011390438392496,22.773918545637297,22.53644665288216,22.298974760127056,22.06150286737186,21.824030974616672,21.58655908186153,21.35343716295258,21.12635687777413,20.899276592595744,20.672196307417288,20.445116022238874,20.21803573706048,19.990955451882073,19.76387516670362,19.536794881525225,19.309714596346783,19.08263431116837,18.864306967856084,18.646339332324345,18.428371696792592,18.210404061260878,17.992436425729174,17.774468790197435,17.556501154665753,17.338533519134014,17.120565883602275,16.908457604725815,16.699780132364484,16.49110266000319,16.282425187641877,16.073747715280536,15.865070242919252,15.65639277055794,15.4477152981966,15.24212496285571,15.045511074963436,14.848897187071113,14.652283299178837,14.455669411286559,14.259055523394268,14.062441635501964,13.865827747609686,13.678374920936486,13.49491159179789,13.311448262659335,13.12798493352078,12.944521604382212,12.76105827524363,12.577594946105075,12.40425958464258,12.232863620088553,12.06146765553455,11.890071690980541,11.718675726426502,11.547279761872513,11.382376389885554,11.221976550657173,11.061576711428827,10.90117687220048,10.740777032972101,10.580377193743756,10.428739709094753,10.278382120098163,10.128024531101584,9.977666942105046,9.827309353108458,9.682637783423225,9.541441002058807,9.40024422069441,9.259047439329983,9.117850657965585,8.983188548757855,8.850368258266485,8.717547967775142,8.584727677283798,8.454287971507815,8.329289603756742,8.204291236005732,8.079292868254672,7.955694678945023,7.839810194847147,7.7239257107492865,7.6080412266514035,7.495063947394316,7.38907462762474,7.283085307855142,7.177095988085565,7.075975502893881,6.976988552278608,6.878001601663346,6.780732086023471,6.686910452449155,6.5930888188748495,6.500469831562464,6.413222663039617,6.325975494516765,6.240302291214258,6.159990407347507,6.079678523480759,6.002118396824167,5.927959160589856,5.853799924355535,5.784152585935667,5.715439161591226,5.641820844322892,5.55937371979153,5.4769265952601875,5.394479470728826,5.312032346197466,5.229585221666106,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[68.01423938733488,68.05671692634364,68.0991944653524,68.14167200436115,68.18414954336991,68.22662708237867,68.26910462138743,68.31158216039618,68.35405969940494,68.3965372384137,68.43901477742246,68.48149231643121,68.52396985543997,68.56644739444874,68.6089249334575,68.65140247246624,68.693880011475,68.73635755048377,68.77883508949252,68.82131262850127,68.86379016751005,68.9062677065188,68.94874524552756,68.9912227845363,69.03370032354508,69.07617786255383,69.11865540156258,69.16113294057135,69.20361047958009,69.24608801858886,69.28856555759762,69.33104309660636,69.37352063561514,69.41599817462388,69.45847571363265,69.50095325264141,69.54343079165017,69.58590833065892,69.62838586966767,69.6713890557721,69.71491788880626,69.7584467218404,69.80197555487455,69.8455043879087,69.88903322094286,69.93256205397701,69.97609088701115,70.0196197200453,70.06314855307946,70.1066773861136,70.15020621914775,70.19373505218189,70.23726388521605,70.2807927182502,70.32432155128436,70.3678503843185,70.41137921735266,70.4549080503868,70.49843688342095,70.54196571645511,70.58549454948925,70.62902338252341,70.67255221555756,70.7160810485917,70.75960988162586,70.80313871466001,70.84666754769415,70.89019638072831,70.93372521376246,70.9772540467966,71.02078287983076,71.0643117128649,71.10784054589905,71.15136937893321,71.19489821196736,71.23842704500152,71.28195587803566,71.3254847110698,71.36901354410395,71.41254237713811,71.45607121017227,71.49960004320641,71.54312887624056,71.5866577092747,71.61070847918093,71.63086363646158,71.65101879374222,71.6711739510229,71.69132910830353,71.71148426558419,71.73163942286484,71.75179458014549,71.77194973742614,71.7921048947068,71.81226005198745,71.83241520926809,71.85257036654875,71.87272552382939,71.89288068111006,71.9130358383907,71.93319099567135,71.95334615295201,71.97350131023265,71.9936564675133,72.01381162479396,72.0339667820746,72.05412193935526,72.07427709663591,72.09443225391657,72.1145874111972,72.13474256847786,72.15489772575852,72.17505288303917,72.19520804031981,72.21536319760047,72.23551835488112,72.25567351216176,72.27582866944242,72.29598382672307,72.31613898400371,72.33629414128438,72.35644929856501,72.37660445584567,72.39675961312633,72.41691477040698,72.43706992768763,72.45722508496827,72.47738024224893,72.49713244924042,72.51486990364144,72.53260735804245,72.55034481244347,72.56808226684448,72.5858197212455,72.6035571756465,72.62129463004752,72.63903208444853,72.65676953884956,72.67450699325056,72.69224444765158,72.70998190205259,72.7277193564536,72.74545681085462,72.76319426525563,72.78093171965665,72.79866917405765,72.81640662845868,72.83414408285968,72.85188153726071,72.86961899166171,72.88735644606274,72.90509390046375,72.92283135486475,72.94056880926576,72.95830626366677,72.97604371806779,72.99378117246881,73.01151862686982,73.02925608127083,73.04699353567185,73.06473099007286,73.08246844447388,73.10020589887489,73.1179433532759,73.13568080767692,73.15341826207793,73.17115571647895,72.88940314799639,72.4579055680721,72.02640798814781,71.59491040822351,71.16341282829922,70.73191524837488,70.30041766845059,69.8689200885263,69.43742250860198,69.0059249286777,68.57442734875336,68.14292976882908,67.71143218890477,67.27993460898045,66.84843702905617,66.41693944913187,65.98544186920756,65.55394428928324,65.12244670935894,64.69094912943466,64.25945154951035,63.827953969586034,63.39645638966175,62.96495880973741,62.533461229813135,62.101963649888816,61.670466069964505,61.23896849004022,60.807470910115896,60.375973330191606,59.9444757502673,59.51297817034299,59.0814805904187,58.649983010494395,58.21848543057009,57.78698785064578,57.355490270721475,56.923992690797185,56.49249511087287,56.060997530948576,55.62949995102427,55.198002371099975,54.76650479117566,54.33500721125136,53.90350963132705,53.47201205140274,53.04051447147845,52.60901689155415,52.17751931162984,51.746021731705525,51.314524151781214,50.88302657185693,50.45152899193262,50.02003141200831,49.58853383208401,49.15703625215971,48.725538672235416,48.294041092311105,47.86254351238679,47.43104593246249,46.9995483525382,46.56805077261389,46.136553192689576,45.705055612765264,45.27355803284098,44.843624312008885,44.43323891072424,44.0228535094396,43.61246810815496,43.20208270687034,42.7916973055857,42.38131190430106,41.970926503016415,41.56054110173178,41.15015570044716,40.739770299162515,40.32938489787787,39.91899949659324,39.508614095308616,39.09822869402397,38.68784329273933,38.277457891454695,37.86707249017006,37.525748941699995,37.253487246044465,36.98122555038895,36.71355690549147,36.44909382766962,36.18463074984771,35.92016767202587,35.65570459420402,35.391241516382095,35.126778438560265,34.86231536073836,34.5978522829165,34.33338920509465,34.06892612727275,33.80446304945084,33.539999971629044,33.27553689380721,33.011073815985284,32.74661073816339,32.4821476603416,32.21768458251969,31.956195267756613,31.699662230795116,31.443129193833535,31.186596156872007,30.930063119910443,30.673530082948925,30.4169970459874,30.160464009025887,29.903930972064373,29.6473979351028,29.390864898141267,29.134331861179714,28.87779882421819,28.62126578725661,28.364732750295094,28.108199713333576,27.857698758225194,27.61021384037832,27.362728922531456,27.115244004684524,26.86775908683765,26.620274168990786,26.372789251143857,26.125304333296924,25.877819415450066,25.630334497603183,25.382849579756304,25.135364661909435,24.887879744062513,24.640394826215587,24.402724656130438,24.165252763375296,23.92778087062014,23.690308977864944,23.45283708510981,23.21536519235461,22.977893299599454,22.740421406844312,22.502949514089128,22.26547762133393,22.02800572857879,21.790533835823688,21.562921885555998,21.335841600377556,21.108761315199157,20.88168103002074,20.654600744842288,20.4275204596639,20.20044017448545,19.973359889307034,19.746279604128635,19.519199318950232,19.294756908151744,19.07678927262004,18.8588216370883,18.640854001556548,18.42288636602488,18.20491873049314,17.986951094961384,17.768983459429673,17.55101582389797,17.33304818836623,17.12232765171824,16.913650179356907,16.704972706995612,16.4962952346343,16.287617762272973,16.078940289911674,15.870262817550364,15.661585345189021,15.455852526552825,15.259238638660534,15.062624750768217,14.866010862875939,14.669396974983663,14.472783087091342,14.276169199199067,14.079555311306788,13.890033857371897,13.706570528233343,13.523107199094786,13.339643869956191,13.156180540817596,12.972717211679043,12.789253882540487,12.612427604913295,12.441031640359295,12.26963567580527,12.098239711251258,11.926843746697232,11.755447782143229,11.5860408775958,11.425641038367443,11.265241199139085,11.10484135991073,10.94444152068235,10.784041681454003,10.62718616480228,10.47682857580569,10.326470986809111,10.176113397812571,10.025755808815983,9.875398220615487,9.73420143925109,9.593004657886663,9.451807876522256,9.310611095157839,9.169969382526823,9.037149092035452,8.904328801544109,8.771508511052765,8.638688220561395,8.509812899324508,8.384814531573475,8.25981616382243,8.134817796071358,8.01231429112624,7.896429807028371,7.780545322930502,7.664660838832627,7.5521369768132764,7.446147657043681,7.340158337274104,7.234169017504526,7.132884414281456,7.0338974636661895,6.934910513050935,6.8371856168075364,6.74336398323322,6.649542349658926,6.5559452102332685,6.468698041710416,6.381450873187589,6.294351263819279,6.21403937995253,6.133727496085788,6.054572761206153,5.980413524971824,5.906254288737503,5.8349210530997215,5.766207628755268,5.697494204410821,5.6150470798794725,5.532599955348123,5.45015283081676,5.3677057062854185,5.285258581754057,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[68.01205228750814,68.0545298265169,68.09700736552566,68.13948490453441,68.18196244354317,68.22443998255193,68.26691752156069,68.30939506056944,68.3518725995782,68.39435013858696,68.43682767759572,68.47930521660447,68.52178275561323,68.56426029462199,68.60673783363075,68.6492153726395,68.69169291164826,68.73417045065702,68.77664798966578,68.81912552867453,68.86160306768329,68.90408060669205,68.9465581457008,68.98903568470956,69.03151322371832,69.07399076272708,69.11646830173584,69.1589458407446,69.20142337975335,69.24390091876211,69.28637845777088,69.32885599677962,69.3713335357884,69.41381107479714,69.45628861380591,69.49876615281467,69.54124369182341,69.58372123083218,69.62619876984093,69.6686763088497,69.71115384785845,69.75363138686721,69.79610892587597,69.83858646488473,69.88106400389348,69.92354154290224,69.966019081911,70.00849662091976,70.05097415992851,70.09345169893727,70.13592923794603,70.17840677695479,70.22088431596354,70.2633618549723,70.30583939398107,70.34831693364598,70.39184576668012,70.43537459971427,70.47890343274842,70.52243226578257,70.56596109881671,70.60948993185087,70.65301876488502,70.69654759791916,70.74007643095332,70.78360526398747,70.82713409702163,70.87066293005577,70.91419176308992,70.95772059612406,71.00124942915822,71.04477826219237,71.08830709522653,71.13183592826067,71.17536476129482,71.21889359432896,71.26242242736312,71.30595126039726,71.34948009343142,71.39300892646557,71.43653775949973,71.48006659253387,71.52359542556802,71.56712425860218,71.5911750285084,71.61133018578906,71.6314853430697,71.65164050035035,71.67179565763101,71.69195081491165,71.7121059721923,71.73226112947296,71.7524162867536,71.77257144403426,71.79272660131491,71.81288175859557,71.83303691587622,71.85319207315686,71.87334723043753,71.89350238771817,71.91365754499883,71.93381270227948,71.95396785956012,71.97412301684078,71.99427817412143,72.01443333140207,72.03458848868273,72.05474364596337,72.07489880324403,72.09505396052468,72.11520911780534,72.13536427508598,72.15390763195583,72.17164508635686,72.18938254075786,72.20711999515888,72.22485744955988,72.2425949039609,72.26033235836191,72.27806981276294,72.29580726716395,72.31354472156497,72.33128217596597,72.34901963036698,72.366757084768,72.38449453916901,72.40223199357003,72.41996944797104,72.43770690237206,72.45544435677307,72.47318181117409,72.4909192655751,72.50865671997612,72.52639417437712,72.54413162877813,72.56186908317915,72.57960653758016,72.59734399198118,72.61508144638219,72.6328189007832,72.65055635518422,72.66829380958524,72.68603126398625,72.70376871838727,72.72150617278828,72.7392436271893,72.75698108159031,72.77471853599133,72.79245599039234,72.81019344479336,72.82793089919437,72.84566835359539,72.86340580799639,72.88114326239739,72.8988807167984,72.91661817119942,72.93435562560043,72.95209308000145,72.96983053440246,72.98756798880348,73.00530544320449,73.0230428976055,73.04078035200652,73.05851780640754,73.07625526080855,73.09399271520957,73.11173016961058,72.82997760112804,72.39848002120374,71.96698244127944,71.53548486135513,71.10398728143083,70.6724897015065,70.24099212158221,69.80949454165793,69.37799696173361,68.94649938180932,68.51500180188499,68.08350422196071,67.6520066420364,67.22050906211209,66.7890114821878,66.35751390226349,65.92601632233918,65.49451874241487,65.06302116249056,64.63152358256627,64.20002600264198,63.768528422717665,63.33703084279338,62.90553326286905,62.47403568294476,62.042538103020455,61.61104052309615,61.17954294317185,60.74804536324753,60.31654778332324,59.885050203398926,59.45355262347462,59.02205504355034,58.59055746362603,58.159059883701715,57.72756230377741,57.29606472385311,56.86456714392881,56.433069564004505,56.00157198408019,55.57007440415592,55.138576824231606,54.707079244307295,54.27558166438298,53.84408408445867,53.412586504534374,52.98108892461008,52.54959134468577,52.11809376476146,51.68659618483716,51.255098604912845,50.82360102498856,50.39210344506425,49.96060586513994,49.529108285215635,49.097610705291345,48.66611312536703,48.23461554544273,47.803117965518425,47.37162038559411,46.94012280566983,46.50862522574552,46.07712764582121,45.645630065896896,45.21413248597261,44.7826349060483,44.351137326124,43.91963974619969,43.481535384292314,43.03609012721741,42.59064487014249,42.14519961306757,41.699754355992646,41.254309098917716,40.80886384184281,40.36341858476789,39.91797332769297,39.47252807061804,39.027082813543146,38.581637556468216,38.136192299393294,37.690747042318364,37.24530178524345,36.890347617795136,36.62588453997322,36.36142146215133,36.096958384329476,35.832495306507624,35.56803222868572,35.30356915086387,35.03910607304203,34.774642995220105,34.510179917398276,34.24571683957636,33.9812537617545,33.71679068393266,33.45232760611076,33.18786452828884,32.923401450467054,32.65893837264521,32.39992719560825,32.14339415864673,31.88686112168517,31.630328084723637,31.373795047762062,31.11726201080056,30.86072897383898,30.604195936877453,30.34766289991589,30.091129862954375,29.834596825992847,29.578063789031333,29.32153075206982,29.064997715108245,28.80846467814671,28.55193164118516,28.301574307061287,28.054089389214404,27.806604471367482,27.55911955352057,27.311634635673688,27.06414971782682,26.816664799979947,26.569179882133017,26.321694964286152,26.074210046439276,25.82672512859235,25.57924021074542,25.33175529289856,25.08427037505168,24.844171302847712,24.606699410092567,24.369227517337425,24.131755624582226,23.89428373182708,23.656811839071942,23.41933994631679,23.18186805356159,22.944396160806455,22.70692426805126,22.469452375296104,22.23198048254096,21.99948689333784,21.77240660815943,21.54532632298103,21.318246037802584,21.091165752624175,20.864085467445733,20.637005182267337,20.40992489708892,20.18284461191047,19.95576432673208,19.728684041553628,19.507239212915714,19.28927157738401,19.071303941852268,18.853336306320557,18.63536867078885,18.417401035257114,18.199433399725358,17.98146576419369,17.763498128661954,17.545530493130197,17.336197698710677,17.12752022634938,16.91884275398808,16.71016528162674,16.501487809265406,16.29281033690411,16.0841328645428,15.87545539218147,15.66958009024997,15.472966202357648,15.276352314465363,15.079738426573066,14.883124538680775,14.686510650788458,14.48989676289618,14.293282875003904,14.101692793807352,13.918229464668766,13.734766135530212,13.551302806391618,13.367839477253064,13.184376148114508,13.000912818975914,12.820595625184025,12.649199660629998,12.477803696076023,12.306407731521984,12.135011766967985,11.963615802413958,11.792219837859946,11.62930552607771,11.468905686849364,11.308505847620983,11.148106008392629,10.98770616916427,10.827306329935915,10.675275031513227,10.524917442516648,10.374559853520111,10.224202264523521,10.073844675526942,9.92696187644335,9.785765095078924,9.644568313714526,9.503371532350128,9.362174750985702,9.22392992580443,9.091109635313087,8.958289344821742,8.825469054330373,8.692648763839028,8.565337827141224,8.440339459390167,8.31534109163913,8.190342723888097,8.068933903307464,7.953049419209595,7.837164935111726,7.721280451013858,7.609210006232236,7.5032206864626465,7.3972313666930685,7.291242046923473,7.189793325669029,7.090806375053763,6.991819424438514,6.8936391475916015,6.7998175140173025,6.705995880442996,6.61217424686868,6.524173420381249,6.436926251858397,6.349679083335545,6.268088352557555,6.187776468690812,6.107464584824063,6.03286788935381,5.958708653119492,5.885689520263769,5.8169760959193155,5.748262671574878,5.670720439967422,5.588273315436062,5.505826190904708,5.423379066373359,5.340931941841996,5.258484817310654,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[68.00986518768138,68.05234272669014,68.0948202656989,68.13729780470766,68.17977534371641,68.22225288272517,68.26473042173393,68.30720796074269,68.34968549975144,68.3921630387602,68.43464057776896,68.47711811677772,68.51959565578647,68.56207319479523,68.60455073380399,68.64702827281275,68.6895058118215,68.73198335083026,68.77446088983902,68.81693842884778,68.85941596785653,68.90189350686529,68.94437104587405,68.98684858488282,69.02932612389156,69.07180366290032,69.1142812019091,69.15675874091784,69.19923627992661,69.24171381893535,69.28419135794411,69.32666889695288,69.36914643596164,69.4116239749704,69.45410151397915,69.49657905298791,69.53905659199667,69.58153413100543,69.62401167001418,69.66648920902294,69.7089667480317,69.75144428704046,69.79392182604921,69.83639936505797,69.87887690406674,69.9213544430755,69.96383198208426,70.00630952109302,70.04878706010177,70.09126459911053,70.13374213811929,70.17621967712805,70.2186972161368,70.26117475514556,70.30365229415432,70.34612983316308,70.38860737217183,70.43108491118059,70.47356245018935,70.5160399891981,70.55851752820686,70.60099506721562,70.64347260622438,70.68595014523314,70.7284276842419,70.77090522325067,70.81338276225941,70.85586030126817,70.89833784027694,70.94081537928568,70.98329291829445,71.02577045730321,71.06877364455397,71.11230247758814,71.15583131062229,71.19936014365643,71.2428889766906,71.28641780972474,71.32994664275888,71.37347547579304,71.41700430882719,71.46053314186133,71.50406197489548,71.54759080792964,71.57164157783586,71.59179673511652,71.61195189239717,71.63210704967781,71.65226220695847,71.67241736423912,71.69257252151976,71.71272767880042,71.73288283608107,71.75303799336173,71.77319315064238,71.79294536027022,71.81068281467124,71.82842026907227,71.84615772347327,71.86389517787428,71.88163263227528,71.89937008667631,71.91710754107733,71.93484499547834,71.95258244987934,71.97031990428036,71.98805735868137,72.00579481308239,72.0235322674834,72.04126972188442,72.05900717628543,72.07674463068645,72.09448208508746,72.11221953948848,72.1299569938895,72.14769444829051,72.16543190269152,72.18316935709254,72.20090681149355,72.21864426589455,72.23638172029557,72.25411917469658,72.2718566290976,72.28959408349861,72.30733153789963,72.32506899230064,72.34280644670166,72.36054390110267,72.37828135550367,72.39601880990469,72.41375626430572,72.43149371870673,72.44923117310773,72.46696862750875,72.48470608190976,72.50244353631078,72.5201809907118,72.53791844511281,72.55565589951382,72.57339335391484,72.59113080831585,72.60886826271687,72.62660571711788,72.6443431715189,72.66208062591991,72.67981808032091,72.69755553472193,72.71529298912294,72.73303044352397,72.75076789792497,72.768505352326,72.786242806727,72.803980261128,72.82171771552902,72.83945516993003,72.85719262433105,72.87493007873206,72.89266753313308,72.9104049875341,72.92814244193511,72.94587989633611,72.96361735073714,72.98135480513814,72.99909225953917,73.01682971394018,73.03456716834118,73.0523046227422,72.77055205425965,72.33905447433537,71.90755689441107,71.47605931448676,71.04456173456246,70.61306415463814,70.18156657471384,69.75006899478956,69.31857141486525,68.88707383494095,68.45557625501662,68.02407867509234,67.59258109516803,67.16108351524372,66.72958593531942,66.29808835539512,65.86659077547081,65.4350931955465,65.00359561562219,64.5720980356979,64.1406004557736,63.70910287584929,63.277605295925,62.846107716000674,62.41461013607639,61.98311255615208,61.551614976227775,61.12011739630348,60.68274714612709,60.2373018890522,59.791856631977275,59.346411374902345,58.900966117827444,58.45552086075252,58.0100756036776,57.56463034660268,57.11918508952775,56.673739832452846,56.228294575377916,55.78284931830299,55.3374040612281,54.89195880415317,54.44651354707825,54.001068290003325,53.555623032928395,53.11017777585347,52.66473251877857,52.21928726170364,51.77384200462872,51.328396747553796,50.882951490478874,50.43750623340398,49.99206097632905,49.54661571925412,49.1011704621792,48.6557252051043,48.21027994802937,47.764834690954444,47.31938943387952,46.8739441768046,46.4284989197297,45.983053662654775,45.537608405579846,45.09216314850492,44.646717891430015,44.2012726343551,43.75582737728018,43.31038212020525,42.864936863130325,42.41949160605542,41.97404634898051,41.52860109190558,41.08315583483065,40.637710577755726,40.192265320680825,39.7468200636059,39.30137480653098,38.85592954945605,38.41048429238115,37.965039035306226,37.5195937782313,37.07414852115638,36.62870326408145,36.27374909663315,36.00928601881123,35.74482294098934,35.480359863167486,35.215896785345635,34.951433707523734,34.68697062970189,34.42250755188004,34.158044474058116,33.893581396236286,33.62911831841437,33.36465524059251,33.10019216277067,32.84365912345988,32.587126086498294,32.33059304953678,32.074060012575266,31.81752697561369,31.560993938652175,31.30446090169061,31.04792786472908,30.7913948277675,30.534861790806,30.278328753844423,30.021795716882895,29.765262679921328,29.508729642959818,29.25219660599829,28.995663569036775,28.745449855897334,28.497964938050455,28.250480020203522,28.002995102356664,27.75551018450978,27.508025266662898,27.260540348815983,27.013055430969068,26.76557051312219,26.518085595275313,26.270600677428448,26.023115759581515,25.775630841734646,25.528145923887774,25.285617949565047,25.048146056809887,24.81067416405476,24.57320227129956,24.335730378544362,24.09825848578922,23.860786593034074,23.623314700278875,23.385842807523737,23.148370914768595,22.91089902201344,22.673427129258236,22.436051901119722,22.208971615941312,21.98189133076286,21.754811045584418,21.52773076040602,21.300650475227602,21.073570190049207,20.84648990487076,20.61940961969235,20.392329334513914,20.165249049335515,19.938168764157098,19.719721517679687,19.501753882147995,19.28378624661624,19.065818611084527,18.847850975552824,18.62988334002108,18.411915704489367,18.193948068957663,17.975980433425924,17.75874521806446,17.550067745703128,17.34139027334183,17.13271280098052,16.92403532861918,16.71535785625788,16.50668038389658,16.298002911535242,16.08932543917391,15.883307653947085,15.686693766054765,15.49007987816249,15.293465990270214,15.096852102377893,14.900238214485604,14.703624326593308,14.507010438701018,14.313351730242777,14.12988840110422,13.946425071965638,13.762961742827072,13.579498413688487,13.396035084549931,13.212571755411336,13.029108426272783,12.857367680900763,12.685971716346726,12.514575751792714,12.34317978723869,12.171783822684713,12.000387858130674,11.832970013787946,11.672570174559599,11.51217033533122,11.351770496102896,11.19137065687455,11.030970817646171,10.873721487220765,10.723363898224214,10.573006309227647,10.42264872023106,10.272291131234478,10.12193354223794,9.978525532271206,9.837328750906789,9.69613196954239,9.554935188177964,9.413738406813565,9.27789046908207,9.1450701785907,9.012249888099348,8.879429597608004,8.746609307116659,8.620862754957916,8.495864387206879,8.370866019455844,8.245867651704787,8.125553515488694,8.009669031390832,7.893784547292949,7.77790006319508,7.6662830356511975,7.560293715881613,7.45430439611203,7.348315076342439,7.246702237056617,7.147715286441343,7.048728335826089,6.950092678375677,6.85627104480136,6.7624494112270614,6.668627777652762,6.579648799052053,6.49240163052921,6.405154462006379,6.322137325162588,6.24182544129584,6.161513557429089,6.085322253735793,6.011163017501472,5.937003781267149,5.867744563083373,5.799031138738926,5.726393800055363,5.6439466755240195,5.561499550992659,5.479052426461299,5.396605301929945,5.314158177398596,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[68.0034339954565,68.04591153446526,68.08838907347402,68.13086661248278,68.17334415149153,68.21582169050029,68.25829922950905,68.3007767685178,68.34325430752656,68.38573184653532,68.42820938554408,68.47068692455284,68.5131644635616,68.55564200257035,68.59811954157911,68.64059708058787,68.68307461959662,68.72555215860538,68.76802969761414,68.8105072366229,68.85298477563165,68.89546231464041,68.93793985364917,68.98041739265793,69.02289493166668,69.06537247067544,69.10785000968421,69.15032754869296,69.19280508770173,69.23528262671049,69.27776016571924,69.320237704728,69.36271524373676,69.40519278274553,69.44767032175427,69.49014786076303,69.5326253997718,69.57510293878055,69.61758047778932,69.66005801679806,69.70253555580682,69.74501309481559,69.78749063382435,69.8299681728331,69.87244571184186,69.91492325085062,69.95740078985938,69.99987832886814,70.04235586787689,70.08483340688565,70.12731094589441,70.16978848490317,70.21226602391192,70.25474356292068,70.29722110192944,70.3396986409382,70.38217617994695,70.42465371895571,70.46713125796447,70.50960879697323,70.55208633598198,70.59456387499074,70.6370414139995,70.67951895300826,70.72199649201701,70.76447403102577,70.80695157003453,70.84942910904329,70.89190664805204,70.9343841870608,70.97686172606956,71.01933926507832,71.06181680408707,71.10429434309583,71.14677188210459,71.18924942111336,71.2317269601221,71.27420449913087,71.31668203813963,71.35834800382268,71.39960818009192,71.44086835636114,71.48212853263037,71.5233887088996,71.54314297702457,71.55859606352068,71.57404915001679,71.5895022365129,71.60495532645047,71.62269278085148,71.64043023525248,71.65816768965351,71.67590514405451,71.69364259845553,71.71138005285654,71.72911750725756,71.74685496165857,71.76459241605959,71.7823298704606,71.80006732486162,71.81780477926263,71.83554223366365,71.85327968806466,71.87101714246567,71.88875459686668,71.90649205126769,71.9242295056687,71.94196696006972,71.95970441447074,71.97744186887175,71.99517932327277,72.01291677767378,72.0306542320748,72.04839168647581,72.06612914087682,72.08386659527783,72.10160404967884,72.11934150407987,72.13707895848088,72.15481641288189,72.1725538672829,72.19029132168392,72.20802877608493,72.22576623048595,72.24350368488696,72.26124113928796,72.27897859368898,72.29671604808999,72.31445350249099,72.33219095689202,72.34992841129304,72.36766586569405,72.38540332009507,72.40314077449607,72.4208782288971,72.43861568329811,72.45635313769912,72.47409059210014,72.49182804650115,72.50956550090217,72.52730295530318,72.5450404097042,72.5627778641052,72.58051531850622,72.59825277290723,72.61599022730825,72.63372768170927,72.65146513611028,72.66920259051129,72.6869400449123,72.70467749931332,72.72241495371432,72.74015240811534,72.75788986251634,72.77562731691737,72.79336477131837,72.8111022257194,72.82883968012041,72.84657713452143,72.86431458892244,72.88205204332345,72.89978949772446,72.91752695212548,72.9352644065265,72.9530018609275,72.97073931532853,72.98847676972953,72.68790191315654,72.22817090109658,71.7684398890366,71.30870887697661,70.84897786491665,70.38924685285666,69.9295158407967,69.46978482873672,69.01005381667673,68.55032280461677,68.09059179255678,67.63871799523875,67.19327273816383,66.7478274810889,66.302382224014,65.85693696693907,65.41149170986415,64.96604645278923,64.5206011957143,64.07515593863941,63.629710681564475,63.18426542448955,62.73882016741465,62.293374910339715,61.8479296532648,61.40248439618987,60.957039139114954,60.51159388204005,60.06614862496511,59.6207033678902,59.17525811081528,58.729812853740356,58.28436759666546,57.83892233959053,57.39347708251561,56.94803182544069,56.50258656836576,56.05714131129085,55.611696054215926,55.166250797141004,54.7208055400661,54.27536028299118,53.82991502591625,53.384469768841335,52.939024511766405,52.49357925469148,52.04813399761658,51.60268874054165,51.15724348346673,50.71179822639181,50.266352969316884,49.82090771224198,49.37546245516705,48.93001719809214,48.48457194101721,48.039126683942314,47.59368142686738,47.14823616979246,46.70279091271754,46.25734565564261,45.81190039856771,45.366455141492786,44.921009884417856,44.47556462734293,44.03011937026803,43.5846741131931,43.13922885611819,42.69378359904326,42.248338341968335,41.802893084893434,41.35744782781851,40.91200257074359,40.46655731366866,40.021112056593736,39.575666799518835,39.130221542443905,38.68477628536899,38.23933102829406,37.79388577121916,37.34844051414424,36.90299525706931,36.457549999994384,36.01210474291946,35.65715057547116,35.39268749764924,35.12822441982735,34.863761342005496,34.599298264183645,34.334835186361744,34.07037210853989,33.80590903071805,33.54392408827296,33.28739105131145,33.030858014349874,32.774324977388346,32.51779194042678,32.261258903465325,32.00472586650374,31.74819282954223,31.491659792580712,31.235126755619135,30.978593718657617,30.722060681696053,30.465527644734525,30.208994607772947,29.952461570811447,29.69592853384987,29.439395496888338,29.18932540473342,28.94184048688655,28.694355569039622,28.44687065119275,28.199385733345835,27.951900815498952,27.704415897652023,27.45693097980516,27.209446061958282,26.9619611441114,26.71447622626448,26.466991308417565,26.219506390570686,25.972021472723814,25.727064596282336,25.489592703527222,25.252120810772034,25.014648918016892,24.777177025261697,24.539705132506537,24.30223323975141,24.06476134699621,23.82728945424101,23.58981756148587,23.352345668730724,23.11487377597553,22.877401883220386,22.645536623723157,22.418456338544704,22.191376053366294,21.964295768187906,21.737215483009493,21.51013519783104,21.283054912652602,21.0559746274742,20.828894342295786,20.601814057117387,20.374733771938942,20.15017145797541,19.93220382244367,19.714236186911965,19.496268551380215,19.2783009158485,19.060333280316804,18.842365644785055,18.62439800925334,18.406430373721637,18.188462738189894,17.972615265056863,17.763937792695568,17.55526032033427,17.346582847972957,17.13790537561163,16.929227903250332,16.72055043088902,16.51187295852768,16.303195486166384,16.097035217644173,15.900421329751884,15.703807441859606,15.507193553967328,15.310579666075009,15.113965778182731,14.917351890290456,14.720738002398136,14.525010666678178,14.341547337539632,14.158084008401065,13.974620679262499,13.791157350123942,13.60769402098536,13.424230691846793,13.240767362708208,13.065535701171491,12.894139736617458,12.722743772063454,12.551347807509455,12.379951842955418,12.208555878401405,12.03715991384738,11.876234662269859,11.7158348230415,11.555434983813132,11.395035144584785,11.234635305356406,11.074235466128082,10.921810353931752,10.771452764935185,10.621095175938596,10.470737586942047,10.320379997945478,10.17128596946345,10.030089188099051,9.888892406734634,9.747695625370245,9.606498844005829,9.465302062641431,9.331851012359692,9.199030721868333,9.06621043137699,8.933390140885619,8.801386050525664,8.676387682774632,8.551389315023595,8.426390947272537,8.301392579521501,8.182173127669923,8.066288643572042,7.9504041594741794,7.83451967537632,7.723356065070159,7.6173667453005605,7.5113774255309895,7.405388105761406,7.303611148444185,7.204624197828942,7.105637247213675,7.006650296598402,6.9127245755854485,6.818902942011139,6.72508130843682,6.635124177722881,6.547877009200034,6.460629840677182,6.3761862977676085,6.29587441390087,6.215562530034123,6.137776618117774,6.063617381883449,5.989458145649133,5.918513030247421,5.849799605902971,5.78108618155853,5.699620035611959,5.6171729110805995,5.534725786549255,5.4522786620178945,5.369831537486535,5.2873844129551815,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[67.98675843760975,68.0292359766185,68.07171351562725,68.11419105463601,68.15666859364477,68.19914613265354,68.24162367166228,68.28410121067105,68.32657874967981,68.36905628868855,68.41153382769733,68.45401136670607,68.49648890571484,68.5389664447236,68.58144398373236,68.62392152274111,68.66639906174986,68.70887660075863,68.75135413976739,68.79383167877614,68.8363092177849,68.87878675679366,68.92126429580242,68.96374183481117,69.00621937381993,69.04869691282869,69.09117445183745,69.1336519908462,69.17612952985496,69.21860706886372,69.26108460787248,69.30356214688123,69.34603968588999,69.38851722489876,69.43099476390752,69.47347230291626,69.51594984192504,69.55842738093378,69.60090491994255,69.6433824589513,69.68585999796005,69.72833753696882,69.77081507597758,69.81329261498634,69.8557701539951,69.89824769300385,69.94072523201261,69.98320277102137,70.02568031003013,70.06815784903888,70.11063538804764,70.1531129270564,70.19559046606516,70.23806800507391,70.28054554408267,70.32302308309143,70.36550062210019,70.40797816110894,70.4504557001177,70.49293323912646,70.53541077813523,70.57788831714397,70.62016296399594,70.66142314026517,70.70268331653439,70.74394349280362,70.78520366907287,70.8264638453421,70.86772402161134,70.90898419788057,70.9502443741498,70.99150455041902,71.03276472668826,71.07402490295749,71.11528507922672,71.15654525549596,71.19780543176519,71.23906560803442,71.28032578430366,71.32158596057289,71.36284613684214,71.40410631311136,71.44536648938059,71.48662666564982,71.50638093377478,71.52183402027089,71.537287106767,71.5527401932631,71.56819327975921,71.58364636625532,71.59909945275143,71.61455253924754,71.63000562574365,71.64545871223974,71.66091179873587,71.67636488523196,71.69181797172807,71.70727105822418,71.72272414472029,71.7381772312164,71.7536303177125,71.76908340420862,71.78453649070472,71.79998957720082,71.81544266369693,71.83203793721002,71.84977539161103,71.86751284601205,71.88525030041306,71.90298775481408,71.92072520921509,71.93846266361611,71.95620011801712,71.97393757241814,71.99167502681915,72.00941248122015,72.02714993562117,72.0448873900222,72.06262484442321,72.08036229882421,72.09809975322523,72.11583720762624,72.13357466202726,72.15131211642827,72.16904957082929,72.1867870252303,72.20452447963132,72.22226193403233,72.23999938843335,72.25773684283436,72.27547429723538,72.29321175163639,72.3109492060374,72.32868666043841,72.34642411483942,72.36416156924044,72.38189902364145,72.39963647804247,72.41737393244348,72.4351113868445,72.45284884124551,72.47058629564653,72.48832375004754,72.50606120444854,72.52379865884957,72.54153611325057,72.55927356765159,72.5770110220526,72.59474847645362,72.61248593085463,72.63022338525565,72.64796083965666,72.66569829405766,72.68343574845868,72.70117320285969,72.71891065726071,72.73664811166172,72.75438556606274,72.77212302046375,72.78986047486477,72.80759792926578,72.8253353836668,72.84307283806781,72.86081029246883,72.87854774686984,72.89628520127086,72.91402265567186,72.61344779909886,72.15371678703892,71.69398577497893,71.23425476291895,70.77452375085898,70.31479273879899,69.85506172673902,69.39533071467906,68.93559970261906,68.47586869055911,68.0161376784991,67.55640666643914,67.09667565437917,66.63694464231918,66.17721363025923,65.71748261819926,65.25775160613927,64.79802059407929,64.3382895820193,63.878558569959345,63.41882755789936,62.95909654583939,62.499365533779425,62.03963452171942,61.57990350965947,61.120172497599484,60.66044148553951,60.200710473479546,59.74097946141955,59.28124844935958,58.821517437299605,58.36178642523962,57.90205541317966,57.44232440111968,56.9825933890597,56.522862376999726,56.06313136493974,55.60340035287979,55.143669340819805,54.68393832875983,54.22420731669987,53.764476304639885,53.3047452925799,52.84501428051992,52.38528326845994,51.92555225639996,51.465821244340006,51.00609023228002,50.54635922022004,50.09519970522979,49.649754448154866,49.20430919107997,48.75886393400505,48.31341867693011,47.86797341985519,47.422528162780296,46.977082905705366,46.53163764863044,46.08619239155552,45.64074713448059,45.19530187740569,44.749856620330775,44.304411363255845,43.85896610618092,43.41352084910602,42.96807559203109,42.52263033495617,42.077185077881246,41.63173982080632,41.186294563731416,40.7408493066565,40.29540404958158,39.84995879250665,39.404513535431725,38.959068278356824,38.513623021281894,38.06817776420697,37.62273250713205,37.17728725005714,36.73184199298222,36.286396735907296,35.84095147883237,35.39550622175745,35.040552054309146,34.77608897648723,34.511625898665336,34.247162820843485,33.98765601612457,33.731122979163004,33.47458994220148,33.218056905239955,32.96152386827838,32.70499083131688,32.4484577943553,32.19192475739377,31.935391720432204,31.678858683470743,31.422325646509165,31.16579260954765,30.909259572586137,30.65272653562456,30.39619349866304,30.13966046170148,29.883127424739946,29.63320095356948,29.38571603572258,29.138231117875648,28.89074620002877,28.643261282181896,28.395776364335028,28.1482914464881,27.900806528641226,27.65332161079431,27.40583669294743,27.158351775100503,26.91086685725364,26.66338193940676,26.41589702155988,26.168511242999678,25.93103935024449,25.693567457489294,25.456095564734152,25.218623671978964,24.981151779223854,24.743679886468666,24.506207993713524,24.268736100958325,24.03126420820317,23.793792315448037,23.556320422692842,23.318848529937643,23.082101631504976,22.855021346326573,22.627941061148164,22.400860775969722,22.17378049079132,21.946700205612867,21.719619920434454,21.49253963525607,21.265459350077656,21.038379064899203,20.81129877972076,20.58421849454236,20.36265376273937,20.144686127207628,19.92671849167592,19.70875085614421,19.49078322061247,19.272815585080764,19.05484794954901,18.836880314017296,18.618912678485607,18.400945042953847,18.18648531204932,17.97780783968799,17.769130367326692,17.56045289496535,17.351775422604053,17.14309795024276,16.934420477881446,16.725743005520116,16.51706553315882,16.310762781341307,16.114148893448988,15.917535005556712,15.720921117664403,15.524307229772115,15.327693341879835,15.131079453987557,14.93446556609524,14.737851678202961,14.553206273975075,14.36974294483648,14.186279615697886,14.00281628655934,13.819352957420774,13.635889628282206,13.452426299143651,13.273703721442212,13.1023077568882,12.930911792334172,12.759515827780172,12.588119863226137,12.416723898672133,12.245327934118134,12.079899149980127,11.91949931075175,11.759099471523403,11.598699632295034,11.438299793066678,11.277899953838308,11.120256809639303,10.969899220642713,10.819541631646134,10.669184042649574,10.518826453653007,10.368468864656418,10.222849625291314,10.08165284392689,9.94045606256248,9.799259281198083,9.658062499833665,9.51863184612866,9.385811555637318,9.252991265145955,9.120170974654602,8.987350684163243,8.856910978342396,8.731912610591339,8.60691424284028,8.481915875089246,8.35691750733821,8.238792739851126,8.122908255753265,8.007023771655405,7.891139287557522,7.7804290944891195,7.674439774719541,7.568450454949946,7.462461135180348,7.360520059831785,7.261533109216512,7.1625461586012396,7.063559207985996,6.969178106369509,6.875356472795204,6.781534839220903,6.6905995563936855,6.603352387870833,6.516105219348006,6.430235270372643,6.349923386505894,6.269611502639139,6.19023098249976,6.116071746265431,6.041912510031111,5.969281497411471,5.900568073067021,5.831854648722576,5.7552933956998995,5.672846271168551,5.59039914663719,5.50795202210583,5.425504897574486,5.343057773043126,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[67.97008287976297,68.01256041877173,68.0550379577805,68.09751549678924,68.13999303579801,68.18247057480677,68.22494811381553,68.26742565282429,68.30990319183304,68.3523807308418,68.39485826985056,68.43733580885932,68.47981334786807,68.52229088687685,68.5647684258856,68.60724596489436,68.6497235039031,68.69220104291188,68.73467858192063,68.77715612092939,68.81963365993815,68.8621111989469,68.90458873795566,68.94706627696442,68.98954381597318,69.03202135498194,69.0744988939907,69.11697643299945,69.15945397200821,69.20193151101697,69.24440905002572,69.28688658903448,69.32936412804324,69.371841667052,69.41431920606075,69.45679674506951,69.49927428407827,69.54175182308703,69.58422936209578,69.62670690110454,69.6691844401133,69.71166197912206,69.75413951813081,69.79661705713957,69.83909459614833,69.8815721351571,69.92323810043843,69.96449827670764,70.00575845297688,70.04701862924612,70.08827880551536,70.12953898178459,70.17079915805382,70.21205933432304,70.25331951059229,70.29457968686151,70.33583986313076,70.37710003939998,70.41836021566921,70.45962039193844,70.50088056820768,70.54214074447692,70.58340092074614,70.62466109701538,70.66592127328462,70.70718144955384,70.74844162582308,70.78970180209231,70.83096197836154,70.87222215463078,70.91348233090001,70.95474250716924,70.99600268343849,71.03726285970771,71.07852303597694,71.11978321224618,71.16104338851541,71.20230356478464,71.24356374105388,71.28482391732311,71.32608409359234,71.36734426986158,71.40860444613081,71.44986462240004,71.469618890525,71.48507197702111,71.50052506351722,71.51597815001332,71.53143123650943,71.54688432300553,71.56233740950164,71.57779049599775,71.59324358249387,71.60869666898998,71.62414975548607,71.63960284198218,71.65505592847829,71.6705090149744,71.68596210147051,71.70141518796662,71.71686827446271,71.73232136095882,71.74777444745493,71.76322753395104,71.77868062044715,71.79413370694326,71.80958679343937,71.82503987993547,71.84049296643157,71.85594605292769,71.87139913942379,71.8868522259199,71.902305312416,71.91775839891211,71.93321148540821,71.94866457190432,71.96411765840044,71.97957074489653,71.99502383139264,72.01047691788875,72.02593000438486,72.04138309356858,72.0591205479696,72.07685800237061,72.09459545677163,72.11233291117264,72.13007036557366,72.14780781997467,72.16554527437567,72.18328272877669,72.20102018317772,72.21875763757872,72.23649509197973,72.25423254638073,72.27197000078176,72.28970745518276,72.30744490958378,72.3251823639848,72.34291981838581,72.36065727278682,72.37839472718784,72.39613218158885,72.41386963598987,72.43160709039088,72.4493445447919,72.46708199919291,72.48481945359393,72.50255690799494,72.52029436239596,72.53803181679697,72.55576927119799,72.573506725599,72.59124418,72.60898163440102,72.62671908880203,72.64445654320303,72.66219399760405,72.67993145200506,72.69766890640608,72.71540636080711,72.73314381520812,72.75088126960914,72.76861872401014,72.78635617841115,72.80409363281217,72.82183108721318,72.8395685416142,72.53899368504119,72.07926267298124,71.61953166092125,71.15980064886128,70.70006963680133,70.24033862474133,69.78060761268137,69.32087660062138,68.8611455885614,68.40141457650144,67.94168356444145,67.48195255238147,67.0222215403215,66.56249052826152,66.10275951620157,65.64302850414158,65.18329749208159,64.72356648002162,64.26383546796164,63.80410445590168,63.3443734438417,62.88464243178172,62.42491141972176,61.96518040766176,61.5054493956018,61.045718383541825,60.58598737148184,60.12625635942189,59.66652534736188,59.20679433530192,58.74706332324194,58.287332311181956,57.827601299122,57.36787028706202,56.908139275002036,56.44840826294206,55.988677250882084,55.52894623882212,55.06921522676214,54.609484214702164,54.149753202642195,53.69002219058222,53.230291178522236,52.77056016646226,52.31082915440228,51.851098142342295,51.39136713028233,50.931636118222364,50.47190510616238,50.01217409410239,49.552443082042416,49.092712069982454,48.63298105792248,48.173250045862495,47.71351903380252,47.25378802174256,46.794057009682575,46.3343259976226,45.87459498556261,45.414863973502634,44.95513296144268,44.495401949382696,44.03567093732272,43.57593992526273,43.11620891320278,42.6564779011428,42.19674688908282,41.737015877022834,41.27728486496285,40.8175538529029,40.357822840842914,39.89809182878294,39.438360816722955,38.97862980466297,38.51889879260301,38.05916778054303,37.59943676848305,37.139705756423076,36.679974744363115,36.22024373230313,35.75248198806892,35.275350977824104,34.79821996757928,34.43138794397619,34.17485490701461,33.9183218700531,33.661788833091535,33.405255796130014,33.14872275916844,32.89218972220692,32.6356566852454,32.37912364828382,32.122590611322316,31.86605757436074,31.60952453739921,31.35299150043765,31.096458463476186,30.839925426514608,30.583392389553094,30.326859352591576,30.077076502405525,29.829591584558607,29.58210666671174,29.33462174886486,29.087136831017975,28.839651913171075,28.592166995324142,28.344682077477263,28.09719715963039,27.849712241783525,27.602227323936596,27.35474240608972,27.107257488242805,26.859772570395922,26.612287652548993,26.37248599696182,26.135014104206626,25.897542211451423,25.660070318696324,25.42259842594114,25.18512653318594,24.947654640430795,24.71018274767561,24.472710854920503,24.23523896216531,23.997767069410173,23.76029517665497,23.522823283899815,23.291586354108414,23.06450606893,22.837425783751552,22.610345498573153,22.38326521339475,22.156184928216337,21.9291046430379,21.702024357859496,21.474944072681044,21.24786378750263,21.020783502324242,20.793703217145833,20.575136067503337,20.357168431971594,20.13920079643989,19.921233160908177,19.703265525376437,19.48529788984473,19.267330254313016,19.049362618781277,18.83139498324957,18.61342734771782,18.40035535904176,18.191677886680473,17.98300041431916,17.77432294195782,17.56564546959649,17.35696799723519,17.14829052487385,16.939613052512552,16.730935580151254,16.52449034503842,16.327876457146143,16.131262569253835,15.934648681361546,15.738034793469225,15.54142090557695,15.34480701768464,15.148193129792356,14.951579241900076,14.764865210410498,14.581401881271905,14.397938552133347,14.214475222994793,14.031011893856197,13.847548564717606,13.664085235579059,13.481871741712938,13.310475777158901,13.139079812604924,12.9676838480509,12.796287883496888,12.624891918942861,12.45349595438886,12.283563637690383,12.123163798462038,11.96276395923367,11.802364120005311,11.641964280776934,11.481564441548587,11.32116460232022,11.168345676350249,11.01798808735367,10.867630498357132,10.717272909360542,10.566915320363963,10.416557731367403,10.274413281119168,10.133216499754743,9.992019718390353,9.850822937025926,9.709626155661521,9.572592389406294,9.43977209891495,9.30695180842358,9.174131517932235,9.041311227440875,8.91243590615909,8.787437538408053,8.66243917065702,8.53744080290596,8.412442435154903,8.295412352032358,8.179527867934482,8.063643383836613,7.947758899738753,7.837502123908085,7.731512804138488,7.625523484368911,7.519534164599333,7.417428971219352,7.31844202060409,7.219455069988843,7.12046811937357,7.025631637153568,6.931810003579267,6.837988370004968,6.746074935064487,6.658827766541652,6.571580598018815,6.484333429495963,6.403972359110929,6.323660475244177,6.243348591377428,6.168526110647411,6.094366874413099,6.02020763817877,5.951336540231061,5.882623115886627,5.810966755787849,5.728519631256489,5.646072506725136,5.563625382193785,5.481178257662426,5.398731133131065,5.316284008599721,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[67.95340732191622,67.99588486092497,68.03836239993373,68.08083993894249,68.12331747795125,68.16579501696,68.20827255596876,68.25075009497752,68.29322763398628,68.33570517299503,68.3781827120038,68.42066025101255,68.4631377900213,68.50561532903008,68.54809286803884,68.5905704070476,68.63304794605634,68.67552548506511,68.71800302407387,68.76048056308262,68.80295810209138,68.84543564110014,68.8879131801089,68.93039071911765,68.97286825812641,69.01534579713517,69.05782333614393,69.10030087515268,69.14277841416144,69.18505306061168,69.22631323688091,69.26757341315015,69.30883358941938,69.35009376568861,69.39135394195785,69.43261411822706,69.4738742944963,69.51513447076553,69.55639464703476,69.597654823304,69.63891499957323,69.68017517584246,69.7214353521117,69.76269552838093,69.80395570465016,69.8452158809194,69.88647605718863,69.92773623345786,69.96899640972708,70.01025658599633,70.05151676226555,70.0927769385348,70.13403711480403,70.17529729107326,70.2165574673425,70.25781764361173,70.29907781988096,70.34033799615018,70.38159817241942,70.42285834868866,70.46411852495788,70.50537870122713,70.54663887749636,70.58789905376558,70.62915923003482,70.67041940630406,70.71167958257328,70.75293975884253,70.79419993511175,70.835460111381,70.87672028765022,70.91798046391946,70.95924064018868,71.00050081645793,71.04176099272715,71.08302116899638,71.12428134526562,71.16554152153485,71.20680169780408,71.24806187407331,71.28932205034255,71.33058222661178,71.37184240288101,71.41310257915025,71.43285684727522,71.44830993377131,71.46376302026742,71.47921610676353,71.49466919325964,71.51012227975575,71.52557536625186,71.54102845274797,71.55648153924406,71.57193462574017,71.58738771223628,71.60284079873239,71.6182938852285,71.6337469717246,71.64920005822071,71.66465314471682,71.68010623121293,71.69555931770904,71.71101240420515,71.72646549070126,71.74191857719737,71.75737166369348,71.77282475018959,71.78827783668568,71.80373092318179,71.8191840096779,71.834637096174,71.85009018267012,71.86554326916622,71.88099635566232,71.89644944215843,71.91190252865454,71.92735561515065,71.94280870164675,71.95826178814286,71.97371487463897,71.98916796113507,72.00462104763118,72.02007413412728,72.0355272206234,72.0509803071195,72.06643339361561,72.08188648011172,72.09733956660783,72.11279265310394,72.12824573960005,72.14369882609614,72.15915191259225,72.17460499908836,72.19005808558447,72.20551117208058,72.22096425857669,72.2364173450728,72.2518704315689,72.26846570432815,72.28620315872917,72.30394061313018,72.3216780675312,72.33941552193221,72.35715297633323,72.37489043073424,72.39262788513525,72.41036533953627,72.42810279393728,72.44584024833829,72.4635777027393,72.48131515714032,72.49905261154133,72.51679006594235,72.53452752034336,72.55226497474438,72.57000242914539,72.5877398835464,72.60547733794742,72.62321479234842,72.64095224674944,72.65868970115045,72.67642715555147,72.69416460995248,72.7119020643535,72.72963951875451,72.74737697315553,72.76511442755654,72.46453957098355,72.00480855892357,71.5450775468636,71.08534653480362,70.62561552274366,70.16588451068367,69.70615349862369,69.24642248656372,68.78669147450373,68.32696046244378,67.86722945038377,67.40749843832381,66.94776742626384,66.48803641420385,66.0283054021439,65.56857439008391,65.10884337802393,64.64911236596396,64.18938135390398,63.72965034184402,63.26991932978404,62.810188317724055,62.3504573056641,61.89072629360409,61.43099528154414,60.97126426948415,60.511533257424176,60.051802245364215,59.59207123330421,59.13234022124426,58.67260920918427,58.21287819712429,57.75314718506433,57.29341617300435,56.83368516094438,56.37395414888439,55.91422313682442,55.45449212476446,54.99476111270448,54.5350301006445,54.075299088584536,53.61556807652455,53.15583706446458,52.69610605240459,52.23637504034461,51.776644028284636,51.316913016224674,50.8571820041647,50.39745099210471,49.93771998004473,49.47798896798475,49.00688106517402,48.52975005492921,48.05261904468438,47.575488034439566,47.09835702419477,46.621226013949936,46.144095003705125,45.6669639934603,45.18983298321548,44.712701972970684,44.235570962725866,43.75843995248104,43.28130894223622,42.80417793199143,42.3270469217466,41.84991591150179,41.37278490125696,40.895653891012145,40.41852288076735,39.94139187052253,39.464260860277705,38.987129850032886,38.50999883978806,38.03286782954327,37.555736819298446,37.07860580905363,36.60147479880881,36.12434378856401,35.64721277831919,35.17008176807437,34.69295075782955,34.215819747584725,33.84898772398164,33.59245468702006,33.335921650058545,33.07938861309698,32.82285557613546,32.56632253917389,32.30978950221237,32.05325646525085,31.796723428289265,31.540190391327766,31.283657354366184,31.027124317404656,30.770591280443096,30.520952051241625,30.273467133394693,30.025982215547778,29.77849729770091,29.531012379854026,29.283527462007108,29.03604254416024,28.78855762631336,28.541072708466476,28.293587790619572,28.046102872772643,27.79861795492576,27.55113303707889,27.303648119232022,27.05616320138509,26.8139326436791,26.57646075092391,26.33898885816876,26.1015169654136,25.86404507265847,25.626573179903275,25.389101287148073,25.151629394392973,24.91415750163779,24.676685608882593,24.439213716127448,24.201741823372263,23.964269930617153,23.72815136189029,23.501071076711888,23.27399079153344,23.046910506355026,22.819830221176595,22.59274993599818,22.365669650819733,22.138589365641334,21.91150908046293,21.684428795284518,21.457348510106076,21.230268224927674,21.005586007799064,20.78761837226731,20.569650736735614,20.351683101203864,20.13371546567215,19.91574783014041,19.697780194608704,19.47981255907699,19.26184492354525,19.043877288013544,18.82590965248183,18.614225406034212,18.40554793367291,18.1968704613116,17.98819298895026,17.779515516588972,17.570838044227663,17.362160571866323,17.153483099504992,16.944805627143694,16.738217908735535,16.54160402084326,16.344990132950983,16.14837624505866,15.951762357166386,15.75514846927408,15.55853458138179,15.36192069348947,15.165306805597194,14.976524146845925,14.793060817707332,14.609597488568774,14.42613415943022,14.242670830291626,14.05920750115307,13.875744172014517,13.692280842875922,13.518643797429654,13.347247832875642,13.175851868321628,13.00445590376759,12.833059939213616,12.66166397465959,12.490268010105579,12.326828286172296,12.166428446943948,12.006028607715571,11.845628768487224,11.685228929258855,11.524829090030499,11.366792132057787,11.21643454306121,11.066076954064672,10.91571936506808,10.765361776071503,10.615004187074964,10.467173718311432,10.325976936947033,10.184780155582615,10.043583374218208,9.902386592853782,9.761189811489393,9.626552932683927,9.493732642192558,9.360912351701213,9.22809206120987,9.0952717707185,8.967960833975804,8.842962466224769,8.717964098473711,8.592965730722675,8.467967362971642,8.35203196421359,8.236147480115706,8.120262996017845,8.00437851191997,7.8945751533270325,7.788585833557455,7.682596513787877,7.57660719401828,7.47433788260694,7.375350931991685,7.276363981376412,7.17737703076115,7.082085167937651,6.988263534363345,6.894441900789028,6.801550313735308,6.714303145212471,6.6270559766896175,6.539808808166782,6.458021331715962,6.377709447849214,6.297397563982463,6.220980475029393,6.14682123879508,6.072662002560751,6.0021050073951265,5.933391583050673,5.864678158706219,5.784192991344435,5.701745866813084,5.619298742281725,5.536851617750371,5.454404493219021,5.371957368687662,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[67.93673176406946,67.97920930307822,68.02168684208698,68.06416438109574,68.1066419201045,68.14911945911325,68.19159699812201,68.23407453713077,68.27655207613952,68.31902961514828,68.36150715415704,68.4039846931658,68.44646223217455,68.48812819705414,68.52938837332339,68.5706485495926,68.61190872586185,68.65316890213109,68.69442907840032,68.73568925466955,68.77694943093879,68.81820960720802,68.85946978347725,68.90072995974649,68.94199013601572,68.98325031228495,69.02451048855417,69.06577066482342,69.10703084109265,69.14829101736188,69.18955119363112,69.23081136990035,69.27207154616957,69.31333172243882,69.35459189870805,69.39585207497727,69.43711225124652,69.47837242751574,69.51963260378497,69.5608927800542,69.60215295632344,69.64341313259267,69.6846733088619,69.72593348513114,69.76719366140037,69.80845383766959,69.84971401393884,69.89097419020807,69.9322343664773,69.97349454274655,70.01475471901577,70.05601489528502,70.09727507155424,70.13853524782346,70.1797954240927,70.22105560036192,70.26231577663117,70.30357595290039,70.34483612916964,70.38609630543887,70.4273564817081,70.46861665797734,70.50987683424657,70.55113701051579,70.59239718678504,70.63365736305427,70.6749175393235,70.71617771559274,70.75743789186197,70.7986980681312,70.83995824440044,70.88121842066967,70.9224785969389,70.96373877320812,71.00499894947737,71.04625912574659,71.08751930201583,71.12877947828505,71.1700396545543,71.21129983082352,71.25256000709275,71.29382018336199,71.33508035963122,71.37634053590045,71.39609480402542,71.41154789052152,71.42700097701763,71.44245406351374,71.45790715000985,71.47336023650595,71.48881332300206,71.50426640949817,71.51971949599428,71.53517258249038,71.5506256689865,71.5660787554826,71.58153184197872,71.59698492847481,71.61243801497093,71.62789110146704,71.64334418796314,71.65879727445925,71.67425036095536,71.68970344745146,71.70515653394756,71.72060962044367,71.73606270693978,71.75151579343589,71.766968879932,71.7824219664281,71.79787505292421,71.81332813942032,71.82878122591643,71.84423431241254,71.85968739890865,71.87514048540476,71.89059357190085,71.90604665839696,71.92149974489307,71.93695283138918,71.95240591788529,71.9678590043814,71.98331209087749,71.9987651773736,72.01421826386971,72.02967135036582,72.04512443686193,72.06057752335803,72.07603060985414,72.09148369635025,72.10693678284636,72.12238986934247,72.13784295583858,72.15329604233469,72.1687491288308,72.18420221532689,72.199655301823,72.21510838831911,72.23056147481522,72.24601456131133,72.26146764780744,72.27692073430354,72.29237382079965,72.30782690729575,72.32327999379187,72.33873308028797,72.35418616678407,72.36963925328018,72.38509233977629,72.4005454262724,72.41599851276851,72.43145159926462,72.44690468576073,72.46235777225682,72.4778108606867,72.49554831508772,72.51328576948873,72.53102322388975,72.54876067829076,72.56649813269178,72.58423558709279,72.6019730414938,72.61971049589482,72.63744795029584,72.65518540469685,72.67292285909785,72.69066031349887,72.39008545692586,71.93035444486591,71.47062343280592,71.01089242074595,70.55116140868599,70.091430396626,69.63169938456603,69.17196837250606,68.71223736044607,68.2525063483861,67.79277533632612,67.33304432426614,66.87331331220616,66.41358230014619,65.95385128808623,65.49412027602625,65.03438926396628,64.57465825190629,64.11492723984631,63.65519622778634,63.19546521572637,62.73573420366638,62.261280142279105,61.784149132034266,61.30701812178946,60.829887111544636,60.35275610129982,59.87562509105502,59.39849408081018,58.92136307056538,58.444232060320566,57.96710105007573,57.48997003983094,57.012839029586125,56.5357080193413,56.05857700909648,55.581445998851656,55.10431498860686,54.62718397836204,54.15005296811722,53.672921957872425,53.19579094762761,52.71865993738278,52.24152892713796,51.764397916893145,51.28726690664832,50.81013589640352,50.333004886158704,49.85587387591388,49.37874286566906,48.90161185542424,48.42448084517944,47.94734983493463,47.4702188246898,46.99308781444498,46.51595680420019,46.03882579395536,45.56169478371055,45.08456377346572,44.60743276322091,44.1303017529761,43.65317074273129,43.17603973248647,42.69890872224164,42.22177771199685,41.74464670175203,41.26751569150721,40.79038468126238,40.31325367101756,39.836122660772766,39.35899165052794,38.88186064028312,38.404729630038304,37.927598619793486,37.45046760954869,36.97333659930387,36.496205589059045,36.01907457881423,35.54194356856943,35.06481255832461,34.587681548079786,34.11055053783497,33.63341952759015,33.266587503987054,33.010054467025476,32.75352143006396,32.4969883931024,32.24045535614088,31.983922319179307,31.727389282217793,31.47085624525626,31.214323208294683,30.964827600077655,30.717342682230726,30.46985776438384,30.222372846536974,29.9748879286901,29.72740301084317,29.479918092996254,29.23243317514939,28.984948257302502,28.737463339455584,28.489978421608715,28.242493503761835,27.995008585914952,27.747523668068048,27.50003875022112,27.255379290396355,27.017907397641217,26.78043550488603,26.54296361213087,26.30549171937573,26.068019826620542,25.83054793386539,25.593076041110233,25.355604148355102,25.118132255599907,24.880660362844708,24.643188470089605,24.40571657733442,24.168244684579225,23.9376360844937,23.71055579931526,23.48347551413685,23.25639522895845,23.029314943780047,22.802234658601595,22.575154373423185,22.348074088244758,22.12099380306634,21.89391351788789,21.666833232709493,21.43975294753109,21.218068312563016,21.000100677031277,20.782133041499574,20.564165405967856,20.346197770436106,20.12823013490441,19.91026249937266,19.692294863840946,19.474327228309207,19.2563595927775,19.038391957245786,18.828095453026634,18.619417980665332,18.410740508303995,18.202063035942697,17.9933855635814,17.78470809122009,17.576030618858745,17.367353146497464,17.158675674136152,16.95194547243264,16.75533158454036,16.558717696648085,16.362103808755766,16.16548992086349,15.968876032971211,15.772262145078892,15.575648257186616,15.379034369294308,15.18818308328131,15.004719754142771,14.821256425004186,14.63779309586563,14.454329766727037,14.27086643758848,14.087403108449925,13.903939779311331,13.72681181770036,13.555415853146384,13.384019888592347,13.212623924038333,13.04122795948432,12.869831994930307,12.69843603037627,12.53049277388252,12.370092934654172,12.20969309542582,12.049293256197473,11.888893416969125,11.728493577740748,11.5680937385124,11.414880998768744,11.264523409772197,11.114165820775609,10.963808231779028,10.813450642782492,10.6630930537859,10.518737374139286,10.37754059277487,10.236343811410462,10.095147030046064,9.953950248681647,9.813333766452876,9.680513475961524,9.547693185470187,9.414872894978837,9.282052604487466,9.149232313996123,9.02348576179251,8.898487394041453,8.773489026290418,8.648490658539384,8.524536060492672,8.408651576394812,8.292767092296938,8.176882608199069,8.060998124101184,7.951648182745993,7.8456588629764035,7.739669543206819,7.633680223437242,7.53124679399451,7.4322598433792475,7.333272892763993,7.234285942148739,7.138538698721715,7.044717065147409,6.950895431573105,6.857073797998799,6.769778523883279,6.682531355360433,6.5952841868375955,6.512070304320986,6.431758420454235,6.351446536587492,6.273434839411369,6.199275603177053,6.125116366942729,6.052873474559171,5.984160050214717,5.915446625870281,5.839866351432382,5.75741922690102,5.674972102369667,5.592524977838316,5.5100778533069565,5.427630728775602,5.345183604244253,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[67.9174595126874,67.95735643373892,67.99725335479044,68.03715027584195,68.07704719689347,68.11808016488887,68.1593403411581,68.20060051742733,68.24186069369657,68.2831208699658,68.32438104623502,68.36564122250425,68.40690139877348,68.44816157504272,68.48942175131195,68.53068192758118,68.57194210385042,68.61320228011965,68.65446245638888,68.69572263265812,68.73698280892735,68.77824298519658,68.81950316146582,68.86076333773505,68.90202351400428,68.94328369027352,68.98454386654275,69.02580404281198,69.06706421908122,69.10832439535045,69.14958457161968,69.19084474788892,69.23210492415815,69.27336510042738,69.31462527669662,69.35588545296585,69.39714562923508,69.43840580550432,69.47966598177354,69.52092615804278,69.562186334312,69.60344651058125,69.64470668685047,69.68596686311972,69.72722703938894,69.76848721565817,69.8097473919274,69.85100756819664,69.89226774446587,69.93352792073512,69.97478809700434,70.01604827327358,70.0573084495428,70.09856862581202,70.13982880208127,70.1810889783505,70.22234915461974,70.26360933088897,70.30486950715819,70.34612968342743,70.38738985969667,70.4286500359659,70.46991021223513,70.51117038850435,70.5524305647736,70.59369074104283,70.63495091731207,70.6762110935813,70.71747126985053,70.75873144611977,70.799991622389,70.84125179865822,70.88251197492747,70.9237721511967,70.96503232746593,71.00629250373517,71.04755268000439,71.08881285627362,71.13007303254285,71.17133320881209,71.21259338508132,71.25385356135057,71.2951137376198,71.33637391388903,71.35407967466394,71.36707455233997,71.38006943001602,71.39306430769206,71.40769799292346,71.42315107941957,71.43860416591568,71.45405725241179,71.4695103389079,71.484963425404,71.50041651190011,71.51586959839621,71.53132268489233,71.54677577138843,71.56222885788455,71.57768194438064,71.59313503087675,71.60858811737286,71.62404120386897,71.63949429036508,71.65494737686117,71.6704004633573,71.68585354985339,71.70130663634951,71.71675972284561,71.73221280934172,71.74766589583783,71.76311898233394,71.77857206883004,71.79402515532615,71.80947824182226,71.82493132831837,71.84038441481447,71.85583750131057,71.8712905878067,71.88674367430279,71.9021967607989,71.917649847295,71.9331029337911,71.94855602028723,71.96400910678332,71.97946219327943,71.99491527977554,72.01036836627165,72.02582145276776,72.04127453926387,72.05672762575998,72.07218071225608,72.0876337987522,72.1030868852483,72.11853997174441,72.1339930582405,72.14944614473661,72.16489923123272,72.18035231772883,72.19580540422494,72.21125849072105,72.22671157721716,72.24216466371327,72.25761775020936,72.27307083670547,72.28852392320158,72.30397700969769,72.3194300961938,72.33488318268991,72.35033626918602,72.36578935568213,72.38124244217823,72.39669552867434,72.41214861517044,72.42760170166656,72.44305478816266,72.45850787465876,72.47396096115487,72.48941404765098,72.50486713414709,72.5203202206432,72.5357733071393,72.55122639363542,72.56667948013151,72.58213256662762,72.59758565312373,72.61303873961984,72.29448008467358,71.80891555900618,71.32335103333877,70.83778650767138,70.35222198200398,69.86665745633654,69.38109293066915,68.89552840500174,68.40996387933433,67.92439935366693,67.4388348279995,66.9532703023321,66.46770577666469,65.98214125099727,65.49657672532989,65.01879699399825,64.54166598375342,64.0645349735086,63.58740396326378,63.11027295301898,62.63314194277416,62.15601093252934,61.678879922284544,61.201748912039704,60.72461790179491,60.24748689155008,59.770355881305264,59.29322487106047,58.81609386081563,58.33896285057082,57.861831840326,57.38470083008118,56.90756981983639,56.430438809591564,55.953307799346746,55.47617678910193,54.9990457788571,54.521914768612305,54.04478375836749,53.56765274812266,53.090521737877864,52.613390727633046,52.13625971738823,51.65912870714341,51.18199769689859,50.704866686653766,50.22773567640897,49.75060466616415,49.273473655919325,48.79634264567451,48.31921163542969,47.842080625184884,47.36494961494007,46.88781860469525,46.41068759445043,45.93355658420563,45.45642557396081,44.979294563715996,44.50216355347116,44.025032543226345,43.54790153298155,43.07077052273673,42.59363951249191,42.116508502247086,41.639377492002296,41.16224648175747,40.68511547151265,40.20798446126783,39.73085345102301,39.25372244077821,38.776591430533394,38.29946042028857,37.82232941004375,37.34519839979893,36.86806738955413,36.39093637930931,35.91380536906449,35.43667435881967,34.959543348574876,34.48241233833005,34.00528132808523,33.528150317840414,33.051019307595595,32.6841872839925,32.42765424703092,32.17112121006941,31.914588173107845,31.658055136146316,31.40870314891369,31.161218231066822,30.91373331321994,30.66624839537296,30.418763477526156,30.171278559679223,29.923793641832336,29.67630872398547,29.428823806138602,29.18133888829167,28.933853970444755,28.686369052597886,28.438884134751,28.191399216904085,27.943914299057216,27.69682593711369,27.45935404435849,27.221882151603364,26.984410258848207,26.746938366093005,26.509466473337866,26.271994580582682,26.034522687827522,25.79705079507238,25.559578902317195,25.322107009562043,25.084635116806883,24.84716322405175,24.609691331296556,24.374201092275577,24.147120807097135,23.920040521918736,23.692960236740284,23.465879951561885,23.238799666383443,23.01171938120503,22.78463909602663,22.557558810848228,22.33047852566978,22.103398240491366,21.876317955312935,21.64923767013452,21.43055061732699,21.212582981795247,20.994615346263544,20.77664771073183,20.558680075200087,20.340712439668383,20.12274480413667,19.90477716860492,19.686809533073223,19.468841897541473,19.25087426200976,19.041965500019074,18.833288027657773,18.62461055529643,18.415933082935137,18.20725561057384,17.998578138212494,17.7899006658512,17.581223193489897,17.372545721128592,17.165673036129757,16.96905914823749,16.772445260345172,16.575831372452885,16.379217484560606,16.182603596668326,15.985989708776007,15.789375820883732,15.592761932991454,15.399842019716766,15.21637869057818,15.032915361439628,14.849452032301032,14.66598870316249,14.482525374023908,14.299062044885353,14.11559871574676,13.934979837971113,13.76358387341709,13.592187908863076,13.42079194430905,13.249395979755075,13.078000015201036,12.906604050647026,12.73520808609301,12.573757422364432,12.413357583136076,12.252957743907707,12.09255790467936,11.932158065451006,11.77175822622266,11.613327454476282,11.462969865479735,11.312612276483156,11.162254687486575,11.011897098490028,10.86153950949344,10.71149781133155,10.570301029967151,10.429104248602725,10.287907467238327,10.14671068587391,10.005513904509504,9.867294309730509,9.734474019239165,9.601653728747795,9.468833438256443,9.336013147765108,9.20400905736026,9.079010689609204,8.954012321858169,8.829013954107134,8.704015586356075,8.581155672673903,8.465271188576043,8.34938670447816,8.2335022203803,8.117617736282424,8.00872121216496,7.902731892395376,7.796742572625785,7.6907532528561955,7.588155705382089,7.489168754766835,7.390181804151569,7.291194853536307,7.194992229505791,7.1011705959314915,7.007348962357175,6.913527328782869,6.8252539025541035,6.738006734031251,6.650759565508409,6.5661192769260115,6.485807393059269,6.405495509192519,6.325889203793354,6.251729967559038,6.177570731324709,6.103641941723216,6.034928517378775,5.966215093034329,5.895539711520321,5.813092586988976,5.730645462457616,5.648198337926256,5.565751213394902,5.483304088863552,5.400856964332192,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[67.89050104665614,67.93039796770766,67.97029488875918,68.01019180981069,68.05008873086223,68.08998565191374,68.12988257296526,68.16977949401678,68.20967641506829,68.24957333611981,68.28947025717133,68.32936717822285,68.36926409927437,68.40916102032588,68.4490579413774,68.48895486242893,68.52885178348043,68.56874870453196,68.60864562558348,68.648542546635,68.68843946768652,68.7287908078481,68.77005098411733,68.81131116038657,68.8525713366558,68.89383151292503,68.93509168919427,68.9763518654635,69.01761204173273,69.05887221800197,69.1001323942712,69.14139257054043,69.18265274680967,69.2239129230789,69.26517309934813,69.30643327561737,69.3476934518866,69.38895362815582,69.43021380442505,69.47147398069428,69.51273415696352,69.55399433323275,69.59525450950198,69.63651468577123,69.67777486204045,69.7190350383097,69.76029521457892,69.80155539084816,69.84281556711738,69.88407574338662,69.92533591965585,69.96659609592508,70.00785627219432,70.04911644846356,70.09037662473278,70.13163680100203,70.17289697727125,70.21415715354048,70.25541732980972,70.29667750607895,70.33793768234818,70.37919785861742,70.42045803488665,70.46171821115588,70.50297838742512,70.54423856369435,70.58549873996358,70.62675891623282,70.66801909250205,70.70927926877128,70.75053944504052,70.79179962130975,70.83305979757898,70.8743199738482,70.91558015011745,70.95684032638668,70.99810050265592,71.03936067892514,71.08062085519438,71.1218810314636,71.16314120773285,71.20440138400207,71.2456615602713,71.28692173654053,71.30462749731544,71.31762237499149,71.33061725266752,71.34361213034357,71.35660700801961,71.36960188569566,71.3825967633717,71.39559164104774,71.40858651872378,71.42158139639983,71.43457627407588,71.44757115175192,71.46056602942797,71.473560907104,71.48655578478005,71.49955066245609,71.51254554013214,71.52554041780817,71.53853529548422,71.55153017316026,71.56493475357604,71.58038784007215,71.59584092656826,71.61129401306437,71.62674709956048,71.64220018605657,71.65765327255268,71.67310635904879,71.6885594455449,71.704012532041,71.7194656185371,71.73491870503321,71.75037179152932,71.76582487802544,71.78127796452155,71.79673105101764,71.81218413751375,71.82763722400986,71.84309031050597,71.85854339700208,71.87399648349819,71.8894495699943,71.9049026564904,71.92035574298652,71.93580882948262,71.95126191597872,71.96671500247484,71.98216808897094,71.99762117546705,72.01307426196315,72.02852734845926,72.04398043495537,72.05943352145147,72.07488660794758,72.09033969444368,72.1057927809398,72.1212458674359,72.13669895393201,72.15215204042812,72.16760512692423,72.18305821342034,72.19851129991645,72.21396438641254,72.22941747290865,72.24487055940476,72.26032364590087,72.27577673239698,72.29122981889309,72.3066829053892,72.32213599188529,72.33758907838141,72.35304216487751,72.36849525137362,72.38394833786973,72.39940142436583,72.41485451086194,72.43030759735805,72.44576068385416,72.46121377035027,72.47666685684638,72.49211994334247,72.50757302983858,72.52302611633469,72.20446746138843,71.71890293572103,71.23333841005362,70.74777388438622,70.26220935871883,69.77664483305139,69.291080307384,68.8055157817166,68.31995125604918,67.83438673038178,67.34882220471435,66.86325767904695,66.37769315337954,65.89212862771213,65.40656410204474,64.92099957637733,64.4354350507099,63.9498705250425,63.464305999375085,62.978741473707686,62.49317694804028,62.00761242237286,61.52204789670547,61.03648337103804,60.550918845370646,60.06535431970323,59.57978979403582,59.09422526836843,58.608660742701,58.1230962170336,57.63753169136619,57.151967165698764,56.66640264003138,56.180838114363965,55.69527358869655,55.209709063029145,54.72414453736173,54.23858001169434,53.753015486026925,53.26745096035951,52.781886434692126,52.29632190902471,51.8107573833573,51.32519285768987,50.83962833202247,50.35406380635505,49.86849928068766,49.382934755020244,48.89737022935284,48.41180570368542,47.92624117801801,47.44067665235062,46.955112126683204,46.46954760101579,45.98398307534838,45.498418549680984,45.01285402401356,44.527289498346164,44.04172497267875,43.55616044701133,43.07059592134394,42.58503139567652,42.09946687000911,41.613902344341696,41.12833781867431,40.6427732930069,40.157208767339476,39.67164424167206,39.18607971600465,38.70051519033726,38.21495066466985,37.729386139002436,37.24382161333502,36.76279817980437,36.285667169559574,35.808536159314755,35.33140514906994,34.85427413882512,34.377143128580315,33.900012118335496,33.42288110809068,32.94575009784586,32.468619087601034,32.101787063997946,31.852578697749728,31.60509377990286,31.35760886205599,31.110123944209054,30.86263902636219,30.615154108515316,30.367669190668433,30.120184272821458,29.872699354974653,29.62521443712772,29.377729519280837,29.13024460143397,28.8827596835871,28.635274765740167,28.387789847893252,28.140304930046383,27.90080069107578,27.66332879832068,27.425856905565496,27.18838501281034,26.950913120055144,26.713441227300013,26.47596933454486,26.238497441789654,26.001025549034516,25.76355365627933,25.52608176352417,25.28860987076903,25.051137978013845,24.813666085258692,24.583685814878972,24.35660552970058,24.129525244522128,23.90244495934376,23.675364674165316,23.448284388986913,23.221204103808464,22.99412381863006,22.76704353345162,22.53996324827321,22.31288296309481,22.08580267791641,21.861000557622717,21.643032922090956,21.425065286559235,21.207097651027517,20.989130015495803,20.77116237996406,20.553194744432357,20.335227108900643,20.117259473368904,19.899291837837197,19.681324202305483,19.464513019372845,19.255835547011557,19.04715807465025,18.838480602288872,18.629803129927573,18.42112565756628,18.212448185204934,18.003770712843636,17.795093240482338,17.586415768120997,17.379400599826884,17.18278671193461,16.98617282404229,16.78955893615,16.592945048257736,16.396331160365413,16.199717272473126,16.003103384580847,15.806489496688572,15.611500956152192,15.428037627013637,15.244574297875053,15.061110968736488,14.877647639597903,14.694184310459349,14.510720981320754,14.327257652182215,14.14379432304363,13.971751893687843,13.800355929133808,13.628959964579805,13.45756400002578,13.286168035471766,13.114772070917741,12.943376106363765,12.777421910074713,12.617022070846334,12.456622231617999,12.29622239238962,12.135822553161262,11.975422713932895,11.815022874704548,11.661416321187273,11.511058732190694,11.360701143194115,11.210343554197566,11.059985965200989,10.909628376204408,10.763061467159414,10.62186468579499,10.48066790443059,10.339471123066192,10.198274341701765,10.057077560337367,9.921254853008142,9.788434562516771,9.655614272025426,9.522793981534083,9.389973691042712,9.259533985176953,9.134535617425927,9.009537249674882,8.884538881923826,8.759540514172791,8.637775284855135,8.521890800757237,8.40600631665939,8.29012183256153,8.174237348463645,8.065794241583916,7.959804921814337,7.853815602044753,7.747826282275169,7.645064616769675,7.546077666154421,7.447090715539149,7.348103764923895,7.251445760289867,7.157624126715561,7.063802493141251,6.9699808595669515,6.880729281224906,6.793482112702064,6.706234944179234,6.620168249531044,6.5398563656642885,6.459544481797545,6.379232597930803,6.304184331941011,6.230025095706694,6.155865859472378,6.085696984542816,6.0169835601983745,5.948270135853933,5.8687659470769145,5.786318822545557,5.703871698014211,5.6214245734828525,5.538977448951491,5.456530324420138,5.374083199888787,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[67.86354258062488,67.9034395016764,67.94333642272792,67.98323334377943,68.02313026483097,68.06302718588248,68.102924106934,68.14282102798552,68.18271794903703,68.22261487008856,68.26251179114007,68.30240871219159,68.34230563324311,68.38220255429462,68.42209947534616,68.46199639639767,68.50189331744917,68.54179023850071,68.58168715955222,68.62158408060374,68.66148100165526,68.70137792270678,68.74127484375829,68.78117176480981,68.82106868586133,68.86096560691286,68.90086252796438,68.94075944901589,68.98065637006741,69.02055329111893,69.06045021217045,69.10034713322197,69.14024405427348,69.180140975325,69.22003789637652,69.25993481742805,69.29983173847957,69.33972865953108,69.38076162707657,69.4220218033458,69.46328197961503,69.50454215588428,69.5458023321535,69.58706250842275,69.62832268469197,69.6695828609612,69.71084303723043,69.75210321349968,69.7933633897689,69.83462356603813,69.87588374230737,69.9171439185766,69.95840409484583,69.99966427111507,70.0409244473843,70.08218462365355,70.12344479992277,70.164704976192,70.20596515246123,70.24722532873047,70.2884855049997,70.32974568126893,70.37100585753817,70.4122660338074,70.45352621007663,70.49478638634587,70.5360465626151,70.57730673888433,70.61856691515356,70.6598270914228,70.70108726769203,70.74234744396125,70.7836076202305,70.82486779649972,70.86612797276896,70.90738814903818,70.94864832530743,70.98990850157665,71.0311686778459,71.07242885411512,71.11368903038436,71.15494920665358,71.19620938292283,71.23746955919205,71.25517531996697,71.268170197643,71.28116507531905,71.29415995299509,71.30715483067114,71.32014970834717,71.33314458602322,71.34613946369926,71.35913434137531,71.37212921905135,71.3851240967274,71.39811897440345,71.41111385207948,71.42410872975552,71.43710360743157,71.45009848510762,71.46309336278365,71.47608824045969,71.48908311813574,71.50207799581179,71.51507287348782,71.52806775116386,71.54106262883991,71.55405750651595,71.567052384192,71.58004726186803,71.59304213954408,71.60603701722013,71.61903189489617,71.6320267725722,71.64502165024825,71.6580165279243,71.67101140560034,71.68400628327637,71.69700116095242,71.70999603862847,71.72299091630451,71.7376246007247,71.75307768722081,71.76853077371693,71.78398386021303,71.79943694670914,71.81489003320524,71.83034311970135,71.84579620619746,71.86124929269357,71.87670237918968,71.89215546568579,71.90760855218188,71.92306163867799,71.9385147251741,71.95396781167021,71.96942089816632,71.98487398466243,72.00032707115854,72.01578015765465,72.03123324415074,72.04668633064685,72.06213941714296,72.07759250363907,72.09304559013518,72.10849867663129,72.1239517631274,72.1394048496235,72.15485793611961,72.17031102261572,72.18576410911183,72.20121719560794,72.21667028210403,72.23212336860014,72.24757645509625,72.26302954159236,72.27848262808847,72.29393571458456,72.30938880108069,72.3248418875768,72.3402949740729,72.35574806056901,72.37120114706512,72.38665423356122,72.40210732005733,72.41756040655343,72.43301349304954,72.11445483810328,71.6288903124359,71.14332578676847,70.65776126110107,70.17219673543369,69.68663220976623,69.20106768409885,68.71550315843145,68.22993863276403,67.74437410709663,67.2588095814292,66.7732450557618,66.28768053009439,65.80211600442698,65.31655147875958,64.83098695309216,64.34542242742477,63.85985790175735,63.37429337608993,62.88872885042254,62.40316432475513,61.91759979908771,61.432035273420325,60.94647074775288,60.4609062220855,59.975341696418084,59.48977717075067,59.00421264508328,58.51864811941584,58.03308359374845,57.54751906808104,57.06195454241363,56.57639001674623,56.09082549107882,55.605260965411404,55.119696439744,54.634131914076576,54.14856738840919,53.66300286274178,53.17743833707436,52.69187381140697,52.206309285739565,51.72074476007215,51.23518023440472,50.749615708737316,50.26405118306991,49.77848665740251,49.2929221317351,48.80735760606768,48.32179308040027,47.836228554732855,47.35066402906547,46.865099503398056,46.379534977730636,45.89397045206323,45.40840592639583,44.922841400728416,44.437276875061016,43.951712349393596,43.46614782372618,42.98058329805879,42.495018772391376,42.00945424672396,41.52388972105655,41.02750971617077,40.522116864051725,40.01672401193269,39.51133115981365,39.005938307694606,38.50054545557559,37.995152603456546,37.48975975133751,36.98436689921847,36.478974047099435,35.97358119498041,35.46818834286138,34.96279549074234,34.45740263862329,33.952009786504284,33.44661693438524,32.9412240822662,32.435831230147166,31.93043837802812,31.553999493045197,31.306514575198218,31.059029657351353,30.811544739504487,30.564059821657548,30.316574903810682,30.06908998596381,29.821605068116927,29.574120150269955,29.326635232423147,29.079150314576218,28.83166539672933,28.584180478882462,28.342247337793115,28.104775445037955,27.867303552282813,27.62983165952763,27.392359766772422,27.15488787401733,26.917415981262142,26.679944088506986,26.442472195751787,26.20500030299666,25.967528410241503,25.730056517486304,25.492584624731165,25.255112731975977,25.020250822660856,24.79317053748241,24.56609025230401,24.339009967125598,24.11192968194715,23.884849396768757,23.657769111590305,23.43068882641193,23.20360854123349,22.976528256055094,22.74944797087664,22.52236768569824,22.295287400519797,22.073482862386683,21.855515226854944,21.6375475913232,21.419579955791527,21.20161232025977,20.98364468472804,20.765677049196327,20.547709413664613,20.32974177813287,20.111774142601167,19.893806507069453,19.678383066365292,19.469705594003994,19.261028121642653,19.05235064928134,18.843673176920056,18.634995704558747,18.42631823219737,18.217640759836073,18.008963287474774,17.800285815113433,17.59312816352403,17.39651427563172,17.199900387739433,17.003286499847125,16.80667261195485,16.61005872406253,16.413444836170243,16.216830948277977,16.020217060385654,15.823603172493367,15.63969656344906,15.456233234310506,15.272769905171913,15.089306576033357,14.905843246894772,14.722379917756207,14.53891658861762,14.355453259479068,14.179919913958571,14.00852394940453,13.837127984850532,13.66573202029653,13.494336055742496,13.322940091188492,13.151544126634468,12.98108639778497,12.820686558556623,12.660286719328255,12.499886880099899,12.339487040871518,12.179087201643185,12.018687362414804,11.859862776894811,11.709505187898229,11.559147598901673,11.408790009905102,11.258432420908523,11.108074831911944,10.957717242915395,10.814625122987277,10.67342834162286,10.532231560258452,10.391034778894028,10.249837997529628,10.10864121616523,9.975215396285764,9.84239510579442,9.70957481530306,9.57675452481169,9.443934234320345,9.315058912993694,9.190060545242632,9.065062177491576,8.940063809740549,8.815065441989505,8.694394897036343,8.578510412938467,8.462625928840621,8.346741444742726,8.230856960644878,8.122867271002882,8.016877951233297,7.910888631463706,7.804899311694129,7.7019735281572625,7.602986577541989,7.503999626926734,7.405012676311479,7.307899291073927,7.214077657499626,7.120256023925327,7.026434390351021,6.936204659895725,6.848957491372888,6.7617103228500355,6.674463154327194,6.593905338269327,6.513593454402578,6.433281570535821,6.356638696322994,6.282479460088679,6.20832022385435,6.136465451706876,6.067752027362426,5.999038603017972,5.9244393071648656,5.841992182633515,5.7595450581021534,5.677097933570796,5.59465080903945,5.512203684508092,5.429756559976729,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[67.83658411459362,67.87648103564514,67.91637795669665,67.95627487774817,67.9961717987997,68.03606871985122,68.07596564090272,68.11586256195424,68.15575948300577,68.19565640405729,68.23555332510881,68.27545024616032,68.31534716721185,68.35524408826336,68.39514100931488,68.4350379303664,68.47493485141791,68.51483177246944,68.55472869352096,68.59462561457248,68.634522535624,68.67441945667552,68.71431637772704,68.75421329877855,68.79411021983007,68.8340071408816,68.8739040619331,68.91380098298463,68.95369790403615,68.99359482508765,69.03349174613919,69.0733886671907,69.11328558824222,69.15318250929374,69.19307943034525,69.23297635139679,69.2728732724483,69.31277019349982,69.35266711455134,69.39256403560285,69.43246095665437,69.47235787770589,69.51225479875743,69.55215171980893,69.59204864086044,69.63194556191196,69.67184248296348,69.71173940401502,69.75163632506653,69.79153324611804,69.83143016716956,69.87132708822108,69.91122400927259,69.95112093032412,69.99147227003581,70.03273244630505,70.07399262257428,70.11525279884351,70.15651297511273,70.19777315138198,70.2390333276512,70.28029350392045,70.32155368018968,70.36281385645891,70.40407403272815,70.44533420899738,70.48659438526661,70.52785456153585,70.56911473780507,70.6103749140743,70.65163509034355,70.69289526661278,70.73415544288201,70.77541561915123,70.81667579542048,70.85793597168971,70.89919614795895,70.94045632422817,70.98171650049741,71.02297667676663,71.06423685303588,71.1054970293051,71.14675720557435,71.18801738184357,71.20572314261848,71.21871802029452,71.23171289797057,71.24470777564662,71.25770265332265,71.27069753099869,71.28369240867474,71.29668728635079,71.30968216402682,71.32267704170286,71.33567191937891,71.34866679705496,71.361661674731,71.37465655240703,71.38765143008308,71.40064630775913,71.41364118543518,71.4266360631112,71.43963094078725,71.4526258184633,71.46562069613934,71.47861557381538,71.49161045149143,71.50460532916748,71.51760020684351,71.53059508451955,71.5435899621956,71.55658483987165,71.56957971754768,71.58257459522372,71.59556947289977,71.60856435057582,71.62155922825185,71.63455410592789,71.64754898360394,71.66054386127998,71.67353873895603,71.68653361663206,71.69952849430811,71.71252337198416,71.7255182496602,71.73851312733623,71.75150800501228,71.76450288268833,71.77749776036437,71.79049263804042,71.80348751571645,71.8164823933925,71.82947727106854,71.84247214874458,71.85546702642063,71.86846190409668,71.88145678177273,71.89486136137728,71.91031444787339,71.9257675343695,71.94122062086561,71.95667370736172,71.97212679385781,71.98757988035392,72.00303296685003,72.01848605334614,72.03393913984225,72.04939222633836,72.06484531283446,72.08029839933056,72.09575148582667,72.11120457232278,72.12665765881889,72.142110745315,72.1575638318111,72.17301691830721,72.18847000480332,72.20392309129942,72.21937617779552,72.23482926429163,72.25028235078774,72.26573543728385,72.28118852377996,72.29664161027608,72.31209469677218,72.32754778326829,72.34300086976438,72.02444221481814,71.53887768915074,71.05331316348332,70.56774863781591,70.08218411214852,69.59661958648108,69.11105506081368,68.6254905351463,68.13992600947887,67.65436148381148,67.16879695814404,66.68323243247664,66.19766790680924,65.71210338114182,65.22653885547444,64.74097432980702,64.2554098041396,63.7698452784722,63.284280752804776,62.79871622713739,62.31315170146998,61.82758717580256,61.34202265013517,60.856458124467736,60.37089359880034,59.88532907313293,59.39976454746552,58.91420002179812,58.42863549613069,57.943070970463296,57.45750644479589,56.971941919128476,56.48637739346108,56.00081286779366,55.51524834212625,55.02968381645884,54.54411929079143,54.058554765124036,53.57299023945662,53.087425713789216,52.60186118812182,52.10548119235703,51.600088340237996,51.09469548811895,50.58930263599992,50.08390978388087,49.578516931761854,49.07312407964282,48.56773122752378,48.062338375404735,47.5569455232857,47.05155267116669,46.546159819047645,46.04076696692861,45.53537411480957,45.02998126269055,44.52458841057151,44.019195558452466,43.513802706333436,43.00840985421439,42.503017002095376,41.99762414997633,41.492231297857295,40.98683844573826,40.48144559361924,39.976052741500204,39.47065988938116,38.96526703726212,38.459874185143086,37.95448133302406,37.449088480905026,36.94369562878599,36.43830277666696,35.93290992454791,35.4275170724289,34.922124220309854,34.41673136819081,33.91133851607178,33.40594566395276,32.90055281183372,32.395159959714675,31.88976710759564,31.3843742554766,31.007935370493676,30.760450452646698,30.512965534799832,30.265480616952964,30.017995699106027,29.77051078125916,29.523025863412293,29.275540945565407,29.028056027718428,28.78369398451043,28.546222091755265,28.30875019900007,28.071278306244885,27.833806413489743,27.596334520734583,27.358862627979445,27.12139073522426,26.883918842469058,26.646446949713958,26.40897505695877,26.171503164203617,25.93403127144842,25.69655937869329,25.459087485938134,25.22973554526427,25.002655260085866,24.775574974907467,24.54849468972902,24.321414404550573,24.094334119372174,23.86725383419376,23.640173549015312,23.41309326383692,23.186012978658468,22.958932693480094,22.731852408301652,22.504772123123256,22.285965167150604,22.0679975316189,21.850029896087158,21.632062260555482,21.41409462502374,21.196126989492,20.97815935396032,20.760191718428565,20.54222408289684,20.324256447365123,20.10628881183341,19.892253113357715,19.683575640996416,19.474898168635075,19.266220696273777,19.05754322391248,18.848865751551138,18.64018827918983,18.431510806828545,18.222833334467232,18.014155862105856,17.806855727221134,17.610241839328854,17.413627951436535,17.217014063544262,17.02040017565195,16.823786287759663,16.627172399867355,16.43055851197508,16.233944624082756,16.03733073619047,15.851355499884487,15.66789217074592,15.484428841607325,15.300965512468771,15.117502183330215,14.93403885419162,14.750575525053065,14.567112195914481,14.388087934229263,14.216691969675287,14.04529600512126,13.873900040567248,13.70250407601321,13.531108111459211,13.359712146905208,13.188316182351175,13.02435104626687,12.863951207038525,12.703551367810146,12.543151528581799,12.38275168935343,12.222351850125074,12.061952010896695,11.907951643605768,11.7575940546092,11.607236465612631,11.456878876616052,11.306521287619494,11.156163698622926,11.00738556017953,10.866188778815133,10.724991997450706,10.583795216086308,10.44259843472189,10.301401653357484,10.161996230054735,10.02917593956339,9.896355649072046,9.763535358580675,9.63071506808933,9.497894777597972,9.370583840810376,9.24558547305934,9.120587105308307,8.995588737557247,8.87059036980619,8.751014509217576,8.635130025119693,8.519245541021824,8.403361056923949,8.287476572826103,8.179940300421833,8.073950980652244,7.9679616608826676,7.861972341113083,7.758882439544843,7.659895488929589,7.560908538314317,7.4619215876990435,7.364352821858008,7.270531188283698,7.176709554709381,7.082887921135082,6.991680038566538,6.904432870043687,6.817185701520851,6.729938532998014,6.647954310874351,6.567642427007595,6.487330543140857,6.409093060704976,6.334933824470656,6.260774588236331,6.187233918870917,6.118520494526464,6.04980707018203,5.980112667252812,5.89766554272145,5.8152184181900965,5.732771293658747,5.650324169127385,5.5678770445960275,5.485429920064681,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[67.80962564856236,67.84952256961388,67.88941949066539,67.92931641171691,67.96921333276843,68.00911025381996,68.04900717487146,68.08890409592298,68.1288010169745,68.16869793802603,68.20859485907755,68.24849178012906,68.28838870118058,68.3282856222321,68.36818254328362,68.40807946433515,68.44797638538665,68.48787330643817,68.5277702274897,68.56766714854122,68.60756406959274,68.64746099064425,68.68735791169578,68.72725483274729,68.76715175379881,68.80704867485034,68.84694559590184,68.88684251695338,68.92673943800489,68.9666363590564,69.00653328010793,69.04643020115944,69.08632712221096,69.12622404326248,69.16612096431399,69.20601788536553,69.24591480641703,69.28581172746856,69.32570864852008,69.36560556957158,69.4055024906231,69.44539941167463,69.48529633272615,69.52519325377767,69.56509017482918,69.6049870958807,69.64488401693222,69.68478093798375,69.72467785903525,69.76457478008678,69.8044717011383,69.84436862218982,69.88426554324133,69.92416246429285,69.96405938534437,70.00395630639589,70.04385322744741,70.08375014849892,70.12364706955044,70.16354399060197,70.20344091165349,70.24333783270501,70.28323475375652,70.32313167480805,70.36302859585956,70.40292551691108,70.44282243796259,70.48271935901413,70.52261628006565,70.56251320111716,70.60241012216868,70.6434430892643,70.68470326553353,70.72596344180276,70.767223618072,70.80848379434123,70.84974397061046,70.8910041468797,70.93226432314891,70.97352449941816,71.0147846756874,71.05604485195663,71.09730502822586,71.1385652044951,71.15627096527,71.16926584294605,71.18226072062208,71.19525559829812,71.20825047597417,71.2212453536502,71.23424023132625,71.24723510900229,71.26022998667834,71.27322486435438,71.28621974203044,71.29921461970646,71.31220949738251,71.32520437505856,71.3381992527346,71.35119413041065,71.36418900808668,71.37718388576273,71.39017876343877,71.40317364111482,71.41616851879085,71.42916339646689,71.44215827414294,71.45515315181898,71.46814802949503,71.48114290717108,71.49413778484711,71.50713266252315,71.5201275401992,71.53312241787525,71.54611729555128,71.55911217322733,71.57210705090337,71.5851019285794,71.59809680625547,71.6110916839315,71.62408656160756,71.63708143928359,71.65007631695963,71.66307119463568,71.67606607231171,71.68906094998775,71.7020558276638,71.71505070533985,71.72804558301588,71.74104046069193,71.75403533836797,71.767030216044,71.78002509372006,71.79301997139609,71.80601484907214,71.81900972674818,71.83200460442423,71.84499948210028,71.85799435977631,71.87098923745236,71.8839841151284,71.89697899280445,71.90997387048048,71.92296874815653,71.93596362583257,71.94895850350862,71.96195338118466,71.9749482588607,71.98794313653674,72.00093801421279,72.01393289188883,72.02692776956488,72.03992264724091,72.05291752491696,72.06755120852596,72.08300429502206,72.09845738151817,72.11391046801427,72.12936355451038,72.14481664100649,72.1602697275026,72.1757228139987,72.19117590049481,72.20662898699092,72.22208207348703,72.23753515998314,72.25298824647925,71.93442959153299,71.44886506586559,70.96330054019818,70.47773601453076,69.99217148886338,69.50660696319594,69.02104243752855,68.53547791186114,68.04991338619372,67.56434886052634,67.0787843348589,66.5932198091915,66.1076552835241,65.62209075785668,65.13652623218928,64.65096170652187,64.16539718085446,63.67983265518705,63.183452668543296,62.67805981642428,62.17266696430524,61.6672741121862,61.16188126006719,60.656488407948125,60.1510955558291,59.645702703710064,59.140309851591034,58.63491699947201,58.129524147352946,57.62413129523393,57.11873844311489,56.613345590995856,56.10795273887684,55.6025598867578,55.09716703463876,54.59177418251972,54.086381330400684,53.58098847828167,53.07559562616263,52.57020277404359,52.06480992192458,51.559417069805534,51.05402421768649,50.54863136556745,50.043238513448415,49.53784566132937,49.032452809210355,48.52705995709132,48.02166710497228,47.516274252853236,47.0108814007342,46.505488548615176,46.000095696496146,45.4947028443771,44.98930999225806,44.48391714013905,43.978524288020004,43.47313143590097,42.96773858378193,42.462345731662886,41.95695287954387,41.45156002742483,40.946167175305796,40.44077432318676,39.93538147106774,39.4299886189487,38.92459576682966,38.419202914710624,37.91381006259158,37.40841721047257,36.90302435835353,36.39763150623449,35.892238654115445,35.38684580199641,34.88145294987739,34.376060097758355,33.87066724563931,33.365274393520274,32.85988154140126,32.35448868928222,31.84909583716318,31.34370298504414,30.838310132925095,30.461871247942177,30.214386330095195,29.966901412248326,29.719416494401457,29.471931576554525,29.22514063122774,28.987668738472557,28.750196845717404,28.512724952962248,28.275253060207078,28.037781167451918,27.800309274696723,27.56283738194153,27.325365489186392,27.087893596431236,26.850421703676094,26.61294981092091,26.375477918165704,26.138006025410608,25.90053413265542,25.666300553046153,25.439220267867658,25.212139982689312,24.98505969751086,24.757979412332446,24.530899127154044,24.303818841975644,24.076738556797196,23.84965827161875,23.62257798644035,23.395497701261938,23.16841741608349,22.941337130905097,22.71641510744633,22.498447471914574,22.280479836382874,22.06251220085113,21.84454456531942,21.626576929787714,21.408609294255974,21.190641658724292,20.97267402319255,20.75470638766081,20.536738752129136,20.31877111659738,20.106123160350165,19.897445687988856,19.688768215627515,19.480090743266217,19.27141327090492,19.062735798543578,18.854058326182276,18.64538085382098,18.43670338145964,18.22802590909833,18.02058329091826,17.82396940302594,17.62735551513365,17.430741627241375,17.2341277393491,17.03751385145678,16.840899963564503,16.64428607567219,16.447672187779908,16.251058299887596,16.06301443631991,15.879551107181317,15.696087778042749,15.512624448904207,15.32916111976564,15.145697790627045,14.962234461488489,14.778771132349934,14.596255954500016,14.42485998994599,14.253464025392015,14.082068060837953,13.910672096283978,13.739276131729952,13.567880167175938,13.396484202621902,13.228015533977107,13.06761569474876,12.907215855520406,12.746816016292057,12.586416177063713,12.426016337835332,12.265616498606988,12.106398099313305,11.956040510316736,11.80568292132017,11.6553253323236,11.50496774332703,11.35461015433046,11.20425256533388,11.058949216007395,10.917752434642969,10.776555653278571,10.635358871914173,10.494162090549747,10.352965309185349,10.215956773332373,10.083136482841004,9.950316192349652,9.817495901858306,9.684675611366963,9.551855320875593,9.42610876862709,9.301110400876055,9.176112033125,9.051113665373961,8.926115297622928,8.807634121398799,8.691749637300916,8.575865153203063,8.45998066910518,8.34409618500731,8.237013329840803,8.131024010071226,8.025034690301627,7.919045370532038,7.815791350932419,7.716804400317158,7.617817449701903,7.518830499086649,7.420806352642073,7.326984719067767,7.233163085493468,7.139341451919158,7.047155417237352,6.959908248714505,6.872661080191668,6.785413911668817,6.702003283479385,6.621691399612642,6.541379515745884,6.461547425086955,6.387388188852645,6.313228952618315,6.2390697163839945,6.169288961690516,6.100575537346074,6.031862113001622,5.9533389028093975,5.870891778278047,5.788444653746685,5.705997529215332,5.623550404683982,5.541103280152621,5.458656155621262,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[67.78063556616722,67.81917959314718,67.85772362012716,67.89626764710714,67.93548812092877,67.97538504198029,68.01528196303181,68.05517888408333,68.09507580513484,68.13497272618636,68.17486964723788,68.21476656828939,68.25466348934093,68.29456041039244,68.33445733144396,68.37435425249548,68.41425117354699,68.45414809459851,68.49404501565003,68.53394193670155,68.57383885775306,68.61373577880458,68.6536326998561,68.69352962090763,68.73342654195915,68.77332346301066,68.81322038406218,68.8531173051137,68.89301422616522,68.93291114721674,68.97280806826825,69.01270498931977,69.0526019103713,69.09249883142282,69.13239575247434,69.17229267352585,69.21218959457737,69.25208651562889,69.29198343668041,69.33188035773193,69.37177727878344,69.41167419983496,69.45157112088648,69.49146804193799,69.53136496298951,69.57126188404104,69.61115880509256,69.65105572614408,69.69095264719559,69.73084956824711,69.77074648929863,69.81064341035015,69.85054033140167,69.89043725245318,69.9303341735047,69.97023109455623,70.01012801560775,70.05002493665927,70.08992185771078,70.1298187787623,70.16971569981382,70.20961262086534,70.24950954191686,70.28940646296837,70.3293033840199,70.36920030507142,70.40909722612292,70.44899414717445,70.48889106822597,70.52878798927749,70.56868491032901,70.60858183138052,70.64847875243204,70.68837567348356,70.72827259453508,70.7681695155866,70.80806643663813,70.84796335768965,70.88786027874116,70.92775719979267,70.9676541208442,71.00755104189571,71.04744796294723,71.08734488399875,71.10243136910587,71.11255576702409,71.12268016494232,71.13376138903463,71.14675626671068,71.15975114438672,71.17274602206277,71.1857408997388,71.19873577741485,71.21173065509089,71.22472553276694,71.23772041044298,71.25071528811903,71.26371016579506,71.27670504347111,71.28969992114716,71.30269479882318,71.31568967649923,71.32868455417528,71.34167943185132,71.35467430952735,71.3676691872034,71.38066406487945,71.39365894255549,71.40665382023154,71.41964869790758,71.43264357558361,71.44563845325966,71.4586333309357,71.47162820861175,71.4846230862878,71.49761796396383,71.51061284163987,71.52360771931592,71.53660259699197,71.549597474668,71.56259235234405,71.57558723002009,71.58858210769614,71.60157698537218,71.61457186304821,71.62756674072426,71.64056161840031,71.65355649607635,71.66655137375238,71.67954625142843,71.69254112910448,71.70553600678052,71.71853088445656,71.7315257621326,71.74452063980866,71.75751551748469,71.77051039516073,71.78350527283678,71.79650015051283,71.80949502818886,71.82248990586491,71.83548478354095,71.848479661217,71.86147453889303,71.87446941656908,71.88746429424512,71.90045917192117,71.9134540495972,71.92644892727324,71.93944380494929,71.95243868262534,71.96543356030138,71.97842843797741,71.99142331565346,72.00441819332951,72.01741307100555,72.0304079486816,72.04340282635764,72.05639770403369,72.06939258170972,72.08238745938577,72.0953823370618,72.10837721473786,72.12137209241389,72.13436697008994,72.14736184776598,72.16035672544203,71.82544177343365,71.31657190658312,70.80770203973258,70.29883217288203,69.7899623060315,69.28109243918092,68.7722225723304,68.26335270547986,67.7544828386293,67.24561297177878,66.7367431049282,66.22787323807768,65.71900337122712,65.21013350437657,64.70126363752604,64.1923937706755,63.68352390382494,63.17465403697439,62.665784170123835,62.15691430327331,61.648044436422765,61.13917456957221,60.63030470272169,60.121434835871106,59.61256496902058,59.10369510217003,58.59482523531948,58.088852876920484,57.583460024801425,57.07806717268241,56.57267432056337,56.067281468444335,55.56188861632531,55.056495764206275,54.55110291208723,54.045710059968194,53.54031720784916,53.03492435573014,52.5295315036111,52.02413865149206,51.51874579937305,51.013352947254,50.50796009513497,50.00256724301594,49.49717439089689,48.99178153877785,48.486388686658835,47.98099583453979,47.475602982420746,46.970210130301716,46.46481727818267,45.95942442606366,45.45403157394461,44.94863872182558,44.443245869706544,43.93785301758753,43.432460165468484,42.92706731334945,42.42167446123041,41.91628160911137,41.41088875699236,40.90549590487331,40.400103052754275,39.89471020063524,39.38931734851622,38.88392449639717,38.378531644278134,37.8731387921591,37.36774594004006,36.86235308792104,36.356960235802006,35.85156738368296,35.346174531563925,34.84078167944489,34.33538882732587,33.82999597520683,33.32460312308778,32.81921027096875,32.31381741884973,31.808424566730697,31.303031714611656,30.79763886249261,30.292246010373574,29.91580712539065,29.668322207543675,29.42911538518986,29.19164349243467,28.954171599679565,28.716699706924373,28.47922781416919,28.241755921414036,28.004284028658876,27.76681213590371,27.52934024314855,27.29186835039335,27.054396457638166,26.816924564883024,26.579452672127864,26.341980779372726,26.104508886617538,25.875785275649566,25.648704990471124,25.421624705292686,25.194544420114315,24.967464134935824,24.74038384975747,24.513303564579022,24.28622327940061,24.059142994222206,23.832062709043807,23.60498242386536,23.377902138686913,23.150821853508514,22.928897412210286,22.71092977667857,22.49296214114684,22.274994505615126,22.057026870083376,21.839059234551666,21.621091599019927,21.403123963488216,21.18515632795651,20.96718869242477,20.74922105689309,20.531253421361345,20.319993207342588,20.111315734981282,19.902638262619938,19.69396079025865,19.48528331789734,19.276605845536004,19.067928373174702,18.859250900813404,18.650573428452063,18.441895956090768,18.234310854615334,18.037696966723075,17.841083078830756,17.64446919093849,17.447855303046172,17.25124141515388,17.0546275272616,16.858013639369325,16.661399751477006,16.46478586358473,16.274673372755355,16.091210043616734,15.907746714478176,15.72428338533962,15.540820056201028,15.35735672706246,15.173893397923917,14.990430068785349,14.806966739646754,14.633028010216734,14.461632045662734,14.290236081108695,14.118840116554669,13.947444152000694,13.776048187446632,13.604652222892655,13.43325625833863,13.271280182459032,13.11088034323065,12.950480504002282,12.790080664773937,12.62968082554558,12.469280986317234,12.30888114708889,12.154486966024244,12.004129377027706,11.853771788031127,11.703414199034558,11.553056610037988,11.40269902104142,11.252341432044851,11.110512871835223,10.969316090470825,10.828119309106427,10.686922527742,10.545725746377602,10.404528965013204,10.269917316609973,10.137097026118628,10.004276735627284,9.871456445135916,9.738636154644563,9.606632064194836,9.481633696443799,9.356635328692741,9.231636960941705,9.10663859319067,8.981640225439614,8.864253733580007,8.748369249482147,8.63248476538428,8.516600281286395,8.400715797188543,8.29408635925975,8.188097039490167,8.08210771972059,7.9761183999510115,7.872700262319993,7.773713311704739,7.674726361089473,7.575739410474212,7.477259883426145,7.383438249851846,7.289616616277527,7.195794982703223,7.102630795908157,7.015383627385319,6.928136458862477,6.84088929033963,6.7560522560844145,6.675740372217666,6.595428488350915,6.515116604484172,6.439842553234613,6.3656833170002916,6.291524080765981,6.220057428854565,6.15134400451012,6.08263058016567,6.009012262897338,5.926565138365979,5.844118013834626,5.761670889303275,5.679223764771914,5.59677664024056,5.5143295157092105,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[67.74409948043166,67.78264350741163,67.82118753439161,67.85973156137158,67.89827558835154,67.93681961533153,67.97536364231149,68.01390766929146,68.05245169627145,68.09099572325141,68.12953975023139,68.16808377721135,68.20662780419133,68.24517183117129,68.28371585815127,68.32225988513125,68.36080391211121,68.39934793909119,68.43789196607116,68.47643599305113,68.51498002003109,68.55487694066528,68.59477386171679,68.63467078276831,68.67456770381983,68.71446462487135,68.75436154592288,68.79425846697438,68.8341553880259,68.87405230907743,68.91394923012895,68.95384615118047,68.99374307223198,69.0336399932835,69.07353691433502,69.11343383538654,69.15333075643805,69.19322767748957,69.2331245985411,69.27302151959262,69.31291844064414,69.35281536169566,69.39271228274717,69.43260920379869,69.47250612485021,69.51240304590173,69.55229996695326,69.59219688800476,69.63209380905629,69.67199073010781,69.71188765115933,69.75178457221085,69.79168149326236,69.83157841431387,69.8714753353654,69.91137225641693,69.95126917746845,69.99116609851995,70.03106301957146,70.07095994062298,70.11085686167452,70.15075378272604,70.19065070377755,70.23054762482906,70.27044454588058,70.31034146693212,70.35023838798362,70.39013530903514,70.43003223008667,70.46992915113817,70.50982607218971,70.54972299324122,70.58961991429274,70.62951683534425,70.66941375639577,70.7093106774473,70.74920759849881,70.78910451955034,70.82900144060186,70.86889836165338,70.90879528270489,70.94869220375641,70.98858912480793,71.02848604585945,71.04357253096656,71.05369692888479,71.06382132680301,71.07394572472124,71.08407012263946,71.09419452055769,71.10431891847591,71.11444331639414,71.12456771431238,71.1346921122306,71.14481651014884,71.15494090806706,71.1650653059853,71.17518970390351,71.18531410182175,71.19543849973996,71.2055628976582,71.21568729557643,71.22581169349465,71.23593609141288,71.24845255491047,71.26144743258652,71.27444231026256,71.2874371879386,71.30043206561464,71.3134269432907,71.32642182096673,71.33941669864276,71.35241157631881,71.36540645399486,71.3784013316709,71.39139620934695,71.40439108702299,71.41738596469904,71.43038084237507,71.44337572005111,71.45637059772716,71.46936547540321,71.48236035307924,71.49535523075528,71.50835010843133,71.52134498610737,71.53433986378343,71.54733474145945,71.5603296191355,71.57332449681155,71.58631937448759,71.59931425216362,71.61230912983967,71.62530400751572,71.63829888519176,71.6512937628678,71.66428864054384,71.6772835182199,71.69027839589593,71.70327327357198,71.71626815124802,71.72926302892405,71.7422579066001,71.75525278427614,71.76824766195219,71.78124253962822,71.79423741730427,71.80723229498032,71.82022717265636,71.8332220503324,71.84621692800845,71.8592118056845,71.87220668336053,71.88520156103657,71.89819643871263,71.91119131638867,71.9241861940647,71.93718107174075,71.95017594941679,71.96317082709282,71.97616570476887,71.98916058244492,72.00215546012096,72.015150337797,72.02814521547305,72.0411400931491,72.05413497082513,71.71922001881677,71.21035015196625,70.7014802851157,70.19261041826515,69.6837405514146,69.17487068456404,68.66600081771351,68.15713095086295,67.6482610840124,67.13939121716189,66.63052135031131,66.12165148346078,65.61278161661023,65.10391174975967,64.59504188290916,64.0861720160586,63.57730214920805,63.068432282357506,62.559562415506946,62.05069254865642,61.54182268180587,61.032952814955316,60.52408294810479,60.01521308125422,59.506343214403685,58.99747334755314,58.48860348070259,57.97973361385206,57.47086374700149,56.96199388015097,56.45312401330041,55.944254146449865,55.435384279599326,54.92651441274879,54.41764454589823,53.90877467904768,53.39990481219713,52.891034945346604,52.38216507849605,51.8732952116455,51.36442534479497,50.85555547794442,50.346685611093875,49.837815744243315,49.32894587739276,48.820076010542216,48.31120614369169,47.80233627684113,47.293466409990586,46.78459654314004,46.27572667628948,45.76685680943896,45.25798694258841,44.74911707573786,44.24024720888731,43.73137734203678,43.222507475186234,42.713637608335674,42.20476774148513,41.69589787463458,41.18702800778405,40.6781581409335,40.169288274082945,39.6604184072324,39.15154854038187,38.64267867353132,38.13380880668077,37.624938939830216,37.11606907297966,36.60719920612914,36.098329339278585,35.58945947242803,35.080059665033154,34.549992477198984,34.01992528936483,33.48985810153066,32.95979091369648,32.4297237258623,31.89965653802815,31.36958935019398,30.839522162359803,30.30945497452563,29.77938778669145,29.39561824639683,29.158146353641627,28.92067446088653,28.683202568131343,28.44573067537623,28.208258782621044,27.97078688986586,27.733314997110703,27.495843104355547,27.258371211600377,27.020899318845217,26.78342742609002,26.545955533334837,26.31235028343143,26.08526999825298,25.85818971307462,25.631109427896178,25.404029142717768,25.176948857539326,24.949868572360884,24.722788287182514,24.495708002004022,24.268627716825673,24.04154743164722,23.814467146468807,23.587386861290405,23.360306576112006,23.141379716974274,22.923412081442606,22.70544444591083,22.487476810379118,22.2695091748474,22.051541539315668,21.833573903783957,21.6156062682522,21.397638632720497,21.179670997188758,20.961703361657047,20.743735726125337,20.53386325433508,20.3251857819737,20.11650830961244,19.907830837251105,19.6991533648898,19.49047589252846,19.28179842016717,19.073120947805858,18.86444347544452,18.65576600308322,18.448038418312525,18.25142453042021,18.0548106425279,17.85819675463559,17.661582866743334,17.464968978851015,17.268355090958746,17.07174120306643,16.87512731517414,16.678513427281864,16.486332309190765,16.3028689800522,16.119405650913645,15.935942321775089,15.752478992636465,15.569015663497911,15.385552334359355,15.202089005220762,15.018625676082193,14.841196030487486,14.669800065933451,14.49840410137941,14.327008136825437,14.155612172271436,13.984216207717395,13.812820243163372,13.641424278609396,13.474944670169275,13.314544830940932,13.154144991712608,12.99374515248423,12.833345313255847,12.672945474027479,12.512545634799134,12.352933421731793,12.202575832735276,12.052218243738695,11.901860654742086,11.751503065745545,11.601145476748968,11.4507878877524,11.303273309027494,11.162076527663107,11.020879746298698,10.879682964934272,10.738486183569874,10.597289402205476,10.456698150378957,10.323877859887594,10.191057569396268,10.058237278904897,9.925416988413554,9.79259669792221,9.662156992011557,9.537158624260499,9.412160256509464,9.28716188875843,9.16216352100737,9.037165153256336,8.920873345761246,8.804988861663375,8.689104377565501,8.573219893467641,8.457335409369772,8.351159388678717,8.245170068909147,8.139180749139548,8.033191429369964,7.929609173707586,7.830622223092332,7.7316352724770585,7.632648321861804,7.533713414210227,7.439891780635898,7.34607014706161,7.252248513487311,7.158426879912993,7.070859006056127,6.9836118375332905,6.896364669010454,6.8101012286894385,6.729789344822696,6.649477460955952,6.569165577089204,6.492296917616594,6.4181376813822855,6.343978445147957,6.27082589601861,6.202112471674173,6.133399047329727,6.064685622985281,5.982238498453931,5.899791373922578,5.817344249391219,5.734897124859865,5.652450000328516,5.570002875797154,5.4875557512658,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[67.70756339469611,67.74610742167607,67.78465144865605,67.82319547563603,67.86173950261599,67.90028352959597,67.93882755657594,67.97737158355591,68.01591561053588,68.05445963751585,68.09300366449582,68.13154769147579,68.17009171845577,68.20863574543574,68.2471797724157,68.28572379939568,68.32426782637566,68.36281185335562,68.4013558803356,68.43989990731558,68.47844393429554,68.5169879612755,68.55553198825548,68.59407601523546,68.63262004221542,68.6711640691954,68.70970809617538,68.74825212315534,68.78679615013532,68.8253401771153,68.86388420409526,68.90242823107523,68.9409722580552,68.97951628503517,69.01806031201514,69.05660433899511,69.09514836597509,69.13436883935027,69.1742657604018,69.2141626814533,69.25405960250482,69.29395652355635,69.33385344460787,69.37375036565939,69.4136472867109,69.45354420776242,69.49344112881394,69.53333804986546,69.57323497091699,69.6131318919685,69.65302881302001,69.69292573407154,69.73282265512306,69.77271957617458,69.81261649722609,69.85251341827761,69.89241033932913,69.93230726038064,69.97220418143218,70.01210110248368,70.0519980235352,70.09189494458673,70.13179186563823,70.17168878668977,70.21158570774128,70.2514826287928,70.29137954984431,70.33127647089583,70.37117339194737,70.41107031299887,70.4509672340504,70.4908641551019,70.53076107615342,70.57065799720495,70.61055491825647,70.65045183930799,70.6903487603595,70.73024568141103,70.77014260246254,70.81003952351406,70.84993644456559,70.88983336561711,70.92973028666862,70.96962720772014,70.98471369282724,70.99483809074547,71.0049624886637,71.01508688658193,71.02521128450016,71.03533568241838,71.0454600803366,71.05558447825483,71.06570887617306,71.0758332740913,71.08595767200953,71.09608206992775,71.10620646784596,71.1163308657642,71.12645526368243,71.13657966160065,71.14670405951888,71.15682845743711,71.16695285535533,71.17707725327357,71.1872016511918,71.19732604911002,71.20745044702825,71.21757484494647,71.2276992428647,71.23782364078292,71.24794803870117,71.25807243661939,71.2681968345376,71.27832123245584,71.28844563037407,71.29857002829229,71.30869442621052,71.31881882412875,71.32894322204697,71.3390676199652,71.35014884311028,71.3631437207863,71.37613859846235,71.3891334761384,71.40212835381443,71.41512323149047,71.42811810916652,71.44111298684257,71.4541078645186,71.46710274219464,71.48009761987069,71.49309249754674,71.50608737522278,71.51908225289883,71.53207713057486,71.54507200825091,71.55806688592695,71.571061763603,71.58405664127903,71.59705151895508,71.61004639663112,71.62304127430717,71.6360361519832,71.64903102965926,71.66202590733529,71.67502078501133,71.68801566268738,71.70101054036343,71.71400541803946,71.72700029571551,71.73999517339155,71.7529900510676,71.76598492874363,71.77897980641968,71.79197468409572,71.80496956177177,71.8179644394478,71.83095931712386,71.84395419479989,71.85694907247593,71.86994395015199,71.88293882782803,71.89593370550406,71.9089285831801,71.92192346085615,71.9349183385322,71.94791321620825,71.61299826419987,71.10412839734934,70.5952585304988,70.08638866364824,69.5775187967977,69.06864892994713,68.55977906309661,68.05090919624605,67.54203932939551,67.03316946254498,66.52429959569442,66.01542972884388,65.50655986199334,64.99768999514279,64.48882012829226,63.9799502614417,63.47108039459115,62.9622105277406,62.45334066089005,61.944470794039525,61.43560092718897,60.92673106033842,60.417861193487894,59.90899132663733,59.40012145978679,58.89125159293625,58.3823817260857,57.873511859235165,57.364641992384584,56.85577212553406,56.346902258683514,55.83803239183296,55.32916252498243,54.82029265813188,54.31142279128133,53.80255292443078,53.29368305758023,52.7848131907297,52.275943323879154,51.7670734570286,51.25820359017807,50.749333723327524,50.24046385647697,49.73159398962642,49.22272412277587,48.71385425592532,48.204984389074795,47.69611452222424,47.18724465537369,46.67837478852314,46.16950492167259,45.660635054822066,45.15176518797152,44.64289530957901,44.11282812174484,43.58276093391069,43.052693746076514,42.522626558242344,41.992559370408166,41.462492182573996,40.93242499473984,40.40235780690566,39.87229061907149,39.342223431237315,38.81215624340316,38.28208905556899,37.75202186773481,37.22195467990064,36.691887492066456,36.161820304232315,35.63175311639814,35.10168592856396,34.57161874072979,34.04155155289561,33.511484365061456,32.981417177227286,32.45134998939311,31.921282801558934,31.391215613724782,30.86114842589061,30.331081238056434,29.801014050222257,29.27094686238808,28.887177322093457,28.64970542933825,28.41223353658316,28.17476164382797,27.937289751072857,27.699817858317672,27.462345965562484,27.22487407280733,26.987402180052175,26.749930287297005,26.52183500603488,26.29475472085639,26.067674435678033,25.84059415049959,25.613513865321135,25.38643358014278,25.159353294964337,24.932273009785924,24.705192724607482,24.478112439429044,24.251032154250677,24.023951869072178,23.796871583893832,23.571829657269944,23.353862021738227,23.13589438620656,22.917926750674784,22.699959115143063,22.481991479611402,22.26402384407962,22.04605620854791,21.828088573016192,21.610120937484464,21.392153301952746,21.174185666420996,20.956410773688795,20.747733301327536,20.53905582896616,20.33037835660482,20.121700884243563,19.913023411882183,19.704345939520923,19.49566846715959,19.286990994798284,19.07831352243694,18.869636050075652,18.661765982009626,18.465152094117308,18.268538206225,18.07192431833275,17.875310430440436,17.678696542548128,17.482082654655816,17.28546876676356,17.088854878871242,16.892240990978973,16.697991245626206,16.514527916487584,16.33106458734903,16.14760125821047,15.964137929071907,15.78067459993335,15.597211270794796,15.413747941656172,15.230284612517618,15.049364050758202,14.877968086204165,14.70657212165018,14.535176157096162,14.363780192542126,14.19238422798809,14.020988263434113,13.849592298880111,13.67860915787952,13.518209318651198,13.357809479422807,13.197409640194449,13.037009800966107,12.876609961737783,12.716210122509404,12.555810283281023,12.4010222884428,12.250664699446222,12.100307110449611,11.949949521453096,11.799591932456515,11.649234343459904,11.498876754463366,11.354836964855357,11.213640183490933,11.072443402126524,10.931246620762138,10.790049839397728,10.6488530580333,10.51065869365658,10.377838403165219,10.245018112673867,10.112197822182505,9.97937753169118,9.846557241199807,9.717681919828248,9.592683552077215,9.467685184326172,9.342686816575114,9.21768844882408,9.093377442040346,8.977492957942477,8.861608473844587,8.745723989746725,8.629839505648857,8.51422173786726,8.408232418097683,8.302243098328098,8.196253778558502,8.090264458788933,7.986518085095154,7.887531134479894,7.788544183864639,7.689557233249385,7.590570282634111,7.496345311419991,7.40252367784568,7.308702044271353,7.214880410697065,7.126334384726947,7.039087216204106,6.951840047681252,6.864592879158415,6.783838317427733,6.703526433560967,6.623214549694224,6.544751281998575,6.4705920457642545,6.39643280952993,6.322273573295622,6.252880938838224,6.184167514493764,6.115454090149327,6.037911858541878,5.955464734010516,5.873017609479167,5.790570484947812,5.708123360416454,5.6256762358851,5.5432291113537495,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[67.67102730896056,67.70957133594052,67.74811536292049,67.78665938990046,67.82520341688044,67.86374744386042,67.90229147084038,67.94083549782036,67.97937952480034,68.0179235517803,68.05646757876028,68.09501160574024,68.13355563272022,68.1720996597002,68.21064368668016,68.24918771366013,68.2877317406401,68.32627576762007,68.36481979460005,68.40336382158002,68.44190784855999,68.48045187553996,68.51899590251993,68.55753992949991,68.59608395647987,68.63462798345985,68.67317201043983,68.71171603741979,68.75026006439975,68.78880409137973,68.82734811835971,68.86589214533967,68.90443617231965,68.94298019929963,68.98152422627959,69.02006825325957,69.05861228023954,69.0971563072195,69.13570033419948,69.17424436117945,69.21278838815942,69.25133241513939,69.28987644211936,69.32842046909934,69.3669644960793,69.40550852305928,69.44405255003925,69.48259657701922,69.5211406039992,69.55968463097916,69.59822865795914,69.63677268493912,69.67531671191908,69.71386073889906,69.75375765908677,69.7936545801383,69.83355150118982,69.87344842224134,69.91334534329286,69.95324226434437,69.99313918539589,70.03303610644741,70.07293302749893,70.11282994855046,70.15272686960196,70.19262379065349,70.232520711705,70.27241763275651,70.31231455380805,70.35221147485956,70.39210839591108,70.4320053169626,70.47190223801412,70.51179915906563,70.55169608011715,70.59159300116868,70.63148992222018,70.67138684327172,70.71128376432323,70.75118068537475,70.79107760642627,70.83097452747779,70.8708714485293,70.91076836958082,70.92585485468794,70.93597925260616,70.94610365052438,70.95622804844261,70.96635244636084,70.97647684427906,70.9866012421973,70.99672564011553,71.00685003803375,71.01697443595198,71.02709883387021,71.03722323178843,71.04734762970668,71.05747202762488,71.06759642554312,71.07772082346135,71.08784522137957,71.0979696192978,71.10809401721603,71.11821841513425,71.12834281305248,71.1384672109707,71.14859160888894,71.15871600680715,71.16884040472539,71.17896480264362,71.18908920056185,71.19921359848007,71.2093379963983,71.21946239431652,71.22958679223476,71.23971119015299,71.2498355880712,71.25995998598944,71.27008438390766,71.28020878182589,71.29033317974412,71.30045757766234,71.31058197558058,71.32070637349881,71.33083077141703,71.34095516933526,71.35107956725348,71.36120396517171,71.37132836308994,71.38145276100818,71.3915771589264,71.40170155684463,71.41182595476286,71.42195035268108,71.4320747505993,71.44219914851753,71.45232354643576,71.4648400089861,71.47783488666214,71.49082976433819,71.50382464201422,71.51681951969027,71.52981439736631,71.54280927504234,71.5558041527184,71.56879903039443,71.58179390807048,71.59478878574652,71.60778366342257,71.62077854109862,71.63377341877465,71.6467682964507,71.65976317412674,71.67275805180279,71.68575292947882,71.69874780715487,71.71174268483091,71.72473756250696,71.737732440183,71.75072731785905,71.76372219553508,71.77671707321113,71.78971195088718,71.8027068285632,71.81570170623925,71.82869658391529,71.84169146159134,71.50677650958298,70.99790664273246,70.4890367758819,69.98016690903135,69.47129704218081,68.96242717533025,68.45355730847972,67.94468744162916,67.43581757477861,66.92694770792808,66.41807784107752,65.90920797422699,65.40033810737644,64.89146824052588,64.38259837367536,63.873728506824804,63.36485863997426,62.85598877312371,62.34711890627315,61.838249039422635,61.329379172572075,60.82050930572153,60.311639438871,59.80276957202042,59.29389970516989,58.785029838319346,58.27615997146879,57.76729010461826,57.25842023776769,56.74955037091717,56.24068050406661,55.73181063721607,55.22294077036553,54.714070903514994,54.205201036664434,53.675663766290704,53.14559657845653,52.61552939062238,52.08546220278821,51.55539501495402,51.02532782711988,50.4952606392857,49.96519345145153,49.43512626361735,48.90505907578318,48.374991887948994,47.84492470011485,47.31485751228068,46.784790324446504,46.25472313661233,45.72465594877815,45.194588760943994,44.66452157310982,44.134454385275646,43.604387197441476,43.07432000960732,42.54425282177314,42.014185633938965,41.48411844610479,40.954051258270624,40.423984070436475,39.89391688260229,39.36384969476812,38.83378250693394,38.303715319099794,37.77364813126562,37.24358094343144,36.71351375559727,36.18344656776309,35.65337937992894,35.123312192094765,34.59324500426059,34.06317781642642,33.53311062859224,33.00304344075809,32.472976252923914,31.94290906508974,31.412841877255566,30.882774689421417,30.35270750158724,29.822640313753062,29.292573125918885,28.76250593808471,28.37873639779009,28.141264505034886,27.903792612279794,27.666320719524602,27.428848826769492,27.191376934014304,26.95840001381671,26.73131972863822,26.50423944345984,26.277159158281457,26.050078873103043,25.82299858792455,25.595918302746192,25.368838017567754,25.141757732389298,24.914677447210938,24.687597162032496,24.460516876854083,24.233436591675645,24.006356306497203,23.784311962033936,23.56634432650222,23.348376690970532,23.130409055438744,22.912441419907026,22.694473784375358,22.47650614884358,22.258538513311866,22.040570877780198,21.822603242248423,21.60463560671671,21.38666797118499,21.17028082068127,20.961603348319894,20.752925875958617,20.544248403597283,20.335570931236024,20.126893458874648,19.918215986513314,19.70953851415205,19.500861041790674,19.29218356942941,19.08350609706808,18.8754935457067,18.678879657814413,18.482265769922176,18.285651882029857,18.089037994137538,17.892424106245233,17.695810218352985,17.499196330460666,17.302582442568358,17.105968554676046,16.90965018206159,16.72618685292302,16.542723523784453,16.359260194645913,16.17579686550729,15.992333536368733,15.80887020723018,15.625406878091614,15.441943548953057,15.258480219814505,15.086136106474934,14.91474014192086,14.743344177366883,14.571948212812845,14.400552248258858,14.229156283704844,14.057760319150807,13.886364354596768,13.72187380636145,13.561473967133058,13.4010741279047,13.240674288676377,13.080274449447986,12.919874610219628,12.759474770991284,12.599468744150297,12.44911115515377,12.298753566157139,12.148395977160622,11.998038388164042,11.847680799167431,11.697323210170916,11.547597402047613,11.406400620683206,11.26520383931879,11.124007057954392,10.982810276589966,10.841613495225555,10.70041671386117,10.564619236934204,10.431798946442834,10.29897865595149,10.166158365460129,10.033338074968777,9.900517784477415,9.773206847644973,9.648208479893915,9.523210112142863,9.39821174439183,9.273213376640786,9.149997054221545,9.034112570123686,8.918228086025826,8.802343601927955,8.686459117830067,8.571294767286247,8.465305447516613,8.359316127747048,8.253326807977471,8.147337488207887,8.043426996482731,7.944440045867483,7.845453095252209,7.7464661446369485,7.647479194021695,7.5527988422040515,7.458977208629745,7.365155575055446,7.271333941481136,7.181809763397766,7.094562594874919,7.007315426352074,6.920068257829232,6.837887290032759,6.757575406166008,6.677263522299265,6.5972056463805675,6.523046410146234,6.448887173911912,6.374727937677591,6.303649406002275,6.234935981657825,6.16622255731338,6.093585218629812,6.011138094098467,5.928690969567109,5.8462438450357475,5.763796720504397,5.681349595973044,5.5989024714416855,5.516455346910332,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[67.634491223225,67.67303525020498,67.71157927718494,67.75012330416492,67.7886673311449,67.82721135812487,67.86575538510482,67.9042994120848,67.94284343906477,67.98138746604475,68.01993149302471,68.05847552000469,68.09701954698467,68.13556357396463,68.17410760094461,68.21265162792459,68.25119565490455,68.28973968188451,68.32828370886449,68.36682773584447,68.40537176282443,68.44391578980441,68.48245981678438,68.52100384376435,68.55954787074432,68.59809189772429,68.63663592470428,68.67517995168423,68.7137239786642,68.75226800564418,68.79081203262415,68.82935605960412,68.86790008658409,68.90644411356408,68.94498814054404,68.983532167524,69.022076194504,69.06062022148396,69.09916424846392,69.1377082754439,69.17625230242386,69.21479632940384,69.25334035638382,69.29188438336378,69.33042841034376,69.36897243732372,69.4075164643037,69.44606049128367,69.48460451826364,69.52314854524361,69.56169257222359,69.60023659920355,69.63878062618353,69.6773246531635,69.71586868014347,69.75441270712344,69.79295673410341,69.83150076108339,69.87004478806335,69.90858881504333,69.94713284202331,69.98567686900327,70.02422089598325,70.06276492296321,70.10130894994319,70.13985297692315,70.17839700390313,70.2169410308831,70.25548505786308,70.29402908484305,70.33324955777178,70.37314647882329,70.41304339987481,70.45294032092633,70.49283724197785,70.53273416302937,70.57263108408088,70.6125280051324,70.65242492618393,70.69232184723545,70.73221876828696,70.77211568933849,70.81201261039,70.85190953144152,70.86699601654863,70.87712041446686,70.88724481238508,70.89736921030331,70.90749360822154,70.91761800613976,70.927742404058,70.93786680197623,70.94799119989445,70.95811559781268,70.96823999573091,70.97836439364913,70.98848879156736,70.99861318948558,71.00873758740381,71.01886198532205,71.02898638324027,71.0391107811585,71.04923517907673,71.05935957699495,71.06948397491318,71.07960837283142,71.08973277074963,71.09985716866787,71.10998156658609,71.12010596450432,71.13023036242255,71.14035476034077,71.150479158259,71.16060355617722,71.17072795409545,71.18085235201369,71.1909767499319,71.20110114785012,71.21122554576837,71.22134994368658,71.23147434160482,71.24159873952304,71.25172313744127,71.26184753535951,71.27197193327771,71.28209633119596,71.29222072911418,71.30234512703241,71.31246952495064,71.32259392286888,71.3327183207871,71.34284271870533,71.35296711662356,71.36309151454178,71.37321591246,71.38334031037823,71.39346470829646,71.40358910621468,71.41371350413291,71.42383790205115,71.43396229996937,71.4440866978876,71.45421109580582,71.46433549372405,71.47445989164228,71.4845842895605,71.49470868747873,71.50483308539697,71.51495748331519,71.52508188123342,71.53520627915165,71.54533067706987,71.5554550749881,71.56653629718589,71.57953117486194,71.59252605253798,71.60552093021403,71.61851580789006,71.6315106855661,71.64450556324215,71.6575004409182,71.67049531859423,71.68349019627028,71.69648507394632,71.70947995162237,71.7224748292984,71.73546970697446,71.40055475496608,70.89168488811556,70.382815021265,69.87394515441446,69.36507528756393,68.85620542071335,68.34733555386283,67.83846568701227,67.32959582016173,66.8207259533112,66.31185608646062,65.8029862196101,65.29411635275954,64.785246485909,64.27637661905847,63.76750675220792,63.238499410836596,62.708432223002426,62.178365035168255,61.6482978473341,61.11823065949992,60.58816347166575,60.058096283831595,59.528029095997404,58.99796190816325,58.46789472032908,57.9378275324949,57.40776034466075,56.87769315682655,56.3476259689924,55.817558781158226,55.28749159332405,54.7574244054899,54.22735721765573,53.697290029821545,53.167222841987375,52.6371556541532,52.107088466319055,51.57702127848487,51.0469540906507,50.51688690281655,49.986819714982374,49.4567525271482,48.92668533931402,48.39661815147984,47.866550963645665,47.336483775811516,46.806416587977346,46.27634940014317,45.746282212309,45.21621502447481,44.68614783664066,44.156080648806494,43.62601346097232,43.09594627313814,42.56587908530399,42.03581189746981,41.50574470963564,40.97567752180146,40.445610333967295,39.91554314613314,39.38547595829896,38.85540877046479,38.325341582630614,37.795274394796465,37.26520720696229,36.73514001912811,36.20507283129393,35.675005643459755,35.144938455625606,34.614871267791436,34.08480407995726,33.55473689212309,33.02466970428891,32.49460251645476,31.964535328620585,31.434468140786407,30.904400952952233,30.374333765118084,29.844266577283907,29.314199389449733,28.784132201615556,28.254065013781382,27.870295473486756,27.632823580731554,27.395351687976458,27.1678847364202,26.940804451241707,26.713724166063386,26.486643880884905,26.259563595706414,26.032483310528043,25.80540302534965,25.57832274017124,25.351242454992747,25.124162169814394,24.897081884635952,24.670001599457496,24.442921314279133,24.215841029100694,23.996794266797885,23.778826631266185,23.56085899573448,23.34289136020276,23.124923724671046,22.906956089139356,22.688988453607568,22.47102081807585,22.253053182544186,22.035085547012407,21.81711791148069,21.599150275949025,21.38415086767369,21.17547339531238,20.966795922951004,20.758118450589784,20.549440978228407,20.34076350586713,20.1320860335058,19.92340856114454,19.71473108878316,19.506053616421827,19.297376144060564,19.08922110940386,18.892607221511522,18.695993333619306,18.49937944572696,18.302765557834668,18.10615166994243,17.909537782050112,17.712923894157793,17.51631000626549,17.31969611837324,17.123082230480918,16.937845789358498,16.754382460219944,16.57091913108132,16.387455801942757,16.203992472804188,16.020529143665648,15.837065814527023,15.653602485388468,15.470139156249914,15.294304126745647,15.122908162191647,14.951512197637596,14.780116233083636,14.60872026852956,14.437324303975583,14.265928339421546,14.09453237486756,13.925538294071703,13.765138454843346,13.604738615614988,13.444338776386646,13.283938937158252,13.123539097929894,12.963139258701572,12.80273941947318,12.647557610861298,12.497200021864737,12.346842432868138,12.19648484387161,12.04612725487498,11.895769665878461,11.745412076881882,11.599161057875456,11.45796427651106,11.316767495146662,11.175570713782253,11.034373932417836,10.893177151053438,10.751980369689013,10.61857978021182,10.485759489720483,10.352939199229132,10.22011890873776,10.087298618246418,9.954478327755055,9.828731775461671,9.703733407710637,9.578735039959602,9.453736672208544,9.328738304457492,9.206616666402807,9.090732182304908,8.97484769820704,8.85896321410918,8.74307873001132,8.6283677967052,8.522378476935623,8.416389157166046,8.31039983739641,8.204410517626847,8.10033590787034,8.001348957255056,7.902362006639795,7.803375056024547,7.704388105409273,7.609252372988115,7.515430739413815,7.421609105839517,7.32778747226521,7.237285142068579,7.150037973545741,7.062790805022899,6.975543636500053,6.891936262637792,6.811624378771027,6.731312494904296,6.651000611037545,6.575500774528232,6.501341538293911,6.427182302059579,6.354417873166323,6.285704448821861,6.216991024477435,6.148277600132986,6.066811454186411,5.984364329655053,5.901917205123707,5.819470080592349,5.7370229560609864,5.6545758315296375,5.572128706998283,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[67.59471292189059,67.63204376273188,67.66937460357316,67.70690764092929,67.74545166790925,67.78399569488923,67.82253972186919,67.86108374884917,67.89962777582913,67.93817180280911,67.97671582978907,68.01525985676905,68.05380388374903,68.09234791072899,68.13089193770897,68.16943596468894,68.2079799916689,68.24652401864887,68.28506804562885,68.32361207260882,68.36215609958879,68.40070012656876,68.43924415354874,68.4777881805287,68.51633220750867,68.55487623448866,68.59342026146862,68.63196428844859,68.67050831542858,68.70905234240854,68.7475963693885,68.78614039636848,68.82468442334846,68.86322845032844,68.9017724773084,68.94031650428838,68.97886053126834,69.0174045582483,69.0559485852283,69.09449261220826,69.13303663918823,69.17158066616821,69.21012469314817,69.24866872012815,69.28721274710811,69.32575677408809,69.36430080106805,69.40284482804803,69.44138885502801,69.47993288200797,69.51847690898795,69.55702093596793,69.59556496294789,69.63410898992785,69.67265301690783,69.71119704388781,69.74974107086777,69.78828509784775,69.82682912482773,69.86537315180769,69.90391717878767,69.94246120576764,69.9810052327476,70.01954925972757,70.05809328670755,70.09663731368752,70.13518134066749,70.17372536764746,70.21226939462744,70.2508134216074,70.28935744858738,70.32790147556734,70.36644550254732,70.40498952952728,70.44353355650726,70.48207758348724,70.5206216104672,70.55916563744717,70.59770966442714,70.63625369140712,70.6747977183871,70.71334174536706,70.75188577234702,70.790429799327,70.80287942733587,70.81011017555049,70.81734092376512,70.82746531888091,70.83758971679913,70.84771411471736,70.8578385126356,70.86796291055381,70.87808730847205,70.88821170639028,70.8983361043085,70.90846050222673,70.91858490014496,70.92870929806318,70.93883369598142,70.94895809389965,70.95908249181787,70.9692068897361,70.97933128765432,70.98945568557255,70.99958008349077,71.009704481409,71.01982887932724,71.02995327724545,71.04007767516369,71.05020207308192,71.06032647100014,71.07045086891837,71.0805752668366,71.09069966475482,71.10082406267304,71.11094846059129,71.1210728585095,71.13119725642773,71.14132165434597,71.15144605226419,71.16157045018241,71.17169484810064,71.18181924601888,71.1919436439371,71.20206804185531,71.21219243977356,71.22231683769178,71.23244123561001,71.24256563352823,71.25269003144646,71.2628144293647,71.27293882728291,71.28306322520115,71.29318762311937,71.3033120210376,71.31343641895583,71.32356081687405,71.33368521479228,71.34380961271052,71.35393401062873,71.36405840854697,71.3741828064652,71.38430720438342,71.39443160230165,71.40455600021988,71.4146803981381,71.42480479605634,71.43492919397455,71.44505359189279,71.455177989811,71.46530238772924,71.47542678564747,71.48555118356569,71.49567558148392,71.50579997940216,71.51592437732037,71.5260487752386,71.53617317315683,71.54629757107506,71.55642196899328,71.56654636691151,71.57667076482974,71.58679516274798,71.5969195606662,71.60704395858443,71.61716835650265,71.62729275442088,71.26568713794171,70.7182165142639,70.17074589058603,69.62740856012417,69.09738970530015,68.56737085047608,68.03735199565205,67.507333140828,66.97731428600396,66.44729543117992,65.91727657635586,65.38725772153184,64.85723886670779,64.32722001188374,63.79720115705972,63.26718230223567,62.73716344741162,62.20714459258757,61.677125737763525,61.147106882939504,60.617088028115454,60.087069173291404,59.55705031846738,59.02703146364331,58.49701260881929,57.96699375399524,57.4369748991712,56.90695604434717,56.3769371895231,55.84691833469908,55.316899479875026,54.78688062505098,54.25686177022696,53.726842915402905,53.19682406057886,52.66680520575481,52.13678635093077,51.60676749610675,51.07674864128269,50.54672978645865,50.01671093163463,49.486692076810584,48.956673221986534,48.42665436716248,47.896635512338435,47.366616657514385,46.83659780269036,46.30657894786631,45.776560093042264,45.246541238218214,44.716522383394164,44.18650352857014,43.65648467374611,43.12646581892205,42.596446964098,42.066428109273986,41.536409254449936,41.006390399625886,40.476371544801836,39.946352689977786,39.416333835153765,38.886314980329715,38.35629612550568,37.82627727068162,37.296258415857594,36.76623956103355,36.23622070620951,35.70620185138546,35.17618299656141,34.64616414173739,34.11614528691334,33.58612643208929,33.056107577265244,32.526088722441195,31.996069867617166,31.466051012793123,30.936032157969073,30.40601330314503,29.875994448321002,29.345975593496952,28.81595673867291,28.28593788384886,27.755919029024813,27.377369459023573,27.15028917384516,26.92320888866668,26.69612860348836,26.469048318309866,26.24196803313155,26.014887747953072,25.78780746277458,25.560727177596206,25.333646892417818,25.106566607239404,24.87948632206091,24.652406036882553,24.427244207093594,24.209276571561805,23.99130893603017,23.773341300498473,23.555373664966677,23.337406029434977,23.119438393903273,22.901470758371552,22.68350312283984,22.465535487308152,22.247567851776363,22.029600216244642,21.811632580712978,21.598020914666144,21.389343442304767,21.18066596994347,20.97198849758217,20.763311025220865,20.55463355285949,20.34595608049827,20.137278608136892,19.928601135775615,19.71992366341428,19.51124619105302,19.302948673100932,19.10633478520865,18.909720897316376,18.713107009424085,18.51649312153175,18.319879233639533,18.123265345747182,17.926651457854895,17.730037569962658,17.53342368207034,17.33680979417802,17.149504725793943,16.96604139665533,16.782578067516763,16.599114738378212,16.415651409239654,16.232188080101032,16.048724750962467,15.865261421823895,15.681798092685355,15.50247214701634,15.331076182462338,15.15968021790834,14.988284253354326,14.816888288800325,14.645492324246272,14.474096359692311,14.302700395138235,14.131304430584258,13.968802942553614,13.808403103325215,13.648003264096877,13.48760342486852,13.327203585640163,13.166803746411817,13.006403907183428,12.846004067955068,12.695646477572247,12.545288888575685,12.394931299579119,12.244573710582559,12.09421612158596,11.943858532589433,11.793500943592802,11.65072471370333,11.50952793233893,11.368331150974488,11.22713436961009,11.08593758824569,10.944740806881281,10.805360613980811,10.672540323489436,10.539720032998083,10.406899742506733,10.274079452015394,10.141259161524042,10.00925507102943,9.884256703278396,9.75925833552733,9.634259967776288,9.509261600025253,9.384263232274218,9.263236278584008,9.147351794486148,9.031467310388289,8.91558282629039,8.79969834219252,8.685440826124148,8.57945150635457,8.473462186584985,8.367472866815408,8.261483547045831,8.157244819257901,8.058257868642649,7.959270918027393,7.8602839674121086,7.761297016796847,7.665705903772182,7.571884270197877,7.478062636623571,7.384241003049271,7.292760520739383,7.20551335221654,7.118266183693703,7.031019015170866,6.945985235242807,6.865673351376064,6.785361467509322,6.705049583642555,6.627955138910184,6.553795902675867,6.479636666441568,6.405477430207247,6.336472915985904,6.267759491641477,6.199046067297015,6.122484814274357,6.040037689743004,5.9575905652116425,5.875143440680284,5.792696316148938,5.71024919161758,5.627802067086218,5.5453549425548685,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[67.53929570452085,67.57662654536213,67.61395738620341,67.6512882270447,67.68861906788598,67.72594990872726,67.76328074956855,67.80061159040983,67.83794243125112,67.8752732720924,67.91260411293368,67.94993495377496,67.98726579461625,68.02459663545753,68.06192747629882,68.09925831714011,68.13658915798139,68.17391999882267,68.21125083966395,68.24858168050523,68.28672131073053,68.3252653377105,68.36380936469047,68.40235339167045,68.44089741865041,68.47944144563039,68.51798547261036,68.55652949959033,68.5950735265703,68.63361755355027,68.67216158053024,68.71070560751022,68.74924963449018,68.78779366147016,68.82633768845012,68.8648817154301,68.90342574241008,68.94196976939004,68.98051379637002,69.01905782334998,69.05760185032996,69.09614587730994,69.1346899042899,69.17323393126988,69.21177795824984,69.25032198522982,69.2888660122098,69.32741003918976,69.36595406616973,69.4044980931497,69.44304212012968,69.48158614710965,69.52013017408962,69.55867420106958,69.59721822804956,69.63576225502953,69.6743062820095,69.71285030898949,69.75139433596945,69.78993836294941,69.8284823899294,69.86702641690937,69.90557044388933,69.94411447086931,69.98265849784927,70.02120252482925,70.05974655180923,70.09829057878919,70.13683460576917,70.17537863274914,70.2139226597291,70.25246668670908,70.29101071368905,70.32955474066901,70.368098767649,70.40664279462897,70.44518682160894,70.48373084858892,70.52227487556888,70.56081890254886,70.59936292952882,70.6379069565088,70.67645098348876,70.71499501046874,70.72744463847759,70.73467538669222,70.74190613490686,70.74913688312148,70.7563676313361,70.76359837955073,70.77082912776537,70.77805987597999,70.78529062419463,70.79252137240925,70.79975212062388,70.8069828688385,70.81421361705314,70.82144436526777,70.82867511348239,70.83590586169703,70.84313660991165,70.85036735812628,70.8575981063409,70.86627567612746,70.87640007404568,70.88652447196391,70.89664886988213,70.90677326780036,70.91689766571858,70.92702206363681,70.93714646155505,70.94727085947328,70.9573952573915,70.96751965530973,70.97764405322795,70.98776845114618,70.9978928490644,71.00801724698263,71.01814164490088,71.02826604281908,71.03839044073732,71.04851483865554,71.05863923657375,71.068763634492,71.07888803241022,71.08901243032845,71.09913682824669,71.1092612261649,71.11938562408314,71.12951002200137,71.13963441991959,71.14975881783782,71.15988321575605,71.17000761367427,71.1801320115925,71.19025640951074,71.20038080742896,71.21050520534719,71.22062960326542,71.23075400118364,71.24087839910187,71.2510027970201,71.26112719493833,71.27125159285656,71.28137599077476,71.29150038869301,71.30162478661124,71.31174918452948,71.3218735824477,71.33199798036591,71.34212237828415,71.35224677620238,71.3623711741206,71.37249557203883,71.38261996995706,71.39274436787528,71.40286876579351,71.41299316371175,71.42311756162997,71.4332419595482,71.44336635746642,71.45349075538465,71.46361515330288,71.4737395512211,71.48386394913933,71.49398834705757,71.50411274497579,71.14250712849662,70.5950365048188,70.04756588114093,69.50009525746307,68.95262463378525,68.40515401010738,67.85768338642956,67.3102127627517,66.76274213907385,66.21527151539603,65.66780089171814,65.12033026804032,64.57285964436247,64.02538902068463,63.477918397006796,62.93044777332894,62.38297714965109,61.835506525973244,61.28803590229539,60.74056527861757,60.19309465493971,59.64562403126186,59.09815340758404,58.55527533071151,58.02525647588748,57.49523762106344,56.965218766239396,56.43519991141536,55.9051810565913,55.375162201767274,54.845143346943225,54.31512449211918,53.78510563729515,53.2550867824711,52.72506792764706,52.19504907282301,51.66503021799897,51.13501136317494,50.60499250835089,50.07497365352685,49.54495479870282,49.014935943878776,48.484917089054726,47.954898234230676,47.42487937940663,46.89486052458258,46.364841669758555,45.834822814934505,45.30480396011046,44.77478510528641,44.24476625046236,43.71474739563834,43.1847285408143,42.65470968599025,42.1246908311662,41.59467197634218,41.06465312151813,40.534634266694084,40.004615411870034,39.474596557045984,38.94457770222196,38.41455884739791,37.88453999257387,37.35452113774982,36.82450228292579,36.29448342810175,35.7644645732777,35.23444571845366,34.70442686362961,34.174408008805585,33.644389153981535,33.114370299157486,32.58435144433344,32.05433258950939,31.524313734685368,30.99429487986132,30.46427602503727,29.934257170213225,29.4042383153892,28.87421946056515,28.344200605741108,27.814181750917058,27.284162896093008,26.905613326091768,26.67853304091336,26.45145275573488,26.22437247055656,25.99729218537807,25.770211900199747,25.54313161502127,25.31605132984278,25.0889710446644,24.861890759486016,24.63972651185762,24.421758876325907,24.20379124079413,23.98582360526243,23.76785596973064,23.549888334199004,23.331920698667304,23.11395306313551,22.895985427603808,22.678017792072108,22.460050156540383,22.24208252100867,22.024114885476983,21.81189096165863,21.603213489297257,21.394536016935895,21.18585854457466,20.977181072213288,20.76850359985199,20.55982612749069,20.351148655129386,20.14247118276801,19.93379371040679,19.725116238045413,19.516676236798034,19.320062348905818,19.123448461013478,18.92683457312119,18.730220685228907,18.533606797336635,18.336992909444344,18.140379021552008,17.94376513365979,17.747151245767444,17.550537357875154,17.361163662229313,17.177700333090744,16.994237003952236,16.810773674813678,16.627310345675063,16.443847016536502,16.260383687397947,16.07692035825939,15.893457029120768,15.71064016728711,15.53924420273312,15.367848238179057,15.196452273625043,15.025056309071042,14.853660344517044,14.68226437996303,14.510868415409028,14.339472450854977,14.172467430263865,14.012067591035562,13.85166775180717,13.691267912578812,13.530868073350414,13.370468234122077,13.21006839489372,13.049668555665363,12.894092933279815,12.743735344283216,12.593377755286685,12.443020166290086,12.292662577293527,12.14230498829696,11.9919473993004,11.843485150895594,11.702288369531187,11.561091588166779,11.419894806802379,11.278698025437983,11.137501244073537,10.99630446270914,10.859321157258439,10.726500866767086,10.59368057627574,10.460860285784362,10.328039995293011,10.195219704801659,10.064779998846145,9.939781631095103,9.814783263344058,9.689784895593023,9.564786527841958,9.439788160090915,9.319855890765233,9.203971406667371,9.088086922569502,8.97220243847164,8.856317954373782,8.742513855543109,8.636524535773525,8.530535216003948,8.42454589623437,8.318556576464786,8.214153730645485,8.115166780030231,8.016179829414966,7.917192878799714,7.818205928184459,7.722159434556267,7.628337800981961,7.534516167407648,7.440694533833343,7.348235899410209,7.260988730887354,7.173741562364518,7.086494393841676,7.000034207847836,6.919722323981093,6.839410440114346,6.759098556247603,6.6804095032921875,6.606250267057849,6.532091030823528,6.4579317945892125,6.387241383149982,6.318527958805521,6.249814534461065,6.178158174362309,6.095711049830948,6.013263925299597,5.930816800768243,5.8483696762368815,5.765922551705524,5.683475427174178,5.60102830264282,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[67.48387848715112,67.5212093279924,67.55854016883367,67.59587100967497,67.63320185051624,67.67053269135752,67.70786353219881,67.74519437304009,67.78252521388137,67.81985605472266,67.85718689556396,67.89451773640522,67.93184857724651,67.96917941808779,68.00651025892908,68.04384109977036,68.08117194061165,68.11850278145292,68.15583362229421,68.1931644631355,68.23049530397678,68.26782614481806,68.30515698565935,68.34248782650063,68.37981866734191,68.4171495081832,68.45448034902448,68.49181118986577,68.52914203070704,68.56647287154833,68.6038037123896,68.6411345532309,68.67846539407218,68.71579623491347,68.75312707575475,68.79045791659603,68.8279909535518,68.86653498053177,68.90507900751174,68.94362303449171,68.98216706147169,69.02071108845166,69.05925511543163,69.0977991424116,69.13634316939157,69.17488719637154,69.21343122335152,69.25197525033148,69.29051927731146,69.32906330429142,69.3676073312714,69.40615135825138,69.44469538523134,69.48323941221132,69.52178343919128,69.56032746617126,69.59887149315122,69.6374155201312,69.67595954711118,69.71450357409114,69.75304760107113,69.7915916280511,69.83013565503106,69.86867968201103,69.907223708991,69.94576773597097,69.98431176295095,70.02285578993092,70.06139981691089,70.09994384389087,70.13848787087083,70.17703189785081,70.21557592483077,70.25411995181075,70.29266397879073,70.33120800577069,70.36975203275067,70.40829605973065,70.44684008671061,70.48538411369059,70.52392814067055,70.56247216765053,70.60101619463049,70.63956022161048,70.65200984961932,70.65924059783394,70.66647134604858,70.6737020942632,70.68093284247783,70.68816359069245,70.6953943389071,70.70262508712172,70.70985583533636,70.71708658355098,70.7243173317656,70.73154807998023,70.73877882819485,70.74600957640949,70.75324032462413,70.76047107283875,70.76770182105338,70.774932569268,70.78216331748263,70.78939406569727,70.79662481391189,70.80385556212653,70.81108631034115,70.81831705855578,70.8255478067704,70.83277855498504,70.84000930319966,70.84724005141429,70.85447079962893,70.86170154784355,70.86893229605818,70.8761630442728,70.88339379248744,70.89062454070206,70.8978552889167,70.90508603713133,70.91521043129221,70.92533482921044,70.93545922712866,70.9455836250469,70.95570802296511,70.96583242088334,70.97595681880156,70.98608121671981,70.99620561463803,71.00633001255626,71.0164544104745,71.02657880839271,71.03670320631095,71.04682760422916,71.0569520021474,71.06707640006562,71.07720079798385,71.08732519590208,71.0974495938203,71.10757399173853,71.11769838965677,71.12782278757498,71.13794718549322,71.14807158341145,71.15819598132967,71.16832037924789,71.17844477716612,71.18856917508435,71.19869357300257,71.2088179709208,71.21894236883904,71.22906676675726,71.23919116467549,71.24931556259372,71.25943996051195,71.26956435843017,71.2796887563484,71.28981315426662,71.29993755218486,71.31006195010309,71.32018634802131,71.33031074593954,71.34043514385777,71.35055954177598,71.36068393969421,71.37080833761244,71.38093273553068,71.01932711905151,70.47185649537369,69.92438587169583,69.37691524801797,68.82944462434014,68.28197400066227,67.73450337698445,67.1870327533066,66.63956212962874,66.09209150595092,65.54462088227304,64.99715025859521,64.44967963491736,63.90220901123951,63.35473838756169,62.807267763883836,62.25979714020599,61.71232651652814,61.164855892850284,60.61738526917246,60.069914645494606,59.52244402181675,58.97497339813893,58.42750277446105,57.88003215078322,57.332561527105376,56.78509090342753,56.237620279749706,55.690149656071824,55.14267903239399,54.59520840871615,54.047737785038294,53.50026716136047,52.952796537682616,52.40532591400477,51.85785529032692,51.31038466664907,50.76291404297124,50.21544341929339,49.66797279561554,49.120502171937716,48.57303154825986,48.02556092458201,47.48314210129883,46.95312324647479,46.42310439165074,45.89308553682672,45.36306668200267,44.833047827178625,44.303028972354575,43.773010117530525,43.242991262706504,42.712972407882454,42.182953553058404,41.65293469823436,41.12291584341034,40.59289698858629,40.06287813376224,39.5328592789382,39.002840424114154,38.47282156929012,37.942802714466076,37.41278385964203,36.88276500481798,36.35274614999396,35.822727295169905,35.29270844034586,34.76268958552181,34.23267073069776,33.70265187587374,33.1726330210497,32.64261416622565,32.112595311401606,31.582576456577552,31.052557601753527,30.52253874692948,29.992519892105435,29.462501037281385,28.93248218245736,28.402463327633313,27.872444472809264,27.342425617985217,26.81240676316117,26.43385719315993,26.206776907981524,25.97969662280304,25.752616337624723,25.525536052446228,25.29845576726791,25.07137548208943,24.852208816621538,24.634241181089823,24.41627354555813,24.19830591002641,23.9803382744947,23.762370638962924,23.54440300343122,23.326435367899432,23.108467732367796,22.890500096836096,22.6725324613043,22.454564825772604,22.236597190240904,22.025761008651017,21.81708353628971,21.60840606392836,21.399728591567115,21.191051119205742,20.982373646844373,20.773696174483145,20.56501870212177,20.356341229760474,20.147663757399172,19.938986285037867,19.730403800495164,19.5337899126029,19.337176024710608,19.14056213681826,18.94394824892604,18.747334361033708,18.550720473141414,18.354106585249134,18.15749269735686,17.96087880946457,17.764264921572238,17.572822598664754,17.38935926952619,17.205895940387567,17.022432611249023,16.838969282110455,16.655505952971943,16.47204262383339,16.288579294694774,16.10511596555621,15.921652636417654,15.74741222300381,15.576016258449847,15.404620293895787,15.233224329341795,15.061828364787734,14.89043240023372,14.719036435679719,14.54764047112572,14.376244506571705,14.215732078745738,14.055332239517437,13.894932400289036,13.734532561060737,13.574132721832346,13.413732882603988,13.253333043375587,13.09293320414725,12.942181799990763,12.791824210994196,12.641466621997637,12.491109033001038,12.340751444004507,12.19039385500791,12.040036266011349,11.895048806723455,11.753852025359022,11.612655243994624,11.471458462630217,11.330261681265808,11.189064899901409,11.04786811853701,10.913281700536066,10.780461410044687,10.647641119553345,10.514820829061994,10.382000538570647,10.24918024807927,10.12030492666286,9.995306558911784,9.87030819116076,9.745309823409716,9.620311455658673,9.495313087907638,9.376475502946441,9.260591018848572,9.144706534750712,9.028822050652849,8.912937566554982,8.799586884962055,8.693597565192478,8.587608245422894,8.481618925653311,8.375629605883734,8.271062642033053,8.172075691417792,8.073088740802538,7.974101790187284,7.875114839572021,7.778612965340351,7.684791331766051,7.590969698191723,7.4971480646174165,7.40371127808102,7.3164641095581775,7.229216941035334,7.141969772512479,7.054722603989642,6.973771296586108,6.893459412719365,6.813147528852623,6.732863867674155,6.658704631439838,6.584545395205524,6.510386158971185,6.438009850314018,6.369296425969562,6.300583001625136,6.2318695772806745,6.151384409918894,6.068937285387539,5.986490160856179,5.904043036324829,5.821595911793475,5.739148787262113,5.656701662730755,5.57425453819941,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[67.42846126978138,67.46579211062266,67.50312295146394,67.54045379230523,67.5777846331465,67.6151154739878,67.65244631482908,67.68977715567036,67.72710799651165,67.76443883735293,67.8017696781942,67.8391005190355,67.87643135987678,67.91376220071807,67.95109304155935,67.98842388240064,68.0257547232419,68.0630855640832,68.10041640492447,68.13774724576577,68.17507808660704,68.21240892744834,68.2497397682896,68.2870706091309,68.32440144997219,68.36173229081346,68.39906313165474,68.43639397249603,68.47372481333731,68.51105565417859,68.54838649501988,68.58571733586116,68.62304817670244,68.66037901754373,68.69770985838501,68.73504069922629,68.77237154006758,68.80970238090886,68.84703322175015,68.88436406259143,68.92169490343272,68.95902574427399,68.99635658511528,69.03368742595657,69.07101826679785,69.10834910763913,69.1456799484804,69.1830107893217,69.22034163016298,69.25767247100426,69.29500331184555,69.33233415268683,69.3696649935281,69.40780462335304,69.44634865033302,69.48489267731298,69.52343670429296,69.56198073127294,69.6005247582529,69.63906878523288,69.67761281221286,69.71615683919282,69.7547008661728,69.79324489315276,69.83178892013274,69.87033294711271,69.90887697409268,69.94742100107266,69.98596502805262,70.0245090550326,70.06305308201257,70.10159710899254,70.14014113597251,70.17868516295249,70.21722918993245,70.25577321691243,70.2943172438924,70.33286127087237,70.37140529785233,70.40994932483233,70.44849335181229,70.48703737879225,70.52558140577221,70.5641254327522,70.57657506076104,70.58380580897568,70.59103655719031,70.59826730540493,70.60549805361956,70.6127288018342,70.61995955004882,70.62719029826344,70.63442104647807,70.6416517946927,70.64888254290733,70.65611329112195,70.66334403933661,70.67057478755122,70.67780553576586,70.68503628398048,70.6922670321951,70.69949778040974,70.70672852862437,70.71395927683899,70.72119002505362,70.72842077326825,70.73565152148288,70.7428822696975,70.75011301791214,70.75734376612677,70.76457451434139,70.77180526255601,70.77903601077065,70.78626675898528,70.7934975071999,70.80072825541454,70.80795900362916,70.81518975184379,70.82242050005843,70.82965124827305,70.83688199648768,70.8441127447023,70.85134349291693,70.85857424113158,70.86580498934619,70.87303573756083,70.88026648577545,70.88749723399008,70.8947279822047,70.90195873041934,70.90918947863396,70.91642022684859,70.92365097506323,70.93088172327785,70.93811247149247,70.94534321970711,70.95402078853874,70.96414518645696,70.9742695843752,70.98439398229343,70.99451838021164,71.00464277812988,71.0147671760481,71.02489157396633,71.03501597188455,71.04514036980278,71.05526476772101,71.06538916563923,71.07551356355746,71.0856379614757,71.09576235939392,71.10588675731215,71.11601115523038,71.1261355531486,71.13625995106683,71.14638434898507,71.15650874690328,71.1666331448215,71.17675754273974,71.18688194065797,71.19700633857619,71.20713073649442,71.21725513441265,71.22737953233089,71.2375039302491,71.24762832816734,71.25775272608556,70.89614710960639,70.34867648592858,69.80120586225071,69.25373523857286,68.70626461489505,68.15879399121717,67.61132336753933,67.06385274386149,66.51638212018364,65.96891149650581,65.42144087282793,64.8739702491501,64.32649962547227,63.779029001794406,63.231558378116574,62.68408775443873,62.13661713076088,61.58914650708303,61.041675883405176,60.49420525972735,59.9467346360495,59.39926401237165,58.85179338869382,58.30432276501594,57.756852141338115,57.20938151766027,56.661910893982416,56.11444027030459,55.56696964662672,55.01949902294889,54.47202839927104,53.92455777559318,53.37708715191536,52.82961652823751,52.282145904559655,51.73467528088181,51.187204657203964,50.63973403352614,50.09226340984827,49.544792786170426,48.9973221624926,48.449851538814755,47.90238091513691,47.35491029145905,46.807439667781196,46.25996904410334,45.71249842042552,45.16502779674768,44.61755717306982,44.07008654939197,43.52261592571412,42.975145302036296,42.42767467835844,41.88020405468059,41.33273343100274,40.78526280732491,40.23779218364706,39.69032155996922,39.14285093629136,38.595380312613514,38.04790968893569,37.50043906525784,36.95296844157998,36.41100887188614,35.88099001706212,35.35097116223807,34.82095230741402,34.290933452589975,33.760914597765925,33.230895742941904,32.700876888117854,32.17085803329381,31.64083917846976,31.11082032364571,30.58080146882169,30.05078261399764,29.520763759173594,28.990744904349544,28.46072604952552,27.930707194701473,27.400688339877426,26.87066948505338,26.340650630229327,25.962101060228086,25.73502077504968,25.5079404898712,25.282658756917247,25.064691121385533,24.84672348585383,24.628755850322054,24.410788214790337,24.192820579258623,23.97485294372693,23.756885308195212,23.538917672663498,23.320950037131723,23.102982401600023,22.88501476606823,22.6670471305366,22.4490794950049,22.23963105564348,22.030953583282116,21.82227611092082,21.61359863855951,21.4049211661982,21.19624369383685,20.987566221475603,20.778888749114227,20.570211276752865,20.361533804391634,20.15285633203026,19.944178859668963,19.747517476300033,19.550903588407685,19.354289700515395,19.15767581262313,18.961061924730842,18.76444803683849,18.567834148946275,18.37122026105394,18.174606373161648,17.977992485269368,17.78448153510019,17.60101820596157,17.417554876823015,17.234091547684457,17.050628218545896,16.86716488940727,16.683701560268727,16.500238231130158,16.316774901991646,16.133311572853092,15.955580243274555,15.784184278720542,15.612788314166542,15.44139234961249,15.26999638505853,15.098600420504468,14.927204455950475,14.755808491396415,14.5844125268424,14.419396566456012,14.258996727227666,14.098596887999308,13.938197048770919,13.777797209542616,13.617397370314217,13.456997531085916,13.296597691857524,13.140628255698307,12.99027066670174,12.83991307770519,12.68955548870858,12.539197899712013,12.388840310715455,12.238482721718853,12.088125132722327,11.946612462551297,11.805415681186899,11.66421889982249,11.523022118458055,11.381825337093657,11.24062855572925,11.100062534305017,10.967242243813676,10.834421953322328,10.701601662830978,10.568781372339599,10.435961081848257,10.303140791356904,10.175829854479554,10.05083148672852,9.925833118977476,9.8008347512264,9.675836383475374,9.550838015724333,9.433095115127642,9.317210631029782,9.201326146931923,9.085441662834054,8.969557178736192,8.856659914381032,8.750670594611448,8.644681274841844,8.538691955072267,8.432702635302682,8.327971553420639,8.228984602805387,8.129997652190108,8.031010701574846,7.932023750959592,7.835066496124409,7.741244862550104,7.6474232289758035,7.5536015954015046,7.459779961827177,7.371939488228977,7.284692319706146,7.197445151183303,7.110197982660461,7.027820269191149,6.947508385324406,6.86719650145764,6.786884617590896,6.711158995821811,6.636999759587489,6.562840523353173,6.488778317478067,6.420064893133606,6.351351468789174,6.282638044444717,6.207057770006834,6.1246106454754745,6.042163520944126,5.959716396412771,5.87726927188141,5.79482214735006,5.712375022818707,5.629927898287345,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[67.37304405241164,67.41037489325292,67.4477057340942,67.48503657493549,67.52236741577677,67.55969825661806,67.59702909745934,67.63435993830062,67.67169077914191,67.70902161998319,67.74635246082448,67.78368330166575,67.82101414250704,67.85834498334833,67.89567582418961,67.93300666503089,67.97033750587217,68.00766834671346,68.04499918755474,68.08233002839603,68.11966086923731,68.15699171007859,68.19432255091988,68.23165339176117,68.26898423260243,68.30631507344373,68.34364591428502,68.38097675512628,68.41830759596758,68.45563843680887,68.49296927765013,68.53030011849143,68.5676309593327,68.604961800174,68.64229264101527,68.67962348185657,68.71695432269784,68.75428516353912,68.79161600438042,68.8289468452217,68.86627768606297,68.90360852690426,68.94093936774554,68.97827020858682,69.01560104942811,69.05293189026939,69.09026273111068,69.12759357195196,69.16492441279324,69.20225525363452,69.23958609447581,69.27691693531709,69.31424777615837,69.35157861699966,69.38890945784095,69.42624029868223,69.46357113952351,69.5009019803648,69.53823282120608,69.57556366204736,69.61289450288864,69.65022534372993,69.6875561845712,69.72488702541249,69.76221786625378,69.79954870709507,69.83687954793635,69.87421038877763,69.9115412296189,69.94907426617432,69.9876182931543,70.02616232013426,70.06470634711424,70.10325037409422,70.14179440107418,70.18033842805416,70.21888245503412,70.2574264820141,70.29597050899406,70.33451453597405,70.37305856295401,70.41160258993399,70.45014661691395,70.48869064389393,70.50114027190278,70.50837102011741,70.51560176833203,70.52283251654666,70.53006326476128,70.53729401297592,70.54452476119056,70.55175550940518,70.55898625761981,70.56621700583443,70.57344775404907,70.5806785022637,70.58790925047833,70.59513999869296,70.6023707469076,70.60960149512222,70.61683224333683,70.62406299155147,70.63129373976611,70.63852448798073,70.64575523619536,70.65298598440998,70.6602167326246,70.66744748083923,70.67467822905387,70.6819089772685,70.68913972548313,70.69637047369775,70.70360122191238,70.710831970127,70.71806271834163,70.72529346655627,70.73252421477089,70.73975496298551,70.74698571120015,70.75421645941478,70.76144720762942,70.76867795584403,70.77590870405866,70.7831394522733,70.79037020048793,70.79760094870255,70.80483169691718,70.8120624451318,70.81929319334643,70.82652394156106,70.8337546897757,70.84098543799033,70.84821618620495,70.85544693441958,70.86267768263421,70.86990843084884,70.87713917906348,70.8843699272781,70.89160067549273,70.89883142370735,70.90606217192197,70.91329292013661,70.92052366835124,70.92775441656588,70.9349851647805,70.94221591299512,70.94944666120975,70.95667740942437,70.96390815763901,70.97113890585365,70.97836965406827,70.9856004022829,70.99283115049752,71.00295554370351,71.01307994162174,71.02320433953997,71.03332873745819,71.04345313537641,71.05357753329464,71.06370193121288,71.0738263291311,71.08395072704933,71.09407512496756,71.10419952288578,71.11432392080401,71.12444831872224,71.13457271664046,70.7729671001613,70.22549647648347,69.67802585280562,69.13055522912775,68.58308460544994,68.03561398177206,67.48814335809423,66.94067273441638,66.39320211073854,65.8457314870607,65.29826086338284,64.75079023970501,64.20331961602716,63.655848992349306,63.10837836867149,62.56090774499363,62.013437121315775,61.46596649763792,60.918495873960076,60.371025250282244,59.8235546266044,59.276084002926545,58.72861337924871,58.18114275557084,57.63367213189302,57.08620150821517,56.538730884537316,55.99126026085949,55.44378963718161,54.896319013503785,54.34884838982594,53.801377766148086,53.25390714247026,52.70643651879241,52.15896589511456,51.61149527143671,51.064024647758856,50.51655402408103,49.96908340040318,49.42161277672533,48.8741421530475,48.326671529369655,47.77920090569181,47.23173028201395,46.6842596583361,46.13678903465825,45.589318410980425,45.04184778730257,44.49437716362472,43.946906539946866,43.39943591626902,42.85196529259119,42.30449466891334,41.7570240452355,41.209553421557644,40.66208279787982,40.114612174201966,39.56714155052411,39.01967092684626,38.472200303168414,37.92472967949059,37.37725905581273,36.829788432134876,36.28231780845704,35.73484718477921,35.18737656110136,34.63990593742351,34.09243531374565,33.5449646900678,32.997494066389976,32.45002344271212,31.90255281903427,31.355082195356424,30.807611571678574,30.260140948000746,29.712670324322893,29.165199700645047,28.617729076967194,28.07025845328937,27.522787829611516,26.975317205933667,26.427846582255814,25.879537348541334,25.495141061681196,25.27717342614948,25.05920579061785,24.84123815508607,24.623270519554357,24.405302884022657,24.18733524849088,23.969367612959164,23.751399977427447,23.533432341895757,23.31546470636404,23.097497070832326,22.87952943530055,22.66217857499721,22.453501102635897,22.244823630274603,22.03614615791324,21.82746868555199,21.61879121319063,21.41011374082934,21.201436268468022,20.992758796106713,20.784081323745365,20.57540385138412,20.36672637902274,20.158048906661378,19.96124503999713,19.76463115210484,19.568017264212564,19.371403376320288,19.17478948842794,18.97817560053565,18.781561712643384,18.584947824751094,18.388333936858746,18.19172004896653,17.996140471535604,17.81267714239704,17.62921381325848,17.445750484119927,17.262287154981305,17.07882382584275,16.895360496704193,16.711897167565628,16.528433838427006,16.344970509288462,16.16374826354532,15.992352298991257,15.820956334437255,15.649560369883254,15.478164405329242,15.306768440775242,15.13537247622119,14.96397651166723,14.792580547113168,14.623061054166312,14.462661214937956,14.302261375709598,14.141861536481207,13.981461697252861,13.821061858024505,13.660662018796113,13.500262179567812,13.339862340339412,13.188717122409276,13.038359533412718,12.888001944416146,12.737644355419581,12.587286766423032,12.436929177426423,12.286571588429855,12.139372899743549,11.998176118379149,11.85697933701474,11.715782555650343,11.574585774285945,11.433388992921536,11.292192211557104,11.154023077582684,11.021202787091333,10.888382496599945,10.755562206108603,10.622741915617256,10.489921625125904,10.357101334634525,10.23135478229626,10.106356414545216,9.981358046794181,9.856359679043146,9.731361311292105,9.60636294354103,9.489714727308904,9.373830243211035,9.257945759113138,9.142061275015278,9.026176790917416,8.913732943799983,8.807743624030406,8.70175430426083,8.595764984491245,8.489775664721641,8.38488046480825,8.285893514192965,8.186906563577704,8.08791961296245,7.988932662347171,7.8915200269084735,7.797698393334175,7.703876759759875,7.61005512618557,7.51623349261127,7.427414866899816,7.340167698376953,7.25292052985411,7.1656733613312795,7.081869241796193,7.001557357929428,6.921245474062685,6.840933590195943,6.763613360203804,6.689454123969487,6.615294887735155,6.541135651500834,6.470833360297683,6.402119935953227,6.333406511608766,6.262731130094777,6.180284005563427,6.097836881032073,6.015389756500715,5.9329426319693646,5.850495507438011,5.76804838290665,5.6856012583753,5.603154133843946,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[67.31615853657769,67.35348937741897,67.39082021826025,67.42815105910154,67.46548189994282,67.50281274078411,67.54014358162539,67.57747442246666,67.61480526330796,67.65213610414924,67.68946694499053,67.72679778583179,67.76412862667308,67.80145946751438,67.83879030835566,67.87612114919693,67.91345199003823,67.9507828308795,67.98811367172078,68.02544451256207,68.06277535340335,68.10010619424463,68.13743703508591,68.17476787592722,68.21209871676848,68.24942955760977,68.28676039845105,68.32409123929233,68.36142208013362,68.39875292097491,68.43608376181618,68.47341460265747,68.51074544349875,68.54807628434004,68.58540712518132,68.6227379660226,68.66006880686389,68.69739964770517,68.73473048854646,68.77206132938772,68.80939217022902,68.8467230110703,68.88405385191157,68.92138469275287,68.95871553359414,68.99604637443542,69.03337721527672,69.070708056118,69.10803889695927,69.14536973780056,69.18270057864186,69.22003141948313,69.25736226032441,69.29469310116569,69.33202394200698,69.36935478284826,69.40668562368954,69.44401646453083,69.48134730537211,69.5186781462134,69.55600898705468,69.59333982789596,69.63067066873725,69.66800150957853,69.70533235041981,69.7426631912611,69.77999403210238,69.81732487294366,69.85465571378495,69.89198655462623,69.9293173954675,69.9666482363088,70.00397907715008,70.04130991799137,70.07864075883265,70.11597159967394,70.15330244051522,70.1906332813565,70.22796412219779,70.26529496303907,70.30262580388035,70.33995664239058,70.3759164424753,70.41187624256003,70.42389516608633,70.43112591430096,70.43835666251559,70.44558741073021,70.45281815894485,70.46004890715948,70.4672796553741,70.47451040358874,70.48174115180336,70.48897190001799,70.49620264823261,70.50343339644725,70.51066414466187,70.51789489287651,70.52512564109114,70.53235638930576,70.5395871375204,70.54681788573502,70.55404863394966,70.56127938216429,70.56851013037891,70.57574087859354,70.58297162680816,70.5902023750228,70.59743312323742,70.60466387145205,70.61189461966669,70.61912536788131,70.62635611609593,70.63358686431056,70.6408176125252,70.64804836073982,70.65527910895446,70.66250985716908,70.66974060538371,70.67697135359835,70.68420210181296,70.6914328500276,70.69866359824223,70.70589434645686,70.71312509467148,70.72035584288611,70.72758659110073,70.73481733931537,70.74204808753,70.74927883574462,70.75650958395926,70.76374033217388,70.7709710803885,70.77820182860313,70.78543257681777,70.7926633250324,70.79989407324702,70.80712482146166,70.81435556967628,70.8215863178909,70.82881706610554,70.83604781432017,70.84327856253479,70.85050931074943,70.85774005896405,70.86497080717868,70.8722015553933,70.87943230360794,70.88666305182257,70.8938938000372,70.90112454825183,70.90835529646645,70.91558604468108,70.9228167928957,70.93004754111034,70.93727828932496,70.94450903753959,70.95173978575423,70.95897053396885,70.96620128218348,70.9734320303981,70.98066277861274,70.98789352682736,70.995124275042,71.00235502325663,71.00668791556964,71.0104412437972,70.63644807168211,70.07358164939579,69.51071522710942,68.95328686360608,68.40246192541754,67.85163698722896,67.30081204904042,66.74998711085186,66.19916217266329,65.64833723447477,65.09751229628617,64.54668735809763,63.99586241990907,63.44503748172051,62.89421254353197,62.34338760534341,61.79256266715485,61.241737728966285,60.69091279077774,60.1400878525892,59.589262914400635,59.038437976212066,58.48761303802353,57.93678809983494,57.38596316164641,56.83513822345785,56.28431328526929,55.733488347080744,55.18266340889217,54.63183847070362,54.081013532515065,53.530188594326496,52.97936365613796,52.4285387179494,51.877713779760846,51.32688884157228,50.776063903383715,50.22523896519518,49.67441402700663,49.12358908881806,48.572764150629524,48.021939212440955,47.4711142742524,46.92028933606383,46.36946439787528,45.818639459686715,45.267814521498174,44.71698958330962,44.16616464512105,43.615339706932495,43.064514768743926,42.513689830555386,41.96286489236683,41.41203995417827,40.861215015989714,40.31039007780117,39.759565139612604,39.20874020142405,38.65791526323548,38.107090325046926,37.556265386858385,37.00544044866982,36.45461551048127,35.9037905722927,35.352965634104166,34.802140695915604,34.25131575772704,33.70049081953849,33.14966588134992,32.598840943161385,32.04801600497282,31.49719106678426,30.9463661285957,30.395541190407133,29.844716252218596,29.293891314030038,28.743066375841476,28.192241437652914,27.641416499464377,27.090591561275815,26.539766623087253,25.98894168489869,25.43811674671013,25.053720459849988,24.835752824318277,24.617785188786645,24.399817553254863,24.181849917723152,23.96388228219145,23.745914646659674,23.527947011127957,23.309979375596242,23.09201174006455,22.876048621989664,22.667371149628288,22.45869367726699,22.250016204905695,22.04133873254438,21.832661260183087,21.62398378782172,21.415306315460477,21.206628843099114,20.99795137073782,20.789273898376504,20.5805964260152,20.37191895365385,20.174972603694204,19.978358715801974,19.781744827909694,19.585130940017358,19.388517052125067,19.19190316423279,18.995289276340515,18.798675388448167,18.602061500555877,18.40544761266361,18.20883372477132,18.024336078832476,17.840872749693865,17.65740942055531,17.473946091416746,17.29048276227819,17.107019433139637,16.923556104001015,16.74009277486246,16.556629445723903,16.373166116585335,16.200520319262,16.029124354708006,15.857728390153994,15.686332425599932,15.514936461045933,15.343540496491933,15.172144531937919,15.000748567383917,14.829352602829866,14.66632570264818,14.505925863419824,14.345526024191486,14.185126184963131,14.024726345734774,13.864326506506382,13.703926667278036,13.543526828049679,13.387163578116827,13.236805989120269,13.086448400123658,12.936090811127098,12.78573322213054,12.635375633133968,12.485018044137403,12.334660455140854,12.190936555571419,12.049739774206973,11.908542992842577,11.767346211478179,11.62614943011377,11.484952648749374,11.343755867384974,11.207983620860285,11.075163330368941,10.942343039877596,10.809522749386245,10.676702458894855,10.543882168403513,10.41187807786402,10.286879710112977,10.161881342361943,10.036882974610874,9.911884606859832,9.7868862391088,9.662218823588004,9.546334339490105,9.430449855392238,9.314565371294385,9.198680887196517,9.08279640309862,8.97080597321893,8.864816653449353,8.75882733367977,8.652838013910191,8.546848694140616,8.44178937619579,8.342802425580558,8.243815474965302,8.144828524350018,8.045841573734757,7.947973557692535,7.854151924118234,7.76033029054393,7.666508656969629,7.572687023395329,7.4828902455705935,7.395643077047757,7.30839590852494,7.221148740002079,7.135918214401208,7.055606330534471,6.975294446667723,6.894982562800957,6.816067724585793,6.74190848835146,6.66774925211714,6.593590015882823,6.5216018274617245,6.452888403117264,6.384174978772837,6.315461554428381,6.235957365651373,6.153510241120012,6.071063116588662,5.9886159920573085,5.906168867525951,5.8237217429946,5.741274618463247,5.658827493931884,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[67.24955967081665,67.28689051165793,67.32422135249922,67.3615521933405,67.3988830341818,67.43621387502307,67.47354471586435,67.51087555670563,67.54820639754692,67.58553723838821,67.62286807922949,67.66019892007077,67.69752976091205,67.73486060175334,67.77219144259462,67.80952228343591,67.84685312427717,67.88418396511847,67.92151480595976,67.95884564680104,67.99617648764232,68.03350732848361,68.07083816932489,68.10816901016616,68.14549985100746,68.18283069184874,68.22016153269003,68.2574923735313,68.29482321437258,68.33215405521386,68.36948489605516,68.40681573689645,68.44414657773771,68.481477418579,68.51880825942028,68.55613910026157,68.59346994110285,68.63080078194413,68.66813162278541,68.7054624636267,68.74279330446798,68.78012414530927,68.81745498615055,68.85478582699183,68.89211666783311,68.9294475086744,68.96677834951569,69.00410919035697,69.04144003119825,69.07877087203954,69.11610171288082,69.1534325537221,69.19076339456339,69.22809423540467,69.26542507624596,69.30275591708724,69.34008675792852,69.37741759876981,69.41474843961109,69.45207928045237,69.48941012129366,69.52674096213494,69.56407180297622,69.6014026438175,69.63873348465879,69.67537880353825,69.71133860362298,69.7472984037077,69.78325820379243,69.81921800387717,69.8551778039619,69.89113760404662,69.92709740413135,69.96305720421607,69.99901700430081,70.03497680438554,70.07093660447026,70.10689640455499,70.14285620463971,70.17881600472444,70.21477580480918,70.2507356048939,70.28669540497863,70.32265520506337,70.33467412858967,70.3419048768043,70.34913562501893,70.35636637323356,70.36359712144818,70.37082786966282,70.37805861787744,70.38528936609207,70.39252011430669,70.39975086252133,70.40698161073595,70.41421235895058,70.42144310716522,70.42867385537984,70.43590460359447,70.4431353518091,70.45036610002373,70.45759684823835,70.46482759645298,70.47205834466762,70.47928909288224,70.48651984109688,70.4937505893115,70.50098133752613,70.50821208574077,70.51544283395539,70.52267358217001,70.52990433038464,70.53713507859928,70.5443658268139,70.55159657502853,70.55882732324315,70.56605807145779,70.57328881967241,70.58051956788704,70.58775031610168,70.5949810643163,70.60221181253092,70.60944256074556,70.61667330896019,70.62390405717481,70.63113480538945,70.63836555360407,70.6455963018187,70.65282705003332,70.66005779824796,70.66728854646259,70.67451929467721,70.68175004289185,70.68898079110647,70.6962115393211,70.70344228753572,70.71067303575036,70.71790378396499,70.72513453217961,70.73236528039425,70.73959602860887,70.74682677682351,70.75405752503812,70.76128827325276,70.76851902146738,70.77574976968202,70.78298051789665,70.79021126611127,70.79628287031379,70.80003619854133,70.80378952676888,70.80754285499643,70.81129618322399,70.81504951145152,70.81880283967908,70.82255616790663,70.82630949613417,70.83006282436173,70.83381615258926,70.83756948081681,70.84132280904437,70.84507613727192,70.84882946549946,70.85258279372701,70.85633612195456,70.8600894501821,70.86384277840966,70.48984960629458,69.92698318400824,69.36411676172189,68.80125033943551,68.23838391714918,67.67551749486277,67.11265107257644,66.54978465029008,65.98691822800372,65.42405180571738,64.86118538343098,64.29831896114466,63.735452538858276,63.172586116571914,62.60971969428558,62.04685327199921,61.48398684971285,60.92112042742649,60.35825400514011,59.795387582853785,59.232521160567416,58.669654738281054,58.106788315994706,57.54392189370832,56.98105547142198,56.41818904913561,55.85532262684925,55.29245620456291,54.74124280706096,54.190417868872416,53.639592930683854,53.0887679924953,52.537943054306766,51.9871181161182,51.436293177929635,50.88546823974108,50.33464330155251,49.78381836336398,49.232993425175415,48.68216848698686,48.13134354879831,47.58051861060976,47.02969367242119,46.478868734232634,45.92804379604407,45.37721885785551,44.82639391966697,44.27556898147841,43.724744043289846,43.17391910510129,42.62309416691272,42.07226922872419,41.52144429053563,40.97061935234706,40.4197944141585,39.86896947596997,39.31814453778141,38.767319599592845,38.21649466140428,37.66566972321572,37.11484478502719,36.56401984683862,36.013194908650064,35.462369970461495,34.91154503227296,34.3607200940844,33.80989515589584,33.259070217707276,32.70824527951872,32.15742034133018,31.60659540314162,31.055770464953056,30.504945526764494,29.954120588575933,29.403295650387392,28.852470712198834,28.30164577401027,27.75082083582171,27.199995897633173,26.64917095944461,26.09834602125605,25.547521083067487,24.996696144878925,24.61229985801879,24.394332222487076,24.17636458695544,23.958396951423666,23.74042931589195,23.52246168036025,23.304494044828473,23.089918668982055,22.881241196620753,22.67256372425946,22.463886251898153,22.255208779536776,22.046531307175478,21.837853834814183,21.629176362452867,21.420498890091576,21.211821417730214,21.003143945368965,20.794466473007603,20.58578900064631,20.388700167391338,20.192086279499048,19.995472391606782,19.798858503714435,19.602244615822205,19.405630727929925,19.209016840037588,19.0124029521453,18.815789064253025,18.619175176360745,18.422561288468398,18.235995015267868,18.05253168612932,17.869068356990756,17.68560502785219,17.502141698713576,17.31867836957502,17.135215040436456,16.9517517112979,16.768288382159344,16.584825053020722,16.408688339532702,16.237292374978704,16.06589641042469,15.89450044587068,15.72310448131669,15.551708516762675,15.380312552208615,15.208916587654612,15.037520623100614,14.86999019035845,14.70959035113006,14.54919051190176,14.388790672673359,14.228390833445003,14.067990994216665,13.907591154988307,13.747191315759952,13.58679147653156,13.435252444827777,13.284894855831205,13.134537266834649,12.98417967783809,12.83382208884148,12.683464499844918,12.533106910848364,12.383696992763657,12.242500211399287,12.10130343003486,11.96010664867045,11.818909867306008,11.677713085941612,11.536516304577212,11.395319523212804,11.261944164137892,11.129123873646547,10.996303583155195,10.863483292663853,10.730663002172507,10.597842711681155,10.467403005680701,10.342404637929667,10.217406270178632,10.09240790242759,9.967409534676555,9.842411166925489,9.718838435769205,9.602953951671346,9.487069467573486,9.371184983475587,9.255300499377718,9.139416015279865,9.027879002637905,8.92188968286832,8.81590036309872,8.709911043329141,8.603921723559557,8.498698287583384,8.39971133696813,8.300724386352844,8.201737435737613,8.102750485122359,8.004427088476616,7.910605454902311,7.81678382132799,7.72296218775369,7.629140554179385,7.538365624241418,7.451118455718582,7.36387128719572,7.276624118672884,7.1899671870062365,7.109655303139488,7.029343419272739,6.949031535406002,6.868719651539255,6.794362852733428,6.72020361649913,6.646044380264797,6.572370294625763,6.503656870281306,6.434943445936879,6.366230021592418,6.291630725739317,6.209183601207963,6.126736476676605,6.044289352145244,5.961842227613893,5.8793951030825395,5.796947978551181,5.714500854019832,5.632053729488478,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[67.18296080505563,67.2202916458969,67.25762248673819,67.29495332757948,67.33228416842076,67.36961500926205,67.40694585010333,67.4442766909446,67.4816075317859,67.51893837262718,67.55626921346847,67.59360005430975,67.63093089515102,67.66826173599232,67.7055925768336,67.74292341767489,67.78025425851615,67.81758509935744,67.85491594019872,67.89224678104,67.9295776218813,67.96690846272259,68.00423930356386,68.04157014440514,68.07890098524642,68.11623182608771,68.153562666929,68.19089350777027,68.22822434861156,68.26555518945284,68.30288603029413,68.34021687113541,68.37754771197669,68.41487855281798,68.45220939365926,68.48954023450055,68.52687107534183,68.56420191618311,68.60153275702439,68.63886359786568,68.67619443870696,68.71352527954825,68.75085612038953,68.7881869612308,68.82551780207208,68.86284864291338,68.90017948375467,68.93751032459593,68.97484116460119,69.01080096468591,69.04676076477065,69.08272056485538,69.1186803649401,69.15464016502483,69.19059996510956,69.22655976519428,69.26251956527902,69.29847936536375,69.33443916544847,69.37039896553321,69.40635876561794,69.44231856570266,69.47827836578739,69.51423816587211,69.55019796595685,69.58615776604158,69.6221175661263,69.65807736621105,69.69403716629577,69.7299969663805,69.76595676646522,69.80191656654995,69.83787636663469,69.87383616671941,69.90979596680414,69.94575576688887,69.9817155669736,70.01767536705833,70.05363516714306,70.08959496722778,70.12555476731251,70.16151456739723,70.19747436748196,70.2334341675667,70.24545309109301,70.25268383930764,70.25991458752227,70.2671453357369,70.27437608395152,70.28160683216615,70.28883758038077,70.29606832859541,70.30329907681003,70.31052982502467,70.3177605732393,70.32499132145392,70.33222206966855,70.33945281788318,70.34668356609781,70.35391431431243,70.36114506252707,70.3683758107417,70.37560655895632,70.38283730717096,70.39006805538558,70.39729880360021,70.40452955181485,70.41176030002947,70.4189910482441,70.42622179645872,70.43345254467334,70.44068329288798,70.4479140411026,70.45514478931725,70.46237553753187,70.4696062857465,70.47683703396113,70.48406778217576,70.49129853039038,70.49852927860502,70.50576002681964,70.51299077503427,70.5202215232489,70.52745227146353,70.53468301967816,70.5419137678928,70.54914451610742,70.55637526432204,70.56360601253667,70.57083676075129,70.57806750896592,70.58529825718055,70.58963115328548,70.59338448151303,70.59713780974059,70.60089113796813,70.60464446619568,70.60839779442323,70.61215112265077,70.61590445087833,70.61965777910586,70.62341110733342,70.62716443556097,70.63091776378852,70.63467109201606,70.63842442024361,70.64217774847116,70.64593107669872,70.64968440492626,70.65343773315381,70.65719106138135,70.66094438960891,70.66469771783646,70.66845104606399,70.67220437429155,70.6759577025191,70.67971103074666,70.68346435897419,70.68721768720174,70.69097101542928,70.69472434365683,70.69847767188439,70.70223100011194,70.70598432833948,70.70973765656703,70.71349098479459,70.71724431302214,70.34325114090706,69.78038471862072,69.21751829633435,68.65465187404799,68.09178545176165,67.52891902947526,66.96605260718891,66.40318618490255,65.84031976261619,65.27745334032986,64.71458691804347,64.15172049575712,63.58885407347075,63.025987651184394,62.463121228898046,61.900254806611684,61.33738838432532,60.77452196203895,60.21165553975259,59.64878911746625,59.085922695179896,58.52305627289353,57.960189850607186,57.397323428320796,56.83445700603445,56.271590583748086,55.708724161461724,55.14585773917539,54.58299131688899,54.02012489460266,53.4572584723163,52.89439205002992,52.33152562774359,51.76865920545722,51.205792783170864,50.642926360884495,50.080059938598126,49.51719351631179,48.95432709402543,48.391460671739054,47.82859424945272,47.26572782716636,46.70286140488,46.13999498259363,45.57712856030726,45.0142621380209,44.451395715734556,43.888529293448194,43.325662871161825,42.76279644887546,42.1999300265891,41.63706360430275,41.08002368870446,40.52919875051589,39.978373812327334,39.42754887413879,38.87672393595024,38.325898997761676,37.775074059573114,37.22424912138455,36.67342418319601,36.12259924500745,35.571774306818895,35.020949368630326,34.47012443044179,33.91929949225323,33.36847455406467,32.81764961587611,32.26682467768755,31.715999739499008,31.165174801310446,30.614349863121884,30.063524924933322,29.512699986744764,28.961875048556223,28.411050110367665,27.860225172179103,27.30940023399054,26.758575295802004,26.207750357613442,25.65692541942488,25.106100481236318,24.555275543047756,24.170879256187618,23.952911620655904,23.734943985124268,23.51697634959249,23.30378871597454,23.09511124361318,22.886433771251948,22.677756298890568,22.469078826529266,22.26040135416798,22.05172388180667,21.843046409445293,21.63436893708399,21.4256914647227,21.217013992361384,21.00833652000009,20.799659047638727,20.602427731088497,20.40581384319622,20.20919995530388,20.012586067411593,19.815972179519303,19.619358291627037,19.42274440373469,19.22613051584246,19.02951662795018,18.832902740057843,18.636288852165556,18.44765395170334,18.264190622564787,18.080727293426225,17.8972639642876,17.713800635149052,17.53033730601049,17.346873976871926,17.16341064773331,16.979947318594757,16.796483989456192,16.616856359803467,16.445460395249466,16.274064430695454,16.102668466141402,15.931272501587403,15.759876537033389,15.588480572479378,15.41708460792539,15.245688643371373,15.074292678817313,14.913254838840349,14.752854999611957,14.592455160383647,14.432055321155255,14.271655481926954,14.111255642698556,13.950855803470196,13.790455964241861,13.633698900535343,13.483341311538734,13.332983722542217,13.182626133545618,13.032268544549046,12.88191095555249,12.73155336655593,12.58119577755932,12.435260648591546,12.294063867227148,12.152867085862704,12.011670304498335,11.870473523133908,11.7292767417695,11.588079960405056,11.448724997906856,11.315904707415546,11.183084416924196,11.050264126432817,10.917443835941471,10.78462354545012,10.651803254958777,10.522927933497447,10.397929565746372,10.27293119799533,10.147932830244295,10.02293446249326,9.897936094742217,9.775458047950426,9.659573563852566,9.543689079754698,9.427804595656836,9.311920111558978,9.196035627461079,9.084952032056883,8.978962712287313,8.872973392517702,8.766984072748118,8.660994752978517,8.555607198970963,8.456620248355701,8.357633297740447,8.258646347125193,8.159659396509907,8.06088061926071,7.967058985686409,7.873237352112081,7.779415718537776,7.685594084963455,7.593841002912251,7.506593834389388,7.419346665866552,7.332099497343716,7.244852328820853,7.163704275744533,7.083392391877774,7.003080508011025,6.922768624144276,6.84681721711543,6.77265798088111,6.698498744646773,6.624339508412473,6.554425337445369,6.485711913100923,6.416998488756467,6.347304085827265,6.264856961295903,6.1824098367645535,6.0999627122332,6.017515587701841,5.935068463170479,5.85262133863913,5.770174214107776,5.687727089576418,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[67.11636193929459,67.15369278013588,67.19102362097716,67.22835446181844,67.26568530265973,67.30301614350103,67.34034698434229,67.37767782518358,67.41500866602486,67.45233950686614,67.48967034770743,67.52700118854872,67.56433202939,67.60166287023128,67.63899371107257,67.67632455191385,67.71365539275513,67.75098623359642,67.7883170744377,67.82564791527898,67.86297875612027,67.90030959696155,67.93764043780283,67.97497127864412,68.0123021194854,68.04963296032668,68.08696380116797,68.12429464200925,68.16162548285054,68.19895632369182,68.2362871645331,68.27361800537439,68.31026332574886,68.34622312583359,68.38218292591831,68.41814272600304,68.45410252608777,68.4900623261725,68.52602212625723,68.56198192634197,68.5979417264267,68.63390152651142,68.66986132659616,68.70582112668089,68.74178092676561,68.77774072685034,68.81370052693507,68.84966032701979,68.88562012710452,68.92157992718926,68.95753972727398,68.99349952735871,69.02945932744345,69.06541912752817,69.1013789276129,69.13733872769762,69.17329852778236,69.20925832786709,69.2452181279518,69.28117792803656,69.31713772812127,69.353097528206,69.38905732829073,69.42501712837546,69.46097692846018,69.49693672854491,69.53289652862965,69.56885632871438,69.6048161287991,69.64077592888384,69.67673572896857,69.71269552905329,69.74865532913802,69.78461512922274,69.82057492930748,69.85653472939221,69.89249452947693,69.92845432956166,69.9644141296464,70.00037392973113,70.03633372981585,70.07229352990058,70.1082533299853,70.14421313007003,70.15623205359634,70.16346280181097,70.1706935500256,70.17792429824023,70.18515504645485,70.19238579466949,70.19961654288412,70.20684729109874,70.21407803931336,70.221308787528,70.22853953574264,70.23577028395725,70.24300103217189,70.25023178038651,70.25746252860115,70.26469327681578,70.2719240250304,70.27915477324503,70.28638552145966,70.29361626967429,70.30084701788891,70.30807776610354,70.31530851431818,70.3225392625328,70.32977001074744,70.33700075896206,70.34423150717669,70.35146225539131,70.35869300360594,70.36592375182057,70.3731545000352,70.37922610802961,70.38297943625716,70.38673276448472,70.39048609271225,70.39423942093981,70.39799274916734,70.4017460773949,70.40549940562246,70.40925273385,70.41300606207756,70.4167593903051,70.42051271853265,70.4242660467602,70.42801937498774,70.4317727032153,70.43552603144285,70.4392793596704,70.44303268789794,70.44678601612549,70.45053934435305,70.45429267258058,70.45804600080814,70.46179932903568,70.46555265726323,70.46930598549079,70.47305931371832,70.47681264194588,70.48056597017343,70.48431929840098,70.48807262662852,70.49182595485607,70.49557928308363,70.49933261131117,70.50308593953872,70.50683926776627,70.51059259599381,70.51434592422137,70.51809925244892,70.52185258067645,70.52560590890401,70.52935923713156,70.53311256535912,70.53686589358665,70.5406192218142,70.54437255004174,70.5481258782693,70.55187920649685,70.5556325347244,70.55938586295194,70.56313919117949,70.56689251940705,70.5706458476346,70.19665267551952,69.63378625323318,69.0709198309468,68.50805340866044,67.94518698637411,67.38232056408773,66.81945414180137,66.25658771951501,65.69372129722865,65.13085487494232,64.56798845265592,64.00512203036958,63.44225560808321,62.87938918579686,62.316522763510505,61.75365634122414,61.19078991893779,60.62792349665142,60.06505707436505,59.50219065207872,58.93932422979235,58.376457807505986,57.81359138521965,57.25072496293326,56.687858540646914,56.12499211836055,55.56212569607418,54.99925927378785,54.43639285150146,53.87352642921512,53.31066000692876,52.74779358464239,52.184927162356054,51.622060740069685,51.05919431778332,50.496327895496954,49.93346147321059,49.37059505092425,48.80772862863788,48.24486220635152,47.68199578406518,47.11912936177882,46.556262939492456,45.993396517206094,45.430530094919725,44.867663672633356,44.304797250347015,43.74193082806065,43.17906440577429,42.61619798348792,42.05333156120156,41.49046513891522,40.92759871662886,40.36473229434249,39.801865872056126,39.23899944976979,38.67613302748342,38.113266605197055,37.55040018291069,36.98753376062433,36.42466733833798,35.86180091605162,35.29893449376526,34.73606807147889,34.17320164919255,33.61033522690619,33.047468804619825,32.48460238233346,31.921735960047094,31.358869537760754,30.796003115474388,30.233136693188026,29.670270270901657,29.107403848615295,28.544537426328958,27.98167100404259,27.418804581756227,26.867979632159333,26.317154693970796,25.766329755782234,25.215504817593676,24.664679879405114,24.11385494121655,23.729458654356417,23.517658762966935,23.30898129060564,23.10030381824434,22.891626345883033,22.682948873521667,22.474271401160436,22.26559392879906,22.056916456437754,21.848238984076467,21.639561511715158,21.43088403935378,21.222206566992483,21.01352909463119,20.81615529478563,20.619541406893294,20.422927519001014,20.226313631108727,20.02969974321645,19.833085855324114,19.636471967431824,19.439858079539537,19.243244191647268,19.04663030375492,18.85001641586269,18.659312888138782,18.475849559000228,18.292386229861606,18.108922900723044,17.925459571584494,17.74199624244593,17.558532913307307,17.37506958416876,17.191606255030194,17.008142925891626,16.825024380074208,16.653628415520213,16.482232450966148,16.310836486412146,16.139440521858145,15.968044557304134,15.796648592750083,15.625252628196083,15.45385666364207,15.282460699088059,15.116919326550587,14.956519487322229,14.796119648093871,14.635719808865527,14.475319969637134,14.314920130408826,14.154520291180434,13.994120451952131,13.833720612723733,13.681787767246279,13.53143017824973,13.381072589253161,13.230715000256552,13.080357411260035,12.929999822263436,12.779642233266864,12.629284644270307,12.486824304419386,12.345627523054977,12.20443074169058,12.06323396032618,11.922037178961737,11.780840397597368,11.639643616232942,11.5026855411845,11.369865250693145,11.237044960201768,11.104224669710458,10.971404379219106,10.838584088727728,10.705763798236381,10.578452861314132,10.453454493563099,10.328456125812066,10.20345775806099,10.078459390309945,9.953461022558912,9.832077660131667,9.716193176033798,9.600308691935908,9.484424207838048,9.368539723740177,9.252655239642317,9.14202506147584,9.036035741706256,8.930046421936671,8.824057102167101,8.71806778239749,8.61251611035855,8.513529159743296,8.414542209128017,8.315555258512756,8.216568307897504,8.117581357282248,8.023512516470461,7.929690882896162,7.835869249321862,7.742047615747534,7.649316381583031,7.562069213060214,7.474822044537377,7.387574876014514,7.300327707491679,7.2177532483495375,7.137441364482807,7.057129480616064,6.976817596749305,6.8992715814973975,6.825112345263076,6.750953109028766,6.676793872794446,6.6051938046094225,6.536480380264965,6.467766955920523,6.399053531576078,6.320530321383849,6.238083196852497,6.155636072321135,6.0731889477897845,5.990741823258431,5.908294698727072,5.825847574195711,5.743400449664361,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[67.04976307353357,67.08709391437485,67.12442475521613,67.1617555960574,67.1990864368987,67.23641727773999,67.27374811858125,67.31107895942255,67.34840980026382,67.38574064110512,67.4230714819464,67.46040232278769,67.49773316362896,67.53506400447026,67.57239484531152,67.60972568615281,67.64568548689654,67.68164528698127,67.71760508706599,67.75356488715073,67.78952468723546,67.82548448732018,67.86144428740491,67.89740408748963,67.93336388757437,67.9693236876591,68.00528348774382,68.04124328782856,68.07720308791329,68.11316288799802,68.14912268808274,68.18508248816747,68.2210422882522,68.25700208833693,68.29296188842166,68.32892168850638,68.36488148859112,68.40084128867585,68.43680108876057,68.4727608888453,68.50872068893003,68.54468048901475,68.58064028909949,68.61660008918422,68.65255988926894,68.68851968935367,68.72447948943841,68.76043928952313,68.79639908960786,68.83235888969259,68.86831868977731,68.90427848986205,68.94023828994678,68.9761980900315,69.01215789011624,69.04811769020097,69.0840774902857,69.12003729037042,69.15599709045514,69.19195689053987,69.2279166906246,69.26387649070935,69.29983629079406,69.33579609087879,69.37175589096353,69.40771569104825,69.44367549113298,69.4796352912177,69.51559509130243,69.55155489138716,69.5875146914719,69.62347449155664,69.65943429164136,69.69539409172609,69.73135389181081,69.76731369189554,69.80327349198026,69.83923329206499,69.87519309214973,69.91115289223445,69.94711269231918,69.9830724924039,70.01903229248865,70.05499209257337,70.06701101609968,70.07424176431431,70.08147251252893,70.08870326074357,70.09593400895818,70.10316475717282,70.11039550538746,70.11762625360207,70.12485700181671,70.13208775003133,70.13931849824596,70.1465492464606,70.15377999467522,70.16101074288986,70.16824149110448,70.1725743910013,70.17632771922885,70.1800810474564,70.18383437568394,70.1875877039115,70.19134103213905,70.1950943603666,70.19884768859414,70.20260101682169,70.20635434504925,70.2101076732768,70.21386100150434,70.21761432973189,70.22136765795943,70.22512098618698,70.22887431441453,70.23262764264209,70.23638097086963,70.24013429909718,70.24388762732474,70.24764095555227,70.25139428377983,70.25514761200738,70.25890094023492,70.26265426846247,70.26640759669002,70.27016092491758,70.27391425314512,70.27766758137267,70.28142090960021,70.28517423782776,70.2889275660553,70.29268089428285,70.29643422251041,70.30018755073795,70.3039408789655,70.30769420719305,70.3114475354206,70.31520086364814,70.31895419187569,70.32270752010325,70.3264608483308,70.33021417655834,70.33396750478589,70.33772083301344,70.34147416124098,70.34522748946854,70.34898081769609,70.35273414592363,70.35648747415118,70.36024080237874,70.36399413060627,70.36774745883383,70.37150078706138,70.37525411528893,70.37900744351649,70.38276077174402,70.38651409997158,70.39026742819911,70.39402075642667,70.39777408465422,70.40152741288176,70.40528074110931,70.40903406933685,70.41278739756441,70.41654072579196,70.42029405401951,70.42404738224705,70.05005421013199,69.48718778784564,68.92432136555927,68.36145494327292,67.79858852098657,67.23572209870018,66.67285567641383,66.10998925412748,65.54712283184112,64.98425640955477,64.42138998726838,63.85852356498204,63.29565714269568,62.73279072040931,62.16992429812298,61.60705787583661,61.04419145355025,60.48132503126388,59.91845860897751,59.355592186691176,58.79272576440481,58.22985934211845,57.666992919832104,57.104126497545714,56.54126007525938,55.97839365297301,55.41552723068664,54.85266080840031,54.28979438611392,53.726927963827585,53.164061541541216,52.601195119254854,52.03832869696851,51.475462274682144,50.91259585239578,50.34972943010942,49.78686300782306,49.22399658553671,48.66113016325035,48.09826374096398,47.53539731867764,46.97253089639128,46.40966447410491,45.846798051818546,45.28393162953218,44.72106520724582,44.1546999212827,43.5865852001905,43.01847047909829,42.45035575800609,41.882241036913875,41.3141263158217,40.746011594729495,40.17789687363729,39.60978215254508,39.04166743145291,38.4735527103607,37.90543798926849,37.337323268176284,36.76920854708408,36.2010938259919,35.6329791048997,35.06486438380749,34.49674966271529,33.9286349416231,33.3605202205309,32.792405499438686,32.224290778346486,31.656176057254278,31.088061336162102,30.519946615069898,29.95183189397769,29.383717172885483,28.81560245179328,28.2474877307011,27.679373009608895,27.111258288516687,26.54314356742448,25.9750288463323,25.406914125240093,24.838799404147892,24.270684683055684,23.702569961963476,23.314173865236793,23.105496392875416,22.896818920514125,22.68814144815282,22.479463975791514,22.270786503430152,22.062109031068918,21.85343155870754,21.644754086346236,21.43607661398495,21.227399141623643,21.0298828584827,20.833268970590424,20.636655082698148,20.440041194805858,20.24342730691352,20.04681341902124,19.850199531128954,19.653585643236674,19.456971755344338,19.26035786745205,19.063743979559764,18.87097182457418,18.687508495435612,18.504045166297043,18.320581837158493,18.137118508019938,17.953655178881313,17.77019184974276,17.5867285206042,17.403265191465636,17.219801862327014,17.03633853318847,16.8617964357909,16.690400471236842,16.519004506682887,16.34760854212889,16.176212577574827,16.004816613020825,15.833420648466822,15.662024683912811,15.490628719358758,15.320583814260853,15.160183975032496,14.999784135804097,14.839384296575762,14.678984457347404,14.518584618119045,14.358184778890699,14.19778493966231,14.037385100434001,13.880234222953836,13.729876633957238,13.57951904496067,13.429161455964099,13.278803866967552,13.128446277970983,12.978088688974374,12.827731099977857,12.679584741611656,12.53838796024725,12.397191178882814,12.255994397518416,12.114797616154007,11.97360083478961,11.832404053425211,11.691207272060765,11.556646084462097,11.423825793970797,11.29100550347941,11.158185212988057,11.02536492249668,10.89254463200537,10.759724341514017,10.633977789130824,10.50897942137979,10.383981053628746,10.258982685877712,10.133984318126679,10.008985950375603,9.888697272312868,9.772812788215008,9.656928304117146,9.541043820019278,9.42515933592139,9.309274851823528,9.199098090894779,9.093108771125202,8.987119451355627,8.881130131586042,8.775140811816458,8.669425021746127,8.570438071130864,8.471451120515603,8.372464169900349,8.27347721928507,8.174490268669809,8.079966047254523,7.986144413680222,7.892322780105917,7.798501146531618,7.70479176025386,7.617544591731018,7.530297423208155,7.443050254685339,7.355803086162502,7.271802220954569,7.191490337087826,7.111178453221067,7.030866569354336,6.951725945879372,6.877566709645072,6.803407473410735,6.729248237176414,6.655962271773468,6.587248847429007,6.518535423084575,6.449821998740119,6.376203681471793,6.293756556940432,6.211309432409081,6.128862307877728,6.046415183346365,5.963968058815016,5.881520934283662,5.799073809752304,5.716626685220942,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[66.98234680960299,67.01672893306237,67.05189989635103,67.08785969643576,67.12381949652048,67.15977929660521,67.19573909668995,67.23169889677467,67.2676586968594,67.30361849694413,67.33957829702885,67.37553809711359,67.41149789719832,67.44745769728304,67.48341749736778,67.51937729745251,67.55533709753723,67.59129689762196,67.62725669770668,67.66321649779142,67.69917629787614,67.73513609796088,67.7710958980456,67.80705569813033,67.84301549821507,67.87897529829979,67.91493509838452,67.95089489846924,67.98685469855397,68.0228144986387,68.05877429872342,68.09473409880816,68.1306938988929,68.16665369897761,68.20261349906235,68.23857329914708,68.2745330992318,68.31049289931653,68.34645269940125,68.382412499486,68.41837229957072,68.45433209965545,68.49029189974019,68.52625169982491,68.56221149990964,68.59817129999436,68.6341311000791,68.67009090016381,68.70605070024854,68.74201050033328,68.777970300418,68.81393010050274,68.84988990058747,68.8858497006722,68.92180950075692,68.95776930084165,68.99372910092639,69.02968890101111,69.06564870109582,69.10160850118056,69.13756830126529,69.17352810135003,69.20948790143476,69.24544770151948,69.2814075016042,69.31736730168893,69.35332710177367,69.3892869018584,69.42524670194314,69.46120650202786,69.49716630211259,69.53312610219731,69.56908590228204,69.60504570236677,69.6410055024515,69.67696530253623,69.71292510262096,69.74888490270568,69.78484470279042,69.82080450287515,69.85676430295987,69.8927241030446,69.92868390312933,69.96464370321405,69.97376477675114,69.97751810497869,69.98127143320623,69.98502476143378,69.98877808966132,69.99253141788888,69.99628474611643,70.00003807434398,70.00379140257152,70.00754473079907,70.01129805902663,70.01505138725418,70.01880471548172,70.02255804370927,70.02631137193683,70.03006470016436,70.03381802839192,70.03757135661947,70.04132468484701,70.04507801307456,70.0488313413021,70.05258466952965,70.0563379977572,70.06009132598476,70.0638446542123,70.06759798243985,70.0713513106674,70.07510463889494,70.0788579671225,70.08261129535005,70.0863646235776,70.09011795180514,70.09387128003269,70.09762460826025,70.1013779364878,70.10513126471534,70.1088845929429,70.11263792117043,70.11639124939798,70.12014457762554,70.12389790585308,70.12765123408064,70.13140456230818,70.13515789053574,70.13891121876327,70.14266454699083,70.14641787521838,70.15017120344592,70.15392453167347,70.15767785990101,70.16143118812857,70.16518451635612,70.16893784458367,70.17269117281121,70.17644450103876,70.18019782926632,70.18395115749385,70.18770448572141,70.19145781394896,70.1952111421765,70.19896447040406,70.2027177986316,70.20647112685916,70.2102244550867,70.21397778331425,70.2177311115418,70.22148443976934,70.22523776799689,70.22899109622445,70.232744424452,70.23649775267954,70.24025108090709,70.24400440913463,70.24775773736219,70.25151106558974,70.25526439381728,70.25901772204483,70.26277105027238,70.26652437849992,70.27027770672748,70.27403103495503,70.27691267853112,70.27543586868346,69.89147332253441,69.3162679082347,68.74106249393498,68.1714705581558,67.60335583706363,67.03524111597139,66.46712639487922,65.899011673787,65.3308969526948,64.76278223160263,64.1946675105104,63.62655278941821,63.058438068326005,62.4903233472338,61.92220862614162,61.35409390504941,60.78597918395721,60.21786446286501,59.649749741772794,59.081635020680615,58.51352029958841,57.94540557849621,57.37729085740402,56.8091761363118,56.24106141521962,55.67294669412741,55.1048319730352,54.53671725194302,53.96860253085079,53.400487809758616,52.83237308866641,52.2642583675742,51.696143646482014,51.12802892538981,50.55991420429761,49.991799483205405,49.4236847621132,48.85557004102102,48.28745531992881,47.71934059883661,47.15122587774443,46.58311115665222,46.01499643556002,45.44688171446781,44.8787669933756,44.3106522722834,43.74253755119122,43.17442283009902,42.60630810900681,42.0381933879146,41.470078666822396,40.901963945730216,40.333849224638016,39.7657345035458,39.1976197824536,38.62950506136142,38.06139034026921,37.49327561917701,36.925160898084805,36.3570461769926,35.78893145590042,35.22081673480821,34.65270201371601,34.0845872926238,33.51647257153162,32.948357850439415,32.38024312934721,31.812128408255006,31.2440136871628,30.67589896607062,30.10778424497841,29.539669523886207,28.971554802794003,28.403440081701795,27.835325360609616,27.26721063951741,26.699095918425204,26.130981197332996,25.562866476240817,24.994751755148613,24.426637034056405,23.858522312964205,23.290407591871997,22.90201149514531,22.693334022783933,22.484656550422642,22.275979078061336,22.06730160570003,21.858624133338665,21.64994666097743,21.441269188616058,21.243610422179803,21.046996534287597,20.85038264639525,20.653768758502956,20.457154870610676,20.260540982718403,20.063927094826113,19.867313206933776,19.670699319041496,19.47408543114921,19.27747154325693,19.082630761009593,18.899167431871028,18.715704102732456,18.532240773593916,18.348777444455347,18.16531411531678,17.981850786178224,17.79838745703967,17.614924127901048,17.43146079876249,17.247997469623936,17.069964456061616,16.898568491507653,16.727172526953662,16.5557765623996,16.38438059784554,16.212984633291587,16.04158866873759,15.870192704183527,15.698796739629525,15.52740077507552,15.363848462742741,15.203448623514442,15.04304878428605,14.882648945057692,14.722249105829292,14.561849266600957,14.401449427372599,14.241049588144241,14.080649748915896,13.928323089664804,13.77796550066824,13.627607911671678,13.477250322675081,13.326892733678513,13.176535144681942,13.026177555685392,12.875819966688825,12.731148397439538,12.589951616075101,12.448754834710703,12.307558053346296,12.166361271981861,12.025164490617463,11.883967709253055,11.743426918231142,11.610606627739765,11.47778633724841,11.344966046757023,11.212145756265723,11.079325465774337,10.946505175282985,10.814501084698598,10.689502716947564,10.564504349196522,10.439505981445453,10.314507613694422,10.189509245943377,10.064510878192342,9.945316884494128,9.82943240039626,9.713547916298364,9.597663432200502,9.48177894810264,9.365894464004771,9.256171120313738,9.150181800544162,9.044192480774578,8.938203161005001,8.832213841235424,8.726333933133699,8.627346982518437,8.52836003190319,8.429373081287928,8.330386130672666,8.231399180057412,8.136419578038593,8.042597944464287,7.948776310889988,7.854954677315687,7.761133043741382,7.67301997040185,7.585772801878995,7.498525633356151,7.411278464833289,7.325851193559599,7.245539309692855,7.165227425826107,7.084915541959363,7.004603658092604,6.930021074027048,6.855861837792715,6.781702601558416,6.707543365324078,6.638017314593066,6.569303890248629,6.500590465904168,6.431877041559735,6.34942991702839,6.266982792497036,6.184535667965674,6.1020885434343235,6.019641418902971,5.93719429437161,5.854747169840259,5.7723000453089055,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[66.90675655812464,66.94113868158401,66.97552080504337,67.00990292850274,67.0442850519621,67.07866717542147,67.11304929888084,67.1474314223402,67.18181354579957,67.21619566925894,67.25057779271832,67.28495991617768,67.31934203963705,67.35372416309642,67.38810628655578,67.42248841001516,67.45687053347451,67.49125265693388,67.52563478164956,67.5615945817343,67.59755438181902,67.63351418190376,67.66947398198847,67.70543378207321,67.74139358215794,67.77735338224267,67.81331318232739,67.84927298241213,67.88523278249686,67.92119258258158,67.95715238266631,67.99311218275105,68.02907198283577,68.0650317829205,68.10099158300523,68.13695138308995,68.17291118317469,68.20887098325942,68.24483078334414,68.28079058342888,68.31675038351361,68.35271018359833,68.38866998368306,68.42462978376778,68.46058958385251,68.49654938393725,68.53250918402198,68.5684689841067,68.60442878419143,68.64038858427615,68.67634838436089,68.71230818444562,68.74826798453034,68.78422778461507,68.8201875846998,68.85614738478453,68.89210718486926,68.928066984954,68.96402678503873,68.99998658512345,69.03594638520818,69.0719061852929,69.10786598537763,69.14382578546237,69.1797855855471,69.21574538563183,69.25170518571655,69.28766498580129,69.32362478588601,69.35958458597074,69.39554438605546,69.43150418614019,69.46746398622491,69.50342378630965,69.53938358639438,69.57534338647912,69.61130318656383,69.64726298664857,69.6832227867333,69.71918258681802,69.75514238690275,69.79110218698749,69.82706198707221,69.86302178715694,69.87214286069401,69.87589618892156,69.87964951714912,69.88340284537665,69.88715617360421,69.89090950183176,69.8946628300593,69.89841615828685,69.9021694865144,69.90592281474196,69.90967614296952,69.91342947119705,69.91718279942461,69.92093612765214,69.9246894558797,69.92844278410726,69.9321961123348,69.93594944056235,69.93970276878989,69.94345609701745,69.94720942524499,69.95096275347254,69.9547160817001,69.95846940992763,69.96222273815519,69.96597606638272,69.96972939461028,69.97348272283783,69.97723605106538,69.98098937929292,69.98474270752048,69.98849603574803,69.99224936397557,69.99600269220312,69.99975602043068,70.00350934865821,70.00726267688577,70.0110160051133,70.01476933334087,70.01852266156843,70.02227598979596,70.02602931802352,70.02978264625105,70.03353597447861,70.03728930270616,70.0410426309337,70.04479595916126,70.0485492873888,70.05230261561636,70.0560559438439,70.05980927207145,70.063562600299,70.06731592852654,70.0710692567541,70.07482258498163,70.07857591320919,70.08232924143674,70.08608256966428,70.08983589789183,70.09358922611939,70.09734255434694,70.10109588257448,70.10484921080203,70.10860253902958,70.11235586725714,70.11262244093264,70.11114563108498,70.10966882123729,70.10819201138963,70.10671520154196,70.10523839169429,70.10376158184661,70.10228477199895,70.10080796215128,70.0993311523036,70.09785434245595,70.09637753260827,70.0949007227606,70.09342391291293,70.09194710306525,70.09047029321759,70.08899348336993,70.08751667352226,69.7035541273732,69.12834871307349,68.55314329877376,67.97793788447404,67.40273247017434,66.82752705587458,66.25232164157488,65.67711622727516,65.10191081297543,64.52670539867573,63.95149998437598,63.37629457007627,62.80108915577655,62.22588374147682,61.650678327177125,61.07547291287739,60.500267498577664,59.92506208427794,59.34985666997821,58.77465125567851,58.199445841378775,57.624240427079044,57.049035012779356,56.473829598479604,55.89862418417991,55.32341876988016,54.74821335558045,54.173007941280744,53.597802526980985,53.02259711268128,52.44739169838155,51.872186284081835,51.296980869782125,50.7217754554824,50.1477518342061,49.57963711311389,49.01152239202169,48.4434076709295,47.875292949837295,47.307178228745094,46.739063507652915,46.170948786560714,45.6028340654685,45.03471934437629,44.466604623284084,43.89848990219188,43.3303751810997,42.762260460007504,42.19414573891529,41.62603101782309,41.05791629673088,40.48980157563871,39.92168685454649,39.353572133454286,38.785457412362085,38.217342691269906,37.649227970177705,37.08111324908549,36.51299852799329,35.94488380690108,35.3767690858089,34.8086543647167,34.24053964362449,33.67242492253229,33.10431020144011,32.5361954803479,31.968080759255695,31.399966038163488,30.831851317071283,30.263736595979104,29.695621874886896,29.127507153794692,28.559392432702484,27.99127771161028,27.4231629905181,26.855048269425893,26.286933548333693,25.71881882724148,25.150704106149302,24.582589385057098,24.01447466396489,23.446359942872686,22.87824522178048,22.489849125053794,22.28117165269242,22.07249418033113,21.863816707969825,21.65513923560852,21.457337985876944,21.260724097984674,21.06411021009238,20.867496322200033,20.67088243430783,20.47426854641548,20.277654658523186,20.08104077063091,19.884426882738637,19.687812994846343,19.491199106954006,19.294585219061727,19.110826368306412,18.927363039167854,18.743899710029304,18.56043638089074,18.376973051752163,18.193509722613626,18.010046393475058,17.82658306433649,17.643119735197935,17.45965640605938,17.278132476332363,17.106736511778358,16.93534054722436,16.763944582670298,16.592548618116332,16.42115265356234,16.249756689008283,16.07836072445422,15.90696475990027,15.73556879534627,15.567512950453015,15.40711311122467,15.24671327199632,15.08631343276792,14.925913593539619,14.765513754311229,14.60511391508287,14.444714075854469,14.284314236626134,14.126769545372316,13.976411956375749,13.826054367379188,13.675696778382626,13.52533918938606,13.3749816003895,13.224624011392901,13.074266422396333,12.923908834631776,12.782712053267383,12.64151527190294,12.500318490538572,12.359121709174135,12.217924927809737,12.076728146445332,11.935531365080895,11.797387461508714,11.664567171017364,11.531746880526052,11.398926590034675,11.266106299543324,11.133286009051934,11.000465718560635,10.87002601251529,10.745027644764248,10.620029277013213,10.495030909262177,10.370032541511137,10.245034173760068,10.120035806009035,10.00193649667533,9.88605201257747,9.77016752847961,9.654283044381742,9.538398560283845,9.422514076185983,9.313244149732714,9.207254829963103,9.101265510193526,8.99527619042395,8.889286870654367,8.78329755088479,8.68425589390604,8.585268943290753,8.486281992675494,8.387295042060245,8.288308091444982,8.192873108822647,8.099051475248348,8.005229841674048,7.9114082080997425,7.817586574525444,7.728495349072655,7.6412481805498125,7.554001012026975,7.466753843504121,7.379900166164638,7.299588282297889,7.219276398431129,7.138964514564386,7.058652630697638,6.982475438409022,6.908316202174705,6.834156965940384,6.759997729706052,6.688785781757128,6.620072357412666,6.5513589330682205,6.482645508723784,6.40510327711633,6.322656152584971,6.240209028053621,6.1577619035222675,6.075314778990906,5.992867654459555,5.910420529928202,5.82797340539684,5.745526280865491,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[66.8311663066463,66.86554843010566,66.89993055356503,66.9343126770244,66.96869480048377,67.00307692394313,67.0374590474025,67.07184117086186,67.10622329432124,67.14060541778059,67.17498754123997,67.20936966469934,67.2437517881587,67.27813391161807,67.31251603507744,67.3468981585368,67.38128028199617,67.41566240545555,67.4500445289149,67.48442665237428,67.51880877583363,67.55319089929301,67.58757302275238,67.62195514621175,67.65633726967111,67.69071939313048,67.72510151658985,67.75948364004921,67.79386576350858,67.82824788696794,67.86263001042731,67.89701213388669,67.93139425734604,67.96577638080542,68.00015850426479,68.03532946703282,68.07128926711755,68.10724906720229,68.14320886728702,68.17916866737174,68.21512846745647,68.25108826754119,68.28704806762593,68.32300786771066,68.3589676677954,68.39492746788012,68.43088726796485,68.46684706804957,68.5028068681343,68.53876666821904,68.57472646830377,68.61068626838849,68.64664606847322,68.68260586855794,68.71856566864267,68.75452546872741,68.79048526881213,68.82644506889687,68.86240486898159,68.89836466906632,68.93432446915105,68.97028426923578,69.0062440693205,69.04220386940523,69.07816366948997,69.11412346957471,69.15008326965942,69.18604306974416,69.22200286982888,69.25796266991361,69.29392246999834,69.32988227008308,69.3658420701678,69.40180187025251,69.43776167033725,69.47372147042199,69.50968127050672,69.54564107059144,69.58160087067617,69.6175606707609,69.65352047084562,69.68948027093036,69.72544007101509,69.76139987109981,69.77052094463689,69.77427427286443,69.77802760109199,69.78178092931954,69.78553425754708,69.78928758577463,69.79304091400218,69.79679424222972,69.80054757045728,69.80430089868483,69.80805422691238,69.81180755513992,69.81556088336748,69.81931421159501,69.82306753982257,69.82682086805012,69.83057419627767,69.83432752450523,69.83808085273277,69.84183418096032,69.84558750918787,69.84934083741541,69.85309416564296,69.8568474938705,69.86060082209806,69.86435415032561,69.86810747855316,69.8718608067807,69.87561413500825,69.87936746323581,69.88312079146336,69.8868741196909,69.89062744791845,69.894380776146,69.89813410437354,69.90188743260109,69.90564076082865,69.90939408905619,69.91314741728374,69.91690074551128,69.92065407373883,69.92440740196639,69.92816073019392,69.93191405842148,69.93566738664903,69.93942071487658,69.94317404310414,69.94692737133167,69.94980901318183,69.94833220333415,69.94685539348649,69.94537858363881,69.94390177379114,69.94242496394348,69.9409481540958,69.93947134424813,69.93799453440047,69.9365177245528,69.93504091470513,69.93356410485745,69.93208729500978,69.93061048516212,69.92913367531445,69.92765686546677,69.92618005561911,69.92470324577144,69.92322643592377,69.9217496260761,69.92027281622842,69.91879600638075,69.91731919653307,69.91584238668541,69.91436557683775,69.91288876699008,69.9114119571424,69.90993514729473,69.90845833744707,69.9069815275994,69.90550471775173,69.90402790790407,69.90255109805639,69.90107428820872,69.89959747836104,69.515634932212,68.94042951791229,68.36522410361256,67.79001868931284,67.21481327501314,66.63960786071338,66.06440244641368,65.48919703211395,64.91399161781423,64.33878620351453,63.76358078921477,63.18837537491507,62.61316996061534,62.03796454631562,61.46275913201591,60.88755371771619,60.31234830341646,59.737142889116726,59.16193747481701,58.586732060517306,58.01152664621757,57.43632123191785,56.86111581761815,56.2859104033184,55.710704989018694,55.135499574718956,54.56029416041923,53.98508874611954,53.409883331819785,52.83467791752008,52.25947250322035,51.68426708892063,51.10906167462093,50.53385626032119,49.95865084602147,49.38344543172174,48.80824001742202,48.23303460312232,47.65782918882258,47.08262377452286,46.507418360223156,45.932212945923425,45.3570075316237,44.78180211732397,44.206596703024246,43.631391288724515,43.05618587442481,42.48098046012509,41.905775045825365,41.330569631525634,40.7553642172259,40.18015880292621,39.60495338862648,39.02974797432675,38.45454256002702,37.87933714572732,37.304131731427596,36.72892631712787,36.15372090282814,35.57851548852841,35.00331007422871,34.428104659928984,33.85289924562925,33.27769383132953,32.70248841702983,32.127283002730096,31.55591838916418,30.987803668071976,30.419688946979768,29.85157422588759,29.283459504795385,28.715344783703177,28.14723006261097,27.579115341518765,27.011000620426586,26.442885899334378,25.874771178242174,25.30665645714997,24.738541736057787,24.170427014965583,23.60231229387338,23.03419757278117,22.466082851688967,22.077686754962283,21.869009282600903,21.671065549574017,21.4744516616818,21.27783777378945,21.081223885897174,20.8846099980049,20.687996110112604,20.49138222222026,20.294768334328054,20.098154446435707,19.901540558543413,19.704926670651133,19.508312782758864,19.322485304741857,19.1390219756033,18.955558646464745,18.772095317326123,18.588631988187565,18.40516865904901,18.221705329910446,18.038242000771874,17.854778671633333,17.671315342494765,17.487852013356196,17.3149045320491,17.143508567495047,16.97211260294104,16.800716638387033,16.629320673833035,16.457924709278974,16.28652874472501,16.11513278017102,15.943736815616958,15.772340851062898,15.61077759893489,15.450377759706546,15.289977920478188,15.129578081249843,14.969178242021496,14.808778402793095,14.648378563564792,14.4879787243364,14.327578885108045,14.174858412083294,14.024500823086747,13.874143234090138,13.723785645093571,13.57342805609701,13.42307046710045,13.272712878103881,13.122355289107322,12.975472490459618,12.83427570909525,12.693078927730804,12.551882146366415,12.41068536500197,12.269488583637601,12.128291802273164,11.987095020908765,11.851348004786312,11.718527714295002,11.585707423803623,11.45288713331227,11.320066842820962,11.187246552329583,11.05442626183823,10.925550940332004,10.800552572580946,10.675554204829902,10.55055583707886,10.425557469327826,10.300559101576791,10.175560733825748,10.058556108856568,9.942671624758677,9.826787140660809,9.710902656562949,9.595018172465087,9.47913368836722,9.370317179151655,9.264327859382078,9.158338539612501,9.05234921984289,8.946359900073313,8.840370580303736,8.7411648052936,8.642177854678346,8.543190904063092,8.444203953447808,8.345217002832545,8.249326639606737,8.15550500603241,8.061683372458104,7.967861738883804,7.874040105309505,7.783970727743453,7.696723559220616,7.60947639069778,7.5222292221749365,7.4349820536521,7.353637254902916,7.273325371036167,7.193013487169418,7.112701603302657,7.0349298027910105,6.96077056655669,6.886611330322358,6.812452094088041,6.739554248921165,6.670840824576708,6.602127400232281,6.53341397588782,6.460776637204269,6.378329512672925,6.29588238814156,6.213435263610203,6.130988139078852,6.0485410145474985,5.966093890016138,5.883646765484787,5.801199640953433,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[66.75557605516795,66.78995817862733,66.82434030208668,66.85872242554606,66.89310454900541,66.9274866724648,66.96186879592416,66.99625091938353,67.03063304284291,67.06501516630226,67.09939728976164,67.13377941322099,67.16816153668036,67.20254366013974,67.2369257835991,67.27130790705847,67.30569003051784,67.3400721539772,67.37445427743657,67.40883640089594,67.4432185243553,67.47760064781468,67.51198277127403,67.54636489473341,67.58074701819277,67.61512914165215,67.6495112651115,67.68389338857088,67.71827551203025,67.75265763548961,67.78703975894898,67.82142188240834,67.85580400586771,67.89018612932708,67.92456825278644,67.95895037624582,67.99333249970519,68.02771462316454,68.06209674662392,68.09647887008329,68.13086099354265,68.16524311700202,68.19962524046139,68.23400736392075,68.26838948738013,68.30277161083949,68.33715373429887,68.37153585775822,68.4059179812176,68.44030010467695,68.47468222813633,68.50906435233138,68.5450241524161,68.58098395250083,68.61694375258556,68.6529035526703,68.68886335275502,68.72482315283975,68.76078295292447,68.7967427530092,68.83270255309394,68.86866235317866,68.90462215326339,68.94058195334812,68.97654175343284,69.01250155351758,69.0484613536023,69.08442115368705,69.12038095377176,69.15634075385648,69.19230055394122,69.22826035402595,69.26422015411069,69.30017995419541,69.33613975428014,69.37209955436487,69.40805935444959,69.44401915453432,69.47997895461906,69.51593875470378,69.55189855478851,69.58785835487325,69.62381815495797,69.6597779550427,69.66889902857977,69.67265235680732,69.67640568503487,69.68015901326243,69.68391234148997,69.68766566971752,69.69141899794506,69.69517232617261,69.69892565440016,69.7026789826277,69.70643231085526,69.71018563908281,69.71393896731036,69.7176922955379,69.72144562376546,69.72519895199301,69.72895228022055,69.7327056084481,69.73645893667565,69.74021226490319,69.74396559313075,69.7477189213583,69.75147224958585,69.75522557781339,69.75897890604094,69.76273223426848,69.76648556249604,69.77023889072359,69.77399221895114,69.77774554717868,69.78149887540624,69.78525220363379,69.78551877558336,69.78404196573568,69.78256515588801,69.78108834604035,69.77961153619268,69.778134726345,69.77665791649733,69.77518110664967,69.773704296802,69.77222748695434,69.77075067710666,69.76927386725899,69.76779705741131,69.76632024756364,69.76484343771598,69.76336662786831,69.76188981802065,69.76041300817296,69.7589361983253,69.75745938847763,69.75598257862995,69.75450576878228,69.7530289589346,69.75155214908695,69.75007533923927,69.7485985293916,69.74712171954394,69.74564490969627,69.7441680998486,69.74269129000092,69.74121448015326,69.73973767030559,69.73826086045791,69.73678405061025,69.73530724076258,69.7338304309149,69.73235362106723,69.73087681121956,69.7294000013719,69.72792319152423,69.72644638167657,69.7249695718289,69.72349276198122,69.72201595213355,69.72053914228587,69.7190623324382,69.71758552259053,69.71610871274287,69.7146319028952,69.71315509304753,69.71167828319986,69.3277157370508,68.75251032275109,68.17730490845138,67.60209949415164,67.02689407985194,66.45168866555218,65.8764832512525,65.30127783695276,64.72607242265303,64.15086700835333,63.57566159405357,63.00045617975388,62.425250765454145,61.85004535115442,61.27483993685472,60.699634522555,60.12442910825526,59.54922369395554,58.97401827965581,58.398812865356106,57.823607451056375,57.24840203675666,56.67319662245695,56.09799120815721,55.52278579385751,54.94758037955776,54.372374965258054,53.797169550958344,53.22196413665859,52.646758722358896,52.07155330805915,51.496347893759435,50.92114247945973,50.34593706516,49.770731650860284,49.195526236560546,48.62032082226082,48.04511540796112,47.46990999366139,46.894704579361665,46.319499165061956,45.74429375076224,45.16908833646251,44.59388292216278,44.01867750786305,43.44347209356333,42.86826667926363,42.293061264963896,41.71785585066417,41.14265043636445,40.56744502206472,39.992239607765015,39.417034193465284,38.84182877916556,38.266623364865836,37.69141795056613,37.1162125362664,36.54100712196668,35.96580170766695,35.39059629336722,34.81539087906752,34.24018546476779,33.66498005046806,33.08977463616834,32.51456922186864,31.93936380756891,31.364158393269186,30.786721424174136,30.20606108515161,29.62540074612911,29.04474040710658,28.46408006808405,27.883419729061522,27.302759390038993,26.722099051016496,26.141438711993967,25.56077837297144,24.980118033948912,24.39945769492641,23.818797355903882,23.238137016881353,22.657476677858824,22.076816338836295,21.688179225378903,21.491565337486616,21.29495144959428,21.09833756170206,20.90172367380971,20.70510978591743,20.50849589802516,20.311882010132866,20.11526812224052,19.918654234348317,19.722040346455966,19.534144241177316,19.350680912038765,19.16721758290015,18.983754253761585,18.800290924623027,18.616827595484473,18.43336426634585,18.249900937207297,18.06643760806874,17.882974278930178,17.699510949791602,17.523072552319828,17.35167658776582,17.180280623211804,17.008884658657806,16.837488694103754,16.666092729549746,16.494696764995737,16.32330080044174,16.151904835887677,15.980508871333713,15.814442086645197,15.654042247416838,15.49364240818848,15.333242568960088,15.172842729731745,15.012442890503388,14.852043051275043,14.691643212046696,14.531243372818293,14.373304867790827,14.22294727879431,14.0725896897977,13.922232100801132,13.771874511804585,13.621516922807974,13.471159333811407,13.320801744814846,13.170444155818286,13.027036146287506,12.885839364923068,12.744642583558669,12.603445802194301,12.462249020829857,12.321052239465466,12.179855458101022,12.038658676736652,11.905308548063969,11.772488257572627,11.63966796708124,11.506847676589928,11.37402738609855,11.241207095607198,11.108386805115888,10.981075868148721,10.856077500397678,10.731079132646634,10.606080764895578,10.481082397144533,10.356084029393491,10.231085661642458,10.11517572103779,9.999291236939921,9.883406752842063,9.767522268744171,9.651637784646304,9.535753300548443,9.427390208570648,9.321400888801065,9.215411569031456,9.109422249261879,9.0034329294923,8.89744360972269,8.798073716681206,8.699086766065951,8.600099815450665,8.501112864835411,8.402125914220159,8.30578017039082,8.211958536816493,8.1181369032422,8.024315269667872,7.930493636093567,7.839446106414286,7.752198937891431,7.664951769368589,7.577704600845752,7.4904574323229145,7.407686227507939,7.327374343641196,7.247062459774455,7.166750575907706,7.087384167172984,7.013224930938669,6.939065694704353,6.864906458470032,6.7907472222357,6.721609291740771,6.652895867396325,6.58418244305187,6.515469018707443,6.434002872760862,6.351555748229504,6.269108623698163,6.186661499166798,6.104214374635439,6.021767250104089,5.939320125572735,5.856873001041373,5.7744258765100245,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[66.67998580368962,66.71436792714898,66.74875005060835,66.7831321740677,66.81751429752708,66.85189642098645,66.88627854444582,66.92066066790518,66.95504279136455,66.98942491482393,67.02380703828328,67.05818916174266,67.09257128520203,67.1269534086614,67.16133553212076,67.19571765558013,67.23009977903949,67.26448190249886,67.29886402595822,67.33324614941759,67.36762827287697,67.40201039633632,67.4363925197957,67.47077464325506,67.50515676671444,67.53953889017379,67.57392101363317,67.60830313709253,67.6426852605519,67.67706738401127,67.71144950747063,67.74583163093,67.78021375438937,67.81459587784875,67.84897800130811,67.88336012476748,67.91774224822684,67.95212437168621,67.98650649514558,68.02088861860494,68.05527074206431,68.08965286552368,68.12403498898306,68.15841711244241,68.19279923590179,68.22718135936115,68.26156348282052,68.29594560627989,68.33032772973925,68.36470985319862,68.39909197665799,68.43347410011735,68.46785622357672,68.50223834703608,68.53662047049545,68.57100259395483,68.6053847174142,68.63976684087356,68.67414896433293,68.7085310877923,68.74291321125166,68.77729533471103,68.81167745817038,68.84605958162976,68.88044170508913,68.91482382854849,68.94920595200786,68.98358807546724,69.01875903771463,69.05471883779937,69.0906786378841,69.12663843796882,69.16259823805355,69.19855803813827,69.23451783822301,69.27047763830774,69.30643743839246,69.34239723847719,69.37835703856193,69.41431683864666,69.45027663873138,69.48623643881612,69.52219623890085,69.55815603898557,69.56727711252265,69.57103044075019,69.57478376897774,69.5785370972053,69.58229042543284,69.58604375366039,69.58979708188794,69.59355041011548,69.59730373834303,69.60105706657058,69.60481039479815,69.60856372302568,69.61231705125324,69.61607037948077,69.61982370770833,69.62270534783254,69.62122853798486,69.61975172813719,69.61827491828952,69.61679810844186,69.61532129859418,69.61384448874652,69.61236767889885,69.61089086905118,69.6094140592035,69.60793724935583,69.60646043950817,69.6049836296605,69.60350681981282,69.60203000996515,69.60055320011749,69.59907639026981,69.59759958042216,69.59612277057448,69.59464596072681,69.59316915087913,69.59169234103146,69.5902155311838,69.58873872133613,69.58726191148845,69.5857851016408,69.58430829179312,69.58283148194545,69.58135467209779,69.57987786225011,69.57840105240244,69.57692424255477,69.57544743270711,69.57397062285943,69.57249381301176,69.57101700316409,69.56954019331641,69.56806338346875,69.56658657362108,69.5651097637734,69.56363295392573,69.56215614407807,69.5606793342304,69.55920252438273,69.55772571453505,69.5562489046874,69.55477209483972,69.55329528499205,69.55181847514437,69.55034166529671,69.54886485544904,69.54738804560138,69.5459112357537,69.54443442590603,69.54295761605836,69.5414808062107,69.54000399636303,69.53852718651535,69.53705037666768,69.53557356682002,69.53409675697235,69.53261994712467,69.531143137277,69.52966632742934,69.52818951758167,69.52671270773399,69.52523589788632,69.52375908803864,69.1397965418896,68.56459112758989,67.98938571329016,67.41418029899043,66.83897488469074,66.26376947039098,65.68856405609128,65.11335864179156,64.53815322749182,63.96294781319212,63.38774239889237,62.81253698459267,62.237331570292945,61.662126155993214,61.08692074169351,60.51171532739379,59.936509913094056,59.36130449879433,58.78609908449461,58.210893670194906,57.63568825589517,57.06048284159545,56.48527742729575,55.91007201299599,55.334866598696294,54.75966118439656,54.18445577009683,53.60925035579714,53.03404494149739,52.45883952719769,51.88363411289795,51.308428698598235,50.73322328429853,50.15305885096012,49.57239851193759,48.99173817291507,48.41107783389254,47.83041749487004,47.24975715584752,46.66909681682499,46.08843647780248,45.50777613877996,44.92711579975743,44.3464554607349,43.76579512171237,43.185134782689836,42.60447444366734,42.02381410464482,41.44315376562229,40.86249342659976,40.28183308757723,39.701172748554725,39.120512409532196,38.53985207050967,37.95919173148715,37.37853139246465,36.797871053442115,36.21721071441959,35.636550375397064,35.055890036374535,34.475229697352034,33.894569358329505,33.313909019306976,32.73324868028445,32.152588341261946,31.571928002239424,30.991267663216895,30.410607324194366,29.829946985171837,29.249286646149336,28.668626307126807,28.08796596810428,27.507305629081753,26.926645290059223,26.345984951036726,25.765324612014197,25.184664272991668,24.60400393396914,24.02334359494664,23.44268325592411,22.86202291690158,22.281362577879054,21.70070223885653,21.31206512539913,21.11545123750684,20.918837349614503,20.722223461722287,20.525609573829936,20.32899568593766,20.132381798045383,19.935767910153093,19.745803177612704,19.56233984847416,19.378876519335595,19.195413190197026,19.011949861058472,18.82848653191986,18.645023202781296,18.461559873642738,18.278096544504184,18.094633215365562,17.911169886227004,17.731240572590572,17.55984460803651,17.388448643482494,17.217052678928503,17.045656714374495,16.874260749820483,16.70286478526648,16.53146882071243,16.36007285615842,16.188676891604413,16.018106574355464,15.857706735127108,15.697306895898706,15.536907056670369,15.376507217442013,15.216107378213655,15.055707538985263,14.89530769975692,14.734907860528562,14.574508021300218,14.42139373450182,14.27103614550521,14.120678556508649,13.970320967512134,13.819963378515522,13.669605789518954,13.519248200522407,13.368890611525796,13.219796583479775,13.078599802115377,12.937403020750939,12.796206239386533,12.655009458022098,12.5138126766577,12.37261589529333,12.231419113928887,12.092089381832965,11.959269091341579,11.826448800850256,11.693628510358879,11.560808219867537,11.427987929376151,11.29516763888484,11.16234734839346,11.036600795965436,10.911602428214369,10.786604060463336,10.661605692712293,10.536607324961249,10.411608957210191,10.28767981731689,10.171795333218995,10.055910849121133,9.940026365023273,9.824141880925403,9.708257396827541,9.592372912729651,9.484463237989589,9.378473918220012,9.272484598450433,9.16649527868085,9.060505958911241,8.954516639141664,8.85498262806875,8.755995677453512,8.657008726838258,8.558021776223004,8.459034825607718,8.362233701174882,8.268412067600583,8.174590434026275,8.080768800451947,7.9869471668776555,7.8949214850850895,7.807674316562249,7.720427148039411,7.633179979516556,7.545932810993714,7.461735200112978,7.381423316246234,7.301111432379468,7.220799548512725,7.140487664645983,7.065679295320659,6.991520059086321,6.917360822852006,6.843201586617689,6.772377758904824,6.703664334560367,6.634950910215925,6.566237485871479,6.48967623284881,6.40722910831746,6.324781983786098,6.24233485925474,6.159887734723397,6.077440610192032,5.9949934856606735,5.9125463611293245,5.83009923659797,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[66.60359063598578,66.63797275944515,66.67235488290453,66.7067370063639,66.74111912982326,66.77550125328263,66.80988337674198,66.84426550020136,66.87864762366073,66.91302974712009,66.94741187057946,66.98179399403882,67.01617611749819,67.05055824095756,67.08494036441692,67.1193224878763,67.15370461133566,67.18808673479504,67.2224688582544,67.25685098171377,67.29123310517313,67.3256152286325,67.35999735209187,67.39437947555123,67.4287615990106,67.46314372246997,67.49752584592935,67.5319079693887,67.56629009284808,67.60067221630744,67.63505433976681,67.66943646322618,67.70381858668554,67.73820071014492,67.77258283360428,67.80696495706364,67.84134708052301,67.87572920398237,67.91011132744175,67.94449345090112,67.97887557436047,68.01325769781985,68.04763982127922,68.08202194473859,68.11640406819797,68.15078619165733,68.1851683151167,68.21955043857606,68.25393256203543,68.2883146854948,68.32269680895416,68.35707893241353,68.3914610558729,68.42584317933226,68.46022530279163,68.49460742625101,68.52898954971036,68.56337167316974,68.59775379662909,68.63213592008847,68.66651804354784,68.7009001670072,68.73528229046657,68.76966441392594,68.8040465373853,68.83842866084467,68.87281078430404,68.9071929077634,68.94157503122278,68.97595715468215,69.01033927814152,69.04472140160087,69.07910352506025,69.11348564851961,69.14786777197898,69.18224989543835,69.21663201889771,69.25101414235708,69.28539626581644,69.31977838927581,69.35416051273519,69.38854263619456,69.42292475965392,69.45627940767554,69.45361122280383,69.45213441295614,69.45065760310848,69.44918079326081,69.44770398341315,69.44622717356548,69.4447503637178,69.44327355387013,69.44179674402245,69.4403199341748,69.43884312432712,69.43736631447945,69.43588950463177,69.4344126947841,69.43293588493644,69.43145907508877,69.4299822652411,69.42850545539342,69.42702864554576,69.42555183569809,69.42407502585041,69.42259821600274,69.42112140615508,69.4196445963074,69.41816778645973,69.41669097661206,69.4152141667644,69.41373735691673,69.41226054706905,69.41078373722138,69.40930692737372,69.40783011752605,69.40635330767839,69.40487649783071,69.40339968798304,69.40192287813537,69.40044606828769,69.39896925844002,69.39749244859236,69.3960156387447,69.39453882889703,69.39306201904935,69.39158520920168,69.390108399354,69.38863158950635,69.38715477965866,69.385677969811,69.38420115996333,69.38272435011565,69.38124754026799,69.37977073042032,69.37829392057266,69.37681711072499,69.37534030087731,69.37386349102964,69.37238668118198,69.3709098713343,69.36943306148663,69.36795625163896,69.3664794417913,69.36500263194363,69.36352582209595,69.36204901224828,69.36057220240062,69.35909539255294,69.35761858270527,69.3561417728576,69.35466496300994,69.35318815316226,69.35171134331459,69.35023453346693,69.34875772361926,69.34728091377158,69.34580410392391,69.34432729407624,69.34285048422858,69.3413736743809,69.33989686453323,69.33842005468556,69.3369432448379,69.33546643499022,69.33398962514256,69.33251281529489,68.94308719770257,68.35968717623798,67.77741526067857,67.19675492165604,66.61609458263354,66.03543424361098,65.45477390458846,64.87411356556595,64.29345322654342,63.71279288752091,63.132132548498355,62.55147220947586,61.97081187045334,61.3901515314308,60.8094911924083,60.22883085338578,59.64817051436325,59.06751017534072,58.48684983631819,57.90618949729569,57.32552915827316,56.74486881925064,56.16420848022814,55.58354814120558,55.00288780218308,54.42222746316055,53.841567124138024,53.26090678511552,52.68024644609297,52.099586107070465,51.518925768047936,50.93826542902542,50.357605090002906,49.776944750980384,49.196284411957855,48.615624072935326,48.0349637339128,47.454303394890296,46.873643055867774,46.292982716845245,45.712322377822744,45.13166203880022,44.551001699777686,43.970341360755164,43.38968102173263,42.8090206827101,42.2283603436876,41.647700004665076,41.06703966564254,40.48637932662002,39.905718987597496,39.32505864857499,38.74439830955246,38.16373797052993,37.5830776315074,37.00241729248491,36.42175695346237,35.84109661443985,35.26043627541732,34.6797759363948,34.09911559737229,33.51845525834976,32.93779491932724,32.35713458030471,31.7764742412822,31.195813902259676,30.61515356323715,30.034493224214625,29.4538328851921,28.87317254616959,28.292512207147066,27.711851868124537,27.13119152910201,26.550531190079482,25.96987085105698,25.389210512034452,24.808550173011923,24.2278898339894,23.647229494966897,23.066569155944368,22.485908816921842,21.905248477899313,21.324588138876784,20.935951025419385,20.739337137527095,20.542723249634758,20.34610936174254,20.149495473850195,19.957462114048184,19.773998784909626,19.59053545577106,19.407072126632436,19.223608797493895,19.04014546835533,18.856682139216762,18.673218810078207,18.489755480939593,18.30629215180103,18.122828822662473,17.939408592861284,17.768012628307268,17.59661666375327,17.425220699199272,17.25382473464521,17.082428770091195,16.911032805537204,16.739636840983195,16.56824087642918,16.39684491187518,16.225448947321127,16.06137122283735,15.900971383609003,15.740571544380659,15.580171705152305,15.419771865923902,15.259372026695566,15.098972187467208,14.93857234823885,14.77817250901046,14.619840190209388,14.469482601212775,14.319125012216178,14.16876742321966,14.01840983422305,13.868052245226488,13.717694656229973,13.567337067233364,13.416979478236795,13.271360239307601,13.130163457943231,12.988966676578823,12.847769895214425,12.706573113849988,12.565376332485583,12.424179551121144,12.282982769756746,12.146049925110614,12.013229634619227,11.880409344127893,11.747589053636505,11.614768763145184,11.481948472653807,11.349128182162465,11.217124091533178,11.092125723782145,10.96712735603111,10.842128988280066,10.717130620529,10.592132252777965,10.467133885026923,10.34429942949808,10.228414945400253,10.112530461302384,9.996645977204489,9.880761493106625,9.764877009008766,9.648992524910897,9.541536267408546,9.435546947638969,9.329557627869386,9.223568308099807,9.117578988330232,9.011589668560648,8.911891539456347,8.812904588841093,8.713917638225816,8.614930687610576,8.515943736995322,8.418687231958952,8.324865598384646,8.231043964810347,8.137222331236046,8.04340069766174,7.950396863755898,7.863149695233086,7.775902526710224,7.688655358187381,7.601408189664545,7.515784172718005,7.435472288851257,7.355160404984515,7.274848521117772,7.194536637251005,7.11813365970264,7.043974423468324,6.969815187234003,6.895655950999664,6.823146226068872,6.754432801724416,6.685719377379984,6.617005953035527,6.545349592936764,6.462902468405399,6.380455343874049,6.298008219342699,6.215561094811337,6.133113970279979,6.050666845748637,5.968219721217272,5.885772596685914,5.8033254721545635,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[66.51206304047668,66.54644516393604,66.58082728739541,66.61520941085477,66.64959153431414,66.68397365777352,66.71835578123287,66.75273790469224,66.78712002815162,66.82150215161099,66.85588427507035,66.89026639852972,66.92464852198908,66.95903064544845,66.99341276890782,67.02779489236718,67.06217701582655,67.09655913928592,67.1309412627453,67.16532338620466,67.19970550966403,67.23408763312338,67.26846975658276,67.30285188004214,67.3372340035015,67.37161612696086,67.40599825042023,67.44038037387959,67.47476249733896,67.50914462079832,67.54352674425769,67.57790886771707,67.61229099117642,67.6466731146358,67.68105523809517,67.71543736155454,67.7498194850139,67.78420160847327,67.81858373193263,67.852965855392,67.88734797885137,67.92173010231073,67.9561122257701,67.99049434922946,68.02487647268885,68.05925859614821,68.09364071960758,68.12802284306694,68.16240496652631,68.19678708998568,68.23116921344504,68.26555133690441,68.29993346036377,68.33431558382314,68.36869770728251,68.40307983074189,68.43746195420125,68.47184407766062,68.50622620111997,68.54060832457935,68.57499044803872,68.60937257149808,68.64375469495745,68.67813681841682,68.7125189418762,68.74690106533555,68.78102631983874,68.81386722982636,68.84670813981396,68.87954904980157,68.91238995978918,68.9452308697768,68.97807177976439,69.010912689752,69.04375359973962,69.07659450972723,69.10943541971484,69.14227632970245,69.17511723969005,69.20795814967767,69.24079905966528,69.27363996965289,69.30648087964049,69.3393217896281,69.336653603626,69.32688359842595,69.3171135932259,69.30734358802586,69.2975735828258,69.28780357762577,69.27803357242571,69.26826356722566,69.25849356202562,69.24872355682557,69.23895355162551,69.22918354642546,69.21941354122542,69.20964353602538,69.19987353082533,69.19010352562528,69.18033352042522,69.1747101126634,69.17323330281573,69.17175649296806,69.1702796831204,69.16880287327271,69.16732606342505,69.16584925357738,69.1643724437297,69.16289563388203,69.16141882403436,69.1599420141867,69.15846520433902,69.15698839449135,69.15551158464369,69.15403477479602,69.15255796494834,69.15108115510067,69.14960434525301,69.14812753540534,69.14665072555766,69.14517391570999,69.14369710586233,69.14222029601466,69.140743486167,69.13926667631932,69.13778986647165,69.13631305662398,69.1348362467763,69.13335943692864,69.13188262708097,69.1304058172333,69.12892900738562,69.12745219753796,69.12597538769029,69.12449857784262,69.12302176799494,69.12154495814727,69.12006814829961,69.11859133845194,69.11711452860428,69.1156377187566,69.11416090890893,69.11268409906125,69.11120728921358,69.10973047936591,69.10825366951825,69.10677685967057,69.10530004982292,69.10382323997524,69.10234643012757,69.1008696202799,69.09939281043222,69.09791600058456,69.09643919073689,69.09496238088921,69.09348557104155,69.09200876119388,69.09053195134621,69.08905514149853,69.08757833165086,69.08610152180319,69.08462471195553,69.08314790210787,69.0816710922602,69.08019428241252,69.07871747256485,68.68929185497252,68.10589183350794,67.52249181204333,66.9390917905787,66.35569176911412,65.77229174764946,65.18889172618486,64.60549170472025,64.02209168325564,63.43869166179104,62.8552916403264,62.27189161886181,61.68849159739719,61.10509157593257,60.52169155446798,59.93829153300336,59.35489151153874,58.77149149007412,58.18809146860951,57.604691447144916,57.02129142568029,56.43789140421568,55.854491382751085,55.27109136128644,54.687691339821846,54.10429131835723,53.52089129689261,52.93749127542802,52.354091253963375,51.77069123249878,51.187291211034164,50.603891189569545,50.02049116810495,49.437091146640334,48.853691125175715,48.27029110371109,47.68689108224648,47.103491060781884,46.520091039317265,45.93669101785265,45.353290996388054,44.76989097492344,44.18649095345882,43.603090931994196,43.019690910529576,42.43629088906496,41.852890867600365,41.2715859046853,40.690925565662766,40.110265226640244,39.52960488761772,38.948944548595215,38.368284209572685,37.787623870550156,37.206963531527634,36.626303192505134,36.045642853482605,35.464982514460075,34.884322175437546,34.30366183641502,33.723001497392524,33.14234115836999,32.561680819347465,31.981020480324936,31.400360141302432,30.819699802279906,30.23903946325738,29.65837912423485,29.077718785212323,28.497058446189822,27.916398107167296,27.335737768144767,26.755077429122238,26.17441709009971,25.59375675107721,25.01309641205468,24.43243607303215,23.851775734009625,23.271115394987124,22.690455055964595,22.10979471694207,21.52913437791954,20.94847403889701,20.55983692543962,20.363223037547325,20.169121050483625,19.985657721345067,19.802194392206445,19.61873106306789,19.435267733929336,19.251804404790768,19.068341075652146,18.884877746513602,18.701414417375037,18.517951088236472,18.334487759097918,18.151024429959307,17.976180648578016,17.804784684023964,17.633388719469966,17.461992754915947,17.29059679036195,17.11920082580795,16.94780486125389,16.776408896699873,16.605012932145886,16.433616967591878,16.265035710547625,16.104635871319232,15.94423603209093,15.783836192862532,15.623436353634181,15.463036514405838,15.30263667517748,15.14223683594908,14.981836996720745,14.821437157492387,14.667929056920286,14.517571467923768,14.36721387892721,14.2168562899306,14.066498700933998,13.916141111937481,13.765783522940872,13.615425933944312,13.465068344947795,13.32292389513547,13.18172711377106,13.040530332406634,12.899333551042263,12.758136769677856,12.616939988313456,12.475743206949021,12.334546425584614,12.200010468388188,12.067190177896876,11.934369887405525,11.801549596914137,11.668729306422804,11.535909015931416,11.403088725440094,11.27264901934987,11.147650651598834,11.022652283847792,10.89765391609676,10.772655548345725,10.64765718059468,10.522658812843614,10.400919041679327,10.285034557581428,10.169150073483559,10.053265589385733,9.937381105287866,9.82149662118997,9.705612137092107,9.598609296827522,9.492619977057938,9.386630657288334,9.280641337518759,9.174652017749175,9.068662697979597,8.968800450843949,8.869813500228663,8.770826549613403,8.67183959899815,8.57285264838287,8.475140762743006,8.381319129168707,8.287497495594407,8.1936758620201,8.099854228445801,8.006032594871503,7.918625073903866,7.831377905381023,7.744130736858213,7.656883568335351,7.569833145323022,7.489521261456279,7.409209377589536,7.3288974937227875,7.248585609856045,7.170588024084597,7.096428787850277,7.0222695516159765,6.94811031538166,6.873951079147339,6.805201268888468,6.736487844544026,6.667774420199571,6.5990609958551385,6.518575828493346,6.436128703961995,6.3536815794306305,6.271234454899281,6.18878733036793,6.106340205836569,6.023893081305211,5.941445956773869,5.858998832242503,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[66.42053544496756,66.45491756842692,66.48929969188629,66.52368181534565,66.55806393880502,66.5924460622644,66.62682818572375,66.66121030918313,66.69559243264248,66.72997455610187,66.76435667956123,66.7987388030206,66.83312092647996,66.86750304993933,66.90188517339871,66.93626729685806,66.97064942031743,67.0050315437768,67.03941366723618,67.07379579069554,67.10817791415491,67.14256003761427,67.17694216107364,67.21132428453302,67.24570640799237,67.28008853145174,67.31447065491112,67.34885277837047,67.38323490182985,67.41761702528922,67.45199914874858,67.48638127220795,67.52076339566732,67.55514551912668,67.58952764258605,67.62390976604541,67.6582918895048,67.69267401296415,67.72705613642353,67.76143825988288,67.79582038334226,67.83020250680163,67.86458463026099,67.89896675372036,67.93334887717972,67.96773100063909,68.00211312409846,68.03649524755784,68.07087737101719,68.10525949447657,68.13861414198956,68.17145505197718,68.20429596196477,68.23713687195239,68.26997778194001,68.30281869192761,68.33565960191522,68.36850051190282,68.40134142189044,68.43418233187806,68.46702324186566,68.49986415185327,68.53270506184089,68.56554597182848,68.59838688181611,68.63122779180371,68.66406870179132,68.69690961177893,68.72975052176653,68.76259143175416,68.79543234174176,68.82827325172937,68.86111416171698,68.8939550717046,68.9267959816922,68.9596368916798,68.99247780166742,69.02531871165503,69.05815962164264,69.09100053163024,69.12384144161786,69.15668235160547,69.18952326159308,69.2223641715807,69.21969598557858,69.20992598037853,69.20015597517849,69.19038596997844,69.18061596477838,69.17084595957834,69.16107595437829,69.15130594917824,69.1415359439782,69.13176593877816,69.1219959335781,69.11222592837805,69.102455923178,69.09268591797795,69.0829159127779,69.07314590757787,69.06337590237781,69.05360589717776,69.04383589197772,69.03406588677767,69.02429588157761,69.01452587637758,69.00475587117752,68.99498586597747,68.98521586077743,68.97544585557738,68.96567585037734,68.95590584517728,68.94613583997723,68.93636583477718,68.92659582957714,68.9168258243771,68.90705581917705,68.89728581397699,68.89580900252297,68.8943321926753,68.89285538282763,68.89137857297996,68.8899017631323,68.88842495328461,68.88694814343695,68.88547133358928,68.8839945237416,68.88251771389393,68.88104090404627,68.8795640941986,68.87808728435093,68.87661047450325,68.87513366465558,68.87365685480792,68.87218004496025,68.87070323511259,68.86922642526491,68.86774961541724,68.86627280556957,68.8647959957219,68.86331918587423,68.86184237602656,68.8603655661789,68.85888875633123,68.85741194648355,68.85593513663588,68.85445832678822,68.85298151694053,68.85150470709287,68.85002789724521,68.84855108739754,68.84707427754986,68.84559746770219,68.84412065785452,68.84264384800684,68.84116703815918,68.83969022831151,68.83821341846385,68.83673660861618,68.8352597987685,68.83378298892083,68.83230617907316,68.83082936922548,68.82935255937781,68.82787574953015,68.82639893968249,68.82492212983482,68.43549651224248,67.8520964907779,67.26869646931328,66.68529644784866,66.10189642638407,65.51849640491942,64.93509638345482,64.35169636199022,63.768296340525595,63.184896319061,62.601496297596356,62.018096276131764,61.43469625466715,60.851296233202525,60.26789621173795,59.68449619027332,59.101096168808695,58.51769614734408,57.93429612587946,57.35089610441487,56.76749608295026,56.18409606148563,55.60069604002104,55.0172960185564,54.4338959970918,53.85049597562719,53.26709595416257,52.68369593269798,52.10029591123333,51.51689588976874,50.933495868304114,50.35009584683951,49.76669582537491,49.18329580391028,48.59989578244568,48.01649576098105,47.43309573951644,46.84969571805185,46.26629569658723,45.68289567512261,45.09949565365802,44.5160956321934,43.93269561072878,43.34929558926416,42.76589556779954,42.18249554633492,41.599095524870336,41.015695503405716,40.4322954819411,39.84889546047648,39.26549543901186,38.682095417547266,38.09869539608265,37.51529537461803,36.93189535315341,36.34849533168882,35.7650953102242,35.18169528875958,34.59829526729496,34.01489524583034,33.43149522436575,32.848095202901135,32.264695181436515,31.681295159971896,31.097895138507305,30.51449511704268,29.931095095578065,29.347695074113446,28.764295052648826,28.180895031184235,27.597495009719616,27.014094988254996,26.430694966790384,25.847294945325764,25.26389492386117,24.680494902396553,24.097094880931934,23.513694859467314,22.928951988686787,22.342306729500773,21.755661470314763,21.169016211128742,20.58237095194273,20.19731665778045,20.01385332864189,19.830389999503335,19.646926670364778,19.463463341226156,19.280000012087598,19.096536682949047,18.91307335381048,18.729610024671857,18.546146695533313,18.362683366394748,18.184348668848706,18.012952704294708,17.841556739740657,17.670160775186694,17.49876481063264,17.32736884607864,17.155972881524626,16.984576916970628,16.813180952416626,16.641784987862568,16.47038902330855,16.30830035902951,16.14790051980111,15.987500680572797,15.827100841344407,15.666701002116104,15.506301162887706,15.345901323659357,15.185501484431011,15.025101645202655,14.866375512627833,14.716017923631286,14.565660334634718,14.415302745638108,14.26494515664159,14.114587567645032,13.964229978648419,13.813872389651822,13.663514800655305,13.515684332327739,13.37448755096334,13.233290769598904,13.092093988234497,12.95089720687009,12.809700425505664,12.668503644141294,12.527306862776886,12.38679130215717,12.253971011665824,12.121150721174473,11.988330430683096,11.855510140191782,11.722689849700433,11.589869559209045,11.457049268717713,11.328173947166594,11.20317557941555,11.078177211664483,10.953178843913449,10.828180476162405,10.703182108411372,10.578183740660336,10.457538653860528,10.341654169762666,10.225769685664805,10.109885201566907,9.994000717469039,9.878116233371212,9.762231749273344,9.655682326246463,9.549693006476886,9.443703686707309,9.337714366937725,9.231725047168121,9.125735727398544,9.02570936223151,8.926722411616256,8.827735461001001,8.728748510385715,8.629761559770454,8.531594293527068,8.437772659952767,8.34395102637846,8.250129392804162,8.156307759229861,8.062486125655557,7.974100452574691,7.8868532840518535,7.799606115528991,7.712358947006148,7.625111778483338,7.543570234061317,7.46325835019455,7.382946466327807,7.302634582461065,7.223042388466581,7.148883152232265,7.074723915997933,7.000564679763613,6.926405443529313,6.855969736052514,6.7872563117080675,6.718542887363622,6.649829463019181,6.574249188581293,6.491802064049927,6.409354939518577,6.326907814987226,6.2444606904558615,6.162013565924512,6.079566441393162,5.9971193168618,5.914672192330443,5.8322250677991,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[66.32900784945845,66.36338997291782,66.39777209637717,66.43215421983655,66.46653634329591,66.50091846675528,66.53530059021465,66.56968271367401,66.6040648371334,66.63844696059274,66.67282908405213,66.70721120751149,66.74159333097086,66.77597545443022,66.81035757788959,66.84473970134896,66.87912182480832,66.91350394826769,66.94788607172707,66.98226819518642,67.01665031864579,67.05103244210517,67.08541456556452,67.1197966890239,67.15417881248325,67.18856093594263,67.222943059402,67.25732518286136,67.29170730632075,67.32608942978011,67.36047155323946,67.39485367669883,67.42923580015821,67.46336105415278,67.4962019641404,67.52904287412801,67.56188378411561,67.59472469410323,67.62756560409083,67.66040651407845,67.69324742406606,67.72608833405367,67.75892924404128,67.7917701540289,67.8246110640165,67.8574519740041,67.89029288399172,67.92313379397933,67.95597470396693,67.98881561395456,68.02165652394216,68.05449743392978,68.08733834391738,68.12017925390498,68.1530201638926,68.1858610738802,68.21870198386782,68.25154289385543,68.28438380384303,68.31722471383065,68.35006562381825,68.38290653380588,68.41574744379348,68.44858835378108,68.48142926376869,68.5142701737563,68.54711108374391,68.57995199373153,68.61279290371914,68.64563381370675,68.67847472369436,68.71131563368196,68.74415654366958,68.77699745365719,68.80983836364479,68.8426792736324,68.87552018362001,68.90836109360762,68.94120200359524,68.97404291358285,69.00688382357046,69.03972473355806,69.07256564354567,69.10540655353329,69.10273836753117,69.09296836233112,69.08319835713108,69.07342835193103,69.06365834673099,69.05388834153094,69.04411833633088,69.03434833113084,69.0245783259308,69.01480832073074,69.0050383155307,68.99526831033064,68.98549830513059,68.97572829993055,68.96595829473051,68.95618828953044,68.9464182843304,68.93664827913037,68.92687827393031,68.91710826873026,68.90733826353022,68.89756825833015,68.88779825313011,68.87802824793008,68.86825824273002,68.85848823752997,68.84871823232993,68.83894822712986,68.82917822192982,68.81940821672978,68.80963821152973,68.79986820632968,68.79009820112964,68.78032819592958,68.77055819072955,68.76078818552949,68.75101818032944,68.74124817512939,68.73147816992935,68.7217081647293,68.71193815952925,68.7021681543292,68.69239814912916,68.68262814392911,68.67285813872905,68.663088133529,68.65331812832896,68.64354812312891,68.63377811792886,68.6240081127288,68.61838470223023,68.61690789238257,68.6154310825349,68.61395427268721,68.61247746283955,68.61100065299189,68.60952384314422,68.60804703329654,68.60657022344887,68.6050934136012,68.60361660375354,68.60213979390586,68.60066298405819,68.59918617421052,68.59770936436284,68.59623255451518,68.59475574466751,68.59327893481984,68.59180212497218,68.5903253151245,68.58884850527683,68.58737169542916,68.5858948855815,68.58441807573382,68.58294126588615,68.58146445603847,68.57998764619082,68.57851083634314,68.57703402649547,68.57555721664781,68.57408040680014,68.57260359695246,68.57112678710479,68.18170116951246,67.59830114804788,67.01490112658327,66.43150110511864,65.84810108365406,65.2647010621894,64.6813010407248,64.0979010192602,63.51450099779558,62.93110097633098,62.34770095486634,61.76430093340175,61.18090091193713,60.59750089047251,60.01410086900792,59.43070084754331,58.84730082607868,58.26390080461407,57.68050078314945,57.09710076168486,56.51370074022024,55.93030071875562,55.34690069729103,54.763500675826386,54.18010065436179,53.59670063289717,53.013300611432555,52.42990058996796,51.84650056850331,51.263100547038725,50.6797005255741,50.096300504109486,49.512900482644895,48.92950046118027,48.346100439715656,47.762700418251036,47.17930039678642,46.595900375321825,46.012500353857206,45.42910033239259,44.845700310927995,44.26230028946338,43.67890026799876,43.095500246534144,42.512100225069524,41.928700203604905,41.34530018214031,40.761900160675694,40.178500139211074,39.59510011774646,39.01170009628184,38.428300074817244,37.842997676542744,37.25635241735672,36.66970715817071,36.083061898984724,35.49641663979871,34.909771380612696,34.32312612142668,33.73648086224067,33.14983560305468,32.56319034386866,31.976545084682648,31.389899825496634,30.803254566310645,30.216609307124635,29.62996404793862,29.0433187887526,28.456673529566586,27.8700282703806,27.283383011194587,26.69673775200857,26.11009249282256,25.523447233636542,24.936801974450553,24.35015671526454,23.763511456078525,23.17686619689251,22.59022093770652,22.00357567852051,21.416930419334495,20.830285160148478,20.243639900962464,19.858585606800183,19.675122277661618,19.491658948523064,19.308195619384506,19.124732290245884,18.94126896110733,18.757805631968775,18.57434230283021,18.392516689119425,18.221120724565434,18.04972476001143,17.87832879545741,17.706932830903412,17.53553686634936,17.364140901795395,17.192744937241347,17.021348972687345,16.84995300813333,16.67855704357933,16.511964846739758,16.3515650075114,16.191165168283046,16.03076532905471,15.870365489826307,15.709965650597997,15.549565811369607,15.389165972141305,15.228766132912904,15.068366293684557,14.914464379338849,14.76410679034228,14.613749201345671,14.46339161234912,14.313034023352555,14.162676434355946,14.012318845359427,13.86196125636287,13.711603667366258,13.567247988155595,13.426051206791197,13.28485442542679,13.14365764406239,13.002460862697953,12.861264081333548,12.720067299969141,12.578870518604715,12.440751845434828,12.30793155494344,12.175111264452097,12.042290973960752,11.9094706834694,11.776650392978022,11.64383010248671,11.511009811995361,11.383698874983292,11.258700507232266,11.133702139481223,11.00870377173018,10.883705403979114,10.75870703622808,10.633708668477038,10.514158266041777,10.398273781943887,10.28238929784602,10.16650481374816,10.050620329650299,9.934735845552401,9.818851361454533,9.712755355665433,9.606766035895847,9.500776716126262,9.394787396356687,9.28879807658711,9.182808756817526,9.082618273619115,8.983631323003861,8.884644372388575,8.78565742177332,8.686670471158067,8.588047824311179,8.49422619073685,8.400404557162531,8.30658292358823,8.212761290013924,8.118939656439625,8.029575831245523,7.942328662722661,7.855081494199826,7.767834325676989,7.680587157154126,7.597619206666341,7.517307322799605,7.436995438932856,7.356683555066089,7.276371671199347,7.201337516614245,7.127178280379924,7.053019044145608,6.978859807911276,6.906738203216573,6.838024778872118,6.769311354527676,6.700597930183229,6.629922548669233,6.5474754241378825,6.465028299606532,6.382581175075167,6.300134050543818,6.217686926012467,6.135239801481101,6.0527926769497515,5.970345552418402,5.887898427887039,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[66.23748025394933,66.2718623774087,66.30624450086806,66.34062662432743,66.37500874778681,66.40939087124617,66.44377299470554,66.4781551181649,66.51253724162427,66.54691936508364,66.581301488543,66.61568361200237,66.65006573546174,66.6844478589211,66.71882998238048,66.75321210583985,66.78759422929922,66.8209488763036,66.85378978629123,66.88663069627884,66.91947160626644,66.95231251625405,66.98515342624167,67.01799433622928,67.05083524621688,67.08367615620449,67.1165170661921,67.14935797617972,67.18219888616733,67.21503979615494,67.24788070614254,67.28072161613015,67.31356252611776,67.34640343610536,67.37924434609299,67.41208525608059,67.4449261660682,67.47776707605581,67.51060798604342,67.54344889603104,67.57628980601865,67.60913071600626,67.64197162599386,67.67481253598147,67.70765344596909,67.74049435595668,67.77333526594431,67.80617617593191,67.83901708591952,67.87185799590713,67.90469890589473,67.93753981588236,67.97038072586996,68.00322163585757,68.03606254584518,68.06890345583278,68.1017443658204,68.134585275808,68.16742618579562,68.20026709578323,68.23310800577084,68.26594891575846,68.29878982574606,68.33163073573365,68.36447164572128,68.3973125557089,68.4301534656965,68.4629943756841,68.49583528567172,68.52867619565933,68.56151710564694,68.59435801563455,68.62719892562217,68.66003983560977,68.69288074559738,68.72572165558499,68.7585625655726,68.7914034755602,68.82424438554781,68.85708529553543,68.88992620552304,68.92276711551065,68.95560802549826,68.98844893548586,68.98578074948375,68.97601074428371,68.96624073908366,68.95647073388362,68.94670072868357,68.93693072348353,68.92716071828346,68.91739071308342,68.90762070788337,68.89785070268333,68.88808069748329,68.87831069228324,68.86854068708318,68.85877068188313,68.84900067668309,68.83923067148304,68.829460666283,68.81969066108294,68.80992065588289,68.80015065068285,68.7903806454828,68.78061064028275,68.7708406350827,68.76107062988265,68.7513006246826,68.74153061948255,68.7317606142825,68.72199060908247,68.7122206038824,68.70245059868236,68.69268059348232,68.68291058828227,68.67314058308222,68.66337057788218,68.65360057268212,68.64383056748207,68.63406056228203,68.62429055708199,68.61452055188192,68.60475054668188,68.59498054148183,68.58521053628178,68.57544053108174,68.56567052588169,68.55590052068163,68.5461305154816,68.53636051028154,68.5265905050815,68.51682049988145,68.5070504946814,68.49728048948135,68.4875104842813,68.47774047908126,68.46797047388121,68.45820046868116,68.4484304634811,68.43866045828106,68.42889045308101,68.41912044788097,68.40935044268092,68.39958043748086,68.38981043228081,68.38004042708077,68.37027042188072,68.36050041668067,68.35073041148061,68.34096040628057,68.3394835920898,68.33800678224213,68.33652997239447,68.33505316254679,68.33357635269913,68.33209954285145,68.33062273300379,68.32914592315612,68.32766911330845,68.32619230346077,68.3247154936131,68.32323868376542,68.32176187391777,68.32028506407009,68.31880825422243,68.31733144437476,67.92790582678244,67.34450580531784,66.76110578385324,66.17770576238861,65.59430574092403,65.01090571945937,64.42750569799477,63.844105676530155,63.26070565506554,62.67730563360095,62.09390561213631,61.51050559067172,60.92710556920709,60.34370554774248,59.76030552627789,59.17690550481326,58.59350548334865,58.010105461884024,57.42670544041941,56.84330541895483,56.2599053974902,55.67650537602558,55.093105354561,54.50970533309634,53.92630531163175,53.34290529016714,52.75704336439867,52.17039810521268,51.58375284602664,50.99710758684065,50.41046232765464,49.82381706846862,49.237171809282636,48.650526550096615,48.06388129091061,47.477236031724594,46.89059077253858,46.30394551335259,45.71730025416657,45.13065499498056,44.544009735794575,43.95736447660856,43.37071921742255,42.784073958236526,42.19742869905051,41.6107834398645,41.024138180678506,40.43749292149249,39.85084766230648,39.264202403120464,38.67755714393445,38.090911884748465,37.50426662556245,36.91762136637643,36.33097610719042,35.74433084800443,35.15768558881842,34.5710403296324,33.98439507044639,33.397749811260375,32.81110455207439,32.22445929288837,31.63781403370236,31.05116877451634,30.464523515330356,29.877878256144342,29.291232996958325,28.704587737772314,28.117942478586293,27.531297219400308,26.944651960214294,26.35800670102828,25.771361441842263,25.184716182656253,24.59807092347026,24.011425664284246,23.424780405098232,22.83813514591222,22.251489886726233,21.664844627540216,21.078199368354202,20.491554109168188,19.90490884998217,19.51985455581989,19.336391226681325,19.152927897542774,18.969464568404216,18.786001239265595,18.602537910127037,18.429288744836178,18.257892780282162,18.0864968157281,17.915100851174113,17.743704886620105,17.57230892206609,17.400912957512087,17.22951699295804,17.058121028404074,16.886725063850022,16.71562933445003,16.555229495221667,16.394829655993323,16.234429816764933,16.074029977536576,15.913630138308218,15.753230299079881,15.59283045985148,15.432430620623173,15.272030781394779,15.112910835046357,14.96255324604979,14.81219565705323,14.661838068056671,14.511480479060102,14.361122890063493,14.210765301066942,14.060407712070377,13.910050123073766,13.760008425347866,13.618811643983468,13.477614862619022,13.336418081254624,13.195221299890228,13.05402451852582,12.91282773716142,12.771630955796983,12.630434174432578,12.494712388712426,12.361892098221091,12.229071807729738,12.09625151723835,11.963431226747007,11.830610936255663,11.69779064576431,11.564970355272932,11.439223802800026,11.31422543504895,11.189227067297907,11.06422869954688,10.939230331795837,10.814231964044794,10.689233596293727,10.570777878222989,10.45489339412512,10.339008910027259,10.223124425929369,10.107239941831502,9.99135545773364,9.875817704853983,9.769828385084372,9.663839065314786,9.557849745545218,9.451860425775633,9.345871106006049,9.239881786236474,9.13952718500666,9.040540234391399,8.941553283776166,8.842566333160914,8.74357938254563,8.644592431930374,8.55067972152094,8.456858087946634,8.363036454372306,8.269214820797986,8.175393187223687,8.085051209916301,7.9978040413934846,7.910556872870648,7.8233097043477855,7.736062535824951,7.6516681792713666,7.571356295404636,7.491044411537869,7.410732527671134,7.330420643804384,7.25379188099623,7.179632644761914,7.1054734085275815,7.031314172293261,6.9575066703806145,6.888793246036173,6.820079821691727,6.751366397347271,6.6826529730028295,6.603148784225822,6.52070165969446,6.438254535163111,6.35580741063176,6.273360286100395,6.1909131615690445,6.108466037037695,6.02601891250633,5.94357178797498,5.861124663443629,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[66.14582284020568,66.17839213991898,66.2112330499066,66.24407395989421,66.27691486988182,66.30975577986943,66.34259668985703,66.37543759984464,66.40827850983226,66.44111941981987,66.47396032980747,66.5068012397951,66.5396421497827,66.5724830597703,66.60532396975792,66.63816487974553,66.67100578973313,66.70384669972074,66.73668760970835,66.76952851969597,66.80236942968358,66.83521033967119,66.86805124965879,66.9008921596464,66.93373306963402,66.96657397962161,66.99941488960924,67.03225579959684,67.06509670958445,67.09793761957206,67.13077852955968,67.16361943954728,67.19646034953489,67.2293012595225,67.26214216951011,67.29498307949773,67.32782398948532,67.36066489947294,67.39350580946055,67.42634671944816,67.45918762943577,67.49202853942339,67.524869449411,67.55771035939861,67.59055126938621,67.62339217937382,67.65623308936144,67.68907399934905,67.72191490933666,67.75475581932426,67.78759672931187,67.82043763929948,67.8532785492871,67.88611945927471,67.91896036926231,67.95180127924992,67.98464218923753,68.01748309922515,68.05032400921276,68.08316491920036,68.11600582918797,68.14884673917558,68.1816876491632,68.2145285591508,68.24736946913842,68.28021037912602,68.31305128911363,68.34589219910124,68.37873310908884,68.41157401907645,68.44441492906407,68.47725583905168,68.51009674903929,68.5429376590269,68.5757785690145,68.60861947900212,68.64146038898973,68.67430129897734,68.70714220896495,68.73998311895255,68.77282402894016,68.80566493892778,68.83850584891539,68.871346758903,68.86867857290089,68.85890856770084,68.84913856250078,68.83936855730076,68.8295985521007,68.81982854690065,68.8100585417006,68.80028853650055,68.7905185313005,68.78074852610045,68.77097852090041,68.76120851570036,68.75143851050032,68.74166850530025,68.73189850010021,68.72212849490018,68.71235848970012,68.70258848450007,68.69281847930003,68.68304847409998,68.67327846889992,68.66350846369988,68.65373845849983,68.64396845329978,68.63419844809974,68.62442844289968,68.61465843769963,68.60488843249959,68.59511842729954,68.58534842209949,68.57557841689945,68.56580841169941,68.55603840649934,68.5462684012993,68.53649839609926,68.5267283908992,68.51695838569916,68.50718838049912,68.49741837529906,68.48764837009901,68.47787836489896,68.4681083596989,68.45833835449886,68.44856834929882,68.43879834409876,68.42902833889872,68.41925833369866,68.40948832849863,68.39971832329857,68.38994831809852,68.38017831289847,68.37040830769843,68.36063830249839,68.35086829729833,68.34109829209828,68.33132828689823,68.32155828169819,68.31178827649813,68.3020182712981,68.29224826609804,68.28247826089799,68.27270825569795,68.26293825049791,68.25316824529786,68.2433982400978,68.23362823489775,68.2238582296977,68.21408822449766,68.20431821929762,68.19454821409757,68.18477820889751,68.17500820369746,68.16523819849742,68.15546819329737,68.14569818809733,68.13592818289727,68.12615817769722,68.11638817249718,68.10661816729713,68.09684816209707,68.08707815689704,68.07730815169698,68.06753814649694,67.67107903885987,67.0844437930686,66.49779853388259,65.91115327469657,65.32450801551059,64.73786275632455,64.15121749713856,63.56457223795255,62.977926978766526,62.39128171958053,61.8046364603945,61.21799120120851,60.6313459420225,60.04470068283648,59.45805542365049,58.87141016446448,58.28476490527847,57.69811964609246,57.11147438690644,56.524829127720444,55.93818386853443,55.351538609348424,54.76489335016243,54.17824809097639,53.591602831790404,53.00495757260439,52.418312313418376,51.83166705423239,51.24502179504634,50.658376535860356,50.07173127667434,49.48508601748833,48.89844075830234,48.31179549911633,47.725150239930315,47.1385049807443,46.55185972155829,45.965214462372295,45.37856920318628,44.79192394400027,44.20527868481428,43.61863342562827,43.03198816644225,42.44534290725623,41.85869764807022,41.272052388884205,40.68540712969822,40.0987618705122,39.512116611326185,38.92547135214017,38.33882609295416,37.75218083376817,37.16553557458215,36.578890315396144,35.99224505621013,35.40559979702414,34.818954537838124,34.23230927865211,33.645664019466096,33.05901876028008,32.4723735010941,31.88572824190808,31.299082982722066,30.712437723536052,30.125792464350063,29.539147205164046,28.952501945978035,28.365856686792018,27.779211427606004,27.19256616842002,26.605920909234,26.019275650047987,25.432630390861974,24.84598513167596,24.25933987248997,23.672694613303957,23.086049354117943,22.49940409493193,21.91275883574594,21.326113576559926,20.739468317373912,20.152823058187895,19.56617779900188,19.1811235048396,18.997660175701036,18.81419684656248,18.63745676510687,18.466060800552853,18.294664835998855,18.123268871444854,17.951872906890838,17.780476942336776,17.60908097778279,17.43768501322878,17.266289048674764,17.094893084120766,16.923497119566715,16.75889398293189,16.598494143703594,16.4380943044752,16.277694465246842,16.1172946260185,15.956894786790109,15.796494947561749,15.636095108333391,15.475695269105056,15.315295429876656,15.160999701757339,15.01064211276074,14.860284523764179,14.70992693476761,14.559569345771052,14.409211756774493,14.258854167777924,14.108496578781315,13.958138989784766,13.8115720811757,13.670375299811292,13.529178518446894,13.387981737082496,13.246784955718054,13.105588174353654,12.964391392989256,12.82319461162485,12.68199783026045,12.548672931990042,12.415852641498688,12.283032351007337,12.150212060516003,12.01739177002465,11.884571479533262,11.75175118904192,11.61974709836775,11.494748730616708,11.369750362865672,11.244751995114639,11.119753627363563,10.99475525961252,10.869756891861494,10.744758524110452,10.627397490404192,10.511513006306329,10.39562852220847,10.2797440381106,10.16385955401274,10.04797506991485,9.932890734272947,9.82690141450337,9.720912094733768,9.614922774964157,9.508933455194573,9.402944135425004,9.29695481565542,9.196436096394246,9.097449145778992,8.998462195163714,8.899475244548453,8.80048829393322,8.701501343317966,8.607133252304996,8.513311618730695,8.419489985156396,8.32566835158209,8.23184671800776,8.140526588587125,8.053279420064289,7.966032251541426,7.8787850830186095,7.791537914495772,7.705717151876399,7.625405268009638,7.545093384142896,7.464781500276166,7.384469616409399,7.306246245378208,7.232087009143887,7.1579277729095665,7.083768536675251,7.009609300440918,6.939561713200225,6.870848288855769,6.802134864511327,6.733421440166881,6.658822144313762,6.576375019782412,6.493927895251054,6.411480770719692,6.329033646188341,6.246586521656992,6.164139397125627,6.081692272594276,5.999245148062926,5.916798023531561,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[66.04144329245598,66.07265454753176,66.10386580260753,66.13507705768329,66.16628831275906,66.19749956783484,66.22871082291061,66.25992207798637,66.29113333306215,66.32234458813792,66.3535558432137,66.38476709828946,66.41597835336523,66.447189608441,66.47840086351677,66.50961211859254,66.54082337366832,66.5725778456568,66.60541875564441,66.63825966563202,66.67110057561963,66.70394148560725,66.73678239559484,66.76962330558246,66.80246421557007,66.83530512555768,66.8681460355453,66.9009869455329,66.93382785552052,66.96666876550812,66.99950967549573,67.03235058548334,67.06519149547094,67.09803240545855,67.13087331544617,67.16371422543378,67.19655513542139,67.229396045409,67.26223695539662,67.29507786538421,67.32791877537183,67.36075968535944,67.39360059534705,67.42644150533467,67.45928241532226,67.49212332530988,67.52496423529749,67.5578051452851,67.59064605527271,67.62348696526031,67.65632787524792,67.68916878523554,67.72200969522314,67.75485060521076,67.78769151519836,67.82053242518597,67.85337333517359,67.8862142451612,67.91905515514881,67.95189606513641,67.98473697512402,68.01757788511163,68.05041879509926,68.08325970508686,68.11610061507446,68.14894152506207,68.18178243504968,68.2146233450373,68.24746425502491,68.28030516501252,68.31314607500012,68.34598698498773,68.37882789497534,68.41166880496296,68.44450971495056,68.47735062493817,68.51019153492578,68.5430324449134,68.575873354901,68.60871426488862,68.64155517487622,68.67439608486383,68.70723699485144,68.74007790483904,68.73740971883694,68.7276397136369,68.71786970843685,68.7080997032368,68.69832969803674,68.6885596928367,68.67878968763665,68.66901968243661,68.65924967723655,68.6494796720365,68.63970966683647,68.62993966163641,68.62016965643637,68.61039965123632,68.60062964603627,68.59085964083621,68.58108963563618,68.57131963043614,68.56154962523608,68.55177962003603,68.54200961483599,68.53223960963592,68.52246960443588,68.51269959923584,68.50292959403579,68.49315958883574,68.4833895836357,68.47361957843563,68.46384957323559,68.45407956803555,68.4443095628355,68.43453955763545,68.42476955243541,68.41499954723535,68.4052295420353,68.39545953683525,68.38568953163522,68.37591952643515,68.36614952123512,68.35637951603508,68.34660951083501,68.33683950563497,68.32706950043493,68.31729949523488,68.30752949003482,68.29775948483477,68.28798947963473,68.27821947443468,68.26844946923464,68.25867946403459,68.24890945883453,68.2391394536345,68.22936944843444,68.21959944323439,68.20982943803435,68.2000594328343,68.19028942763424,68.1805194224342,68.17074941723415,68.16097941203411,68.15120940683406,68.141439401634,68.13166939643396,68.12189939123391,68.11212938603386,68.1023593808338,68.08824467520014,68.06544060208057,68.04263652896101,68.01983245584144,67.99702838272188,67.9742243096023,67.95142023648275,67.92861616336317,67.90581209024361,67.88300801712406,67.86020394400448,67.83739987088492,67.81459579776535,67.79179172464579,67.76898765152623,67.74618357840666,67.72337950528708,67.32474806197328,66.73820293356239,66.15165780515149,65.56511267674058,64.97856754832969,64.39202241991875,63.80547729150787,63.21893216309696,62.63238703468605,62.04584190627516,61.45929677786422,60.872751649453335,60.28620652104242,59.69966139263151,59.11311626422063,58.52657113580972,57.94002600739881,57.353480878987895,56.766935750576984,56.180390622166094,55.59384549375518,55.00730036534427,54.420755236933395,53.83421010852245,53.24766498011157,52.661119851700654,52.07457472328974,51.48802959487886,50.90148446646792,50.31493933805704,49.72839420964612,49.14184908123521,48.555303952824325,47.96875882441341,47.38221369600251,46.79566856759159,46.209123439180686,45.622578310769796,45.03603318235889,44.449488053947974,43.86294292553709,43.27639779712618,42.68985266871527,42.10330754030435,41.51676241189344,40.930217283482534,40.343672155071644,39.75712702666073,39.17058189824982,38.58403676983892,37.997491641428,37.41094651301712,36.82440138460621,36.2378562561953,35.65131112778439,35.0647659993735,34.47822087096259,33.891675742551676,33.305130614140765,32.718585485729854,32.13204035731897,31.54549522890806,30.958950100497148,30.372404972086237,29.78585984367535,29.199314715264435,28.612769586853524,28.026224458442613,27.4396793300317,26.85313420162082,26.26658907320991,25.680043944799,25.093498816388088,24.506953687977173,23.92040855956629,23.33386343115538,22.747318302744468,22.160673043951665,21.574027784765672,20.987382525579658,20.400737266393644,19.81409200720763,19.227446748021613,18.845624785377634,18.674228820823625,18.502832856269574,18.331436891715573,18.160040927161557,17.98864496260756,17.81724899805356,17.645853033499545,17.474457068945483,17.303061104391492,17.131665139837484,16.962558470642186,16.802158631413842,16.64175879218549,16.48135895295709,16.320959113728794,16.1605592745004,16.000159435272042,15.839759596043699,15.679359756815305,15.51895991758695,15.359446157464866,15.209088568468317,15.058730979471745,14.90837339047518,14.75801580147858,14.607658212482022,14.457300623485454,14.306943034488894,14.156585445492334,14.006227856495766,13.863135737003546,13.721938955639198,13.580742174274752,13.439545392910343,13.298348611545947,13.157151830181547,13.015955048817103,12.874758267452705,12.735453765759045,12.602633475267691,12.469813184776314,12.33699289428497,12.204172603793616,12.071352313302265,11.93853202281093,11.805711732319576,11.675272026184484,11.550273658433415,11.42527529068238,11.300276922931337,11.175278555180302,11.05028018742927,10.925281819678194,10.80028345192715,10.684017102585452,10.568132618487583,10.452248134389684,10.336363650291824,10.220479166193964,10.104594682096096,9.989963763691907,9.883974443922332,9.777985124152748,9.671995804383169,9.566006484613569,9.460017164843958,9.354027845074373,9.253345007781858,9.154358057166572,9.055371106551311,8.956384155936057,8.85739720532078,8.758410254705518,8.663586783089066,8.569765149514765,8.47594351594046,8.38212188236616,8.288300248791861,8.19600196725796,8.108754798735117,8.02150763021226,7.934260461689424,7.847013293166562,7.759766124643745,7.679454240614687,7.5991423567479375,7.518830472881177,7.438518589014435,7.3587006097601835,7.2845413735258635,7.210382137291552,7.136222901057232,7.06206366482291,6.990330180364274,6.9216167560198185,6.852903331675386,6.78418990733093,6.71449550440172,6.632048379870366,6.549601255339009,6.467154130807658,6.3847070062763,6.30225988174494,6.219812757213589,6.137365632682238,6.054918508150873,5.972471383619523,5.8900242590881735,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[65.93706374470628,65.96827499978204,65.99948625485781,66.03069750993359,66.06190876500936,66.09312002008514,66.1243312751609,66.15554253023667,66.18675378531243,66.21796504038821,66.24917629546398,66.28038755053976,66.31159880561552,66.34281006069129,66.37402131576707,66.40523257084283,66.4364438259186,66.46765508099438,66.49886633607014,66.53007759114591,66.56128884622169,66.59250010129745,66.62371135637322,66.654922611449,66.68613386652476,66.71734512160053,66.7485563766763,66.77976763175208,66.81097888682785,66.84219014190361,66.87340139697939,66.90461265205515,66.93582390713092,66.96703516220671,66.9996044613822,67.03244537136983,67.06528628135743,67.09812719134504,67.13096810133266,67.16380901132025,67.19664992130787,67.22949083129548,67.26233174128309,67.2951726512707,67.3280135612583,67.36085447124591,67.39369538123353,67.42653629122114,67.45937720120875,67.49221811119635,67.52505902118396,67.55789993117158,67.59074084115919,67.6235817511468,67.6564226611344,67.68926357112201,67.72210448110962,67.75494539109724,67.78778630108485,67.82062721107246,67.85346812106008,67.88630903104767,67.91914994103529,67.9519908510229,67.98483176101051,68.01767267099811,68.05051358098572,68.08335449097333,68.11619540096095,68.14903631094856,68.18187722093617,68.21471813092377,68.24755904091138,68.280399950899,68.3132408608866,68.3460817708742,68.37892268086182,68.41176359084943,68.44460450083704,68.47744541082466,68.51028632081227,68.54312723079987,68.57596814078748,68.6088090507751,68.60614086477298,68.59637085957294,68.58660085437289,68.57683084917284,68.5670608439728,68.55729083877274,68.54752083357269,68.53775082837265,68.52798082317258,68.51821081797254,68.5084408127725,68.49867080757245,68.48890080237241,68.47913079717236,68.46936079197232,68.45959078677227,68.44982078157221,68.44005077637217,68.43028077117212,68.42051076597207,68.41074076077203,68.40097075557198,68.39120075037192,68.38143074517187,68.37166073997183,68.36189073477178,68.35212072957174,68.34235072437168,68.33258071917163,68.32281071397159,68.31304070877154,68.3032707035715,68.29350069837145,68.28373069317139,68.27396068797135,68.26419068277129,68.25442067757126,68.24465067237121,68.23488066717115,68.22511066197112,68.21534065677106,68.20557065157101,68.19580064637097,68.18603064117092,68.17626063597086,68.16649063077081,68.15672062557077,68.14695062037072,68.13718061517068,68.12741060997062,68.10677886822657,68.08397479510701,68.06117072198745,68.03836664886788,68.0155625757483,67.99275850262875,67.96995442950917,67.94715035638961,67.92434628327004,67.90154221015048,67.87873813703092,67.85593406391135,67.83312999079179,67.81032591767223,67.78752184455266,67.7647177714331,67.74191369831352,67.71910962519397,67.69630555207439,67.67350147895483,67.65069740583526,67.6278933327157,67.60508925959613,67.58228518647657,67.559481113357,67.53667704023744,67.51387296711786,67.4910688939983,67.46826482087874,67.44546074775917,67.42265667463961,67.39985260152005,67.37704852840048,66.97841708508666,66.39187195667579,65.80532682826487,65.21878169985396,64.63223657144307,64.04569144303213,63.45914631462125,62.872601186210346,62.286056057799435,61.699510929388545,61.112965800977605,60.52642067256672,59.93987554415581,59.3533304157449,58.76678528733401,58.180240158923105,57.593695030512194,57.00714990210128,56.420604773690364,55.83405964527948,55.24751451686857,54.66096938845766,54.074424260046776,53.487879131635836,52.90133400322495,52.31478887481404,51.72824374640313,51.14169861799225,50.5551534895813,49.96860836117042,49.382063232759506,48.7955181043486,48.20897297593771,47.6224278475268,47.0358827191159,46.449337590704985,45.86279246229407,45.276247333883184,44.68970220547227,44.10315707706136,43.51661194865047,42.93006682023957,42.34352169182865,41.75697656341774,41.170431435006826,40.58388630659592,39.99734117818503,39.41079604977411,38.824250921363216,38.2377057929523,37.65116066454139,37.0646155361305,36.4780704077196,35.89152527930868,35.30498015089777,34.71843502248689,34.13188989407597,33.545344765665064,32.958799637254145,32.37225450884324,31.78570938043235,31.19916425202144,30.61261912361053,30.026073995199617,29.44101597189487,28.85638283256343,28.271749693231985,27.68711655390055,27.102483414569107,26.5178502752377,25.933217135906254,25.34858399657481,24.763950857243376,24.179317717911932,23.59468457858052,23.01005143924908,22.425418299917638,21.840785160586197,21.256152021254785,20.67151888192334,20.086885742591903,19.502252603260462,18.91761946392902,18.53960491198631,18.3682089474323,18.19681298287825,18.02541701832425,17.854021053770232,17.682625089216234,17.511229124662236,17.33983316010822,17.16843719555416,17.005823119124116,16.845423279895716,16.68502344066736,16.524623601439014,16.364223762210667,16.203823922982266,16.043424083753965,15.883024244525574,15.722624405297216,15.562224566068872,15.407535024175868,15.257177435179255,15.10681984618269,14.956462257186141,14.806104668189567,14.655747079193004,14.505389490196404,14.355031901199842,14.204674312203275,14.055896174195828,13.91469939283143,13.773502611467023,13.632305830102577,13.491109048738226,13.349912267373782,13.208715486009371,13.067518704644975,12.926321923280577,12.78941430903664,12.656594018545295,12.523773728053953,12.3909534375626,12.258133147071222,12.125312856579876,11.992492566088526,11.859672275597172,11.730796954001182,11.605798586250138,11.480800218499096,11.35580185074803,11.230803482996993,11.105805115245952,10.980806747494917,10.856521198864518,10.740636714766651,10.624752230668783,10.50886774657093,10.392983262473061,10.277098778375164,10.161214294277302,10.047036793110856,9.941047473341271,9.835058153571694,9.729068833802117,9.623079514032533,9.517090194262956,9.411100874493354,9.31025391916942,9.21126696855416,9.112280017938911,9.013293067323625,8.914306116708365,8.815319166093111,8.720040313873126,8.62621868029882,8.53239704672452,8.43857541315022,8.344753779575916,8.251477345928762,8.164230177405924,8.076983008883083,7.989735840360241,7.902488671837386,7.815241503314549,7.733503213219719,7.653191329352959,7.572879445486215,7.492567561619467,7.412255677752707,7.336995737907858,7.26283650167352,7.1886772654392,7.114518029204889,7.041098647528315,6.9723852231838555,6.903671798839428,6.834958374494972,6.76624495015054,6.6877217399583015,6.605274615426953,6.5228274908955965,6.44038036636424,6.357933241832891,6.275486117301531,6.19303899277017,6.11059186823882,6.02814474370747,5.945697619176105,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[65.83268419695656,65.86389545203232,65.8951067071081,65.92631796218386,65.95752921725963,65.98874047233541,66.01995172741118,66.05116298248694,66.08237423756272,66.11358549263849,66.14479674771427,66.17600800279003,66.2072192578658,66.23843051294158,66.26964176801735,66.30085302309311,66.33206427816889,66.36327553324466,66.39448678832042,66.4256980433962,66.45690929847197,66.48812055354774,66.5193318086235,66.55054306369928,66.58175431877505,66.61296557385081,66.64417682892659,66.67538808400236,66.70659933907812,66.7378105941539,66.76902184922967,66.80023310430543,66.83144435938121,66.86265561445698,66.89386686953274,66.92507812460853,66.95628937968429,66.98750063476005,67.01871188983584,67.0499231449116,67.08113439998738,67.11234565506315,67.14355691013891,67.17476816521469,67.20597942029045,67.23719067536622,67.268401930442,67.29961318551777,67.33082444059353,67.36203569566932,67.39379016712002,67.42663107710763,67.45947198709524,67.49231289708284,67.52515380707045,67.55799471705807,67.59083562704568,67.62367653703328,67.65651744702089,67.6893583570085,67.72219926699611,67.75504017698373,67.78788108697134,67.82072199695894,67.85356290694655,67.88640381693416,67.91924472692178,67.95208563690939,67.984926546897,68.0177674568846,68.05060836687221,68.08344927685982,68.11629018684744,68.14913109683505,68.18197200682265,68.21481291681026,68.24765382679787,68.28049473678549,68.3133356467731,68.3461765567607,68.37901746674831,68.41185837673592,68.44469928672353,68.47754019671113,68.47487201070903,68.46510200550898,68.45533200030893,68.44556199510889,68.43579198990884,68.4260219847088,68.41625197950874,68.40648197430869,68.39671196910865,68.3869419639086,68.37717195870854,68.3674019535085,68.35763194830847,68.3478619431084,68.33809193790836,68.3283219327083,68.31855192750825,68.30878192230821,68.29901191710816,68.28924191190812,68.27947190670807,68.26970190150801,68.25993189630796,68.25016189110792,68.24039188590787,68.23062188070783,68.22085187550778,68.21108187030772,68.20131186510768,68.19154185990764,68.18177185470759,68.17200184950754,68.16223184430748,68.14811713437257,68.125313061253,68.10250898813344,68.07970491501386,68.0569008418943,68.03409676877475,68.01129269565519,67.98848862253561,67.96568454941605,67.94288047629648,67.92007640317692,67.89727233005735,67.87446825693779,67.85166418381823,67.82886011069866,67.8060560375791,67.78325196445951,67.76044789133996,67.73764381822039,67.71483974510083,67.69203567198126,67.6692315988617,67.64642752574213,67.62362345262255,67.60081937950301,67.57801530638343,67.55521123326386,67.5324071601443,67.50960308702474,67.48679901390517,67.46399494078561,67.44119086766605,67.41838679454648,67.39558272142692,67.37277864830735,67.34997457518777,67.32717050206821,67.30436642894864,67.28156235582908,67.25875828270952,67.23595420958995,67.21315013647039,67.19034606335083,67.16754199023126,67.1447379171117,67.12193384399212,67.09912977087255,67.076325697753,67.05352162463343,67.03071755151387,66.63208610820004,66.04554097978917,65.45899585137826,64.87245072296734,64.28590559455645,63.69936046614552,63.112815337734645,62.52627020932373,61.93972508091281,61.35317995250193,60.766634824091,60.18008969568011,59.5935445672692,59.00699943885829,58.4204543104474,57.833909182036486,57.247364053625574,56.66081892521467,56.07427379680375,55.48772866839286,54.90118353998196,54.314638411571046,53.72809328316016,53.141548154749216,52.55500302633834,51.96845789792742,51.38191276951651,50.79536764110562,50.208822512694695,49.622277384283805,49.03573225587289,48.449187127461975,47.86264199905111,47.27609687064018,46.68955174222927,46.103006613818366,45.51646148540746,44.929916356996564,44.34337122858565,43.75682610017475,43.17028097176386,42.58373584335295,41.997190714942036,41.41229202446366,40.827658885132216,40.24302574580078,39.65839260646936,39.07375946713793,38.48912632780649,37.904493188475044,37.31986004914361,36.73522690981219,36.150593770480754,35.56596063114931,34.98132749181787,34.396694352486456,33.81206121315501,33.22742807382358,32.64279493449214,32.0581617951607,31.473528655829288,30.88889551649784,30.3042623771664,29.719629237834962,29.13499609850355,28.55036295917211,27.965729819840668,27.381096680509227,26.796463541177786,26.211830401846374,25.627197262514933,25.042564123183496,24.45793098385205,23.873297844520607,23.2886647051892,22.704031565857754,22.119398426526317,21.534765287194876,20.950132147863464,20.365499008532023,19.780865869200582,19.19623272986914,18.6115995905377,18.23358503859499,18.062189074040976,17.890793109486925,17.719397144932927,17.54800118037891,17.376605215824913,17.20948760683434,17.049087767605986,16.888687928377628,16.72828808914929,16.56788824992089,16.407488410692537,16.247088571464193,16.086688732235842,15.92628889300744,15.765889053779139,15.605981479883372,15.4556238908868,15.305266301890201,15.154908712893684,15.004551123897073,14.854193534900507,14.703835945903958,14.553478356907386,14.40312076791082,14.25276317891422,14.1074598300237,13.966263048659256,13.825066267294858,13.68386948593046,13.542672704566053,13.401475923201605,13.260279141837255,13.119082360472811,12.977885579108403,12.843374852314282,12.710554561822905,12.57773427133155,12.444913980840207,12.312093690348863,12.179273399857511,12.046453109366134,11.91363281887479,11.786321881817866,11.661323514066824,11.536325146315797,11.411326778564755,11.286328410813713,11.161330043062645,11.036331675311612,10.91314081104575,10.79725632694789,10.68137184285,10.565487358752131,10.449602874654264,10.333718390556411,10.217833906458543,10.104109822529795,9.998120502760218,9.892131182990642,9.786141863221058,9.680152543451479,9.574163223681904,9.46817390391232,9.367162830556989,9.268175879941735,9.169188929326472,9.070201978711212,8.971215028095964,8.872228077480678,8.7764938446572,8.682672211082878,8.588850577508579,8.495028943934274,8.401207310359975,8.307385676785675,8.219705556076724,8.132458387553886,8.04521121903105,7.957964050508208,7.8707168819853655,7.787552185824722,7.707240301957978,7.626928418091248,7.546616534224487,7.466304650357745,7.389450102289826,7.315290866055507,7.241131629821193,7.166972393586856,7.092813157352534,7.0231536903479155,6.95444026600347,6.885726841659008,6.817013417314582,6.743395100046249,6.66094797551489,6.578500850983533,6.496053726452183,6.413606601920828,6.3311594773894715,6.248712352858121,6.166265228326763,6.0838181037954016,6.001370979264051,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[65.72830464920686,65.75951590428264,65.7907271593584,65.82193841443417,65.85314966950995,65.8843609245857,65.91557217966148,65.94678343473726,65.97799468981302,66.0092059448888,66.04041719996457,66.07162845504033,66.1028397101161,66.13405096519188,66.16526222026765,66.19647347534342,66.22768473041918,66.25889598549496,66.29010724057073,66.3213184956465,66.35252975072227,66.38374100579804,66.4149522608738,66.44616351594956,66.47737477102535,66.50858602610111,66.53979728117689,66.57100853625266,66.60221979132844,66.6334310464042,66.66464230147997,66.69585355655575,66.72706481163151,66.75827606670728,66.78948732178306,66.82069857685883,66.85190983193459,66.88312108701037,66.91433234208614,66.9455435971619,66.97675485223768,67.00796610731345,67.03917736238921,67.070388617465,67.10159987254076,67.13281112761652,67.1640223826923,67.19523363776807,67.22644489284384,67.2576561479196,67.28886740299538,67.32007865807115,67.35128991314693,67.3825011682227,67.41371242329846,67.44492367837424,67.47613493345,67.50734618852579,67.53855744360153,67.56976869867732,67.60097995375308,67.63219120882886,67.66340246390462,67.69461371898039,67.72582497405617,67.75703622913193,67.7882474842077,67.82081678284544,67.85365769283305,67.88649860282067,67.91933951280826,67.95218042279588,67.98502133278349,68.0178622427711,68.0507031527587,68.08354406274631,68.11638497273393,68.14922588272154,68.18206679270915,68.21490770269676,68.24774861268438,68.28058952267197,68.31343043265959,68.3462713426472,68.34360315664509,68.33383315144505,68.324063146245,68.31429314104494,68.3045231358449,68.29475313064485,68.2849831254448,68.27521312024474,68.2654431150447,68.25567310984465,68.24590310464461,68.23613309944456,68.2263630942445,68.21659308904447,68.20682308384443,68.19705307864437,68.18728307344432,68.16665132739902,68.14384725427946,68.12104318115989,68.09823910804032,68.07543503492076,68.05263096180119,68.02982688868164,68.00702281556207,67.98421874244251,67.96141466932293,67.93861059620338,67.9158065230838,67.89300244996424,67.87019837684468,67.84739430372511,67.82459023060555,67.80178615748598,67.7789820843664,67.75617801124685,67.73337393812727,67.71056986500773,67.68776579188815,67.6649617187686,67.64215764564902,67.61935357252946,67.59654949940989,67.57374542629034,67.55094135317076,67.5281372800512,67.50533320693164,67.48252913381206,67.4597250606925,67.43692098757293,67.41411691445337,67.3913128413338,67.36850876821424,67.34570469509467,67.32290062197511,67.30009654885554,67.27729247573598,67.2544884026164,67.23168432949684,67.20888025637728,67.18607618325771,67.16327211013815,67.1404680370186,67.11766396389902,67.09485989077946,67.07205581765989,67.04925174454033,67.02644767142075,67.00364359830118,66.98083952518162,66.95803545206206,66.93523137894249,66.91242730582293,66.88962323270336,66.8668191595838,66.84401508646422,66.82121101334467,66.7984069402251,66.77560286710553,66.75279879398597,66.7299947208664,66.70719064774684,66.68438657462727,66.28575513131346,65.69921000290257,65.11266487449167,64.52611974608075,63.93957461766987,63.35302948925893,62.76648436084805,62.179939232437135,61.593394104026224,61.00684897561534,60.42030384720441,59.83375871879352,59.24721359038261,58.6606684619717,58.07412333356081,57.4875782051499,56.90103307673899,56.31448794832808,55.72794281991716,55.14139769150627,54.554852563095366,53.96830743468446,53.38356807703251,52.79893493770104,52.214301798369625,51.62966865903818,51.045035519706744,50.46040238037533,49.87576924104387,49.29113610171245,48.706502962381016,48.12186982304957,47.537236683718156,46.95260354438672,46.36797040505527,45.78333726572383,45.19870412639239,44.614070987060984,44.02943784772954,43.444804708398095,42.86017156906669,42.27553842973524,41.690905290403805,41.10627215107236,40.52163901174092,39.937005872409486,39.35237273307807,38.767739593746626,38.18310645441519,37.59847331508375,37.01384017575231,36.42920703642089,35.844573897089454,35.25994075775801,34.67530761842657,34.090674479095156,33.50604133976372,32.92140820043228,32.33677506110084,31.7521419217694,31.167508782437984,30.582875643106547,29.998242503775103,29.413609364443662,28.82897622511225,28.24434308578081,27.659709946449368,27.07507680711793,26.490443667786487,25.905810528455074,25.321177389123633,24.736544249792196,24.151911110460752,23.567277971129315,22.9826448317979,22.398011692466458,21.813378553135017,21.228745413803576,20.644112274472164,20.059479135140723,19.474845995809282,18.890212856477845,18.3055797171464,17.92756516520369,17.756169200649683,17.58477323609563,17.41337727154163,17.252752255316278,17.092352416087888,16.93195257685954,16.771552737631186,16.61115289840283,16.450753059174488,16.29035321994609,16.129953380717733,15.96955354148939,15.80915370226104,15.654070346594327,15.503712757597768,15.353355168601214,15.202997579604641,15.052639990608045,14.902282401611526,14.751924812614917,14.601567223618348,14.4512096346218,14.300852045625227,14.159023485851547,14.017826704487149,13.876629923122751,13.735433141758309,13.594236360393909,13.453039579029511,13.311842797665102,13.170646016300656,13.030155686083258,12.897335395591906,12.76451510510052,12.631694814609208,12.49887452411783,12.366054233626478,12.233233943135133,12.100413652643791,11.967593362152439,11.841846809634605,11.716848441883537,11.591850074132493,11.466851706381453,11.341853338630425,11.216854970879382,11.09185660312834,10.969760423226974,10.853875939129113,10.737991455031246,10.622106970933386,10.506222486835496,10.390338002737625,10.274453518639758,10.16118285194879,10.055193532179207,9.949204212409594,9.843214892640018,9.737225572870441,9.631236253100857,9.52524693333128,9.42407174194457,9.32508479132931,9.226097840714054,9.1271108900988,9.028123939483537,8.929136988868278,8.832947375441297,8.739125741866992,8.645304108292665,8.551482474718345,8.457660841144044,8.36383920756974,8.275180934747539,8.1879337662247,8.10068659770186,8.013439429179023,7.926192260656185,7.841601158429769,7.761289274563021,7.68097739069626,7.600665506829516,7.520353622962787,7.441904466671806,7.367745230437489,7.293585994203169,7.2194267579688525,7.145267521734537,7.073922157511975,7.005208733167514,6.936495308823076,6.867781884478632,6.79906846013417,6.716621335602838,6.634174211071488,6.55172708654013,6.469279962008773,6.386832837477423,6.304385712946068,6.2219385884147105,6.139491463883361,6.057044339352003,5.9745972148206405,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[65.62392510145715,65.65513635653292,65.68634761160868,65.71755886668446,65.74877012176023,65.77998137683599,65.81119263191177,65.84240388698754,65.87361514206331,65.90482639713908,65.93603765221485,65.96724890729061,65.99846016236638,66.02967141744216,66.06088267251793,66.09209392759371,66.12330518266947,66.15451643774524,66.18572769282102,66.21693894789678,66.24815020297255,66.27936145804833,66.31057271312409,66.34178396819986,66.37299522327562,66.4042064783514,66.43541773342719,66.46662898850295,66.49784024357872,66.52905149865448,66.56026275373026,66.59147400880603,66.62268526388179,66.65389651895757,66.68510777403334,66.71631902910912,66.74753028418488,66.77874153926065,66.80995279433643,66.84116404941219,66.87237530448796,66.90358655956373,66.9347978146395,66.96600906971528,66.99722032479104,67.0284315798668,67.05964283494258,67.09085409001835,67.12206534509413,67.1532766001699,67.18448785524566,67.21569911032144,67.24691036539721,67.27812162047297,67.30933287554875,67.34054413062452,67.37175538570028,67.40296664077606,67.43417789585183,67.46538915092759,67.49660040600337,67.52781166107914,67.5590229161549,67.59023417123068,67.62144542630645,67.65265668138223,67.683867936458,67.71507919153376,67.74629044660954,67.77750170168531,67.80871295676107,67.83992421183684,67.87113546691262,67.90234672198838,67.93355797706415,67.96476923213993,67.99598048721569,68.02719174229146,68.05840299736724,68.08961425244301,68.12082550751877,68.15203676259455,68.18324801767032,68.21500248858324,68.20798959354502,68.18518552042545,68.16238144730589,68.13957737418632,68.11677330106676,68.0939692279472,68.07116515482763,68.04836108170807,68.02555700858849,68.00275293546893,67.97994886234936,67.9571447892298,67.93434071611023,67.91153664299067,67.8887325698711,67.86592849675154,67.84312442363198,67.82032035051242,67.79751627739284,67.77471220427327,67.75190813115371,67.72910405803415,67.70629998491458,67.68349591179502,67.66069183867545,67.63788776555589,67.61508369243633,67.59227961931676,67.5694755461972,67.54667147307762,67.52386739995806,67.5010633268385,67.47825925371893,67.45545518059936,67.4326511074798,67.40984703436024,67.38704296124067,67.3642388881211,67.34143481500155,67.31863074188198,67.2958266687624,67.27302259564286,67.25021852252328,67.22741444940371,67.20461037628414,67.18180630316458,67.15900223004502,67.13619815692545,67.11339408380589,67.09059001068631,67.06778593756675,67.04498186444718,67.02217779132762,66.99937371820805,66.97656964508849,66.95376557196892,66.93096149884936,66.90815742572978,66.88535335261022,66.86254927949065,66.83974520637109,66.81694113325153,66.79413706013196,66.7713329870124,66.74852891389284,66.72572484077327,66.70292076765371,66.68011669453415,66.65731262141458,66.634508548295,66.61170447517544,66.58890040205587,66.56609632893631,66.54329225581674,66.52048818269718,66.49768410957762,66.47488003645805,66.45207596333849,66.42927189021891,66.40646781709935,66.38366374397978,66.36085967086022,66.33805559774066,65.93947726893272,65.35484412960129,64.77021099026986,64.18557785093842,63.600944711607006,63.016311572275534,62.431678432944125,61.84704529361268,61.262412154281236,60.67777901494983,60.09314587561836,59.508512736286946,58.9238795969555,58.339246457624064,57.75461331829265,57.16998017896121,56.58534703962977,56.00071390029834,55.41608076096689,54.831447621635476,54.24681448230404,53.662181342972595,53.077548203641186,52.49291506430971,51.9082819249783,51.32364878564687,50.73901564631542,50.15438250698401,49.56974936765254,48.98511622832113,48.40048308898969,47.81584994965825,47.231216810326835,46.6465836709954,46.06195053166395,45.47731739233251,44.89268425300107,44.308051113669656,43.72341797433822,43.138784835006774,42.55415169567536,41.96951855634393,41.384885417012484,40.80025227768105,40.2156191383496,39.63098599901816,39.04635285968675,38.46171972035531,37.87708658102387,37.29245344169243,36.707820302360986,36.12318716302957,35.53855402369813,34.95392088436669,34.36928774503525,33.784654605703835,33.2000214663724,32.61538832704096,32.03075518770952,31.44612204837808,30.861488909046663,30.276855769715223,29.69222263038378,29.10758949105234,28.52295635172093,27.938323212389488,27.353690073058047,26.769056933726606,26.184423794395165,25.599790655063753,25.015157515732312,24.43052437640087,23.84589123706943,23.261258097737993,22.676624958406578,22.091991819075137,21.507358679743696,20.922725540412255,20.338092401080843,19.753459261749402,19.16882612241796,18.58419298308652,17.99955984375508,17.621545291812367,17.4564167430265,17.29601690379815,17.135617064569807,16.975217225341453,16.814817386113063,16.654417546884716,16.494017707656358,16.333617868428004,16.173218029199663,16.012818189971263,15.852516802301878,15.702159213305276,15.55180162430876,15.401444035312151,15.25108644631559,15.100728857319035,14.950371268322465,14.800013679325865,14.649656090329348,14.499298501332738,14.351783923043781,14.21058714167943,14.069390360314985,13.928193578950577,13.786996797586179,13.645800016221783,13.504603234857337,13.363406453492939,13.22220967212854,13.084116229360859,12.951295938869507,12.81847564837817,12.68565535788682,12.552835067395431,12.42001477690412,12.28719448641274,12.154374195921392,12.022370105202327,11.897371737451294,11.772373369700253,11.647375001949218,11.522376634198151,11.397378266447108,11.272379898696066,11.14738153094504,11.026380035408215,10.910495551310344,10.794611067212454,10.678726583114592,10.562842099016727,10.446957614918865,10.331073130820975,10.21825588136773,10.112266561598148,10.006277241828576,9.900287922058993,9.79429860228938,9.688309282519803,9.582319962750228,9.480980653332155,9.381993702716901,9.283006752101622,9.184019801486361,9.085032850871109,8.986045900255855,8.889400906225353,8.795579272651047,8.701757639076753,8.607936005502449,8.51411437192812,8.420292738353801,8.330656313418341,8.2434091448955,8.156161976372664,8.068914807849826,7.981667639326984,7.895650131034807,7.8153382471680635,7.735026363301297,7.65471447943455,7.57440259556779,7.494358831053795,7.420199594819475,7.346040358585143,7.271881122350826,7.197721886116505,7.124690624676017,7.055977200331575,6.987263775987129,6.918550351642667,6.849836927298231,6.772294695690785,6.689847571159427,6.60740044662807,6.524953322096719,6.442506197565361,6.360059073034005,6.2776119485026545,6.1951648239713,6.112717699439942,6.030270574908592,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[65.51288603785714,65.54409729293292,65.57530854800868,65.60651980308445,65.63773105816023,65.668942313236,65.70015356831178,65.73136482338754,65.76257607846331,65.79378733353907,65.82499858861485,65.85620984369062,65.88742109876638,65.91863235384216,65.94984360891793,65.9810548639937,66.01226611906947,66.04347737414524,66.07468862922101,66.10589988429679,66.13711113937255,66.16832239444832,66.19953364952408,66.23074490459986,66.26195615967563,66.29316741475141,66.32437866982718,66.35558992490294,66.38680117997872,66.4180124350545,66.44922369013025,66.48043494520603,66.5116462002818,66.54285745535756,66.57406871043334,66.60527996550911,66.63649122058487,66.66770247566063,66.69891373073642,66.73012498581218,66.76133624088796,66.79254749596373,66.8237587510395,66.85497000611528,66.88618126119104,66.91739251626682,66.94860377134258,66.97981502641835,67.01102628149413,67.0422375365699,67.07344879164566,67.10466004672143,67.13587130179721,67.16708255687298,67.19829381194874,67.22950506702452,67.2607163221003,67.29192757717607,67.32313883225183,67.3543500873276,67.38556134240336,67.41677259747914,67.44798385255491,67.47919510763067,67.51040636270645,67.54161761778222,67.572828872858,67.60404012793376,67.63363154613066,67.66289899926103,67.6921664523914,67.72143390552176,67.75070135865214,67.77996881178251,67.80923626491287,67.83850371804323,67.8677711711736,67.89703862430397,67.92630607743435,67.9555735305647,67.98484098369508,68.01410843682544,68.04337588995581,68.07264334308617,68.04266503480154,68.0008375742339,67.95901011366628,67.91718265309864,67.87535519253102,67.83352773196339,67.79170027139575,67.74987281082812,67.70804535026049,67.66621788969285,67.62439042912523,67.5825629685576,67.54073550798995,67.49890804742232,67.4570805868547,67.41525312628707,67.38927846975967,67.3664743966401,67.34367032352054,67.32086625040097,67.29806217728141,67.27525810416184,67.25245403104228,67.22964995792272,67.20684588480314,67.18404181168358,67.16123773856401,67.13843366544445,67.11562959232488,67.09282551920532,67.07002144608575,67.04721737296619,67.02441329984661,67.00160922672706,66.97880515360748,66.95600108048792,66.93319700736835,66.91039293424879,66.88758886112923,66.86478478800966,66.8419807148901,66.81917664177054,66.79637256865097,66.7735684955314,66.75076442241183,66.72796034929227,66.7051562761727,66.68235220305314,66.65954812993357,66.63674405681401,66.61393998369444,66.59113591057488,66.56833183745532,66.54552776433574,66.52272369121619,66.49991961809661,66.47711554497705,66.45431147185748,66.43150739873792,66.40870332561835,66.38589925249879,66.36309517937921,66.34029110625967,66.3174870331401,66.29468296002054,66.27187888690096,66.2490748137814,66.22627074066185,66.20346666754227,66.1806625944227,66.15785852130314,66.13505444818357,66.11225037506401,66.08944630194443,66.06664222882488,66.0438381557053,66.02103408258574,65.99823000946617,65.97542593634661,65.95262186322705,65.92981779010748,65.90701371698792,65.88420964386835,65.49340597148382,64.91860249946686,64.34379902744986,63.76899555543288,63.19419208341591,62.619388611398904,62.04458513938193,61.469781667364956,60.89497819534797,60.32017472333099,59.74537125131398,59.17056777929702,58.595764307280035,58.02096083526305,57.44615736324607,56.8713538912291,56.2965504192121,55.72032663502337,55.135580907341996,54.55083517966066,53.96608945197929,53.38134372429792,52.79659799661658,52.21185226893519,51.627106541253845,51.04236081357248,50.45761508589111,49.87286935820977,49.288123630528375,48.70337790284704,48.118632175165665,47.533886447484306,46.94914071980296,46.364394992121596,45.779649264440216,45.19490353675886,44.610157809077485,44.02541208139614,43.440666353714775,42.8559206260334,42.271174898352065,41.6864291706707,41.101683442989334,40.51693771530796,39.932191987626595,39.34744625994522,38.762700532263885,38.17795480458252,37.593209076901154,37.00846334921978,36.423717621538415,35.83897189385707,35.254226166175705,34.66948043849434,34.084734710812974,33.49998898313163,32.915243255450264,32.3304975277689,31.745751800087525,31.16100607240616,30.576260344724815,29.991514617043453,29.406768889362084,28.822023161680715,28.237277433999374,27.652531706318005,27.067785978636635,26.48304025095527,25.898294523273904,25.31354879559256,24.728803067911194,24.144057340229825,23.559311612548456,22.97456588486709,22.38982015718575,21.80507442950438,21.220328701823014,20.635582974141645,20.050837246460304,19.466091518778935,18.881345791097566,18.2966000634162,17.71185433573483,17.33928155228008,17.178881713051684,17.01848187382333,16.858082034594986,16.69768219536663,16.537282356138242,16.376882516909895,16.216482677681537,16.056082838453182,15.900605669012839,15.750248080016268,15.599890491019698,15.4495329020231,15.299175313026582,15.148817724029973,14.998460135033412,14.848102546036857,14.697744957040285,14.547387368043687,14.403347578871667,14.262150797507259,14.120954016142814,13.979757234778463,13.838560453414019,13.697363672049608,13.55616689068521,13.414970109320814,13.27377332795637,13.1380767726385,13.005256482147121,12.87243619165577,12.739615901164418,12.606795610673082,12.47397532018173,12.341155029690341,12.208334739199032,12.077895033019056,11.952896665268012,11.827898297516946,11.702899929765913,11.577901562014867,11.452903194263834,11.327904826512768,11.202906458761722,11.082999647589414,10.967115163491563,10.851230679393694,10.735346195295826,10.619461711197935,10.503577227100074,10.387692743002207,10.275328910786682,10.169339591017103,10.063350271247518,9.957360951477936,9.851371631708366,9.74538231193878,9.63939299216917,9.53788956471975,9.438902614104473,9.339915663489212,9.240928712873956,9.141941762258677,9.042954811643417,8.945854437009414,8.852032803435115,8.75821116986081,8.664389536286503,8.57056790271221,8.476746269137903,8.38613169208916,8.298884523566324,8.211637355043468,8.124390186520627,8.03714301799779,7.949895849474953,7.86938721977308,7.789075335906338,7.708763452039594,7.628451568172828,7.548139684306081,7.472653959201449,7.398494722967131,7.324335486732811,7.2501762504984795,7.176017014264162,7.106745667495628,7.0380322431511715,6.969318818806729,6.900605394462285,6.827968055778721,6.745520931247375,6.663073806716013,6.580626682184655,6.498179557653298,6.415732433121947,6.33328530859059,6.250838184059233,6.168391059527883,6.085943934996527,6.003496810465171,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[65.40163886503869,65.43285012011447,65.46406137519023,65.495272630266,65.52648388534178,65.55769514041754,65.58890639549331,65.62011765056909,65.65132890564485,65.68254016072062,65.7137514157964,65.74496267087216,65.77617392594794,65.8073851810237,65.83859643609948,65.86980769117525,65.90101894625101,65.93223020132679,65.96344145640256,65.99465271147832,66.02586396655411,66.05707522162987,66.08828647670565,66.11949773178141,66.15070898685718,66.18192024193294,66.21313149700872,66.2443427520845,66.27555400716025,66.30676526223604,66.3379765173118,66.36918777238758,66.40039902746335,66.43161028253911,66.46282153761489,66.49403279269066,66.52524404776642,66.5564553028422,66.58766655791796,66.61887781299374,66.65008906806952,66.68130032314528,66.71251157822105,66.74372283329683,66.77493408837259,66.80614534344835,66.83735659852414,66.8685678535999,66.89977910867567,66.93099036375145,66.96220161882721,66.99276493905661,67.02203239218699,67.05129984531735,67.08056729844772,67.10983475157808,67.13910220470845,67.16836965783882,67.19763711096918,67.22690456409956,67.25617201722991,67.28543947036029,67.31470692349066,67.34397437662102,67.3732418297514,67.40250928288175,67.43177673601213,67.46104418914248,67.49031164227286,67.51957909540323,67.54884654853359,67.57811400166396,67.60738145479432,67.6366489079247,67.66591636105507,67.69518381418543,67.7244512673158,67.75371872044616,67.78298617357653,67.81225362670689,67.84152107983726,67.87078853296764,67.900055986098,67.92932343922837,67.89934513094373,67.8575176703761,67.81569020980847,67.77386274924083,67.73203528867322,67.69020782810557,67.64838036753794,67.60655290697031,67.56472544640268,67.52289798583504,67.48107052526741,67.43924306469978,67.39741560413215,67.35558814356452,67.31376068299689,67.27193322242925,67.23010576186162,67.18827830129399,67.14645084072636,67.10462338015873,67.0627959195911,67.02096845902346,66.97914099845583,66.9373135378882,66.89548607732057,66.85365861675294,66.8118311561853,66.77000369561767,66.72817623505003,66.68634877448241,66.64452131391478,66.60269385334715,66.56720751346761,66.54440344034805,66.52159936722848,66.4987952941089,66.47599122098934,66.45318714786978,66.43038307475021,66.40757900163065,66.38477492851109,66.36197085539153,66.33916678227196,66.3163627091524,66.29355863603283,66.27075456291327,66.2479504897937,66.22514641667414,66.20234234355456,66.179538270435,66.15673419731543,66.13393012419587,66.1111260510763,66.08832197795674,66.06551790483718,66.0427138317176,66.01990975859803,65.99710568547847,65.97430161235891,65.95149753923934,65.92869346611978,65.90588939300022,65.88308531988065,65.86028124676108,65.83747717364153,65.81467310052196,65.79186902740238,65.76906495428283,65.74626088116325,65.7234568080437,65.70065273492412,65.67784866180456,65.65504458868499,65.63224051556543,65.60943644244585,65.5866323693263,65.56382829620674,65.54102422308716,65.5182201499676,65.49541607684804,65.47261200372847,65.4498079306089,65.42700385748934,65.03620018510482,64.46139671308785,63.886593241070855,63.311789769053874,62.73698629703691,62.1621828250199,61.58737935300292,61.01257588098595,60.437772408968954,59.86296893695199,59.28816546493498,58.71336199291801,58.13855852090103,57.56375504888403,56.988951576867066,56.414148104850085,55.83934463283309,55.26454116081611,54.68973768879911,54.11493421678215,53.540130744765165,52.965327272748176,52.39052380073121,51.81572032871419,51.24091685669724,50.666113384680244,50.091309912663256,49.51650644064629,48.94170296862928,48.36689949661232,47.792096024595324,47.217292552578336,46.642489080561376,46.06768560854439,45.4928821365274,44.91736850678405,44.332622779102685,43.74787705142134,43.163131323739975,42.5783855960586,41.993639868377265,41.40889414069589,40.824148413014534,40.23940268533316,39.654656957651795,39.06991122997043,38.485165502289085,37.90041977460772,37.31567404692635,36.73092831924498,36.14618259156361,35.56143686388227,34.9766911362009,34.39194540851953,33.80719968083817,33.22245395315683,32.63770822547546,32.05296249779409,31.468216770112726,30.883471042431356,30.298725314750016,29.71397958706865,29.129233859387277,28.544488131705915,27.95974240402457,27.374996676343205,26.790250948661836,26.20550522098047,25.6207594932991,25.03601376561776,24.45126803793639,23.86652231025502,23.281776582573656,22.697030854892287,22.112285127210946,21.527539399529577,20.94279367184821,20.35804794416684,19.7733022164855,19.18855648880413,18.603810761122766,18.019065033441397,17.434319305760027,17.061746522305278,16.901346683076877,16.740946843848526,16.580547004620183,16.42014716539183,16.259747326163435,16.099347486935088,15.948694535723837,15.798336946727227,15.647979357730678,15.497621768734112,15.347264179737541,15.19690659074094,15.046549001744422,14.896191412747813,14.745833823751253,14.59610801606392,14.45491123469951,14.313714453335113,14.172517671970715,14.031320890606306,13.89012410924186,13.74892732787751,13.607730546513066,13.466533765148657,13.32533698378426,13.192037315916123,13.059217025424768,12.926396734933425,12.793576444442046,12.660756153950693,12.52793586345934,12.395115572968004,12.262295282476654,12.13341996083575,12.00842159308472,11.883423225333683,11.75842485758264,11.633426489831574,11.508428122080542,11.383429754329496,11.258431386578462,11.139619259770674,11.023734775672775,10.907850291574906,10.791965807477055,10.676081323379186,10.560196839281316,10.444312355183426,10.332401940205663,10.226412620436054,10.120423300666479,10.0144339808969,9.908444661127316,9.802455341357733,9.696466021588163,9.594798476107306,9.495811525492067,9.396824574876813,9.297837624261536,9.198850673646273,9.099863723031019,9.002307967793485,8.908486334219178,8.81466470064488,8.720843067070579,8.627021433496274,8.533199799921968,8.44160707076,8.354359902237135,8.267112733714294,8.17986556519146,8.092618396668602,8.00537122814576,7.923436192378108,7.843124308511365,7.7628124246446175,7.682500540777875,7.602188656911132,7.525108323583445,7.450949087349107,7.3767898511147925,7.302630614880475,7.228471378646154,7.157514134659676,7.08880071031522,7.020087285970788,6.951373861626333,6.88266043728189,6.801194291335315,6.71874716680396,6.636300042272614,6.553852917741253,6.471405793209895,6.388958668678538,6.306511544147187,6.2240644196158295,6.1416172950844725,6.059170170553122,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[65.29039169222023,65.32160294729601,65.35281420237177,65.38402545744754,65.41523671252332,65.44644796759908,65.47765922267484,65.50887047775062,65.5400817328264,65.57129298790217,65.60250424297794,65.6337154980537,65.66492675312948,65.69613800820525,65.72734926328103,65.7585605183568,65.78977177343256,65.82098302850834,65.85219428358411,65.88340553865987,65.91461679373563,65.94582804881142,65.97703930388718,66.00825055896294,66.03946181403872,66.07067306911449,66.10188432419025,66.13309557926604,66.1643068343418,66.19551808941758,66.22672934449335,66.25794059956911,66.28915185464489,66.32036310972066,66.35157436479643,66.38116578511293,66.41043323824329,66.43970069137366,66.46896814450402,66.49823559763439,66.52750305076475,66.55677050389511,66.5860379570255,66.61530541015586,66.64457286328623,66.67384031641659,66.70310776954696,66.73237522267732,66.76164267580769,66.79091012893807,66.82017758206842,66.84944503519878,66.87871248832916,66.90797994145953,66.9372473945899,66.96651484772026,66.99578230085064,67.025049753981,67.05431720711137,67.08358466024173,67.1128521133721,67.14211956650247,67.17138701963283,67.2006544727632,67.22992192589356,67.25918937902394,67.2884568321543,67.31772428528467,67.34699173841503,67.37625919154542,67.40552664467577,67.43479409780613,67.4640615509365,67.49332900406688,67.52259645719724,67.55186391032761,67.58113136345797,67.61039881658834,67.63966626971872,67.66893372284908,67.69820117597945,67.72746862910981,67.75673608224018,67.78600353537054,67.75602522708591,67.71419776651828,67.67237030595065,67.63054284538302,67.58871538481537,67.54688792424776,67.50506046368012,67.46323300311249,67.42140554254486,67.37957808197723,67.33775062140958,67.29592316084197,67.25409570027432,67.2122682397067,67.17044077913906,67.12861331857142,67.08678585800381,67.04495839743618,67.00313093686853,66.96130347630091,66.91947601573328,66.87764855516564,66.83582109459802,66.79399363403039,66.75216617346274,66.71033871289512,66.66851125232748,66.62668379175986,66.58485633119223,66.5430288706246,66.50120141005695,66.45937394948932,66.41754648892169,66.37571902835407,66.33389156778642,66.2920641072188,66.25023664665116,66.20840918608354,66.1665817255159,66.12475426494827,66.08292680438063,66.04109934381302,65.99927188324537,65.95744442267775,65.91561696211011,65.87378950154248,65.83196204097484,65.79013458040723,65.74830711983958,65.72233248405595,65.69952841093638,65.67672433781682,65.65392026469726,65.63111619157769,65.60831211845813,65.58550804533856,65.562703972219,65.53989989909942,65.51709582597987,65.4942917528603,65.47148767974073,65.44868360662116,65.42587953350161,65.40307546038204,65.38027138726248,65.35746731414291,65.33466324102335,65.31185916790378,65.2890550947842,65.26625102166464,65.24344694854508,65.22064287542551,65.19783880230595,65.1750347291864,65.15223065606682,65.12942658294726,65.10662250982769,65.08381843670813,65.06101436358855,65.038210290469,65.01540621734942,64.99260214422986,64.96979807111029,64.57899439872577,64.0041909267088,63.42938745469181,62.854583982674825,62.27978051065786,61.70497703864085,61.13017356662389,60.5553700946069,59.980566622589905,59.40576315057294,58.83095967855593,58.25615620653896,57.68135273452198,57.106549262504984,56.53174579048803,55.956942318471036,55.382138846454055,54.80733537443705,54.23253190242007,53.65772843040311,53.082924958386116,52.50812148636913,51.93331801435216,51.35851454233515,50.78371107031818,50.208907598301195,49.634104126284214,49.05930065426725,48.48449718225023,47.90969371023327,47.334890238216275,46.760086766199294,46.18528329418233,45.61047982216534,45.03567635014835,44.46087287813136,43.88606940611437,43.31126593409741,42.73646246208042,42.16165899006343,41.58685551804647,41.012052046029474,40.43724857401249,39.8624451019955,39.287641629978516,38.712838157961514,38.13803468594456,37.56323121392757,36.98842774191058,36.41362426989359,35.8388207978766,35.26401732585964,34.68921385384265,34.114410378544704,33.529664650863346,32.944918923182,32.360173195500636,31.775427467819267,31.190681740137904,30.60593601245653,30.021190284775194,29.43644455709382,28.851698829412452,28.26695310173109,27.682207374049746,27.09746164636838,26.512715918687007,25.92797019100564,25.343224463324276,24.758478735642935,24.173733007961566,23.588987280280197,23.00424155259883,22.419495824917462,21.83475009723612,21.250004369554752,20.665258641873386,20.080512914192017,19.495767186510676,18.911021458829307,18.32627573114794,17.741530003466572,17.156784275785206,16.78421149233045,16.623811653102052,16.4634118138737,16.303011974645358,16.14714099143138,15.996783402434781,15.846425813438222,15.696068224441657,15.545710635445046,15.395353046448497,15.24499545745193,15.09463786845536,14.94428027945876,14.793922690462242,14.647671671891743,14.506474890527347,14.365278109162949,14.224081327798539,14.082884546434142,13.941687765069743,13.800490983705334,13.659294202340892,13.51809742097654,13.378818149685104,13.245997859193753,13.113177568702376,12.980357278211033,12.84753698771968,12.714716697228335,12.581896406736956,12.449076116245605,12.316255825754252,12.188944888652454,12.06394652090141,11.938948153150367,11.813949785399334,11.6889514176483,11.563953049897258,11.43895468214619,11.313956314395156,11.196238871951849,11.080354387854014,10.964469903756154,10.848585419658257,10.732700935560388,10.616816451462535,10.500931967364668,10.38947496962463,10.283485649855052,10.177496330085448,10.071507010315841,9.965517690546264,9.859528370776687,9.753539051007103,9.651707387494893,9.552720436879644,9.45373348626436,9.35474653564912,9.255759585033868,9.156772634418589,9.058761498577537,8.964939865003236,8.87111823142894,8.777296597854631,8.683474964280332,8.589653330706033,8.497082449430778,8.409835280907934,8.322588112385123,8.235340943862262,8.148093775339419,8.060846606816582,7.977485164983147,7.897173281116379,7.816861397249637,7.736549513382894,7.656237629516147,7.577562687965417,7.503403451731101,7.429244215496779,7.355084979262442,7.280925743028127,7.208282601823717,7.139569177479256,7.070855753134829,7.002142328790374,6.933428904445942,6.856867651423261,6.7744205268919115,6.691973402360546,6.609526277829191,6.527079153297846,6.444632028766484,6.362184904235125,6.279737779703769,6.197290655172418,6.1148435306410605,6.032396406109703,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[65.17914451940177,65.21035577447755,65.24156702955331,65.27277828462908,65.30398953970486,65.33520079478063,65.3664120498564,65.39762330493217,65.42883456000794,65.46004581508372,65.49125707015949,65.52246832523525,65.55367958031101,65.5848908353868,65.61610209046256,65.64731334553834,65.6785246006141,65.70973585568987,65.74029917803887,65.76956663116923,65.79883408429961,65.82810153742996,65.85736899056033,65.8866364436907,65.91590389682106,65.94517134995144,65.9744388030818,66.00370625621217,66.03297370934254,66.0622411624729,66.09150861560327,66.12077606873363,66.150043521864,66.17931097499437,66.20857842812472,66.23784588125511,66.26711333438547,66.29638078751584,66.32564824064622,66.35491569377658,66.38418314690695,66.4134506000373,66.44271805316768,66.47198550629804,66.50125295942841,66.53052041255877,66.55978786568915,66.58905531881952,66.61832277194988,66.64759022508025,66.67685767821061,66.70612513134098,66.73539258447136,66.76466003760171,66.79392749073209,66.82319494386246,66.85246239699282,66.88172985012318,66.91099730325355,66.94026475638393,66.96953220951428,66.99879966264466,67.02806711577503,67.05733456890539,67.08660202203576,67.11586947516612,67.1451369282965,67.17440438142685,67.20367183455723,67.2329392876876,67.26220674081796,67.29147419394833,67.32074164707869,67.35000910020906,67.37927655333942,67.4085440064698,67.43781145960017,67.46707891273053,67.4963463658609,67.52561381899127,67.55488127212165,67.584148725252,67.61341617838237,67.64268363151274,67.6127053232281,67.57087786266047,67.52905040209284,67.4872229415252,67.44539548095757,67.40356802038994,67.36174055982232,67.31991309925468,67.27808563868705,67.23625817811941,67.19443071755178,67.15260325698415,67.11077579641652,67.06894833584889,67.02712087528126,66.98529341471362,66.94346595414599,66.90163849357836,66.85981103301073,66.8179835724431,66.77615611187545,66.73432865130783,66.6925011907402,66.65067373017257,66.60884626960494,66.56701880903731,66.52519134846968,66.48336388790204,66.4415364273344,66.39970896676677,66.35788150619913,66.31605404563152,66.27422658506389,66.23239912449625,66.19057166392862,66.14874420336098,66.10691674279336,66.06508928222571,66.02326182165808,65.98143436109046,65.93960690052282,65.8977794399552,65.85595197938756,65.81412451881994,65.77229705825229,65.73046959768467,65.68864213711704,65.64681467654941,65.60498721598177,65.56315975541413,65.52133229484652,65.47950483427888,65.43767737371124,65.39584991314362,65.35402245257598,65.31219499200836,65.27036753144073,65.2285400708731,65.18671261030546,65.14488514973783,65.1030576891702,65.06123022860257,65.01940276803492,64.97757530746729,64.93574784689966,64.9002615277639,64.87745745464434,64.85465338152477,64.8318493084052,64.80904523528564,64.78624116216606,64.7634370890465,64.74063301592693,64.71782894280737,64.69502486968781,64.67222079656824,64.64941672344867,64.62661265032911,64.60380857720955,64.58100450408999,64.55820043097042,64.53539635785086,64.51259228473128,64.12178861234676,63.54698514032979,62.97218166831281,62.397378196295804,61.82257472427885,61.247771252261835,60.672967780244875,60.09816430822789,59.5233608362109,58.94855736419393,58.373753892176914,57.79895042015996,57.22414694814297,56.64934347612598,56.07454000410901,55.49973653209203,54.924933060075034,54.35012958805805,53.77532611604106,53.20052264402409,52.6257191720071,52.050915699990114,51.47611222797316,50.90130875595614,50.326505283939184,49.75170181192219,49.17689833990521,48.602094867888226,48.027291395871224,47.45248792385425,46.87768445183727,46.30288097982027,45.72807750780332,45.153274035786325,44.57847056376934,44.00366709175235,43.42886361973536,42.8540601477184,42.27925667570141,41.70445320368442,41.129649731667456,40.554846259650475,39.98004278763347,39.4052393156165,38.830435843599496,38.255632371582514,37.680828899565554,37.10602542754856,36.53122195553157,35.95641848351458,35.38161501149759,34.806811539480634,34.232008067463646,33.65720459544666,33.08240112342966,32.5075976514127,31.932794179395714,31.35799070737872,30.78318723536174,30.20838376334474,29.63358029132778,29.058776819310797,28.483973347293805,27.909169875276817,27.334366403259857,26.759562931242865,26.18475945922588,25.609955987208885,25.0351525151919,24.46034904317494,23.885545571157945,23.31074209914096,22.726706522624024,22.14196079494266,21.557215067261318,20.97246933957995,20.387723611898586,19.802977884217214,19.218232156535873,18.633486428854507,18.048740701173134,17.463994973491772,16.879249245810403,16.50667646235565,16.346276623127252,16.19522985814235,16.044872269145753,15.894514680149221,15.744157091152623,15.593799502156063,15.443441913159496,15.293084324162887,15.142726735166338,14.99236914616977,14.8420115571732,14.699235327719636,14.55803854635524,14.416841764990796,14.275644983626398,14.134448202261998,13.99325142089759,13.852054639533193,13.710857858168794,13.569661076804385,13.43277869296272,13.299958402471388,13.16713811198003,13.034317821488681,12.901497530997302,12.76867724050596,12.635856950014608,12.503036659523262,12.370216369031883,12.244469816469186,12.11947144871814,11.994473080967083,11.869474713216041,11.744476345464996,11.619477977713963,11.494479609962928,11.369481242211885,11.252858484133101,11.136974000035211,11.021089515937343,10.90520503183951,10.789320547741648,10.67343606364375,10.557551579545882,10.446547999043599,10.340558679274015,10.23456935950443,10.128580039734853,10.022590719965248,9.91660140019564,9.810612080426065,9.708616298882504,9.609629348267218,9.510642397651958,9.411655447036711,9.312668496421425,9.213681545806187,9.11521502936165,9.02139339578733,8.927571762213002,8.833750128638702,8.739928495064405,8.646106861490097,8.552557828101632,8.465310659578774,8.378063491055912,8.29081632253307,8.20356915401026,8.116321985487396,8.03153413758817,7.951222253721427,7.870910369854684,7.790598485987918,7.710286602121176,7.630017052347414,7.555857816113075,7.481698579878762,7.407539343644444,7.3333801074101235,7.259220871175786,7.1903376446433205,7.121624220298878,7.052910795954418,6.984197371609991,6.91254101151122,6.830093886979858,6.747646762448508,6.665199637917158,6.582752513385793,6.5003053888544375,6.417858264323092,6.335411139791731,6.252964015260373,6.170516890729015,6.088069766197666,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[65.06789734658331,65.09910860165908,65.12870002409517,65.15796747722554,65.18723493035591,65.21650238348627,65.24576983661665,65.275037289747,65.30430474287738,65.33357219600774,65.36283964913811,65.39210710226848,65.42137455539884,65.45064200852921,65.47990946165957,65.50917691478995,65.5384443679203,65.56771182105068,65.59697927418105,65.62624672731141,65.65551418044178,65.68478163357216,65.71404908670252,65.74331653983289,65.77258399296325,65.80185144609362,65.83111889922398,65.86038635235435,65.88965380548473,65.91892125861509,65.94818871174546,65.97745616487582,66.00672361800619,66.03599107113655,66.06525852426694,66.0945259773973,66.12379343052766,66.15306088365803,66.1823283367884,66.21159578991876,66.24086324304912,66.27013069617948,66.29939814930987,66.32866560244022,66.3579330555706,66.38720050870096,66.41646796183133,66.44573541496169,66.47500286809206,66.50427032122244,66.5335377743528,66.56280522748317,66.59207268061354,66.6213401337439,66.65060758687426,66.67987504000463,66.709142493135,66.73840994626536,66.76767739939574,66.7969448525261,66.82621230565647,66.85547975878683,66.8847472119172,66.91401466504757,66.94328211817793,66.9725495713083,67.00181702443868,67.03108447756904,67.0603519306994,67.08961938382977,67.11888683696014,67.1481542900905,67.17742174322088,67.20668919635125,67.23595664948161,67.26522410261198,67.29449155574234,67.32375900887271,67.35302646200309,67.38229391513345,67.4115613682638,67.44082882139418,67.47009627452455,67.49936372765491,67.46938541937027,67.42755795880264,67.385730498235,67.34390303766737,67.30207557709976,67.26024811653213,67.2184206559645,67.17659319539686,67.13476573482923,67.0929382742616,67.05111081369397,67.00928335312634,66.96745589255869,66.92562843199107,66.88380097142344,66.84197351085581,66.80014605028818,66.75831858972055,66.71649112915291,66.67466366858527,66.63283620801765,66.59100874745002,66.54918128688237,66.50735382631476,66.46552636574712,66.42369890517949,66.38187144461185,66.34004398404421,66.29821652347658,66.25638906290897,66.21456160234132,66.17273414177369,66.13090668120606,66.08907922063844,66.0472517600708,66.00542429950318,65.96359683893553,65.9217693783679,65.87994191780027,65.83811445723265,65.796286996665,65.75445953609739,65.71263207552974,65.67080461496212,65.62897715439448,65.58714969382685,65.54532223325921,65.5034947726916,65.46166731212395,65.41983985155632,65.37801239098869,65.33618493042107,65.29435746985342,65.25253000928579,65.21070254871816,65.16887508815053,65.1270476275829,65.08522016701527,65.04339270644763,65.00156524588,64.95973778531237,64.91791032474474,64.8760828641771,64.83425540360948,64.79242794304184,64.75060048247421,64.70877302190658,64.66694556133895,64.62511810077132,64.58329064020369,64.54146317963605,64.49963571906842,64.45780825850079,64.41598079793316,64.37415333736553,64.33232587679788,64.29049841623026,64.24867095566263,64.206843495095,64.16501603452737,64.12318857395974,64.0813611133921,64.05538649835225,63.664582825967706,63.08977935395075,62.51497588193376,61.94017240991677,61.36536893789981,60.79056546588279,60.21576199386583,59.640958521848844,59.06615504983185,58.49135157781489,57.91654810579788,57.341744633780905,56.766941161763924,56.192407212531656,55.618681893205334,55.044956573879,54.47123125455267,53.897505935226334,53.32378061589999,52.75005529657367,52.17632997724735,51.602604657921,51.028879338594685,50.45515401926833,49.88142869994202,49.30770338061567,48.73397806128934,48.16025274196302,47.586527422636664,47.01280210331035,46.43907678398402,45.86535146465768,45.291626145331364,44.71790082600503,44.14417550667869,43.57045018735235,42.99672486802601,42.42299954869971,41.849274229373364,41.27554891004702,40.70182359072072,40.12809827139438,39.554372952068036,38.9806476327417,38.406922313415365,37.83319699408902,37.259471674762715,36.68574635543637,36.112021036110036,35.5382957167837,34.964570397457365,34.39084507813105,33.817119758804715,33.24339443947838,32.66966912015204,32.09594380082572,31.522218481499387,30.94849316217305,30.374767842846715,29.801042523520373,29.227317204194062,28.653591884867723,28.079866565541387,27.50614124621505,26.932415926888737,26.3586906075624,25.784965288236066,25.211239968909723,24.637514649583384,24.063789330257077,23.490064010930737,22.916338691604395,22.34261337227806,21.768888052951723,21.19516273362541,20.621437414299074,20.047712094972734,19.4739867756464,18.900261456320084,18.32653613699375,17.75281081766741,17.179085498341074,16.605360179014735,16.243318724853296,16.09296113585673,15.942603546860171,15.792245957863573,15.641888368867043,15.491530779870445,15.341173190873883,15.19081560187732,15.040458012880707,14.891995764911918,14.750798983547474,14.609602202183066,14.468405420818668,14.32720863945427,14.186011858089824,14.044815076725428,13.90361829536103,13.762421513996621,13.621224732632223,13.486739236240371,13.35391894574902,13.221098655257633,13.0882783647663,12.955458074274942,12.822637783783591,12.689817493292212,12.55699720280087,12.424993112036908,12.299994744285874,12.17499637653484,12.049998008783797,11.924999641032755,11.800001273281698,11.675002905530654,11.55000453777961,11.425362580412173,11.309478096314312,11.193593612216443,11.077709128118583,10.961824644020693,10.845940159922824,10.73005567582499,10.614171191727129,10.503621028462538,10.397631708692954,10.291642388923385,10.185653069153801,10.079663749384215,9.97367442961464,9.867685109845034,9.765525210270065,9.66653825965481,9.567551309039555,9.46856435842427,9.369577407809011,9.270590457193764,9.171668560145712,9.077846926571405,8.984025292997107,8.890203659422786,8.796382025848459,8.702560392274158,8.60873875869986,8.520786038249572,8.433538869726755,8.3462917012039,8.259044532681038,8.171797364158195,8.085583110193197,8.005271226326446,7.924959342459699,7.8446474585929575,7.764335574726214,7.684023690859447,7.608312180495051,7.53415294426075,7.459993708026413,7.385834471792098,7.3116752355577805,7.241106111807376,7.172392687462915,7.103679263118474,7.034965838774033,6.966252414429571,6.885767247067801,6.8033201225364515,6.72087299800509,6.638425873473739,6.5559787489423895,6.473531624411024,6.391084499879669,6.308637375348324,6.226190250816962,6.143743126285604,6.061296001754247,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[64.94830923236229,64.97543081336667,65.00255239437105,65.02967397537543,65.05679555637983,65.0839171373842,65.11103871838857,65.13816029939295,65.16528188039734,65.19240346140172,65.2195250424061,65.24664662341048,65.27376820441486,65.30088978541926,65.32801136642364,65.35513294742802,65.38368511215887,65.41295256528922,65.4422200184196,65.47148747154996,65.50075492468034,65.53002237781071,65.55928983094105,65.58855728407144,65.6178247372018,65.64709219033217,65.67635964346255,65.7056270965929,65.73489454972326,65.76416200285364,65.79342945598401,65.82269690911437,65.85196436224473,65.88123181537512,65.91049926850548,65.93976672163583,65.96903417476621,65.99830162789658,66.02756908102694,66.05683653415731,66.08610398728769,66.11537144041804,66.1446388935484,66.17390634667879,66.20317379980915,66.23244125293951,66.26170870606988,66.29097615920024,66.32024361233061,66.34951106546099,66.37877851859135,66.40804597172172,66.43731342485208,66.46658087798244,66.49584833111282,66.52511578424318,66.55438323737356,66.58365069050393,66.61291814363429,66.64218559676465,66.67145304989502,66.7007205030254,66.72998795615575,66.75925540928613,66.78852286241649,66.81779031554686,66.84705776867722,66.87632522180759,66.90559267493796,66.93486012806832,66.9641275811987,66.99339503432905,67.02266248745943,67.05192994058979,67.08119739372016,67.11046484685053,67.13973229998089,67.16899975311127,67.19826720624162,67.227534659372,67.25680211250237,67.28606956563273,67.31533701876309,67.34460447189348,67.31462616360885,67.27279870304122,67.23097124247356,67.18914378190594,67.14731632133831,67.10548886077068,67.06366140020305,67.02183393963541,66.98000647906778,66.93817901850015,66.89635155793252,66.85452409736489,66.81269663679726,66.77086917622962,66.72904171566199,66.68721425509436,66.64538679452673,66.6035593339591,66.56173187339147,66.51990441282383,66.4780769522562,66.43624949168857,66.39442203112094,66.35259457055331,66.31076710998568,66.26893964941803,66.22711218885041,66.18528472828277,66.14345726771515,66.10162980714752,66.05980234657989,66.01797488601225,65.97614742544461,65.93431996487699,65.89249250430936,65.85066504374173,65.80883758317408,65.76701012260645,65.72518266203883,65.6833552014712,65.64152774090356,65.59970028033592,65.5578728197683,65.51604535920066,65.47421789863304,65.4323904380654,65.39056297749778,65.34873551693013,65.3069080563625,65.26508059579487,65.22325313522725,65.18142567465962,65.13959821409198,65.09777075352434,65.05594329295671,65.01411583238908,64.97228837182146,64.93046091125382,64.88863345068619,64.84680599011855,64.80497852955094,64.7631510689833,64.72132360841566,64.67949614784803,64.6376686872804,64.59584122671276,64.55401376614513,64.5121863055775,64.4459387919978,64.37969125213999,64.31344371228217,64.24719617242435,64.18094863256654,64.11470109270871,64.04845355285089,63.982206012993075,63.915958473135255,63.849710933277436,63.783463393419616,63.7172158535618,63.65096831370398,63.58472077384616,63.518473233988345,63.12331227953881,62.563694617793466,62.0040769560481,61.44445929430274,60.884841632557404,60.32522397081201,59.76560630906667,59.20598864732131,58.646370985575935,58.0867533238306,57.527135662085215,56.96751800033987,56.40790033859451,55.848282676849145,55.2886650151038,54.72904735335844,54.16942969161307,53.60981202986771,53.05019436812235,52.490576706377006,51.92370366596516,51.34997834663882,50.776253027312514,50.20252770798616,49.628802388659835,49.05507706933349,48.481351750007164,47.90762643068085,47.33390111135448,46.76017579202818,46.186450472701836,45.61272515337551,45.038999834049186,44.46527451472285,43.8915491953965,43.31782387607017,42.74409855674382,42.17037323741752,41.596647918091186,41.02292259876485,40.449197279438536,39.8754719601122,39.30174664078586,38.72802132145952,38.15429600213318,37.580570682806844,37.00684536348054,36.433120044154194,35.85939472482786,35.285669405501515,34.71194408617518,34.13821876684887,33.56449344752253,32.990768128196194,32.41704280886986,31.843317489543544,31.269592170217205,30.69586685089087,30.122141531564534,29.548416212238195,28.974690892911884,28.400965573585545,27.82724025425921,27.253514934932873,26.67978961560656,26.106064296280223,25.532338976953884,24.95861365762754,24.384888338301202,23.811163018974895,23.23743769964856,22.663712380322217,22.08998706099588,21.516261741669542,20.942536422343228,20.36881110301689,19.795085783690553,19.221360464364217,18.647635145037903,18.073909825711567,17.50018450638523,16.926459187058892,16.352733867732557,15.990692413571123,15.840334824574551,15.689977235577995,15.539619646581395,15.389262057584865,15.238904468588267,15.088546879591707,14.943559420739748,14.802362639375303,14.661165858010952,14.519969076646507,14.378772295282097,14.2375755139177,14.096378732553303,13.955181951188855,13.813985169824461,13.673520070009323,13.540699779517972,13.407879489026627,13.275059198535283,13.14223890804393,13.009418617552543,12.87659832706121,12.743778036569854,12.610957746078503,12.480518039853635,12.355519672102602,12.230521304351527,12.10552293660049,11.980524568849455,11.855526201098415,11.73052783334737,11.605529465596314,11.481982192593412,11.366097708495513,11.250213224397653,11.134328740299793,11.018444256201924,10.902559772104063,10.786675288006174,10.670790803908304,10.560694057881488,10.454704738111912,10.348715418342326,10.242726098572742,10.136736778803174,10.030747459033588,9.924758139264004,9.822434121657638,9.72344717104238,9.624460220427121,9.525473269811867,9.426486319196611,9.327499368581327,9.228512417966066,9.134300457355472,9.040478823781168,8.946657190206862,8.852835556632561,8.759013923058241,8.665192289483914,8.576261416920397,8.489014248397561,8.401767079874698,8.314519911351882,8.227272742829026,8.140025574306165,8.059320198931482,7.979008315064727,7.898696431197978,7.81838454733123,7.738072663464488,7.660766544877024,7.586607308642718,7.512448072408387,7.438288836174086,7.36412959993975,7.291874578971419,7.223161154626977,7.154447730282532,7.085734305938071,7.017020881593629,6.941440607155748,6.858993482624383,6.776546358093032,6.6940992335616825,6.61165210903032,6.529204984498971,6.4467578599676205,6.364310735436256,6.281863610904901,6.199416486373556,6.116969361842193,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[64.82808648057576,64.85520806158014,64.88232964258451,64.90945122358889,64.93657280459328,64.96369438559766,64.99081596660204,65.01793754760642,65.04505912861082,65.0721807096152,65.09930229061958,65.12642387162396,65.15354545262832,65.18066703363272,65.20778861463711,65.23491019564148,65.26203177664586,65.28915335765025,65.31627493865463,65.34339651965901,65.37051810066339,65.39763968166778,65.42476126267215,65.45188284367654,65.47900442468091,65.5061260056853,65.53324758668968,65.56036916769406,65.58749074869846,65.61461232970282,65.64173391070722,65.6688554917116,65.69633472002538,65.72560217315575,65.75486962628612,65.78413707941648,65.81340453254685,65.84267198567721,65.87193943880759,65.90120689193795,65.93047434506832,65.95974179819869,65.98900925132904,66.01827670445942,66.0475441575898,66.07681161072016,66.10607906385053,66.13534651698089,66.16461397011125,66.19388142324163,66.223148876372,66.25241632950235,66.28168378263273,66.3109512357631,66.34021868889346,66.36948614202382,66.3987535951542,66.42802104828456,66.45728850141492,66.4865559545453,66.51582340767567,66.54509086080603,66.57435831393639,66.60362576706676,66.63289322019713,66.66216067332749,66.69142812645786,66.72069557958824,66.7499630327186,66.77923048584897,66.80849793897933,66.83776539210969,66.86703284524008,66.89630029837043,66.92556775150081,66.95483520463117,66.98410265776154,67.01337011089191,67.04263756402227,67.07190501715264,67.101172470283,67.13043992341338,67.15970737654374,67.18897482967411,67.15899652138948,67.11716906082185,67.0753416002542,67.03351413968657,66.99168667911896,66.94985921855132,66.9080317579837,66.86620429741606,66.82437683684843,66.7825493762808,66.74072191571315,66.69889445514552,66.6570669945779,66.61523953401027,66.57341207344263,66.531584612875,66.48975715230738,66.44792969173974,66.4061022311721,66.36427477060447,66.32244731003684,66.28061984946922,66.23879238890157,66.19696492833395,66.15513746776631,66.11331000719868,66.07148254663106,66.02965508606341,65.98782762549578,65.94600016492815,65.90417270436052,65.86234524379289,65.82051778322526,65.77869032265762,65.73686286208999,65.69503540152236,65.65320794095473,65.6113804803871,65.56955301981947,65.52772555925183,65.4858980986842,65.44407063811657,65.40224317754894,65.36041571698131,65.31858825641368,65.27676079584604,65.23493333527841,65.19310587471078,65.15127841414315,65.10945095357552,65.06762349300789,65.013586015044,64.94733847518619,64.88109093532836,64.81484339547055,64.74859585561272,64.68234831575491,64.61610077589708,64.54985323603927,64.48360569618144,64.41735815632362,64.3511106164658,64.28486307660799,64.21861553675016,64.15236799689235,64.08612045703453,64.01987291717671,63.9536253773189,63.88737783746107,63.82113029760325,63.75488275774543,63.68863521788761,63.622387678029796,63.55614013817197,63.48989259831416,63.42364505845633,63.35739751859852,63.2911499787407,63.22490243888288,63.15865489902505,63.09240735916724,63.02615981930942,62.9599122794516,62.564751325002064,62.00513366325673,61.445516001511365,60.885898339766,60.326280678020666,59.76666301627527,59.20704535452993,58.64742769278456,58.0878100310392,57.52819236929386,56.96857470754847,56.408957045803135,55.84933938405777,55.2897217223124,54.73010406056706,54.170486398821694,53.61086873707633,53.05125107533097,52.4916334135856,51.93201575184027,51.3723980900949,50.812780428349534,50.25316276660419,49.693545104858806,49.13392744311347,48.5743097813681,48.01469211962274,47.4550744578774,46.895456796132,46.33583913438667,45.77622147264131,45.21660381089594,44.656986149150605,44.097368487405234,43.53775082565987,42.97813316391451,42.418515502169136,41.8588978404238,41.29928017867844,40.73966251693307,40.18004485518774,39.62042719344237,39.0491203295037,38.47539501017736,37.90166969085103,37.32794437152469,36.75421905219837,36.18049373287203,35.606768413545694,35.03304309421936,34.45931777489302,33.88559245556671,33.31186713624037,32.73814181691404,32.164416497587695,31.590691178261384,31.016965858935045,30.443240539608713,29.869515220282377,29.295789900956038,28.722064581629724,28.148339262303388,27.574613942977052,27.00088862365071,26.427163304324395,25.85343798499806,25.279712665671727,24.70598734634538,24.132262027019046,23.55853670769274,22.984811388366403,22.41108606904006,21.83736074971372,21.26363543038738,20.689910111061067,20.11618479173473,19.542459472408396,18.968734153082057,18.395008833755746,17.82128351442941,17.24755819510307,16.673832875776732,16.100107556450396,15.738066102288963,15.587708513292394,15.437350924295835,15.286993335299236,15.136635746302707,14.995123076567598,14.853926295203204,14.712729513838795,14.571532732474349,14.430335951109997,14.289139169745555,14.147942388381145,14.006745607016747,13.865548825652349,13.727480613286934,13.594660322795592,13.461840032304249,13.329019741812894,13.19619945132155,13.063379160830207,12.930558870338855,12.797738579847467,12.664918289356132,12.53604296767034,12.411044599919297,12.286046232168262,12.16104786441723,12.036049496666154,11.911051128915119,11.786052761164084,11.661054393413043,11.538601804774624,11.422717320676771,11.306832836578902,11.190948352481005,11.075063868383145,10.959179384285283,10.843294900187416,10.727410416089556,10.617767087300473,10.511777767530862,10.405788447761285,10.29979912799171,10.193809808222124,10.08782048845254,9.981831168682971,9.879343033045217,9.780356082429956,9.6813691318147,9.582382181199446,9.483395230584184,9.38440827996893,9.285421329353676,9.190753988139537,9.096932354565231,9.003110720990938,8.909289087416632,8.815467453842327,8.721645820268028,8.63173679559121,8.54448962706837,8.457242458545531,8.369995290022695,8.282748121499832,8.195500952977016,8.113369171536515,8.033057287669767,7.952745403803019,7.872433519936264,7.792121636069515,7.713220909259016,7.6390616730247,7.564902436790368,7.490743200556063,7.416583964321731,7.342643046135468,7.273929621791007,7.20521619744658,7.136502773102137,7.067789348757692,6.997113967243685,6.914666842712335,6.832219718180985,6.749772593649619,6.6673254691182695,6.584878344586919,6.502431220055557,6.419984095524207,6.337536970992858,6.255089846461492,6.172642721930137,6.090195597398791,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[64.70786372878922,64.7349853097936,64.76210689079798,64.78922847180236,64.81635005280674,64.84347163381112,64.8705932148155,64.89771479581988,64.92483637682427,64.95195795782865,64.97907953883303,65.00620111983741,65.0333227008418,65.06044428184617,65.08756586285057,65.11468744385495,65.14180902485933,65.16893060586371,65.19605218686809,65.22317376787247,65.25029534887685,65.27741692988124,65.3045385108856,65.33166009189,65.35878167289437,65.38590325389876,65.41302483490315,65.44014641590752,65.46726799691191,65.4943895779163,65.52151115892067,65.54863273992505,65.57575432092943,65.60287590193383,65.6299974829382,65.65711906394257,65.68424064494697,65.71136222595135,65.73848380695573,65.76560538796011,65.79272696896449,65.81984854996888,65.84697013097326,65.87409171197764,65.90121329298202,65.9283348739864,65.95545645499078,65.98257803599516,66.00969961699954,66.03825178102227,66.06751923415263,66.09678668728299,66.12605414041336,66.15532159354373,66.18458904667409,66.21385649980446,66.24312395293484,66.2723914060652,66.30165885919556,66.33092631232593,66.3601937654563,66.38946121858666,66.41872867171703,66.4479961248474,66.47726357797777,66.50653103110812,66.5357984842385,66.56506593736887,66.59433339049923,66.6236008436296,66.65286829675996,66.68213574989034,66.71140320302071,66.74067065615107,66.76993810928144,66.7992055624118,66.82847301554217,66.85774046867253,66.8870079218029,66.91627537493328,66.94554282806365,66.97481028119401,67.00407773432437,67.03334518745474,67.0033668791701,66.96153941860247,66.91971195803485,66.8778844974672,66.83605703689959,66.79422957633196,66.75240211576433,66.71057465519668,66.66874719462906,66.62691973406142,66.5850922734938,66.54326481292615,66.50143735235852,66.45960989179089,66.41778243122326,66.37595497065564,66.334127510088,66.29230004952036,66.25047258895273,66.2086451283851,66.16681766781747,66.12499020724984,66.0831627466822,66.04133528611457,65.99950782554694,65.95768036497931,65.91585290441168,65.87402544384405,65.83219798327642,65.79037052270878,65.74854306214115,65.70671560157352,65.66488814100589,65.62306068043826,65.58123321987063,65.51498569823231,65.4487381583745,65.38249061851668,65.31624307865887,65.24999553880104,65.18374799894322,65.1175004590854,65.05125291922758,64.98500537936977,64.91875783951195,64.85251029965413,64.78626275979632,64.72001521993849,64.65376768008068,64.58752014022285,64.52127260036504,64.45502506050721,64.3887775206494,64.32252998079157,64.25628244093376,64.19003490107593,64.12378736121812,64.0575398213603,63.99129228150248,63.925044741644655,63.858797201786835,63.792549661929016,63.7263021220712,63.660054582213384,63.593807042355564,63.52755950249774,63.461311962639925,63.395064422782106,63.328816882924286,63.26256934306647,63.19632180320864,63.13007426335082,63.06382672349301,62.99757918363518,62.93133164377737,62.86508410391956,62.79883656406173,62.732589024203904,62.66634148434609,62.60009394448827,62.53384640463045,62.46759886477264,62.40135132491481,62.006190370465276,61.44657270871994,60.88695504697458,60.32733738522922,59.76771972348388,59.20810206173849,58.64848439999315,58.08886673824777,57.52924907650241,56.969631414757075,56.41001375301168,55.85039609126635,55.290778429520984,54.73116076777562,54.17154310603027,53.611925444284914,53.05230778253955,52.49269012079418,51.933072459048816,51.37345479730348,50.81383713555812,50.25421947381275,49.69460181206742,49.134984150322026,48.57536648857668,48.01574882683131,47.45613116508595,46.896513503340614,46.33689584159522,45.77727817984989,45.21766051810452,44.65804285635915,44.09842519461382,43.538807532868454,42.97918987112308,42.41957220937772,41.859954547632356,41.30033688588702,40.74071922414165,40.18110156239629,39.62148390065095,39.06186623890558,38.502248577160216,37.94263091541485,37.38301325366949,36.823395591924125,36.26377793017879,35.70416026843342,35.14454260668806,34.58492494494269,34.02530728319733,33.465689621451986,32.90607195970662,32.34645429796126,31.786836636215895,31.227218974470553,30.66760131272519,30.10798365097983,29.54836598923446,28.9887483274891,28.429130665743756,27.869513003998392,27.30989534225303,26.74826231236853,26.174536993042217,25.600811673715885,25.027086354389546,24.453361035063203,23.879635715736867,23.305910396410553,22.73218507708422,22.158459757757882,21.584734438431543,21.011009119105204,20.43728379977889,19.863558480452554,19.289833161126218,18.71610784179988,18.14238252247356,17.56865720314723,16.994931883820893,16.421206564494554,15.847481245168217,15.485439791006781,15.335082202010211,15.187883513759871,15.046686732395472,14.905489951031027,14.76429316966663,14.623096388302232,14.481899606937823,14.34070282557338,14.199506044209029,14.058309262844585,13.917112481480176,13.781441156564542,13.648620866073234,13.515800575581846,13.382980285090502,13.250159994599159,13.117339704107804,12.984519413616463,12.851699123125117,12.718878832633767,12.59156789548706,12.466569527735999,12.341571159984957,12.216572792233915,12.091574424482879,11.966576056731846,11.84157768898077,11.716579321229736,11.595221416955871,11.479336932857972,11.363452448760105,11.247567964662252,11.131683480564384,11.015798996466486,10.899914512368625,10.784030028270765,10.674840116719412,10.568850796949837,10.462861477180258,10.356872157410649,10.25088283764107,10.144893517871495,10.03890419810191,9.9362519444328,9.837264993817556,9.738278043202268,9.639291092587008,9.540304141971754,9.441317191356497,9.342330240741237,9.247207518923597,9.153385885349296,9.059564251774992,8.965742618200684,8.87192098462639,8.778099351052084,8.687212174262028,8.599965005739191,8.512717837216336,8.425470668693492,8.338223500170656,8.25097633164782,8.167418144141548,8.087106260274787,8.006794376408045,7.926482492541297,7.846170608674548,7.765858724807794,7.6915160374066724,7.617356801172351,7.543197564938034,7.469038328703703,7.394879092469398,7.324698088955078,7.255984664610621,7.18727124026616,7.118557815921734,7.049844391577292,6.970340202800282,6.887893078268916,6.805445953737566,6.722998829206216,6.64055170467485,6.5581045801435,6.47565745561215,6.393210331080788,6.310763206549439,6.228316082018089,6.145868957486723,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[64.58764097700268,64.61476255800706,64.64188413901144,64.66900572001582,64.6961273010202,64.72324888202458,64.75037046302896,64.77749204403334,64.80461362503773,64.83173520604211,64.85885678704649,64.88597836805087,64.91309994905525,64.94022153005963,64.96734311106403,64.9944646920684,65.02158627307278,65.04870785407716,65.07582943508156,65.10295101608594,65.13007259709032,65.1571941780947,65.18431575909908,65.21143734010346,65.23855892110782,65.26568050211222,65.29280208311661,65.31992366412098,65.34704524512537,65.37416682612975,65.40128840713413,65.42840998813851,65.45553156914289,65.48265315014729,65.50977473115167,65.53689631215605,65.56401789316043,65.5911394741648,65.61826105516919,65.64538263617357,65.67250421717794,65.69962579818234,65.72674737918672,65.7538689601911,65.78099054119548,65.80811212219986,65.83523370320424,65.86235528420862,65.889476865213,65.91659844621738,65.94372002722177,65.97084160822615,65.99796318923053,66.02508477023491,66.05220635123929,66.07932793224367,66.10644951324805,66.13357109425243,66.16069267525681,66.1878142562612,66.21493583726559,66.24205741826997,66.26917899927435,66.29630058027874,66.32342216128312,66.35090138888876,66.38016884201913,66.4094362951495,66.43870374827986,66.46797120141024,66.4972386545406,66.52650610767097,66.55577356080133,66.5850410139317,66.61430846706207,66.64357592019243,66.6728433733228,66.70211082645316,66.73137827958354,66.7606457327139,66.78991318584428,66.81918063897464,66.848448092105,66.87771554523538,66.84773723695073,66.8059097763831,66.76408231581549,66.72225485524784,66.68042739468021,66.63859993411259,66.59677247354495,66.55494501297731,66.51311755240968,66.47129009184205,66.42946263127442,66.38763517070679,66.34580771013916,66.30398024957152,66.26215278900389,66.22032532843626,66.17849786786863,66.136670407301,66.08263292127846,66.01638538142065,65.95013784156284,65.88389030170501,65.81764276184718,65.75139522198937,65.68514768213154,65.61890014227373,65.55265260241592,65.48640506255809,65.42015752270026,65.35390998284245,65.28766244298464,65.22141490312681,65.15516736326899,65.08891982341117,65.02267228355336,64.95642474369554,64.89017720383771,64.8239296639799,64.75768212412208,64.69143458426426,64.62518704440643,64.55893950454862,64.4926919646908,64.42644442483298,64.36019688497515,64.29394934511734,64.22770180525953,64.1614542654017,64.09520672554389,64.02895918568606,63.96271164582825,63.89646410597042,63.83021656611261,63.76396902625479,63.69772148639697,63.631473946539145,63.56522640668133,63.498978866823514,63.432731326965694,63.366483787107875,63.300236247250055,63.233988707392236,63.167741167534416,63.101493627676604,63.03524608781878,62.96899854796096,62.90275100810314,62.836503468245326,62.7702559283875,62.70400838852967,62.63776084867185,62.57151330881404,62.50526576895622,62.439018229098394,62.37277068924058,62.30652314938277,62.24027560952494,62.17402806966712,62.107780529809304,62.04153298995149,61.975285450093665,61.909037910235845,61.84279037037803,61.447629415928496,60.88801175418316,60.32839409243779,59.76877643069243,59.2091587689471,58.6495411072017,58.08992344545636,57.530305783711,56.97068812196563,56.411070460220294,55.8514527984749,55.29183513672956,54.7322174749842,54.172599813238826,53.6129821514935,53.053364489748134,52.49374682800276,51.9341291662574,51.37451150451204,50.8148938427667,50.25527618102134,49.695658519275966,49.13604085753063,48.576423195785246,48.01680553403989,47.457187872294526,46.89757021054916,46.33795254880383,45.778334887058435,45.2187172253131,44.659099563567736,44.09948190182237,43.53986424007703,42.980246578331666,42.420628916586296,41.86101125484094,41.30139359309557,40.74177593135023,40.18215826960487,39.622540607859506,39.06292294611416,38.50330528436879,37.94368762262343,37.384069960878065,36.8244522991327,36.26483463738734,35.705216975642,35.14559931389664,34.585981652151276,34.0263639904059,33.46674632866055,32.9071286669152,32.347511005169835,31.78789334342447,31.22827568167911,30.668658019933773,30.10904035818841,29.549422696443045,28.989805034697675,28.430187372952314,27.870569711206972,27.31095204946161,26.75133438771624,26.191716725970878,25.632099064225542,25.07248140248017,24.512863740734815,23.953246078989444,23.393628417244088,22.834010755498742,22.27439309375338,21.71477543200801,21.15515777026265,20.595540108517287,20.03592244677194,19.476304785026585,18.916687144512487,18.361819208475154,17.806951272437843,17.252083336400517,16.697215400363184,16.142347464325855,15.58747952828852,15.23944716958771,15.098250388223303,14.957053606858903,14.815856825494505,14.67466004413006,14.533463262765663,14.392266481401267,14.251069700036858,14.109872918672414,13.968676137308062,13.835401699842185,13.702581409350833,13.569761118859454,13.436940828368144,13.304120537876758,13.171300247385414,13.03847995689407,12.905659666402716,12.772839375911374,12.647092823303758,12.522094455552715,12.397096087801671,12.272097720050613,12.147099352299572,12.022100984548528,11.897102616797492,11.772104249046459,11.651841029137072,11.535956545039213,11.420072060941353,11.304187576843454,11.188303092745585,11.072418608647732,10.956534124549865,10.840649640451968,10.731913146138362,10.625923826368785,10.519934506599203,10.413945186829624,10.307955867060048,10.201966547290436,10.095977227520859,9.993160855820403,9.894173905205117,9.795186954589857,9.696200003974608,9.597213053359322,9.498226102744063,9.399239152128809,9.30366104970768,9.20983941613335,9.11601778255905,9.02219614898475,8.928374515410447,8.83455288183614,8.74268755293284,8.655440384409996,8.568193215887153,8.480946047364318,8.393698878841462,8.306451710318619,8.22146711674655,8.14115523287981,8.060843349013078,7.980531465146319,7.900219581279576,7.819907697412827,7.743970401788641,7.6698111655543295,7.595651929320009,7.521492693085689,7.447333456851371,7.375466556119121,7.306753131774659,7.238039707430233,7.169326283085777,7.100612858741316,7.026013562888218,6.943566438356867,6.861119313825513,6.778672189294147,6.696225064762797,6.613777940231447,6.531330815700082,6.448883691168732,6.3664365666373826,6.28398944210602,6.20154231757467,6.11909519304332,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[64.46741822521615,64.49453980622053,64.52166138722491,64.54878296822929,64.57590454923367,64.60302613023805,64.63014771124243,64.65726929224681,64.6843908732512,64.71151245425558,64.73863403525996,64.76575561626434,64.79287719726872,64.81999877827312,64.8471203592775,64.87424194028188,64.90136352128626,64.92848510229064,64.95560668329502,64.98272826429941,65.00984984530378,65.03697142630817,65.06409300731254,65.09121458831693,65.11833616932131,65.14545775032569,65.17257933133007,65.19970091233445,65.22682249333884,65.25394407434321,65.2810656553476,65.30818723635198,65.33530881735636,65.36243039836074,65.38955197936512,65.41667356036952,65.4437951413739,65.47091672237826,65.49803830338266,65.52515988438704,65.55228146539142,65.57940304639581,65.60652462740018,65.63364620840457,65.66076778940894,65.68788937041333,65.71501095141771,65.74213253242209,65.76925411342647,65.79637569443085,65.82349727543524,65.85061885643961,65.877740437444,65.90486201844838,65.93198359945276,65.95910518045714,65.98622676146152,66.0133483424659,66.04046992347028,66.06759150447468,66.09471308547906,66.12183466648344,66.14895624748782,66.1760778284922,66.20319940949658,66.23032099050096,66.25744257150535,66.28456415250972,66.31168573351411,66.33880731451849,66.36592889552287,66.39305047652725,66.42017205753164,66.44729363853602,66.4744152195404,66.50153680054478,66.52865838154916,66.55577996255354,66.58290154355792,66.6100231245623,66.6371447055667,66.66426628657106,66.69281844988564,66.72208590301602,66.69210759473138,66.65028013416375,66.58403260446684,66.51778506460901,66.45153752475119,66.38528998489338,66.31904244503555,66.25279490517774,66.18654736531991,66.1202998254621,66.05405228560427,65.98780474574646,65.92155720588863,65.85530966603082,65.789062126173,65.72281458631518,65.65656704645735,65.59031950659954,65.52407196674172,65.4578244268839,65.39157688702608,65.32532934716826,65.25908180731044,65.19283426745262,65.1265867275948,65.06033918773699,64.99409164787917,64.92784410802135,64.86159656816353,64.79534902830571,64.7291014884479,64.66285394859007,64.59660640873224,64.53035886887443,64.46411132901662,64.39786378915879,64.33161624930096,64.26536870944315,64.19912116958534,64.13287362972753,64.0666260898697,64.00037855001189,63.93413101015406,63.86788347029624,63.80163593043842,63.73538839058061,63.66914085072278,63.602893310864964,63.536645771007144,63.47039823114932,63.404150691291505,63.337903151433686,63.271655611575866,63.205408071718054,63.13916053186023,63.07291299200241,63.00666545214459,62.940417912286776,62.87417037242895,62.80792283257113,62.74167529271331,62.6754277528555,62.60918021299767,62.54293267313986,62.47668513328205,62.41043759342422,62.3441900535664,62.27794251370858,62.211694973850754,62.14544743399294,62.079199894135115,62.012952354277296,61.94670481441948,61.880457274561664,61.81420973470384,61.74796219484602,61.681714654988205,61.615467115130386,61.54921957527256,61.48297203541475,61.41672449555693,61.35047695569911,61.28422941584129,60.88906846139176,60.329450799646416,59.76983313790105,59.21021547615569,58.65059781441035,58.090980152664955,57.53136249091962,56.97174482917425,56.41687688814969,55.86200895211239,55.30714101607503,54.752273080037725,54.197405144000385,53.64253720796306,53.08766927192576,52.53280133588842,51.97793339985109,51.42306546381376,50.868197527776424,50.31332959173912,49.75846165570179,49.20359371966446,48.64872578362716,48.093857847589796,47.538989911552484,46.98412197551516,46.42925403947783,45.87438610344052,45.31951816740316,44.764650231365856,44.20978229532852,43.65491435929119,43.100046423253886,42.54517848721656,41.99031055117923,41.43544261514189,40.88057467910456,40.32570674306726,39.770838807029925,39.21597087099259,38.66110293495529,38.106234998917955,37.55136706288062,36.9964991268433,36.441631190805964,35.886763254768624,35.33189531873132,34.777027382693994,34.22215944665666,33.667291510619336,33.112423574581996,32.55755563854469,32.00268770250736,31.44781976647003,30.8929518304327,30.338083894395393,29.783215958358063,29.22834802232073,28.673480086283398,28.11861215024607,27.563744214208764,27.008876278171435,26.454008342134102,25.89914040609677,25.34427247005946,24.789404534022133,24.2345365979848,23.67966866194747,23.124800725910134,22.56993278987283,22.015064853835504,21.460196917798168,20.90532898176084,20.350461045723506,19.7955931096862,19.240725173648865,18.685857237611536,18.130989301574203,17.576121365536896,17.021253429499566,16.466385493462237,15.911517557424904,15.356649621387572,15.008617262686757,14.867420481322348,14.72622369995795,14.585026918593552,14.443830137229108,14.302633355864709,14.161436574500312,14.02218253361119,13.8893622431198,13.756541952628499,13.623721662137113,13.49090137164576,13.358081081154381,13.225260790663071,13.092440500171685,12.95962020968034,12.827616118871497,12.702617751120453,12.57761938336942,12.452621015618385,12.327622647867344,12.2026242801163,12.077625912365242,11.9526275446142,11.827629176863157,11.708460641318297,11.592576157220437,11.476691673122566,11.360807189024706,11.244922704926847,11.12903822082895,11.013153736731079,10.897269252633226,10.788986175557346,10.682996855787762,10.577007536018161,10.471018216248583,10.365028896479,10.259039576709423,10.153050256939846,10.050069767207974,9.95108281659272,9.852095865977466,9.75310891536218,9.654121964746919,9.555135014131674,9.456148063516387,9.360114580491764,9.266292946917442,9.172471313343145,9.078649679768816,8.984828046194517,8.891006412620216,8.798162931603645,8.710915763080804,8.623668594557971,8.53642142603513,8.449174257512286,8.36192708898945,8.275516089351598,8.195204205484831,8.114892321618088,8.034580437751346,7.954268553884615,7.873956670017856,7.7964247661706425,7.722265529936322,7.648106293701985,7.573947057467673,7.499787821233352,7.426235023283164,7.357521598938707,7.288808174594282,7.220094750249819,7.151381325905393,7.081686922976172,6.9992397984448145,6.916792673913457,6.834345549382107,6.7518984248507525,6.669451300319388,6.587004175788037,6.504557051256687,6.422109926725322,6.339662802193971,6.2572156776626215,6.17476855313126,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[64.33355066132931,64.36067224233369,64.38779382333809,64.41491540434245,64.44203698534685,64.46915856635123,64.4962801473556,64.52340172835999,64.55052330936437,64.57764489036875,64.60476647137314,64.6318880523775,64.6590096333819,64.68613121438628,64.71325279539067,64.74037437639505,64.76749595739943,64.79461753840381,64.82173911940819,64.84886070041257,64.87598228141695,64.90310386242133,64.93022544342571,64.9573470244301,64.98446860543447,65.01159018643887,65.03871176744323,65.06583334844763,65.09295492945199,65.12007651045639,65.14719809146077,65.17431967246515,65.20144125346954,65.2285628344739,65.2556844154783,65.28280599648268,65.30992757748706,65.33704915849145,65.36417073949582,65.39129232050021,65.4184139015046,65.44553548250897,65.47265706351335,65.49977864451773,65.52690022552211,65.55402180652649,65.58114338753089,65.60826496853527,65.63538654953965,65.66250813054403,65.6896297115484,65.71675129255279,65.74387287355717,65.77099445456155,65.79811603556593,65.82523761657032,65.8523591975747,65.87948077857908,65.90660235958346,65.93372394058785,65.96084552159223,65.98796710259661,66.015088683601,66.04221026460537,66.06933184560975,66.09645342661413,66.12357500761851,66.15069658862289,66.17781816962729,66.20391332350883,66.22898204923662,66.25405077496443,66.27911950069223,66.30418822642004,66.32925695214784,66.35432567787564,66.37939440360344,66.40446312933125,66.42953185505905,66.45460058078686,66.47966930651467,66.50473803224246,66.52980675797026,66.55487548369808,66.4803124946238,66.38582316258913,66.29133383055445,66.19684449851977,66.10235516648508,66.0078658344504,65.91337650241573,65.81888717038105,65.72439783834636,65.62990850631168,65.535419174277,65.44092984224233,65.34644051020764,65.25195117817296,65.16216881859224,65.09592127873442,65.02967373887661,64.9634261990188,64.89717865916097,64.83093111930314,64.76468357944533,64.69843603958752,64.6321884997297,64.56594095987187,64.49969342001405,64.43344588015624,64.36719834029842,64.30095080044059,64.23470326058278,64.16845572072495,64.10220818086714,64.03596064100931,63.9697131011515,63.90346556129368,63.83721802143586,63.77097048157804,63.70472294172022,63.6384754018624,63.57222786200458,63.50598032214677,63.43973278228894,63.37348524243113,63.3072377025733,63.24099016271549,63.174742622857664,63.108495082999845,63.04224754314203,62.976000003284206,62.909752463426386,62.84350492356857,62.77725738371075,62.711009843852935,62.644762303995115,62.578514764137296,62.51226722427947,62.44601968442166,62.37977214456383,62.31352460470602,62.2472770648482,62.18102952499038,62.11478198513255,62.04853444527474,61.98228690541693,61.9160393655591,61.84979182570128,61.78354428584346,61.71729674598565,61.65104920612782,61.584801666269996,61.518554126412184,61.452306586554364,61.386059046696545,61.31981150683872,61.2535639669809,61.187316427123086,61.12106888726527,61.05482134740745,60.98857380754963,60.92232626769181,60.85607872783399,60.78983118797617,60.72358364811836,60.65733610826054,60.27529239598243,59.73535059749423,59.195408799006,58.655467000517774,58.11552520202959,57.57558340354134,57.03564160505313,56.495699806564915,55.95575800807669,55.41581620958849,54.875874411100234,54.33593261261204,53.79599081412382,53.25604901563559,52.71610721714739,52.176165418659174,51.636223620170945,51.09628182168272,50.556340023194494,50.01639822470629,49.476456426218064,48.93651462772985,48.39657282924165,47.856631030753405,47.308160004651526,46.753292068614186,46.19842413257686,45.643556196539556,45.08868826050219,44.5338203244649,43.97895238842756,43.42408445239022,42.86921651635292,42.31434858031559,41.759480644278256,41.20461270824092,40.64974477220359,40.09487683616629,39.54000890012896,38.98514096409162,38.430273028054316,37.87540509201699,37.32053715597966,36.765669219942325,36.21080128390499,35.655933347867666,35.10106541183036,34.54619747579302,33.99132953975569,33.436461603718364,32.88159366768103,32.32672573164372,31.771857795606394,31.21698985956906,30.66212192353173,30.107253987494424,29.552386051457095,28.99751811541976,28.442650179382433,27.8877822433451,27.332914307307796,26.778046371270463,26.22317843523313,25.668310499195798,25.113442563158493,24.55857462712116,24.003706691083828,23.448838755046502,22.89397081900917,22.33910288297186,21.784234946934532,21.2293670108972,20.674499074859867,20.119631138822534,19.56476320278523,19.009895266747893,18.455027330710568,17.90015939467323,17.345291458635927,16.790423522598598,16.23555558656126,15.680687650523936,15.1258197144866,14.77778735578579,14.636590574421382,14.495393793056984,14.354197011692584,14.213000230328142,14.076143076888792,13.94332278639745,13.810502495906098,13.677682205414712,13.54486191492341,13.412041624432023,13.279221333940672,13.146401043449293,13.013580752957983,12.883141046688216,12.758142678937181,12.633144311186115,12.508145943435071,12.383147575684038,12.258149207933002,12.133150840181958,12.008152472430917,11.88315410467986,11.765080253499535,11.649195769401668,11.533311285303778,11.417426801205917,11.301542317108048,11.185657833010188,11.069773348912328,10.953888864814429,10.846059204976287,10.740069885206719,10.634080565437134,10.528091245667552,10.42210192589795,10.316112606128371,10.210123286358787,10.106978678595548,10.007991727980269,9.909004777365029,9.810017826749776,9.711030876134522,9.612043925519236,9.513056974903975,9.416568111275831,9.322746477701525,9.22892484412722,9.135103210552899,9.0412815769786,8.947459943404272,8.853638310274452,8.766391141751615,8.679143973228772,8.59189680470593,8.504649636183098,8.417402467660256,8.330155299137415,8.249253178089871,8.168941294223128,8.088629410356363,8.00831752648962,7.928005642622877,7.848879130552611,7.774719894318311,7.70056065808398,7.626401421849659,7.552242185615321,7.47808294938101,7.40829006610278,7.339576641758319,7.270863217413861,7.202149793069436,7.1334363687249756,7.054913158532753,6.972466034001403,6.8900189094700455,6.807571784938688,6.725124660407339,6.6426775358759835,6.560230411344619,6.477783286813268,6.395336162281918,6.312889037750553,6.230441913219202,6.1479947886878525,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[64.19797749551365,64.22509907651803,64.25222065752241,64.2793422385268,64.30646381953119,64.33358540053555,64.36070698153995,64.38782856254433,64.41495014354871,64.44207172455309,64.46919330555747,64.49631488656185,64.52343646756623,64.55055804857062,64.577679629575,64.60480121057938,64.63192279158376,64.65904437258814,64.68616595359254,64.7132875345969,64.7404091156013,64.76753069660568,64.79465227761006,64.82177385861443,64.84889543961881,64.87601702062321,64.90313860162759,64.93026018263195,64.95738176363635,64.98450334464073,65.01162492564511,65.03874650664949,65.06586808765387,65.09298966865826,65.12011124966264,65.14723283066701,65.1743544116714,65.20147599267578,65.22859757368016,65.25571915468454,65.28284073568892,65.30996231669332,65.3370838976977,65.36420547870208,65.39132705970646,65.41844864071084,65.44557022171523,65.4726918027196,65.49981338372399,65.52693496472835,65.55405654573275,65.58117812673713,65.60829970774151,65.63336843364604,65.65843715937385,65.68350588510165,65.70857461082944,65.73364333655725,65.75871206228506,65.78378078801286,65.80884951374065,65.83391823946846,65.85898696519627,65.88405569092407,65.90912441665188,65.93419314237968,65.95926186810749,65.9843305938353,66.00939931956309,66.0344680452909,66.0595367710187,66.08460549674649,66.10967422247431,66.1347429482021,66.15981167392991,66.18488039965771,66.20994912538552,66.23501785111333,66.26008657684113,66.28515530256892,66.31022402829674,66.33529275402454,66.36036147975234,66.38543020548015,66.31086721640587,66.2163778843712,66.12188855233651,66.02739922030183,65.93290988826716,65.83842055623248,65.7439312241978,65.64944189216311,65.55495256012844,65.46046322809374,65.36597389605907,65.27148456402439,65.17699523198972,65.08250589995504,64.98801656792035,64.89352723588567,64.799037903851,64.70454857181632,64.61005923978163,64.51556990774695,64.42108057571227,64.3265912436776,64.23210191164291,64.13761257960823,64.04312324757355,63.94863391553888,63.854144583504194,63.75965525146951,63.665165919434834,63.57067658740015,63.476187255365474,63.40052578721328,63.33427824735546,63.268030707497644,63.20178316763983,63.135535627782005,63.069288087924186,63.003040548066366,62.936793008208554,62.870545468350734,62.80429792849291,62.738050388635095,62.67180284877727,62.60555530891945,62.53930776906164,62.47306022920381,62.406812689346,62.34056514948817,62.27431760963036,62.20807006977253,62.14182252991472,62.0755749900569,62.00932745019908,61.94307991034127,61.87683237048344,61.81058483062562,61.7443372907678,61.67808975090999,61.61184221105216,61.545594671194344,61.47934713133652,61.41309959147871,61.346852051620886,61.280604511763066,61.21435697190525,61.148109432047434,61.081861892189615,61.015614352331795,60.94936681247397,60.88311927261615,60.81687173275833,60.75062419290052,60.68437665304269,60.618129113184864,60.55188157332705,60.48563403346923,60.41938649361141,60.3531389537536,60.28689141389577,60.22064387403796,60.154396334180134,60.08814879432232,60.0219012544645,59.63985754218639,59.09991574369819,58.55997394520997,58.02003214672174,57.48009034823355,56.9401485497453,56.400206751257095,55.86026495276887,55.32032315428065,54.78038135579245,54.2404395573042,53.700497758816,53.160555960327784,52.620614161839555,52.080672363351354,51.54073056486313,51.0007887663749,50.46084696788668,49.92090516939845,49.38096337091026,48.84102157242202,48.30107977393381,47.76113797544561,47.22119617695736,46.68125437846916,46.141312579980934,45.60137078149271,45.06142898300452,44.52148718451626,43.981545386028074,43.44160358753983,42.901661789051616,42.361719990563415,41.821778192075186,41.28183639358697,40.74189459509874,40.20195279661053,39.66201099812233,39.1220691996341,38.58212740114587,38.04218560265767,37.502243804169446,36.962302005681224,36.422360207192995,35.88241840870477,35.34247661021655,34.80253481172835,34.26259301324013,33.7226512147519,33.18270941626368,32.64276761777545,32.09589582474275,31.541027888705425,30.98615995266809,30.431292016630763,29.876424080593452,29.321556144556126,28.76668820851879,28.211820272481454,27.65695233644413,27.102084400406824,26.547216464369495,25.992348528332162,25.437480592294825,24.882612656257518,24.327744720220192,23.77287678418286,23.21800884814553,22.663140912108194,22.108272976070886,21.55340504003356,20.998537103996227,20.443669167958898,19.888801231921562,19.333933295884258,18.779065359846925,18.2241974238096,17.66932948777226,17.114461551734955,16.559593615697626,16.004725679660293,15.449857743622967,14.894989807585631,14.54695744888482,14.405760667520413,14.264563886156013,14.130103620166398,13.997283329675048,13.8644630391837,13.731642748692359,13.598822458201008,13.46600216770962,13.333181877218319,13.20036158672693,13.06754129623558,12.938665974504906,12.813667606753873,12.688669239002827,12.563670871251793,12.438672503500728,12.313674135749682,12.188675767998651,12.063677400247615,11.938679032496573,11.821699865680735,11.705815381582884,11.589930897485013,11.474046413387146,11.358161929289256,11.242277445191394,11.126392961093526,11.010508476995666,10.90313223439527,10.797142914625686,10.691153594856074,10.585164275086504,10.479174955316921,10.373185635547337,10.267196315777735,10.163887589983114,10.064900639367853,9.9659136887526,9.866926738137321,9.767939787522081,9.66895283690683,9.569965886291575,9.473021642059882,9.379200008485578,9.285378374911284,9.191556741336978,9.097735107762674,9.003913474188352,8.910091840614054,8.821866520422432,8.734619351899577,8.64737218337674,8.560125014853897,8.472877846331055,8.385630677808223,8.30330215069491,8.222990266828143,8.142678382961401,8.062366499094658,7.9820546152278915,7.901742731361148,7.827174258700268,7.753015022465946,7.678855786231647,7.604696549997314,7.530537313762994,7.459058533266816,7.3903451089223795,7.321631684577934,7.252918260233473,7.184204835889016,7.110586518620697,7.028139394089342,6.945692269557986,6.863245145026635,6.780798020495277,6.69835089596392,6.61590377143257,6.5334566469012145,6.45100952236985,6.3685623978385,6.28611527330715,6.203668148775785,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[64.062404329698,64.08952591070239,64.11664749170676,64.14376907271114,64.17089065371553,64.1980122347199,64.22513381572429,64.25225539672867,64.27937697773305,64.30649855873745,64.33362013974183,64.3607417207462,64.38786330175058,64.41498488275496,64.44210646375934,64.46922804476372,64.4963496257681,64.5234712067725,64.55059278777688,64.57771436878126,64.60483594978564,64.63195753079003,64.6590791117944,64.68620069279878,64.71332227380316,64.74044385480755,64.76756543581192,64.79468701681631,64.82180859782069,64.84893017882507,64.87605175982945,64.90317334083383,64.93029492183823,64.95741650284259,64.98453808384699,65.01165966485136,65.03775481805546,65.06282354378327,65.08789226951107,65.11296099523888,65.13802972096667,65.16309844669448,65.18816717242228,65.21323589815009,65.2383046238779,65.2633733496057,65.2884420753335,65.3135108010613,65.3385795267891,65.36364825251691,65.38871697824472,65.41378570397252,65.43885442970031,65.46392315542812,65.48899188115593,65.51406060688373,65.53912933261154,65.56419805833934,65.58926678406715,65.61433550979496,65.63940423552275,65.66447296125057,65.68954168697836,65.71461041270615,65.73967913843397,65.76474786416178,65.78981658988958,65.81488531561737,65.83995404134518,65.86502276707299,65.89009149280079,65.91516021852858,65.9402289442564,65.9652976699842,65.990366395712,66.01543512143981,66.04050384716761,66.06557257289542,66.09064129862323,66.11571002435102,66.14077875007882,66.16584747580664,66.19091620153444,66.21598492726223,66.14142193818797,66.04693260615328,65.95244327411861,65.85795394208394,65.76346461004924,65.66897527801457,65.57448594597989,65.4799966139452,65.38550728191053,65.29101794987584,65.19652861784117,65.1020392858065,65.0075499537718,64.91306062173713,64.81857128970245,64.72408195766778,64.6295926256331,64.53510329359841,64.44061396156371,64.34612462952906,64.25163529749437,64.15714596545969,64.06265663342501,63.96816730139033,63.87367796935565,63.77918863732097,63.68469930528628,63.59020997325162,63.495720641216934,63.40123130918225,63.30674197714757,63.21225264511288,63.11776331307821,63.02327398104353,62.92878464900885,62.83429531697417,62.73980598493948,62.64531665290481,62.55082732087013,62.45633798883544,62.36184865680076,62.26735932476609,62.17286999273141,62.07838066069672,61.98389132866204,61.88940199662736,61.79491266459269,61.70513029569218,61.638882755834366,61.57263521597655,61.50638767611873,61.44014013626091,61.37389259640308,61.30764505654526,61.24139751668745,61.17514997682963,61.1089024369718,61.04265489711399,60.97640735725617,60.91015981739835,60.84391227754053,60.77766473768271,60.711417197824886,60.645169657967074,60.578922118109254,60.512674578251435,60.44642703839362,60.380179498535796,60.313931958677976,60.24768441882016,60.18143687896234,60.11518933910452,60.0489417992467,59.98269425938888,59.916446719531066,59.85019917967324,59.78395163981543,59.7177040999576,59.65145656009978,59.58520902024196,59.51896148038415,59.45271394052632,59.38646640066851,59.004422688390406,58.46448088990221,57.92453909141398,57.38459729292576,56.84465549443756,56.30471369594931,55.7647718974611,55.22483009897289,54.68488830048466,54.14494650199646,53.605004703508214,53.065062905020014,52.525121106531785,51.98517930804356,51.44523750955537,50.90529571106714,50.36535391257891,49.82541211409069,49.28547031560247,48.745528517114266,48.20558671862604,47.66564492013782,47.12570312164962,46.58576132316138,46.04581952467318,45.50587772618494,44.96593592769672,44.425994129208526,43.886052330720275,43.346110532232075,42.806168733743846,42.26622693525563,41.72628513676743,41.1863433382792,40.646401539790986,40.10645974130275,39.566517942814535,39.026576144326334,38.4866343458381,37.946692547349876,37.40675074886168,36.86680895037345,36.32686715188523,35.78692535339701,35.24698355490878,34.70704175642056,34.16709995793236,33.627158159444136,33.087216360955914,32.54727456246769,32.00733276397946,31.467390965491266,30.92744916700304,30.387507368514814,29.84756557002659,29.307623771538392,28.767681973050166,28.227740174561944,27.687798376073715,27.147856577585497,26.607914779097293,26.06797298060907,25.52803118212085,24.988089383632623,24.448147585144426,23.9082057866562,23.36826398816798,22.828322189679753,22.288380391191527,21.74843859270333,21.208496794215105,20.66855499572688,20.128613197238657,19.58867139875043,19.048729600262234,18.50878780177401,17.968846003285783,17.42890420479756,16.883631644834004,16.328763708796675,15.77389577275934,15.219027836722015,14.664159900684679,14.316884453935403,14.184064163444015,14.051243872952705,13.918423582461324,13.785603291969974,13.652783001478628,13.519962710987285,13.387142420495936,13.254322130004546,13.121501839513245,12.994190902321646,12.869192534570573,12.744194166819536,12.619195799068503,12.49419743131746,12.369199063566425,12.244200695815358,12.119202328064315,11.994203961959855,11.878319477861996,11.762434993764128,11.64655050966623,11.530666025568376,11.414781541470509,11.29889705737264,11.18301257327475,11.06712808917689,10.960205263814222,10.854215944044645,10.748226624275068,10.642237304505484,10.536247984735873,10.430258664966301,10.324269345196718,10.220796501370712,10.121809550755456,10.022822600140177,9.923835649524918,9.824848698909664,9.725861748294385,9.626874797679147,9.529475172843954,9.435653539269655,9.341831905695349,9.248010272121045,9.15418863854675,9.060367004972443,8.966545371398139,8.877341899093244,8.790094730570408,8.702847562047566,8.61560039352471,8.528353225001872,8.44110605647903,8.357351123299932,8.277039239433194,8.196727355566447,8.11641547169968,8.036103587832939,7.955791703966195,7.879628623082259,7.805469386847943,7.731310150613611,7.657150914379289,7.582991678144991,7.509827000430869,7.441113576086408,7.372400151741976,7.303686727397539,7.234973303053095,7.166259878708633,7.083812754177297,7.001365629645941,6.918918505114585,6.8364713805832285,6.754024256051878,6.67157713152052,6.589130006989162,6.506682882457813,6.424235757926459,6.341788633395093,6.259341508863743,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[63.92683116388234,63.95395274488672,63.98107432589111,64.00819590689548,64.03531748789987,64.06243906890425,64.08956064990863,64.11668223091301,64.1438038119174,64.17092539292177,64.19804697392615,64.22516855493055,64.25229013593493,64.27941171693931,64.30653329794369,64.33365487894807,64.36077645995245,64.38789804095683,64.41501962196122,64.44214120246488,64.46720992819269,64.49227865392048,64.51734737964829,64.54241610537609,64.5674848311039,64.5925535568317,64.61762228255951,64.6426910082873,64.66775973401512,64.69282845974291,64.71789718547072,64.74296591119852,64.76803463692633,64.79310336265414,64.81817208838194,64.84324081410975,64.86830953983754,64.89337826556535,64.91844699129315,64.94351571702094,64.96858444274875,64.99365316847656,65.01872189420436,65.04379061993217,65.06885934565997,65.09392807138778,65.11899679711559,65.14406552284339,65.16913424857118,65.19420297429899,65.2192717000268,65.2443404257546,65.2694091514824,65.2944778772102,65.319546602938,65.34461532866581,65.36968405439362,65.39475278012142,65.41982150584923,65.44489023157703,65.46995895730484,65.49502768303263,65.52009640876045,65.54516513448824,65.57023386021605,65.59530258594386,65.62037131167165,65.64544003739947,65.67050876312726,65.69557748885506,65.72064621458287,65.74571494031068,65.77078366603848,65.79585239176627,65.82092111749408,65.84598984322189,65.87105856894969,65.8961272946775,65.9211960204053,65.94626474613311,65.97133347186092,65.99640219758871,66.02147092331651,66.04653964904432,65.97197665997004,65.87748732793537,65.78299799590069,65.688508663866,65.59401933183133,65.49952999979665,65.40504066776197,65.31055133572728,65.21606200369261,65.12157267165793,65.02708333962326,64.93259400758856,64.8381046755539,64.74361534351921,64.64912601148453,64.55463667944984,64.46014734741516,64.36565801538049,64.2711686833458,64.17667935131112,64.08219001927645,63.98770068724177,63.893211355207086,63.7987220231724,63.70423269113772,63.60974335910305,63.51525402706836,63.42076469503368,63.326275362999006,63.23178603096432,63.137296698929646,63.04280736689496,62.94831803486028,62.85382870282561,62.759339370790926,62.66485003875624,62.57036070672156,62.47587137468688,62.381382042652206,62.28689271061752,62.19240337858284,62.09791404654817,62.003424714513486,61.9089353824788,61.81444605044412,61.71995671840944,61.625467386374766,61.53097805434008,61.436488722305405,61.341999390270715,61.24751005823604,61.15302072620136,61.05853139416668,60.964042062132,60.86955273009732,60.77506339806264,60.68057406602796,60.586084733993275,60.4915954019586,60.39710606992392,60.30261673788924,60.208127405854555,60.11363807381988,60.0191487417852,59.94348726431322,59.8772397244554,59.81099218459759,59.744744644739754,59.67849710488194,59.61224956502412,59.5460020251663,59.47975448530849,59.41350694545066,59.347259405592844,59.281011865735024,59.21476432587721,59.148516786019385,59.082269246161566,59.016021706303746,58.94977416644593,58.88352662658811,58.817279086730295,58.751031546872476,58.368987834594364,57.82904603610617,57.28910423761794,56.74916243912972,56.20922064064152,55.66927884215327,55.12933704366507,54.589395245176846,54.049453446688624,53.50951164820042,52.969569849712165,52.42962805122397,51.88968625273575,51.34974445424752,50.80980265575933,50.2698608572711,49.729919058782876,49.189977260294654,48.650035461806425,48.11009366331823,47.57015186483,47.03021006634178,46.49026826785358,45.950326469365336,45.410384670877136,44.8704428723889,44.33050107390069,43.79055927541249,43.25061747692423,42.71067567843603,42.17073387994781,41.63079208145959,41.09085028297139,40.55090848448316,40.010966685994944,39.47102488750671,38.93108308901849,38.39114129053029,37.85119949204206,37.31125769355384,36.77131589506564,36.23137409657742,35.69143229808919,35.15149049960097,34.611548701112746,34.07160690262452,33.53166510413632,32.991723305648094,32.452898126894034,31.92300584963554,31.393113572377036,30.863221295118564,30.333329017860063,29.803436740601562,29.273544463343065,28.74365218608459,28.213759908826084,27.683867631567587,27.15397535430909,26.624083077050592,26.094190799792116,25.564298522533612,25.034406245275115,24.504513968016617,23.974621690758138,23.44472941349964,22.91483713624114,22.38494485898264,21.85505258172414,21.32516030446567,20.795268027207168,20.265375749948664,19.735483472690166,19.205591195431666,18.67569891817319,18.145806640914692,17.61591436365619,17.086022086397694,16.556129809139218,16.026237531880717,15.496345254622218,14.96645297736372,14.436560700105218,14.105204416230313,13.972384125738925,13.839563835247617,13.706743544756236,13.573923254264885,13.44110296377354,13.308282673282196,13.175462382790846,13.049715830138327,12.924717462387305,12.799719094636261,12.674720726885184,12.54972235913415,12.424723991383116,12.299725623632074,12.174727255881038,12.050823574141067,11.934939090043198,11.819054605945336,11.703170121847478,11.587285637749607,11.47140115365171,11.355516669553857,11.239632185455989,11.123747701358122,11.017278293233172,10.911288973463595,10.805299653694009,10.699310333924434,10.593321014154856,10.48733169438527,10.381342374615661,10.277705412758314,10.178718462143028,10.079731511527767,9.980744560912512,9.881757610297234,9.782770659681972,9.683783709066718,9.585928703628039,9.49210707005371,9.39828543647941,9.30446380290511,9.210642169330804,9.1168205357565,9.022998902182206,8.932817277764048,8.845570109241208,8.75832294071837,8.671075772195532,8.583828603672693,8.496581435149837,8.411400095904977,8.33108821203821,8.250776328171463,8.170464444304725,8.090152560437978,8.00984067657121,7.932082987464233,7.857923751229916,7.783764514995596,7.709605278761279,7.635446042526947,7.561286806292626,7.491882043250465,7.423168618906024,7.354455194561563,7.2857417702171325,7.217028345872695,7.139486114265237,7.057038989733879,6.9745918652025285,6.8921447406711716,6.809697616139817,6.72725049160846,6.64480336707711,6.562356242545752,6.479909118014395,6.397461993483045,6.31501486895169,6.232567744420324,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[63.79125799806668,63.81837957907106,63.84550116007544,63.871596312602094,63.8966650383299,63.921733764057706,63.94680248978551,63.97187121551331,63.996939941241116,64.02200866696892,64.04707739269672,64.07214611842453,64.09721484415232,64.12228356988014,64.14735229560793,64.17242102133575,64.19748974706354,64.22255847279135,64.24762719851915,64.27269592424696,64.29776464997477,64.32283337570256,64.34790210143036,64.37297082715816,64.39803955288598,64.42310827861378,64.44817700434157,64.47324573006938,64.49831445579719,64.52338318152499,64.5484519072528,64.5735206329806,64.59858935870841,64.62365808443622,64.648726810164,64.67379553589183,64.69886426161962,64.72393298734742,64.74900171307522,64.77407043880302,64.79913916453083,64.82420789025863,64.84927661598644,64.87434534171425,64.89941406744205,64.92448279316986,64.94955151889765,64.97462024462547,64.99968897035326,65.02475769608107,65.04982642180887,65.07489514753667,65.09996387326449,65.12503259899228,65.15010132472008,65.17517005044789,65.2002387761757,65.2253075019035,65.2503762276313,65.2754449533591,65.30051367908692,65.32558240481471,65.35065113054252,65.37571985627032,65.40078858199813,65.42585730772593,65.45092603345373,65.47599475918153,65.50106348490934,65.52613221063714,65.55120093636495,65.57626966209276,65.60133838782055,65.62640711354835,65.65147583927616,65.67654456500397,65.70161329073177,65.72668201645958,65.75175074218738,65.77681946791517,65.80188819364298,65.82695691937079,65.85202564509858,65.8770943708264,65.80253138175213,65.70804204971745,65.61355271768277,65.5190633856481,65.4245740536134,65.33008472157873,65.23559538954405,65.14110605750938,65.04661672547468,64.95212739344001,64.85763806140532,64.76314872937064,64.66865939733597,64.57417006530127,64.4796807332666,64.38519140123192,64.29070206919725,64.19621273716257,64.10172340512788,64.0072340730932,63.91274474105853,63.81825540902384,63.723766076989165,63.62927674495449,63.534787412919805,63.44029808088512,63.345808748850445,63.25131941681576,63.15683008478109,63.062340752746394,62.967851420711725,62.87336208867704,62.778872756642365,62.68438342460769,62.589894092573005,62.49540476053832,62.40091542850364,62.30642609646897,62.211936764434284,62.11744743239961,62.02295810036492,61.92846876833025,61.83397943629555,61.73949010426088,61.6450007722262,61.550511440191514,61.45602210815684,61.36153277612215,61.26704344408748,61.172554112052794,61.07806478001811,60.98357544798344,60.88908611594875,60.79459678391408,60.70010745187939,60.60561811984472,60.51112878781004,60.41663945577535,60.32215012374067,60.227660791706,60.13317145967131,60.03868212763663,59.94419279560195,59.84970346356728,59.7552141315326,59.66072479949791,59.56623546746324,59.47174613542855,59.37725680339387,59.28276747135919,59.1882781393245,59.09378880728983,58.99929947525515,58.90481014322047,58.8103208111858,58.715831479151106,58.62134214711643,58.52685281508175,58.43236348304707,58.33787415101239,58.24809177279207,58.18184423293425,58.115596693076434,57.73355298079833,57.193611182310136,56.65366938382191,56.11372758533368,55.57378578684548,55.03384398835723,54.496693734045714,53.966801456787216,53.43690917952872,52.907016902270236,52.37712462501172,51.84723234775324,51.317340070494744,50.78744779323624,50.257555515977764,49.72766323871926,49.19777096146077,48.667878684202265,48.13798640694376,47.60809412968529,47.078201852426794,46.54830957516829,46.018417297909814,45.48852502065129,44.95863274339282,44.42874046613432,43.898848188875824,43.36895591161735,42.839063634358816,42.30917135710034,41.77927907984185,41.249386802583345,40.71949452532487,40.189602248066365,39.659709970807874,39.12981769354937,38.59992541629087,38.07003313903239,37.54014086177389,37.010248584515395,36.480356307256926,35.95046402999842,35.420571752739924,34.89067947548142,34.36078719822292,33.83089492096442,33.30100264370594,32.771110366447445,32.24121808918895,31.71132581193045,31.181433534671946,30.65154125741347,30.121648980154973,29.591756702896475,29.061864425637975,28.531972148379502,28.002079871120998,27.4721875938625,26.942295316604,26.4124030393455,25.882510762087026,25.352618484828525,24.822726207570025,24.292833930311524,23.762941653053048,23.23304937579455,22.703157098536053,22.17326482127755,21.64337254401905,21.113480266760575,20.583587989502078,20.053695712243577,19.523803434985076,18.99391115772658,18.464018880468103,17.934126603209602,17.4042343259511,16.8743420486926,16.344449771434128,15.814557494175627,15.284665216917126,14.75477293965863,14.224880662400128,13.893524378525223,13.760704088033837,13.627883797542527,13.495063507051148,13.362243216559797,13.230239125706095,13.105240757955029,12.980242390203985,12.855244022452942,12.730245654701916,12.605247286950874,12.480248919199799,12.355250551448764,12.230252183697731,12.107443186322271,11.991558702224438,11.875674218126548,11.759789734028677,11.643905249930818,11.52802076583296,11.412136281735089,11.296251797637192,11.180367313539339,11.074351322652118,10.968362002882534,10.862372683112957,10.75638336334338,10.650394043573796,10.544404723804218,10.438415404034643,10.334614324145852,10.235627373530612,10.136640422915365,10.03765347230008,9.93866652168482,9.839679571069563,9.740692620454286,9.642382234412112,9.548560600837792,9.454738967263495,9.360917333689164,9.267095700114865,9.173274066540566,9.07945243296626,8.988292656434867,8.901045487912038,8.813798319389175,8.726551150866332,8.639303982343495,8.552056813820657,8.465449068509992,8.385137184643249,8.304825300776505,8.22451341690974,8.144201533042992,8.063889649176254,7.984537351846223,7.910378115611885,7.83621887937757,7.762059643143252,7.687900406908932,7.613741170674615,7.542650510414522,7.473937086070062,7.4052236617256195,7.336510237381178,7.267796813036717,7.195159474353176,7.112712349821834,7.030265225290468,6.94781810075911,6.86537097622776,6.782923851696403,6.700476727165048,6.618029602633691,6.5355824781023415,6.453135353570982,6.370688229039626,6.288241104508276,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[63.6380262142797,63.663094940007504,63.6881636657353,63.71323239146311,63.738301117190915,63.76336984291871,63.78843856864653,63.81350729437432,63.83857602010213,63.86364474582993,63.88871347155774,63.913782197285535,63.93885092301334,63.96391964874115,63.98898837446895,64.01405710019675,64.03912582592456,64.06419455165236,64.08926327738016,64.11433200310798,64.13940072883577,64.16446945456357,64.18953818029138,64.21460690601918,64.23967563174699,64.2647443574748,64.2898130832026,64.3148818089304,64.33995053465821,64.365019260386,64.3900879861138,64.41515671184162,64.44022543756941,64.46529416329723,64.49036288902502,64.51543161475283,64.54050034048063,64.56556906620844,64.59063779193625,64.61570651766404,64.64077524339186,64.66584396911966,64.69091269484746,64.71598142057525,64.74105014630305,64.76611887203086,64.79118759775866,64.81625632348647,64.84132504921428,64.86639377494208,64.89146250066989,64.9165312263977,64.9415999521255,64.9666686778533,64.99173740358111,65.0168061293089,65.0418748550367,65.06694358076452,65.09201230649231,65.11708103222011,65.14214975794792,65.16721848367573,65.19228720940353,65.21735593513134,65.24242466085914,65.26749338658695,65.29256211231476,65.31763083804255,65.34269956377035,65.36776828949814,65.39142152501316,65.41479166365541,65.43816180229766,65.4615319409399,65.48490207958216,65.5082722182244,65.53164235686666,65.5550124955089,65.57838263415115,65.6017527727934,65.62512291143565,65.6484930500779,65.67186318872015,65.6952333273624,65.59497318431292,65.4699869849251,65.34500078553727,65.22001458614943,65.09502838676161,64.97004218737379,64.84505598798597,64.72006978859814,64.59508358921032,64.47009738982248,64.34511119043466,64.22012499104683,64.09513879165901,63.97015259227118,63.87058043150844,63.77609109947376,63.68160176743907,63.58711243540439,63.492623103369716,63.398133771335026,63.30364443930035,63.20915510726567,63.114665775230996,63.02017644319632,62.92568711116163,62.83119777912695,62.73670844709227,62.64221911505759,62.547729783022916,62.453240450988226,62.35875111895355,62.26426178691887,62.16977245488419,62.07528312284951,61.98079379081483,61.88630445878015,61.791815126745476,61.697325794710785,61.60283646267611,61.50834713064143,61.413857798606756,61.31936846657207,61.22487913453739,61.13038980250271,61.03590047046802,60.94141113843335,60.84692180639867,60.752432474363985,60.65794314232931,60.56345381029463,60.46896447825995,60.374475146225265,60.279985814190596,60.18549648215591,60.09100715012123,59.996517818086545,59.90202848605187,59.80753915401719,59.71304982198251,59.618560489947825,59.52407115791315,59.42958182587847,59.33509249384379,59.240603161809105,59.14611382977443,59.051624497739745,58.95713516570507,58.86264583367039,58.768156501635694,58.673667169601025,58.57917783756634,58.484688505531665,58.39019917349698,58.2957098414623,58.20122050942762,58.106731177392945,58.01224184535826,57.917752513323585,57.8232631812889,57.728773849254225,57.63428451721954,57.539795185184865,57.44530585315019,57.06932657512732,56.552602324110424,56.03587807309351,55.51915382207658,55.00242957105969,54.48570532004275,53.96898106902585,53.452256818008934,52.935532566992016,52.41880831597511,51.902084064958174,51.38535981394128,50.86863556292436,50.351911311907436,49.83518706089055,49.31846280987362,48.8017385588567,48.28501430783977,47.768290056822856,47.25156580580597,46.73484155478904,46.218117303772125,45.70139305275522,45.18466880173829,44.66794455072139,44.15122029970447,43.634496048687545,43.11777179767065,42.60104754665371,42.084323295636814,41.56759904213678,41.037706764878266,40.5078144876198,39.97792221036129,39.4480299331028,38.9181376558443,38.3882453785858,37.858353101327324,37.32846082406883,36.79856854681032,36.26867626955185,35.73878399229335,35.208891715034845,34.67899943777635,34.14910716051785,33.619214883259346,33.08932260600087,32.55943032874237,32.029538051483875,31.499645774225378,30.969753496966874,30.439861219708398,29.9099689424499,29.3800766651914,28.850184387932902,28.32029211067443,27.790399833415925,27.260507556157425,26.730615278898924,26.200723001640426,25.670830724381954,25.140938447123453,24.611046169864952,24.08115389260645,23.551261615347975,23.021369338089478,22.491477060830977,21.961584783572476,21.43169250631398,20.901800229055503,20.371907951797002,19.8420156745385,19.312123397280004,18.782231120021503,18.25233884276303,17.72244656550453,17.19255428824603,16.662662010987532,16.132769733729056,15.602877456470555,15.072985179212054,14.543092901953557,14.013200624695056,13.681844340820147,13.549024050328761,13.416203759837451,13.285764053522804,13.16076568577176,13.035767318020726,12.91076895026966,12.785770582518616,12.660772214767572,12.535773847016548,12.410775479265505,12.28577711151443,12.16406279850349,12.048178314405657,11.932293830307763,11.81640934620993,11.70052486211204,11.58464037801417,11.46875589391631,11.35287140981845,11.237413671840708,11.131424352071098,11.02543503230153,10.919445712531918,10.813456392762333,10.707467072992758,10.601477753223179,10.495488433453595,10.391523235533457,10.292536284918178,10.193549334302917,10.094562383687677,9.995575433072432,9.896588482457146,9.797601531841885,9.698835765196183,9.605014131621884,9.511192498047578,9.417370864473257,9.323549230898958,9.22972759732463,9.13590596375033,9.04376803510569,8.956520866582864,8.86927369806,8.782026529537173,8.694779361014309,8.607532192491467,8.520285023968631,8.439186157248278,8.35887427338153,8.278562389514788,8.198250505648044,8.11793862178128,8.03762673791453,7.962832479993887,7.888673243759566,7.814514007525228,7.740354771290913,7.6661955350565965,7.593418977578566,7.52470555323411,7.455992128889684,7.387278704545222,7.318565280200781,7.24985185585634,7.168385709909773,7.085938585378416,7.003491460847074,6.921044336315707,6.83859721178435,6.756150087252999,6.673702962721643,6.591255838190288,6.508808713658931,6.4263615891275805,6.343914464596223,6.261467340064865,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[63.48164110650001,63.50670983222781,63.53177855795561,63.55684728368342,63.581916009411216,63.60698473513902,63.63205346086683,63.657122186594634,63.68219091232244,63.707259638050246,63.73232836377805,63.757397089505844,63.78246581523365,63.807534540961456,63.83260326668926,63.85767199241707,63.88274071814486,63.907809443872665,63.93287816960047,63.95794689532828,63.98301562105608,64.00808434678389,64.03315307251168,64.0582217982395,64.08329052396729,64.1083592496951,64.1334279754229,64.15849670115071,64.18356542687852,64.20863415260632,64.23370287833411,64.25877160406193,64.28384032978971,64.30890905551753,64.33397778124534,64.35904650697314,64.38411523270094,64.40918395842874,64.43425268415655,64.45932140988435,64.48439013561216,64.50945886133997,64.53452758706777,64.55959631279556,64.58466503852337,64.60973376425117,64.63480248997898,64.65987121570679,64.68493994143458,64.7100086671624,64.73507739289019,64.760146118618,64.7852148443458,64.8097173731233,64.83308751176556,64.8564576504078,64.87982778905005,64.9031979276923,64.92656806633455,64.9499382049768,64.97330834361905,64.9966784822613,65.02004862090355,65.0434187595458,65.06678889818805,65.0901590368303,65.11352917547255,65.1368993141148,65.16026945275705,65.1836395913993,65.20700973004155,65.2303798686838,65.25375000732605,65.2771201459683,65.30049028461055,65.3238604232528,65.34723056189505,65.3706007005373,65.39397083917954,65.4173409778218,65.44071111646404,65.4640812551063,65.48745139374854,65.51082153239079,65.41056138934132,65.28557518995348,65.16058899056566,65.03560279117784,64.91061659179,64.78563039240218,64.66064419301435,64.53565799362653,64.41067179423871,64.28568559485088,64.16069939546306,64.03571319607522,63.910726996687394,63.78574079729957,63.66075459791175,63.53576839852392,63.410782199136094,63.28579599974827,63.16080980036045,63.03582360097261,62.91083740158479,62.785851202196966,62.66086500280913,62.53587880342131,62.41089260403348,62.28590640464566,62.16092020525783,62.035934005870004,61.910947806482184,61.78596160709435,61.67114100762305,61.576651675588366,61.48216234355368,61.387673011519006,61.29318367948433,61.198694347449646,61.10420501541497,61.00971568338028,60.9152263513456,60.820737019310926,60.72624768727625,60.63175835524157,60.53726902320689,60.442779691172206,60.34829035913752,60.25380102710285,60.15931169506817,60.064822363033485,59.9703330309988,59.87584369896412,59.78135436692944,59.686865034894765,59.59237570286009,59.497886370825405,59.40339703879072,59.30890770675604,59.21441837472137,59.119929042686685,59.025439710652,58.93095037861732,58.83646104658264,58.741971714547965,58.64748238251328,58.5529930504786,58.45850371844393,58.36401438640924,58.26952505437456,58.175035722339885,58.08054639030519,57.98605705827052,57.891567726235834,57.79707839420115,57.702589062166474,57.6080997301318,57.51361039809712,57.41912106606244,57.32463173402776,57.23014240199308,57.135653069958394,57.04116373792372,56.94667440588904,56.85218507385436,56.75769574181968,56.38171646379682,55.864992212779924,55.34826796176301,54.83154371074608,54.31481945972918,53.79809520871225,53.281370957695344,52.76464670667842,52.24792245566151,51.731198204644606,51.21447395362767,50.697749702610764,50.18102545159385,49.664301200576936,49.14757694956003,48.63085269854311,48.1141284475262,47.597404196509274,47.08067994549235,46.56395569447546,46.04723144345854,45.53050719244162,45.01378294142472,44.49705869040778,43.98033443939088,43.46361018837396,42.946885937357045,42.43016168634015,41.9134374353232,41.39671318430631,40.87998893328939,40.36326468227247,39.846540431255576,39.32981618023866,38.813091929221734,38.29636767820482,37.7796434271879,37.262919176170996,36.74619492515408,36.229470674137154,35.71274642312026,35.19602217210334,34.679297921086416,34.1625736700695,33.64584941905258,33.129125168035664,32.61240091701876,32.09567666600184,31.578952414984922,31.062228163968005,30.545503912951084,30.028779661934188,29.51205541091727,28.99533115990035,28.478606908883428,27.961882657866532,27.445158406849615,26.92843415583269,26.411709904815773,25.894985653798855,25.37826140278196,24.861537151765035,24.344812900748117,23.8280886497312,23.3113643987143,22.79464014769738,22.27791589668046,21.74990474586739,21.22001246860889,20.690120191350413,20.160227914091912,19.630335636833415,19.100443359574914,18.570551082316413,18.04065880505794,17.51076652779944,16.98087425054094,16.45098197328244,15.921089696023962,15.391197418765465,14.861305141506964,14.331412864248467,13.801520586989966,13.470164303115059,13.341288981339487,13.21629061358845,13.091292245837415,12.966293878086375,12.84129551033534,12.716297142584272,12.59129877483323,12.466300407082187,12.341302039331161,12.22068241068473,12.104797926586864,11.988913442488972,11.873028958391139,11.757144474293243,11.641259990195412,11.52537550609752,11.409491021999651,11.294486701259654,11.188497381490079,11.082508061720494,10.976518741950885,10.870529422181313,10.764540102411704,10.65855078264212,10.552561462872545,10.448432146921023,10.349445196305764,10.25045824569051,10.151471295075229,10.05248434445997,9.953497393844732,9.854510443229485,9.7555234926142,9.661467662405938,9.56764602883164,9.473824395257338,9.380002761683034,9.286181128108712,9.192359494534415,9.099243413776504,9.011996245253668,8.924749076730814,8.837501908207988,8.750254739685127,8.663007571162296,8.575760402639435,8.493235129853293,8.412923245986551,8.332611362119808,8.25229947825306,8.171987594386316,8.091675710519574,8.015286844375854,7.941127608141534,7.866968371907223,7.792809135672902,7.718649899438565,7.64449066320425,7.575474020398166,7.50676059605372,7.438047171709265,7.369333747364837,7.300620323020376,7.224059069997717,7.141611945466367,7.059164820935004,6.976717696403647,6.894270571872305,6.81182344734094,6.729376322809581,6.646929198278231,6.564482073746874,6.48203494921552,6.399587824684162,6.317140700152812,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[63.32525599872034,63.350324724448136,63.375393450175935,63.40046217590374,63.42553090163155,63.45059962735935,63.47566835308716,63.50073707881495,63.52580580454276,63.55087453027057,63.57594325599837,63.60101198172617,63.62608070745397,63.65114943318178,63.676218158909585,63.70128688463739,63.72635561036519,63.751424336092995,63.7764930618208,63.8015617875486,63.826630513276406,63.85169923900421,63.876767964732004,63.901836690459824,63.92690541618761,63.95197414191543,63.977042867643235,64.00211159337103,64.02718031909885,64.05224904482664,64.07731777055444,64.10238649628226,64.12745522201004,64.15252394773786,64.17759267346565,64.20266139919346,64.22773012492127,64.25138335987573,64.27475349851798,64.29812363716022,64.32149377580248,64.34486391444473,64.36823405308698,64.39160419172923,64.41497433037148,64.43834446901373,64.46171460765598,64.48508474629823,64.50845488494048,64.53182502358273,64.55519516222498,64.57856530086723,64.60193543950948,64.62530557815172,64.64867571679397,64.67204585543622,64.69541599407847,64.71878613272072,64.74215627136297,64.76552641000522,64.78889654864747,64.81226668728972,64.83563682593197,64.85900696457422,64.88237710321647,64.90574724185872,64.92911738050097,64.95248751914322,64.97585765778547,64.99922779642772,65.02259793506997,65.04596807371222,65.06933821235447,65.09270835099672,65.11607848963897,65.13944862828122,65.16281876692346,65.18618890556571,65.20955904420796,65.23292918285021,65.25629932149245,65.27966946013471,65.30303959877695,65.32640973741921,65.22614959436973,65.1011633949819,64.97617719559408,64.85119099620624,64.72620479681842,64.60121859743059,64.47623239804277,64.35124619865495,64.22625999926711,64.10127379987928,63.97628760049147,63.85130140110363,63.72631520171581,63.60132900232799,63.47634280294016,63.35135660355234,63.22637040416451,63.10138420477668,62.97639800538886,62.851411806001025,62.726425606613205,62.60143940722538,62.47645320783755,62.35146700844973,62.2264808090619,62.10149460967408,61.97650841028625,61.85152221089842,61.7265360115106,61.60154981212277,61.47656361273495,61.351577413347115,61.226591213959296,61.10160501457147,60.97661881518364,60.851632615795815,60.72664641640799,60.60166021702016,60.47667401763234,60.351687818244514,60.22670161885669,60.10171541946886,59.976729220081026,59.851743020693206,59.726756821305386,59.60177062191755,59.47678442252973,59.377212251703035,59.28272291966836,59.18823358763366,59.093744255598985,58.99925492356431,58.90476559152963,58.81027625949495,58.71578692746027,58.62129759542559,58.52680826339091,58.43231893135623,58.33782959932155,58.24334026728687,58.148850935252185,58.05436160321751,57.959872271182824,57.86538293914815,57.770893607113464,57.67640427507878,57.581914943044104,57.487425611009435,57.392936278974744,57.29844694694006,57.20395761490538,57.10946828287071,57.014978950836024,56.92048961880134,56.82600028676666,56.73151095473199,56.637021622697304,56.54253229066262,56.44804295862794,56.35355362659327,56.259064294558584,56.1645749625239,56.07008563048923,55.69410635246636,55.177382101449474,54.66065785043256,54.143933599415625,53.627209348398736,53.1104850973818,52.5937608463649,52.07703659534798,51.56031234433106,51.04358809331416,50.52686384229722,50.01013959128032,49.493415340263404,48.97669108924648,48.45996683822958,47.94324258721266,47.426518336195755,46.909794085178824,46.3930698341619,45.876345583145,45.359621332128086,44.84289708111116,44.32617283009427,43.809448579077326,43.29272432806043,42.77600007704351,42.259275826026595,41.7425515750097,41.22582732399275,40.70910307297586,40.19237882195894,39.675654570942015,39.158930319925126,38.6422060689082,38.12548181789128,37.60875756687436,37.09203331585744,36.57530906484054,36.05858481382363,35.541860562806704,35.02513631178981,34.50841206077289,33.99168780975597,33.47496355873905,32.958239307722124,32.44151505670521,31.92479080568831,31.408066554671397,30.89134230365447,30.37461805263755,29.857893801620634,29.341169550603738,28.824445299586817,28.307721048569896,27.790996797552975,27.274272546536082,26.75754829551916,26.24082404450224,25.72409979348532,25.207375542468398,24.690651291451502,24.173927040434585,23.657202789417664,23.140478538400746,22.623754287383846,22.10703003636693,21.59225493271982,21.09177370802653,20.591292483333245,20.09081125863998,19.590330033946692,19.089848809253404,18.589367584560115,18.088886359866823,17.58840513517356,17.08792391048027,16.587442685786982,16.086961461093694,15.58648023640043,15.085999011707141,14.585517787013853,14.085036562320564,13.584555337627275,13.271815541405159,13.146817173654117,13.021818805903083,12.896820438152048,12.771822070401006,12.646823702649971,12.521825334898905,12.396826967147861,12.277302022865948,12.161417538768093,12.045533054670225,11.929648570572358,11.813764086474466,11.697879602376632,11.581995118278737,11.466110634180904,11.351559730678613,11.24557041090903,11.139581091139451,11.033591771369876,10.927602451600292,10.821613131830683,10.715623812061112,10.609634492291502,10.505341058308622,10.406354107693367,10.307367157078087,10.208380206462826,10.109393255847573,10.010406305232294,9.911419354617035,9.812432404001793,9.717921193190014,9.624099559615708,9.5302779260414,9.436456292467103,9.342634658892802,9.248813025318496,9.154991391744176,9.067471623924481,8.980224455401638,8.892977286878804,8.805730118355948,8.718482949833122,8.63123578131026,8.547284102458327,8.466972218591597,8.38666033472483,8.306348450858088,8.226036566991345,8.145724683124598,8.067741208757836,7.993581972523535,7.919422736289198,7.845263500054877,7.771104263820566,7.696945027586245,7.626242487562225,7.5575290632177685,7.488815638873326,7.420102214528881,7.351388790184425,7.279732430085672,7.197285305554306,7.114838181022956,7.032391056491606,6.949943931960245,6.867496807428887,6.785049682897544,6.702602558366179,6.620155433834822,6.537708309303471,6.455261184772114,6.372814060240759,6.290366935709402,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[63.16887089094064,63.193939616668445,63.219008342396236,63.24407706812404,63.269145793851855,63.294214519579654,63.31928324530746,63.34435197103525,63.369420696763065,63.39448942249087,63.41955814821868,63.444626873946476,63.469695599674274,63.49476432540209,63.51983305112989,63.54490177685769,63.5699705025855,63.5950392283133,63.6201079540411,63.64517667976891,63.66967920798589,63.693049346628136,63.716419485270386,63.73978962391264,63.763159762554885,63.786529901197135,63.809900039839384,63.83327017848164,63.85664031712389,63.88001045576613,63.90338059440838,63.92675073305064,63.95012087169288,63.97349101033514,63.99686114897738,64.02023128761964,64.04360142626189,64.06697156490414,64.09034170354639,64.11371184218862,64.13708198083089,64.16045211947313,64.18382225811538,64.20719239675763,64.23056253539988,64.25393267404213,64.27730281268438,64.30067295132663,64.32404308996887,64.34741322861112,64.37078336725338,64.39415350589562,64.41752364453787,64.44089378318012,64.46426392182236,64.48763406046461,64.51100419910688,64.53437433774911,64.55774447639138,64.58111461503361,64.60448475367586,64.62785489231813,64.65122503096038,64.67459516960263,64.69796530824487,64.72133544688711,64.74470558552937,64.76807572417161,64.79144586281386,64.81481600145612,64.83818614009837,64.86155627874062,64.88492641738287,64.9082965560251,64.93166669466736,64.95503683330962,64.97840697195186,65.00177711059412,65.02514724923635,65.04851738787862,65.07188752652085,65.09525766516312,65.11862780380535,65.1419979424476,65.04173779939813,64.9167516000103,64.79176540062247,64.66677920123465,64.54179300184683,64.41680680245899,64.29182060307117,64.16683440368334,64.0418482042955,63.916862004907685,63.791875805519865,63.66688960613204,63.54190340674421,63.41691720735638,63.29193100796856,63.16694480858073,63.0419586091929,62.91697240980508,62.79198621041725,62.66700001102943,62.5420138116416,62.41702761225378,62.29204141286595,62.167055213478136,62.0420690140903,61.91708281470247,61.79209661531465,61.66711041592683,61.542124216538994,61.41713801715116,61.29215181776334,61.16716561837551,61.042179418987686,60.917193219599866,60.79220702021205,60.66722082082422,60.54223462143639,60.41724842204856,60.29226222266074,60.167276023272905,60.042289823885085,59.91730362449726,59.79231742510943,59.66733122572161,59.54234502633378,59.41735882694596,59.29237262755814,59.167386428170296,59.042400228782476,58.91741402939465,58.792427830006815,58.667441630619,58.54245543123117,58.41746923184335,58.292483032455515,58.167496833067695,58.04251063367987,57.91752443429204,57.792538234904214,57.667552035516394,57.54256583612856,57.41757963674074,57.29259343735292,57.17777282781764,57.083283495782965,56.98879416374828,56.894304831713605,56.79981549967892,56.70532616764423,56.61083683560956,56.51634750357487,56.421858171540194,56.32736883950551,56.232879507470834,56.13839017543616,56.043900843401474,55.94941151136679,55.854922179332114,55.76043284729743,55.665943515262754,55.57145418322808,55.4769648511934,55.382475519158724,55.006496241135864,54.48977199011896,53.97304773910205,53.456323488085125,52.93959923706823,52.42287498605129,51.90615073503439,51.38942648401748,50.87270223300056,50.355977981983656,49.83925373096671,49.32252947994982,48.8058052289329,48.28908097791598,47.77235672689908,47.25563247588216,46.73890822486524,46.22218397384832,45.7054597228314,45.188735471814496,44.67201122079758,44.15528696978066,43.638562718763765,43.12183846774683,42.60511421672993,42.088389965713006,41.57166571469609,41.0549414636792,40.538217212662246,40.02149296164535,39.50476871062844,38.98804445961151,38.47132020859462,37.9545959575777,37.43787170656078,36.92114745554385,36.41221986583293,35.911738641139664,35.411257416446375,34.91077619175309,34.41029496705982,33.90981374236653,33.40933251767324,32.90885129297995,32.408370068286665,31.907888843593376,31.407407618900113,30.906926394206824,30.406445169513535,29.905963944820247,29.40548272012696,28.905001495433694,28.404520270740406,27.904039046047117,27.40355782135383,26.903076596660565,26.40259537196727,25.902114147273988,25.401632922580696,24.90115169788741,24.400670473194147,23.900189248500855,23.39970802380757,22.899226799114277,22.398745574421014,21.898264349727725,21.397783125034437,20.897301900341148,20.39682067564786,19.896339450954596,19.395858226261304,18.89537700156802,18.39489577687473,17.894414552181438,17.393933327488174,16.89345210279489,16.392970878101597,15.89248965340831,15.392008428715044,14.891527204021756,14.391045979328467,13.890564754635179,13.39008352994189,13.077343733719772,12.952345365968732,12.827346998217696,12.70234863046666,12.577350262715619,12.452351894964584,12.333921635047192,12.218037150949295,12.10215266685143,11.986268182753573,11.870383698655706,11.754499214557837,11.638614730459947,11.522730246362114,11.408632760097557,11.302643440327978,11.196654120558401,11.090664800788817,10.984675481019242,10.878686161249664,10.77269684148008,10.666707521710471,10.5622499696962,10.463263019080935,10.364276068465676,10.265289117850422,10.166302167235143,10.067315216619882,9.968328266004628,9.869341315389349,9.774374723974066,9.680553090399762,9.586731456825468,9.492909823251162,9.399088189676856,9.30526655610256,9.211444922528257,9.122947002595282,9.035699834072444,8.948452665549608,8.861205497026765,8.773958328503928,8.686711159981073,8.601333075063362,8.521021191196613,8.440709307329858,8.360397423463127,8.28008553959636,8.199773655729619,8.120195573139824,8.046036336905503,7.971877100671171,7.8977178644368715,7.823558628202534,7.749399391968213,7.677010954726272,7.608297530381812,7.539584106037379,7.470870681692923,7.402157257348481,7.3334438330040355,7.25295866564225,7.1705115411108995,7.088064416579535,7.005617292048185,6.923170167516834,6.840723042985473,6.758275918454114,6.675828793922773,6.593381669391407,6.510934544860049,6.4284874203286995,6.3460402957973425,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[63.01248578316094,63.037554508888746,63.06262323461655,63.08769196034436,63.11134519473829,63.13471533338054,63.15808547202279,63.18145561066504,63.20482574930729,63.22819588794953,63.25156602659179,63.27493616523404,63.29830630387629,63.32167644251853,63.34504658116079,63.36841671980304,63.391786858445286,63.41515699708753,63.43852713572979,63.46189727437203,63.485267413014284,63.50863755165653,63.53200769029878,63.55537782894103,63.578747967583276,63.60211810622553,63.625488244867775,63.64885838351003,63.672228522152274,63.69559866079452,63.71896879943678,63.74233893807903,63.76570907672127,63.78907921536353,63.81244935400577,63.83581949264803,63.85918963129027,63.88255976993253,63.90592990857477,63.92930004721702,63.952670185859276,63.976040324501525,63.999410463143775,64.02278060178602,64.04615074042827,64.06952087907052,64.09289101771277,64.11626115635502,64.13963129499727,64.16300143363952,64.18637157228177,64.20974171092402,64.23311184956627,64.25648198820852,64.27985212685077,64.30322226549302,64.32659240413527,64.34996254277752,64.37333268141977,64.39670282006202,64.42007295870427,64.44344309734652,64.46681323598877,64.49018337463102,64.51355351327327,64.53692365191552,64.56029379055776,64.58366392920001,64.60703406784226,64.63040420648451,64.65377434512676,64.67714448376901,64.70051462241125,64.72388476105351,64.74725489969575,64.77062503833801,64.79399517698025,64.81736531562251,64.84073545426475,64.86410559290701,64.88747573154924,64.91084587019151,64.93421600883374,64.957586147476,64.85732600442653,64.73233980503869,64.60735360565087,64.48236740626304,64.35738120687522,64.23239500748738,64.10740880809956,63.98242260871174,63.85743640932391,63.73245020993608,63.60746401054826,63.482477811160436,63.35749161177261,63.23250541238478,63.107519212996955,62.98253301360913,62.85754681422131,62.732560614833474,62.607574415445654,62.48258821605782,62.35760201667001,62.23261581728217,62.10762961789435,61.98264341850653,61.85765721911869,61.73267101973087,61.60768482034304,61.48269862095522,61.35771242156739,61.232726222179565,61.10774002279174,60.98275382340391,60.857767624016084,60.73278142462827,60.60779522524044,60.48280902585262,60.35782282646478,60.232836627076956,60.107850427689144,59.9828642283013,59.857878028913476,59.732891829525656,59.60790563013782,59.48291943075,59.357933231362175,59.23294703197435,59.10796083258653,58.982974633198694,58.857988433810874,58.73300223442304,58.60801603503521,58.48302983564739,58.358043636259566,58.23305743687174,58.10807123748391,57.983085038096085,57.85809883870826,57.73311263932044,57.608126439932605,57.483140240544785,57.35815404115695,57.23316784176913,57.10818164238131,56.98319544299348,56.85820924360565,56.73322304421782,56.608236844829996,56.483250645442176,56.35826444605435,56.23327824666653,56.108292047278695,55.983305847890875,55.85831964850304,55.733333449115214,55.6083472497274,55.48336105033957,55.35837485095175,55.233388651563914,55.108402452176094,54.98341625278827,54.88384407189757,54.78935473986289,54.69486540782821,54.31888612980536,53.80216187878845,53.285437627771536,52.76871337675462,52.25198912573772,51.73526487472078,51.23218479894606,50.73170357425276,50.23122234955948,49.73074112486621,49.230259900172896,48.72977867547964,48.22929745078635,47.728816226093066,47.2283350013998,46.72785377670651,46.22737255201322,45.72689132731993,45.226410102626645,44.72592887793338,44.22544765324009,43.72496642854679,43.22448520385353,42.72400397916022,42.223522754466956,41.72304152977367,41.22256030508038,40.72207908038711,40.22159785569381,39.72111663100054,39.22063540630725,38.720154181613964,38.2196729569207,37.71919173222741,37.21871050753412,36.71822928284084,36.21774805814754,35.717266833454275,35.21678560876099,34.716304384067705,34.21582315937444,33.71534193468115,33.21486070998786,32.71437948529457,32.213898260601276,31.71341703590799,31.212935811214727,30.71245458652144,30.21197336182815,29.71149213713486,29.21101091244157,28.710529687748313,28.21004846305502,27.709567238361736,27.209086013668443,26.708604788975176,26.20812356428189,25.7076423395886,25.20716111489531,24.706679890202025,24.20619866550876,23.70571744081547,23.205236216122184,22.704754991428896,22.20427376673563,21.70379254204234,21.20331131734905,20.702830092655763,20.202348867962474,19.701867643269207,19.20138641857592,18.700905193882633,18.200423969189345,17.699942744496056,17.19946151980279,16.6989802951095,16.19849907041621,15.698017845722925,15.19753662102966,14.69705539633637,14.196574171643082,13.696092946949793,13.195611722256505,12.882871926034385,12.757873558283343,12.63287519053231,12.507876822781276,12.390541247228397,12.274656763130535,12.158772279032673,12.042887794934776,11.92700331083691,11.811118826739055,11.695234342641188,11.57934985854332,11.46570578951653,11.359716469746951,11.253727149977342,11.147737830207763,11.04174851043819,10.935759190668604,10.829769870899026,10.72378055112945,10.61915888108376,10.5201719304685,10.421184979853251,10.322198029237988,10.22321107862273,10.124224128007475,10.025237177392196,9.926250226776936,9.830828254758151,9.73700662118385,9.643184987609523,9.549363354035217,9.455541720460925,9.361720086886619,9.267898453312311,9.178422381266103,9.091175212743249,9.003928044220405,8.91668087569757,8.829433707174733,8.74218653865189,8.65538204766838,8.575070163801639,8.49475827993489,8.414446396068142,8.334134512201388,8.253822628334657,8.17351074446789,8.098490701287478,8.02433146505316,7.950172228818839,7.876012992584507,7.801853756350208,7.727779421890309,7.659065997545864,7.590352573201427,7.5216391488569645,7.452925724512533,7.384212300168078,7.308632025730196,7.226184901198835,7.143737776667484,7.061290652136135,6.978843527604768,6.896396403073419,6.813949278542069,6.731502154010707,6.649055029479349,6.566607904948007,6.484160780416642,6.401713655885284,6.319266531353934,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[62.843745654679736,62.865518744908535,62.88729183513733,62.90906492536613,62.93083801559493,62.95261110582373,62.974384196052526,62.99615728628133,63.01793037651012,63.03970346673893,63.061476556967726,63.083249647196524,63.10502273742532,63.12679582765412,63.14963361550766,63.1730037541499,63.19637389279215,63.2197440314344,63.24311417007666,63.2664843087189,63.28985444736115,63.3132245860034,63.33659472464564,63.35996486328791,63.38333500193014,63.4067051405724,63.43007527921465,63.4534454178569,63.47681555649915,63.5001856951414,63.52355583378365,63.5469259724259,63.57029611106814,63.5936662497104,63.617036388352645,63.640406526994894,63.663776665637144,63.687146804279394,63.71051694292164,63.733887081563886,63.75725722020614,63.78062735884839,63.80399749749064,63.82736763613289,63.85073777477514,63.87410791341739,63.89747805205964,63.92084819070189,63.94421832934414,63.96758846798639,63.99095860662864,64.01432874527089,64.03769888391314,64.06106902255539,64.08443916119764,64.10780929983989,64.13117943848214,64.15454957712438,64.17791971576663,64.20128985440888,64.22465999305113,64.24803013169338,64.27140027033563,64.29477040897788,64.31814054762013,64.34151068626238,64.36488082490463,64.38825096354688,64.41162110218913,64.43499124083138,64.45836137947363,64.48173151811588,64.50510165675811,64.52847179540038,64.55184193404263,64.57521207268488,64.59858221132713,64.62195234996938,64.64532248861163,64.66869262725388,64.69206276589613,64.71543290453837,64.73880304318062,64.76217318182287,64.66191303877339,64.53692683938556,64.41194063999774,64.28695444060992,64.16196824122208,64.03698204183426,63.91199584244643,63.78700964305861,63.66202344367078,63.53703724428295,63.412051044895136,63.287064845507295,63.162078646119475,63.03709244673165,62.91210624734383,62.787120047956,62.662133848568175,62.53714764918034,62.41216144979253,62.28717525040469,62.162189051016874,62.03720285162904,61.91221665224121,61.78723045285339,61.66224425346557,61.53725805407774,61.41227185468992,61.287285655302085,61.162299455914265,61.03731325652643,60.91232705713861,60.78734085775078,60.66235465836296,60.53736845897513,60.412382259587304,60.28739606019948,60.16240986081165,60.03742366142382,59.912437462036,59.787451262648176,59.66246506326035,59.53747886387253,59.412492664484695,59.287506465096875,59.16252026570904,59.03753406632122,58.912547866933394,58.78756166754557,58.66257546815774,58.537589268769906,58.41260306938209,58.28761686999427,58.16263067060643,58.03764447121861,57.91265827183078,57.78767207244296,57.66268587305514,57.537699673667305,57.412713474279485,57.28772727489166,57.16274107550383,57.037754876116004,56.91276867672818,56.78778247734035,56.66279627795252,56.537810078564696,56.41282387917687,56.28783767978905,56.162851480401216,56.03786525495172,55.88128911376208,55.724712972572455,55.568136831382816,55.411560690193184,55.25498454900356,55.098408407813935,54.9418322666243,54.78525612543467,54.62867998424504,54.472103843055415,54.31552770186578,54.15895156067615,54.00237541948653,53.62298247807581,53.13218113655461,52.64137979503338,52.15057845351215,51.65977711199094,51.16897577046969,50.67817442894848,50.18737308742726,49.69657174590603,49.20577040438482,48.714969062863574,48.22416772134236,47.73336637982113,47.2425650382999,46.751763696778696,46.26096235525746,45.770161013736235,45.27935967221501,44.78855833069378,44.29775698917257,43.80695564765134,43.316154306130116,42.82535296460891,42.334551623087656,41.84375028156645,41.35294894004522,40.86214759852399,40.371346257002784,39.880544915481536,39.38974357396033,38.8989422324391,38.40814089091787,37.917339549396665,37.42653820787543,36.935736866354205,36.44493552483298,35.954134183311744,35.46333284179054,34.97253150026931,34.48173015874808,33.990928817226866,33.50012747570564,33.00932613418441,32.51852479266318,32.01942645291591,31.518945228222623,31.018464003529356,30.517982778836068,30.01750155414278,29.51702032944949,29.016539104756202,28.516057880062938,28.015576655369653,27.51509543067636,27.014614205983072,26.51413298128981,26.01365175659652,25.513170531903228,25.01268930720994,24.512208082516654,24.011726857823387,23.511245633130102,23.010764408436813,22.51028318374352,22.009801959050257,21.50932073435697,21.008839509663677,20.50835828497039,20.007877060277103,19.50739583558384,19.006914610890547,18.506433386197262,18.005952161503973,17.50547093681068,17.004989712117418,16.504508487424133,16.00402726273084,15.503546038037552,15.003064813344288,14.502583588651001,14.002102363957711,13.50162113926442,13.001139914571134,12.688400118349017,12.563401750597976,12.447160859409646,12.331276375311754,12.215391891213889,12.099507407116025,11.983622923018165,11.867738438920268,11.7518539548224,11.635969470724548,11.52277881893549,11.416789499165908,11.31080017939633,11.204810859626752,11.098821539857141,10.992832220087564,10.886842900317989,10.780853580548403,10.676067792471367,10.577080841856112,10.478093891240828,10.379106940625567,10.280119990010316,10.181133039395055,10.082146088779794,9.98315913816454,9.887281785542221,9.793460151967917,9.699638518393616,9.605816884819317,9.511995251244988,9.418173617670682,9.32435198409639,9.23389775993692,9.146650591414076,9.059403422891238,8.972156254368382,8.884909085845543,8.797661917322705,8.710414748799868,8.629119136406663,8.548807252539921,8.468495368673178,8.38818348480643,8.30787160093968,8.227559717072927,8.150945065669474,8.076785829435153,8.002626593200821,7.928467356966505,7.854308120732183,7.7801488844978515,7.709834464709916,7.641121040365469,7.5724076160210245,7.503694191676589,7.434980767332126,7.364305385818136,7.281858261286786,7.199411136755436,7.1169640122240745,7.034516887692725,6.952069763161375,6.869622638630009,6.787175514098659,6.704728389567308,6.622281265035948,6.53983414050459,6.4573870159732465,6.374939891441882,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[62.67207121023313,62.69384430046192,62.71561739069072,62.737390480919515,62.75916357114832,62.78093666137712,62.80270975160591,62.82448284183471,62.846255932063514,62.86802902229232,62.88980211252111,62.911575202749916,62.933348292978714,62.95512138320751,62.97689447343631,62.99866756366511,63.02044065389391,63.042213744122705,63.06398683435151,63.08575992458031,63.10753301480911,63.129306105037905,63.151079195266696,63.17285228549551,63.19462537572429,63.2163984659531,63.23817155618191,63.25994464641069,63.28171773663951,63.3034908268683,63.32553009138584,63.34890023002809,63.37227036867034,63.39564050731259,63.41901064595484,63.44238078459709,63.46575092323934,63.4891210618816,63.51249120052384,63.53586133916609,63.55923147780834,63.58260161645059,63.60597175509284,63.62934189373509,63.65271203237734,63.67608217101959,63.69945230966184,63.722822448304086,63.746192586946336,63.769562725588585,63.792932864230835,63.816303002873084,63.839673141515334,63.86304328015758,63.88641341879983,63.90978355744208,63.93315369608433,63.95652383472658,63.97989397336883,64.00326411201108,64.02663425065333,64.05000438929558,64.07337452793783,64.09674466658008,64.12011480522233,64.14348494386458,64.16685508250683,64.19022522114908,64.21359535979133,64.23696549843358,64.26033563707583,64.28370577571808,64.30707591436033,64.33044605300258,64.35381619164482,64.37718633028707,64.40055646892932,64.42392660757157,64.44729674621382,64.47066688485607,64.49403702349832,64.51740716214057,64.54077730078282,64.56414743942506,64.46388729637557,64.33890109698775,64.21391489759993,64.08892869821211,63.963942498824274,63.83895629943646,63.71397010004862,63.5889839006608,63.46399770127297,63.33901150188514,63.214025302497326,63.089039103109485,62.964052903721665,62.839066704333845,62.71408050494602,62.58909430555819,62.46410810617037,62.33912190678254,62.21413570739472,62.089149508006884,61.964163308619064,61.83917710923124,61.71419090984341,61.58920471045559,61.464218511067756,61.339232311679936,61.21424611229211,61.08925991290427,60.96427371351646,60.83928751412863,60.7143013147408,60.589315115352974,60.46432891596515,60.33934271657733,60.2143565171895,60.08937031780167,59.96438411841385,59.83939791902602,59.71441171963819,59.58942552025037,59.46443932086254,59.33945312147472,59.214466922086885,59.089480722699065,58.964494523311245,58.83950832392341,58.714522124535584,58.58953592514776,58.46454972575994,58.3395635263721,58.21457732698428,58.089591127596464,57.96460492820863,57.823823749081605,57.66724760789197,57.510671466702334,57.35409532551271,57.197519184323085,57.04094304313345,56.88436690194382,56.72779076075419,56.57121461956456,56.41463847837493,56.2580623371853,56.101486195995676,55.94491005480604,55.78833391361641,55.63175777242679,55.47518163123715,55.318605490047524,55.162029348857885,55.00545320766825,54.84887706647862,54.69230092528899,54.53572478409937,54.37914864290974,54.22257250172011,54.06599636053048,53.909420219340845,53.75284407815122,53.59626793696159,53.43969179577196,53.28311565458234,52.90372271317162,52.41292137165041,51.92212003012919,51.43131868860796,50.940517347086754,50.44971600556549,49.958914664044286,49.46811332252307,48.97731198100183,48.48651063948063,47.99570929795938,47.504907956438174,47.01410661491694,46.52330527339571,46.0325039318745,45.54170259035328,45.05090124883205,44.560099907310814,44.06929856578959,43.57849722426838,43.087695882747155,42.59689454122592,42.106093199704716,41.61529185818346,41.12449051666226,40.63368917514103,40.142887833619795,39.65208649209859,39.16128515057734,38.67048380905613,38.1796824675349,37.688881126013676,37.19807978449247,36.70727844297124,36.21647710145002,35.725675759928784,35.23487441840756,34.744073076886345,34.25327173536512,33.762470393843884,33.27166905232267,32.780867710801445,32.29006636928022,31.799265027758988,31.30846368623776,30.81766234471653,30.326861003195326,29.8360596616741,29.345258320152872,28.85445697863164,28.363655637110412,27.872854295589207,27.382052954067973,26.891251612546746,26.400450271025516,25.909648929504307,25.418847587983077,24.92804624646185,24.43724490494062,23.94644356341939,23.455642221898188,22.96484088037696,22.47403953885573,21.9832381973345,21.492436855813292,21.001635514292065,20.510834172770835,20.02003283124961,19.529231489728375,19.03843014820717,18.547628806685942,18.056827465164712,17.566026123643482,17.075224782122255,16.58442344060105,16.093622099079816,15.60282079990455,15.134959555863814,14.667098311823095,14.199237067782358,13.731375823741615,13.263514579700882,12.795653335660143,12.503780471590856,12.387895987492985,12.272011503395127,12.156127019297235,12.040242535199368,11.924358051101507,11.808473567003647,11.69258908290575,11.579851848354432,11.473862528584862,11.367873208815277,11.261883889045693,11.155894569276116,11.049905249506539,10.943915929736928,10.83792660996735,10.732976703858935,10.633989753243673,10.53500280262842,10.436015852013165,10.337028901397879,10.23804195078262,10.139055000167371,10.040068049552108,9.943735316326297,9.849913682751996,9.756092049177676,9.662270415603372,9.568448782029073,9.474627148454772,9.380805514880445,9.289373138607717,9.202125970084884,9.114878801562043,9.027631633039201,8.940384464516363,8.853137295993507,8.765890127470666,8.683168109011701,8.602856225144958,8.522544341278191,8.44223245741145,8.361920573544706,8.28160868967796,8.203399430051427,8.129240193817116,8.05508095758281,7.980921721348489,7.906762485114157,7.832603248879841,7.760602931873968,7.6918895075295115,7.62317608318507,7.554462658840624,7.485749234496178,7.417035810151742,7.337531621374733,7.255084496843368,7.1726373723120185,7.090190247780669,7.007743123249306,6.925295998717956,6.842848874186606,6.760401749655241,6.67795462512389,6.595507500592541,6.513060376061179,6.43061325152982,6.348166126998479,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[62.50039676578652,62.522169856015324,62.543942946244115,62.56571603647291,62.58748912670171,62.60926221693052,62.63103530715931,62.652808397388114,62.674581487616905,62.69635457784571,62.718127668074516,62.73990075830331,62.7616738485321,62.7834469387609,62.80522002898971,62.8269931192185,62.848766209447305,62.87053929967611,62.8923123899049,62.91408548013371,62.9358585703625,62.957631660591304,62.979404750820095,63.0011778410489,63.02295093127769,63.0447240215065,63.066497111735295,63.08827020196409,63.1100432921929,63.13181638242169,63.153589472650495,63.17536256287929,63.197135653108084,63.21890874333689,63.24068183356569,63.26245492379448,63.284228014023284,63.30600110425208,63.32777419448089,63.34954728470968,63.37132037493848,63.39309346516728,63.414866555396074,63.43663964562488,63.458412735853685,63.480185826082476,63.50195891631128,63.52479670590628,63.54816684454853,63.57153698319078,63.59490712183303,63.61827726047528,63.64164739911753,63.66501753775978,63.68838767640203,63.71175781504428,63.73512795368653,63.75849809232878,63.78186823097103,63.80523836961328,63.82860850825553,63.85197864689778,63.87534878554003,63.898718924182276,63.92208906282452,63.945459201466775,63.96882934010902,63.992199478751274,64.01556961739352,64.03893975603577,64.06230989467802,64.08568003332027,64.10905017196251,64.13242031060477,64.15579044924702,64.17916058788927,64.20253072653152,64.22590086517377,64.24927100381602,64.27264114245827,64.29601128110052,64.31938141974277,64.34275155838502,64.36612169702727,64.26586155397779,64.14087535458995,64.01588915520213,63.890902955814305,63.76591675642648,63.64093055703866,63.515944357650824,63.390958158263,63.26597195887517,63.14098575948735,63.01599956009952,62.89101336071169,62.76602716132387,62.64104096193604,62.516054762548215,62.391068563160395,62.26608236377257,62.141096164384734,62.016109964996915,61.89112376560908,61.76613756622126,61.641151366833434,61.51616516744561,61.39117896805779,61.26619276866995,61.14120656928213,61.016220369894306,60.89123417050648,60.76624797111866,60.641261771730825,60.516275572343005,60.39128937295517,60.26630317356735,60.141316974179524,60.0163307747917,59.89134457540387,59.76635837601604,59.609782243211484,59.45320610202186,59.296629960832234,59.1400538196426,58.98347767845297,58.82690153726334,58.67032539607371,58.51374925488407,58.357173113694444,58.200596972504826,58.04402083131519,57.88744469012556,57.73086854893592,57.57429240774629,57.417716266556674,57.26114012536704,57.10456398417741,56.94798784298778,56.79141170179815,56.63483556060852,56.47825941941889,56.32168327822926,56.16510713703963,56.008530995849995,55.85195485466036,55.69537871347074,55.53880257228111,55.38222643109148,55.22565028990184,55.06907414871222,54.91249800752259,54.755921866332955,54.59934572514333,54.44276958395369,54.286193442764066,54.12961730157443,53.9730411603848,53.81646501919518,53.659888878005546,53.503312736815914,53.34673659562628,53.19016045443665,53.033584313247026,52.8770081720574,52.72043203086776,52.56385588967814,52.18446294826743,51.69366160674622,51.202860265225,50.712058923703765,50.22125758218255,49.730456240661304,49.2396548991401,48.74885355761887,48.25805221609764,47.76725087457643,47.276449533055185,46.78564819153398,46.294846850012746,45.80404550849152,45.31324416697031,44.82244282544909,44.331641483927854,43.84084014240663,43.3500388008854,42.85923745936418,42.36843611784296,41.87763477632173,41.38683343480052,40.896032093279274,40.40523075175807,39.914429410236835,39.4236280687156,38.932826727194396,38.44202538567315,37.95122404415194,37.46042270263071,36.96962136110949,36.47882001958827,35.98801867806704,35.497217336545816,35.00641599502459,34.51561465350336,34.02481331198216,33.534011970460924,33.04321062893969,32.552409287418484,32.06160794589726,31.570806604376028,31.080005262854797,30.589203921333567,30.098402579812344,29.60760123829113,29.116799896769898,28.625998555248675,28.135197213727444,27.644395872206218,27.153594530685012,26.662793189163786,26.188480056826904,25.72061881278617,25.252757568745444,24.784896324704707,24.317035080663974,23.849173836623237,23.381312592582496,22.913451348541777,22.44559010450104,21.977728860460306,21.509867616419562,21.042006372378847,20.57414512833811,20.10628388429737,19.638422640256632,19.170561396215895,18.702700152175176,18.23483890813444,17.7669776640937,17.299116420052965,16.831255176012224,16.36339393197151,15.895532687930768,15.427671443890034,14.959810199849294,14.491948955808576,14.024087711767837,13.556226467727098,13.08836522368636,12.620503979645623,12.328631115576338,12.212746631478467,12.096862147380609,11.980977663282717,11.865093179184848,11.749208695086988,11.636924877773385,11.5309355580038,11.424946238234217,11.318956918464647,11.212967598695062,11.10697827892548,11.000988959155901,10.894999639386324,10.789885615246519,10.690898664631266,10.591911714015987,10.492924763400726,10.39393781278547,10.294950862170218,10.195963911554934,10.09697696093967,10.000188847110362,9.906367213536056,9.81254557996175,9.718723946387449,9.62490231281313,9.531080679238826,9.437259045664526,9.344848517278525,9.257601348755683,9.170354180232842,9.083107011710009,8.99585984318717,8.908612674664324,8.821365506141488,8.737217081616722,8.656905197749973,8.57659331388323,8.496281430016488,8.41596954614972,8.335657662282978,8.25585379443342,8.1816945581991,8.107535321964763,8.03337608573045,7.959216849496146,7.885057613261824,7.811371399038009,7.742657974693567,7.673944550349122,7.605231126004665,7.536517701660224,7.4678042773157784,7.393204981462665,7.310757856931323,7.228310732399965,7.145863607868599,7.0634164833372495,6.9809693588059,6.898522234274537,6.816075109743188,6.733627985211838,6.651180860680473,6.568733736149122,6.486286611617771,6.40383948708641,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[62.328722321339924,62.35049541156873,62.37226850179752,62.39404159202631,62.41581468225512,62.43758777248392,62.459360862712714,62.48113395294152,62.50290704317031,62.524680133399116,62.54645322362792,62.56822631385671,62.5899994040855,62.61177249431431,62.633545584543114,62.65531867477192,62.67709176500071,62.698864855229516,62.72063794545831,62.7424110356871,62.764184125915904,62.78595721614471,62.8077303063735,62.829503396602306,62.8512764868311,62.8730495770599,62.8948226672887,62.9165957575175,62.938368847746304,62.960141937975095,62.981915028203886,63.0036881184327,63.02546120866149,63.047234298890295,63.06900738911909,63.090780479347885,63.1125535695767,63.13432665980548,63.15609975003429,63.177872840263085,63.19964593049188,63.22141902072069,63.24319211094948,63.264965201178285,63.286738291407076,63.30851138163588,63.33028447186469,63.35205756209348,63.37383065232227,63.395603742551074,63.41737683277988,63.43914992300867,63.460923013237476,63.48269610346627,63.50446919369507,63.52624228392388,63.54801537415267,63.569788464381475,63.591561554610266,63.61333464483907,63.63510773506786,63.65688082529667,63.67865391552546,63.700693181784494,63.724063320426744,63.74743345906899,63.77080359771124,63.79417373635349,63.81754387499574,63.84091401363799,63.86428415228024,63.887654290922484,63.91102442956474,63.93439456820698,63.95776470684924,63.98113484549148,64.00450498413375,64.02787512277598,64.05124526141823,64.0746154000605,64.09798553870273,64.121355677345,64.14472581598723,64.16809595462948,64.06783581158,63.94284961219217,63.81786341280435,63.69287721341652,63.567891014028696,63.442904814640876,63.31791861525304,63.19293241586522,63.06794621647739,62.94296001708957,62.81797381770174,62.692987618313914,62.56800141892609,62.44301521953826,62.31802902015043,62.193042820762614,62.06805662137478,61.94307042198696,61.81808422259913,61.693098023211306,61.55231687853106,61.39574073734143,61.239164596151795,61.08258845496218,60.92601231377253,60.769436172582914,60.61286003139328,60.45628389020365,60.29970774901403,60.14313160782439,59.98655546663476,59.82997932544513,59.6734031842555,59.51682704306587,59.360250901876235,59.2036747606866,59.04709861949697,58.89052247830734,58.73394633711772,58.57737019592809,58.42079405473846,58.26421791354884,58.1076417723592,57.95106563116958,57.79448948997994,57.637913348790306,57.48133720760069,57.32476106641104,57.168184925221425,57.01160878403179,56.85503264284216,56.69845650165253,56.54188036046291,56.38530421927328,56.22872807808364,56.07215193689401,55.91557579570438,55.75899965451475,55.60242351332512,55.445847372135496,55.28927123094586,55.132695089756226,54.9761189485666,54.81954280737697,54.662966666187344,54.50639052499771,54.34981438380808,54.19323824261845,54.03666210142882,53.88008596023919,53.72350981904955,53.56693367785993,53.4103575366703,53.253781395480665,53.09720525429104,52.94062911310141,52.78405297191178,52.627476830722145,52.47090068953251,52.314324548342896,52.157748407153264,52.00117226596363,51.84459612477401,51.465203183363286,50.97440184184208,50.48360050032085,49.99279915879963,49.50199781727842,49.01119647575717,48.520395134235955,48.02959379271473,47.5387924511935,47.047991109672296,46.55718976815104,46.066388426629835,45.57558708510861,45.084785743587375,44.59398440206617,44.10318306054494,43.612381719023716,43.12158037750249,42.630779035981256,42.13997769446005,41.64917635293881,41.15837501141759,40.667573669896385,40.17677232837513,39.685970986853924,39.1951696453327,38.704368303811464,38.21356696229026,37.722765620769,37.24200055779001,36.77413931374927,36.306278069708526,35.83841682566782,35.37055558162708,34.90269433758634,34.4348330935456,33.96697184950487,33.499110605464146,33.03124936142341,32.56338811738267,32.095526873341946,31.627665629301212,31.15980438526048,30.69194314121974,30.224081897179005,29.75622065313826,29.288359409097545,28.820498165056808,28.35263692101607,27.884775676975327,27.41691443293459,26.949053188893878,26.481191944853137,26.013330700812396,25.54546945677166,25.077608212730944,24.609746968690203,24.141885724649466,23.67402448060873,23.20616323656799,22.738301992527276,22.27044074848653,21.802579504445795,21.334718260405058,20.866857016364342,20.3989957723236,19.93113452828286,19.463273284242128,18.99541204020139,18.527550796160668,18.059689552119927,17.591828308079194,17.12396706403846,16.65610581999772,16.188244575957,15.72038333191626,15.252522087875526,14.784660843834788,14.316799599794074,13.84893835575333,13.381077111712589,12.913215867671859,12.445354623631115,12.15348175956183,12.037597275463963,11.921712791366103,11.80582830726821,11.69399790719239,11.588008587422813,11.482019267653184,11.3760299478836,11.270040628114018,11.164051308344447,11.058061988574861,10.95207266880528,10.846794526634078,10.747807576018825,10.648820625403584,10.549833674788331,10.450846724173052,10.351859773557793,10.252872822942537,10.153885872327283,10.056642377894425,9.96282074432012,9.868999110745825,9.775177477171521,9.681355843597215,9.587534210022914,9.493712576448596,9.400323895949352,9.313076727426518,9.225829558903662,9.138582390380819,9.051335221857977,8.964088053335145,8.876840884812303,8.791266054221746,8.710954170355,8.63064228648826,8.550330402621512,8.470018518754769,8.389706634888025,8.309394751021259,8.234148922581095,8.159989686346764,8.085830450112443,8.011671213878106,7.937511977643794,7.86335274140949,7.793426441857626,7.724713017513171,7.65599959316873,7.587286168824282,7.518572744479828,7.4488783415506274,7.36643121701927,7.283984092487905,7.201536967956563,7.119089843425204,7.036642718893839,6.9541955943624885,6.8717484698311395,6.789301345299777,6.706854220768427,6.624407096237078,6.541959971705712,6.459512847174362,6.377065722643011,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[62.157047876893316,62.17882096712212,62.20059405735091,62.22236714757971,62.244140237808516,62.265913328037314,62.28768641826611,62.30945950849491,62.33123259872371,62.35300568895251,62.374778779181305,62.39655186941011,62.4183249596389,62.44009804986771,62.461871140096505,62.48364423032531,62.5054173205541,62.52719041078291,62.548963501011706,62.5707365912405,62.5925096814693,62.6142827716981,62.6360558619269,62.657828952155704,62.67960204238449,62.7013751326133,62.7231482228421,62.74492131307089,62.766694403299695,62.78846749352849,62.81024058375729,62.83201367398609,62.85378676421488,62.875559854443686,62.897332944672485,62.91910603490128,62.94087912513009,62.96265221535888,62.984425305587685,63.006198395816476,63.02797148604528,63.04974457627408,63.07151766650288,63.09329075673168,63.115063846960474,63.13683693718928,63.15861002741808,63.180383117646876,63.20215620787567,63.22392929810447,63.24570238833327,63.26747547856207,63.289248568790875,63.311021659019666,63.33279474924847,63.35456783947727,63.37634092970607,63.39811401993487,63.419887110163664,63.44166020039246,63.46343329062126,63.48520638085006,63.50697947107886,63.52875256130766,63.55052565153646,63.57229874176526,63.59407183199406,63.615844922222855,63.63761801245166,63.65939110268045,63.68116419290925,63.70293728313805,63.72471037336685,63.74648346359565,63.76825655382445,63.79002964405325,63.81180273428205,63.833575824510845,63.85534891473965,63.87712200496845,63.899959796304934,63.923329934947176,63.94670007358943,63.97007021223168,63.8698100691822,63.74482386979437,63.61983767040655,63.49485147101872,63.338275372660945,63.18169923147132,63.02512309028169,62.86854694909206,62.711970807902425,62.55539466671279,62.39881852552317,62.24224238433354,62.085666243143905,61.92909010195427,61.77251396076464,61.61593781957502,61.459361678385385,61.30278553719576,61.14620939600613,60.989633254816496,60.83305711362687,60.67648097243724,60.5199048312476,60.36332869005798,60.20675254886834,60.05017640767872,59.89360026648908,59.73702412529945,59.58044798410983,59.42387184292019,59.26729570173057,59.110719560540936,58.954143419351304,58.79756727816168,58.64099113697205,58.484414995782416,58.327838854592784,58.17126271340315,58.01468657221352,57.8581104310239,57.70153428983427,57.54495814864464,57.38838200745501,57.231805866265375,57.075229725075744,56.91865358388612,56.762077442696494,56.60550130150686,56.44892516031723,56.2923490191276,56.13577287793797,55.97919673674834,55.82262059555871,55.66604445436908,55.50946831317945,55.352892171989815,55.19631603080019,55.03973988961056,54.88316374842093,54.72658760723131,54.57001146604166,54.413435324852045,54.256859183662414,54.100283042472775,53.94370690128315,53.78713076009351,53.630554618903886,53.47397847771426,53.31740233652462,53.160826195335,53.00425005414536,52.847673912955734,52.69109777176611,52.53452163057648,52.377945489386846,52.22136934819722,52.06479320700759,51.90821706581796,51.751640924628326,51.5950647834387,51.43848864224906,51.28191250105944,51.12533635986981,50.7459434184591,50.25514207693789,49.76434073541666,49.273539393895426,48.78273805237423,48.29552105875308,47.82765981471236,47.35979857067163,46.891937326630895,46.424076082590176,45.956214838549414,45.488353594508695,45.02049235046796,44.55263110642722,44.0847698623865,43.61690861834577,43.14904737430503,42.68118613026428,42.213324886223546,41.745463642182834,41.27760239814209,40.80974115410135,40.34187991006065,39.874018666019886,39.40615742197917,38.93829617793842,38.470434933897685,38.002573689856966,37.53471244581621,37.06685120177549,36.59898995773475,36.13112871369401,35.6632674696533,35.19540622561256,34.72754498157182,34.259683737531084,33.79182249349034,33.323961249449624,32.85610000540889,32.38823876136814,31.920377517327434,31.45251627328669,30.984655029245953,30.51679378520522,30.04893254116448,29.581071297123746,29.113210053083023,28.645348809042286,28.17748756500155,27.709626320960812,27.241765076920068,26.773903832879352,26.306042588838615,25.83818134479788,25.370320100757137,24.90245885671642,24.43459761267568,23.966736368634947,23.498875124594207,23.031013880553466,22.563152636512754,22.095291392472014,21.627430148431273,21.15956890439054,20.69170766034982,20.22384641630908,19.75598517226834,19.288123928227606,18.820262684186865,18.35240144014615,17.88454019610541,17.41667895206467,16.948817708023935,16.480956463983198,16.013095219942475,15.545233975901743,15.077372731861004,14.609511487820267,14.14165024377955,13.673788999738813,13.205927755698067,12.738066511657335,12.270205267616596,11.978332403547311,11.862447919449442,11.751070936611338,11.645081616841761,11.539092297072175,11.433102977302598,11.327113657532971,11.221124337763387,11.115135017993804,11.009145698224232,10.903703438021669,10.80471648740641,10.70572953679113,10.606742586175876,10.507755635560638,10.408768684945384,10.309781734330105,10.210794783714844,10.11309590867851,10.019274275104209,9.925452641529882,9.831631007955576,9.737809374381282,9.643987740806976,9.55016610723267,9.456344473658369,9.36855210609732,9.281304937574477,9.194057769051643,9.106810600528785,9.019563432005945,8.9323162634831,8.845315026826789,8.76500314296004,8.684691259093274,8.60437937522653,8.524067491359789,8.44375560749304,8.363443723626299,8.28660328696307,8.212444050728733,8.138284814494433,8.064125578260102,7.98996634202578,7.915807105791442,7.844194909021674,7.775481484677212,7.706768060332781,7.638054635988325,7.569341211643883,7.500627787299437,7.422104577107216,7.339657452575859,7.257210328044501,7.174763203513136,7.092316078981794,7.009868954450436,6.927421829919071,6.84497470538772,6.76252758085637,6.680080456325009,6.597633331793658,6.515186207262309,6.432739082730944,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[61.98718604918173,62.008959139410535,62.03073222963933,62.052505319868125,62.07427841009692,62.09605150032573,62.11782459055453,62.139597680783325,62.161370771012116,62.18314386124092,62.20491695146972,62.226690041698525,62.248463131927316,62.270236222156115,62.29200931238491,62.31378240261372,62.335555492842516,62.357328583071315,62.37910167330011,62.40087476352892,62.42264785375771,62.444420943986515,62.46619403421531,62.48796712444411,62.50974021467291,62.53151330490171,62.553286395130506,62.575059485359304,62.59683257558811,62.6186056658169,62.640378756045706,62.6621518462745,62.6839249365033,62.705698026732094,62.7274711169609,62.74924420718969,62.771017297418496,62.7927903876473,62.81456347787609,62.8363365681049,62.85810965833369,62.879882748562494,62.901655838791285,62.92342892902009,62.94520201924888,62.96697510947769,62.98874819970649,63.010521289935284,63.032294380164075,63.05406747039288,63.075840560621685,63.09761365085048,63.11938674107928,63.14115983130807,63.16293292153688,63.184706011765684,63.206479101994475,63.22825219222328,63.25002528245207,63.27179837268088,63.29357146290967,63.31534455313847,63.33711764336728,63.35889073359607,63.380663823824875,63.402436914053666,63.42421000428247,63.44598309451126,63.46775618474007,63.48952927496886,63.511302365197665,63.53189597630306,63.55131010188814,63.57072422747323,63.59013835305832,63.60955247864341,63.628966604228495,63.64838072981359,63.66779485539867,63.68720898098376,63.70662310656885,63.726037232153935,63.74545135773903,63.764865483324115,63.61105172074152,63.42259238052538,63.23413304030926,63.045673700093126,62.857214359877,62.66875501966088,62.48029567944475,62.29183633922862,62.10337699901249,61.914917658796355,61.726458318580235,61.53799897836411,61.35485354788186,61.19827740669222,61.04170126550259,60.885125124312964,60.72854898312333,60.57197284193371,60.415396700744076,60.258820559554444,60.10224441836482,59.94566827717519,59.789092135985555,59.63251599479593,59.47593985360629,59.31936371241667,59.162787571227035,59.0062114300374,58.849635288847786,58.69305914765815,58.536483006468515,58.37990686527888,58.22333072408925,58.06675458289963,57.910178441709995,57.75360230052036,57.59702615933073,57.4404500181411,57.283873876951475,57.12729773576185,56.97072159457222,56.814145453382594,56.65756931219296,56.50099317100333,56.3444170298137,56.187840888624066,56.03126474743444,55.8746886062448,55.71811246505518,55.561536323865546,55.40496018267592,55.24838404148629,55.09180790029666,54.935231759107026,54.778655617917394,54.62207947672776,54.46550333553814,54.30892719434851,54.15235105315888,53.99577491196926,53.83919877077962,53.682622629589986,53.526046488400354,53.36947034721072,53.212894206021105,53.05631806483146,52.89974192364184,52.74316578245221,52.58658964126257,52.430013500072945,52.27343735888331,52.11686121769368,51.96028507650405,51.80370893531442,51.6471327941248,51.49055665293517,51.33398051174554,51.177404370555905,51.02082822936627,50.864252088176656,50.707675946987024,50.551099805797385,50.39452366460776,50.03386208090714,49.571157775951065,49.10845347099497,48.64574916603887,48.18304486108279,47.720340556126665,47.257636251170595,46.7949319462145,46.332227641258406,45.869523336302336,45.40681903134622,44.94411472639014,44.481410421434035,44.018706116477944,43.55600181152187,43.09329750656576,42.63059320160967,42.16788889665357,41.705184591697474,41.242480286741404,40.7797759817853,40.31707167682921,39.85436737187313,39.39166306691701,38.928958761960935,38.46625445700484,38.003550152048746,37.54084584709267,37.07814154213655,36.61543723718047,36.152732932224374,35.690028627268276,35.22732432231221,34.7646200173561,34.3019157124,33.839211407443905,33.376507102487814,32.91380279753174,32.45109849257564,31.98839418761954,31.525689882663464,31.06298557770737,30.600281272751275,30.137576967795177,29.67487266283908,29.21216835788298,28.749464052926903,28.286759747970805,27.82405544301471,27.361351138058613,26.898646833102518,26.43594252814644,25.973238223190343,25.510533918234245,25.047829613278147,24.585125308322077,24.12242100336598,23.65971669840988,23.197012393453782,22.734308088497684,22.271603783541607,21.808899478585513,21.346195173629415,20.88349086867332,20.420786563717243,19.958082258761145,19.495377953805047,19.03267364884895,18.569969343892854,18.10726503893678,17.644560733980683,17.181856429024585,16.719152124068486,16.256447819112392,15.793743514156317,15.331039209200219,14.868334904244122,14.405630599288024,13.942926294331944,13.480221989375847,13.01751768441975,12.554813379463653,12.092109074507558,11.808143966030284,11.702154646260702,11.596165326491125,11.490176006721546,11.384186686951963,11.278197367182385,11.172208047412756,11.066218727643173,10.960612349409256,10.861625398794008,10.762638448178723,10.663651497563464,10.564664546948183,10.465677596332931,10.36669064571769,10.267703695102437,10.16954943946257,10.075727805888263,9.981906172313966,9.888084538739665,9.794262905165338,9.700441271591032,9.606619638016738,9.512798004442432,9.424027484768118,9.336780316245283,9.249533147722445,9.162285979199602,9.075038810676768,8.987791642153912,8.900544473631069,8.819052115565054,8.738740231698317,8.658428347831569,8.578116463964804,8.497804580098059,8.417492696231317,8.339057651345037,8.264898415110721,8.190739178876406,8.116579942642069,8.04242070640777,7.968261470173437,7.89496337618571,7.826249951841264,7.7575365274968275,7.688823103152367,7.6201096788079346,7.551396254463478,7.47777793719515,7.395330812663797,7.312883688132448,7.23043656360109,7.1479894390697325,7.065542314538368,6.983095190007026,6.900648065475667,6.818200940944301,6.735753816412952,6.653306691881602,6.57085956735024,6.488412442818889,6.4059653182875405,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[61.81787277681106,61.83964586703986,61.861418957268654,61.88319204749745,61.90496513772625,61.926738227955056,61.948511318183854,61.97028440841265,61.992057498641444,62.01383058887025,62.035603679099054,62.057376769327846,62.07914985955664,62.10092294978544,62.12269604001425,62.14446913024305,62.166242220471844,62.18801531070065,62.20978840092944,62.231561491158246,62.25333458138704,62.27510767161584,62.29688076184464,62.31865385207344,62.34042694230224,62.362200032531035,62.383973122759826,62.40574621298864,62.42751930321743,62.44929239344623,62.471065483675034,62.492838573903825,62.51461166413264,62.53638475436142,62.55815784459023,62.57993093481902,62.60170402504782,62.62347711527663,62.64525020550542,62.667023295734225,62.688796385963016,62.71056947619182,62.73234256642061,62.75411565664942,62.77588874687822,62.797661837107015,62.81943492733582,62.84120801756461,62.862981107793416,62.88475419802221,62.90652728825101,62.928300378479804,62.95007346870861,62.971846558937415,62.993619649166206,63.013033777560516,63.03244790314561,63.051862028730696,63.071276154315775,63.09069027990087,63.110104405485956,63.12951853107104,63.148932656656136,63.168346782241215,63.1877609078263,63.207175033411396,63.22658915899648,63.24600328458157,63.26541741016666,63.28483153575174,63.304245661336836,63.32365978692192,63.34307391250701,63.362488038092096,63.38190216367719,63.40131628926227,63.42073041484736,63.440144540432456,63.459558666017536,63.47897279160263,63.498386917187716,63.517801042772795,63.53721516835789,63.556629293942976,63.40281553136038,63.21435619114425,63.02589685092813,62.83743751071199,62.648978170495866,62.46051883027974,62.27205949006361,62.08360014984748,61.89514080963136,61.70668146941522,61.5182221291991,61.32976278898297,61.14130344876684,60.95284410855071,60.76438476833458,60.57592542811846,60.38746608790233,60.1990067476862,60.01054740747007,59.822088067253944,59.633628727037824,59.44516938682169,59.25671004660556,59.06825070638944,58.8797913661733,58.69133202595718,58.50287268574105,58.314413345524926,58.1259540053088,57.95875016907909,57.80217402788947,57.64559788669984,57.4890217455102,57.33244560432057,57.17586946313094,57.019293321941305,56.86271718075167,56.70614103956204,56.549564898372424,56.39298875718279,56.23641261599316,56.07983647480354,55.9232603336139,55.76668419242427,55.61010805123464,55.45353191004501,55.29695576885538,55.140379627665745,54.98380348647613,54.827227345286495,54.670651204096856,54.51407506290724,54.35749892171761,54.200922780527975,54.04434663933834,53.88777049814871,53.73119435695908,53.574618215769455,53.41804207457982,53.2614659333902,53.10488979220056,52.948313651010935,52.7917375098213,52.63516136863167,52.47858522744205,52.32200908625241,52.16543294506279,52.00885680387315,51.85228066268352,51.695704521493894,51.539128380304255,51.38255223911463,51.225976097925,51.06939995673537,50.91282381554574,50.75624767435611,50.599671533166486,50.443095391976854,50.28651925078722,50.12994310959759,49.97336696840796,49.816790827218334,49.66021468602871,49.299553102328076,48.83684879737201,48.37414449241591,47.91144018745982,47.44873588250374,46.986031577547614,46.523327272591544,46.060622967635446,45.59791866267935,45.13521435772327,44.67251005276715,44.20980574781108,43.747101442854984,43.284397137898885,42.82169283294281,42.35898852798671,41.89628422303062,41.433579918074514,40.97087561311842,40.508171308162346,40.04546700320624,39.58276269825015,39.12005839329407,38.65735408833796,38.19464978338188,37.731945478425786,37.26924117346969,36.80653686851362,36.3438325635575,35.88112825860142,35.418423953645316,34.955719648689225,34.49301534373315,34.03031103877704,33.56760673382095,33.10490242886485,32.642198123908756,32.179493818952686,31.71678951399658,31.254085209040486,30.791380904084413,30.328676599128315,29.865972294172217,29.40326798921612,28.940563684260024,28.477859379303926,28.015155074347845,27.552450769391754,27.089746464435652,26.627042159479558,26.16433785452346,25.701633549567383,25.238929244611285,24.77622493965519,24.313520634699096,23.85081632974302,23.38811202478692,22.925407719830826,22.462703414874724,21.999999109918633,21.537294804962556,21.074590500006455,20.61188619505036,20.149181890094262,19.715485929189494,19.28255333927627,18.84962074936304,18.416688159449812,17.983755569536587,17.550822979623383,17.117890389710155,16.68495779979693,16.2520252098837,15.819092619970474,15.386160030057269,14.953227440144042,14.520294850230814,14.087362260317589,13.65442967040438,13.221497080491151,12.788564490577924,12.355631900664697,11.922699310751472,11.653238355910085,11.5472490361405,11.441259716370926,11.335270396601347,11.229281076831763,11.123291757062184,11.017521260796842,10.918534310181585,10.819547359566322,10.720560408951073,10.621573458335789,10.52258650772053,10.423599557105248,10.324612606489996,10.226002970246656,10.132181336672335,10.038359703098035,9.944538069523729,9.85071643594943,9.75689480237513,9.663073168800802,9.569251535226496,9.47950286343896,9.392255694916116,9.305008526393253,9.217761357870417,9.130514189347581,9.043267020824738,8.956019852301901,8.873101088170108,8.79278920430336,8.712477320436593,8.632165436569856,8.551853552703108,8.471541668836341,8.391512015727034,8.317352779492703,8.243193543258382,8.169034307024065,8.09487507078975,8.020715834555412,7.946556598321113,7.877018419005317,7.808304994660872,7.739591570316426,7.670878145971989,7.6021647216275285,7.533451297283096,7.4510041727517455,7.3685570482203895,7.286109923689038,7.203662799157687,7.121215674626329,7.0387685500949715,6.956321425563607,6.873874301032265,6.791427176500907,6.708980051969541,6.626532927438191,6.544085802906841,6.461638678375479,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[61.64855950444037,61.67033259466916,61.69210568489797,61.713878775126766,61.735651865355564,61.75742495558437,61.77919804581316,61.800971136041966,61.82274422627077,61.844517316499555,61.86629040672836,61.88806349695716,61.90983658718596,61.931609677414755,61.95338276764356,61.97515585787236,61.99692894810115,62.018702038329955,62.040475128558754,62.06224821878756,62.08402130901635,62.10579439924515,62.127567489473954,62.14934057970275,62.17111366993155,62.19288676016035,62.21465985038915,62.236432940617945,62.25820603084675,62.27997912107554,62.30175221130435,62.323525301533145,62.34529839176194,62.36707148199074,62.38884457221954,62.41061766244834,62.43239075267714,62.45416384290594,62.474757453232876,62.49417157881797,62.51358570440305,62.53299982998814,62.55241395557323,62.571828081158316,62.5912422067434,62.61065633232849,62.630070457913575,62.64948458349867,62.668898709083756,62.688312834668835,62.70772696025393,62.72714108583902,62.74655521142411,62.765969337009196,62.78538346259428,62.80479758817937,62.824211713764456,62.84362583934954,62.86303996493463,62.88245409051972,62.901868216104816,62.921282341689896,62.94069646727498,62.960110592860076,62.97952471844516,62.99893884403025,63.018352969615336,63.03776709520043,63.057181220785516,63.07659534637061,63.09600947195569,63.115423597540776,63.13483772312587,63.154251848710956,63.17366597429604,63.193080099881136,63.212494225466216,63.2319083510513,63.251322476636396,63.270736602221476,63.29015072780657,63.309564853391656,63.32897897897675,63.348393104561836,63.194579341979235,63.006120001763094,62.817660661546974,62.62920132133085,62.44074198111472,62.2522826408986,62.06382330068246,61.875363960466345,61.6869046202502,61.498445280034076,61.309985939817956,61.12152659960182,60.933067259385695,60.74460791916957,60.55614857895344,60.36768923873731,60.179229898521186,59.99077055830506,59.802311218088924,59.61385187787279,59.42539253765668,59.23693319744055,59.04847385722441,58.86001451700829,58.671555176792154,58.48309583657603,58.294636496359914,58.10617715614377,57.91771781592765,57.72925847571151,57.54079913549539,57.35233979527926,57.163880455063136,56.97542111484701,56.78696177463088,56.59850243441475,56.41004309419863,56.221583753982486,56.033124413766366,55.844665073550246,55.656205733334104,55.46774639311799,55.27928705290185,55.09082771268573,54.902368372469596,54.71922293146589,54.562646790276276,54.40607064908664,54.24949450789701,54.09291836670738,53.93634222551775,53.77976608432813,53.6231899431385,53.46661380194886,53.31003766075923,53.153461519569596,52.99688537837997,52.84030923719035,52.683733096000715,52.52715695481108,52.37058081362145,52.21400467243182,52.057428531242195,51.90085239005256,51.74427624886293,51.58770010767329,51.43112396648367,51.27454782529404,51.11797168410441,50.96139554291479,50.80481940172515,50.64824326053552,50.49166711934589,50.33509097815626,50.17851483696664,50.021938695777,49.86536255458737,49.70878641339774,49.55221027220811,49.39563413101848,49.23905798982885,49.08248184863922,48.925905707449594,48.56524412374897,48.10253981879289,47.6398355138368,47.1771312088807,46.71442690392462,46.251722598968506,45.789018294012436,45.32631398905633,44.86360968410024,44.40090537914416,43.93820107418804,43.47549676923197,43.012792464275876,42.55008815931977,42.087383854363694,41.6246795494076,41.161975244451504,40.699270939495406,40.236566634539315,39.77386232958324,39.31115802462713,38.84845371967104,38.385749414714965,37.923045109758846,37.46034080480277,36.997636499846664,36.53493219489057,36.0722278899345,35.60952358497838,35.14681928002231,34.6841149750662,34.22141067011011,33.75870636515403,33.296002060197935,32.833297755241844,32.37059345028574,31.907889145329648,31.445184840373575,30.98248053541747,30.51977623046137,30.057071925505298,29.5943676205492,29.131663315593105,28.668959010637007,28.21923211733371,27.786299527420486,27.353366937507282,26.920434347594053,26.487501757680825,26.0545691677676,25.62163657785437,25.188703987941167,24.75577139802794,24.322838808114714,23.88990621820149,23.45697362828828,23.024041038375053,22.591108448461824,22.158175858548603,21.725243268635374,21.292310678722167,20.85937808880894,20.426445498895713,19.99351290898249,19.56058031906928,19.127647729156052,18.694715139242827,18.261782549329602,17.828849959416374,17.395917369503167,16.96298477958994,16.530052189676717,16.097119599763488,15.664187009850263,15.231254419937057,14.798321830023829,14.365389240110602,13.932456650197377,13.499524060284166,13.06659147037094,12.633658880457713,12.200726290544488,11.76779370063126,11.498332745789872,11.392343426020286,11.286354106250709,11.180364786481134,11.074430172184407,10.975443221569153,10.876456270953897,10.777469320338636,10.678482369723376,10.579495419108126,10.480508468492841,10.381521517877582,10.282534567262303,10.188634867456415,10.094813233882109,10.000991600307788,9.90716996673349,9.813348333159182,9.719526699584884,9.625705066010584,9.534978242109776,9.447731073586914,9.360483905064083,9.273236736541241,9.185989568018378,9.098742399495544,9.011495230972706,8.927150060775123,8.84683817690838,8.766526293041636,8.68621440917489,8.605902525308123,8.525590641441385,8.445278757574638,8.369807143874686,8.295647907640369,8.221488671406037,8.147329435171716,8.0731701989374,7.999010962703085,7.927786886169369,7.859073461824914,7.790360037480472,7.721646613136025,7.652933188791581,7.584219764447144,7.506677532839686,7.424230408308328,7.341783283776977,7.25933615924562,7.176889034714268,7.094441910182919,7.011994785651561,6.929547661120203,6.847100536588838,6.764653412057497,6.682206287526138,6.599759162994773,6.517312038463422,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[61.479246232069684,61.50101932229849,61.52279241252728,61.54456550275608,61.566338592984884,61.588111683213675,61.609884773442474,61.63165786367128,61.65343095390007,61.67520404412888,61.69697713435768,61.71875022458647,61.74052331481527,61.762296405044076,61.784069495272874,61.80584258550167,61.82761567573047,61.849388765959276,61.87116185618807,61.89293494641687,61.91470803664566,61.93648112687447,61.955895254490315,61.9753093800754,61.99472350566049,62.01413763124558,62.03355175683066,62.05296588241575,62.07238000800084,62.09179413358592,62.111208259171015,62.13062238475611,62.15003651034119,62.16945063592628,62.18886476151136,62.208278887096455,62.22769301268154,62.24710713826663,62.266521263851715,62.28593538943681,62.305349515021895,62.324763640606974,62.34417776619207,62.36359189177716,62.38300601736224,62.40242014294733,62.42183426853242,62.44124839411751,62.460662519702595,62.48007664528768,62.49949077087277,62.518904896457855,62.53831902204294,62.557733147628035,62.57714727321313,62.596561398798215,62.615975524383295,62.63538964996839,62.654803775553475,62.67421790113856,62.69363202672365,62.71304615230874,62.73246027789382,62.751874403478915,62.771288529064,62.790702654649095,62.81011678023418,62.82953090581926,62.848945031404355,62.86835915698944,62.88777328257453,62.907187408159615,62.92660153374471,62.94601565932979,62.96542978491488,62.98484391049997,63.004258036085055,63.02367216167015,63.043086287255235,63.06250041284032,63.08191453842541,63.101328664010495,63.12074278959559,63.140156915180675,62.98634315259809,62.79788381238195,62.60942447216582,62.4209651319497,62.232505791733566,62.044046451517445,61.85558711130131,61.667127771085184,61.47866843086905,61.29020909065293,61.10174975043681,60.913290410220675,60.72483107000454,60.536371729788414,60.34791238957228,60.15945304935616,59.97099370914003,59.782534368923905,59.59407502870778,59.40561568849164,59.21715634827552,59.02869700805939,58.84023766784326,58.65177832762714,58.463318987411,58.27485964719489,58.08640030697875,57.897940966762626,57.709481626546506,57.521022286330364,57.33256294611425,57.14410360589811,56.95564426568198,56.76718492546586,56.57872558524973,56.3902662450336,56.201806904817474,56.01334756460135,55.82488822438522,55.63642888416909,55.447969543952965,55.25951020373684,55.0710508635207,54.88259152330458,54.69413218308844,54.505672842872315,54.3172135026562,54.12875416244006,53.94029482222394,53.751835482007806,53.56337614179168,53.37491680157555,53.186457461359424,52.99799812114329,52.80953878092717,52.62107944071103,52.432620100494916,52.24416076027879,52.055701420062654,51.86724207984653,51.67878273963039,51.490323399414265,51.32311955266308,51.16654341147345,51.00996727028382,50.85339112909418,50.69681498790455,50.54023884671493,50.383662705525296,50.22708656433567,50.07051042314603,49.91393428195641,49.757358140766776,49.600781999577144,49.44420585838753,49.28762971719789,49.131053576008256,48.974477434818624,48.81790129362899,48.66132515243937,48.504749011249736,48.348172870060104,48.191596728870486,47.83093514516986,47.368230840213776,46.90552653525768,46.44282223030159,45.98011792534551,45.51741362038939,45.054709315433314,44.59200501047722,44.12930070552113,43.666596400565055,43.203892095608936,42.74118779065285,42.27848348569675,41.815779180740655,41.35307487578458,40.89037057082849,40.427666265872396,39.9649619609163,39.5022576559602,39.03955335100412,38.57684904604802,38.11414474109193,37.65144043613585,37.18873613117973,36.726031826223654,36.290045715564716,35.8571131256515,35.424180535738294,34.991247945825044,34.55831535591184,34.12538276599861,33.69245017608539,33.25951758617218,32.82658499625895,32.39365240634572,31.960719816432494,31.527787226519276,31.09485463660607,30.661922046692837,30.228989456779612,29.7960568668664,29.363124276953176,28.93019168703995,28.497259097126726,28.064326507213497,27.631393917300272,27.198461327387065,26.76552873747384,26.33259614756061,25.899663557647386,25.466730967734158,25.033798377820954,24.60086578790773,24.1679331979945,23.735000608081272,23.302068018168065,22.86913542825484,22.436202838341615,22.003270248428386,21.57033765851516,21.137405068601954,20.70447247868873,20.2715398887755,19.838607298862275,19.405674708949068,18.972742119035843,18.539809529122614,18.10687693920939,17.673944349296164,17.241011759382957,16.80807916946973,16.375146579556503,15.942213989643275,15.50928139973005,15.076348809816844,14.643416219903617,14.210483629990389,13.777551040077164,13.344618450163953,12.911685860250726,12.4787532703375,12.045820680424274,11.612888090511047,11.343427135669659,11.237437815900075,11.131448496130497,11.032352132956722,10.933365182341463,10.834378231726207,10.735391281110951,10.636404330495692,10.537417379880429,10.438430429265182,10.339443478649896,10.245088398240469,10.151266764666168,10.05744513109187,9.963623497517563,9.869801863943245,9.775980230368944,9.682158596794638,9.59045362078058,9.503206452257745,9.415959283734903,9.32871211521204,9.24146494668921,9.154217778166368,9.066970609643505,8.981199033380161,8.90088714951342,8.820575265646655,8.740263381779911,8.659951497913168,8.579639614046421,8.499327730179653,8.422261508256664,8.348102272022343,8.273943035788022,8.199783799553705,8.125624563319374,8.051465327085054,7.978555353333413,7.90984192898897,7.841128504644525,7.772415080300069,7.703701655955627,7.634988231611182,7.562350892927625,7.479903768396282,7.397456643864917,7.315009519333559,7.232562394802208,7.150115270270852,7.067668145739501,6.985221021208151,6.902773896676793,6.820326772145435,6.737879647614069,6.655432523082728,6.57298539855137,6.490538274020005,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[61.30993295969901,61.33170604992781,61.35347914015661,61.37525223038541,61.397025320614205,61.41761893016269,61.43703305574777,61.456447181332855,61.47586130691795,61.495275432503036,61.51468955808813,61.534103683673216,61.553517809258295,61.57293193484339,61.592346060428476,61.61176018601357,61.631174311598656,61.650588437183735,61.67000256276883,61.689416688353916,61.708830813939,61.72824493952409,61.74765906510918,61.76707319069426,61.78648731627935,61.80590144186445,61.825315567449536,61.84472969303461,61.86414381861971,61.883557944204796,61.90297206978988,61.922386195374976,61.941800320960056,61.961214446545156,61.980628572130236,62.00004269771532,62.01945682330041,62.038870948885496,62.05828507447059,62.077699200055676,62.09711332564076,62.11652745122585,62.135941576810936,62.15535570239603,62.174769827981116,62.194183953566196,62.21359807915129,62.23301220473638,62.25242633032147,62.271840455906556,62.29125458149164,62.310668707076736,62.33008283266182,62.3494969582469,62.368911083831996,62.38832520941708,62.40773933500218,62.42715346058726,62.44656758617235,62.465981711757436,62.48539583734252,62.50480996292761,62.5242240885127,62.54363821409779,62.563052339682876,62.58246646526796,62.60188059085305,62.621294716438136,62.64070884202323,62.66012296760832,62.6795370931934,62.69895121877849,62.718365344363576,62.73777946994866,62.75719359553376,62.77660772111884,62.79602184670393,62.81543597228902,62.8348500978741,62.8542642234592,62.87367834904428,62.89309247462937,62.91250660021446,62.93192072579954,62.77810696321695,62.589647623000815,62.40118828278469,62.21272894256855,62.024269602352426,61.83581026213631,61.64735092192018,61.45889158170405,61.27043224148792,61.08197290127178,60.89351356105567,60.70505422083954,60.51659488062341,60.328135540407274,60.13967620019115,59.951216859975034,59.7627575197589,59.574298179542765,59.385838839326645,59.19737949911051,59.008920158894384,58.82046081867826,58.63200147846212,58.44354213824601,58.255082798029875,58.06662345781375,57.87816411759761,57.68970477738148,57.501245437165366,57.312786096949225,57.124326756733105,56.93586741651697,56.74740807630084,56.55894873608473,56.370489395868596,56.18203005565246,55.993570715436334,55.80511137522021,55.61665203500409,55.42819269478795,55.239733354571825,55.05127401435571,54.86281467413957,54.674355333923444,54.48589599370732,54.29743665349119,54.10897731327506,53.92051797305893,53.73205863284281,53.543599292626666,53.355139952410546,53.166680612194426,52.97822127197829,52.789761931762165,52.60130259154603,52.4128432513299,52.22438391111379,52.03592457089765,51.84746523068152,51.6590058904654,51.47054655024926,51.28208721003314,51.09362786981701,50.90516852960088,50.71670918938476,50.52824984916862,50.339790508952504,50.15133116873637,49.96287182852024,49.774412488304115,49.58595314808798,49.397493807871854,49.209034467655734,49.0205751274396,48.83211578722348,48.643656447007345,48.45519710679122,48.26673776657509,48.083592315049934,47.92701617386031,47.77044003267068,47.613863891481046,47.45728775029143,47.0966261665908,46.633921861634725,46.17121755667863,45.708513251722536,45.24580894676646,44.79379190370895,44.36085931379575,43.92792672388252,43.4949941339693,43.062061544056085,42.62912895414284,42.196196364229635,41.763263774316414,41.33033118440318,40.89739859448998,40.46446600457675,40.03153341466353,39.59860082475029,39.16566823483707,38.732735644923864,38.299803055010635,37.866870465097406,37.4339378751842,37.001005285270956,36.568072695357756,36.13514010544452,35.7022075155313,35.26927492561809,34.83634233570485,34.403409745791635,33.970477155878406,33.53754456596519,33.10461197605198,32.67167938613875,32.23874679622553,31.805814206312295,31.372881616399077,30.939949026485866,30.507016436572634,30.07408384665941,29.641151256746202,29.208218666832973,28.775286076919752,28.342353487006523,27.909420897093298,27.47648830718007,27.043555717266866,26.610623127353637,26.177690537440412,25.744757947527184,25.31182535761396,24.878892767700755,24.445960177787526,24.013027587874298,23.580094997961073,23.147162408047866,22.71422981813464,22.281297228221412,21.848364638308187,21.415432048394962,20.982499458481755,20.549566868568526,20.116634278655297,19.683701688742076,19.25076909882887,18.81783650891564,18.38490391900241,17.95197132908919,17.51903873917596,17.086106149262754,16.653173559349526,16.2202409694363,15.787308379523076,15.354375789609849,14.921443199696643,14.488510609783415,14.055578019870188,13.622645429956963,13.189712840043752,12.756780250130525,12.323847660217298,11.890915070304072,11.457982480390847,11.188521525549458,11.089261044344317,10.990274093729067,10.891287143113784,10.792300192498525,10.69331324188327,10.594326291268015,10.495339340652754,10.396352390037494,10.301541929024568,10.20772029545024,10.113898661875934,10.020077028301634,9.926255394727336,9.83243376115303,9.738612127578708,9.645928999451394,9.558681830928553,9.471434662405715,9.38418749388288,9.296940325360035,9.209693156837174,9.122445988314343,9.03524800598517,8.954936122118442,8.874624238251698,8.794312354384957,8.71400047051819,8.633688586651447,8.553376702784703,8.474715872638658,8.40055663640432,8.326397400170007,8.252238163935688,8.178078927701367,8.10391969146705,8.029760455232719,7.960610396153029,7.891896971808572,7.823183547464131,7.7544701231196855,7.685756698775229,7.617043274430787,7.5355771284842294,7.453130003952872,7.370682879421529,7.288235754890163,7.205788630358806,7.123341505827455,7.0408943812960985,6.958447256764748,6.876000132233397,6.79355300770204,6.711105883170682,6.628658758639316,6.546211634107975,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[61.13098767278659,61.15040179837169,61.16981592395676,61.189230049541855,61.208644175126956,61.228058300712036,61.24747242629712,61.26688655188221,61.286300677467295,61.30571480305239,61.325128928637476,61.34454305422256,61.36395717980765,61.38337130539274,61.40278543097783,61.422199556562916,61.441613682148,61.461027807733096,61.480441933318176,61.499856058903276,61.51927018448835,61.53868431007345,61.55809843565852,61.577512561243616,61.5969266868287,61.61634081241379,61.63575493799888,61.65516906358396,61.674583189169056,61.69399731475416,61.71341144033923,61.73282556592433,61.75223969150941,61.7716538170945,61.79106794267959,61.810482068264676,61.82989619384976,61.84931031943485,61.86872444501994,61.88813857060502,61.907552696190116,61.9269668217752,61.94638094736028,61.965795072945376,61.98520919853046,62.004623324115556,62.024037449700636,62.04345157528573,62.062865700870816,62.0822798264559,62.10169395204099,62.12110807762608,62.14052220321116,62.15993632879625,62.17935045438134,62.19876457996643,62.21817870555152,62.23759283113661,62.257006956721696,62.27642108230678,62.29583520789187,62.315249333476956,62.33466345906205,62.354077584647136,62.37349171023222,62.3929058358173,62.412319961402396,62.43173408698748,62.451148212572576,62.47056233815766,62.48997646374275,62.50939058932783,62.52668846589874,62.54356309104902,62.5604377161993,62.57731234134959,62.594186966499876,62.611061591650156,62.62793621680044,62.64481084195073,62.661685467101016,62.678560092251296,62.695434717401575,62.71230934255186,62.53269470763647,62.31378222070795,62.09486973377944,61.87595724685092,61.65704475992241,61.4381322729939,61.21921978606537,61.00030729913686,60.78139481220833,60.56248232527982,60.34356983835131,60.12465735142279,59.93112250292124,59.74266316270511,59.55420382248897,59.36574448227285,59.177285142056725,58.98882580184059,58.80036646162447,58.611907121408336,58.423447781192216,58.23498844097608,58.046529100759955,57.85806976054383,57.6696104203277,57.48115108011157,57.292691739895446,57.10423239967931,56.91577305946319,56.72731371924705,56.53885437903094,56.3503950388148,56.161935698598676,55.973476358382555,55.78501701816642,55.59655767795029,55.40809833773417,55.21963899751803,55.03117965730191,54.84272031708578,54.65426097686965,54.46580163665353,54.277342296437396,54.08888295622127,53.90042361600514,53.711964275789015,53.52350493557289,53.33504559535675,53.14658625514063,52.9581269149245,52.76966757470837,52.58120823449225,52.39274889427612,52.20428955406,52.01583021384386,51.82737087362773,51.638911533411616,51.450452193195474,51.26199285297935,51.07353351276323,50.88507417254709,50.69661483233097,50.50815549211484,50.31969615189871,50.13123681168259,49.94277747146646,49.75431813125033,49.5658587910342,49.37739945081806,49.18894011060195,49.000480770385806,48.812021430169686,48.62356208995355,48.435102749737425,48.24664340952131,48.05818406930518,47.86972472908905,47.681265388872916,47.49280604865679,47.30434670844066,47.11588736822454,46.92742802800841,46.73896868779229,46.40759654328045,46.00476799662079,45.601939449961115,45.19911090330145,44.79628235664179,44.39345380998209,43.99062526332245,43.587796716662766,43.184968170003096,42.78213962334344,42.37931107668374,41.97648253002409,41.573653983364416,41.17082543670474,40.75255888947999,40.319626299566764,39.88669370965354,39.45376111974031,39.020828529827085,38.58789593991388,38.154963350000656,37.72203076008742,37.28909817017421,36.85616558026097,36.42323299034777,35.990300400434535,35.55736781052131,35.124435220608106,34.69150263069486,34.258570040781656,33.82563745086843,33.392704860955206,32.95977227104199,32.52683968112876,32.09390709121554,31.660974501302313,31.22804191138909,30.79510932147588,30.362176731562656,29.929244141649427,29.496311551736216,29.06337896182299,28.630446371909766,28.19751378199654,27.764581192083313,27.331648602170084,26.89871601225688,26.465783422343655,26.032850832430427,25.599918242517198,25.166985652603973,24.73405306269077,24.30112047277754,23.868187882864312,23.435255292951087,23.00232270303788,22.569390113124655,22.136457523211426,21.7035249332982,21.270592343384976,20.83765975347177,20.40472716355854,19.97179457364531,19.538861983732087,19.10592939381888,18.672996803905654,18.240064213992426,17.8071316240792,17.374199034165976,16.94126644425277,16.50833385433954,16.075401264426315,15.642468674513088,15.209536084599861,14.776603494686654,14.343670904773429,13.910738314860202,13.477805724946975,13.044873135033765,12.611940545120538,12.179007955207311,11.746075365294086,11.313142775380859,11.047183005116633,10.948196054501372,10.849209103886118,10.750222153270839,10.65123520265558,10.552248252040325,10.453261301425067,10.357995459808622,10.264173826234295,10.170352192660024,10.076530559085697,9.98270892551139,9.88888729193709,9.795065658362791,9.701404378122211,9.614157209599355,9.526910041076519,9.439662872553678,9.35241570403084,9.265168535508003,9.177921366985162,9.090674198462297,9.008985094723467,8.9286732108567,8.84836132698997,8.768049443123228,8.687737559256487,8.60742567538972,8.527170237020613,8.453011000786315,8.378851764551992,8.304692528317656,8.230533292083344,8.156374055849025,8.082214819614702,8.01137886331707,7.942665438972614,7.873952014628183,7.805238590283727,7.736525165939285,7.667811741594839,7.591250488572176,7.508803364040825,7.42635623950946,7.343909114978103,7.261461990446761,7.179014865915395,7.096567741384036,7.014120616852686,6.93167349232133,6.849226367789979,6.766779243258628,6.684332118727271,6.601884994195912,6.519437869664548,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[60.9484303797027,60.967844505287786,60.98725863087287,61.00667275645796,61.02608688204305,61.04550100762814,61.064915133213226,61.084329258798306,61.10374338438341,61.12315750996849,61.14257163555357,61.161985761138666,61.181399886723746,61.20081401230884,61.22022813789393,61.23964226347901,61.259056389064106,61.27847051464919,61.29788464023429,61.31729876581937,61.33671289140446,61.35612701698955,61.375541142574626,61.39495526815972,61.414369393744806,61.4337835193299,61.453197644914994,61.472611770500066,61.49202589608516,61.51144002167025,61.53085414725534,61.55026827284043,61.56968239842551,61.5890965240106,61.60851064959569,61.62792477518077,61.64733890076587,61.666753026350946,61.68616715193605,61.70558127752112,61.72499540310621,61.74440952869131,61.76382365427639,61.78323777986148,61.80265190544657,61.82206603103165,61.84148015661674,61.86089428220183,61.88030840778691,61.899722533372,61.91913665895709,61.93855078454218,61.957964910127274,61.97737903571235,61.99679316129744,62.01536078766673,62.03223541281702,62.049110037967296,62.065984663117575,62.08285928826787,62.09973391341815,62.11660853856844,62.133483163718715,62.150357788868995,62.16723241401928,62.184107039169575,62.200981664319855,62.21785628947014,62.23473091462043,62.25160553977071,62.268480164920994,62.285354790071274,62.30222941522156,62.319104040371855,62.335978665522134,62.352853290672414,62.3697279158227,62.38660254097299,62.40347716612327,62.420351791273546,62.43722641642384,62.45410104157412,62.4709756667244,62.48785029187469,62.3082356569593,62.08932317003078,61.870410683102264,61.65149819617375,61.43258570924523,61.213673222316714,60.9947607353882,60.77584824845968,60.556935761531165,60.33802327460264,60.11911078767413,59.900198300745615,59.6812858138171,59.46237332688858,59.24346083996006,59.02454835303155,58.80563586610303,58.586723379174515,58.367810892246,58.14889840531747,57.929985918388965,57.71107343146044,57.492160944531925,57.273248457603415,57.05433597067489,56.835423483746375,56.61651099681786,56.39759850988934,56.18883708300686,56.00037774279072,55.811918402574605,55.62345906235847,55.434999722142344,55.24654038192622,55.05808104171009,54.869621701493955,54.681162361277835,54.4927030210617,54.30424368084558,54.115784340629446,53.92732500041332,53.7388656601972,53.55040631998106,53.36194697976494,53.17348763954881,52.985028299332676,52.79656895911656,52.60810961890042,52.4196502786843,52.23119093846817,52.04273159825204,51.85427225803592,51.665812917819785,51.47735357760366,51.288894237387524,51.1004348971714,50.911975556955284,50.72351621673914,50.535056876523015,50.346597536306895,50.15813819609076,49.96967885587463,49.781219515658506,49.59276017544238,49.40430083522625,49.21584149501012,49.027382154794,48.83892281457787,48.650463474361736,48.462004134145616,48.273544793929474,48.085085453713354,47.89662611349722,47.70816677328109,47.519707433064966,47.33124809284884,47.14278875263271,46.954329412416584,46.76587007220046,46.57741073198433,46.3889513917682,46.200492051552075,46.01203271133595,45.680660566824116,45.27783202016445,44.87500347350478,44.47217492684511,44.06934638018546,43.666517833525766,43.26368928686611,42.860860740206434,42.45803219354676,42.05520364688711,41.65237510022742,41.24954655356776,40.846718006908084,40.443889460248414,40.04106091358875,39.63823236692908,39.23540382026941,38.832575273609734,38.429746726950064,38.02691818029041,37.624089633630724,37.221261086971055,36.818432540311406,36.415603993651715,36.01277544699205,35.609946900332375,35.207118353672705,34.804289807013056,34.40146126035336,33.99863271369371,33.595804167034025,33.192975620374355,32.79014707371471,32.38577469128583,31.952842101372603,31.519909511459375,31.086976921546153,30.654044331632946,30.221111741719717,29.78817915180649,29.35524656189328,28.922313971980053,28.48938138206683,28.056448792153603,27.623516202240374,27.19058361232715,26.757651022413945,26.324718432500717,25.891785842587492,25.458853252674263,25.025920662761038,24.59298807284783,24.160055482934606,23.727122893021377,23.294190303108152,22.861257713194945,22.428325123281716,21.99539253336849,21.562459943455266,21.129527353542038,20.69659476362883,20.263662173715606,19.83072958380238,19.397796993889152,18.964864403975945,18.53193181406272,18.098999224149495,17.666066634236266,17.23313404432304,16.800201454409834,16.36726886449661,15.93433627458338,15.501403684670155,15.068471094756926,14.635538504843721,14.202605914930494,13.769673325017267,13.33674073510404,12.90380814519083,12.470875555277605,12.037942965364376,11.605010375451151,11.172077785537924,10.906118015273698,10.807131064658439,10.708144114043185,10.609157163427906,10.510170212812644,10.414448990592692,10.320627357018394,10.226805723444087,10.13298408986976,10.03916245629549,9.945340822721162,9.851519189146856,9.757697555572555,9.66963258827019,9.582385419747347,9.49513825122449,9.407891082701656,9.320643914178811,9.233396745655975,9.146149577133139,9.063034067328493,8.982722183461743,8.902410299595008,8.82209841572824,8.74178653186151,8.661474647994767,8.581162764128026,8.50546536516829,8.431306128933958,8.357146892699658,8.282987656465338,8.208828420230999,8.134669183996689,8.06214733048112,7.993433906136659,7.9247204817922325,7.856007057447776,7.787293633103344,7.718580208758889,7.646923848660131,7.564476724128765,7.482029599597415,7.399582475066064,7.3171353505347,7.234688226003342,7.152241101472,7.069793976940634,6.987346852409277,6.904899727877927,6.822452603346569,6.740005478815218,6.657558354283867,6.575111229752511,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[60.76587308661878,60.78528721220387,60.804701337788956,60.82411546337404,60.84352958895913,60.86294371454422,60.882357840129316,60.901771965714396,60.92118609129949,60.940600216884576,60.96001434246967,60.97942846805475,60.998842593639836,61.01825671922493,61.037670844810016,61.05708497039511,61.07649909598019,61.095913221565276,61.11532734715037,61.134741472735456,61.15415559832054,61.173569723905636,61.192983849490716,61.2123979750758,61.23181210066089,61.25122622624598,61.27064035183108,61.290054477416156,61.30946860300125,61.32888272858633,61.34829685417142,61.36771097975652,61.387125105341596,61.40653923092669,61.42595335651177,61.445367482096856,61.46478160768196,61.484195733267036,61.50360985885214,61.52090773458499,61.53778235973527,61.55465698488556,61.57153161003584,61.58840623518612,61.60528086033641,61.62215548548669,61.63903011063699,61.65590473578726,61.67277936093754,61.689653986087826,61.70652861123811,61.72340323638841,61.74027786153868,61.757152486688966,61.77402711183925,61.790901736989525,61.807776362139826,61.824650987290106,61.841525612440385,61.85840023759067,61.87527486274095,61.892149487891245,61.909024113041525,61.925898738191805,61.9427733633421,61.95964798849238,61.976522613642665,61.993397238792944,62.01027186394323,62.02714648909351,62.044021114243805,62.060895739394084,62.077770364544364,62.09464498969466,62.11151961484494,62.128394239995224,62.1452688651455,62.16214349029579,62.17901811544607,62.195892740596356,62.21276736574664,62.22964199089692,62.24651661604722,62.263391241197496,62.083776606282115,61.864864119353584,61.645951632425074,61.42703914549656,61.208126658568034,60.98921417163953,60.77030168471101,60.551389197782484,60.332476710853975,60.11356422392545,59.89465173699695,59.675739250068425,59.45682676313991,59.23791427621139,59.01900178928287,58.800089302354365,58.581176815425835,58.36226432849732,58.1433518415688,57.924439354640285,57.70552686771177,57.48661438078325,57.267701893854735,57.048789406926225,56.829876919997695,56.61096443306919,56.39205194614067,56.173139459212145,55.95422697228364,55.73531448535511,55.5164019984266,55.297489511498085,55.07857702456956,54.85966453764105,54.640752050712535,54.42183956378402,54.202927076855495,53.984014589926986,53.76510210299847,53.54618961606995,53.32727712914143,53.108364642212926,52.889452155284395,52.670539668355886,52.45162718142737,52.25809232287629,52.069632982660174,51.88117364244403,51.69271430222791,51.50425496201178,51.31579562179565,51.12733628157953,50.9388769413634,50.75041760114727,50.561958260931135,50.37349892071501,50.18503958049889,49.99658024028276,49.808120900066626,49.619661559850506,49.431202219634365,49.24274287941825,49.05428353920212,48.86582419898599,48.67736485876986,48.48890551855372,48.30044617833761,48.111986838121474,47.92352749790535,47.73506815768923,47.546608817473086,47.358149477256966,47.16969013704084,46.981230796824704,46.792771456608584,46.60431211639245,46.41585277617632,46.227393435960195,46.03893409574407,45.85047475552794,45.662015415311814,45.473556075095686,45.28509673487956,44.95372459036773,44.55089604370807,44.148067497048395,43.745238950388725,43.34241040372906,42.93958185706937,42.53675331040972,42.133924763750045,41.73109621709037,41.32826767043072,40.92543912377103,40.522610577111365,40.119782030451695,39.71695348379202,39.31412493713236,38.91129639047269,38.50846784381302,38.105639297153346,37.70281075049367,37.29998220383402,36.897153657174336,36.494325110514666,36.09149656385502,35.688668017195326,35.28583947053566,34.883010923875986,34.48018237721632,34.07735383055666,33.67452528389697,33.27169673723732,32.868868190577636,32.466039643917966,32.06321109725832,31.660382550598634,31.257554003938964,30.854725457279287,30.45189691061962,30.04906836395996,29.646239817300284,29.24341127064061,28.84058272398096,28.43775417732128,28.034925630661608,27.632097084001934,27.22926853734226,26.826439990682587,26.42361144402293,26.020782897363258,25.617954350703585,25.215125804043907,24.812297257384238,24.409468710724582,24.00664016406491,23.586057903178432,23.153125313265207,22.720192723352,22.28726013343877,21.854327543525542,21.42139495361232,20.988462363699092,20.555529773785885,20.122597183872657,19.68966459395943,19.256732004046206,18.823799414133,18.39086682421977,17.957934234306546,17.52500164439332,17.092069054480092,16.659136464566885,16.22620387465366,15.793271284740435,15.360338694827206,14.927406104913981,14.494473515000774,14.061540925087547,13.62860833517432,13.195675745261095,12.762743155347884,12.329810565434657,11.89687797552143,11.463945385608206,11.031012795694979,10.76505302543075,10.66606607481549,10.567079124200237,10.470902521376772,10.377080887802467,10.283259254228147,10.189437620653846,10.09561598707954,10.001794353505213,9.907972719930944,9.814151086356615,9.725107966940987,9.637860798418151,9.550613629895313,9.46336646137247,9.376119292849616,9.28887212432678,9.201624955803936,9.117083039933531,9.036771156066788,8.956459272200021,8.876147388333273,8.795835504466535,8.71552362059977,8.635211736733039,8.557919729550262,8.483760493315945,8.409601257081624,8.335442020847292,8.261282784612993,8.187123548378672,8.112964312144335,8.044202373300719,7.975488948956273,7.906775524611812,7.838062100267385,7.76934867592293,7.700635251578499,7.620150084216712,7.537702959685362,7.455255835153997,7.372808710622646,7.290361586091297,7.207914461559932,7.125467337028574,7.043020212497232,6.960573087965867,6.878125963434508,6.795678838903158,6.713231714371801,6.630784589840449,6.5483374653091,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[60.58331579353488,60.602729919119966,60.62214404470505,60.64155817029014,60.660972295875226,60.68038642146031,60.699800547045406,60.719214672630486,60.738628798215586,60.75804292380067,60.77745704938576,60.796871174970846,60.81628530055593,60.83569942614102,60.85511355172611,60.8745276773112,60.89394180289628,60.91335592848137,60.93277005406646,60.952184179651546,60.97159830523664,60.991012430821726,61.009580056352966,61.026454681503246,61.04332930665353,61.06020393180381,61.0770785569541,61.093953182104386,61.110827807254665,61.12770243240496,61.14457705755523,61.16145168270552,61.17832630785581,61.1952009330061,61.21207555815637,61.22895018330666,61.245824808456945,61.262699433607224,61.27957405875752,61.29644868390779,61.31332330905808,61.33019793420836,61.34707255935865,61.36394718450894,61.38082180965922,61.397696434809504,61.41457105995978,61.43144568511006,61.44832031026035,61.46519493541064,61.482069560560916,61.49894418571121,61.51581881086149,61.53269343601177,61.54956806116206,61.56644268631234,61.583317311462636,61.60019193661291,61.61706656176319,61.63394118691349,61.65081581206377,61.66769043721405,61.684565062364335,61.70143968751462,61.7183143126649,61.735188937815195,61.752063562965475,61.768938188115754,61.78581281326604,61.80268743841632,61.819562063566615,61.836436688716894,61.85331131386718,61.87018593901746,61.887060564167754,61.903935189318034,61.92080981446831,61.9376844396186,61.95455906476888,61.97143368991917,61.98830831506945,62.00518294021974,62.02205756537002,62.0389321905203,61.85931755560492,61.64040506867639,61.421492581747884,61.20258009481937,60.983667607890844,60.764755120962334,60.54584263403382,60.326930147105294,60.10801766017678,59.889105173248254,59.670192686319744,59.451280199391235,59.232367712462704,59.0134552255342,58.79454273860567,58.57563025167716,58.356717764748645,58.13780527782013,57.918892790891604,57.69998030396309,57.48106781703458,57.26215533010606,57.043242843177545,56.824330356249035,56.605417869320505,56.386505382391995,56.16759289546347,55.948680408534955,55.72976792160645,55.51085543467792,55.291942947749405,55.07303046082089,54.85411797389237,54.63520548696386,54.41629300003534,54.19738051310682,53.978468026178305,53.75955553924978,53.54064305232128,53.321730565392755,53.10281807846424,52.88390559153572,52.66499310460719,52.44608061767869,52.22716813075017,52.008255643821656,51.78934315689314,51.57043066996462,51.351518183036106,51.13260569610759,50.913693209179065,50.694780722250556,50.47586823532203,50.25695574839352,50.038043261465,49.81913077453648,49.600218287607966,49.381305800679456,49.16239331375093,48.94348082682243,48.7245683398939,48.515806902961856,48.32734756274573,48.1388882225296,47.950428882313474,47.76196954209735,47.57351020188121,47.38505086166509,47.19659152144896,47.00813218123284,46.819672841016704,46.631213500800584,46.44275416058445,46.254294820368315,46.065835480152195,45.877376139936075,45.68891679971994,45.50045745950381,45.31199811928768,45.12353877907155,44.93507943885543,44.7466200986393,44.55816075842318,44.22678861391133,43.82396006725168,43.421131520592006,43.018302973932336,42.61547442727267,42.21264588061298,41.80981733395333,41.406988787293656,41.00416024063398,40.60133169397432,40.19850314731464,39.795674600654976,39.39284605399531,38.99001750733563,38.587188960675974,38.1843604140163,37.781531867356634,37.37870332069696,36.97587477403728,36.573046227377624,36.17021768071795,35.76738913405828,35.36456058739863,34.96173204073893,34.558903494079274,34.1560749474196,33.75324640075993,33.35041785410027,32.94758930744058,32.544760760780925,32.14193221412125,31.739103667461578,31.336275120801922,30.933446574142245,30.530618027482575,30.127789480822898,29.724960934163228,29.322132387503572,28.919303840843895,28.516475294184218,28.113646747524566,27.710818200864892,27.30798965420522,26.905161107545545,26.50233256088587,26.0995040142262,25.696675467566543,25.293846920906866,24.891018374247192,24.48818982758752,24.085361280927845,23.682532734268193,23.27970418760852,22.876875640948843,22.47404709428917,22.071218547629513,21.668390000969843,21.265561454310166,20.862732907650496,20.45990436099082,20.057075814331164,19.654247267671494,19.251418721011817,18.848590174352147,18.445761627692487,18.042933081032814,17.640104534373144,17.23727598771347,16.834447441053793,16.43161889439414,16.028790347734464,15.62596180107479,15.21927370498426,14.786341115071036,14.353408525157828,13.920475935244601,13.487543345331375,13.05461075541815,12.621678165504939,12.188745575591712,11.755812985678485,11.32288039576526,10.889947805852033,10.623988035587807,10.527356052160828,10.433534418586527,10.339712785012228,10.245891151437924,10.152069517863602,10.058247884289303,9.964426250714997,9.87060461714067,9.780583345611799,9.693336177088955,9.606089008566114,9.518841840043278,9.43159467152044,9.344347502997596,9.257100334474742,9.171132012538552,9.090820128671803,9.010508244805061,8.93019636093832,8.849884477071553,8.769572593204803,8.689260709338065,8.61037409393225,8.53621485769793,8.462055621463598,8.387896385229281,8.31373714899496,8.23957791276063,8.165418676526329,8.094970840464773,8.026257416120313,7.957543991775874,7.888830567431429,7.820117143086968,7.751403718742542,7.675823444304651,7.593376319773293,7.5109291952419435,7.428482070710594,7.346034946179228,7.263587821647878,7.181140697116529,7.098693572585163,7.0162464480538045,6.933799323522463,6.851352198991097,6.768905074459739,6.686457949928389,6.604010825397031,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[60.400758500450976,60.42017262603607,60.43958675162115,60.459000877206236,60.47841500279133,60.49782912837642,60.515127003271246,60.532001628421526,60.54887625357182,60.5657508787221,60.582625503872386,60.599500129022665,60.616374754172945,60.63324937932324,60.65012400447352,60.666998629623805,60.683873254774085,60.700747879924364,60.71762250507466,60.73449713022494,60.751371755375224,60.76824638052551,60.7851210056758,60.80199563082608,60.818870255976364,60.835744881126644,60.85261950627692,60.86949413142722,60.8863687565775,60.90324338172778,60.92011800687807,60.93699263202835,60.953867257178636,60.97074188232892,60.9876165074792,61.0044911326295,61.021365757779776,61.038240382930056,61.05511500808034,61.07198963323063,61.08886425838091,61.10573888353119,61.122613508681475,61.13948813383176,61.15636275898204,61.17323738413233,61.19011200928262,61.206986634432894,61.22386125958318,61.24073588473347,61.25761050988375,61.27448513503404,61.29135976018432,61.3082343853346,61.325109010484894,61.341983635635174,61.35885826078547,61.37573288593574,61.39260751108602,61.40948213623632,61.42635676138659,61.44323138653688,61.46010601168716,61.476980636837446,61.49385526198773,61.51072988713802,61.5276045122883,61.544479137438586,61.56135376258887,61.57822838773916,61.59510301288944,61.61197763803972,61.628852263190005,61.64572688834029,61.66260151349058,61.67947613864086,61.696350763791145,61.71322538894143,61.73010001409172,61.746974639242,61.76384926439228,61.780723889542564,61.79759851469285,61.81447313984314,61.63485850492775,61.41594601799922,61.19703353107071,60.97812104414219,60.75920855721367,60.540296070285166,60.32138358335665,60.10247109642812,59.8835586094996,59.664646122571085,59.445733635642576,59.22682114871406,59.007908661785535,58.788996174857026,58.5700836879285,58.35117120099999,58.13225871407147,57.91334622714295,57.694433740214436,57.47552125328592,57.2566087663574,57.037696279428886,56.81878379250037,56.59987130557187,56.380958818643336,56.16204633171482,55.9431338447863,55.724221357857786,55.50530887092928,55.28639638400075,55.067483897072236,54.84857141014372,54.6296589232152,54.4107464362867,54.19183394935817,53.97292146242965,53.75400897550114,53.53509648857262,53.3161840016441,53.09727151471559,52.87835902778707,52.65944654085856,52.44053405393003,52.22162156700152,52.002709080073004,51.78379659314449,51.56488410621597,51.34597161928745,51.12705913235894,50.90814664543041,50.6892341585019,50.47032167157339,50.25140918464487,50.032496697716354,49.81358421078783,49.59467172385931,49.375759236930804,49.15684675000229,48.93793426307376,48.719021776145254,48.500109289216724,48.28119680228822,48.062284315359705,47.843371828431174,47.62445934150267,47.40554685457414,47.18663436764564,46.967721880717114,46.74880939378859,46.52989690686009,46.31098441993156,46.09207193300304,45.873159446074524,45.65424695914601,45.435334472217505,45.21642198528898,44.99750949836046,44.77859701143194,44.58506214283134,44.39660280261521,44.20814346239909,44.01968412218296,43.83122478196684,43.499852637455,43.097024090795344,42.694195544135674,42.291366997476,41.88853845081634,41.48570990415665,41.082881357496994,40.68005281083732,40.27722426417765,39.87439571751799,39.47156717085829,39.068738624198645,38.66591007753897,38.26308153087929,37.86025298421964,37.45742443755997,37.054595890900295,36.65176734424062,36.24893879758094,35.8461102509213,35.443281704261615,35.040453157601945,34.63762461094229,34.2347960642826,33.83196751762294,33.429138970963265,33.026310424303595,32.62348187764393,32.22065333098425,31.817824784324593,31.414996237664912,31.012167691005242,30.609339144345586,30.206510597685913,29.80760657574741,29.410272394106386,29.01293821246535,28.615604030824343,28.218269849183315,27.820935667542287,27.423601485901276,27.02626730426025,26.62893312261922,26.23159894097819,25.834264759337163,25.43693057769613,25.039596396055124,24.642262214414096,24.244928032773068,23.84759385113204,23.450259669491007,23.052925487849997,22.655591306208972,22.258257124567944,21.860922942926916,21.463588761285905,21.066254579644877,20.66892039800385,20.27158621636282,19.874252034721792,19.47691785308078,19.07958367143975,18.682249489798725,18.284915308157693,17.887581126516686,17.490246944875658,17.09291276323463,16.695578581593598,16.298244399952573,15.900910218311562,15.503576036670534,15.106241855029504,14.708907673388476,14.311573491747449,13.914239310106439,13.51690512846541,13.11957094682438,12.722236765183352,12.324902583542343,11.927568401901313,11.530234220260287,11.132900038619256,10.735565856978228,10.4899879493706,10.396166315796293,10.302344682221994,10.208523048647692,10.114701415073387,10.020879781499067,9.92705814792477,9.836058724282625,9.748811555759783,9.661564387236933,9.57431721871409,9.487070050191248,9.39982288166841,9.312575713145574,9.22532854462273,9.144869101276832,9.064557217410089,8.98424533354334,8.903933449676598,8.823621565809855,8.74330968194309,8.662997798076338,8.588669222079917,8.514509985845594,8.440350749611275,8.366191513376942,8.292032277142626,8.217873040908305,8.145739307628821,8.077025883284378,8.008312458939933,7.939599034595472,7.870885610251036,7.802172185906589,7.731496804392585,7.6490496798612355,7.566602555329885,7.484155430798527,7.401708306267177,7.319261181735826,7.2368140572044615,7.154366932673112,7.071919808141761,6.989472683610396,6.907025559079038,6.824578434547695,6.7421313100163305,6.659684185484973,6.577237060953622,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[60.204290264933306,60.21872548175937,60.23316069858543,60.24759591541149,60.26203113223755,60.27646634906361,60.29090156588967,60.30533678271573,60.31977199954179,60.33420721636785,60.34864243319391,60.363077650019974,60.37913913834468,60.39601376349496,60.41288838864525,60.42976301379554,60.446637638945816,60.463512264096096,60.48038688924639,60.49726151439667,60.514136139546956,60.531010764697236,60.54788538984752,60.5647600149978,60.581634640148096,60.598509265298375,60.615383890448655,60.63225851559895,60.64913314074923,60.666007765899515,60.682882391049795,60.69975701620008,60.71663164135036,60.733506266500655,60.750380891650934,60.76725551680122,60.78413014195151,60.80100476710179,60.81787939225207,60.834754017402354,60.85162864255264,60.86850326770292,60.885377892853214,60.90225251800349,60.91912714315378,60.93600176830406,60.952876393454346,60.96975101860463,60.98662564375492,61.0035002689052,61.02037489405548,61.037249519205766,61.05412414435605,61.07099876950633,61.087873394656626,61.1047480198069,61.1216226449572,61.13849727010747,61.15537189525775,61.17224652040804,61.189121145558325,61.20599577070861,61.22287039585889,61.23974502100917,61.256619646159464,61.27349427130975,61.29036889646003,61.30724352161032,61.3241181467606,61.340992771910884,61.35786739706117,61.37474202221145,61.39161664736174,61.40849127251202,61.42536589766231,61.4422405228126,61.459115147962876,61.475989773113156,61.49286439826344,61.50973902341373,61.52661364856401,61.543488273714296,61.560362898864575,61.57723752401486,61.397622889099466,61.178710402170935,60.95979791524243,60.74088542831392,60.5219729413854,60.30306045445688,60.084147967528374,59.86523548059985,59.64632299367133,59.42741050674281,59.208498019814314,58.98958553288578,58.770673045957274,58.55176055902875,58.33284807210024,58.113935585171724,57.8950230982432,57.67611061131469,57.45719812438617,57.23828563745765,57.019373150529134,56.80046066360061,56.5815481766721,56.362635689743584,56.14372320281506,55.92481071588655,55.70589822895803,55.48698574202952,55.268073255101,55.04916076817248,54.83024828124397,54.611335794315444,54.39242330738692,54.17351082045842,53.9545983335299,53.73568584660137,53.51677335967287,53.29786087274434,53.078948385815835,52.86003589888732,52.64112341195879,52.422210925030285,52.203298438101754,51.984385951173245,51.76547346424473,51.54656097731622,51.327648490387695,51.10873600345917,50.889823516530655,50.67091102960214,50.45199854267362,50.23308605574512,50.014173568816595,49.79526108188807,49.576348594959555,49.35743610803103,49.13852362110253,48.91961113417401,48.70069864724549,48.48178616031698,48.262873673388455,48.043961186459946,47.82504869953143,47.6061362126029,47.387223725674396,47.168311238745865,46.94939875181736,46.73048626488884,46.511573777960315,46.29266129103181,46.07374880410328,45.854836308968125,45.60802239428474,45.36120847960136,45.11439456491799,44.8675806502346,44.620766735551214,44.373952820867835,44.12713890618445,43.88032499150108,43.6335110768177,43.38669716213431,43.13988324745094,42.8088066422712,42.43559869184336,42.062390741415484,41.689182790987616,41.31597484055977,40.94276689013188,40.56955893970404,40.19635098927616,39.82314303884829,39.449935088420446,39.076727137992556,38.7035191875647,38.33031123713684,37.95710328670897,37.58389533628112,37.21068738585325,36.8284321089213,36.43109792728028,36.03376374563925,35.636429563998234,35.239095382357206,34.841761200716185,34.44442701907517,34.04709283743412,33.649758655793114,33.252424474152086,32.85509029251106,32.457756110870044,32.060421929229,31.663087747587987,31.26575356594696,30.868419384305934,30.471085202664923,30.073751021023895,29.676416839382867,29.279082657741835,28.881748476100807,28.4844142944598,28.08708011281877,27.68974593117774,27.292411749536733,26.895077567895704,26.497743386254676,26.100409204613648,25.703075022972616,25.305740841331584,24.90840665969058,24.511072478049552,24.11373829640852,23.716404114767496,23.319069933126464,22.921735751485453,22.524401569844425,22.1270673882034,21.729733206562372,21.332399024921358,20.93506484328033,20.5377306616393,20.140396479998273,19.74306229835725,19.345728116716238,18.948393935075206,18.55105975343418,18.15372557179315,17.756391390152142,17.35905720851111,16.961723026870082,16.564388845229054,16.167054663588026,15.769720481947017,15.372386300305989,14.97505211866496,14.57771793702393,14.180383755382902,13.783049573741891,13.385715392100863,12.988381210459837,12.591047028818807,12.193712847177798,11.796378665536768,11.399044483895741,11.001710302254711,10.604376120613683,10.358798213006054,10.26497657943175,10.171154945857449,10.077333312283148,9.983511678708844,9.891534102953429,9.804286934430571,9.71703976590775,9.629792597384906,9.542545428862056,9.455298260339214,9.368051091816373,9.280803923293535,9.19891807388187,9.118606190015102,9.03829430614836,8.957982422281617,8.877670538414868,8.797358654548129,8.717046770681383,8.641123586461902,8.566964350227563,8.492805113993253,8.418645877758932,8.344486641524611,8.27032740529028,8.196507774792861,8.127794350448415,8.059080926103976,7.990367501759533,7.921654077415086,7.852940653070625,7.7842272287261896,7.704723039949182,7.622275915417816,7.539828790886466,7.457381666355117,7.374934541823759,7.292487417292408,7.210040292761057,7.1275931682296925,7.045146043698342,6.962698919166993,6.880251794635627,6.797804670104269,6.715357545572927,6.6329104210415615,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[60.001480276570405,60.01591549339646,60.03035071022252,60.044785927048586,60.059221143874645,60.0736563607007,60.08809157752676,60.10252679435282,60.11696201117888,60.13139722800494,60.145832444831,60.16026766165706,60.174702878483124,60.18913809530918,60.20357331213524,60.2180085289613,60.232443745787364,60.24687896261342,60.26131417943948,60.275749396265546,60.290184613091604,60.30461982991766,60.31905504674371,60.333490263569786,60.347925480395844,60.3623606972219,60.37679591404796,60.39123113087402,60.4060729146341,60.422947539784396,60.439822164934675,60.45669679008496,60.47357141523525,60.490446040385535,60.507320665535815,60.5241952906861,60.54106991583638,60.55794454098667,60.574819166136955,60.59169379128723,60.60856841643752,60.6254430415878,60.64231766673809,60.659192291888374,60.67606691703866,60.69294154218895,60.70981616733923,60.726690792489514,60.74356541763979,60.76044004279008,60.77731466794036,60.79418929309064,60.81106391824093,60.82793854339121,60.844813168541506,60.861687793691786,60.878562418842066,60.89543704399235,60.91231166914263,60.92918629429292,60.94606091944321,60.96293554459349,60.97981016974378,60.996684794894065,61.013559420044345,61.03043404519463,61.04730867034492,61.0641832954952,61.081057920645485,61.097932545795764,61.11480717094605,61.13168179609634,61.148556421246624,61.165431046396904,61.182305671547184,61.19918029669747,61.21605492184776,61.232929546998044,61.24980417214832,61.26667879729861,61.28355342244889,61.30042804759918,61.31730267274946,61.33417729789974,61.15456266298436,60.93565017605583,60.71673768912733,60.49782520219881,60.27891271527028,60.06000022834178,59.84108774141326,59.62217525448474,59.403262767556214,59.1843502806277,58.965437793699195,58.74652530677067,58.527612819842155,58.30870033291363,58.089787845985114,57.87087535905661,57.65196287212808,57.433050385199564,57.21413789827105,56.99522541134253,56.77631292441402,56.5574004374855,56.33848795055698,56.11957546362847,55.90066297669994,55.68175048977143,55.462838002842915,55.2439255159144,55.02501302898589,54.80610054205736,54.58718805512885,54.36827556820033,54.149363081271815,53.9304505943433,53.71153810741479,53.49262562048625,53.27371313355775,53.05480064662922,52.835888159700716,52.6169756727722,52.39806318584368,52.179150698915166,51.960238211986635,51.74132572505813,51.522413238129616,51.30350075120109,51.08458826427258,50.86567577734406,50.64676329041555,50.42785080348703,50.2089383165585,49.99002582963,49.771113342701476,49.552200855772966,49.333288368844435,49.100425155228095,48.853611240544716,48.606797325861336,48.35998341117795,48.11316949649458,47.866355581811185,47.61954166712781,47.37272775244443,47.12591383776105,46.879099923077675,46.632286008394274,46.38547209371091,46.13865817902752,45.891844264344144,45.645030349660765,45.39821643497737,45.151402520294,44.90458860561061,44.65777469092723,44.41096077624386,44.164146861560475,43.917332946877096,43.67051903219371,43.42370511751032,43.17689120282695,42.93007728814357,42.683263373460186,42.43644945877681,42.10537285359708,41.73216490316924,41.358956952741366,40.9857490023135,40.61254105188565,40.23933310145776,39.86612515102991,39.492917200602044,39.119709250174175,38.74650129974633,38.37329334931843,38.000085398890576,37.626877448462714,37.253669498034846,36.880461547607,36.50725359717912,36.134045646751254,35.760837696323385,35.38762974589552,35.01442179546767,34.64121384503979,34.26800589461193,33.89479794418407,33.52158999375619,33.14838204332834,32.77517409290047,32.401966142472595,32.02875819204475,31.65555024161686,31.28234229118901,30.909134340761145,30.535926390333273,30.162718439905422,29.789510489477554,29.41630253904968,29.043094588621813,28.669886638193944,28.29667868776609,27.92347073733822,27.550262786910356,27.161222013172186,26.763887831531157,26.36655364989013,25.9692194682491,25.571885286608072,25.17455110496704,24.777216923326037,24.37988274168501,23.982548560043973,23.585214378402952,23.18788019676192,22.79054601512091,22.393211833479885,21.995877651838853,21.598543470197825,21.201209288556814,20.803875106915786,20.406540925274758,20.00920674363373,19.611872561992705,19.21453838035169,18.817204198710662,18.419870017069638,18.022535835428606,17.625201653787595,17.227867472146567,16.83053329050554,16.43319910886451,16.035864927223482,15.638530745582472,15.241196563941443,14.843862382300415,14.446528200659387,14.049194019018357,13.651859837377348,13.25452565573632,12.857191474095291,12.459857292454263,12.062523110813252,11.665188929172224,11.267854747531196,10.870520565890168,10.47318638424914,10.227608476641507,10.133786843067202,10.039965209492903,9.947009481624255,9.859762313101392,9.772515144578556,9.685267976055698,9.598020807532874,9.510773639010033,9.423526470487182,9.336279301964339,9.252967046486887,9.172655162620142,9.0923432787534,9.012031394886634,8.931719511019892,8.851407627153149,8.7710957432864,8.693577950843872,8.619418714609559,8.545259478375236,8.471100242140897,8.396941005906587,8.322781769672266,8.248622533437945,8.178562817612473,8.109849393268018,8.041135968923571,7.972422544579129,7.903709120234689,7.834995695890242,7.76039640003712,7.677949275505771,7.595502150974413,7.513055026443048,7.430607901911698,7.348160777380348,7.265713652848989,7.18326652831764,7.100819403786289,7.0183722792549235,6.9359251547235745,6.853478030192224,6.771030905660858,6.6885837811295,6.606136656598158,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[59.798670288207504,59.81310550503356,59.82754072185962,59.841975938685685,59.85641115551174,59.8708463723378,59.88528158916386,59.899716805989925,59.91415202281598,59.92858723964204,59.94302245646811,59.957457673294165,59.97189289012022,59.98632810694628,60.00076332377235,60.015198540598405,60.02963375742446,60.04406897425052,60.05850419107659,60.072939407902645,60.0873746247287,60.10180984155476,60.11624505838083,60.130680275206885,60.14511549203294,60.159550708859,60.17398592568506,60.18842114251112,60.202856359337176,60.217291576163234,60.231726792989306,60.246162009815365,60.26059722664142,60.27503244346748,60.28946766029354,60.3039028771196,60.318338093945655,60.33277331077173,60.347208527597786,60.361643744423844,60.3760789612499,60.39051417807596,60.40494939490202,60.419384611728084,60.433819828554135,60.44988131607385,60.46675594122413,60.483630566374416,60.500505191524695,60.51737981667498,60.53425444182527,60.55112906697555,60.56800369212583,60.58487831727612,60.6017529424264,60.61862756757669,60.635502192726975,60.652376817877254,60.66925144302754,60.68612606817782,60.70300069332811,60.7198753184784,60.73674994362868,60.75362456877896,60.77049919392924,60.787373819079534,60.80424844422981,60.82112306938011,60.83799769453039,60.85487231968067,60.87174694483095,60.88862156998124,60.90549619513152,60.92237082028181,60.93924544543209,60.95612007058237,60.972994695732666,60.989869320882946,61.006743946033225,61.02361857118351,61.0404931963338,61.05736782148408,61.07424244663436,61.09111707178465,60.91150243686926,60.69258994994074,60.47367746301222,60.254764976083706,60.03585248915519,59.81694000222667,59.598027515298156,59.37911502836964,59.160202541441116,58.9412900545126,58.72237756758409,58.50346508065557,58.28455259372706,58.06564010679853,57.84672761987002,57.62781513294151,57.40890264601299,57.18999015908447,56.97107767215596,56.75216518522743,56.533252698298924,56.3143402113704,56.09542772444188,55.876515237513374,55.65760275058485,55.43869026365634,55.21977777672782,55.0008652897993,54.78195280287079,54.56304031594227,54.34412782901375,54.125215342085234,53.90630285515671,53.68739036822821,53.468477881299684,53.24956539437116,53.03065290744265,52.81174042051413,52.592827916171515,52.34601400148813,52.09920008680474,51.85238617212138,51.605572257437984,51.35875834275461,51.11194442807121,50.86513051338784,50.61831659870447,50.371502684021074,50.1246887693377,49.877874854654316,49.63106093997093,49.38424702528756,49.13743311060417,48.89061919592079,48.64380528123741,48.39699136655402,48.15017745187065,47.903363537187275,47.65654962250388,47.40973570782051,47.162921793137116,46.916107878453744,46.669293963770365,46.422480049086985,46.1756661344036,45.92885221972021,45.68203830503683,45.435224390353454,45.18841047567007,44.941596560986696,44.6947826463033,44.44796873161993,44.201154816936544,43.954340902253165,43.70752698756979,43.460713072886406,43.21389915820302,42.96708524351964,42.72027132883626,42.47345741415289,42.2266434994695,41.97982958478612,41.733015670102745,41.40193906492302,41.028731114495166,40.6555231640673,40.28231521363943,39.90910726321158,39.53589931278369,39.162691362355844,38.789483411927975,38.4162754615001,38.04306751107225,37.66985956064436,37.296651610216514,36.923443659788646,36.55023570936078,36.17702775893292,35.80381980850506,35.430611858077185,35.05740390764932,34.68419595722145,34.3109880067936,33.937780056365725,33.56457210593786,33.19136415551,32.81815620508212,32.44494825465427,32.0717403042264,31.698532353798527,31.32532440337068,30.952116452942793,30.578908502514942,30.205700552087073,29.832492601659204,29.45928465123135,29.08607670080348,28.712868750375613,28.339660799947744,27.966452849519875,27.59324489909202,27.220036948664152,26.846828998236283,26.473621047808436,26.100413097380564,25.7272051469527,25.353997196524826,24.980789246096958,24.607581295669085,24.234373345241238,23.86116539481337,23.4879574443855,23.114749493957632,22.74154154352976,22.36833359310191,21.995125642674044,21.62191769224617,21.248709741818303,20.87550179139045,20.502293840962583,20.129085890534714,19.755877940106842,19.382669989678977,19.009462039251122,18.636254088823254,18.263046138395385,17.88983818796752,17.49401191742306,17.096677735782034,16.699343554141002,16.302009372499974,15.904675190858946,15.507341009217937,15.11000682757691,14.71267264593588,14.315338464294854,13.918004282653822,13.520670101012811,13.123335919371783,12.726001737730755,12.328667556089728,11.931333374448718,11.53399919280769,11.13666501116666,10.739330829525631,10.341996647884605,10.096418740276972,10.002597106702668,9.915237691772203,9.827990523249388,9.740743354726526,9.653496186203688,9.566249017680832,9.47900184915801,9.391754680635167,9.307016019091918,9.226704135225189,9.146392251358424,9.066080367491681,8.98576848362494,8.905456599758171,8.82514471589143,8.746032315225854,8.671873078991517,8.597713842757218,8.523554606522902,8.44939537028858,8.375236134054242,8.301076897819932,8.22933128477652,8.160617860432076,8.091904436087633,8.023191011743178,7.954477587398731,7.88576416305429,7.816069760125076,7.733622635593718,7.65117551106236,7.568728386531012,7.486281261999653,7.403834137468288,7.321387012936938,7.2389398884055876,7.156492763874229,7.074045639342879,6.991598514811529,6.909151390280163,6.826704265748814,6.744257141217464,6.661810016686099,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[59.59586029984459,59.61029551667065,59.62473073349671,59.63916595032277,59.65360116714883,59.668036383974886,59.68247160080095,59.69690681762701,59.71134203445307,59.725777251279126,59.74021246810519,59.75464768493125,59.76908290175731,59.783518118583366,59.79795333540943,59.81238855223549,59.826823769061555,59.841258985887606,59.85569420271367,59.87012941953973,59.884564636365795,59.898999853191846,59.91343507001791,59.92787028684397,59.94230550367003,59.956740720496086,59.971175937322144,59.985611154148216,60.00004637097426,60.01448158780033,60.02891680462639,60.04335202145245,60.05778723827851,60.072222455104566,60.086657671930624,60.10109288875668,60.11552810558274,60.12996332240881,60.14439853923487,60.15883375606093,60.17326897288699,60.187704189713045,60.20213940653911,60.216574623365176,60.23100984019123,60.245445057017285,60.25988027384335,60.2743154906694,60.28875070749546,60.30318592432153,60.31762114114758,60.332056357973656,60.34649157479971,60.360926791625765,60.37536200845183,60.38979722527789,60.404232442103954,60.418667658930005,60.43310287575606,60.447538092582136,60.46197330940819,60.476815092363275,60.49368971751356,60.51056434266385,60.527438967814135,60.544313592964414,60.5611882181147,60.57806284326499,60.59493746841527,60.611812093565554,60.628686718715834,60.64556134386613,60.66243596901641,60.679310594166694,60.69618521931697,60.71305984446727,60.72993446961755,60.746809094767826,60.76368371991811,60.7805583450684,60.797432970218686,60.814307595368966,60.831182220519246,60.84805684566953,60.668442210754144,60.44952972382562,60.23061723689711,60.011704749968594,59.79279226304008,59.57387977611156,59.354967289183044,59.13605480225453,58.917142315326004,58.69822982839749,58.479317341468985,58.260404854540454,58.041492367611944,57.82257988068342,57.603667393754904,57.384754906826394,57.16584241989788,56.94692993296936,56.72801744604084,56.509104959112314,56.290192472183804,56.07127998525529,55.83841676243148,55.591602847748106,55.34478893306472,55.09797501838134,54.851161103697955,54.604347189014575,54.3575332743312,54.11071935964781,53.86390544496443,53.61709153028105,53.37027761559767,53.12346370091429,52.876649786230914,52.62983587154753,52.38302195686415,52.13620804218076,51.88939412749739,51.642580212813996,51.39576629813062,51.14895238344725,50.90213846876385,50.65532455408048,50.40851063939709,50.161696724713714,49.91488281003034,49.66806889534695,49.421254980663576,49.17444106598019,48.92762715129681,48.68081323661343,48.433999321930045,48.18718540724666,47.94037149256329,47.6935575778799,47.44674366319653,47.19992974851314,46.95311583382976,46.706301919146384,46.459488004463,46.21267408977962,45.96586017509624,45.71904626041285,45.47223234572948,45.22541843104609,44.978604516362715,44.731790601679336,44.48497668699594,44.23816277231257,43.99134885762918,43.744534942945805,43.49772102826242,43.25090711357904,43.00409319889566,42.75727928421229,42.5104653695289,42.263651454845515,42.01683754016213,41.77002362547876,41.52320971079538,41.27639579611199,41.02958188142862,40.69850527624889,40.32529732582105,39.95208937539318,39.57888142496531,39.205673474537456,38.83246552410957,38.45925757368172,38.08604962325384,37.71284167282598,37.33963372239813,36.96642577197024,36.593217821542396,36.22000987111453,35.84680192068665,35.473593970258804,35.100386019830935,34.72717806940307,34.3539701189752,33.98076216854733,33.607554218119475,33.234346267691606,32.86113831726374,32.48793036683588,32.114722416408,31.741514465980146,31.368306515552277,30.995098565124408,30.621890614696557,30.24868266426867,29.875474713840816,29.502266763412948,29.12905881298508,28.755850862557224,28.382642912129356,28.009434961701494,27.63622701127362,27.26301906084575,26.889811110417895,26.51660315999003,26.143395209562158,25.77018725913431,25.396979308706438,25.023771358278573,24.650563407850704,24.277355457422836,23.904147506994963,23.530939556567116,23.157731606139244,22.784523655711375,22.411315705283506,22.038107754855638,21.664899804427787,21.291691853999918,20.91848390357205,20.54527595314418,20.17206800271633,19.798860052288457,19.42565210186059,19.05244415143272,18.67923620100485,18.306028250577,17.93282030014913,17.559612349721263,17.186404399293394,16.81319644886554,16.439988498437675,16.066780548009802,15.693572597581936,15.320364647154065,14.947156696726214,14.573948746298345,14.200740795870477,13.827532845442606,13.457404842988485,13.09497661264281,12.732548382297118,12.370120151951424,12.007691921605732,11.645263691260055,11.282835460914361,10.920407230568667,10.557979000222975,10.195550769877283,9.97071307044303,9.883465901920188,9.79621873339733,9.708971564874515,9.621724396351652,9.534477227828814,9.447230059305959,9.36106499169697,9.280753107830206,9.200441223963448,9.12012934009672,9.039817456229954,8.959505572363211,8.87919368849647,8.798881804629701,8.724327443373523,8.650168207139192,8.576008970904855,8.501849734670554,8.427690498436238,8.353531262201916,8.280099751940575,8.211386327596124,8.142672903251675,8.07395947890723,8.00524605456279,7.936532630218332,7.867819205873886,7.789295995681671,7.7068488711503145,7.624401746618956,7.541954622087599,7.45950749755625,7.377060373024892,7.294613248493526,7.2121661239621755,7.129718999430826,7.047271874899467,6.964824750368117,6.882377625836767,6.799930501305402,6.717483376774052,6.635036252242703,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[59.39305031148168,59.40748552830774,59.4219207451338,59.43635596195986,59.45079117878592,59.46522639561198,59.479661612438036,59.494096829264095,59.50853204609015,59.52296726291621,59.537402479742276,59.55183769656834,59.56627291339439,59.58070813022045,59.595143347046516,59.609578563872574,59.62401378069863,59.63844899752469,59.652884214350756,59.667319431176814,59.68175464800287,59.69618986482893,59.710625081654996,59.725060298481054,59.73949551530711,59.75393073213317,59.768365948959236,59.782801165785294,59.79723638261135,59.81167159943741,59.826106816263476,59.840542033089534,59.85497724991559,59.86941246674166,59.883847683567716,59.89828290039378,59.91271811721984,59.9271533340459,59.94158855087196,59.956023767698014,59.97045898452407,59.984894201350144,59.999329418176195,60.01376463500226,60.02819985182832,60.04263506865438,60.057070285480435,60.07150550230649,60.08594071913255,60.10037593595862,60.11481115278468,60.12924636961074,60.1436815864368,60.15811680326286,60.172552020088915,60.18698723691498,60.20142245374104,60.215857670567104,60.23029288739316,60.24472810421922,60.25916332104528,60.27359853787134,60.2880337546974,60.30246897152346,60.31690418834952,60.331339405175584,60.34577462200164,60.3602098388277,60.37464505565376,60.389080272479816,60.40351548930588,60.41795070613194,60.432385922958,60.44682113978406,60.46125635661012,60.47569157343618,60.49012679026224,60.504562007088296,60.520623493803,60.53749811895328,60.55437274410357,60.571247369253854,60.58812199440413,60.60499661955442,60.42538198463903,60.20646949771051,59.987557010782,59.768644523853474,59.54973203692496,59.33081952337484,59.08400560869146,58.83719169400807,58.59037777932469,58.343563864641304,58.09674994995793,57.84993603527455,57.603122120591166,57.35630820590779,57.109494291224394,56.86268037654102,56.61586646185765,56.369052547174256,56.12223863249087,55.8754247178075,55.628610803124126,55.38179688844073,55.13498297375736,54.88816905907399,54.64135514439059,54.394541229707215,54.14772731502383,53.90091340034045,53.65409948565708,53.407285570973684,53.16047165629031,52.91365774160693,52.66684382692354,52.42002991224017,52.173215997556795,51.9264020828734,51.67958816819002,51.432774253506636,51.185960338823264,50.93914642413988,50.69233250945649,50.44551859477312,50.19870468008973,49.95189076540636,49.70507685072297,49.45826293603959,49.211449021356216,48.96463510667283,48.71782119198945,48.47100727730607,48.224193362622685,47.97737944793931,47.73056553325593,47.48375161857254,47.23693770388916,46.99012378920578,46.7433098745224,46.496495959839024,46.24968204515564,46.002868130472265,45.75605421578887,45.50924030110549,45.26242638642212,45.015612471738734,44.76879855705536,44.52198464237196,44.27517072768859,44.02835681300521,43.781542898321824,43.53472898363845,43.28791506895506,43.041101154271686,42.7942872395883,42.547473324904914,42.30065941022154,42.05384549553816,41.807031580854776,41.56021766617139,41.31340375148801,41.06658983680464,40.81977592212125,40.572962007437866,40.326148092754494,39.99507148757477,39.621863537146915,39.24865558671905,38.87544763629118,38.50223968586334,38.12903173543545,37.75582378500759,37.382615834579724,37.009407884151855,36.636199933724,36.26299198329611,35.88978403286827,35.516576082440395,35.14336813201253,34.77016018158467,34.39695223115681,34.02374428072894,33.65053633030107,33.2773283798732,32.90951032328086,32.54708209293517,32.18465386258948,31.8222256322438,31.45979740189809,31.097369171552412,30.734940941206723,30.372512710861027,30.010084480515353,29.647656250169643,29.28522801982397,28.922799789478272,28.560371559132577,28.1979433287869,27.835515098441206,27.473086868095514,27.11065863774982,26.74823040740413,26.38580217705845,26.023373946712763,25.660945716367063,25.29851748602139,24.936089255675697,24.573661025330004,24.211232794984312,23.848804564638616,23.48637633429292,23.123948103947246,22.76151987360155,22.39909164325586,22.036663412910166,21.67423518256447,21.3118069522188,20.949378721873103,20.58695049152741,20.22452226118172,19.86209403083604,19.499665800490348,19.137237570144652,18.774809339798963,18.412381109453268,18.049952879107593,17.6875246487619,17.325096418416205,16.96266818807051,16.600239957724835,16.23781172737914,15.875383497033448,15.512955266687754,15.150527036342062,14.788098805996384,14.425670575650692,14.063242345305,13.700814114959305,13.338385884613611,12.975957654267937,12.613529423922245,12.251101193576549,11.888672963230857,11.526244732885178,11.163816502539486,10.801388272193794,10.4389600418481,10.076531811502406,9.851694112068154,9.764446943545313,9.677199775022455,9.589952606499638,9.502705437976777,9.41545826945394,9.334802080435232,9.254490196568499,9.174178312701734,9.093866428834977,9.01355454496825,8.933242661101483,8.852930777234741,8.77678180775548,8.702622571521175,8.62846333528686,8.554304099052528,8.48014486281819,8.40598562658389,8.331826390349574,8.262154794760175,8.193441370415728,8.124727946071276,8.05601452172683,7.987301097382384,7.918587673037943,7.844969355769612,7.762522231238253,7.680075106706903,7.597627982175546,7.5151808576441885,7.43273373311283,7.350286608581481,7.267839484050122,7.185392359518757,7.102945234987407,7.020498110456058,6.938050985924699,6.855603861393349,6.773156736861999,6.690709612330633,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[59.18982442553618,59.20425964236224,59.2186948591883,59.23313007601436,59.24756529284042,59.26200050966648,59.276435726492544,59.290870943318595,59.30530616014465,59.31974137697071,59.334176593796776,59.348611810622835,59.36304702744889,59.37748224427495,59.391917461101016,59.406352677927075,59.42078789475313,59.43522311157919,59.449658328405256,59.464093545231314,59.47852876205737,59.49296397888344,59.507399195709496,59.521834412535554,59.53626962936161,59.55070484618767,59.56514006301373,59.57957527983979,59.59401049666586,59.60844571349192,59.622880930317976,59.637316147144034,59.65175136397009,59.66618658079616,59.680621797622216,59.695057014448274,59.70949223127433,59.7239274481004,59.738362664926456,59.752797881752514,59.76723309857857,59.78166831540463,59.7961035322307,59.81053874905675,59.82497396588281,59.83940918270887,59.853844399534935,59.868279616360994,59.88271483318705,59.89715005001311,59.91158526683917,59.92602048366523,59.9404557004913,59.95489091731736,59.969326134143415,59.98376135096947,59.99819656779553,60.01263178462159,60.02706700144765,60.04150221827371,60.05593743509978,60.07037265192584,60.084807868751895,60.09924308557795,60.11367830240401,60.12811351923007,60.14254873605613,60.15698395288219,60.17141916970826,60.18585438653432,60.200289603360375,60.21472482018643,60.2291600370125,60.242040982261216,60.25336766003585,60.26469433781048,60.27602101558512,60.287347693359756,60.29867437113439,60.31000104890903,60.321327726683656,60.33265440445829,60.34398108223293,60.35530776000756,60.15151727740052,59.90470336271712,59.65788944803375,59.41107553335037,59.164261618666984,58.91744770398361,58.67063378930023,58.42381987461684,58.17700595993346,57.930192045250074,57.6833781305667,57.43656421588332,57.189750301199936,56.94293638651655,56.696122471833164,56.4493085571498,56.20249464246641,55.955680727783026,55.70886681309965,55.46205289841626,55.215238983732895,54.9684250690495,54.72161115436612,54.47479723968276,54.22798332499936,53.981169410315985,53.7343554956326,53.48754158094921,53.24072766626585,52.99391375158245,52.747099836899075,52.500285922215696,52.25347200753231,52.00665809284894,51.75984417816555,51.51303026348217,51.26621634879879,51.01940243411539,50.77258851943203,50.52577460474865,50.27896069006526,50.03214677538189,49.78533286069849,49.538518946015124,49.29170503133174,49.04489111664836,48.798077201964986,48.551263287281586,48.304449372598214,48.05763545791483,47.81082154323144,47.564007628548076,47.3171937138647,47.07037979918131,46.823565884497924,46.57675196981454,46.329938055131166,46.08312414044779,45.83631022576439,45.58949631108103,45.342682396397635,45.09586848171426,44.849054567030876,44.60224065234749,44.35542673766412,44.108612822980724,43.86179890829735,43.61498499361397,43.368171078930594,43.12135716424722,42.87454324956382,42.62772933488045,42.372381704291655,42.099966692582164,41.82755168087268,41.55513666916318,41.28272165745369,41.010306645744194,40.737891634034696,40.46547662232521,40.193061610615715,39.920646598906224,39.64823158719674,39.32806387565966,38.98401981420882,38.63997575275798,38.29593169130713,37.951887629856294,37.60784356840543,37.2637995069546,36.919755445503746,36.5757113840529,36.23166732260207,35.8876232611512,35.54357919970037,35.19953513824952,34.85549107679867,34.51144701534784,34.16740295389699,33.82335889244614,33.47931483099529,33.13527076954444,32.790491364905996,32.428063134560304,32.06563490421461,31.703206673868934,31.340778443523227,30.978350213177546,30.615921982831857,30.25349375248616,29.891065522140483,29.528637291794777,29.1662090614491,28.803780831103403,28.44135260075771,28.078924370412036,27.71649614006634,27.35406790972065,26.991639679374952,26.629211449029263,26.266783218683585,25.904354988337897,25.5419267579922,25.179498527646523,24.81707029730083,24.454642066955138,24.092213836609442,23.72978560626375,23.367357375918054,23.004929145572383,22.642500915226687,22.28007268488099,21.9176444545353,21.555216224189607,21.192787993843933,20.830359763498237,20.467931533152544,20.105503302806852,19.743075072461174,19.380646842115482,19.01821861176979,18.655790381424094,18.2933621510784,17.930933920732727,17.56850569038703,17.206077460041342,16.843649229695647,16.48122099934997,16.118792769004276,15.756364538658584,15.393936308312892,15.031508077967196,14.66907984762152,14.306651617275827,13.944223386930133,13.58179515658444,13.219366926238747,12.85693869589307,12.494510465547378,12.132082235201684,11.76965400485599,11.407225774510312,11.04479754416462,10.682369313818928,10.319941083473234,9.957512853127541,9.732675153693288,9.645427985170446,9.558180816647589,9.470933648124772,9.388851053040252,9.308539169173509,9.228227285306767,9.147915401440036,9.067603517573271,8.987291633706514,8.906979749839786,8.829236172137474,8.755076935903155,8.680917699668823,8.60675846343452,8.532599227200205,8.458439990965871,8.384280754731535,8.312923261924206,8.244209837579781,8.175496413235335,8.106782988890888,8.038069564546436,7.969356140201991,7.900642715857544,7.818195591326209,7.735748466794851,7.653301342263493,7.570854217732143,7.488407093200785,7.405959968669428,7.323512844138071,7.24106571960672,7.158618595075362,7.076171470543998,6.993724346012647,6.9112772214812965,6.828830096949938,6.746382972418588,6.663935847887238,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[58.986371095661234,59.0008063124873,59.01524152931336,59.029676746139415,59.044111962965474,59.05854717979154,59.0729823966176,59.087417613443655,59.10185283026971,59.11628804709578,59.13072326392184,59.145158480747895,59.15959369757396,59.17402891440001,59.18846413122608,59.20289934805214,59.2173345648782,59.23176978170425,59.24620499853032,59.26064021535638,59.27507543218244,59.2895106490085,59.30394586583456,59.31838108266062,59.33281629948668,59.34725151631274,59.3616867331388,59.376121949964855,59.39055716679091,59.40499238361697,59.41942760044303,59.4338628172691,59.44829803409516,59.46273325092122,59.477168467747276,59.491603684573334,59.50603890139939,59.52047411822545,59.534909335051516,59.54934455187758,59.56377976870364,59.5782149855297,59.592650202355756,59.607085419181814,59.62152063600788,59.63595585283394,59.65039106965999,59.66482628648606,59.67926150331212,59.69369672013817,59.708131936964236,59.722567153790294,59.73700237061636,59.75143758744241,59.76587280426848,59.780308021094534,59.79474323756379,59.806069915338426,59.81739659311306,59.8287232708877,59.840049948662326,59.85137662643697,59.8627033042116,59.87402998198623,59.88535665976087,59.89668333753551,59.90801001531015,59.91933669308478,59.93066337085941,59.941990048634054,59.95331672640869,59.96464340418332,59.97597008195795,59.98729675973259,59.99862343750723,60.00995011528186,60.0212767930565,60.032603470831134,60.04393014860577,60.0552568263804,60.066583504155034,60.07791018192967,60.08923685970431,60.10056353747894,59.89677305487189,59.64995914018849,59.40314522550513,59.15633131082174,58.909517396138355,58.66270348145498,58.415889566771604,58.16907565208822,57.92226173740483,57.67544782272145,57.42863390803808,57.181819993354694,56.93500607867131,56.68819216398792,56.44137824930454,56.19456433462117,55.94775041993778,55.700936505254404,55.45412259057102,55.20730867588763,54.96049476120427,54.71368084652088,54.466866931837494,54.22005301715413,53.97323910247073,53.726425187787356,53.47961127310397,53.232797358420584,52.98598344373722,52.73916952905382,52.492355614370446,52.24554169968707,51.99872778500368,51.75191387032031,51.50509995563692,51.258286040953536,51.01147212627016,50.76465821158678,50.517844296903405,50.27103038222002,50.02421646753663,49.77740255285326,49.53058863816987,49.283774723486495,49.036960808803116,48.79014689411973,48.54333297943636,48.29651906475296,48.049705150069585,47.80289123538621,47.556077320702826,47.309263406019454,47.06244949133607,46.81563557665268,46.5688216619693,46.322007747285916,46.05385958214224,45.78144457043274,45.50902955872324,45.23661454701376,44.964199535304246,44.69178452359476,44.41936951188527,44.146954500175774,43.8745394884663,43.602124476756785,43.3297094650473,43.05729445333781,42.784879441628306,42.51246442991882,42.24004941820931,41.967634406499826,41.69521939479034,41.422804383080845,41.15038937137136,40.87797435966186,40.605559347952365,40.33314433624287,40.060729324533376,39.78831431282389,39.515899301114395,39.243484289404904,38.97106927769542,38.65090156615834,38.30685750470751,37.96281344325666,37.61876938180581,37.274725320354975,36.930681258904116,36.58663719745328,36.24259313600243,35.89854907455158,35.55450501310075,35.210460951649885,34.86641689019905,34.5223728287482,34.17832876729735,33.83428470584652,33.49024064439567,33.146196582944825,32.802152521493966,32.45810846004313,32.11406439859229,31.77002033714144,31.425976275690594,31.081932214239764,30.737888152788898,30.39384409133806,30.04980002988721,29.705755968436364,29.361711906985533,29.017667845534667,28.673623784083837,28.329579722632985,27.98553566118214,27.641491599731307,27.29744753828045,26.953403476829607,26.609359415378755,26.26531535392791,25.92127129247708,25.577227231026225,25.233183169575376,24.889139108124542,24.545095046673694,24.201050985222846,23.857006923771998,23.512962862321146,23.1689188008703,22.824874739419467,22.480830677968616,22.136786616517767,21.79274255506692,21.436197265814734,21.07376903546906,20.711340805123363,20.348912574777668,19.98648434443198,19.6240561140863,19.261627883740605,18.899199653394913,18.53677142304922,18.174343192703528,17.81191496235785,17.449486732012158,17.087058501666466,16.72463027132077,16.362202040975095,15.999773810629401,15.637345580283707,15.274917349938013,14.912489119592323,14.550060889246645,14.187632658900952,13.825204428555258,13.462776198209566,13.100347967863872,12.737919737518196,12.375491507172503,12.01306327682681,11.650635046481115,11.288206816135439,10.925778585789747,10.563350355444053,10.200922125098359,9.838493894752666,9.613656195318413,9.52640902679557,9.442900025645292,9.36258814177853,9.282276257911782,9.201964374045039,9.121652490178297,9.041340606311566,8.9610287224448,8.881690536519448,8.807531300285111,8.733372064050808,8.659212827816491,8.58505359158216,8.510894355347855,8.43673511911354,8.363691729088265,8.294978304743832,8.226264880399361,8.157551456054936,8.08883803171049,8.020124607366043,7.95141118302159,7.873868951414141,7.79142182688279,7.70897470235144,7.626527577820082,7.544080453288724,7.461633328757373,7.379186204226016,7.2967390796946585,7.214291955163301,7.131844830631953,7.049397706100594,6.966950581569228,6.884503457037878,6.802056332506528,6.71960920797517,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[58.7829177657863,58.79735298261236,58.81178819943842,58.82622341626448,58.84065863309054,58.8550938499166,58.86952906674266,58.88396428356872,58.898399500394774,58.91283471722084,58.927269934046905,58.94170515087296,58.95614036769902,58.97057558452508,58.985010801351144,58.999446018177196,59.01388123500326,59.02831645182932,59.042751668655384,59.05718688548144,59.0716221023075,59.08605731913356,59.100492535959624,59.114927752785675,59.12936296961173,59.14379818643779,59.15823340326385,59.17266862008992,59.18710383691598,59.20153905374204,59.2159742705681,59.230409487394155,59.24484470422021,59.25927992104627,59.273715137872344,59.2881503546984,59.30258557152446,59.31702078835052,59.33145600517658,59.345891222002635,59.35877217064101,59.37009884841565,59.381425526190284,59.39275220396492,59.40407888173955,59.415405559514184,59.42673223728882,59.43805891506345,59.449385592838084,59.46071227061272,59.472038948387365,59.483365626162,59.49469230393663,59.506018981711264,59.5173456594859,59.52867233726053,59.539999015035164,59.55132569280981,59.562652370584445,59.57397904835907,59.58530572613371,59.596632403908345,59.60795908168298,59.61928575945761,59.63061243723225,59.64193911500689,59.653265792781525,59.66459247055616,59.67591914833079,59.687245826105425,59.69857250388006,59.70989918165469,59.72122585942934,59.73255253720397,59.743879214978605,59.75520589275324,59.76653257052787,59.777859248302505,59.78918592607714,59.80051260385178,59.81183928162641,59.82316595940105,59.834492637175686,59.84581931495032,59.64202883234327,59.39521491765987,59.148401002976506,58.90158708829312,58.65477317360973,58.40795925892636,58.16114534424298,57.914331429559596,57.66751751487621,57.42070360019282,57.17388968550946,56.92707577082607,56.680261856142685,56.433447941459306,56.18663402677592,55.93982011209255,55.69300619740916,55.446192282725775,55.199378368042396,54.95256445335902,54.705750538675645,54.45893662399226,54.21212270930888,53.9653087946255,53.718494879942114,53.47168096525874,53.224867050575355,52.97805313589197,52.7312392212086,52.4844253065252,52.23761139184183,51.990797477158445,51.743983562475066,51.497169647791694,51.25035573310831,51.00354181842492,50.756727903741535,50.509913989058155,50.26310007437478,50.00775247170229,49.73533745999279,49.46292244828331,49.190507436573796,48.91809242486431,48.64567741315483,48.37326240144533,48.10084738973585,47.828432378026335,47.55601736631685,47.28360235460736,47.01118734289787,46.738772331188386,46.46635731947889,46.19394230776939,45.92152729605989,45.649112284350394,45.37669727264092,45.10428226093142,44.83186724922192,44.55945223751244,44.28703722580293,44.01462221409345,43.74220720238395,43.469792190674454,43.19737717896498,42.924962167255465,42.65254715554598,42.380132143836484,42.10771713212699,41.83530212041751,41.562887108708,41.29047209699851,41.018057085289016,40.745642073579525,40.47322706187004,40.20081205016054,39.92839703845105,39.655982026741555,39.38356701503206,39.11115200332257,38.838736991613075,38.566321979903584,38.29390696819411,37.973739256657026,37.62969519520619,37.28565113375534,36.94160707230449,36.59756301085366,36.25351894940279,35.90947488795196,35.565430826501114,35.22138676505026,34.877342703599425,34.533298642148566,34.189254580697735,33.84521051924688,33.50116645779603,33.1571223963452,32.81307833489436,32.469034273443505,32.12499021199265,31.780946150541805,31.43690208909097,31.09285802764012,30.748813966189275,30.404769904738444,30.060725843287578,29.716681781836744,29.372637720385892,29.028593658935048,28.684549597484214,28.340505536033348,27.996461474582517,27.652417413131666,27.30837335168082,26.964329290229987,26.62028522877913,26.276241167328287,25.932197105877435,25.58815304442659,25.24410898297576,24.900064921524905,24.556020860074057,24.211976798623223,23.867932737172374,23.52388867572153,23.179844614270678,22.835800552819826,22.49175649136898,22.147712429918144,21.8036683684673,21.459624307016448,21.115580245565603,20.77153618411475,20.42749212266392,20.08344806121307,19.73940399976222,19.395359938311373,19.05131587686054,18.70727181540969,18.363227753958842,18.019183692507994,17.675139631057146,17.331095569606312,16.98705150815546,16.643007446704615,16.298963385253764,15.954919323802933,15.610875262352083,15.266831200901233,14.922787139450385,14.578743077999537,14.234699016548703,13.890654955097853,13.546610893647006,13.202566832196158,12.85852277074531,12.514478709294476,12.170434647843628,11.826390586392778,11.482346524941928,11.138302463491094,10.794258402040242,10.444331397069178,10.081903166723485,9.719474936377791,9.496948998250316,9.416637114383548,9.336325230516822,9.256013346650063,9.175701462783314,9.09538957891657,9.015077695049829,8.9347658111831,8.859985664667112,8.785826428432788,8.71166719219845,8.637507955964146,8.563348719729829,8.489189483495498,8.415030247261193,8.345746771907846,8.277033347563421,8.208319923218989,8.139606498874517,8.07089307453009,8.002179650185644,7.929542311502081,7.847095186970737,7.764648062439372,7.6822009379080205,7.599753813376671,7.517306688845315,7.434859564313957,7.352412439782606,7.269965315251248,7.18751819071989,7.105071066188532,7.022623941657183,6.940176817125825,6.857729692594461,6.77528256806311,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[58.57946443591137,58.593899652737434,58.60833486956349,58.62277008638955,58.637205303215616,58.651640520041674,58.66607573686773,58.68051095369379,58.694946170519856,58.709381387345914,58.72381660417197,58.73825182099804,58.752687037824096,58.767122254650154,58.78155747147621,58.79599268830228,58.810427905128336,58.824863121954394,58.83929833878046,58.85373355560652,58.868168772432576,58.882603989258634,58.8970392060847,58.91147442291076,58.92280110371824,58.934127781492876,58.94545445926752,58.95678113704216,58.96810781481679,58.97943449259142,58.990761170366056,59.00208784814069,59.01341452591532,59.02474120368997,59.03606788146459,59.04739455923924,59.05872123701387,59.0700479147885,59.08137459256314,59.09270127033777,59.1040279481124,59.115354625887036,59.12668130366167,59.13800798143632,59.14933465921095,59.160661336985584,59.17198801476022,59.18331469253486,59.19464137030949,59.20596804808412,59.21729472585876,59.22862140363339,59.23994808140803,59.25127475918267,59.2626014369573,59.27392811473194,59.285254792506564,59.296581470281204,59.30790814805584,59.31923482583046,59.33056150360511,59.34188818137974,59.353214859154384,59.36454153692902,59.375868214703644,59.38719489247828,59.39852157025291,59.409848248027544,59.42117492580219,59.432501603576824,59.44382828135146,59.45515495912609,59.466481636900724,59.47780831467537,59.489134992450005,59.50046167022464,59.51178834799927,59.523115025773905,59.53444170354854,59.54576838132317,59.557095059097804,59.56842173687244,59.57974841464707,59.59107509242172,59.38728460981467,59.14047069513127,58.893656780447905,58.64684286576452,58.40002895108113,58.15321503639776,57.906401121714374,57.659587207030995,57.41277329234761,57.16595937766422,56.91914546298086,56.67233154829747,56.425517633614085,56.178703718930706,55.93188980424732,55.68507588956395,55.43826197488056,55.191448060197175,54.944634145513795,54.697820230830416,54.451006316147044,54.20419240146366,53.95737848678027,53.689230349552915,53.41681533784342,53.144400326133926,52.871985314424435,52.59957030271493,52.327155291005454,52.05474027929594,51.78232526758646,51.50991025587697,51.23749524416747,50.965080232457986,50.69266522074849,50.420250209039,50.1478351973295,49.87542018562,49.60300517391052,49.33059016220103,49.05817515049153,48.785760138782045,48.51334512707254,48.24093011536306,47.96851510365356,47.69610009194406,47.42368508023458,47.15127006852507,46.87885505681559,46.6064400451061,46.3340250333966,46.061610021687116,45.78919500997762,45.51677999826812,45.24436498655862,44.97194997484913,44.69953496313965,44.42711995143015,44.15470493972066,43.882289928011176,43.60987491630166,43.33745990459218,43.06504489288269,42.79262988117319,42.52021486946371,42.2477998577542,41.97538484604472,41.70296983433522,41.43055482262572,41.15813981091624,40.88572479920673,40.61330978749725,40.34089477578775,40.068479764078255,39.79606475236877,39.52364974065928,39.25123472894978,38.978819717240285,38.70640470553079,38.43398969382131,38.16157468211181,37.88915967040232,37.61674465869284,37.296576947155756,36.952532885704926,36.60848882425407,36.26444476280322,35.92040070135239,35.576356639901526,35.23231257845069,34.888268516999844,34.544224455549,34.20018039409816,33.8561363326473,33.512092271196465,33.16804820974562,32.82400414829477,32.47996008684394,32.13591602539309,31.791871963942235,31.44782790249139,31.10378384104054,30.759739779589705,30.415695718138853,30.07165165668801,29.727607595237178,29.383563533786315,29.039519472335478,28.695475410884626,28.35143134943378,28.00738728798295,27.66334322653208,27.31929916508125,26.9752551036304,26.63121104217955,26.28716698072872,25.94312291927787,25.599078857827024,25.25503479637617,24.910990734925324,24.566946673474494,24.22290261202364,23.87885855057279,23.534814489121956,23.190770427671108,22.846726366220263,22.50268230476941,22.158638243318563,21.814594181867715,21.47055012041688,21.126506058966033,20.782461997515185,20.438417936064333,20.098884417538564,19.770627363000624,19.442370308462674,19.11411325392472,18.785856199386767,18.457599144848828,18.129342090310875,17.80108503577292,17.472827981234968,17.144570926697018,16.81631387215908,16.488056817621125,16.15979976308317,15.831542708545221,15.503285654007282,15.175028599469327,14.846771544931375,14.518514490393422,14.190257435855468,13.86200038131753,13.533743326779579,13.205486272241625,12.877229217703672,12.548972163165718,12.220715108627779,11.892458054089825,11.564200999551874,11.235943945013922,10.907686890475983,10.57942983593803,10.251172781400076,9.922915726862122,9.594658672324169,9.390374203121851,9.310062319255083,9.22975043538836,9.1494385515216,9.06912666765485,8.988814783788106,8.912440029049097,8.838280792814794,8.764121556580456,8.68996232034613,8.615803084111793,8.54164384787749,8.467484611643172,8.396515239071922,8.327801814727492,8.259088390383006,8.19037496603858,8.121661541694147,8.052948117349676,7.9842346930052495,7.9027685470586775,7.82032142252732,7.737874297995977,7.655427173464612,7.57298004893326,7.490532924401911,7.408085799870554,7.325638675339196,7.243191550807845,7.160744426276488,7.07829730174513,6.9958501772137724,6.9134030526824235,6.830955928151065,6.7485088036197,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[58.37601110603644,58.390446322862495,58.40488153968856,58.41931675651462,58.43375197334068,58.448187190166735,58.4626224069928,58.47550335902083,58.48683003679546,58.498156714570094,58.50948339234473,58.52081007011937,58.532136747894,58.543463425668634,58.554790103443274,58.56611678121791,58.57744345899254,58.58877013676718,58.600096814541814,58.61142349231645,58.62275017009108,58.634076847865714,58.64540352564035,58.65673020341498,58.66805688118962,58.679383558964254,58.690710236738894,58.70203691451353,58.71336359228816,58.724690270062794,58.736016947837435,58.747343625612075,58.75867030338671,58.76999698116134,58.78132365893597,58.79265033671061,58.80397701448524,58.815303692259874,58.826630370034515,58.83795704780914,58.84928372558378,58.86061040335842,58.871937081133055,58.88326375890769,58.89459043668232,58.905917114456955,58.917243792231595,58.92857047000622,58.93989714778086,58.951223825555495,58.962550503330135,58.973877181104776,58.98520385887941,58.996530536654035,59.007857214428675,59.019183892203316,59.03051056997794,59.04183724775258,59.053163925527215,59.06449060330185,59.07581728107648,59.08714395885112,59.098470636625756,59.10979731440039,59.12112399217503,59.13245066994966,59.143777347724296,59.15510402549893,59.16643070327356,59.177757381048195,59.189084058822836,59.20041073659747,59.2117374143721,59.22306409214674,59.234390769921376,59.24571744769601,59.25704412547064,59.268370803245276,59.27969748101991,59.29102415879454,59.30235083656918,59.313677514343816,59.325004192118456,59.33633086989309,59.13254038728604,58.88572647260264,58.63891255791928,58.39209864323589,58.145284728552504,57.89847081386913,57.643123239112974,57.37070822740348,57.098293215693985,56.82587820398449,56.553463192275004,56.28104818056551,56.00863316885601,55.73621815714652,55.46380314543702,55.191388133727536,54.918973122018045,54.64655811030855,54.37414309859905,54.10172808688956,53.829313075180075,53.55689806347058,53.28448305176108,53.012068040051595,52.7396530283421,52.467238016632606,52.194823004923116,51.92240799321361,51.649992981504134,51.37757796979462,51.10516295808514,50.83274794637564,50.56033293466615,50.28791792295666,50.01550291124717,49.74308789953768,49.47067288782818,49.19825787611868,48.9258428644092,48.6534278526997,48.3810128409902,48.10859782928073,47.83618281757122,47.563767805861744,47.29135279415224,47.01893778244275,46.746522770733264,46.47410775902375,46.20169274731427,45.92927773560478,45.65686272389528,45.384447712185796,45.1120327004763,44.8396176887668,44.5672026770573,44.294787665347805,44.02237265363833,43.74995764192883,43.47754263021934,43.20512761850985,42.932712606800344,42.66029759509086,42.38788258338136,42.115467571671864,41.84305255996239,41.57063754825288,41.2982225365434,41.02580752483391,40.7533925131244,40.48097750141492,40.208562489705415,39.936147477995924,39.66373246628643,39.39131745457694,39.11890244286746,38.84648743115797,38.57407241944847,38.30165740773897,38.029242396029474,37.75682738431999,37.48441237261049,37.211997360900995,36.93958234919151,36.61941463765443,36.275370576203606,35.931326514752755,35.58728245330191,35.24323839185107,34.89919433040021,34.555150268949376,34.21110620749853,33.86706214604768,33.52301808459684,33.178974023145976,32.834929961695146,32.4908859002443,32.14684183879345,31.8095635857763,31.481306531238346,31.153049476700392,30.82479242216244,30.49653536762449,30.168278313086546,29.840021258548596,29.511764204010642,29.183507149472703,28.855250094934735,28.5269930403968,28.198735985858846,27.870478931320893,27.542221876782953,27.213964822244986,26.885707767707046,26.557450713169096,26.22919365863114,25.900936604093204,25.572679549555254,25.2444224950173,24.916165440479347,24.587908385941397,24.259651331403454,23.9313942768655,23.603137222327547,23.27488016778961,22.946623113251658,22.618366058713704,22.29010900417575,21.961851949637797,21.633594895099844,21.305337840561904,20.977080786023954,20.648823731486,20.320566676948044,19.992309622410094,19.664052567872158,19.3357955133342,19.007538458796247,18.679281404258298,18.35102434972036,18.022767295182405,17.69451024064445,17.3662531861065,17.037996131568548,16.70973907703061,16.381482022492655,16.0532249679547,15.72496791341675,15.39671085887881,15.068453804340855,14.740196749802903,14.411939695264952,14.083682640726998,13.755425586189059,13.427168531651109,13.098911477113155,12.770654422575202,12.442397368037248,12.114140313499309,11.785883258961356,11.457626204423404,11.129369149885449,10.801112095347513,10.47285504080956,10.144597986271606,9.816340931733652,9.4880838771957,9.283799407993381,9.203487524126617,9.123175640259891,9.042863756393132,8.964894393431068,8.890735157196735,8.816575920962434,8.742416684728129,8.668257448493792,8.594098212259466,8.519938976025129,8.447283706235932,8.378570281891506,8.30985685754708,8.241143433202648,8.172430008858163,8.103716584513736,8.035003160169303,7.958441907146624,7.875994782615274,7.793547658083909,7.711100533552551,7.62865340902121,7.546206284489843,7.463759159958492,7.3813120354271415,7.298864910895785,7.216417786364427,7.133970661833077,7.051523537301719,6.969076412770361,6.886629288239003,6.8041821637076545,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[58.165114279987094,58.17324087817611,58.18136747636513,58.189494074554155,58.19762067274318,58.20574727093219,58.213873869121215,58.22200046731023,58.23012706549926,58.238253663688276,58.24638026711152,58.25770694488616,58.26903362266079,58.280360300435426,58.29168697821006,58.3030136559847,58.31434033375933,58.325667011533966,58.336993689308606,58.34832036708324,58.359647044857866,58.370973722632506,58.38230040040714,58.39362707818177,58.40495375595641,58.416280433731046,58.42760711150568,58.43893378928032,58.45026046705495,58.46158714482959,58.47291382260423,58.48424050037886,58.49556717815349,58.506893855928126,58.51822053370276,58.5295472114774,58.540873889252026,58.55220056702667,58.5635272448013,58.57485392257594,58.58618060035057,58.59750727812521,58.60883395589984,58.62016063367447,58.631487311449106,58.64281398922375,58.65414066699838,58.66546734477302,58.67679402254765,58.68812070032229,58.69944737809692,58.71077405587155,58.72210073364619,58.73342741142082,58.74475408919547,58.75608076697009,58.767407444744734,58.77873412251936,58.790060800294,58.801387478068634,58.81271415584327,58.8240408336179,58.83536751139253,58.84669418916717,58.85802086694181,58.86934754471645,58.88067422249108,58.892000900265714,58.90332757804035,58.91465425581499,58.92598093358962,58.93730761136426,58.948634289138894,58.95996096691353,58.97128764468816,58.982614322462794,58.99394100023743,59.00526767801207,59.0165943557867,59.027921033561334,59.03924771133597,59.05057438911061,59.06190106688524,59.073227744659874,58.84810301453107,58.575688002821565,58.303272991112074,58.03085797940258,57.758442967693085,57.4860279559836,57.21361294427411,56.94119793256461,56.66878292085512,56.39636790914562,56.12395289743614,55.85153788572664,55.579122874017145,55.30670786230765,55.034292850598156,54.76187783888867,54.489462827179175,54.217047815469684,53.944632803760186,53.67221779205069,53.39980278034121,53.127387768631706,52.854972756922216,52.58255774521274,52.31014273350323,52.03772772179374,51.765312710084245,51.492897698374755,51.220482686665264,50.94806767495576,50.67565266324627,50.40323765153678,50.13082263982729,49.858407628117796,49.585992616408305,49.31357760469881,49.04116259298931,48.76874758127981,48.49633256957033,48.22391755786083,47.95150254615134,47.679087534441855,47.40667252273235,47.13425751102287,46.86184249931337,46.58942748760387,46.31701247589439,46.04459746418488,45.7721824524754,45.4997674407659,45.22735242905641,44.954937417346926,44.68252240563743,44.41010739392793,44.13769238221844,43.86527737050894,43.59286235879946,43.32044734708997,43.04803233538047,42.775617323670986,42.50320231196147,42.23078730025199,41.9583722885425,41.685957276833,41.41354226512352,41.14112725341401,40.86871224170453,40.59629722999503,40.32388221828553,40.05146720657605,39.779052194866544,39.50663718315706,39.23422217144756,38.945731713089884,38.6492034722468,38.35267523140371,38.05614699056062,37.759618749717525,37.46309050887443,37.166562268031356,36.87003402718826,36.57350578634517,36.27697754550209,35.968147827782175,35.653167371623866,35.33818691546555,35.02320645930723,34.70822600314893,34.3932455469906,34.078265090832296,33.76328463467398,33.44830417851566,33.13332372235736,32.81834326619903,32.50336281004073,32.18838235388241,31.873401897724097,31.55842144156579,31.243440985407478,30.928460529249158,30.61348007309084,30.298499616932524,29.98351916077422,29.668538704615905,29.35355824845759,29.03857779229929,28.723597336140955,28.408616879982652,28.092161190730387,27.76390413619243,27.43564708165449,27.107390027116523,26.779132972578584,26.45087591804063,26.12261886350268,25.79436180896474,25.466104754426787,25.13784769988884,24.809590645350884,24.48133359081293,24.15307653627499,23.824819481737038,23.496562427199084,23.168305372661152,22.840048318123195,22.51179126358524,22.18353420904729,21.855277154509334,21.52702009997138,21.19876304543344,20.870505990895488,20.542248936357534,20.213991881819585,19.88573482728163,19.55747777274369,19.229220718205738,18.90096366366779,18.572706609129835,18.244449554591895,17.916192500053942,17.587935445515992,17.25967839097804,16.931421336440085,16.603164281902146,16.274907227364192,15.94665017282624,15.618393118288289,15.290136063750348,14.961879009212394,14.633621954674442,14.305364900136489,13.977107845598535,13.648850791060598,13.320593736522646,12.992336681984693,12.664079627446739,12.335822572908786,12.007565518370846,11.679308463832895,11.351051409294941,11.02279435475699,10.69453730021905,10.366280245681097,10.038023191143143,9.70976613660519,9.381509082067238,9.177224612864919,9.096912728998152,9.01734875781308,8.943189521578748,8.869030285344412,8.79487104911008,8.720711812875777,8.646552576641472,8.572393340407135,8.49823410417281,8.429338749055583,8.360625324711092,8.291911900366664,8.223198476022239,8.154485051677808,8.085771627333322,8.01411526723458,7.93166814270322,7.849221018171864,7.766773893640513,7.684326769109148,7.6018796445777905,7.519432520046449,7.436985395515083,7.354538270983733,7.272091146452381,7.1896440219210245,7.107196897389667,7.024749772858316,6.942302648326959,6.8598555237956,6.777408399264243,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[57.94937917929266,57.957505777481686,57.96563237567071,57.97375897385973,57.98188557204875,57.99001217023777,57.998138768426784,58.006265366615814,58.01439196480483,58.02251856299385,58.03064516118287,58.03877175937189,58.04689835756091,58.055024955749936,58.06315155393895,58.07127815212798,58.079404750316996,58.08753134850602,58.09565794669504,58.10378454488406,58.11191114307309,58.1200377412621,58.128164339451125,58.13629093764014,58.144417535829156,58.152544134018186,58.1606707322072,58.17039737489523,58.18172405266987,58.193050730444504,58.20437740821914,58.21570408599378,58.22703076376841,58.238357441543045,58.24968411931768,58.26101079709232,58.272337474866944,58.28366415264158,58.294990830416225,58.30631750819085,58.31764418596549,58.328970863740125,58.34029754151476,58.35162421928939,58.362950897064025,58.37427757483866,58.3856042526133,58.39693093038793,58.408257608162565,58.4195842859372,58.43091096371184,58.44223764148647,58.453564319261105,58.46489099703575,58.476217674810385,58.48754435258502,58.49887103035965,58.510197708134285,58.52152438590892,58.53285106368355,58.544177741458185,58.55550441923282,58.56683109700746,58.5781577747821,58.58948445255673,58.600811130331365,58.612137808106,58.62346448588063,58.634791163655265,58.6461178414299,58.65744451920454,58.66877119697918,58.68009787475381,58.691424552528446,58.70275123030308,58.71407790807772,58.725404585852345,58.73673126362698,58.748057941401626,58.75938461917626,58.77071129695089,58.782037974725526,58.79336465250016,58.80469133027479,58.579566600145995,58.30715158843648,58.034736576727,57.7623215650175,57.48990655330801,57.21749154159852,56.94507652988903,56.67266151817953,56.40024650647003,56.12783149476054,55.85541648305105,55.583001471341554,55.31058645963206,55.038171447922565,54.76575643621307,54.49334142450358,54.22092641279409,53.948511401084595,53.676096389375104,53.403681377665606,53.13126636595612,52.858851354246625,52.586436342537134,52.31402133082764,52.041606319118145,51.76919130740866,51.49677629569916,51.224361283989666,50.95194627228018,50.67953126057067,50.40711624886119,50.1347012371517,49.8622862254422,49.58987121373272,49.31745620202322,49.045041190313725,48.77262617860423,48.50021116689473,48.227796155185246,47.955381143475755,47.68296613176626,47.41055112005677,47.13813610834727,46.865721096637785,46.59330608492829,46.32089107321879,46.048476061509305,45.77606104979981,45.50364603809032,45.231231026380826,44.95881601467133,44.686401002961844,44.413985991252346,44.14157097954285,43.869155967833365,43.59674095612386,43.32030710835431,43.023778867511204,42.727250626668116,42.430722385825035,42.134194144981926,41.83766590413885,41.54113766329576,41.24460942245267,40.94808118160959,40.65155294076648,40.355024699923405,40.05849645908032,39.761968218237215,39.465439977394134,39.16891173655104,38.87238349570796,38.57585525486486,38.279327014021774,37.98279877317869,37.6862705323356,37.38974229149251,37.093214050649415,36.79668580980632,36.500157568963246,36.20362932812015,35.907101087277056,35.61057284643398,35.30174312871406,34.986762672555756,34.67178221639744,34.35680176023912,34.04182130408083,33.72684084792249,33.411860391764186,33.09687993560587,32.78189947944755,32.46691902328925,32.15193856713092,31.836958110972617,31.521977654814304,31.206997198655987,30.89201674249768,30.577036286339368,30.262055830181048,29.94707537402273,29.632094917864414,29.31711446170611,29.002134005547795,28.68715354938948,28.372173093231176,28.057192637072845,27.742212180914542,27.427231724756226,27.11225126859791,26.797270812439606,26.482290356281275,26.167309900122973,25.852329443964656,25.53734898780634,25.22236853164804,24.90738807548972,24.592407619331404,24.27742716317309,23.962446707014767,23.647466250856468,23.33248579469815,23.017505338539834,22.70252488238153,22.387544426223215,22.0725639700649,21.757583513906585,21.442603057748265,21.12762260158995,20.812642145431646,20.49766168927333,20.18268123311501,19.867700776956696,19.55272032079838,19.237739864640076,18.92275940848176,18.607778952323446,18.292798496165126,17.977818040006824,17.662837583848507,17.34785712769019,17.032876671531874,16.717896215373557,16.402915759215254,16.08793530305694,15.772954846898624,15.457974390740304,15.142993934582002,14.82801347842369,14.51303302226537,14.198052566107053,13.870533050470064,13.542275995932128,13.214018941394174,12.885761886856223,12.55750483231827,12.229247777780314,11.900990723242378,11.572733668704425,11.244476614166471,10.916219559628518,10.58796250509058,10.259705450552625,9.931448396014675,9.60319134147672,9.274934286938768,9.070649817736447,8.995643885960682,8.921484649726416,8.847325413492085,8.773166177257746,8.699006941023415,8.624847704789111,8.550688468554808,8.480107216219588,8.411393791875168,8.342680367530736,8.273966943186245,8.205253518841818,8.136540094497393,8.06782667015296,7.987341502791154,7.904894378259804,7.822447253728446,7.740000129197088,7.657553004665739,7.575105880134373,7.492658755603014,7.4102116310716735,7.3277645065403085,7.245317382008957,7.162870257477606,7.080423132946249,6.9979760084148905,6.915528883883541,6.833081759352185,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[57.733644078598246,57.74177067678727,57.749897274976284,57.7580238731653,57.76615047135432,57.774277069543345,57.78240366773237,57.79053026592139,57.79865686411041,57.80678346229943,57.81491006048845,57.82303665867747,57.83116325686649,57.83928985505551,57.847416453244534,57.85554305143356,57.86366964962257,57.871796247811595,57.87992284600061,57.88804944418964,57.896176042378656,57.90430264056768,57.912429238756694,57.92055583694572,57.92868243513474,57.93680903332376,57.94493563151278,57.95306222970181,57.961188827890815,57.969315426079845,57.97744202426887,57.98556862245788,57.99369522064691,58.00182181883592,58.00994841702495,58.01807501521397,58.02620161340299,58.03432821159201,58.04245480978103,58.05058140797005,58.05870800615907,58.06683460434809,58.07496120253711,58.08308780490432,58.09441448267896,58.10574116045359,58.11706783822822,58.128394516002864,58.1397211937775,58.15104787155214,58.16237454932677,58.173701227101404,58.18502790487604,58.19635458265067,58.2076812604253,58.21900793819994,58.23033461597457,58.24166129374921,58.25298797152385,58.264314649298484,58.27564132707312,58.28696800484775,58.298294682622384,58.309621360397024,58.320948038171665,58.3322747159463,58.34360139372093,58.354928071495564,58.3662547492702,58.37758142704483,58.388908104819464,58.400234782594104,58.411561460368745,58.42288813814338,58.43421481591801,58.445541493692645,58.45686817146728,58.46819484924191,58.479521527016544,58.49084820479118,58.50217488256581,58.51350156034046,58.52482823811509,58.536154915889725,58.31103018576091,58.03861517405141,57.76620016234192,57.49378515063243,57.22137013892293,56.948955127213445,56.676540115503954,56.404125103794456,56.131710092084965,55.85929508037547,55.586880068665984,55.314465056956486,55.042050045246995,54.7696350335375,54.497220021828,54.22480501011852,53.95238999840902,53.67997498669953,53.407559974990036,53.13514496328054,52.862729951571055,52.59031493986156,52.31789992815206,52.045484916442575,51.77306990473307,51.50065489302359,51.22823988131409,50.9558248696046,50.683409857895114,50.4109948461856,50.13857983447612,49.86616482276662,49.59374981105712,49.32133479934764,49.04891978763815,48.77650477592865,48.50408976421916,48.23167475250966,47.95925974080018,47.68684472909068,47.39835426277561,47.10182602193254,46.80529778108943,46.50876954024635,46.21224129940325,45.915713058560165,45.619184817717084,45.32265657687398,45.0261283360309,44.729600095187806,44.43307185434472,44.13654361350164,43.84001537265855,43.543487131815446,43.24695889097236,42.95043065012927,42.65390240928619,42.3573741684431,42.0608459276,41.764317686756925,41.46778944591382,41.17126120507074,40.87473296422765,40.57820472338456,40.28167648254148,39.98514824169837,39.688620000855295,39.3920917600122,39.095563519169104,38.79903527832603,38.50250703748292,38.20597879663984,37.90945055579675,37.61292231495366,37.316394074110576,37.01986583326749,36.72333759242439,36.4268093515813,36.13028111073821,35.83375286989513,35.53722462905204,35.240696388208946,34.94416814736587,34.63533842964594,34.320357973487646,34.005377517329336,33.69039706117101,33.37541660501272,33.06043614885438,32.745455692696076,32.43047523653776,32.11549478037944,31.80051432422114,31.48553386806281,31.170553411904507,30.85557295574619,30.540592499587877,30.22561204342957,29.910631587271254,29.595651131112938,29.280670674954628,28.965690218796304,28.650709762638,28.335729306479685,28.02074885032137,27.705768394163066,27.390787938004735,27.075807481846432,26.760827025688116,26.4458465695298,26.130866113371496,25.815885657213165,25.500905201054863,25.185924744896546,24.87094428873823,24.55596383257993,24.240983376421614,23.926002920263294,23.611022464104977,23.29604200794666,22.98106155178836,22.66608109563004,22.351100639471724,22.03612018331342,21.72113972715511,21.40615927099679,21.09117881483847,20.776198358680155,20.461217902521838,20.146237446363536,19.83125699020522,19.516276534046902,19.201296077888586,18.88631562173027,18.571335165571966,18.25635470941365,17.941374253255333,17.62639379709702,17.311413340938714,16.996432884780397,16.68145242862208,16.366471972463767,16.051491516305447,15.736511060147144,15.421530603988828,15.106550147830514,14.791569691672194,14.476589235513893,14.161608779355577,13.860910585191428,13.566977739557128,13.273044893922826,12.97911204828854,12.685179202654243,12.391246357019943,12.097313511385645,11.803380665751341,11.509447820117057,11.215514974482756,10.921582128848456,10.627649283214156,10.33371643757987,10.03978359194557,9.74585074631127,9.451917900676971,9.157985055042673,8.973939014108359,8.89977977787402,8.825620541639752,8.751461305405423,8.677302069171084,8.603142832936753,8.530875683383668,8.462162259039237,8.393448834694746,8.324735410350325,8.256021986005893,8.187308561661402,8.118595137316975,8.043014862879106,7.960567738347749,7.878120613816392,7.795673489285043,7.713226364753684,7.630779240222326,7.548332115690977,7.465884991159612,7.383437866628253,7.300990742096912,7.218543617565546,7.136096493034195,7.053649368502845,6.971202243971487,6.8887551194401295,6.806307994908779,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[57.51790897790383,57.52603557609285,57.534162174281875,57.54228877247089,57.55041537065992,57.558541968848935,57.56666856703795,57.57479516522697,57.582921763415996,57.59104836160502,57.59917495979404,57.607301557983064,57.61542815617208,57.62355475436111,57.631681352550125,57.63980795073914,57.64793454892816,57.656061147117185,57.66418774530621,57.67231434349523,57.680440941684246,57.68856753987327,57.696694138062284,57.70482073625131,57.71294733444033,57.72107393262935,57.72920053081837,57.7373271290074,57.745453727196406,57.75358032538543,57.76170692357446,57.76983352176347,57.777960119952496,57.78608671814152,57.794213316330534,57.802339914519564,57.81046651270857,57.818593110897595,57.82671970908662,57.83484630727563,57.84297290546466,57.85109950365368,57.8592261018427,57.867352700031724,57.87547929822074,57.88360589640976,57.891732494598784,57.8998590927878,57.90798569097682,57.91611228916585,57.92423888735487,57.93236548554388,57.94049208373291,57.94861868192193,57.95674528011095,57.964871878299974,57.97299847648899,57.98112507467802,57.98925167286703,57.99737827105606,58.00710491268806,58.0184315904627,58.02975826823733,58.04108494601196,58.052411623786604,58.06373830156124,58.07506497933587,58.086391657110504,58.09771833488514,58.10904501265977,58.12037169043441,58.131698368209044,58.14302504598368,58.15435172375832,58.16567840153295,58.17700507930759,58.18833175708222,58.19965843485685,58.21098511263149,58.222311790406124,58.23363846818076,58.2449651459554,58.25629182373003,58.267618501504664,58.04249377137585,57.770078759666355,57.497663747956864,57.22524873624737,56.952833724537875,56.68041871282839,56.4080037011189,56.1355886894094,55.863173677699905,55.59075866599041,55.31834365428093,55.045928642571425,54.773513630861935,54.501098619152444,54.22868360744294,53.95626859573346,53.683853584023964,53.41143857231447,53.139023560604976,52.86660854889548,52.594193537185994,52.3217785254765,52.049363513767005,51.772929658040084,51.47640141719698,51.1798731763539,50.883344935510806,50.58681669466772,50.29028845382464,49.993760212981535,49.697231972138454,49.40070373129536,49.10417549045227,48.80764724960919,48.5111190087661,48.214590767923006,47.91806252707991,47.621534286236816,47.32500604539374,47.02847780455065,46.73194956370756,46.435421322864485,46.138893082021376,45.842364841178295,45.5458366003352,45.249308359492105,44.95278011864903,44.65625187780593,44.35972363696285,44.06319539611975,43.766667155276664,43.47013891443358,43.17361067359049,42.87708243274739,42.580554191904305,42.28402595106121,41.987497710218136,41.69096946937505,41.394441228531946,41.097912987688865,40.80138474684576,40.50485650600268,40.208328265159594,39.911800024316506,39.61527178347342,39.318743542630315,39.022215301787234,38.72568706094415,38.42915882010105,38.13263057925798,37.83610233841487,37.53957409757179,37.24304585672869,36.946517615885604,36.64998937504252,36.35346113419943,36.05693289335635,35.760404652513245,35.46387641167016,35.16734817082708,34.87081992998398,34.57429168914089,34.27776344829782,33.96893373057789,33.653953274419585,33.33897281826127,33.02399236210295,32.70901190594466,32.394031449786326,32.079050993628016,31.764070537469703,31.44909008131139,31.13410962515308,30.81912916899475,30.504148712836447,30.189168256678137,29.87418780051982,29.559207344361514,29.244226888203197,28.92924643204488,28.614265975886568,28.299285519728247,27.984305063569945,27.66932460741163,27.354344151253315,27.039363695095005,26.724383238936674,26.409402782778372,26.094422326620055,25.77944187046174,25.464461414303436,25.149480958145112,24.83450050198681,24.519520045828486,24.20453958967017,23.889559133511867,23.57457867735355,23.259598221195237,22.94461776503692,22.629637308878607,22.314656852720304,21.99967639656198,21.701233309230783,21.4073004635965,21.113367617962197,20.8194347723279,20.5255019266936,20.2315690810593,19.937636235424996,19.643703389790712,19.349770544156417,19.055837698522115,18.761904852887813,18.467972007253515,18.174039161619227,17.88010631598493,17.586173470350627,17.292240624716328,16.998307779082044,16.704374933447742,16.410442087813443,16.116509242179145,15.822576396544845,15.528643550910559,15.234710705276258,14.940777859641958,14.646845014007656,14.352912168373372,14.058979322739072,13.765046477104772,13.471113631470471,13.177180785836171,12.883247940201885,12.589315094567587,12.295382248933285,12.001449403298986,11.707516557664686,11.4135837120304,11.119650866396102,10.825718020761801,10.5317851751275,10.237852329493213,9.943919483858915,9.649986638224615,9.356053792590314,9.062120946956014,8.878074906021704,8.803915669787363,8.729756433553097,8.655597197318766,8.58164415054774,8.512930726203255,8.444217301858826,8.375503877514396,8.306790453169905,8.238077028825483,8.169363604481052,8.098688222967056,8.016241098435698,7.933793973904347,7.851346849372989,7.768899724841633,7.6864526003102815,7.604005475778924,7.521558351247567,7.439111226716216,7.356664102184851,7.274216977653494,7.1917698531221514,7.109322728590786,7.026875604059435,6.944428479528084,6.861981354996727,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[57.3021738772094,57.31030047539843,57.31842707358744,57.32655367177646,57.33468026996548,57.34280686815451,57.35093346634352,57.35906006453254,57.36718666272157,57.37531326091059,57.38343985909961,57.39156645728863,57.39969305547765,57.40781965366667,57.415946251855694,57.424072850044716,57.43219944823373,57.440326046422754,57.44845264461178,57.45657924280079,57.464705840989815,57.47283243917884,57.48095903736786,57.48908563555687,57.497212233745906,57.50533883193492,57.51346543012394,57.521592028312966,57.529718626501975,57.537845224691,57.54597182288002,57.55409842106904,57.562225019258065,57.57035161744707,57.5784782156361,57.58660481382513,57.59473141201415,57.602858010203164,57.61098460839219,57.61911120658121,57.62723780477023,57.63536440295925,57.64349100114828,57.65161759933729,57.659744197526315,57.66787079571533,57.67599739390435,57.68412399209337,57.69225059028239,57.70037718847142,57.70850378666044,57.71663038484945,57.724756983038475,57.7328835812275,57.74101017941652,57.74913677760554,57.75726337579456,57.76538997398358,57.773516572172596,57.781643170361626,57.78976976855064,57.797896366739664,57.80602296492869,57.8141495631177,57.822276161306725,57.83040275949575,57.83852935768477,57.846655955873786,57.85478255406281,57.86290915225183,57.871035750440846,57.87916234862987,57.88728894681889,57.895415545007914,57.90354214319693,57.91166874138595,57.91979534269714,57.931122020471776,57.94244869824641,57.95377537602104,57.96510205379568,57.976428731570316,57.987755409344956,57.99908208711959,57.77395735699078,57.50154234528127,57.22912733357179,56.95671232186229,56.68429731015279,56.41188229844332,56.13946728673382,55.8509768124614,55.5544485716183,55.25792033077521,54.96139208993213,54.66486384908904,54.36833560824594,54.071807367402855,53.77527912655976,53.478750885716686,53.18222264487359,52.885694404030495,52.5891661631874,52.29263792234431,51.99610968150123,51.69958144065814,51.403053199815055,51.106524958971974,50.809996718128865,50.513468477285784,50.216940236442696,49.92041199559961,49.62388375475652,49.32735551391342,49.03082727307034,48.73429903222725,48.43777079138415,48.14124255054108,47.844714309697984,47.54818606885489,47.2516578280118,46.955129587168706,46.658601346325625,46.36207310548254,46.06554486463944,45.76901662379637,45.47248838295326,45.175960142110185,44.87943190126709,44.582903660423995,44.28637541958092,43.98984717873782,43.69331893789473,43.39679069705164,43.100262456208554,42.803734215365466,42.50720597452238,42.21067773367929,41.91414949283619,41.6176212519931,41.321093011150026,41.02456477030693,40.728036529463836,40.43150828862076,40.134980047777645,39.83845180693457,39.541923566091484,39.24539532524839,38.94886708440531,38.652338843562205,38.355810602719124,38.059282361876036,37.76275412103294,37.46622588018986,37.16969763934675,36.87316939850368,36.57664115766059,36.280112916817494,35.98358467597441,35.687056435131325,35.39052819428823,35.093999953445135,34.79747171260205,34.500943471758966,34.20441523091587,33.90788699007278,33.6113587492297,33.30252903150978,32.987548575351475,32.67256811919316,32.35758766303485,32.042607206876546,31.727626750718212,31.41264629455991,31.097665838401596,30.782685382243276,30.467704926084973,30.152724469926643,29.837744013768344,29.541556033270133,29.247623187635835,28.953690342001547,28.65975749636725,28.365824650732947,28.07189180509865,27.777958959464346,27.484026113830062,27.190093268195763,26.896160422561465,26.602227576927177,26.308294731292868,26.014361885658577,25.72042904002428,25.42649619438998,25.132563348755692,24.83863050312138,24.544697657487095,24.25076481185279,23.956831966218495,23.662899120584207,23.36896627494991,23.075033429315607,22.781100583681308,22.487167738047006,22.193234892412722,21.89930204677842,21.605369201144125,21.311436355509837,21.01750350987553,20.723570664241237,20.429637818606935,20.135704972972636,19.841772127338338,19.547839281704046,19.25390643606975,18.95997359043545,18.66604074480115,18.37210789916685,18.07817505353256,17.784242207898263,17.49030936226396,17.196376516629662,16.90244367099538,16.60851082536108,16.314577979726778,16.02064513409248,15.72671228845818,15.432779442823893,15.138846597189593,14.844913751555293,14.550980905920992,14.257048060286706,13.963115214652408,13.669182369018106,13.375249523383808,13.08131667774951,12.787383832115221,12.493450986480921,12.199518140846621,11.905585295212322,11.611652449578022,11.317719603943736,11.023786758309438,10.729853912675136,10.435921067040837,10.14198822140655,9.848055375772251,9.55412253013795,9.26018968450365,8.96625683886935,8.782210797935038,8.708051561700698,8.633892325466434,8.563699193367325,8.494985769022893,8.426272344678408,8.35755892033398,8.288845495989548,8.220132071645057,8.151418647300638,8.071914458523638,7.989467333992286,7.907020209460928,7.824573084929578,7.74212596039822,7.659678835866863,7.577231711335513,7.494784586804156,7.412337462272798,7.329890337741448,7.247443213210083,7.164996088678725,7.082548964147382,7.0001018396160175,6.917654715084666,6.835207590553315,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[57.0750564927796,57.083183090968625,57.09130968915764,57.09943628734666,57.107562885535685,57.11568948372471,57.12381608191372,57.13194268010274,57.14006927829176,57.148195876480784,57.15632247466981,57.16444907285883,57.17257567104785,57.180702269236875,57.18882886742588,57.19695546561491,57.20508206380393,57.21320866199295,57.221335260181974,57.229461858370996,57.23758845656001,57.24571505474904,57.25384165293805,57.26196825112707,57.270094849316095,57.27822144750512,57.28634804569414,57.29447464388316,57.302601242072186,57.310727840261194,57.31885443845022,57.32698103663924,57.33510763482826,57.343234233017284,57.3513608312063,57.35948742939532,57.367614027584345,57.37574062577337,57.38386722396239,57.391993822151406,57.40012042034043,57.40824701852945,57.416373616718474,57.42450021490749,57.432626813096505,57.440753411285534,57.44888000947455,57.45700660766357,57.465133205852595,57.47325980404162,57.48138640223064,57.489513000419656,57.497639598608686,57.505766196797694,57.513892794986724,57.52201939317574,57.53014599136476,57.538272589553785,57.5463991877428,57.55452578593183,57.562652384120845,57.57077898230987,57.57890558049889,57.587032178687906,57.59515877687693,57.60328537506595,57.611411973254974,57.61953857144399,57.62766516963301,57.635791767822035,57.64391836601105,57.65204496420007,57.660171562389095,57.66829816057812,57.675889211703144,57.680802511878966,57.68571581205479,57.69062911223062,57.69554241240644,57.70045571258227,57.7053690127581,57.71028231293392,57.71519561310974,57.72010891328557,57.45690612416486,57.14008011718484,56.823254110204836,56.50642810322483,56.18960209624481,55.87277608926482,55.5559500822848,55.239124075304794,54.92229806832478,54.61562096086765,54.31909272002458,54.02256447918148,53.726036238338395,53.4295079974953,53.132979756652205,52.83645151580913,52.539923274966036,52.24339503412295,51.94686679327985,51.650338552436764,51.35381031159368,51.05728207075059,50.7607538299075,50.46422558906442,50.16769734822131,49.871169107378236,49.57464086653514,49.27811262569205,48.98158438484897,48.68505614400586,48.38852790316278,48.091999662319694,47.795471421476606,47.498943180633525,47.20241493979043,46.905886698947334,46.609358458104246,46.31283021726115,46.01630197641808,45.719773735574975,45.42324549473189,45.12671725388881,44.830189013045704,44.53366077220262,44.237132531359535,43.94060429051644,43.64407604967336,43.34754780883026,43.051019567987176,42.75449132714409,42.45796308630099,42.16143484545792,41.86490660461482,41.56837836377173,41.27185012292864,40.97532188208555,40.678793641242464,40.382265400399376,40.085737159556274,39.7892089187132,39.4926806778701,39.19615243702702,38.89962419618393,38.603095955340834,38.30656771449775,38.01003947365465,37.71351123281157,37.41698299196848,37.120454751125386,36.823926510282305,36.5273982694392,36.23087002859612,35.93434178775303,35.63781354690994,35.34128530606686,35.04475706522376,34.748228824380675,34.45170058353758,34.15517234269449,33.85864410185141,33.562115861008316,33.26558762016522,32.96905937932215,32.67936213389093,32.39308038616569,32.10679863844043,31.820516890715172,31.53423514298993,31.24795339526466,30.961671647539415,30.67538989981416,30.3891081520889,30.10282640436366,29.816544656638392,29.53026290891314,29.24398116118789,28.95769941346263,28.671417665737387,28.385135918012132,28.098854170286877,27.81257242256162,27.526290674836364,27.240008927111116,26.953727179385858,26.667445431660603,26.381163683935362,26.094881936210086,25.80860018848485,25.522318440759594,25.23603669303433,24.94975494530909,24.66347319758382,24.37719144985857,24.090909702133317,23.804627954408062,23.518346206682818,23.23206445895756,22.9457827112323,22.659500963507043,22.373219215781788,22.086937468056547,21.80065572033129,21.509505093057456,21.21557224742317,20.921639401788873,20.62770655615457,20.333773710520273,20.039840864885974,19.745908019251672,19.451975173617384,19.158042327983086,18.864109482348784,18.570176636714486,18.276243791080184,17.982310945445903,17.6883780998116,17.3944452541773,17.100512408543,16.806579562908716,16.512646717274414,16.218713871640112,15.924781026005814,15.630848180371515,15.336915334737231,15.04298248910293,14.74904964346863,14.455116797834329,14.161183952200043,13.867251106565742,13.573318260931444,13.279385415297144,12.985452569662844,12.691519724028558,12.397586878394259,12.103654032759959,11.809721187125659,11.515788341491358,11.221855495857072,10.927922650222772,10.633989804588472,10.340056958954172,10.046124113319888,9.752191267685587,9.458258422051287,9.164325576416987,8.870392730782687,8.686346689848373,8.614467660531334,8.545754236186907,8.477040811842482,8.408327387498051,8.339613963153564,8.270900538809137,8.202187114464706,8.127587818611575,8.045140694080226,7.962693569548868,7.880246445017518,7.797799320486161,7.71535219595481,7.632905071423452,7.550457946892094,7.468010822360744,7.385563697829387,7.30311657329803,7.22066944876668,7.138222324235314,7.055775199703956,6.973328075172613,6.8908809506412485,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[56.839199138532635,56.84732573672164,56.855452334910666,56.86357893309969,56.87170553128871,56.879832129477734,56.88795872766675,56.89608532585578,56.9042119240448,56.91233852223381,56.92046512042285,56.928591718611855,56.93671831680088,56.9448449149899,56.952971513178916,56.961098111367946,56.969224709556954,56.977351307745984,56.985477905935,56.99360450412402,57.001731102313045,57.00985770050207,57.01798429869108,57.02611089688011,57.03423749506912,57.04236409325815,57.050490691447166,57.05861728963619,57.06674388782521,57.07487048601423,57.08299708420326,57.091123682392265,57.09925028058129,57.10737687877031,57.11550347695933,57.123630075148355,57.13175667333737,57.139883271526394,57.148009869715416,57.15613646790443,57.164263066093454,57.17238966428248,57.1805162624715,57.18864286066052,57.19676945884954,57.20489605703856,57.21302265522758,57.2211492534166,57.22927585160562,57.237402449794644,57.245529047983666,57.25365564617268,57.26178224436171,57.26990884255073,57.27803544073975,57.286162038928765,57.29428863711779,57.30241523530681,57.30839963689504,57.31331293707087,57.31822623724669,57.32313953742252,57.32805283759834,57.332966137774164,57.33787943795,57.34279273812582,57.347706038301645,57.352619338477474,57.357532638653296,57.362445938829126,57.367359239004955,57.37227253918078,57.3771858393566,57.38209913953243,57.38701243970826,57.39192573988408,57.3968390400599,57.40175234023573,57.40666564041155,57.41157894058738,57.416492240763205,57.421405540939034,57.426318841114856,57.43123214129068,57.168029352169974,56.85120334518995,56.53437733820995,56.217551331229934,55.900725324249926,55.58389931726993,55.267073310289916,54.9502473033099,54.63342129632989,54.316595289349884,53.99976928236988,53.682943275389874,53.36611726840985,53.04929126142984,52.732465254449835,52.415639247469834,52.09881324048982,51.78198723350981,51.4651612265298,51.14833521954979,50.831509212569784,50.514683205589776,50.19785719860976,49.881031191629766,49.56420518464974,49.247379190775064,48.95085094993197,48.65432270908889,48.3577944682458,48.06126622740269,47.764737986559616,47.46820974571652,47.17168150487343,46.875153264030345,46.578625023187264,46.28209678234417,45.985568541501074,45.68904030065798,45.3925120598149,45.09598381897181,44.79945557812872,44.50292733728565,44.20639909644254,43.90987085559945,43.61334261475637,43.31681437391327,43.02028613307019,42.72375789222709,42.427229651384,42.13070141054092,41.83417316969782,41.537644928854746,41.24111668801165,40.944588447168556,40.64806020632547,40.35153196548238,40.05500372463929,39.758475483796204,39.461947242953116,39.16541900211003,38.868890761266925,38.572362520423845,38.27583427958076,37.97930603873766,37.68277779789458,37.38624955705148,37.0897213162084,36.79319307536531,36.49666483452221,36.20013659367913,35.90360835283603,35.60708011199295,35.31055187114986,35.01402363030677,34.717495389463686,34.4209671486206,34.1244389077775,33.82791066693441,33.53138242609132,33.23485418524824,32.93832594440515,32.641797703562055,32.345269462718974,32.05557221728776,31.769290469562517,31.48300872183726,31.196726974112003,30.91044522638676,30.624163478661487,30.337881730936246,30.051599983210984,29.76531823548573,29.479036487760492,29.19275474003522,28.906472992309975,28.62019124458472,28.333909496859462,28.04762774913421,27.76134600140896,27.4750642536837,27.188782505958446,26.90250075823319,26.61621901050794,26.32993726278269,26.04365551505743,25.757373767332183,25.471092019606914,25.184810271881673,24.89852852415642,24.612246776431157,24.325965028705912,24.039683280980647,23.7534015332554,23.467119785530144,23.180838037804886,22.894556290079645,22.608274542354387,22.32199279462913,22.03571104690387,21.749429299178615,21.46314755145337,21.176865803728116,20.890584056002858,20.604302308277617,20.318020560552355,20.031738812827104,19.745457065101842,19.459175317376587,19.17289356965133,18.88661182192609,18.60033007420083,18.31404832647557,18.027766578750317,17.74148483102506,17.455203083299814,17.16892133557456,16.8826395878493,16.596357840124043,16.310076092398802,16.023794344673544,15.737512596948287,15.45123084922303,15.164949101497774,14.878667353772528,14.592385606047273,14.306103858322015,14.01982211059676,13.733540362871514,13.447258615146257,13.160976867421002,12.874695119695744,12.588413371970486,12.302131624245245,12.015849876519987,11.72956812879473,11.443286381069472,11.157004633344215,10.870722885618973,10.592225684811341,10.33071284890625,10.069200013001161,9.807687177096085,9.546174341190994,9.284661505285905,9.023148669380815,8.761635833475728,8.596522703350983,8.527809279006492,8.459095854662067,8.39038243031764,8.32166900597321,8.252955581628724,8.183261178699532,8.100814054168174,8.018366929636816,7.935919805105467,7.853472680574108,7.771025556042757,7.6885784315114005,7.606131306980051,7.523684182448692,7.441237057917335,7.358789933385984,7.2763428088546265,7.193895684323269,7.111448559791919,7.029001435260554,6.946554310729196,6.864107186197854,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[56.60334178428565,56.61146838247467,56.61959498066368,56.6277215788527,56.63584817704172,56.643974775230745,56.65210137341977,56.66022797160878,56.668354569797806,56.67648116798682,56.68460776617585,56.69273436436487,56.70086096255389,56.70898756074291,56.717114158931935,56.72524075712096,56.73336735530997,56.741493953498995,56.74962055168801,56.75774714987704,56.765873748066056,56.77400034625508,56.782126944444094,56.79025354263312,56.79838014082213,56.80650673901116,56.814633337200185,56.8227599353892,56.83088653357822,56.839013131767246,56.84713972995626,56.855266328145284,56.863392926334306,56.87151952452332,56.879646122712344,56.88777272090137,56.89589931909039,56.90402591727941,56.91215251546843,56.92027911365744,56.92840571184647,56.935996761911106,56.940910062086935,56.94582336226276,56.95073666243858,56.95564996261441,56.96056326279024,56.96547656296606,56.97038986314188,56.97530316331772,56.980216463493534,56.98512976366937,56.99004306384519,56.994956364021014,56.999869664196844,57.004782964372666,57.009696264548495,57.01460956472432,57.01952286490014,57.02443616507597,57.02934946525179,57.03426276542763,57.03917606560344,57.04408936577927,57.0490026659551,57.05391596613093,57.058829266306745,57.063742566482574,57.0686558666584,57.073569166834226,57.078482467010055,57.08339576718588,57.088309067361706,57.09322236753753,57.09813566771335,57.10304896788918,57.10796226806501,57.11287556824083,57.11778886841665,57.12270216859248,57.127615468768305,57.13252876894413,57.137442069119956,57.142355369295785,56.879152580175074,56.56232657319505,56.24550056621505,55.92867455923505,55.611848552255026,55.29502254527503,54.978196538295016,54.66137053131501,54.34454452433499,54.02771851735498,53.71089251037498,53.394066503394974,53.07724049641495,52.76041448943494,52.44358848245493,52.12676247547493,51.80993646849492,51.49311046151491,51.176284454534894,50.85945844755489,50.54263244057489,50.225806433594876,49.90898042661486,49.592154419634866,49.275328412654844,48.95850240567484,48.64167639869483,48.32485039171482,48.008024384734824,47.691198377754795,47.37437237077479,47.05754636379478,46.740720356814776,46.42389434983477,46.10706834285476,45.790242335874744,45.473416328894736,45.15659032191472,44.839764314934726,44.52293830795471,44.2061123009747,43.88928629399471,43.58260917983931,43.28608093899623,42.98955269815314,42.693024457310045,42.396496216466964,42.09996797562386,41.80343973478078,41.50691149393769,41.210383253094605,40.913855012251524,40.61732677140843,40.320798530565334,40.024270289722246,39.72774204887915,39.43121380803608,39.13468556719298,38.83815732634989,38.541629085506806,38.2451008446637,37.94857260382062,37.652044362977534,37.35551612213444,37.05898788129136,36.762459640448256,36.465931399605175,36.16940315876209,35.87287491791899,35.57634667707592,35.27981843623281,34.98329019538973,34.68676195454664,34.390233713703545,34.093705472860464,33.79717723201737,33.50064899117428,33.204120750331185,32.9075925094881,32.611064268645016,32.31453602780192,32.01800778695883,31.721479546115752,31.43178230068454,31.145500552959295,30.859218805234036,30.57293705750878,30.286655309783537,30.000373562058268,29.714091814333024,29.427810066607766,29.141528318882507,28.855246571157267,28.568964823431998,28.282683075706753,27.9964013279815,27.71011958025624,27.42383783253099,27.137556084805734,26.85127433708048,26.564992589355224,26.27871084162997,25.992429093904725,25.706147346179467,25.41986559845421,25.13358385072896,24.847302103003692,24.561020355278455,24.274738607553196,23.988456859827934,23.702175112102694,23.415893364377425,23.12961161665218,22.843329868926922,22.557048121201664,22.270766373476423,21.984484625751165,21.69820287802591,21.411921130300648,21.125639382575397,20.839357634850153,20.553075887124894,20.26679413939964,19.98051239167439,19.694230643949137,19.40794889622388,19.12166714849862,18.83538540077337,18.54910365304811,18.262821905322866,17.976540157597608,17.69025840987235,17.403976662147095,17.11769491442184,16.831413166696592,16.545131418971337,16.258849693198403,15.997336857293313,15.735824021388236,15.474311185483145,15.212798349578057,14.951285513672966,14.689772677767877,14.4282598418628,14.166747005957712,13.905234170052623,13.643721334147532,13.382208498242456,13.120695662337363,12.859182826432274,12.597669990527187,12.336157154622096,12.07464431871702,11.813131482811931,11.551618646906842,11.290105811001752,11.028592975096661,10.767080139191584,10.505567303286494,10.244054467381407,9.982541631476316,9.72102879557124,9.459515959666149,9.19800312376106,8.936490287855971,8.67497745195088,8.50986432182614,8.44115089748165,8.372437473137223,8.303724048792796,8.235010624448366,8.156487414256121,8.074040289724763,7.991593165193405,7.909146040662047,7.826698916130698,7.744251791599339,7.6618046670679885,7.5793575425366315,7.496910418005281,7.414463293473922,7.332016168942565,7.249569044411216,7.167121919879858,7.0846747953485,7.002227670817151,6.919780546285786,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[56.36748443003865,56.37561102822767,56.38373762641669,56.39186422460571,56.399990822794734,56.40811742098376,56.41624401917277,56.42437061736179,56.432497215550825,56.44062381373984,56.448750411928856,56.45687701011788,56.4650036083069,56.473130206495924,56.481256804684946,56.48938340287396,56.497510001062984,56.505636599252,56.51376319744103,56.521889795630045,56.53001639381906,56.53814299200809,56.546269590197106,56.55439618838613,56.56252278657515,56.56850718710299,56.57342048727882,56.578333787454646,56.58324708763047,56.58816038780629,56.59307368798212,56.59798698815794,56.60290028833377,56.6078135885096,56.612726888685415,56.617640188861245,56.622553489037074,56.6274667892129,56.63238008938872,56.63729338956455,56.64220668974038,56.6471199899162,56.65203329009203,56.65694659026785,56.66185989044368,56.666773190619494,56.671686490795324,56.676599790971146,56.68151309114697,56.686426391322804,56.69133969149863,56.696252991674456,56.70116629185027,56.70607959202611,56.71099289220193,56.71590619237775,56.72081949255359,56.7257327927294,56.73064609290523,56.73555939308106,56.74047269325689,56.74538599343272,56.750299293608535,56.755212593784364,56.76012589396019,56.765039194136016,56.76995249431184,56.77486579448767,56.779779094663496,56.784692394839325,56.78960569501514,56.79451899519097,56.7994322953668,56.80434559554262,56.80925889571844,56.81417219589427,56.819085496070095,56.823998796245924,56.82891209642175,56.833825396597575,56.838738696773405,56.84365199694923,56.84856529712505,56.85347859730088,56.59027580818017,56.273449801200144,55.95662379422014,55.639797787240134,55.32297178026012,55.006145773280124,54.68931976630011,54.3724937593201,54.055667752340085,53.73884174536008,53.42201573838008,53.10518973140006,52.78836372442005,52.47153771744004,52.154711710460035,51.837885703480026,51.52105969650001,51.20423368952,50.887407682539994,50.570581675559986,50.253755668579984,49.93692966159997,49.62010365461995,49.303277647639966,48.986451640659936,48.669625633679935,48.35279962669992,48.03597361971991,47.71914761273992,47.40232160575989,47.085495598779886,46.76866959179988,46.45184358481986,46.13501757783986,45.81819157085985,45.501365563879844,45.18453955689983,44.86771354991981,44.55088754293982,44.23406153595981,43.91723552897979,43.6004095219998,43.28358351501977,42.96675750803977,42.649931501059754,42.333105494079746,42.01627948709975,41.69945348011972,41.38262747313972,41.06580146615971,40.7489754591797,40.4321494521997,40.11532344521969,39.79849743823968,39.48167143125967,39.16484542427965,38.84801941729965,38.531193410319645,38.214367409746664,37.91783916890358,37.62131092806048,37.3247826872174,37.02825444637431,36.73172620553122,36.435197964688136,36.13866972384504,35.84214148300196,35.545613242158865,35.24908500131577,34.95255676047269,34.65602851962959,34.359500278786506,34.06297203794342,33.76644379710032,33.46991555625724,33.17338731541415,32.87685907457106,32.58033083372797,32.283802592884875,31.987274352041798,31.690746111198706,31.39421787035561,31.097689629512534,30.807992384081317,30.521710636356076,30.23542888863082,29.94914714090556,29.662865393180315,29.376583645455042,29.090301897729802,28.804020150004543,28.517738402279285,28.231456654554048,27.945174906828775,27.65889315910353,27.372611411378273,27.086329663653018,26.800047915927774,26.513766168202512,26.227484420477257,25.941202672752002,25.65492092502675,25.368639177301503,25.08235742957624,24.796075681850986,24.509793934125742,24.223512186400473,23.93723043867523,23.650948690949974,23.364666943224716,23.07838519549947,22.792103447774206,22.505821700048955,22.219539952323704,21.933258204598445,21.663960865680384,21.402448029775297,21.140935193870206,20.879422357965115,20.617909522060028,20.35639668615495,20.09488385024986,19.83337101434477,19.571858178439697,19.310345342534607,19.048832506629516,18.787319670724425,18.525806834819335,18.264293998914248,18.00278116300917,17.74126832710408,17.47975549119899,17.218242655293903,16.956729819388812,16.695216983483732,16.433704147578645,16.172191311673554,15.910678475768467,15.649165639863389,15.387652803958298,15.126139968053211,14.864627132148122,14.603114296243032,14.341601460337955,14.080088624432864,13.818575788527776,13.557062952622687,13.295550116717608,13.034037280812518,12.772524444907429,12.511011609002342,12.249498773097251,11.987985937192175,11.726473101287086,11.464960265381995,11.203447429476906,10.941934593571816,10.680421757666739,10.418908921761648,10.157396085856561,9.89588324995147,9.634370414046394,9.372857578141303,9.111344742236213,8.849831906331124,8.588319070426035,8.423205940301294,8.354492515956803,8.285779091612376,8.212160774344067,8.129713649812702,8.047266525281351,7.964819400749994,7.882372276218637,7.799925151687278,7.71747802715593,7.635030902624571,7.5525837780932195,7.4701366535618625,7.387689529030513,7.305242404499155,7.222795279967797,7.140348155436447,7.0579010309050885,6.975453906373732,6.893006781842383,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[56.131627075791684,56.1397536739807,56.147880272169715,56.156006870358745,56.16413346854777,56.17226006673678,56.180386664925805,56.18851326311483,56.196104312119076,56.2010176122949,56.20593091247073,56.210844212646556,56.21575751282238,56.2206708129982,56.22558411317403,56.23049741334985,56.23541071352568,56.24032401370151,56.245237313877325,56.250150614053155,56.255063914228984,56.25997721440481,56.264890514580635,56.269803814756465,56.27471711493228,56.27963041510811,56.28454371528394,56.28945701545976,56.29437031563559,56.29928361581141,56.30419691598724,56.30911021616306,56.31402351633889,56.31893681651472,56.32385011669054,56.328763416866366,56.333676717042195,56.338590017218024,56.34350331739384,56.34841661756967,56.3533299177455,56.35824321792132,56.36315651809715,56.36806981827297,56.3729831184488,56.377896418624616,56.38280971880045,56.387723018976274,56.392636319152096,56.397549619327926,56.40246291950375,56.40737621967958,56.4122895198554,56.41720282003122,56.42211612020705,56.42702942038288,56.43194272055871,56.436856020734524,56.44176932091035,56.44668262108618,56.451595921262,56.45650922143784,56.461422521613656,56.46633582178948,56.471249121965315,56.47616242214113,56.481075722316966,56.48598902249279,56.49090232266862,56.49581562284443,56.50072892302026,56.50564222319609,56.51055552337192,56.515468823547735,56.520382123723564,56.525295423899394,56.530208724075216,56.535122024251045,56.54003532442687,56.544948624602696,56.549861924778526,56.55477522495435,56.55968852513017,56.564601825306,56.30139903618529,55.984573029205265,55.667747022225264,55.350921015245255,55.03409500826524,54.717269001285246,54.40044299430523,54.08361698732522,53.766790980345206,53.4499649733652,53.1331389663852,52.81631295940518,52.49948695242517,52.182660945445164,51.86583493846514,51.54900893148515,51.23218292450513,50.91535691752512,50.598530910545115,50.28170490356511,49.964878896585105,49.64805288960509,49.331226882625074,49.01440087564508,48.69757486866505,48.380748861685056,48.06392285470505,47.74709684772503,47.43027084074504,47.11344483376501,46.79661882678501,46.47979281980499,46.162966812824976,45.84614080584498,45.529314798864974,45.21248879188496,44.89566278490495,44.578836777924934,44.26201077094494,43.945184763964924,43.62835875698491,43.31153275000492,42.99470674302489,42.67788073604489,42.361054729064875,42.04422872208487,41.72740271510487,41.41057670812484,41.09375070114484,40.77692469416483,40.46009868718482,40.143272680204824,39.82644667322481,39.5096206662448,39.192794659264784,38.87596865228477,38.559142645304775,38.242316638324766,37.92549063134475,37.60866462436475,37.29183861738473,36.975012610404725,36.65818660342472,36.3413605964447,36.02453458946471,35.70770858248468,35.390882575504676,35.07405656852467,34.75723056154465,34.44040455456465,34.12357854758463,33.80675254060463,33.48992653362462,33.1731005266446,32.85627451966461,32.549597398810974,32.253069157967886,31.956540917124798,31.660012676281703,31.363484435438625,31.066956194595534,30.77042795375244,30.47389971290936,30.184202467478144,29.8979207197529,29.61163897202764,29.325357224302383,29.039075476577143,28.752793728851874,28.46651198112663,28.180230233401375,27.893948485676116,27.607666737950872,27.330584874067437,27.069072038162364,26.807559202257274,26.546046366352183,26.284533530447106,26.02302069454202,25.76150785863693,25.499995022731838,25.23848218682675,24.976969350921674,24.715456515016584,24.453943679111493,24.19243084320642,23.930918007301315,23.66940517139624,23.407892335491148,23.14637949958606,22.88486666368098,22.62335382777588,22.361840991870803,22.100328155965713,21.838815320060625,21.577302484155545,21.31578964825046,21.054276812345364,20.792763976440277,20.53125114053519,20.269738304630113,20.008225468725023,19.746712632819932,19.48519979691486,19.223686961009765,18.962174125104678,18.700661289199587,18.439148453294496,18.177635617389406,17.91612278148433,17.654609945579242,17.39309710967415,17.13158427376906,16.870071437863974,16.608558601958894,16.347045766053807,16.085532930148716,15.824020094243629,15.56250725833855,15.30099442243346,15.039481586528371,14.77796875062328,14.516455914718193,14.254943078813117,13.993430242908026,13.731917407002937,13.470404571097845,13.20889173519277,12.94737889928768,12.68586606338259,12.4243532274775,12.162840391572413,11.901327555667335,11.639814719762246,11.378301883857157,11.116789047952068,10.855276212046977,10.5937633761419,10.33225054023681,10.07073770433172,9.809224868426632,9.547712032521552,9.286199196616465,9.024686360711375,8.763173524806286,8.501660688901195,8.336547558776452,8.267834134431961,8.185387009900657,8.102939885369306,8.020492760837941,7.938045636306591,7.855598511775234,7.773151387243876,7.690704262712518,7.608257138181169,7.52581001364981,7.443362889118459,7.3609157645871015,7.278468640055753,7.196021515524394,7.113574390993037,7.031127266461687,6.948680141930328,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[55.88646115024781,55.89137445042364,55.89628775059946,55.90120105077529,55.906114350951114,55.911027651126936,55.915940951302765,55.920854251478595,55.92576755165442,55.930680851830246,55.935594152006075,55.94050745218189,55.94542075235772,55.95033405253355,55.95524735270938,55.9601606528852,55.96507395306102,55.96998725323685,55.974900553412674,55.9798138535885,55.984727153764325,55.98964045394015,55.99455375411598,55.999467054291806,56.00438035446763,56.00929365464345,56.01420695481928,56.0191202549951,56.02403355517093,56.02894685534676,56.03386015552259,56.038773455698404,56.04368675587423,56.04860005605006,56.053513356225885,56.058426656401714,56.063339956577536,56.068253256753366,56.073166556929195,56.07807985710502,56.08299315728084,56.08790645745667,56.09281975763249,56.09773305780831,56.10264635798414,56.10755965815997,56.1124729583358,56.117386258511615,56.122299558687445,56.127212858863274,56.13212615903909,56.13703945921493,56.14195275939074,56.14686605956658,56.151779359742406,56.15669265991822,56.16160596009405,56.16651926026988,56.1714325604457,56.17634586062153,56.18125916079735,56.18617246097318,56.191085761149,56.19599906132483,56.20091236150066,56.205825661676485,56.21073896185231,56.21565226202814,56.220565562203966,56.22547886237979,56.23039216255562,56.23530546273144,56.24021876290726,56.24513206308309,56.25004536325892,56.253114828062735,56.25434045760038,56.25556608713802,56.256791716675664,56.25801734621331,56.259242975750944,56.26046860528859,56.26169423482623,56.26291986436387,55.99910246347014,55.682276456490115,55.365450449510114,55.048624442530105,54.73179843555009,54.414972428570096,54.09814642159008,53.78132041461007,53.464494407630056,53.14766840065005,52.830842393670046,52.51401638669003,52.19719037971002,51.880364372730014,51.56353836574999,51.24671235877,50.92988635178999,50.61306034480997,50.296234337829965,49.97940833084996,49.662582323869955,49.34575631688994,49.028930309909924,48.71210430292993,48.3952782959499,48.078452288969906,47.7616262819899,47.44480027500988,47.12797426802989,46.81114826104986,46.49432225406986,46.17749624708984,45.860670240109826,45.54384423312983,45.22701822614982,44.91019221916981,44.5933662121898,44.276540205209784,43.95971419822979,43.64288819124977,43.32606218426976,43.009236177289765,42.69241017030974,42.37558416332974,42.058758156349725,41.74193214936972,41.42510614238972,41.10828013540969,40.79145412842969,40.474628121449676,40.15780211446967,39.84097610748967,39.52415010050966,39.20732409352965,38.890498086549634,38.57367207956962,38.256846072589624,37.94002006560961,37.62319405862959,37.3063680516496,36.98954204466958,36.672716037689575,36.35589003070957,36.03906402372955,35.72223801674956,35.40541200976953,35.088586002789526,34.77175999580952,34.4549339888295,34.1381079818495,33.82128197486948,33.50445596788948,33.18762996090947,32.87080395392945,32.549105998668615,32.21766414747516,31.88622229628171,31.55478044508826,31.22333859389481,30.89189674270137,30.56045489150792,30.229013040314467,29.89757118912103,29.61439621436105,29.35535467781784,29.096313141274617,28.837271604731388,28.578230068188176,28.319188531644944,28.06014699510173,27.80110545855851,27.542063922015277,27.28302238547207,27.023980848928833,26.764939312385618,26.5058977758424,26.24685623929917,25.987814702755962,25.72877316621274,25.46973162966951,25.210690093126285,24.951648556583066,24.69260702003985,24.433565483496626,24.174523946953403,23.91548241041019,23.656440873866956,23.39739933732374,23.13835780078052,22.879316264237296,22.620274727694085,22.36123319115085,22.102191654607633,21.843150118064408,21.584108581521185,21.325067044977974,21.06602550843475,20.806983971891523,20.5479424353483,20.288900898805075,20.029859362261863,19.770817825718638,19.511776289175415,19.2527347526322,18.993693216088978,18.734651679545753,18.475610143002527,18.216568606459305,17.957527069916082,17.698485533372867,17.439443996829645,17.18040246028642,16.921360923743194,16.66231938719997,16.40327785065676,16.144236314113535,15.88519477757031,15.626153241027088,15.367111704483875,15.10807016794065,14.849028631397427,14.589987094854202,14.330945558310978,14.071904021767766,13.812862485224542,13.553820948681317,13.294779412138094,13.035737875594881,12.776696339051657,12.517654802508433,12.25861326596521,11.999571729421984,11.740530192878772,11.48148865633555,11.222447119792324,10.9634055832491,10.704364046705876,10.445322510162665,10.18628097361944,9.927239437076217,9.668197900532991,9.40915636398978,9.150114827446554,8.89107329090333,8.632097933627477,8.3749444617637,8.241060369988611,8.158613245457246,8.076166120925896,7.993718996394545,7.91127187186318,7.828824747331829,7.746377622800472,7.6639304982691145,7.581483373737757,7.499036249206408,7.416589124675049,7.334142000143697,7.2516948756123405,7.169247751080991,7.086800626549632,7.004353502018276,6.921906377486925,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[55.63288170819159,55.63779500836742,55.64270830854324,55.64762160871907,55.65253490889489,55.657448209070715,55.662361509246544,55.66727480942237,55.672188109598196,55.677101409774025,55.682014709949854,55.68692801012567,55.6918413103015,55.69675461047733,55.70166791065314,55.70658121082897,55.7114945110048,55.71640781118063,55.72132111135645,55.72623441153228,55.731147711708104,55.736061011883926,55.740974312059755,55.745887612235585,55.75080091241141,55.75571421258723,55.76062751276306,55.76554081293888,55.77045411311471,55.77536741329053,55.780280713466354,55.78519401364218,55.79010731381801,55.79502061399384,55.79993391416966,55.804847214345486,55.809760514521315,55.814673814697144,55.81958711487296,55.82450041504879,55.82941371522462,55.83432701540044,55.83924031557626,55.84415361575209,55.84906691592792,55.853980216103736,55.858893516279565,55.86380681645539,55.86872011663121,55.87363341680705,55.87854671698287,55.8834600171587,55.88837331733451,55.89328661751034,55.89819991768617,55.903113217862,55.90802651803783,55.912939818213644,55.9178531177281,55.91907874726574,55.92030437680339,55.92153000634102,55.922755635878666,55.92398126541631,55.92520689495395,55.92643252449159,55.92765815402923,55.928883783566874,55.93010941310452,55.93133504264216,55.932560672179804,55.93378630171745,55.93501193125509,55.93623756079273,55.93746319033037,55.93868881986801,55.939914449405656,55.9411400789433,55.942365708480935,55.94359133801858,55.94481696755622,55.946042597093864,55.94726822663151,55.94849385616915,55.68467645527541,55.367850448295385,55.05102444131539,54.734198434335376,54.41737242735536,54.10054642037537,53.78372041339536,53.46689440641534,53.15006839943533,52.833242392455325,52.516416385475324,52.1995903784953,51.88276437151529,51.565938364535285,51.249112357555276,50.93228635057527,50.61546034359526,50.29863433661525,49.98180832963524,49.66498232265523,49.348156315675226,49.03133030869521,48.7145043017152,48.39767829473521,48.08085228775518,47.76402628077518,47.44720027379517,47.13037426681516,46.81354825983516,46.49672225285513,46.179896245875135,45.86307023889512,45.546244231915104,45.22941822493511,44.9125922179551,44.595766210975086,44.27894020399507,43.96211419701506,43.64528819003506,43.32846218305505,43.01163617607504,42.69481016909504,42.37798416211501,42.06115815513502,41.744332148154996,41.42750614117499,41.11068013419499,40.79385412721497,40.47702812023497,40.160202113254954,39.843376106274945,39.52655009929495,39.209724092314936,38.89289808533492,38.57607207835491,38.259246071374896,37.942420064394895,37.62559405741489,37.296588177635684,36.96514632644225,36.633704475248784,36.302262624055345,35.9708207728619,35.639378921668445,35.307937070475006,34.97649521928154,34.6450533680881,34.31361151689465,33.9821696657012,33.65072781450776,33.3192859633143,32.98784411212086,32.65640226092741,32.32496040973396,31.993518558540522,31.66207670734707,31.330634856153615,30.999193004960166,30.667751153766712,30.336309302573277,30.004867451379823,29.673425600186373,29.341983748992938,29.058808774232958,28.799767237689743,28.540725701146517,28.281684164603295,28.022642628060083,27.76360109151685,27.504559554973635,27.245518018430413,26.98647648188719,26.727434945343976,26.468393408800736,26.20935187225753,25.9503103357143,25.69126879917108,25.43222726262787,25.17318572608464,24.914144189541418,24.655102652998192,24.39606111645497,24.137019579911755,23.877978043368532,23.61893650682531,23.359894970282095,23.10085343373886,22.841811897195647,22.58277036065242,22.3237288241092,22.064687287565988,21.80564575102275,21.54660421447954,21.287562677936315,21.028521141393092,20.769479604849877,20.510438068306655,20.25139653176343,19.992354995220207,19.73331345867698,19.47427192213377,19.215230385590548,18.956188849047322,18.69714731250411,18.438105775960885,18.17906423941766,17.920022702874437,17.66098116633121,17.40193962978799,17.142898093244778,16.883856556701552,16.624815020158326,16.3657734836151,16.10673194707188,15.847690410528667,15.588648873985441,15.32960733744222,15.070565800898995,14.811524264355782,14.552482727812558,14.293441191269334,14.034399654726109,13.775358118182886,13.516316581639675,13.25727504509645,12.998233508553225,12.739324330697615,12.48120930369374,12.223094276689853,11.964979249685966,11.706864222682078,11.448749195678191,11.190634168674315,10.93251914167043,10.67440411466654,10.416289087662653,10.158174060658766,9.903424476904904,9.649155670346081,9.394886863787258,9.146780739116629,8.902534573251973,8.667535802461021,8.455891277087147,8.297927313304628,8.214286605545192,8.131839481013841,8.049392356482477,7.966945231951126,7.884498107419776,7.802050982888412,7.719603858357061,7.637156733825703,7.5547096092943455,7.472262484762987,7.389815360231639,7.307368235700281,7.224921111168929,7.142473986637572,7.060026862106222,6.977579737574864,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[55.37930226613538,55.38421556631121,55.389128866487034,55.394042166662864,55.398955466838686,55.40386876701451,55.40878206719034,55.41369536736617,55.41860866754199,55.42352196771781,55.42843526789364,55.43334856806946,55.43826186824529,55.443175168421114,55.448088468596936,55.453001768772765,55.457915068948594,55.46282836912442,55.46774166930024,55.47265496947607,55.4775682696519,55.48248156982772,55.48739487000355,55.49230817017937,55.49722147035519,55.50213477053102,55.50704807070685,55.51196137088267,55.516874671058495,55.521787971234325,55.52670127141015,55.531614571585976,55.536527871761805,55.54144117193762,55.54635447211345,55.55126777228928,55.5561810724651,55.56109437264093,55.56600767281675,55.57092097299258,55.575834273168404,55.580747573344226,55.58381703693112,55.585042666468766,55.58626829600641,55.58749392554405,55.588719555081695,55.58994518461934,55.59117081415698,55.59239644369461,55.59362207323227,55.5948477027699,55.596073332307554,55.59729896184519,55.59852459138283,55.59975022092047,55.60097585045811,55.602201479995756,55.6034271095334,55.60465273907104,55.605878368608685,55.60710399814632,55.60832962768397,55.609555257221615,55.61078088675925,55.612006516296894,55.61323214583454,55.61445777537218,55.61568340490982,55.61690903444746,55.6181346639851,55.619360293522746,55.62058592306039,55.62181155259803,55.623037182135675,55.62426281167332,55.625488441210955,55.6267140707486,55.62793970028624,55.62916532982388,55.63039095936152,55.63161658889916,55.63284221843681,55.63406784797445,55.370250447080714,55.05342444010069,54.73659843312069,54.419772426140675,54.102946419160666,53.78612041218067,53.46929440520066,53.15246839822064,52.83564239124063,52.518816384260624,52.20199037728062,51.8851643703006,51.56833836332059,51.251512356340584,50.934686349360575,50.617860342380574,50.301034335400566,49.98420832842055,49.66738232144054,49.35055631446053,49.033730307480525,48.71690430050052,48.4000782935205,48.08325228654051,47.76642627956048,47.44960027258048,47.132774265600474,46.81594825862046,46.49912225164046,46.182296244660435,45.865470237680434,45.54864423070042,45.2318182237204,44.91499221674041,44.5981662097604,44.281340202780385,43.964514195800376,43.64768818882036,43.33086218184036,43.01403617486035,42.69721016788034,42.37551220779627,42.0440703566028,41.71262850540936,41.38118665421592,41.04974480302246,40.718302951829024,40.38686110063556,40.055419249442124,39.72397739824867,39.39253554705522,39.061093695861786,38.72965184466833,38.39820999347488,38.066768142281425,37.73532629108797,37.40388443989454,37.07244258870109,36.74100073750763,36.4095588863142,36.078117035120734,35.746675183927294,35.41523333273385,35.083791481540395,34.752349630346956,34.42090777915349,34.089465927960056,33.7580240767666,33.42658222557315,33.09514037437972,32.76369852318625,32.43225667199281,32.10081482079936,31.76937296960591,31.43793111841247,31.10648926721902,30.775047416025565,30.44360556483211,30.112163713638665,29.780721862445226,29.449280011251773,29.117838160058326,28.786396308864887,28.503221334104907,28.244179797561692,27.98513826101847,27.726096724475244,27.467055187932033,27.2080136513888,26.948972114845585,26.689930578302363,26.430889041759137,26.171847505215926,25.912805968672686,25.653764432129478,25.394722895586252,25.135681359043026,24.87663982249982,24.617598285956593,24.358556749413367,24.09951521287014,23.84047367632692,23.58143213978371,23.322390603240482,23.06334906669726,22.804307530154045,22.545265993610812,22.286224457067597,22.027182920524375,21.76814138398115,21.509099847437938,21.2500583108947,20.991016774351486,20.731975237808268,20.472933701265042,20.21389216472183,19.954850628178608,19.69580909163538,19.436767555092157,19.17772601854893,18.91868448200572,18.659642945462494,18.40060140891927,18.141559872376057,17.882518335832835,17.62347679928961,17.364435262746387,17.10539372620316,16.846550727767795,16.588435700763917,16.33032067376003,16.072205646756146,15.814090619752257,15.55597559274837,15.297860565744497,15.039745538740606,14.78163051173672,14.523515484732833,14.265400457728955,14.00728543072507,13.749170403721182,13.491055376717295,13.232940349713408,12.974825322709533,12.716710295705646,12.458595268701757,12.200480241697871,11.942365214693996,11.68617329860496,11.431904492046137,11.177635685487312,10.923366878928487,10.669098072369676,10.414829265810852,10.16357176932515,9.918687046970808,9.673802324616465,9.431216405683955,9.193994361627118,8.964292212342446,8.747779742177547,8.548902034223028,8.380048056843771,8.26995996563314,8.187512841101789,8.105065716570431,8.02261859203908,7.940171467507716,7.857724342976367,7.775277218445016,7.692830093913651,7.6103829693823,7.527935844850943,7.445488720319585,7.363041595788228,7.2805944712568795,7.19814734672552,7.115700222194169,7.033253097662811,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[55.12572282407915,55.13063612425498,55.1355494244308,55.14046272460663,55.14537602478245,55.15028932495827,55.1552026251341,55.16011592530993,55.16502922548575,55.16994252566158,55.17485582583741,55.17976912601323,55.184682426189056,55.189595726364885,55.194509026540715,55.19942232671654,55.20433562689236,55.20924892706819,55.21416222724401,55.21907552741984,55.22398882759566,55.228902127771484,55.23381542794731,55.23872872812314,55.243642028298964,55.24855532659649,55.249780956134124,55.25100658567177,55.25223221520941,55.253457844747054,55.2546834742847,55.25590910382234,55.25713473335998,55.258360362897626,55.25958599243526,55.260811621972906,55.26203725151055,55.26326288104819,55.26448851058583,55.26571414012348,55.266939769661114,55.26816539919876,55.2693910287364,55.270616658274044,55.27184228781169,55.27306791734932,55.27429354688698,55.27551917642461,55.27674480596225,55.277970435499896,55.27919606503754,55.28042169457518,55.281647324112825,55.282872953650454,55.28409858318811,55.28532421272574,55.2865498422634,55.28777547180103,55.28900110133867,55.29022673087633,55.291452360413956,55.2926779899516,55.29390361948924,55.295129249026886,55.29635487856453,55.29758050810217,55.29880613763981,55.30003176717745,55.301257396715094,55.30248302625274,55.30370865579038,55.304934285328024,55.30615991486567,55.3073855444033,55.308611173940946,55.30983680347859,55.31106243301623,55.312288062553876,55.31351369209152,55.31473932162916,55.315964951166805,55.31719058070444,55.318416210242084,55.31964183977973,55.05582443888599,54.73899843190597,54.42217242492597,54.10534641794595,53.788520410965944,53.47169440398594,53.154868397005934,52.838042390025926,52.52121638304591,52.204390376065895,51.8875643690859,51.570738362105885,51.25391235512588,50.937086348145854,50.620260341165846,50.30343433418585,49.986608327205836,49.66978232022583,49.35295631324582,49.036130306265804,48.7193042992858,48.402478292305794,48.08565228532578,47.768826278345784,47.452000271365755,47.122994386763345,46.79155253556989,46.46011068437644,46.128668833183,45.79722698198953,45.4657851307961,45.134343279602646,44.80290142840919,44.47145957721576,44.14001772602231,43.808575874828854,43.4771340236354,43.14569217244195,42.814250321248515,42.48280847005506,42.15136661886161,41.81992476766818,41.48848291647471,41.15704106528127,40.82559921408782,40.49415736289437,40.16271551170093,39.83127366050747,39.49983180931403,39.16838995812058,38.836948106927125,38.50550625573369,38.17406440454024,37.842622553346786,37.51118070215333,37.17973885095988,36.84829699976645,36.51685514857299,36.18541329737954,35.85397144618611,35.52252959499264,35.1910877437992,34.859645892605755,34.5282040414123,34.19676219021886,33.865320339025395,33.53387848783196,33.20243663663851,32.870994785445056,32.539552934251624,32.20811108305816,31.876669231864717,31.545227380671264,31.213785529477818,30.88234367828438,30.550901827090925,30.219459975897475,29.888018124704022,29.556576273510572,29.225134422317137,28.893692571123683,28.56225071993023,28.230808868736794,27.94763389397681,27.688592357433606,27.429550820890377,27.17050928434715,26.91146774780394,26.652426211260703,26.393384674717492,26.13434313817427,25.875301601631044,25.616260065087832,25.357218528544593,25.098176992001378,24.83913545545816,24.580093918914933,24.32105238237172,24.0620108458285,23.802969309285274,23.543927772742048,23.284886236198826,23.025844699655615,22.76680316311239,22.507761626569167,22.24872009002595,21.989678553482715,21.730637016939504,21.47159548039628,21.212553943853056,20.953777124837945,20.69566209783404,20.43754707083017,20.179432043826285,19.921317016822393,19.66320198981852,19.405086962814632,19.146971935810747,18.888856908806858,18.63074188180297,18.372626854799094,18.11451182779521,17.85639680079132,17.598281773787445,17.34016674678356,17.08205171977967,16.82393669277578,16.565821665771896,16.30770663876801,16.049591611764132,15.791476584760245,15.533361557756358,15.27524653075247,15.017131503748583,14.759016476744709,14.50090144974082,14.242786422736934,13.984671395733047,13.72655636872917,13.468922120304974,13.21465331374615,12.960384507187324,12.706115700628501,12.451846894069691,12.197578087510866,11.943309280952043,11.689040474393218,11.434771667834408,11.180502861275585,10.935478077179294,10.690593354824951,10.445708632470609,10.200823910116277,9.959898238115905,9.72267619405907,9.48545415000223,9.261048622223841,9.040694257716343,8.836583692254845,8.641912791358877,8.471217338985007,8.335851906887664,8.243186201189722,8.16073907665837,8.078291952127021,7.995844827595663,7.913397703064313,7.830950578532947,7.748503454001597,7.666056329470247,7.583609204938883,7.501162080407533,7.418714955876175,7.336267831344817,7.2538207068134595,7.17137358228211,7.088926457750752,7.006479333219399,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[54.87214338202294,54.87705668219877,54.88196998237459,54.88688328255042,54.89179658272624,54.896709882902066,54.901623183077895,54.906536483253724,54.911449783429546,54.91451924579952,54.915744875337154,54.9169705048748,54.91819613441245,54.91942176395008,54.92064739348772,54.92187302302536,54.923098652563006,54.924324282100656,54.92554991163829,54.926775541175935,54.92800117071358,54.92922680025122,54.930452429788865,54.9316780593265,54.932903688864144,54.934129318401794,54.93535494793942,54.936580577477066,54.93780620701471,54.93903183655235,54.940257466089996,54.94148309562764,54.94270872516528,54.943934354702925,54.94515998424056,54.94638561377821,54.947611243315855,54.94883687285349,54.950062502391134,54.95128813192878,54.95251376146642,54.953739391004056,54.9549650205417,54.95619065007934,54.957416279616986,54.95864190915462,54.95986753869227,54.96109316822991,54.96231879776755,54.963544427305195,54.96477005684284,54.96599568638048,54.967221315918124,54.96844694545576,54.9696725749934,54.970898204531046,54.97212383406869,54.973349463606326,54.97457509314397,54.97580072268162,54.977026352219255,54.978251981756905,54.97947761129454,54.980703240832185,54.98192887036983,54.983154499907464,54.98438012944511,54.98560575898275,54.98683138852039,54.988057018058036,54.98928264759567,54.990508277133316,54.99173390667096,54.9929595362086,54.994185165746245,54.99541079528389,54.99663642482153,54.997862054359175,54.99908768389682,55.00031331343446,55.001538942972104,55.00276457250975,55.00399020204738,55.005215831585026,54.74139843069129,54.42457242371127,54.10774641673127,53.79092040975125,53.47409440277124,53.15726839579124,52.84044238881123,52.52361638183122,52.2019184169239,51.870476565730456,51.53903471453701,51.207592863343564,50.87615101215012,50.54470916095667,50.21326730976321,49.88182545856978,49.55038360737633,49.21894175618287,48.887499904989426,48.556058053795965,48.22461620260253,47.89317435140909,47.561732500215626,47.230290649022194,46.89884879782872,46.56740694663529,46.23596509544184,45.90452324424838,45.57308139305495,45.24163954186149,44.91019769066804,44.578755839474596,44.24731398828115,43.9158721370877,43.58443028589426,43.25298843470081,42.92154658350735,42.590104732313904,42.25866288112046,41.92722102992701,41.595779178733565,41.264337327540126,40.93289547634666,40.60145362515322,40.270011773959766,39.93856992276632,39.60712807157288,39.27568622037942,38.94424436918598,38.61280251799252,38.281360666799074,37.94991881560564,37.61847696441218,37.287035113218735,36.95559326202529,36.62415141083183,36.292709559638396,35.961267708444936,35.62982585725149,35.29838400605806,34.96694215486459,34.63550030367115,34.3040584524777,33.97261660128425,33.64117475009081,33.309732898897344,32.978291047703905,32.64684919651046,32.315407345317006,31.98396549412357,31.652523642930102,31.321081791736667,30.989639940543213,30.65819808934976,30.326756238156324,29.99531438696287,29.66387253576942,29.33243068457597,29.00098883338252,28.669546982189082,28.338105130995633,28.00666327980218,27.675221428608744,27.39204645384876,27.133004917305552,26.873963380762326,26.6149218442191,26.355880307675893,26.096838771132656,25.83779723458944,25.57875569804622,25.319714161502997,25.061003521908123,24.802888494904224,24.54477346790035,24.28665844089646,24.028543413892574,23.7704283868887,23.51231335988481,23.254198332880925,22.996083305877036,22.73796827887315,22.479853251869272,22.221738224865387,21.9636231978615,21.705508170857623,21.447393143853724,21.189278116849852,20.931163089845963,20.673048062842074,20.4149330358382,20.1568180088343,19.898702981830425,19.640587954826536,19.38247292782265,19.124357900818776,18.866242873814887,18.608127846811,18.350012819807112,18.091897792803227,17.833782765799352,17.575667738795463,17.317552711791574,17.0594376847877,16.801322657783814,16.543207630779925,16.285092603776036,16.02697757677215,15.768862549768265,15.51074752276439,15.252632495760501,14.997402135446201,14.743133328887378,14.488864522328555,14.234595715769744,13.98032690921092,13.726058102652097,13.471789296093274,13.217520489534463,12.963251682975638,12.708982876416815,12.45471406985799,12.200445263299168,11.952269107387814,11.70738438503347,11.462499662679129,11.217614940324786,10.972730217970454,10.727845495616114,10.488580070547888,10.251358026491049,10.014135982434212,9.780248848427263,9.557805032105275,9.33536121578329,9.12949820779365,8.928157978469493,8.735335917036103,8.562386621126265,8.417090355195402,8.301843519347917,8.216412436746312,8.133965312214956,8.051518187683605,7.969071063152254,7.886623938620896,7.804176814089546,7.72172968955818,7.63928256502683,7.556835440495481,7.474388315964116,7.391941191432765,7.309494066901408,7.227046942370049,7.144599817838692,7.062152693307343,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[54.613554840406486,54.61027744741177,54.60700005441706,54.60372266142234,54.60044526842762,54.59716787543291,54.59389048243819,54.59061308944347,54.587335696448754,54.58856132220679,54.589786951744436,54.59101258128207,54.59223821081972,54.59346384035736,54.594689469895,54.595915099432645,54.59714072897029,54.59836635850793,54.599591988045574,54.60081761758322,54.602043247120854,54.6032688766585,54.60449450619614,54.60572013573378,54.606945765271426,54.60817139480907,54.609397024346706,54.61062265388435,54.61184828342199,54.613073912959635,54.61429954249728,54.61552517203492,54.616750801572564,54.61797643111021,54.619202060647844,54.620427690185494,54.62165331972313,54.62287894926077,54.62410457879841,54.62533020833606,54.626555837873696,54.62778146741134,54.62900709694898,54.630232726486625,54.63145835602427,54.63268398556191,54.63390961509956,54.6351352446372,54.636360874174834,54.637586503712484,54.63881213325012,54.64003776278777,54.6412633923254,54.64248902186304,54.643714651400686,54.64494028093833,54.64616591047597,54.64739154001361,54.64861716955126,54.6498427990889,54.65106842862653,54.65229405816419,54.65351968770182,54.65474531723947,54.65597094677711,54.65719657631475,54.658422205852396,54.65964783539004,54.660873464927676,54.66209909446532,54.66332472400296,54.664550353540605,54.66577598307824,54.667001612615884,54.66822724215353,54.66945287169117,54.670678501228814,54.67190413076646,54.6731297603041,54.67435538984174,54.675581019379386,54.67680664891702,54.678032278454666,54.67925790799231,54.393127631590005,54.049526173999695,53.70592471640941,53.36232325881912,53.01872180122882,52.67512034363853,52.33151888604824,51.98791742845793,51.65444896599221,51.323007114798756,50.99156526360532,50.66012341241186,50.32868156121842,49.997239710024964,49.66579785883151,49.33435600763807,49.002914156444625,48.67147230525117,48.340030454057725,48.00858860286427,47.67714675167083,47.345704900477386,47.01426304928393,46.682821198090494,46.351379346897026,46.019937495703594,45.68849564451014,45.35705379331669,45.02561194212325,44.69417009092978,44.36272823973635,44.031286388542895,43.69984453734944,43.36840268615601,43.03696083496256,42.7055189837691,42.37407713257566,42.042635281382196,41.711193430188764,41.37975157899532,41.04830972780186,40.716867876608426,40.38542602541496,40.05398417422152,39.722542323028065,39.39110047183462,39.05965862064118,38.72821676944772,38.39677491825428,38.06533306706083,37.733891215867374,37.40244936467394,37.07100751348049,36.73956566228704,36.40812381109358,36.076681959900135,35.745240108706696,35.41379825751324,35.082356406319796,34.75091455512636,34.41947270393289,34.08803085273945,33.756589001546004,33.42514715035255,33.09370529915911,32.76226344796565,32.43082159677221,32.09937974557876,31.7679378943853,31.43649604319187,31.1050541919984,30.773612340804963,30.442170489611513,30.11072863841806,29.779286787224624,29.44784493603117,29.11640308483772,28.784961233644268,28.453519382450818,28.122077531257382,27.79063568006393,27.459193828870475,27.12775197767704,26.845194675943283,26.58707964893941,26.328964621935523,26.070849594931637,25.812734567927762,25.554619540923866,25.296504513919988,25.0383894869161,24.780274459912214,24.52215943290834,24.264044405904443,24.00592937890056,23.747814351896675,23.48969932489279,23.231584297888915,22.973469270885026,22.715354243881137,22.457239216877255,22.199124189873366,21.941009162869488,21.6828941358656,21.424779108861713,21.16666408185784,20.908549054853943,20.650434027850064,20.39231900084618,20.13420397384229,19.876088946838415,19.617973919834515,19.359858892830637,19.10174386582675,18.843628838822866,18.58551381181899,18.327398784815102,18.069283757811213,17.811168730807328,17.553053703803442,17.294938676799568,17.03682364979568,16.780150957146216,16.525882150587407,16.27161334402858,16.017344537469757,15.763075730910934,15.508806924352111,15.254538117793288,15.000269311234476,14.746000504675653,14.49173169811683,14.237462891558005,13.98319408499918,13.72892527844037,13.474656471881545,13.220387665322724,12.969060137596287,12.724175415241955,12.479290692887613,12.234405970533272,11.989521248178928,11.744636525824589,11.499751803470257,11.254867081115913,11.01726190297984,10.780039858923,10.542817814866176,10.305595770809337,10.07700525830866,9.854561441986672,9.632117625664685,9.422412723332446,9.218302157870948,9.02116873560535,8.829944602779973,8.655472947832289,8.50220155132101,8.373880175201837,8.272085796834244,8.189638672302902,8.107191547771544,8.024744423240186,7.942297298708835,7.859850174177485,7.777403049646127,7.694955925114778,7.612508800583412,7.530061676052062,7.4476145515207115,7.365167426989347,7.282720302457997,7.20027317792664,7.117826053395282,7.035378928863923,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[54.34964413148792,54.3463667384932,54.343089345498484,54.33981195250377,54.336534559509055,54.33325716651434,54.329979773519625,54.32670238052491,54.32342498753019,54.32014759453547,54.31687020154075,54.31359280854603,54.31031541555133,54.30703802255661,54.30376062956189,54.300483236567175,54.297205843572456,54.29392845057774,54.29065105758302,54.28737366458831,54.28409627159359,54.28081887859887,54.27754148560416,54.27426409260944,54.270986699614724,54.26996081336358,54.271186442901225,54.27241207243887,54.27363770197651,54.274863331514155,54.2760889610518,54.27731459058944,54.278540220127084,54.27976584966473,54.280991479202356,54.282217108740014,54.28344273827764,54.284668367815286,54.28589399735293,54.28711962689057,54.288345256428215,54.28957088596586,54.2907965155035,54.292022145041145,54.29324777457879,54.294473404116424,54.295699033654074,54.29692466319171,54.298150292729346,54.299375922267,54.30060155180464,54.30182718134229,54.30305281087992,54.304278440417555,54.305504069955205,54.30672969949284,54.30795532903049,54.30918095856813,54.31040658810577,54.31163221764342,54.31285784718106,54.31408347671871,54.31530910625634,54.31653473579398,54.31776036533162,54.318985994869266,54.32021162440691,54.32143725394455,54.322662883482195,54.32388851301984,54.32511414255748,54.326339772095125,54.32756540163277,54.32879103117041,54.33001666070804,54.33124229024568,54.33246791978334,54.333693549320984,54.33491917885861,54.336144808396256,54.3373704379339,54.33859606747154,54.339821697009185,54.34104732654683,54.05491705014452,53.71131559255421,53.367714134963926,53.02411267737363,52.680511219783334,52.33690976219305,51.99330830460275,51.64970684701245,51.30610538942215,50.962503931831854,50.61890247424157,50.27530101665128,49.93169955906098,49.58809810147068,49.24449664388038,48.90089518629009,48.5572937286998,48.2136922711095,47.87009081351921,47.52648935592891,47.18288789833863,46.83928644074833,46.49568498315803,46.15208352556775,45.81253525789724,45.481093406703806,45.14965155551035,44.8182097043169,44.48676785312346,44.15532600193,43.82388415073656,43.492442299543114,43.16100044834966,42.82955859715622,42.49811674596277,42.16667489476932,41.83523304357587,41.503791192382415,41.172349341188976,40.84090748999553,40.50946563880208,40.17802378760864,39.84658193641517,39.51514008522173,39.183698234028284,38.85225638283483,38.52081453164139,38.18937268044793,37.85793082925449,37.52648897806104,37.195047126867586,36.86360527567415,36.5321634244807,36.20072157328725,35.8692797220938,35.53783787090035,35.20639601970691,34.87495416851346,34.54351231732001,34.21207046612657,33.8806286149331,33.54918676373966,33.217744912546216,32.88630306135276,32.55486121015932,32.22341935896586,31.891977507772424,31.56053565657897,31.22909380538552,30.89765195419208,30.566210102998614,30.23476825180518,29.90332640061173,29.571884549418275,29.24044269822484,28.909000847031386,28.577558995837936,28.246117144644483,27.914675293451037,27.583233442257598,27.251791591064148,26.920349739870694,26.588907888677255,26.306350586943502,26.048235559939627,25.790120532935738,25.532005505931853,25.273890478927974,25.01577545192408,24.757660424920203,24.499545397916314,24.241430370912425,23.983315343908554,23.725200316904655,23.46708528990078,23.20897026289689,22.950855235893002,22.692740208889127,22.434625181885238,22.176510154881356,21.918395127877467,21.660280100873578,21.402165073869703,21.144050046865814,20.885935019861932,20.627819992858054,20.369704965854154,20.11158993885028,19.85347491184639,19.5953598848425,19.337244857838627,19.07912983083473,18.821014803830856,18.56289977884623,18.30863097228741,18.054362165728598,17.80009335916977,17.545824552610952,17.291555746052126,17.037286939493306,16.783018132934494,16.528749326375667,16.274480519816844,16.020211713258032,15.765942906699209,15.511674100140384,15.25740529358156,15.003136487022736,14.748867680463915,14.494598873905101,14.240330067346278,13.986061260787455,13.740966445450429,13.49608172309609,13.251197000741755,13.006312278387414,12.76142755603307,12.51654283367873,12.271658111324399,12.026773388970057,11.783165779468625,11.54594373541179,11.30872169135495,11.071499647298126,10.83427760324129,10.597055559184449,10.373761668190053,10.151317851868077,9.928874035546091,9.71532723887123,9.511216673409729,9.307413922715941,9.114179492741208,8.924553288523851,8.750081633576167,8.593370833462245,8.454659443528259,8.336830661603184,8.24531203239084,8.162864907859483,8.080417783328132,7.997970658796775,7.915523534265418,7.833076409734068,7.7506292852027165,7.668182160671359,7.585735036140008,7.503287911608643,7.420840787077293,7.338393662545943,7.2559465380145785,7.173499413483228,7.091052288951872,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[54.085733422569376,54.08245602957466,54.079178636579954,54.075901243585236,54.07262385059052,54.0693464575958,54.06606906460108,54.06279167160636,54.059514278611644,54.05623688561693,54.05295949262222,54.049682099627496,54.04640470663278,54.04312731363807,54.03984992064335,54.03657252764863,54.03329513465391,54.0300177416592,54.02674034866448,54.023462955669764,54.020185562675046,54.01690816968033,54.01363077668561,54.0103533836909,54.00707599069618,54.00379859770147,54.00052120470675,53.99724381171203,53.993966418717314,53.990689025722595,53.987411632727884,53.984134239733166,53.98085684673845,53.977579453743736,53.97430206074902,53.9710246677543,53.96774727475958,53.96446988176486,53.961192488770145,53.957915095775434,53.954637702780715,53.951360309786,53.95258593405804,53.953811563595686,53.95503719313333,53.956262822670965,53.957488452208615,53.95871408174625,53.959939711283894,53.96116534082154,53.96239097035918,53.963616599896824,53.96484222943447,53.9660678589721,53.96729348850975,53.96851911804738,53.96974474758504,53.97097037712267,53.97219600666031,53.97342163619796,53.9746472657356,53.97587289527324,53.977098524810884,53.97832415434853,53.97954978388617,53.980775413423814,53.98200104296146,53.9832266724991,53.98445230203674,53.98567793157438,53.98690356111202,53.988129190649666,53.98935482018731,53.990580449724945,53.99180607926259,53.99303170880023,53.994257338337874,53.99548296787552,53.99670859741316,53.997934226950804,53.99915985648844,54.00038548602609,54.001611115563726,54.00283674510137,53.71670646869906,53.37310501110875,53.02950355351847,52.68590209592817,52.342300638337875,51.998699180747586,51.6550977231573,51.31149626556699,50.96789480797669,50.624293350386395,50.28069189279611,49.93709043520582,49.59348897761552,49.249887520025226,48.906286062434916,48.56268460484464,48.21908314725434,47.87548168966404,47.531880232073746,47.18827877448345,46.84467731689317,46.50107585930287,46.15747440171257,45.813872944122295,45.47027148653198,45.12667002894169,44.78306857135139,44.4394671137611,44.095865656170815,43.7522641985805,43.40866274099022,43.06506128339992,42.72145982580962,42.377858368219336,42.03425691062904,41.690655453038744,41.34705399544845,41.00345253785815,40.65985108026786,40.31624962267757,39.97264816508727,39.6391796986089,39.307737847415424,38.97629599622199,38.64485414502854,38.313412293835086,37.981970442641654,37.650528591448186,37.319086740254754,36.98764488906129,36.65620303786784,36.32476118667441,35.993319335480955,35.6618774842875,35.330435633094055,34.998993781900595,34.66755193070716,34.336110079513716,34.004668228320256,33.673226377126824,33.34178452593336,33.01034267473992,32.67890082354647,32.347458972353024,32.01601712115958,31.684575269966114,31.353133418772682,31.021691567579232,30.69024971638577,30.35880786519234,30.027366013998872,29.695924162805433,29.364482311611987,29.033040460418533,28.701598609225094,28.370156758031644,28.03871490683819,27.70727305564474,27.375831204451288,27.044389353257852,26.712947502064402,26.38150565087095,26.050063799677513,25.767506497943756,25.50939147093988,25.251276443935993,24.993161416932107,24.73504638992823,24.476931362924333,24.218816335920458,23.96070130891657,23.702586281912687,23.44447125490881,23.18635622790491,22.928241200901034,22.670126173897145,22.412011146893256,22.15389611988938,21.895781092885493,21.63766606588161,21.37955103887772,21.121436011873836,20.86332098486996,20.60520595786607,20.347090930862187,20.091379793987475,19.83711098742864,19.58284218086983,19.328573374311002,19.07430456775218,18.820035761193367,18.565766954634533,18.31149814807572,18.057229341516894,17.802960534958075,17.548691728399263,17.294422921840436,17.040154115281616,16.78588530872279,16.53161650216397,16.277347695605158,16.02307888904633,15.768810082487509,15.514541275928698,15.260272469369871,15.006003662811048,14.75775747565895,14.512872753304606,14.267988030950265,14.023103308595934,13.778218586241593,13.533333863887247,13.288449141532908,13.043564419178566,12.798679696824234,12.553794974469891,12.31184761190061,12.074625567843771,11.837403523786945,11.600181479730109,11.362959435673268,11.125737391616433,10.892961894393466,10.670518078071488,10.4480742617495,10.225630445427516,10.008241754410037,9.80413118894855,9.60002062348705,9.40042467985182,9.20719024987708,9.01916197426774,8.844690319320065,8.684540115603504,8.53911215228598,8.411908443516008,8.3057597253912,8.218538267947439,8.13609114341608,8.053644018884723,7.971196894353373,7.888749769822015,7.806302645290657,7.723855520759306,7.641408396227956,7.558961271696599,7.476514147165249,7.394067022633884,7.311619898102533,7.229172773571182,7.146725649039817,7.064278524508467,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[53.82182271365082,53.8185453206561,53.81526792766138,53.81199053466666,53.80871314167195,53.80543574867723,53.80215835568251,53.79888096268779,53.795603569693085,53.79232617669837,53.78904878370365,53.78577139070893,53.78249399771421,53.779216604719494,53.775939211724776,53.77266181873007,53.769384425735346,53.766107032740635,53.76282963974592,53.7595522467512,53.75627485375648,53.75299746076176,53.74972006776705,53.74644267477233,53.74316528177762,53.7398878887829,53.736610495788184,53.733333102793466,53.73005570979875,53.72677831680403,53.72350092380931,53.72022353081461,53.716946137819875,53.71366874482517,53.71039135183045,53.707113958835734,53.703836565841016,53.7005591728463,53.697281779851586,53.69400438685687,53.69072699386215,53.68744960086743,53.68417220787271,53.680894814878,53.677617421883284,53.67434002888857,53.67106263589385,53.667785242899136,53.66450784990442,53.6612304569097,53.65795306391498,53.65467567092026,53.65139827792555,53.64812088493083,53.64484349193612,53.6415660989414,53.638288705946685,53.63501131295196,53.633985425214824,53.63521105475248,53.63643668429011,53.63766231382776,53.63888794336539,53.64011357290303,53.64133920244068,53.642564831978326,53.64379046151597,53.64501609105361,53.64624172059125,53.64746735012889,53.648692979666535,53.64991860920418,53.65114423874182,53.652369868279465,53.65359549781711,53.65482112735475,53.656046756892394,53.65727238643004,53.65849801596767,53.659723645505316,53.66094927504296,53.662174904580596,53.66340053411824,53.66462616365588,53.37849588725358,53.03489442966326,52.69129297207298,52.34769151448268,52.00409005689239,51.660488599302106,51.31688714171181,50.97328568412151,50.62968422653121,50.286082768940915,49.942481311350626,49.59887985376034,49.255278396170034,48.91167693857973,48.568075480989435,48.224474023399154,47.88087256580886,47.537271108218555,47.193669650628266,46.85006819303797,46.50646673544768,46.162865277857385,45.81926382026709,45.47566236267681,45.1320609050865,44.78845944749621,44.44485798990591,44.10125653231561,43.757655074725335,43.41405361713502,43.070452159544736,42.72685070195444,42.38324924436414,42.039647786773855,41.69604632918356,41.35244487159326,41.00884341400296,40.665241956412665,40.32164049882238,39.97803904123209,39.634437583641784,39.2908361260515,38.94723466846119,38.60363321087091,38.260031753280614,37.91643029569032,37.57282883810003,37.22922738050971,36.88562592291943,36.542024465329135,36.19842300773884,35.85482155014856,35.51122009255826,35.16761863496796,34.82401717737766,34.480415719787366,34.136814262197085,33.79726599051393,33.465824139320475,33.13438228812704,32.80294043693357,32.471498585740136,32.14005673454668,31.808614883353233,31.477173032159797,31.14573118096633,30.81428932977289,30.482847478579444,30.151405627385984,29.81996377619255,29.48852192499908,29.157080073805645,28.825638222612195,28.494196371418745,28.162754520225306,27.83131266903186,27.499870817838406,27.168428966644953,26.836987115451503,26.505545264258068,26.174103413064614,25.84266156187116,25.51121971067773,25.22866240894397,24.970547381940097,24.712432354936208,24.45431732793232,24.196202300928444,23.93808727392455,23.679972246920673,23.421857219916784,23.1637421929129,22.905627165909024,22.64751213890512,22.38939711190125,22.13128208489736,21.874128615687475,21.619859809128666,21.365591002569843,21.11132219601102,20.857053389452194,20.60278458289337,20.348515776334562,20.094246969775735,19.839978163216916,19.585709356658104,19.331440550099266,19.077171743540454,18.822902936981627,18.568634130422808,18.314365323863996,18.060096517305162,17.80582771074635,17.551558904187523,17.297290097628704,17.04302129106989,16.788752484511065,16.53448367795224,16.28021487139342,16.025946064834596,15.774548505867434,15.52966378351309,15.284779061158751,15.03989433880442,14.795009616450074,14.550124894095735,14.305240171741394,14.06035544938705,13.815470727032709,13.570586004678376,13.325701282324037,13.08081655996969,12.84052944433256,12.603307400275723,12.366085356218896,12.128863312162057,11.891641268105221,11.654419224048382,11.417197179991556,11.189718304274871,10.967274487952885,10.744830671630897,10.522386855308913,10.30115626994883,10.097045704487332,9.892935139025834,9.688824573564334,9.49343543698768,9.300201007012937,9.113770660011621,8.939299005063935,8.77570939774474,8.624355045798247,8.492228531861137,8.374858929917357,8.276002002877524,8.191764503504027,8.10931737897267,8.026870254441311,7.9444231299099535,7.8619760053786045,7.779528880847247,7.697081756315889,7.614634631784538,7.5321875072531865,7.44974038272183,7.367293258190481,7.284846133659114,7.202399009127764,7.119951884596414,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[53.55791200473225,53.554634611737534,53.551357218742815,53.548079825748104,53.544802432753386,53.541525039758675,53.53824764676395,53.53497025376923,53.53169286077452,53.5284154677798,53.52513807478509,53.52186068179037,53.518583288795654,53.51530589580094,53.512028502806224,53.508751109811506,53.50547371681678,53.50219632382207,53.49891893082735,53.49564153783264,53.49236414483792,53.4890867518432,53.48580935884849,53.48253196585377,53.479254572859055,53.47597717986433,53.47269978686962,53.46942239387491,53.46614500088018,53.46286760788547,53.45959021489075,53.456312821896034,53.45303542890132,53.449758035906605,53.44648064291189,53.44320324991717,53.43992585692246,53.43664846392774,53.43337107093302,53.4300936779383,53.426816284943584,53.423538891948866,53.420261498954154,53.416984105959436,53.413706712964725,53.41042931997001,53.40715192697529,53.40387453398057,53.40059714098585,53.39731974799114,53.394042354996415,53.390764962001704,53.387487569006986,53.384210176012274,53.380932783017556,53.37765539002284,53.37437799702812,53.3711006040334,53.36782321103868,53.36454581804397,53.36126842504925,53.35799103205454,53.354713639059824,53.351436246065106,53.34815885307039,53.34488146007567,53.34160406708095,53.33832667408624,53.33504928109152,53.3317718880968,53.32849449510209,53.32521710210737,53.321939709112655,53.31866231611794,53.31538492312322,53.31661054590926,53.31783617544691,53.31906180498455,53.32028743452219,53.321513064059836,53.32273869359747,53.323964323135115,53.32518995267276,53.3264155822104,53.0402853058081,52.69668384821779,52.353082390627506,52.0094809330372,51.66587947544691,51.322278017856625,50.97867656026632,50.635075102676026,50.29147364508573,49.947872187495435,49.60427072990515,49.26066927231485,48.91706781472455,48.57346635713425,48.229864899543955,47.88626344195367,47.54266198436338,47.19906052677308,46.85545906918278,46.51185761159248,46.1682561540022,45.824654696411905,45.48105323882161,45.13745178123133,44.79385032364101,44.45024886605072,44.106647408460425,43.76304595087013,43.41944449327985,43.07584303568954,42.732241578099256,42.38864012050895,42.04503866291866,41.701437205328375,41.35783574773807,41.014234290147776,40.67063283255747,40.32703137496718,39.983429917376895,39.6398284597866,39.296227002196304,38.95262554460602,38.609024087015705,38.26542262942542,37.92182117183513,37.57821971424483,37.23461825665455,36.89101679906423,36.54741534147395,36.203813883883655,35.86021242629336,35.51661096870308,35.17300951111278,34.82940805352248,34.48580659593218,34.14220513834188,33.7986036807516,33.4550022231613,33.111400765571005,32.767799307980724,32.42419785039041,32.080596392800125,31.73699493520983,31.39339347761953,31.049792020029248,30.706190562438934,30.362589104848652,30.018987647258356,29.67538618966806,29.33178473207777,28.98818327448746,28.64458181689718,28.300980359306884,27.95737890171658,27.62391043122552,27.29246858003207,26.96102672883862,26.629584877645165,26.298143026451715,25.96670117525828,25.635259324064826,25.303817472871376,24.97237562167794,24.689818319944184,24.43170329294031,24.173588265936424,23.915473238932538,23.65735821192866,23.402608630828666,23.148339824269854,22.894071017711035,22.63980221115221,22.3855334045934,22.131264598034562,21.87699579147575,21.62272698491693,21.368458178358104,21.11418937179929,20.85992056524047,20.605651758681645,20.351382952122822,20.097114145564,19.842845339005187,19.58857653244636,19.33430772588754,19.08003891932873,18.825770112769895,18.57150130621108,18.317232499652256,18.062963693093433,17.808694886534624,17.554426079975787,17.300157273416975,17.045888466858152,16.79161966029933,16.546454813721578,16.301570091367232,16.056685369012897,15.81180064665855,15.566915924304208,15.322031201949878,15.077146479595534,14.832261757241195,14.587377034886863,14.342492312532517,14.097607590178178,13.852722867823838,13.607838145469493,13.36921127676451,13.131989232707685,12.894767188650846,12.657545144594005,12.42032310053717,12.183101056480334,11.945879012423507,11.708918530478254,11.486474714156268,11.264030897834278,11.041587081512304,10.819143265190316,10.596699448868332,10.389960220026115,10.185849654564617,9.98173908910313,9.77968062409827,9.586446194123528,9.393211764148786,9.208379345755498,9.033907690807814,8.866878679885982,8.715524327939482,8.57668124061884,8.449936711830176,8.339433653948149,8.247437863591973,8.164990739060617,8.082543614529266,8.000096489997908,7.917649365466549,7.8352022409351925,7.752755116403843,7.670307991872486,7.587860867341127,7.505413742809777,7.4229666182784255,7.340519493747069,7.258072369215719,7.175625244684353,7.093178120153002,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[53.29073004408654,53.28745265109182,53.2841752580971,53.28089786510238,53.27762047210767,53.27434307911295,53.271065686118234,53.267788293123516,53.264510900128805,53.26123350713409,53.25795611413937,53.25467872114465,53.25140132814994,53.24812393515522,53.2448465421605,53.24156914916579,53.23829175617107,53.235014363176354,53.231736970181636,53.22845957718692,53.22518218419221,53.22190479119749,53.21862739820277,53.21535000520806,53.21207261221333,53.20879521921862,53.205517826223904,53.20224043322918,53.198963040234474,53.19568564723975,53.19240825424504,53.18913086125033,53.1858534682556,53.18257607526089,53.17929868226617,53.17602128927146,53.17274389627674,53.16946650328202,53.16618911028731,53.16291171729259,53.15963432429787,53.15635693130315,53.15307953830843,53.14980214531373,53.14652475231901,53.14324735932429,53.13996996632957,53.136692573334855,53.13341518034014,53.13013778734542,53.12686039435071,53.123583001355996,53.12030560836128,53.11702821536656,53.11375082237184,53.11047342937712,53.107196036382405,53.103918643387686,53.100641250392975,53.097363857398264,53.094086464403546,53.09080907140883,53.08753167841411,53.08425428541939,53.08097689242467,53.077699499429954,53.07442210643524,53.07114471344053,53.067867320445814,53.064589927451095,53.06131253445638,53.05803514146166,53.05475774846694,53.05148035547222,53.048202962477504,53.0449255694828,53.0407413399399,53.03202297168541,53.02330460343092,53.01458623517643,53.00586786692194,52.997149498667454,52.988431130412955,52.97971276215847,52.68462094422613,52.3322544363582,51.9798879284903,51.62752142062239,51.27515491275447,50.922788404886575,50.57042189701866,50.22243790246818,49.878836444877884,49.53523498728758,49.1916335296973,48.848032072106996,48.5044306145167,48.160829156926404,47.81722769933611,47.473626241745826,47.13002478415553,46.78642332656523,46.44282186897493,46.099220411384636,45.755618953794354,45.41201749620406,45.068416038613755,44.72481458102347,44.38121312343316,44.03761166584288,43.69401020825258,43.35040875066228,43.006807293072,42.66320583548168,42.3196043778914,41.976002920301106,41.63240146271081,41.28880000512052,40.945198547530225,40.60159708993993,40.25799563234963,39.91439417475933,39.57079271716905,39.22719125957875,38.88358980198846,38.539988344398175,38.19638688680786,37.852785429217576,37.50918397162728,37.165582514036984,36.8219810564467,36.478379598856385,36.1347781412661,35.79117668367581,35.447575226085505,35.10397376849522,34.76037231090493,34.41677085331463,34.073169395724335,33.72956793813404,33.38596648054375,33.042365022953454,32.69876356536315,32.35516210777287,32.01156065018256,31.667959192592274,31.32435773500198,30.980756277411682,30.6371548198214,30.293553362231087,29.949951904640805,29.606350447050502,29.262748989460206,28.919147531869925,28.575546074279615,28.231944616689333,27.88834315909903,27.544741701508734,27.201140243918452,26.857538786328153,26.513937328737853,26.170335871147557,25.82673441355726,25.48313295596698,25.139531498376677,24.79593004078638,24.4523285831961,24.16828222629344,23.91401341973463,23.659744613175803,23.40547580661698,23.151207000058168,22.896938193499334,22.642669386940522,22.3884005803817,22.134131773822876,21.87986296726406,21.625594160705226,21.371325354146414,21.117056547587595,20.862787741028768,20.608518934469956,20.354250127911136,20.09998132135231,19.84571251479349,19.591443708234664,19.33717490167585,19.082906095117025,18.828637288558205,18.574368481999393,18.320099675440556,18.065830868881747,17.81156206232292,17.563245843930083,17.318361121575755,17.0734763992214,16.828591676867074,16.583706954512728,16.338822232158385,16.093937509804054,15.849052787449711,15.604168065095372,15.35928334274103,15.114398620386687,14.869513898032357,14.624629175678013,14.379744453323674,14.135115153253341,13.897893109196506,13.660671065139667,13.423449021082828,13.186226977025989,12.949004932969153,12.711782888912328,12.474560844855487,12.23733880079865,12.005674940359675,11.783231124037691,11.560787307715714,11.33834349139373,11.115899675071743,10.893455858749753,10.682874735564933,10.478764170103435,10.274653604641935,10.070543039180437,9.87269138123414,9.679456951259407,9.486222521284667,9.302988031499389,9.128516376551703,8.95804796202724,8.806693610080742,8.66113394937656,8.529797620194008,8.412887198231529,8.309675931434484,8.220664099148571,8.138216974617213,8.055769850085856,7.973322725554504,7.890875601023147,7.80842847649179,7.725981351960432,7.6435342274290825,7.561087102897725,7.478639978366367,7.396192853835017,7.313745729303665,7.231298604772308,7.148851480240957,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[53.01945902037871,53.016181627384,53.01290423438928,53.009626841394564,53.00634944839985,53.003072055405134,52.999794662410416,52.9965172694157,52.99323987642098,52.98996248342627,52.98668509043155,52.98340769743683,52.98013030444211,52.9768529114474,52.973575518452684,52.970298125457965,52.96702073246325,52.963743339468536,52.96046594647382,52.9571885534791,52.95391116048438,52.95063376748966,52.947356374494944,52.94407898150023,52.940801588505515,52.937524195510804,52.934246802516085,52.93096940952137,52.92769201652665,52.92441462353193,52.92113723053721,52.9178598375425,52.914582444547776,52.91130505155307,52.90802765855835,52.904750265563635,52.901472872568924,52.8981954795742,52.89491808657949,52.89164069358477,52.88836330059006,52.88508590759534,52.88180851460062,52.8785311216059,52.875253728611185,52.871976335616466,52.86869894262175,52.86542154962704,52.86214415663232,52.85886676363761,52.85558937064289,52.85231197764817,52.84903458465345,52.845757191658734,52.842479798664016,52.8392024056693,52.83592501267458,52.83264761967986,52.82937022668515,52.82609283369044,52.81918811948416,52.81046975122968,52.80175138297518,52.7930330147207,52.78431464646621,52.775596278211715,52.76687790995723,52.75815954170274,52.749441173448254,52.74072280519376,52.73200443693927,52.723286068684786,52.714567700430294,52.7058493321758,52.69713096392131,52.68841259566682,52.679694227412334,52.67097585915784,52.66225749090336,52.653539122648866,52.644820754394374,52.63610238613988,52.62738401788539,52.61866564963091,52.32357383169857,51.97120732383063,51.618840815962734,51.26647430809482,50.91410780022691,50.56174129235901,50.2093747844911,49.857008276623176,49.50464176875526,49.15227526088736,48.79990875301946,48.447542245151546,48.095175737283625,47.74280922941571,47.3904427215478,47.0380762136799,46.68570970581199,46.333343197944075,45.98097669007616,45.62861018220825,45.27624367434036,44.92387716647244,44.571510658604524,44.219144150736625,43.875542686103785,43.53194122851351,43.18833977092321,42.844738313332904,42.50113685574263,42.157535398152305,41.81393394056203,41.47033248297173,41.12673102538144,40.78312956779115,40.439528110200854,40.09592665261056,39.75232519502026,39.40872373742996,39.06512227983967,38.72152082224938,38.37791936465908,38.034317907068804,37.69071644947849,37.347114991888205,37.00351353429791,36.659912076707606,36.316310619117324,35.972709161527014,35.62910770393673,35.28550624634643,34.94190478875613,34.59830333116585,34.254701873575556,33.91110041598526,33.56749895839496,33.22389750080466,32.88029604321438,32.536694585624076,32.19309312803378,31.8494916704435,31.50589021285319,31.162288755262907,30.81868729767261,30.47508584008231,30.13148438249203,29.787882924901716,29.444281467311434,29.10068000972113,28.757078552130835,28.413477094540553,28.06987563695024,27.726274179359958,27.38267272176966,27.039071264179363,26.69546980658908,26.351868348998778,26.008266891408482,25.664665433818186,25.321063976227887,24.977462518637605,24.63386106104731,24.29025960345701,23.946658145866728,23.662611788964064,23.408342982405255,23.154074175846432,22.899805369287606,22.645536562728793,22.39126775616996,22.136998949611147,21.882730143052324,21.6284613364935,21.37419252993469,21.119923723375855,20.865654916817043,20.61138611025822,20.357117303699397,20.102848497140585,19.84857969058176,19.59431088402294,19.340042077464112,19.08577327090529,18.83150446434648,18.58003687413857,18.335152151784225,18.090267429429893,17.84538270707554,17.600497984721216,17.35561326236687,17.11072854001253,16.8658438176582,16.62095909530384,16.376074372949518,16.13118965059517,15.886304928240829,15.641420205886497,15.396535483532155,15.151650761177816,14.906766038823474,14.663796985685282,14.426574941628456,14.18935289757162,13.952130853514777,13.714908809457953,13.477686765401113,13.240464721344278,13.003242677287439,12.7660206332306,12.528798589173764,12.302431350241083,12.079987533919098,11.857543717597114,11.635099901275122,11.412656084953138,11.19021226863116,10.975789251103716,10.771678685642218,10.567568120180722,10.363457554719233,10.159346989257735,9.96570213837,9.772467708395258,9.579233278420514,9.397596717243268,9.223125062295583,9.049217244168478,8.897862892221978,8.746508540275485,8.614250328951716,8.48796498014435,8.375837684632875,8.279918208920805,8.19389033470516,8.111443210173801,8.028996085642444,7.9465489611110876,7.864101836579736,7.78165471204838,7.699207587517021,7.616760462985664,7.5343133384543135,7.451866213922956,7.369419089391599,7.286971964860247,7.204524840328897,7.1220777157975395,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[52.74818799667089,52.744910603676175,52.74163321068146,52.73835581768674,52.735078424692034,52.731801031697316,52.72852363870259,52.72524624570788,52.72196885271316,52.71869145971844,52.71541406672373,52.712136673729006,52.708859280734295,52.705581887739584,52.702304494744865,52.69902710175015,52.69574970875543,52.69247231576072,52.689194922766,52.68591752977128,52.68264013677656,52.679362743781844,52.67608535078713,52.672807957792415,52.6695305647977,52.66625317180298,52.66297577880827,52.65969838581354,52.65642099281883,52.65314359982411,52.649866206829394,52.64658881383469,52.64331142083996,52.64003402784525,52.63675663485053,52.63347924185582,52.6302018488611,52.62692445586637,52.62364706287167,52.62036966987694,52.61709227688223,52.613814883887514,52.610537490892796,52.60635326728293,52.597634899028435,52.58891653077394,52.58019816251945,52.57147979426496,52.562761426010475,52.55404305775599,52.54532468950149,52.536606321247014,52.527887952992515,52.51916958473803,52.510451216483546,52.50173284822905,52.49301447997456,52.48429611172007,52.47557774346558,52.466859375211094,52.458141006956595,52.44942263870212,52.44070427044762,52.431985902193134,52.42326753393864,52.41454916568415,52.40583079742967,52.39711242917517,52.38839406092069,52.3796756926662,52.370957324411705,52.36223895615722,52.35352058790273,52.344802219648244,52.33608385139375,52.32736548313926,52.31864711488477,52.30992874663028,52.301210378375785,52.2924920101213,52.283773641866816,52.275055273612324,52.26633690535783,52.25761853710334,51.962526719171,51.61016021130307,51.257793703435176,50.90542719556726,50.55306068769935,50.20069417983145,49.84832767196354,49.49596116409562,49.143594656227705,48.79122814835979,48.43886164049189,48.08649513262398,47.73412862475606,47.38176211688815,47.029395609020234,46.677029101152335,46.32466259328443,45.97229608541651,45.619929577548604,45.26756306968069,44.91519656181279,44.56283005394487,44.21046354607696,43.85809703820906,43.50573053034113,43.153364022473234,42.800997514605314,42.44863100673741,42.09626449886951,41.74389799100158,41.391531483133676,41.03916497526576,40.68679846739785,40.33443195952995,39.98206545166204,39.629698943794125,39.27733243592621,38.9249659280583,38.5725994201904,38.22023291232249,37.872248927329714,37.52864746973943,37.185046012149115,36.84144455455883,36.49784309696854,36.154241639378235,35.81064018178795,35.46703872419764,35.12343726660736,34.77983580901706,34.43623435142676,34.09263289383648,33.749031436246185,33.40542997865588,33.061828521065586,32.71822706347529,32.37462560588501,32.031024148294705,31.68742269070441,31.343821233114127,31.000219775523814,30.656618317933532,30.313016860343236,29.969415402752936,29.625813945162655,29.28221248757234,28.93861102998206,28.59500957239176,28.25140811480146,27.907806657211175,27.564205199620865,27.220603742030583,26.877002284440287,26.53340082684999,26.18979936925971,25.846197911669407,25.50259645407911,25.15899499648881,24.815393538898512,24.47179208130823,24.128190623717934,23.78458916612764,23.440987708537357,23.156941351634693,22.90267254507588,22.648403738517057,22.394134931958234,22.139866125399422,21.885597318840585,21.631328512281776,21.37705970572295,21.12279089916413,20.868522092605318,20.614253286046484,20.359984479487668,20.105715672928845,19.851446866370022,19.59717805981121,19.351943181992716,19.107058459638374,18.862173737284028,18.617289014929685,18.372404292575357,18.127519570221015,17.88263484786667,17.637750125512337,17.392865403157984,17.147980680803656,16.903095958449313,16.65821123609497,16.413326513740643,16.168441791386282,15.923557069031961,15.678672346677615,15.433787624323273,15.192478818117243,14.955256774060405,14.718034730003568,14.480812685946727,14.243590641889895,14.006368597833065,13.769146553776231,13.531924509719389,13.294702465662564,13.057480421605725,12.821631576444464,12.599187760122481,12.376743943800493,12.154300127478507,11.931856311156528,11.709412494834545,11.48696867851256,11.2687037666425,11.064593201181001,10.860482635719512,10.656372070258014,10.452261504796517,10.25194732548059,10.058712895505858,9.865478465531115,9.672244035556373,9.492205402987139,9.317733748039453,9.143262093091776,8.98903217436322,8.83767782241672,8.698703037709416,8.567366708526874,8.450915466545696,8.34334985999143,8.250160486407129,8.16711657026174,8.084669445730391,8.002222321199033,7.919775196667676,7.837328072136318,7.754880947604967,7.67243382307361,7.589986698542252,7.507539574010895,7.4250924494795445,7.342645324948188,7.26019820041683,7.17775107588548,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[52.476916972963096,52.47363957996838,52.47036218697365,52.467084793978934,52.46380740098422,52.46053000798951,52.45725261499479,52.453975222000075,52.450697829005364,52.447420436010646,52.44414304301593,52.4408656500212,52.43758825702649,52.43431086403178,52.43103347103706,52.42775607804234,52.424478685047625,52.42120129205291,52.417923899058195,52.414646506063484,52.41136911306876,52.40809172007404,52.40481432707932,52.40153693408461,52.398259541089885,52.394982148095174,52.39170475510047,52.384800046827216,52.37608167857274,52.36736331031825,52.358644942063755,52.34992657380926,52.34120820555477,52.332489837300294,52.3237714690458,52.31505310079131,52.30633473253681,52.29761636428233,52.28889799602784,52.28017962777335,52.27146125951886,52.26274289126437,52.25402452300988,52.2453061547554,52.236587786500905,52.227869418246414,52.21915104999192,52.21043268173742,52.20171431348294,52.19299594522846,52.18427757697396,52.17555920871948,52.16684084046498,52.15812247221049,52.149404103956016,52.14068573570151,52.131967367447025,52.123248999192526,52.11453063093804,52.10581226268356,52.097093894429065,52.08837552617458,52.07965715792009,52.07093878966559,52.06222042141111,52.05350205315662,52.04478368490213,52.036065316647644,52.027346948393145,52.01862858013867,52.009910211884176,52.001191843629684,51.9924734753752,51.9837551071207,51.97503673886622,51.966318370611724,51.95760000235723,51.94888163410275,51.940163265848255,51.931444897593764,51.92272652933927,51.91400816108478,51.9052897928303,51.896571424575804,51.601479606643466,51.24911309877553,50.89674659090764,50.544380083039734,50.192013575171806,49.83964706730391,49.487280559436,49.134914051568074,48.782547543700176,48.430181035832256,48.07781452796436,47.725448020096444,47.37308151222853,47.02071500436062,46.668348496492705,46.315981988624806,45.963615480756886,45.61124897288898,45.25888246502107,44.90651595715315,44.55414944928525,44.20178294141735,43.84941643354943,43.49704992568153,43.144683417813596,42.7923169099457,42.439950402077784,42.08758389420987,41.73521738634197,41.38285087847404,41.030484370606146,40.67811786273823,40.32575135487032,39.97338484700242,39.62101833913451,39.268651831266595,38.91628532339868,38.56391881553076,38.21155230766286,37.85918579979495,37.50681929192703,37.154452784059146,36.80208627619121,36.44971976832331,36.09735326045539,35.74498675258749,35.39262024471959,35.04025373685165,34.68788722898376,34.33552072111584,33.983154213247936,33.63078770538004,33.27842119751212,32.92605468964421,32.57368818177629,32.22132167390838,31.868955168555672,31.52535371096537,31.18175225337507,30.838150795784788,30.494549338194478,30.150947880604196,29.807346423013897,29.4637449654236,29.12014350783332,28.776542050243005,28.432940592652724,28.089339135062424,27.745737677472125,27.402136219881843,27.05853476229153,26.714933304701248,26.371331847110948,26.027730389520652,25.68412893193037,25.34052747434007,24.996926016749775,24.65332455915948,24.309723101569176,23.966121643978894,23.6225201863886,23.2789187287983,22.935317271208017,22.651270914305357,22.397002107746548,22.142733301187718,21.8884644946289,21.63419568807009,21.379926881511253,21.12565807495244,20.871389268393617,20.61712046183479,20.36873421220123,20.123849489846883,19.878964767492548,19.634080045138205,19.389195322783863,19.144310600429534,18.8994258780752,18.65454115572085,18.409656433366507,18.164771711012165,17.919886988657836,17.675002266303494,17.430117543949148,17.185232821594816,16.940348099240463,16.695463376886135,16.450578654531792,16.205693932177454,15.960809209823122,15.72116065054922,15.483938606492384,15.246716562435552,15.009494518378713,14.772272474321888,14.535050430265049,14.297828386208211,14.060606342151372,13.823384298094538,13.58616225403771,13.348940209980874,13.118387986325892,12.895944170003915,12.673500353681927,12.45105653735994,12.228612721037956,12.006168904715969,11.783725088393982,11.56161828218132,11.357507716719821,11.153397151258321,10.949286585796822,10.745176020335325,10.541065454873834,10.344958082616472,10.15172365264173,9.958489222666987,9.765254792692255,9.586814088731037,9.412342433783351,9.237870778835667,9.080201456504472,8.928847104557981,8.783155746467138,8.651819417284589,8.525993248458523,8.413865952947054,8.313592137477764,8.22278993034969,8.140342805818332,8.05789568128698,7.975448556755631,7.893001432224273,7.810554307692915,7.7281071831615575,7.645660058630208,7.56321293409885,7.480765809567492,7.398318685036135,7.3158715605047835,7.233424435973427,7.15097731144207,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[52.20564594925528,52.20236855626056,52.199091163265834,52.19581377027112,52.192536377276404,52.18925898428169,52.185981591286975,52.18270419829226,52.179426805297545,52.17614941230283,52.17196519462598,52.16324682637149,52.15452845811701,52.145810089862515,52.13709172160802,52.12837335335353,52.11965498509905,52.110936616844555,52.10221824859007,52.09349988033558,52.084781512081086,52.076063143826595,52.06734477557211,52.05862640731762,52.049908039063126,52.04118967080864,52.03247130255415,52.02375293429966,52.01503456604517,52.00631619779068,51.99759782953619,51.9888794612817,51.980161093027206,51.97144272477273,51.96272435651824,51.954005988263745,51.94528762000925,51.93656925175476,51.92785088350028,51.919132515245785,51.9104141469913,51.90169577873681,51.89297741048232,51.884259042227825,51.87554067397334,51.86682230571884,51.858103937464364,51.849385569209865,51.84066720095538,51.83194883270089,51.8232304644464,51.81451209619192,51.80579372793741,51.79707535968293,51.788356991428444,51.77963862317395,51.77092025491947,51.76220188666497,51.753483518410484,51.744765150156,51.7360467819015,51.727328413647015,51.71861004539252,51.70989167713803,51.70117330888355,51.692454940629055,51.68373657237457,51.67501820412008,51.66629983586559,51.6575814676111,51.64886309935662,51.64014473110212,51.63142636284763,51.62270799459314,51.61398962633865,51.60527125808416,51.596552889829674,51.58783452157518,51.5791161533207,51.570397785066206,51.561679416811714,51.55296104855722,51.54424268030273,51.53552431204824,51.24043249411591,50.88806598624797,50.535699478380074,50.18333297051216,49.83096646264425,49.47859995477635,49.12623344690844,48.773866939040516,48.4215004311726,48.0691339233047,47.7167674154368,47.364400907568886,47.012034399700966,46.65966789183305,46.30730138396514,45.95493487609724,45.60256836822933,45.25020186036141,44.8978353524935,44.54546884462559,44.19310233675769,43.84073582888977,43.48836932102186,43.13600281315396,42.78363630528604,42.43126979741814,42.07890328955022,41.726536781682306,41.37417027381441,41.02180376594649,40.66943725807859,40.31707075021067,39.96470424234275,39.612337734474856,39.25997122660694,38.90760471873903,38.55523821087111,38.2028717030032,37.8505051951353,37.498138687267385,37.14577217939947,36.79340567153158,36.441039163663646,36.08867265579575,35.736306147927834,35.38393964005992,35.03157313219202,34.679206624324095,34.3268401164562,33.97447360858828,33.62210710072036,33.269740592852465,32.91737408498456,32.56500757711664,32.212641069248726,31.860274561380812,31.507908053512917,31.155541545645,30.803175037777088,30.45080852990919,30.098442022041258,29.746075514173363,29.393709006305446,29.041342498437533,28.688975990569634,28.336609482701704,27.98424297483381,27.631876466965892,27.27950995909798,26.927143451230084,26.574776943362153,26.222410435494254,25.87004392762634,25.52205995219128,25.178458494601,24.834857037010703,24.4912555794204,24.147654121830104,23.80405266423981,23.460451206649523,23.116849749059227,22.773248291468928,22.42964683387865,22.145600476975982,21.891331670417173,21.637062863858347,21.385525242409702,21.140640520055374,20.89575579770102,20.650871075346693,20.405986352992347,20.161101630638008,19.916216908283673,19.671332185929327,19.42644746357499,19.18156274122065,18.936678018866306,18.691793296511978,18.44690857415764,18.202023851803297,17.95713912944895,17.71225440709461,17.46736968474028,17.222484962385938,16.977600240031595,16.73271551767726,16.487830795322907,16.249842482981173,16.012620438924337,15.775398394867503,15.538176350810673,15.30095430675383,15.063732262696995,14.826510218640163,14.589288174583324,14.352066130526499,14.114844086469661,13.877622042412822,13.640399998355983,13.415144396207287,13.192700579885312,12.970256763563325,12.74781294724134,12.525369130919362,12.302925314597374,12.080481498275388,11.858037681953403,11.650422232258604,11.446311666797104,11.242201101335617,11.038090535874117,10.83397997041262,10.631203269727061,10.43796883975232,10.244734409777587,10.051499979802845,9.858265549828102,9.681422774474907,9.50695111952723,9.332479464579546,9.171370738645715,9.020016386699215,8.868662034752717,8.736272126042294,8.604935796859746,8.48894373485987,8.377023788548385,8.28383441496409,8.196016165906277,8.113569041374921,8.031121916843562,7.948674792312212,7.866227667780862,7.783780543249505,7.701333418718146,7.6188862941867885,7.536439169655439,7.453992045124082,7.371544920592724,7.289097796061366,7.206650671530015,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[51.93020650706048,51.91493653912366,51.89966657118683,51.884396603249996,51.86912663531317,51.85385666737635,51.83858669943952,51.825500605207566,51.816782236953074,51.80806386869858,51.79934550044409,51.7906271321896,51.78190876393512,51.77319039568063,51.76447202742614,51.755753659171646,51.747035290917154,51.73831692266266,51.729598554408184,51.72088018615369,51.7121618178992,51.70344344964471,51.69472508139022,51.686006713135725,51.677288344881234,51.668569976626756,51.659851608372264,51.65113324011777,51.64241487186328,51.63369650360879,51.6249781353543,51.61625976709982,51.60754139884533,51.598823030590836,51.590104662336344,51.58138629408185,51.57266792582736,51.56394955757287,51.55523118931839,51.5465128210639,51.53779445280941,51.529076084554916,51.520357716300424,51.51163934804593,51.502920979791455,51.49420261153696,51.48548424328247,51.47676587502798,51.46804750677349,51.459329138519,51.45061077026451,51.441892402010026,51.433174033755535,51.42445566550104,51.41573729724656,51.40701892899206,51.398300560737574,51.38958219248308,51.3808638242286,51.372145455974106,51.363427087719614,51.35470871946513,51.34599035121063,51.337271982956146,51.32855361470166,51.31983524644717,51.31111687819268,51.302398509938186,51.293680141683694,51.28496177342922,51.276243405174725,51.26752503692023,51.25880666866574,51.25008830041125,51.24136993215676,51.232651563902266,51.22393319564779,51.2152148273933,51.206496459138805,51.19777809088431,51.18905972262982,51.180341354375344,51.17162298612085,51.16290461786636,50.86463966628775,50.50846539804431,50.1522911298009,49.79611686155747,49.439942593314036,49.08376832507063,48.72822868770856,48.375862179840645,48.02349567197274,47.671129164104826,47.31876265623693,46.96639614836901,46.614029640501094,46.26166313263318,45.90929662476527,45.55693011689737,45.20456360902945,44.852197101161536,44.49983059329363,44.14746408542571,43.79509757755782,43.442731069689906,43.09036456182199,42.737998053954094,42.38563154608616,42.03326503821826,41.68089853035035,41.328532022482435,40.976165514614536,40.6237990067466,40.27143249887871,39.9190659910108,39.566699483142884,39.214332975274985,38.86196646740707,38.50959995953916,38.157233451671246,37.80486694380333,37.452500435935434,37.10013392806752,36.74776742019961,36.39540091233171,36.043034404463775,35.690667896595876,35.33830138872797,34.98593488086005,34.63356837299215,34.281201865124224,33.928835357256325,33.57646884938841,33.2241023415205,32.8717358336526,32.51936932578469,32.167002817916774,31.814636310048858,31.46226980218095,31.10990329431305,30.757536786445133,30.405170278577216,30.052803770709318,29.70043726284139,29.34807075497349,28.99570424710558,28.643337739237666,28.290971231369767,27.93860472350184,27.58623821563394,27.233871707766024,26.88150519989811,26.529138692030216,26.17677218416228,25.824405676294386,25.47203916842647,25.119672660558557,24.767306152690658,24.414939644822745,24.062573136954832,23.710206629086915,23.357840121219002,23.005473613351107,22.65310710548319,22.300740597615277,21.94837408974738,21.667662105555166,21.42277738320083,21.17789266084649,20.933007938492146,20.688123216137818,20.443238493783465,20.198353771429137,19.953469049074794,19.70858432672045,19.463699604366116,19.21881488201177,18.97393015965744,18.729045437303093,18.48416071494875,18.239275992594422,17.99439127024008,17.749506547885737,17.504621825531395,17.259737103177052,17.01574635946996,16.778524315413126,16.541302271356287,16.304080227299462,16.066858183242616,15.829636139185787,15.592414095128948,15.355192051072112,15.117970007015284,14.880747962958441,14.643525918901606,14.406303874844774,14.169081830787935,13.934344622410679,13.711900806088694,13.489456989766708,13.267013173444719,13.044569357122732,12.822125540800759,12.59968172447877,12.377237908156786,12.154794091834809,11.943336747797396,11.739226182335896,11.5351156168744,11.3310050514129,11.126894485951402,10.922783920489913,10.72421402686292,10.530979596888178,10.337745166913436,10.144510736938694,9.95127630696396,9.776031460218785,9.601559805271101,9.427088150323415,9.26254002078696,9.11118566884046,8.95983131689396,8.820724834799996,8.689388505617446,8.56402151677269,8.451894221261217,8.347266066034711,8.254076692450411,8.169242401462867,8.08679527693151,8.004348152400151,7.9219010278687945,7.839453903337443,7.757006778806093,7.674559654274735,7.592112529743378,7.50966540521202,7.427218280680669,7.344771156149313,7.262324031617955,7.179876907086597,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[51.6486186458068,51.633348677869975,51.61807870993315,51.60280874199631,51.58753877405949,51.572268806122665,51.55699883818584,51.54172887024902,51.526458902312186,51.51118893437536,51.49591896643852,51.4806489985017,51.465379030564876,51.45010906262805,51.43483909469121,51.41956912675439,51.404299158817565,51.38902919088074,51.37375922294391,51.358489255007086,51.34321928707026,51.32794931913343,51.3126793511966,51.297409383259776,51.28759908778798,51.27888071953349,51.270162351279,51.261443983024506,51.25272561477003,51.24400724651554,51.235288878261045,51.22657051000655,51.21785214175206,51.20913377349757,51.20041540524309,51.191697036988586,51.18297866873411,51.17426030047962,51.165541932225125,51.15682356397063,51.14810519571614,51.139386827461664,51.13066845920717,51.12195009095268,51.11323172269819,51.1045133544437,51.09579498618921,51.08707661793471,51.07835824968023,51.06963988142574,51.060921513171245,51.05220314491677,51.04348477666226,51.034766408407776,51.0260480401533,51.0173296718988,51.008611303644315,50.999892935389816,50.99117456713533,50.98245619888085,50.973737830626355,50.96501946237187,50.95630109411737,50.94758272586288,50.938864357608395,50.9301459893539,50.92142762109941,50.912709252844934,50.90399088459044,50.89527251633595,50.88655414808146,50.87783577982697,50.869117411572475,50.860399043318,50.851680675063506,50.842962306809014,50.83424393855452,50.82552557030003,50.81680720204555,50.80808883379105,50.799370465536555,50.79065209728208,50.781933729027585,50.773215360773094,50.47495040919449,50.11877614095104,49.76260187270764,49.40642760446421,49.05025333622078,48.69407906797737,48.337904799733934,47.98173053149051,47.625556263247084,47.269381995003656,46.91320772676025,46.55703345851682,46.20085919027339,45.84468492202996,45.488510653786534,45.13233638554313,44.7761621172997,44.41998784905626,44.063813580812834,43.70763931256941,43.351465044326,42.99529077608257,42.63911650783914,42.28548075003658,41.93311424216864,41.58074773430074,41.22838122643283,40.87601471856492,40.52364821069702,40.171281702829084,39.81891519496119,39.46654868709327,39.11418217922536,38.76181567135747,38.409449163489555,38.05708265562164,37.70471614775372,37.35234963988581,36.99998313201791,36.64761662415,36.29525011628208,35.942883608414185,35.59051710054626,35.23815059267836,34.885784084810446,34.533417576942526,34.18105106907463,33.8286845612067,33.4763180533388,33.123951545470895,32.771585037602975,32.419218529735076,32.06685202186716,31.71448551399925,31.362119006131334,31.009752498263424,30.657385990395525,30.305019482527612,29.9526529746597,29.6002864667918,29.247919958923866,28.895553451055967,28.543186943188058,28.19082043532014,27.83845392745225,27.486087419584315,27.133720911716416,26.781354403848503,26.42898789598059,26.07662138811269,25.724254880244764,25.371888372376866,25.01952186450895,24.667155356641036,24.314788848773137,23.96242234090522,23.610055833037308,23.257689325169395,22.90532281730148,22.552956309433583,22.20058980156567,21.848223293697757,21.495856785829858,21.215144801637646,20.970260079283314,20.725375356928968,20.480490634574625,20.235605912220297,19.990721189865944,19.745836467511616,19.500951745157273,19.25606702280293,19.011182300448596,18.76629757809425,18.521412855739914,18.276528133385572,18.03164341103123,17.7867586886769,17.544428191901943,17.307206147845108,17.069984103788272,16.832762059731436,16.595540015674604,16.35831797161777,16.12109592756093,15.883873883504107,15.646651839447259,15.40942979539043,15.172207751333591,14.934985707276757,14.697763663219927,14.460541619163084,14.23110103229211,14.008657215970118,13.786213399648133,13.563769583326154,13.34132576700417,13.118881950682184,12.896438134360196,12.673994318038208,12.451550501716234,12.236251263336205,12.032140697874706,11.828030132413218,11.623919566951718,11.41980900149022,11.215698436028722,11.011587870567222,10.817224783998793,10.623990354024059,10.430755924049317,10.237521494074574,10.045111800910359,9.870640145962675,9.696168491014998,9.521696836067314,9.353709302928209,9.20235495098171,9.05100059903522,8.905177543557716,8.773841214375166,8.642504885192617,8.526972003174043,8.414844707662574,8.317508343521045,8.224915761550808,8.14246863701945,8.0600215124881,7.977574387956743,7.895127263425386,7.812680138894027,7.7302330143626765,7.647785889831327,7.565338765299969,7.482891640768612,7.400444516237254,7.317997391705903,7.235550267174546,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[51.367030784553094,51.35176081661627,51.33649084867944,51.321220880742615,51.305950912805784,51.29068094486896,51.275410976932136,51.260141008995305,51.244871041058474,51.22960107312166,51.214331105184826,51.199061137247995,51.183791169311164,51.16852120137435,51.153251233437516,51.13798126550069,51.12271129756386,51.10744132962704,51.09217136169021,51.076901393753374,51.06163142581655,51.046361457879726,51.031091489942895,51.01582152200607,51.00055155406924,50.985281586132416,50.970011618195585,50.95474165025876,50.93947168232194,50.92420171438511,50.90893174644829,50.89366177851145,50.87839181057463,50.8631218426378,50.847851874700964,50.83258190676414,50.81731193882732,50.80204197089049,50.78677200295367,50.77150203501684,50.75841593862285,50.74969757036837,50.74097920211388,50.732260833859385,50.72354246560489,50.7148240973504,50.70610572909592,50.69738736084142,50.68866899258693,50.67995062433245,50.67123225607796,50.66251388782347,50.65379551956897,50.64507715131448,50.636358783060004,50.62764041480551,50.61892204655102,50.61020367829653,50.60148531004204,50.59276694178755,50.58404857353306,50.575330205278576,50.566611837024084,50.55789346876959,50.54917510051511,50.540456732260616,50.531738364006124,50.52301999575164,50.51430162749715,50.505583259242655,50.49686489098817,50.48814652273368,50.47942815447919,50.4707097862247,50.46199141797021,50.45327304971572,50.44455468146123,50.435836313206735,50.42711794495225,50.418399576697766,50.409681208443274,50.40096284018878,50.39224447193429,50.3835261036798,50.0852611521012,49.729086883857754,49.37291261561434,49.01673834737092,48.66056407912748,48.304389810884075,47.948215542640646,47.59204127439722,47.23586700615379,46.87969273791036,46.52351846966695,46.16734420142352,45.811169933180096,45.45499566493666,45.09882139669324,44.742647128449825,44.386472860206396,44.030298591962975,43.674124323719546,43.31795005547611,42.9617757872327,42.605601518989275,42.24942725074585,41.89325298250243,41.53707871425899,41.180904446015575,40.824730177772146,40.46855590952872,40.11238164128531,39.75620737304187,39.40003310479845,39.043858836555025,38.6876845683116,38.33151030006819,37.97533603182476,37.61916176358133,37.2629874953379,36.906813227094474,36.55063895885106,36.195099320232444,35.842732812364524,35.490366304496625,35.1379997966287,34.7856332887608,34.43326678089289,34.08090027302497,33.728533765157074,33.37616725728915,33.02380074942125,32.671434241553335,32.31906773368542,31.966701225817523,31.61433471794961,31.261968210081694,30.90960170221378,30.557235194345868,30.204868686477973,29.852502178610056,29.50013567074214,29.147769162874248,28.795402655006313,28.443036147138415,28.0906696392705,27.73830313140259,27.38593662353469,27.033570115666762,26.681203607798864,26.32883709993095,25.976470592063034,25.624104084195135,25.271737576327205,24.919371068459306,24.567004560591393,24.21463805272348,23.86227154485558,23.509905036987668,23.157538529119755,22.805172021251842,22.45280551338393,22.10043900551603,21.748072497648117,21.395705989780204,21.043339481912305,20.76262749772009,20.517742775365754,20.27285805301141,20.02797333065707,19.78308860830274,19.538203885948388,19.29331916359406,19.048434441239717,18.803549718885375,18.55866499653104,18.31378027417669,18.0731100243339,17.835887980277057,17.598665936220222,17.361443892163397,17.124221848106554,16.88699980404972,16.649777759992883,16.412555715936048,16.175333671879216,15.93811162782238,15.700889583765541,15.463667539708718,15.226445495651868,14.98922345159504,14.752001407538202,14.527857442173502,14.305413625851525,14.08296980952953,13.860525993207553,13.638082176885561,13.41563836056358,13.193194544241601,12.970750727919617,12.74830691159763,12.52916577887499,12.32505521341349,12.120944647952003,11.916834082490503,11.712723517029005,11.508612951567516,11.304502386106018,11.10346997110939,10.91023554113465,10.717001111159908,10.523766681185165,10.330532251210434,10.139720486654237,9.965248831706553,9.79077717675887,9.616305521811185,9.444878585069453,9.293524233122954,9.142169881176454,8.990815529229955,8.858293923132873,8.726957593950324,8.602049785086862,8.48992248957539,8.380939994591667,8.28775062100737,8.198141997107397,8.11569487257604,8.033247748044683,7.950800623513333,7.868353498981974,7.785906374450617,7.703459249919259,7.621012125387908,7.538565000856558,7.456117876325201,7.373670751793842,7.291223627262484,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[51.08544292329941,51.07017295536258,51.05490298742575,51.039633019488925,51.0243630515521,51.00909308361527,50.99382311567844,50.978553147741614,50.96328317980479,50.94801321186796,50.93274324393114,50.91747327599431,50.90220330805748,50.886933340120656,50.87166337218383,50.856393404247,50.84112343631017,50.825853468373346,50.81058350043652,50.79531353249969,50.78004356456286,50.76477359662604,50.74950362868921,50.73423366075239,50.71896369281556,50.70369372487873,50.6884237569419,50.67315378900508,50.65788382106825,50.64261385313142,50.6273438851946,50.61207391725777,50.59680394932094,50.58153398138411,50.56626401344728,50.55099404551046,50.53572407757363,50.5204541096368,50.50518414169998,50.48991417376315,50.47464420582632,50.4593742378895,50.444104269952675,50.428834302015844,50.41356433407901,50.39829436614219,50.383024398205364,50.367754430268526,50.3524844623317,50.33721449439488,50.321944526458054,50.30667455852122,50.2914045905844,50.276134622647575,50.260864654710744,50.24559468677392,50.23032471883708,50.22051442120326,50.21179605294878,50.20307768469429,50.1943593164398,50.185640948185316,50.17692257993082,50.168204211676326,50.15948584342185,50.150767475167356,50.142049106912864,50.13333073865837,50.12461237040389,50.115894002149396,50.10717563389491,50.09845726564042,50.08973889738593,50.081020529131436,50.072302160876944,50.06358379262245,50.05486542436796,50.046147056113476,50.037428687858984,50.0287103196045,50.01999195135001,50.011273583095516,50.002555214841024,49.99383684658653,49.69557189500793,49.33939762676449,48.98322335852107,48.62704909027765,48.270874822034216,47.91470055379081,47.55852628554738,47.20235201730395,46.84617774906052,46.490003480817094,46.13382921257369,45.77765494433025,45.42148067608683,45.065306407843394,44.70913213959997,44.352957871356566,43.99678360311313,43.64060933486971,43.28443506662628,42.92826079838285,42.572086530139444,42.21591226189601,41.85973799365258,41.50356372540917,41.14738945716572,40.79121518892231,40.43504092067889,40.07886665243545,39.722692384192044,39.3665181159486,39.01034384770519,38.65416957946176,38.29799531121833,37.94182104297492,37.585646774731494,37.229472506488065,36.87329823824464,36.51712397000121,36.1609497017578,35.80477543351437,35.448601165270944,35.09242689702753,34.73625262878409,34.38007836054067,34.02390409229724,33.66772982405382,33.31155555581041,32.955381287566965,32.59920701932355,32.24303275108012,31.886858482836693,31.530684214593286,31.174509946349854,30.818335678106425,30.462161409862997,30.10598714161957,29.75235138256045,29.399984874692535,29.047618366824622,28.695251858956723,28.34288535108879,27.990518843220894,27.63815233535298,27.285785827485064,26.933419319617173,26.581052811749238,26.22868630388134,25.876319796013426,25.52395328814551,25.17158678027761,24.819220272409684,24.466853764541785,24.114487256673875,23.76212074880596,23.40975424093806,23.057387733070147,22.70502122520223,22.352654717334318,22.000288209466405,21.647921701598506,21.295555193730593,20.94318868586268,20.59082217799478,20.310110193802565,20.065225471448233,19.82034074909389,19.575456026739545,19.33057130438522,19.085686582030867,18.84080185967654,18.60179185676588,18.36456981270904,18.127347768652214,17.890125724595368,17.652903680538543,17.4156816364817,17.178459592424865,16.94123754836804,16.7040155043112,16.46679346025436,16.229571416197523,15.992349372140692,15.755127328083857,15.517905284027023,15.280683239970184,15.047057668376919,14.824613852054926,14.60217003573295,14.379726219410962,14.157282403088978,13.934838586767,13.712394770445004,13.489950954123028,13.267507137801037,13.045063321479056,12.822619505157075,12.617969728952309,12.413859163490809,12.20974859802931,12.005638032567813,11.801527467106323,11.597416901644825,11.393306336183326,11.196480728245273,11.003246298270529,10.810011868295788,10.616777438321044,10.423543008346304,10.234329172398125,10.059857517450451,9.885385862502767,9.710914207555081,9.536442552607397,9.384693515264205,9.233339163317712,9.081984811371214,8.942746631890587,8.811410302708037,8.680073973525495,8.565000271488222,8.452872975976748,8.351182272077999,8.2579928984937,8.171368232664003,8.088921108132643,8.006473983601285,7.9240268590699285,7.841579734538579,7.759132610007221,7.676685485475864,7.594238360944505,7.5117912364131545,7.429344111881804,7.346896987350448,7.264449862819089,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[50.8038550620457,50.788585094108875,50.77331512617205,50.75804515823522,50.74277519029839,50.72750522236157,50.71223525442474,50.69696528648791,50.681695318551085,50.66642535061426,50.65115538267743,50.6358854147406,50.620615446803775,50.60534547886695,50.59007551093013,50.5748055429933,50.55953557505647,50.54426560711964,50.52899563918282,50.51372567124599,50.49845570330916,50.48318573537233,50.4679157674355,50.45264579949868,50.43737583156185,50.42210586362502,50.406835895688204,50.39156592775137,50.37629595981454,50.36102599187771,50.34575602394089,50.33048605600406,50.31521608806724,50.299946120130414,50.28467615219358,50.26940618425675,50.25413621631993,50.238866248383104,50.22359628044627,50.20832631250944,50.193056344572625,50.17778637663579,50.16251640869896,50.14724644076213,50.131976472825315,50.116706504888484,50.10143653695166,50.08616656901483,50.070896601078005,50.05562663314117,50.04035666520435,50.025086697267525,50.009816729330694,49.99454676139386,49.97927679345704,49.964006825520215,49.948736857583384,49.93346688964655,49.91819692170973,49.902926953772905,49.887656985836074,49.87238701789924,49.85711704996242,49.841847082025595,49.826577114088764,49.81130714615194,49.796037178215116,49.780767210278285,49.76549724234145,49.75022727440463,49.734957306467805,49.71968733853098,49.70441737059415,49.69133127203814,49.68261290378365,49.67389453552916,49.66517616727467,49.65645779902018,49.6477394307657,49.639021062511205,49.63030269425671,49.62158432600222,49.612865957747736,49.604147589493245,49.30588263791464,48.9497083696712,48.59353410142779,48.237359833184364,47.88118556494093,47.52501129669752,47.16883702845409,46.81266276021066,46.456488491967235,46.10031422372381,45.7441399554804,45.387965687236964,45.03179141899354,44.675617150750114,44.31944288250669,43.96326861426328,43.60709434601985,43.250920077776414,42.89474580953299,42.538571541289556,42.18239727304615,41.82622300480272,41.47004873655929,41.113874468315885,40.757700200072435,40.40152593182903,40.0453516635856,39.68917739534217,39.333003127098756,38.97682885885531,38.6206545906119,38.26448032236847,37.90830605412505,37.552131785881635,37.195957517638206,36.83978324939478,36.48360898115135,36.12743471290792,35.771260444664506,35.415086176421084,35.058911908177656,34.70273763993424,34.34656337169079,33.990389103447384,33.63421483520396,33.27804056696053,32.92186629871712,32.56569203047367,32.20951776223026,31.853343493986834,31.497169225743406,31.14099495749999,30.784820689256563,30.428646421013138,30.072472152769713,29.71629788452628,29.36012361628287,29.00394934803944,28.647775079796013,28.291600811552602,27.935426543309156,27.579252275065745,27.223078006822313,26.866903738578888,26.510729470335477,26.154555202092034,25.798380933848623,25.442206665605195,25.086032397361766,24.729858129118355,24.37368386087491,24.017509592631498,23.661969952756316,23.3096034448884,22.957236937020504,22.60487042915259,22.252503921284674,21.90013741341676,21.547770905548845,21.19540439768095,20.843037889813036,20.49067138194512,20.138304874077225,19.857592889885012,19.612708167530677,19.367823445176334,19.130473689197835,18.893251645141,18.65602960108415,18.41880755702733,18.181585512970493,17.94436346891365,17.707141424856825,17.46991938079998,17.232697336743154,16.99547529268631,16.758253248629476,16.521031204572648,16.28380916051581,16.046587116458973,15.809365072402136,15.572143028345304,15.343814078258315,15.121370261936331,14.898926445614343,14.676482629292366,14.454038812970374,14.231594996648395,14.009151180326409,13.786707364004425,13.564263547682447,13.34181973136045,13.119375915038475,12.91088424449109,12.706773679029594,12.502663113568104,12.298552548106606,12.094441982645106,11.89033141718361,11.68622085172211,11.482725915355864,11.289491485381122,11.09625705540638,10.903022625431646,10.709788195456904,10.516553765482161,10.328937858142005,10.154466203194321,9.979994548246635,9.80552289329896,9.631051238351276,9.475862797405448,9.32450844545895,9.173154093512448,9.027199340648295,8.895863011465746,8.764526682283194,8.640078053401036,8.527950757889569,8.415823462378095,8.321424549564327,8.228235175980025,8.144594468220584,8.062147343689233,7.979700219157875,7.897253094626517,7.81480597009516,7.73235884556381,7.649911721032452,7.567464596501094,7.485017471969737,7.402570347438386,7.3201232229070365,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[50.51573913407445,50.50046916613762,50.48519919820079,50.469929230263965,50.45465926232714,50.43938929439032,50.424119326453486,50.40884935851666,50.39357939057983,50.37830942264301,50.36303945470618,50.34776948676935,50.33249951883253,50.3172295508957,50.30195958295887,50.28668961502204,50.27141964708522,50.25614967914839,50.24087971121157,50.22560974327473,50.210339775337914,50.195069807401076,50.17979983946425,50.16452987152743,50.14925990359059,50.13398993565377,50.11871996771695,50.10344999978011,50.088180031843294,50.07291006390646,50.05764009596963,50.04237012803281,50.027100160095976,50.01183019215915,49.99656022422232,49.981290256285504,49.96602028834867,49.95075032041184,49.935480352475025,49.92021038453819,49.90494041660136,49.88967044866453,49.87440048072771,49.859130512790884,49.84386054485405,49.82859057691723,49.813320608980405,49.798050641043574,49.78278067310675,49.767510705169926,49.752240737233095,49.73697076929626,49.72170080135944,49.706430833422615,49.691160865485784,49.67589089754896,49.66062092961213,49.645350961675305,49.63008099373848,49.61481102580166,49.599541057864826,49.584271089927995,49.56900112199117,49.55373115405435,49.538461186117516,49.52319121818069,49.50792125024387,49.49265128230703,49.477381314370206,49.46211134643338,49.44684137849656,49.43157141055973,49.4163014426229,49.40103147468607,49.38576150674925,49.370491538812416,49.35522157087559,49.33995160293877,49.31813212630256,49.29500274542308,49.271873364543616,49.248743983664134,49.225614602784674,49.2024852219052,48.901818434889094,48.54564416664565,48.18946989840225,47.833295630158815,47.47712136191539,47.12094709367198,46.76477282542855,46.40859855718512,46.052424288941694,45.696250020698265,45.34007575245485,44.98390148421142,44.627727215967994,44.27155294772457,43.915378679481144,43.55920441123773,43.2030301429943,42.846855874750865,42.49068160650744,42.134507338264015,41.7783330700206,41.42215880177717,41.065984533533744,40.70981026529033,40.35363599704689,39.99746172880348,39.64128746056005,39.28511319231662,38.92893892407321,38.572764655829765,38.21659038758635,37.86041611934292,37.5042418510995,37.148067582856086,36.79189331461266,36.435719046369236,36.0795447781258,35.72337050988238,35.367196241638965,35.01102197339553,34.654847705152115,34.29867343690869,33.94249916866525,33.586324900421836,33.230150632178415,32.87397636393498,32.51780209569157,32.16162782744813,31.805453559204718,31.44927929096129,31.09310502271786,30.736930754474447,30.380756486231018,30.024582217987593,29.668407949744164,29.312233681500736,28.956059413257325,28.599885145013896,28.243710876770468,27.887536608527054,27.53136234028361,27.1751880720402,26.81901380379677,26.462839535553343,26.106665267309932,25.75049099906649,25.39431673082308,25.03814246257965,24.68196819433622,24.32579392609281,23.969619657849364,23.613445389605953,23.25727112136253,22.901096853119096,22.544922584875685,22.18874831663226,21.832574048388828,21.47676398269395,21.121136018490862,20.76550805428779,20.4098800900847,20.05425212588161,19.698624161678538,19.421933477572935,19.18471143351611,18.947489389459278,18.710267345402443,18.47304530134561,18.235823257288764,17.99860121323194,17.761379169175104,17.52415712511826,17.286935081061436,17.04971303700459,16.812490992947765,16.575268948890923,16.338046904834087,16.10082486077726,15.86360281672042,15.640570488139716,15.418126671817728,15.195682855495736,14.973239039173764,14.750795222851778,14.52835140652979,14.305907590207813,14.083463773885821,13.861019957563842,13.638576141241854,13.416132324919873,13.203798760029883,12.999688194568376,12.795577629106887,12.59146706364539,12.387356498183891,12.183245932722402,11.979135367260904,11.775024801799404,11.575736672491711,11.38250224251697,11.189267812542237,10.996033382567495,10.802798952592752,10.60956452261802,10.423546543885884,10.2490748889382,10.074603233990514,9.900131579042828,9.725659924095144,9.567032079546692,9.415677727600192,9.264323375653692,9.112969023707194,8.980315720223448,8.848979391040903,8.717643061858352,8.603028539802382,8.490901244290908,8.384856200634951,8.291666827050651,8.20026782830853,8.117820703777172,8.035373579245814,7.952926454714464,7.870479330183107,7.788032205651749,7.705585081120391,7.623137956589042,7.540690832057684,7.458243707526327,7.375796582994968,7.293349458463617,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[50.2161990883738,50.200929120436975,50.18565915250014,50.17038918456333,50.1551192166265,50.13984924868967,50.12457928075284,50.10930931281601,50.094039344879185,50.07876937694236,50.06349940900553,50.048229441068706,50.03295947313187,50.01768950519505,50.00241953725823,49.987149569321396,49.97187960138457,49.95660963344774,49.94133966551091,49.92606969757409,49.91079972963726,49.89552976170043,49.8802597937636,49.86498982582678,49.84971985788995,49.83444988995312,49.8191799220163,49.80390995407947,49.78863998614264,49.77337001820581,49.758100050268986,49.74283008233216,49.72756011439533,49.712290146458514,49.697020178521676,49.68175021058485,49.66648024264803,49.6512102747112,49.63594030677437,49.62067033883754,49.60540037090072,49.59013040296389,49.57486043502706,49.55959046709023,49.54432049915341,49.52905053121658,49.51378056327976,49.49851059534292,49.4832406274061,49.46797065946927,49.45270069153245,49.437430723595625,49.42216075565879,49.40689078772196,49.39162081978514,49.37635085184831,49.36108088391148,49.34581091597465,49.33054094803783,49.315270980101,49.300001012164174,49.28211124070249,49.258981859823024,49.23585247894354,49.21272309806408,49.18959371718461,49.16646433630514,49.14333495542566,49.12020557454619,49.09707619366672,49.07394681278725,49.050817431907774,49.0276880510283,49.00455867014883,48.98142928926936,48.95829990838988,48.93517052751041,48.91204114663094,48.888911765751466,48.86578238487199,48.84265300399252,48.81952362311305,48.79639424223358,48.77326486135411,48.47259807433801,48.116423806094566,47.76024953785116,47.40407526960773,47.047901001364295,46.69172673312089,46.33555246487746,45.97937819663403,45.6232039283906,45.26702966014717,44.91085539190376,44.55468112366033,44.19850685541691,43.84233258717347,43.486158318930045,43.12998405068664,42.77380978244321,42.41763551419978,42.06146124595636,41.70528697771292,41.349112709469516,40.99293844122609,40.63676417298266,40.280589904739244,39.9244156364958,39.56824136825239,39.212067100008966,38.85589283176553,38.49971856352212,38.14354429527868,37.787370027035266,37.43119575879184,37.07502149054841,36.718847222305,36.362672954061566,36.006498685818144,35.65032441757471,35.29415014933129,34.93797588108788,34.581801612844444,34.22562734460102,33.86945307635761,33.513278808114165,33.15710453987075,32.80093027162732,32.444756003383894,32.08858173514049,31.732407466897037,31.37623319865363,31.0200589304102,30.663884662166772,30.307710393923358,29.95153612567993,29.5953618574365,29.239187589193072,28.883013320949644,28.526839052706237,28.170664784462808,27.81449051621938,27.458316247975965,27.102233030351044,26.74660506614797,26.390977101944884,26.03534913774179,25.67972117353872,25.324093209335615,24.968465245132542,24.612837280929455,24.257209316726367,23.901581352523294,23.545953388320186,23.190325424117113,22.834697459914025,22.479069495710938,22.123441531507865,21.767813567304774,21.412185603101687,21.056557638898596,20.700929674695505,20.345301710492432,19.989673746289345,19.634045782086254,19.27841781788318,19.001727133777578,18.764505089720753,18.52728304566392,18.29006100160709,18.052838957550254,17.815616913493407,17.578394869436583,17.341172825379747,17.103950781322904,16.86672873726608,16.629506693209233,16.39228464915241,16.159770714343132,15.93732689802114,15.714883081699162,15.492439265377174,15.269995449055193,15.047551632733205,14.825107816411213,14.60266400008924,14.380220183767253,14.157776367445265,13.935332551123288,13.712888734801295,13.496713275568693,13.292602710107195,13.088492144645695,12.884381579184208,12.680271013722699,12.47616044826121,12.272049882799713,12.067939317338215,11.863828751876724,11.668747429627592,11.475512999652851,11.282278569678107,11.089044139703368,10.895809709728633,10.70257527975389,10.518155229629773,10.3436835746821,10.169211919734414,9.994740264786728,9.820268609839044,9.65820136168794,9.506847009741442,9.35549265779495,9.204138305848453,9.064768428981168,8.933432099798617,8.802095770616068,8.678106321715216,8.565979026203742,8.453851730692268,8.355098478121281,8.261909104536985,8.173494063865128,8.09104693933377,8.008599814802412,7.926152690271054,7.843705565739704,7.761258441208347,7.678811316676988,7.596364192145632,7.5139170676142815,7.431469943082923,7.349022818551566,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[49.91665904267313,49.90138907473631,49.88611910679947,49.870849138862646,49.85557917092582,49.84030920298899,49.82503923505217,49.80976926711534,49.79449929917851,49.77922933124169,49.76395936330486,49.74868939536803,49.7334194274312,49.718149459494384,49.70287949155755,49.68760952362072,49.67233955568389,49.657069587747074,49.64179961981024,49.62652965187342,49.611259683936595,49.595989715999764,49.58071974806293,49.56544978012611,49.55017981218928,49.534909844252454,49.51963987631563,49.50436990837879,49.489099940441974,49.47382997250514,49.45856000456832,49.443290036631495,49.428020068694664,49.41275010075785,49.39748013282101,49.382210164884185,49.36694019694736,49.35167022901052,49.3364002610737,49.32113029313687,49.305860325200044,49.29059035726322,49.27532038932639,49.260050421389565,49.24478045345274,49.22296097422293,49.19983159334346,49.176702212463994,49.15357283158451,49.13044345070505,49.10731406982556,49.0841846889461,49.06105530806662,49.03792592718715,49.014796546307686,48.99166716542821,48.968537784548744,48.94540840366926,48.922279022789795,48.89914964191033,48.876020261030845,48.85289088015138,48.8297614992719,48.80663211839243,48.78350273751296,48.76037335663349,48.73724397575402,48.714114594874545,48.69098521399508,48.6678558331156,48.64472645223613,48.62159707135666,48.598467690477186,48.57533830959771,48.55220892871824,48.52907954783876,48.505950166959295,48.48282078607982,48.459691405200346,48.43656202432088,48.4134326434414,48.39030326256193,48.36717388168246,48.34404450080299,48.04337771378688,47.687203445543446,47.331029177300024,46.9748549090566,46.618680640813174,46.26250637256976,45.90633210432634,45.5501578360829,45.193983567839474,44.83780929959606,44.48163503135264,44.1254607631092,43.76928649486579,43.413112226622346,43.05693795837893,42.70076369013552,42.34458942189209,41.98841515364866,41.63224088540523,41.2760666171618,40.919892348918395,40.56371808067496,40.20754381243154,39.851369544188124,39.49519527594468,39.13902100770127,38.78284673945784,38.42667247121441,38.070498202970995,37.71432393472756,37.35814966648414,37.00197539824072,36.64580112999728,36.289626861753874,35.93345259351045,35.57727832526702,35.221104057023595,34.86492978878016,34.508755520536745,34.15258125229333,33.796406984049895,33.44023271580649,33.08405844756304,32.72788417931963,32.37207411380503,32.01644614960194,31.660818185398867,31.305190221195762,30.949562256992692,30.5939342927896,30.238306328586514,29.88267836438344,29.52705040018035,29.171422435977263,28.81579447177417,28.46016650757108,28.104538543368008,27.74891057916492,27.393282614961834,27.03765465075876,26.682026686555652,26.32639872235258,25.97077075814949,25.615142793946404,25.25951482974333,24.903886865540226,24.548258901337153,24.192630937134066,23.837002972930975,23.481375008727902,23.125747044524797,22.770119080321724,22.414491116118636,22.058863151915546,21.703235187712473,21.34760722350938,20.991979259306294,20.636351295103204,20.280723330900116,19.925095366697043,19.569467402493956,19.213839438290865,18.858211474087792,18.58152078998219,18.344298745925368,18.107076701868532,17.869854657811697,17.632632613754865,17.39541056969802,17.158188525641194,16.92096648158436,16.683744437527515,16.45652712422453,16.234083307902534,16.011639491580553,15.789195675258577,15.566751858936586,15.344308042614609,15.12186422629262,14.89942040997064,14.676976593648652,14.45453277732666,14.232088961004685,14.009645144682704,13.789627791107476,13.585517225645987,13.38140666018448,13.17729609472299,12.973185529261492,12.769074963799994,12.564964398338505,12.360853832876998,12.156743267415509,11.954992616738181,11.76175818676344,11.568523756788709,11.375289326813967,11.182054896839226,10.988820466864482,10.795586036889741,10.612763915373652,10.43829226042597,10.263820605478282,10.089348950530608,9.914877295582922,9.749370643829185,9.598016291882686,9.446661939936185,9.295307587989686,9.149221137738873,9.017884808556325,8.886548479373776,8.755212150191225,8.641056808116556,8.528929512605089,8.418530129191907,8.325340755607606,8.232151382023307,8.146720299421709,8.064273174890358,7.981826050359,7.899378925827643,7.816931801296286,7.734484676764935,7.652037552233578,7.569590427702219,7.487143303170862,7.404696178639512,7.322249054108155,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[49.61711899697246,49.601849029035634,49.5865790610988,49.57130909316197,49.55603912522515,49.540769157288324,49.52549918935149,49.51022922141467,49.494959253477845,49.47968928554101,49.46441931760418,49.44914934966736,49.433879381730534,49.4186094137937,49.40333944585687,49.38806947792005,49.37279950998322,49.35752954204639,49.34225957410957,49.326989606172745,49.311719638235914,49.29644967029909,49.28117970236225,49.265909734425435,49.250639766488604,49.23536979855178,49.220099830614956,49.20482986267812,49.18694008862284,49.163810707743366,49.14068132686389,49.117551945984424,49.09442256510495,49.071293184225475,49.04816380334601,49.02503442246653,49.00190504158706,48.97877566070759,48.95564627982811,48.93251689894864,48.90938751806917,48.8862581371897,48.863128756310225,48.83999937543075,48.81686999455128,48.79374061367181,48.77061123279234,48.747481851912866,48.72435247103339,48.701223090153924,48.67809370927445,48.654964328394975,48.6318349475155,48.608705566636026,48.585576185756565,48.562446804877084,48.539317423997616,48.51618804311814,48.49305866223867,48.4699292813592,48.446799900479725,48.42367051960026,48.400541138720776,48.3774117578413,48.354282376961834,48.331152996082366,48.3080236152029,48.28489423432342,48.26176485344395,48.238635472564475,48.215506091685,48.19237671080553,48.169247329926066,48.146117949046584,48.122988568167116,48.09985918728764,48.07672980640817,48.0536004255287,48.030471044649225,48.00734166376975,47.98421228289028,47.96108290201081,47.937953521131334,47.914824140251866,47.61415735323577,47.25798308499232,46.90180881674891,46.545634548505475,46.189460280262054,45.83328601201864,45.47711174377521,45.12093747553178,44.764763207288354,44.40858893904493,44.052414670801525,43.69624040255808,43.34006613431467,42.98389186607123,42.62771759782781,42.271543329584404,41.91536906134097,41.55919479309753,41.20302052485411,40.846846256610675,40.49067198836727,40.13449772012384,39.77832345188041,39.422149183637,39.065974915393554,38.709800647150146,38.35362637890672,37.99754316146209,37.64191519725902,37.286287233055916,36.93065926885284,36.575031304649755,36.21940334044666,35.86377537624359,35.5081474120405,35.152519447837406,34.796891483634326,34.44126351943123,34.08563555522816,33.73000759102507,33.37437962682198,33.01875166261891,32.6631236984158,32.307495734212736,31.951867770009642,31.596239805806555,31.24061184160348,30.884983877400373,30.5293559131973,30.173727948994213,29.818099984791125,29.462472020588052,29.10684405638496,28.751216092181874,28.395588127978783,28.039960163775696,27.684332199572623,27.328704235369532,26.97307627116644,26.617448306963368,26.261820342760267,25.906192378557193,25.550564414354106,25.194936450151015,24.839308485947942,24.483680521744837,24.128052557541764,23.772424593338677,23.41679662913559,23.061168664932516,22.705540700729408,22.349912736526335,21.994284772323248,21.63865680812016,21.283028843917087,20.927400879713996,20.57177291551091,20.216144951307818,19.860516987104727,19.504889022901654,19.149261058698567,18.793633094495476,18.438005130292403,18.161314446186804,17.924092402129975,17.686870358073143,17.44964831401631,17.212426269959476,16.975727350427906,16.75328353410593,16.53083971778394,16.308395901461953,16.085952085139976,15.86350826881798,15.641064452496003,15.418620636174024,15.196176819852033,14.973733003530056,14.751289187208068,14.528845370886085,14.306401554564097,14.083957738242106,13.878431741184771,13.674321175723271,13.470210610261777,13.266100044800284,13.061989479338777,12.857878913877288,12.653768348415792,12.449657782954292,12.245547217492803,12.048003373874034,11.8547689438993,11.661534513924558,11.468300083949817,11.275065653975084,11.08183122400034,10.888596794025599,10.707372601117527,10.532900946169843,10.35842929122216,10.183957636274478,10.009485981326792,9.840539925970429,9.68918557402393,9.537831222077429,9.386476870130931,9.23512251818443,9.102337517314025,8.971001188131481,8.839664858948932,8.716134590029377,8.604007294517903,8.491879999006429,8.388772406678232,8.29558303309393,8.202393659509632,8.11994653497829,8.03749941044694,7.955052285915588,7.872605161384231,7.7901580368528744,7.707710912321517,7.625263787790167,7.542816663258809,7.460369538727452,7.377922414196093,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[49.31757895127181,49.30230898333498,49.28703901539816,49.27176904746132,49.2564990795245,49.24122911158767,49.22595914365085,49.210689175714016,49.1954192077772,49.18014923984036,49.16487927190354,49.149609303966706,49.127789822143306,49.104660441263825,49.081531060384364,49.05840167950488,49.035272298625415,49.01214291774593,48.98901353686647,48.965884155987005,48.942754775107524,48.919625394228056,48.89649601334858,48.873366632469114,48.85023725158963,48.827107870710165,48.80397848983069,48.78084910895122,48.75771972807174,48.734590347192274,48.711460966312806,48.68833158543333,48.66520220455386,48.64207282367438,48.618943442794915,48.59581406191544,48.57268468103597,48.54955530015649,48.52642591927703,48.50329653839755,48.48016715751808,48.457037776638614,48.43390839575913,48.410779014879665,48.3876496340002,48.364520253120716,48.34139087224125,48.318261491361774,48.2951321104823,48.27200272960283,48.24887334872335,48.22574396784388,48.20261458696441,48.179485206084934,48.15635582520547,48.133226444326,48.11009706344653,48.08696768256705,48.06383830168758,48.040708920808115,48.01757953992863,47.994450159049165,47.971320778169684,47.948191397290216,47.92506201641075,47.901932635531274,47.8788032546518,47.85567387377233,47.83254449289286,47.80941511201338,47.786285731133916,47.76315635025445,47.740026969374966,47.7168975884955,47.69376820761602,47.67063882673655,47.64750944585708,47.62438006497761,47.60125068409813,47.578121303218666,47.55499192233919,47.53186254145972,47.50873316058025,47.485603779700774,47.18493699268467,46.828762724441226,46.47258845619782,46.11641418795439,45.76023991971096,45.40406565146755,45.04789138322412,44.69171711498069,44.33554284673726,43.97936857849383,43.62319431025043,43.2673842449161,42.91175628071302,42.55612831650993,42.20050035230685,41.844872388103774,41.489244423900686,41.13361645969759,40.777988495494505,40.42236053129141,40.066732567088344,39.71110460288526,39.35547663868216,38.99984867447909,38.64422071027599,38.288592746072915,37.93296478186982,37.57733681766673,37.22170885346366,36.86608088926056,36.510452925057486,36.1548249608544,35.799196996651304,35.44356903244823,35.087941068245144,34.73231310404205,34.37668513983897,34.021057175635875,33.6654292114328,33.309801247229714,32.95417328302662,32.598545318823554,32.242917354620445,31.887289390417376,31.531661426214285,31.176033462011198,30.820405497808125,30.464777533605016,30.109149569401943,29.753521605198856,29.39789364099577,29.042265676792695,28.686637712589604,28.331009748386517,27.975381784183426,27.61975381998034,27.264125855777266,26.90849789157417,26.552869927371084,26.19724196316801,25.84161399896491,25.485986034761837,25.13035807055875,24.77473010635566,24.419102142152585,24.06347417794948,23.707846213746407,23.35221824954332,22.99659028534023,22.64096232113716,22.28533435693405,21.929706392730978,21.57407842852789,21.218450464324803,20.86282250012173,20.50719453591864,20.151566571715552,19.795938607512458,19.44031064330937,19.084682679106297,18.72905471490321,18.37342675070012,18.017798786497046,17.741108102391443,17.50388605833462,17.272483760309342,17.05003994398735,16.827596127665377,16.60515231134338,16.382708495021404,16.160264678699413,15.937820862377428,15.715377046055451,15.492933229733456,15.270489413411477,15.0480455970895,14.825601780767508,14.603157964445531,14.380714148123543,14.171346256723579,13.967235691262081,13.763125125800583,13.559014560339094,13.354903994877596,13.150793429416098,12.946682863954607,12.742572298493101,12.53846173303161,12.334351167570112,12.141014131009914,11.94777970103518,11.75454527106043,11.561310841085696,11.368076411110954,11.174841981136215,10.98160755116148,10.801981286861423,10.627509631913737,10.453037976966055,10.27856632201837,10.10409466707069,9.93170920811168,9.780354856165179,9.629000504218688,9.47764615227219,9.326291800325691,9.186790226071745,9.055453896889194,8.924117567706645,8.7927812385241,8.679085076430734,8.56695778091926,8.454830485407786,8.359014684164562,8.265825310580265,8.175619895066246,8.093172770534888,8.01072564600353,7.92827852147218,7.845831396940829,7.763384272409472,7.680937147878113,7.5984900233467565,7.516042898815407,7.43359577428405,7.351148649752691,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[49.00083455801362,48.97025796944809,48.939681380882554,48.90910479231702,48.87852820375148,48.84795161518594,48.82233982757725,48.79921044669778,48.7760810658183,48.752951684938836,48.72982230405936,48.70669292317989,48.68356354230042,48.660434161420945,48.63730478054147,48.614175399661995,48.59104601878253,48.56791663790305,48.544787257023586,48.52165787614411,48.49852849526464,48.47539911438516,48.452269733505695,48.42914035262622,48.406010971746745,48.38288159086727,48.3597522099878,48.33662282910833,48.313493448228854,48.29036406734939,48.26723468646992,48.244105305590445,48.22097592471097,48.1978465438315,48.17471716295203,48.15158778207255,48.128458401193086,48.105329020313604,48.08219963943414,48.05907025855466,48.03594087767519,48.01281149679572,47.98968211591625,47.96655273503677,47.943423354157304,47.92029397327783,47.89716459239836,47.87403521151889,47.85090583063942,47.82777644975994,47.80464706888047,47.78151768800099,47.75838830712152,47.735258926242054,47.71212954536258,47.68900016448311,47.66587078360364,47.64274140272417,47.619612021844695,47.59648264096522,47.573353260085746,47.55022387920627,47.527094498326804,47.503965117447336,47.480835736567855,47.45770635568839,47.43457697480892,47.41144759392944,47.38831821304997,47.365188832170496,47.34205945129103,47.318930070411554,47.29580068953208,47.27267130865261,47.24954192777314,47.22641254689366,47.20328316601419,47.18015378513472,47.157024404255246,47.13389502337577,47.110765642496304,47.08763626161684,47.064506880737355,47.04137749985789,46.74116596620874,46.38553800200563,46.02991003780255,45.674282073599464,45.31865410939638,44.96302614519331,44.60739818099022,44.25177021678712,43.896142252584035,43.54051428838095,43.18488632417788,42.82925835997479,42.47363039577171,42.11800243156861,41.76237446736552,41.40674650316245,41.051118538959365,40.69549057475627,40.33986261055318,39.98423464635009,39.62860668214702,39.27297871794393,38.91735075374084,38.56172278953777,38.20609482533466,37.85046686113159,37.4948388969285,37.13921093272541,36.78358296852234,36.42795500431923,36.072327040116164,35.71669907591307,35.361071111709975,35.00544314750691,34.64981518330383,34.294187219100735,33.93855925489765,33.58293129069455,33.22730332649148,32.87167536228839,32.5160473980853,32.16041943388223,31.804791469679124,31.44916350547605,31.093535541272963,30.737907577069876,30.382279612866803,30.026651648663698,29.671023684460625,29.315395720257534,28.959767756054447,28.604139791851374,28.248511827648283,27.892883863445192,27.537255899242105,27.181627935039018,26.825999970835944,26.470372006632857,26.114744042429766,25.759116078226693,25.403488114023588,25.047860149820515,24.692232185617428,24.336604221414333,23.98097625721126,23.62534829300816,23.26972032880509,22.914092364602,22.55846440039891,22.202836436195838,21.84720847199273,21.49158050778966,21.13595254358657,20.780324579383482,20.424696615180405,20.069068650977318,19.713440686774227,19.357812726134373,19.008552633374812,18.65929254061527,18.310032447855708,17.960772355096147,17.611512262336603,17.346796353868747,17.12435253754677,16.901908721224785,16.679464904902794,16.457021088580824,16.23457727225883,16.01213345593685,15.78968963961486,15.567245823292875,15.344802006970898,15.122358190648903,14.899914374326924,14.677470558004947,14.464260772262364,14.260150206800873,14.056039641339376,13.851929075877877,13.647818510416379,13.44370794495488,13.239597379493391,13.035486814031891,12.831376248570395,12.627265683108906,12.427259318120505,12.234024888145772,12.040790458171028,11.847556028196289,11.654321598221555,11.461087168246804,11.267852738272072,11.074618308297326,10.896589972605295,10.722118317657618,10.547646662709933,10.373175007762246,10.198703352814563,10.02423169786688,9.871524138306425,9.720169786359925,9.568815434413425,9.417461082466932,9.271242934829454,9.139906605646903,9.008570276464352,8.877233947281802,8.75416285834355,8.642035562832081,8.529908267320607,8.422446335235188,8.329256961650886,8.236067588066586,8.148846130622836,8.066399006091478,7.983951881560119,7.9015047570287615,7.819057632497412,7.736610507966061,7.654163383434703,7.571716258903346,7.4892691343719875,7.406822009840638,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[48.64806856710901,48.61749197854348,48.58691538997794,48.5563388014124,48.525762212846864,48.495185624281326,48.46460903571579,48.43403244715025,48.403455858584714,48.372879270019176,48.34230268145364,48.3117260928881,48.28114950432257,48.25057291575703,48.219996327191495,48.18941973862596,48.15884315006042,48.12826656149488,48.097689972929345,48.06711338436381,48.03653679579827,48.00596020723273,47.976624814552224,47.95349543367275,47.930366052793275,47.9072366719138,47.88410729103433,47.86097791015486,47.837848529275384,47.814719148395916,47.79158976751644,47.768460386636974,47.74533100575749,47.722201624878025,47.69907224399855,47.67594286311908,47.65281348223961,47.629684101360134,47.60655472048066,47.58342533960119,47.56029595872172,47.53716657784224,47.514037196962775,47.4909078160833,47.46777843520383,47.44464905432436,47.42151967344489,47.39839029256541,47.37526091168595,47.352131530806474,47.32900214992699,47.305872769047525,47.28274338816805,47.259614007288576,47.23648462640911,47.21335524552964,47.19022586465016,47.16709648377069,47.14396710289122,47.12083772201174,47.097708341132275,47.0745789602528,47.051449579373326,47.02832019849386,47.00519081761439,46.98206143673491,46.95893205585544,46.935802674975974,46.9126732940965,46.889543913217025,46.86641453233756,46.84328515145808,46.82015577057861,46.797026389699134,46.77389700881966,46.75076762794019,46.72763824706072,46.70450886618125,46.681379485301775,46.65825010442231,46.635120723542826,46.61199134266336,46.58886196178389,46.56573258090441,46.26552104725526,45.909893083052154,45.554265118849074,45.19863715464599,44.8430091904429,44.487381226239826,44.13175326203674,43.776125297833644,43.420497333630564,43.06486936942747,42.709241405224404,42.35361344102132,41.99798547681823,41.642357512615135,41.286729548412055,40.931101584208974,40.57547362000588,40.2198456558028,39.864217691599706,39.50858972739662,39.152961763193545,38.79733379899045,38.44170583478737,38.08607787058429,37.73044990638118,37.374821942178116,37.01919397797502,36.66356601377194,36.30793804956886,35.95231008536576,35.59668212116269,35.24105415695959,34.885426192756505,34.52979822855343,34.17417026435035,33.81854230014726,33.46291433594417,33.107286371741075,32.751658407538,32.39603044333492,32.04040247913183,31.684774514928755,31.329146550725646,30.97351858652258,30.617890622319493,30.262262658116402,29.906634693913325,29.55100672971022,29.195378765507147,28.83975080130406,28.48412283710097,28.128494872897896,27.772866908694805,27.417238944491718,27.061610980288627,26.70598301608554,26.350355051882467,25.99472708767938,25.63909912347629,25.283471159273216,24.92784319507011,24.57539917120274,24.226139078443182,23.87687898568362,23.527618892924078,23.1783588001645,22.829098707404956,22.479838614645395,22.130578521885838,21.78131842912629,21.432058336366715,21.082798243607172,20.733538150847608,20.38427805808805,20.035017965328503,19.685757872568942,19.336497779809385,18.98723768704982,18.637977594290263,18.28871750153072,17.939457408771155,17.590197316011597,17.240937223252054,16.976221314784194,16.753777498462217,16.531333682140232,16.308889865818244,16.086446049496274,15.864002233174276,15.641558416852298,15.419114600530307,15.196670784208322,14.974226967886343,14.757175287801147,14.55306472233966,14.348954156878161,14.144843591416661,13.940733025955172,13.736622460493674,13.532511895032176,13.328401329570678,13.124290764109178,12.920180198647689,12.71606963318619,12.520270075256363,12.32703564528163,12.133801215306878,11.940566785332145,11.747332355357404,11.554097925382662,11.36086349540793,11.167629065433179,10.991198658349171,10.816727003401486,10.642255348453803,10.467783693506126,10.293312038558444,10.118840383610756,9.962693420447659,9.811339068501159,9.65998471655467,9.50863036460817,9.357276012661668,9.224359314404609,9.09302298522206,8.961686656039511,8.830350326856959,8.717113344744897,8.604986049233425,8.492858753721954,8.392688612721512,8.299499239137212,8.20630986555291,8.122072366179417,8.039625241648066,7.957178117116708,7.874730992585351,7.792283868053993,7.709836743522643,7.627389618991291,7.544942494459934,7.462495369928576,7.380048245397219,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[48.29530257620442,48.26472598763888,48.234149399073345,48.20357281050781,48.17299622194227,48.14241963337674,48.1118430448112,48.081266456245665,48.05068986768013,48.02011327911459,47.98953669054906,47.958960101983514,47.92838351341798,47.897806924852446,47.86723033628691,47.83665374772137,47.80607715915583,47.775500570590296,47.74492398202476,47.71434739345922,47.68377080489368,47.653194216328146,47.62261762776261,47.59204103919707,47.56146445063153,47.530887862065995,47.50031127350046,47.46973468493492,47.43915809636938,47.408581507803845,47.37800491923831,47.34742833067277,47.31685174210724,47.2862751535417,47.255698564976164,47.22512197641063,47.19454538784509,47.16396879927955,47.133392210714014,47.10778042064775,47.084651039768275,47.06152165888881,47.03839227800933,47.01526289712986,46.99213351625039,46.96900413537092,46.94587475449145,46.922745373611974,46.8996159927325,46.87648661185303,46.85335723097356,46.83022785009408,46.80709846921461,46.78396908833514,46.76083970745567,46.73771032657619,46.714580945696724,46.69145156481725,46.66832218393778,46.64519280305831,46.62206342217883,46.59893404129936,46.57580466041989,46.552675279540416,46.52954589866095,46.506416517781474,46.483287136902,46.460157756022525,46.43702837514306,46.41389899426358,46.39076961338411,46.36764023250464,46.344510851625174,46.32138147074569,46.298252089866224,46.27512270898675,46.251993328107275,46.22886394722781,46.20573456634833,46.18260518546886,46.15947580458939,46.13634642370992,46.11321704283044,46.090087661950975,45.78987612830181,45.43424816409871,45.07862019989564,44.722992235692544,44.367364271489464,44.011736307286384,43.656108343083304,43.30048037888021,42.94485241467712,42.589224450474035,42.23359648627096,41.87796852206787,41.52234055786478,41.16671259366169,40.811084629458605,40.45545666525554,40.099828701052445,39.74420073684935,39.38857277264626,39.032944808443176,38.6773168442401,38.321688880037016,37.96606091583393,37.610432951630855,37.25480498742775,36.899177023224674,36.543549059021586,36.18792109481849,35.832293130615426,35.47666516641232,35.121037202209244,34.76540923800616,34.40978127380306,34.05415330959999,33.69852534539691,33.342897381193815,32.98726941699073,32.63164145278763,32.27601348858456,31.920385524381476,31.564757560178382,31.209129595975316,30.85350163177221,30.497873667569134,30.142245709030682,29.792985616271118,29.443725523511574,29.094465430751995,28.74520533799246,28.395945245232895,28.046685152473334,27.697425059713787,27.34816496695423,26.99890487419467,26.649644781435107,26.300384688675546,25.951124595916,25.601864503156442,25.25260441039688,24.903344317637337,24.55408422487776,24.204824132118215,23.855564039358654,23.506303946599097,23.157043853839554,22.807783761079975,22.45852366832043,22.109263575560874,21.76000348280131,21.410743390041766,21.061483297282187,20.712223204522644,20.362963111763083,20.013703019003522,19.66444292624398,19.315182833484418,18.965922740724857,18.6166626479653,18.267402555205738,17.91814246244619,17.568882369686634,17.219622276927073,16.87036218416753,16.605646275699673,16.383202459377692,16.16075864305571,15.93831482673372,15.715871010411748,15.493427194089753,15.270983377767774,15.050089803339963,14.845979237878467,14.641868672416978,14.43775810695547,14.23364754149398,14.029536976032484,13.825426410570984,13.621315845109494,13.417205279647998,13.213094714186498,13.008984148724998,12.806515262366977,12.613280832392244,12.4200464024175,12.22681197244276,12.033577542468027,11.840343112493276,11.647108682518542,11.453874252543798,11.260639822569058,11.08580734409307,10.911335689145377,10.736864034197701,10.562392379250017,10.387920724302333,10.213449069354656,10.05386270258892,9.902508350642417,9.75115399869592,9.599799646749421,9.448445294802928,9.308812023162323,9.177475693979773,9.04613936479723,8.914803035614682,8.792191126657729,8.680063831146255,8.56793653563478,8.456120263792142,8.362930890207846,8.269741516623546,8.177745726267371,8.095298601736012,8.012851477204656,7.930404352673306,7.847957228141948,7.765510103610591,7.683062979079232,7.600615854547883,7.518168730016531,7.435721605485174,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[47.942536585299806,47.911959996734275,47.88138340816873,47.85080681960319,47.82023023103766,47.789653642472125,47.75907705390659,47.72850046534105,47.69792387677552,47.66734728820998,47.636770699644444,47.6061941110789,47.57561752251337,47.54504093394783,47.514464345382294,47.483887756816756,47.45331116825122,47.42273457968568,47.39215799112014,47.361581402554606,47.33100481398907,47.30042822542353,47.26985163685799,47.239275048292455,47.20869845972692,47.17812187116138,47.14754528259585,47.116968694030305,47.086392105464775,47.05581551689924,47.0252389283337,46.99466233976816,46.96408575120263,46.933509162637094,46.902932574071556,46.87235598550602,46.84177939694048,46.811202808374944,46.7806262198094,46.75004963124387,46.71947304267833,46.68889645411279,46.658319865547256,46.62774327698172,46.59716668841618,46.56659009985064,46.536013511285105,46.50543692271957,46.47486033415403,46.44428374558849,46.41370715702296,46.383130568457425,46.35255397989189,46.32197739132635,46.29140080276081,46.262065407622714,46.23893602674325,46.21580664586377,46.192677264984304,46.16954788410483,46.146418503225355,46.12328912234588,46.10015974146641,46.07703036058694,46.053900979707464,46.030771598828,46.00764221794852,45.98451283706905,45.96138345618958,45.938254075310105,45.91512469443063,45.891995313551156,45.86886593267168,45.84573655179222,45.82260717091274,45.79947779003327,45.776348409153805,45.75321902827433,45.730089647394855,45.70696026651538,45.68383088563591,45.66070150475644,45.637572123876964,45.61444274299749,45.31423120934834,44.95860324514524,44.60297528094217,44.247347316739074,43.891719352535986,43.53609138833291,43.180463424129826,42.82483545992673,42.469207495723644,42.11357953152056,41.75795156731749,41.4023236031144,41.04669563891131,40.691067674708215,40.335439710505135,39.979811746302055,39.62418378209897,39.26855581789588,38.91292785369279,38.5572998894897,38.20167192528663,37.84604396108354,37.49041599688045,37.13478803267738,36.77916006847427,36.4235321042712,36.06790414006811,35.712276175865014,35.359832154099045,35.01057206133947,34.66131196857992,34.312051875820366,33.9627917830608,33.61353169030126,33.26427159754169,32.915011504782136,32.56575141202258,32.216491319263014,31.86723122650347,31.517971133743913,31.168711040984352,30.819450948224805,30.470190855465233,30.120930762705683,29.77167066994613,29.422410577186568,29.073150484427018,28.723890391667446,28.374630298907903,28.02537020614834,27.67611011338878,27.326850020629237,26.977589927869676,26.628329835110115,26.279069742350554,25.929809649590993,25.58054955683145,25.23128946407189,24.882029371312328,24.532769278552784,24.183509185793206,23.834249093033662,23.484989000274105,23.135728907514544,22.786468814755,22.43720872199542,22.08794862923588,21.738688536476317,21.389428443716756,21.040168350957213,20.690908258197634,20.34164816543809,19.99238807267853,19.64312797991897,19.293867887159426,18.944607794399865,18.595347701640303,18.246087608880746,17.89682751612118,17.547567423361638,17.19830733060208,16.84904723784252,16.499787145082976,16.235071236615116,16.01262742029314,15.790183603971157,15.567739787649165,15.345295971327197,15.13889375341725,14.93478318795576,14.73067262249426,14.526562057032764,14.322451491571275,14.118340926109767,13.91423036064828,13.710119795186781,13.506009229725281,13.301898664263792,13.097788098802294,12.899526019502835,12.706291589528092,12.51305715955335,12.319822729578618,12.126588299603874,11.933353869629133,11.7401194396544,11.546885009679649,11.354887684784627,11.180416029836941,11.005944374889257,10.83147271994158,10.657001064993887,10.48252941004621,10.308057755098526,10.145031984730156,9.993677632783662,9.842323280837164,9.690968928890664,9.539614576944164,9.393264731920024,9.261928402737482,9.130592073554931,8.99925574437238,8.867919415189839,8.755141613059076,8.643014317547602,8.530887022036127,8.426362541278467,8.333173167694166,8.239983794109872,8.150971961823954,8.068524837292596,7.986077712761238,7.903630588229881,7.821183463698531,7.738736339167173,7.656289214635815,7.573842090104458,7.491394965573107,7.408947841041757,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[47.5897705943952,47.55919400582966,47.52861741726412,47.498040828698585,47.46746424013305,47.43688765156751,47.40631106300197,47.375734474436435,47.345157885870904,47.31458129730537,47.28400470873983,47.25342812017429,47.222851531608754,47.192274943043216,47.16169835447768,47.13112176591214,47.1005451773466,47.069968588781066,47.03939200021553,47.00881541164999,46.97823882308445,46.947662234518916,46.91708564595338,46.88650905738785,46.8559324688223,46.825355880256765,46.794779291691235,46.76420270312569,46.73362611456017,46.70304952599462,46.672472937429085,46.64189634886355,46.61131976029802,46.58074317173248,46.55016658316694,46.519589994601404,46.489013406035866,46.45843681747033,46.427860228904784,46.39728364033925,46.366707051773716,46.33613046320818,46.30555387464264,46.2749772860771,46.244400697511566,46.21382410894603,46.18324752038049,46.15267093181495,46.122094343249415,46.09151775468388,46.06094116611834,46.0303645775528,45.99978798898727,45.96921140042173,45.9386348118562,45.90805822329066,45.87748163472512,45.84690504615958,45.81632845759405,45.78575186902851,45.75517528046297,45.72459869189744,45.6940221033319,45.663445514766366,45.63286892620083,45.60229233763529,45.57171574906975,45.541139160504216,45.51056257193868,45.47998598337314,45.4494093948076,45.418832806242065,45.39322101371821,45.370091632838744,45.34696225195927,45.323832871079794,45.30070349020033,45.27757410932085,45.25444472844138,45.2313153475619,45.208185966682436,45.18505658580296,45.161927204923494,45.13879782404402,44.83858629039487,44.48295832619176,44.12733036198869,43.7717023977856,43.41607443358251,43.06044646937944,42.704818505176355,42.349190540973254,41.99356257677017,41.63793461256708,41.28230664836401,40.92667869192696,40.5774185991674,40.22815850640784,39.87889841364827,39.529638320888736,39.18037822812917,38.831118135369614,38.48185804261006,38.13259794985049,37.78333785709094,37.43407776433139,37.08481767157183,36.73555757881228,36.386297486052705,36.03703739329316,35.6877773005336,35.33851720777404,34.989257115014496,34.63999702225492,34.290736929495374,33.941476836735816,33.59221674397625,33.24295665121671,32.893696558457144,32.544436465697586,32.19517637293803,31.84591628017846,31.496656187418917,31.14739609465936,30.7981360018998,30.448875909140256,30.099615816380677,29.750355723621134,29.401095630861573,29.051835538102015,28.702575445342468,28.35331535258289,28.00405525982335,27.654795167063785,27.305535074304228,26.956274981544684,26.60701488878512,26.257754796025562,25.908494703266,25.55923461050644,25.209974517746897,24.860714424987336,24.511454332227775,24.16219423946823,23.812934146708653,23.46367405394911,23.114413961189552,22.765153868429987,22.415893775670444,22.066633682910865,21.717373590151322,21.368113497391764,21.018853404632203,20.669593311872656,20.32033321911308,19.971073126353534,19.621813033593977,19.272552940834416,18.923292848074873,18.57403275531531,18.22477266255575,17.875512569796193,17.526252477036632,17.17699238427709,16.827732291517528,16.478472198757967,16.129212105998423,15.864496197530567,15.642052381208588,15.431808268956043,15.227697703494545,15.023587138033054,14.819476572571547,14.615366007110058,14.41125544164856,14.207144876187062,14.003034310725573,13.798923745264066,13.594813179802577,13.390702614341077,13.186592048879579,12.992536776638692,12.79930234666395,12.60606791668921,12.412833486714465,12.219599056739725,12.026364626764991,11.833130196790247,11.639895766815508,11.449496370528502,11.275024715580809,11.100553060633136,10.92608140568545,10.751609750737765,10.57713809579009,10.402666440842395,10.236201266871396,10.084846914924897,9.9334925629784,9.782138211031906,9.630783859085408,9.479429507138907,9.346381111495182,9.215044782312631,9.08370845313009,8.952372123947539,8.83021939497189,8.71809209946042,8.605964803948947,8.493837508437474,8.396604818764791,8.303415445180493,8.21022607159619,8.124198197380544,8.041751072849184,7.959303948317826,7.876856823786469,7.7944096992551115,7.711962574723762,7.629515450192404,7.547068325661046,7.464621201129688,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[47.22167044302791,47.19109385446238,47.160517265896836,47.1299406773313,47.09936408876577,47.06878750020023,47.03821091163469,47.007634323069155,46.97705773450362,46.94648114593808,46.91590455737254,46.885327968807005,46.85475138024147,46.82417479167594,46.7935982031104,46.763021614544854,46.73244502597932,46.701868437413786,46.67129184884825,46.640715260282704,46.61013867171717,46.579562083151636,46.5489854945861,46.51840890602056,46.48783231745502,46.457255728889486,46.426679140323955,46.39610255175841,46.36552596319288,46.33494937462734,46.304372786061805,46.27379619749627,46.24321960893073,46.21264302036519,46.182066431799655,46.15148984323412,46.12091325466858,46.09033666610304,46.059760077537504,46.02918348897197,45.99860690040643,45.96803031184089,45.937453723275354,45.906877134709816,45.876300546144286,45.84572395757874,45.815147369013204,45.78457078044767,45.753994191882136,45.7234176033166,45.69284101475106,45.66226442618552,45.631687837619985,45.60111124905445,45.57053466048891,45.53995807192338,45.50938148335784,45.4788048947923,45.44822830622677,45.41765171766123,45.38707512909569,45.356498540530154,45.32592195196462,45.29534536339908,45.26476877483354,45.234192186268004,45.203615597702466,45.17303900913693,45.14246242057139,45.11188583200586,45.08130924344032,45.050732654874786,45.02015606630925,44.98957947774371,44.95900288917817,44.928426300612635,44.8978497120471,44.86727312348156,44.83669653491602,44.802640465195054,44.76510493079319,44.72756939639133,44.69003386198948,44.65249832758762,44.36541397505513,44.028419858896484,43.69142574273787,43.35443162657925,43.01539319550631,42.66613310274676,42.316873009987205,41.96761291722765,41.61835282446808,41.269092731708525,40.91983263894898,40.57057254618942,40.22131245342986,39.872052360670295,39.52279226791074,39.173532175151195,38.82427208239163,38.47501198963207,38.125751896872515,37.77649180411295,37.42723171135341,37.07797161859385,36.728711525834285,36.37945143307474,36.03019134031516,35.68093124755562,35.331671154796055,34.9824110620365,34.633150969276954,34.283890876517376,33.93463078375783,33.585370690998275,33.23611059823871,32.88685050547917,32.5375904127196,32.188330319960045,31.839070227200487,31.489810134440926,31.14055004168138,30.791289948921822,30.44202985616226,30.092769763402718,29.743509670643142,29.394249577883595,29.044989485124038,28.695729392364477,28.34646929960493,27.99720920684535,27.64794911408581,27.298689021326247,26.94942892856669,26.600168835807146,26.25090874304758,25.901648650288024,25.552388557528463,25.203128464768902,24.85386837200936,24.504608279249798,24.155348186490237,23.806088093730693,23.456828000971115,23.10756790821157,22.758307815452014,22.40904772269245,22.059787629932906,21.71052753717333,21.361267444413787,21.012007351654226,20.66274725889466,20.31348716613512,19.964227073375543,19.614966980616,19.26570688785644,18.916446795096878,18.567186702337334,18.217926609577773,17.868666516818216,17.51940642405865,17.170146331299094,16.82088623853955,16.47162614577999,16.12236605302043,15.773105960260883,15.520612219033353,15.316501653571864,15.112391088110364,14.908280522648866,14.704169957187379,14.50005939172587,14.295948826264382,14.091838260802884,13.887727695341384,13.683617129879895,13.479506564418388,13.278781963749307,13.085547533774562,12.892313103799822,12.699078673825088,12.505844243850348,12.312609813875603,12.119375383900863,11.92614095392612,11.732906523951387,11.544105056272393,11.369633401324709,11.195161746377032,11.020690091429337,10.846218436481664,10.671746781533978,10.497275126586295,10.327370549012656,10.176016197066149,10.024661845119658,9.873307493173158,9.72195314122666,9.570598789280167,9.430833820252904,9.299497491070353,9.168161161887802,9.036824832705253,8.90548850352271,8.793169881373247,8.681042585861775,8.568915290350306,8.460036469835426,8.366847096251126,8.273657722666826,8.180468349082526,8.097424432937132,8.014977308405783,7.932530183874424,7.850083059343067,7.767635934811709,7.685188810280352,7.6027416857490016,7.520294561217643,7.437847436686286,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[46.81468725745957,46.78411066889403,46.75353408032849,46.722957491762955,46.69238090319742,46.661804314631894,46.63122772606634,46.60065113750081,46.57007454893528,46.53949796036973,46.508921371804206,46.478344783238654,46.44776819467313,46.41719160610759,46.38661501754205,46.35603842897652,46.32546184041097,46.29488525184544,46.264308663279905,46.23373207471436,46.20315548614883,46.17257889758329,46.142002309017755,46.11142572045222,46.08084913188668,46.05027254332114,46.01969595475561,45.98911936619007,45.95854277762453,45.92796618905899,45.897389600493455,45.866813011927924,45.83623642336238,45.80565983479685,45.77508324623131,45.744506657665774,45.713930069100236,45.6833534805347,45.65277689196916,45.622200303403616,45.591623714838086,45.56104712627254,45.53047053770701,45.49989394914147,45.46931736057594,45.4387407720104,45.40816418344486,45.37758759487932,45.34701100631379,45.31643441774825,45.28585782918271,45.25528124061717,45.22470465205164,45.1941280634861,45.16355147492057,45.13297488635503,45.10239829778949,45.071821709223954,45.04124512065842,45.01066853209288,44.98009194352734,44.949515354961804,44.918938761953136,44.88140322755128,44.84386769314941,44.806332158747566,44.768796624345704,44.73126108994384,44.69372555554198,44.65619002114013,44.61865448673827,44.58111895233641,44.54358341793455,44.506047883532695,44.46851234913083,44.43097681472898,44.39344128032711,44.35590574592526,44.3183702115234,44.28083467712154,44.24329914271968,44.205763608317824,44.16822807391597,44.13069253951411,43.84360818698161,43.50661407082297,43.169619954664356,42.832625838505734,42.49563172234711,42.1586376061885,41.82164349002988,41.48464937387126,41.14765525771262,40.810661141554,40.473667025395386,40.136672909236765,39.79967879307814,39.46268467691951,39.12569056076089,38.78869644460228,38.45170232844365,38.11470821228503,37.7777140961264,37.44071997996778,37.103725863809174,36.758554437748145,36.40929434498859,36.060034252229045,35.710774159469466,35.361514066709915,35.01225397395036,34.6629938811908,34.31373378843125,33.96447369567168,33.61521360291213,33.26595351015257,32.91669341739301,32.56743332463346,32.218173231873905,31.868913139114348,31.519653046354783,31.170392953595226,30.821132860835675,30.471872768076118,30.12261267531656,29.773352582557017,29.424092489797438,29.074832397037895,28.725572304278334,28.376312211518776,28.02705211875923,27.67779202599965,27.32853193324011,26.979271840480546,26.630011747720992,26.280751654961442,25.931491562201884,25.58223146944232,25.232971376682762,24.883711283923205,24.534451191163654,24.185191098404097,23.835931005644532,23.48667091288499,23.137410820125417,22.788150727365867,22.43889063460631,22.089630541846752,21.74037044908721,21.39111035632763,21.041850263568087,20.692590170808522,20.34333007804896,19.994069985289418,19.644809892529842,19.2955497997703,18.946289707010735,18.597029614251177,18.247769521491634,17.898509428732073,17.54924933597251,17.19998924321295,16.85072915045339,16.501469057693846,16.15220896493429,15.802948872174726,15.453688779415181,15.201195038187652,14.997084472726163,14.792973907264663,14.588863341803165,14.384752776341676,14.180642210880167,13.976531645418678,13.77242107995718,13.568310514495682,13.371792720885164,13.178558290910413,12.98532386093568,12.792089430960939,12.598855000986195,12.405620571011463,12.21238614103672,12.019151711061978,11.825917281087237,11.638713742016261,11.464242087068587,11.289770432120902,11.115298777173216,10.94082712222554,10.766355467277847,10.591883812330174,10.41853983115389,10.267185479207392,10.1158311272609,9.964476775314393,9.8131224233679,9.661768071421402,9.515286529010602,9.38395019982806,9.252613870645511,9.12127754146296,8.98994121228041,8.868247663286063,8.756120367774594,8.64399307226312,8.531865776751648,8.430278747321752,8.337089373737452,8.24390000015315,8.153097793025093,8.070650668493736,7.988203543962378,7.905756419431027,7.82330929489967,7.740862170368311,7.658415045836954,7.575967921305597,7.493520796774247,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[46.40770407189126,46.37712748332572,46.34655089476018,46.31597430619465,46.28539771762911,46.25482112906357,46.224244540498034,46.1936679519325,46.16309136336696,46.13251477480142,46.101938186235884,46.07136159767035,46.04078500910481,46.01020842053928,45.97963183197374,45.9490552434082,45.918478654842666,45.88790206627713,45.85732547771159,45.82674888914606,45.796172300580515,45.76559571201498,45.73501912344944,45.70444253488391,45.673865946318365,45.643289357752835,45.6127127691873,45.58213618062175,45.55155959205622,45.520983003490684,45.49040641492515,45.45982982635961,45.42925323779407,45.39867664922854,45.368100060663,45.33752347209746,45.30694688353193,45.276370294966384,45.245793706400846,45.21521711783531,45.18464052926978,45.15406394070423,45.1234873521387,45.092910763573165,45.062334175007635,45.03175758644209,44.9977015243094,44.96016598990754,44.92263045550568,44.88509492110383,44.84755938670196,44.810023852300105,44.77248831789825,44.73495278349639,44.697417249094535,44.65988171469267,44.62234618029082,44.58481064588896,44.547275111487096,44.50973957708525,44.47220404268338,44.434668508281526,44.397132973879664,44.35959743947781,44.32206190507594,44.284526370674094,44.24699083627223,44.20945530187037,44.17191976746851,44.134384233066655,44.0968486986648,44.05931316426294,44.02177762986108,43.98424209545922,43.94670656105737,43.90917102665551,43.871635492253645,43.834099957851784,43.79656442344992,43.75902888904807,43.72149335464621,43.68395782024435,43.64642228584249,43.608886751440636,43.32180239890814,42.984808282749505,42.64781416659089,42.31082005043226,41.97382593427364,41.63683181811503,41.299837701956406,40.96284358579778,40.62584946963915,40.28885535348053,39.951861237321914,39.61486712116329,39.27787300500467,38.940878888846036,38.603884772687415,38.26689065652881,37.92989654037018,37.59290242421156,37.25590830805293,36.91891419189431,36.5819200757357,36.244925959577074,35.907931843418446,35.57093772725984,35.233943611101196,34.89694949494259,34.55995537878397,34.22296126262534,33.885967146466726,33.54897303030809,33.211978914149476,32.874984797990855,32.53799068183223,32.20099656567361,31.86400244951499,31.527008333356363,31.190014217197742,30.850975772749543,30.50171567999,30.152455587230442,29.803195494470877,29.45393540171134,29.104675308951762,28.755415216192215,28.406155123432654,28.056895030673097,27.707634937913554,27.358374845153975,27.00911475239443,26.659854659634867,26.31059456687531,25.961334474115766,25.6120743813562,25.262814288596644,24.91355419583708,24.564294103077522,24.21503401031798,23.86577391755842,23.516513824798857,23.167253732039313,22.817993639279734,22.46873354652019,22.119473453760634,21.77021336100107,21.420953268241526,21.071693175481947,20.722433082722404,20.373172989962846,20.023912897203285,19.67465280444374,19.325392711684163,18.97613261892462,18.62687252616506,18.277612433405498,17.928352340645954,17.579092247886393,17.229832155126836,16.88057206236727,16.531311969607714,16.18205187684817,15.83279178408861,15.483531691329047,15.134271598569503,14.881777857341973,14.677667291880484,14.473556726418987,14.269446160957488,14.065335595495998,13.861225030034491,13.658037907995777,13.464803478021034,13.271569048046292,13.07833461807156,12.88510018809681,12.691865758122075,12.498631328147333,12.305396898172592,12.112162468197859,11.918928038223118,11.733322427760159,11.558850772812477,11.38437911786479,11.209907462917117,11.03543580796943,10.860964153021747,10.686492498074069,10.512020843126376,10.35835476134865,10.207000409402152,10.055646057455654,9.904291705509161,9.752937353562656,9.601583001616163,9.468402908585775,9.337066579403224,9.20573025022068,9.074393921038132,8.943325445198894,8.83119814968742,8.719070854175948,8.60694355866448,8.494816263153005,8.400521024808082,8.307331651223787,8.214142277639487,8.126324028581667,8.043876904050332,7.961429779518975,7.878982654987618,7.796535530456267,7.714088405924909,7.631641281393551,7.549194156862194,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[46.00072088632291,45.97014429775738,45.939567709191834,45.9089911206263,45.878414532060766,45.84783794349522,45.81726135492969,45.78668476636415,45.75610817779862,45.72553158923308,45.69495500066754,45.66437841210201,45.633801823536466,45.603225234970935,45.57264864640539,45.54207205783986,45.511495469274315,45.480918880708785,45.45034229214325,45.41976570357771,45.38918911501217,45.358612526446635,45.3280359378811,45.29745934931556,45.266882760750015,45.236306172184484,45.205729583618954,45.17515299505341,45.14457640648787,45.113999817922334,45.076464286665626,45.038928752263764,45.0013932178619,44.96385768346005,44.92632214905819,44.888786614656325,44.85125108025447,44.81371554585262,44.776180011450755,44.738644477048894,44.70110894264704,44.663573408245185,44.62603787384332,44.58850233944146,44.5509668050396,44.51343127063774,44.475895736235884,44.43836020183402,44.40082466743217,44.363289133030314,44.325753598628445,44.28821806422659,44.250682529824736,44.213146995422875,44.17561146102102,44.13807592661916,44.100540392217304,44.063004857815436,44.02546932341358,43.98793378901173,43.950398254609865,43.91286272020801,43.87532718580614,43.83779165140429,43.800256117002434,43.76272058260058,43.72518504819872,43.687649513796856,43.650113979395,43.61257844499314,43.57504291059128,43.537507376189424,43.49997184178756,43.4624363073857,43.42490077298385,43.387365238581985,43.349829704180124,43.31229416977827,43.274758635376415,43.23722310097455,43.19968756657269,43.16215203217084,43.12461649776898,43.087080963367114,42.799996610834626,42.46300249467598,42.12600837851737,41.78901426235875,41.45202014620013,41.11502603004151,40.77803191388289,40.44103779772426,40.104043681565635,39.767049565407014,39.4300554492484,39.09306133308978,38.75606721693115,38.41907310077252,38.0820789846139,37.745084868455294,37.408090752296665,37.07109663613804,36.734102519979416,36.397108403820795,36.06011428766219,35.72312017150355,35.38612605534493,35.049131939186324,34.71213782302768,34.375143706869075,34.03814959071045,33.70115547455182,33.36416135839321,33.02716724223457,32.69017312607596,32.35317900991733,32.016184893758705,31.6791907776001,31.342196661441474,31.00520254528285,30.668208429124224,30.331214312965596,29.99422019680699,29.657226080648364,29.32023196448974,28.98323784833113,28.64624373217249,28.30924961601388,27.972255499855255,27.63526138369663,27.29826726753802,26.96127315137938,26.624279035220766,26.287284919062145,25.950290802903517,25.61329668674491,25.27630257058628,24.93930845442766,24.594137014991382,24.24487692223182,23.895616829472274,23.546356736712717,23.197096643953152,22.84783655119361,22.498576458434034,22.14931636567449,21.80005627291493,21.45079618015537,21.101536087395825,20.75227599463625,20.403015901876703,20.053755809117146,19.70449571635758,19.355235623598038,19.005975530838462,18.656715438078916,18.307455345319354,17.958195252559797,17.60893515980025,17.259675067040693,16.91041497428113,16.56115488152157,16.21189478876201,15.862634696002466,15.513374603242905,15.164114510483344,14.8148544177238,14.56236067649627,14.358250111034781,14.154139545573283,13.950028980111785,13.751048665131634,13.557814235156883,13.36457980518215,13.171345375207409,12.978110945232666,12.784876515257933,12.591642085283183,12.39840765530845,12.20517322533371,12.011938795358967,11.82793111350404,11.653459458556354,11.47898780360867,11.304516148660987,11.130044493713301,10.955572838765626,10.78110118381794,10.606629528870258,10.449524043489893,10.298169691543388,10.146815339596895,9.995460987650397,9.844106635703898,9.692752283757406,9.552855617343475,9.421519288160932,9.29018295897838,9.158846629795832,9.027510300613288,8.906275931600241,8.794148636088767,8.682021340577295,8.569894045065821,8.463952675878707,8.370763302294408,8.277573928710106,8.184384555125812,8.099550264138259,8.0171031396069,7.934656015075563,7.8522088905442065,7.769761766012849,7.687314641481499,7.604867516950141,7.522420392418784,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[45.593737700754566,45.56316111218903,45.53258452362349,45.502007935057954,45.471431346492416,45.440854757926886,45.41027816936134,45.3797015807958,45.34912499223027,45.318548403664735,45.2879718150992,45.25739522653366,45.22681863796812,45.1927625834237,45.15522704902184,45.11769151461999,45.08015598021813,45.04262044581627,45.00508491141441,44.96754937701255,44.9300138426107,44.89247830820884,44.854942773806975,44.81740723940512,44.77987170500326,44.742336170601405,44.70480063619955,44.66726510179769,44.62972956739583,44.592194032993966,44.554658498592104,44.51712296419025,44.479587429788396,44.442051895386534,44.40451636098468,44.36698082658282,44.329445292180964,44.2919097577791,44.25437422337724,44.216838688975386,44.179303154573525,44.14176762017166,44.10423208576981,44.06669655136795,44.02916101696609,43.99162548256423,43.95408994816238,43.91655441376051,43.879018879358654,43.8414833449568,43.80394781055494,43.76641227615308,43.72887674175122,43.69134120734937,43.65380567294751,43.616270138545644,43.57873460414379,43.54119906974193,43.50366353534007,43.46612800093821,43.42859246653635,43.3910569321345,43.353521397732635,43.31598586333078,43.278450328928926,43.24091479452706,43.2033792601252,43.16584372572335,43.12830819132148,43.090772656919626,43.053237122517764,43.0157015881159,42.978166053714055,42.940630519312194,42.90309498491034,42.86555945050847,42.828023916106616,42.79048838170476,42.75295284730289,42.71541731290104,42.67788177849918,42.64034624409732,42.60281070969547,42.5652751752936,42.278190822761104,41.94119670660247,41.604202590443855,41.26720847428523,40.930214358126605,40.59322024196799,40.25622612580938,39.91923200965075,39.58223789349213,39.2452437773335,38.90824966117489,38.571255545016264,38.234261428857636,37.897267312699014,37.560273196540386,37.22327908038178,36.88628496422315,36.54929084806452,36.21229673190591,35.87530261574728,35.538308499588666,35.20131438343004,34.864320267271424,34.52732615111281,34.19033203495417,33.85333791879556,33.51634380263693,33.17934968647831,32.842355570319704,32.505361454161054,32.16836733800245,31.831373221843826,31.494379105685198,31.15738498952659,30.820390873367963,30.483396757209334,30.146402641050713,29.80940852489209,29.472414408733478,29.13542029257485,28.798426176416225,28.461432060257618,28.12443794409898,27.78744382794037,27.450449711781744,27.113455595623115,26.77646147946451,26.439467363305866,26.102473247147255,25.76547913098863,25.42848501483001,25.0914908986714,24.75449678251277,24.417502666354146,24.08050855019552,23.743514434036896,23.406520317878286,23.06952620171966,22.732532085561036,22.395537969402426,22.058543853243783,21.721549737085176,21.384555620926548,21.047561504767923,20.710567388609313,20.37357327245067,20.036579156292063,19.699585040133442,19.362590923974814,19.025596807816203,18.686558349992758,18.337298257233215,17.988038164473654,17.638778071714093,17.28951797895455,16.94025788619499,16.590997793435427,16.24173770067587,15.892477607916307,15.543217515156764,15.193957422397203,14.844697329637643,14.4954372368781,14.24294349565057,14.038832930189079,13.844059422267485,13.65082499229274,13.457590562318007,13.264356132343257,13.071121702368526,12.877887272393783,12.684652842419041,12.49141841244431,12.298183982469556,12.104949552494825,11.922539799247913,11.748068144300227,11.573596489352548,11.399124834404862,11.22465317945718,11.050181524509496,10.87570986956181,10.701238214614134,10.54069332563113,10.38933897368463,10.237984621738137,10.08663026979163,9.93527591784514,9.783921565898641,9.637308326101182,9.505971996918639,9.374635667736083,9.24329933855354,9.111963009370989,8.981353713513055,8.869226418001588,8.757099122490114,8.64497182697864,8.532844531467166,8.43419495336503,8.341005579780733,8.247816206196433,8.155223624226197,8.072776499694847,7.99032937516349,7.907882250632132,7.825435126100795,7.7429880015694375,7.6605408770380805,7.57809375250673,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[45.18598134404682,45.14844580964497,45.11091027524311,45.073374740841246,45.03583920643939,44.99830367203754,44.960768137635675,44.923232603233814,44.88569706883196,44.8481615344301,44.810626000028236,44.77309046562638,44.73555493122452,44.698019396822666,44.660483862420804,44.62294832801895,44.58541279361709,44.547877259215234,44.51034172481337,44.47280619041151,44.43527065600965,44.3977351216078,44.36019958720594,44.32266405280408,44.28512851840222,44.24759298400036,44.2100574495985,44.17252191519664,44.134986380794786,44.09745084639293,44.05991531199107,44.02237977758921,43.984844243187354,43.9473087087855,43.90977317438363,43.872237639981776,43.834702105579915,43.79716657117806,43.7596310367762,43.722095502374344,43.68455996797248,43.64702443357062,43.60948889916877,43.571953364766905,43.534417830365044,43.49688229596319,43.45934676156133,43.42181122715947,43.38427569275761,43.34674015835576,43.3092046239539,43.271669089552034,43.23413355515018,43.196598020748326,43.159062486346464,43.1215269519446,43.08399141754275,43.04645588314089,43.00892034873903,42.97138481433717,42.933849279935316,42.896313745533455,42.85877821113159,42.82124267672974,42.78370714232788,42.746171607926016,42.70863607352416,42.6711005391223,42.633565004720445,42.596029470318584,42.55849393591672,42.52095840151487,42.483422867113006,42.44588733271115,42.40835179830929,42.37081626390743,42.333280729505574,42.29574519510371,42.25820966070186,42.2206741263,42.17543584452152,42.12865699806931,42.08187815161709,42.03509930516487,41.74647440062399,41.409480284465346,41.07248616830674,40.73549205214811,40.39849793598949,40.061503819830875,39.724509703672254,39.38751558751363,39.050521471355,38.713527355196376,38.37653323903776,38.03953912287914,37.70254500672052,37.365550890561885,37.02855677440326,36.691562658244656,36.35456854208603,36.0175744259274,35.68058030976878,35.34358619361016,35.00659207745154,34.669597961292915,34.332603845134294,33.99560972897568,33.658615612817044,33.32162149665843,32.9846273804998,32.64763326434118,32.310639148182574,31.97364503202393,31.63665091586532,31.299656799706696,30.96266268354807,30.62566856738946,30.288674451230836,29.95168033507221,29.614686218913587,29.27769210275496,28.940697986596348,28.603703870437727,28.2667097542791,27.929715638120488,27.59272152196185,27.25572740580324,26.918733289644614,26.581739173485985,26.24474505732738,25.90775094116874,25.57075682501013,25.2337627088515,24.89676859269288,24.559774476534272,24.222780360375644,23.88578624421702,23.548792128058395,23.211798011899766,22.87480389574116,22.537809779582535,22.20081566342391,21.863821547265296,21.526827431106657,21.189833314948046,20.852839198789425,20.515845082630797,20.17885096647219,19.841856850313548,19.504862734154937,19.167868617996312,18.830874501837688,18.493880385679077,18.156886269520438,17.819892153361828,17.482898037203203,17.145903921044578,16.808909804885968,16.471915688727343,16.134921572568715,15.797927456410092,15.460933340251465,15.134817143654036,14.81413994037378,14.493462737093523,14.17278553381328,13.937070179403355,13.743835749428623,13.55060131945388,13.357366889479138,13.164132459504405,12.970898029529655,12.777663599554923,12.584429169580178,12.391194739605437,12.197960309630705,12.017148484991802,11.842676830044123,11.668205175096443,11.493733520148757,11.31926186520108,11.144790210253392,10.970318555305708,10.795846900358026,10.631862607772382,10.480508255825889,10.32915390387939,10.177799551932893,10.026445199986398,9.875090848039893,9.7237364960934,9.590424705676353,9.459088376493803,9.32775204731126,9.196415718128703,9.06507938894616,8.944304199914415,8.832176904402939,8.720049608891472,8.607922313379998,8.497626604435663,8.404437230851364,8.311247857267062,8.218058483682766,8.128449859782794,8.046002735251436,7.963555610720086,7.8811084861887295,7.798661361657372,7.716214237126035,7.633767112594677,7.5513199880633195,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[44.77580882640392,44.738273292002056,44.7007377576002,44.66320222319834,44.625666688796485,44.588131154394624,44.55059561999277,44.51306008559091,44.47552455118905,44.43798901678719,44.40045348238533,44.362917947983476,44.325382413581615,44.28784687917976,44.2503113447779,44.212775810376044,44.17524027597418,44.13770474157233,44.10016920717047,44.062633672768605,44.025098138366744,43.98756260396489,43.950027069563035,43.91249153516117,43.87495600075931,43.83742046635746,43.799884931955596,43.762349397553734,43.72481386315187,43.68727832875002,43.64974279434816,43.6122072599463,43.57467172554444,43.53713619114258,43.499600656740725,43.46206512233886,43.424529587937,43.38699405353515,43.34945851913329,43.311922984731424,43.27438745032957,43.236851915927716,43.19931638152586,43.16178084712399,43.12424531272214,43.08670977832028,43.04917424391842,43.01163870951656,42.974103175114706,42.936567640712845,42.89903210631098,42.86149657190913,42.82396103750727,42.786425503105406,42.74888996870355,42.71135443430169,42.673818899899835,42.636283365497974,42.59874783109612,42.561212296694265,42.523676762292396,42.48614122789054,42.44860569348868,42.40798906621024,42.36121021975802,42.3144313733058,42.26765252685359,42.22087368040137,42.17409483394915,42.12731598749693,42.08053714104471,42.033758294592495,41.986979448140275,41.940200601688055,41.893421755235835,41.84664290878362,41.7998640623314,41.75308521587918,41.70630636942696,41.65952752297474,41.61274867652252,41.5659698300703,41.51919098361809,41.47241213716587,41.18378723262498,40.846793116466344,40.50979900030773,40.17280488414911,39.83581076799048,39.49881665183187,39.161822535673245,38.824828419514624,38.487834303355996,38.150840187197375,37.81384607103876,37.47685195488013,37.13985783872151,36.80286372256288,36.46586960640426,36.128875490245655,35.79188137408702,35.4548872579284,35.11789314176978,34.78089902561115,34.44390490945254,34.10691079329391,33.76991667713529,33.43292256097668,33.095928444818036,32.75893432865943,32.4219402125008,32.08494609634218,31.747951980183572,31.410957864024926,31.073963747866316,30.736969631707694,30.39997551554907,30.06298139939046,29.725987283231834,29.38899316707321,29.05199905091458,28.715004934755957,28.378010818597346,28.041016702438725,27.704022586280097,27.36702847012149,27.030034353962847,26.69304023780424,26.356046121645612,26.019052005486987,25.682057889328377,25.345063773169738,25.008069657011127,24.6710755408525,24.334081424693878,23.99708730853527,23.660093192376642,23.323099076218018,22.986104960059393,22.649110843900765,22.312116727742158,21.97512261158353,21.63812849542491,21.301134379266294,20.964140263107655,20.627146146949045,20.29287149660471,19.972194293324456,19.651517090044216,19.330839886763943,19.0101626834837,18.689485480203444,18.36880827692319,18.048131073642946,17.727453870362673,17.406776667082433,17.086099463802178,16.76542226052192,16.44474505724168,16.12406785396142,15.803390650681164,15.482713447400908,15.162036244120651,14.841359040840409,14.520681837560153,14.200004634279896,13.879327430999654,13.64361207658973,13.450377646614996,13.257143216640255,13.063908786665511,12.870674356690778,12.677439926716028,12.484205496741295,12.290971066766552,12.11175717073568,11.937285515788004,11.76281386084031,11.588342205892634,11.413870550944951,11.239398895997265,11.064927241049588,10.8904555861019,10.723031889913624,10.571677537967126,10.420323186020626,10.268968834074132,10.117614482127633,9.966260130181135,9.814905778234642,9.674877414434054,9.54354108525151,9.41220475606896,9.28086842688641,9.149532097703867,9.01938198182723,8.907254686315762,8.795127390804288,8.683000095292813,8.570872799781345,8.467868881921987,8.374679508337687,8.281490134753387,8.188300761169089,8.101676095339384,8.019228970808026,7.936781846276668,7.854334721745319,7.771887597213961,7.6894404726826036,7.606993348151266,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[44.365636308761005,44.32810077435915,44.29056523995728,44.25302970555543,44.21549417115357,44.17795863675171,44.14042310234986,44.102887567947995,44.065352033546134,44.02781649914427,43.99028096474241,43.952745430340556,43.9152098959387,43.87767436153684,43.84013882713498,43.80260329273312,43.76506775833127,43.7275322239294,43.68999668952755,43.65246115512569,43.61492562072383,43.57739008632197,43.53985455192011,43.50231901751826,43.4647834831164,43.42724794871454,43.38971241431268,43.35217687991082,43.31464134550896,43.277105811107106,43.239570276705244,43.20203474230339,43.16449920790153,43.126963673499674,43.08942813909781,43.05189260469595,43.014357070294096,42.976821535892235,42.93928600149037,42.90175046708852,42.864214932686664,42.8266793982848,42.78914386388294,42.75160832948108,42.714072795079225,42.676537260677364,42.63900172627551,42.59376344144674,42.54698459499452,42.5002057485423,42.45342690209009,42.40664805563786,42.359869209185646,42.313090362733426,42.266311516281206,42.21953266982899,42.172753823376766,42.12597497692455,42.07919613047233,42.03241728402011,41.9856384375679,41.93885959111567,41.89208074466346,41.84530189821124,41.79852305175902,41.75174420530681,41.704965358854594,41.65818651240237,41.61140766595015,41.564628819497926,41.51784997304571,41.47107112659349,41.42429228014127,41.37751343368906,41.33073458723683,41.28395574078462,41.23717689433241,41.19039804788018,41.14361920142797,41.09684035497574,41.05006150852353,41.003282662071314,40.95650381561909,40.909724969166874,40.621100064625985,40.28410594846734,39.94711183230873,39.6101177161501,39.27312359999148,38.936129483832865,38.59913536767424,38.262141251515615,37.92514713535699,37.58815301919837,37.25115890303976,36.91416478688113,36.57717067072251,36.24017655456388,35.90318243840525,35.566188322246646,35.22919420608802,34.892200089929396,34.55520597377077,34.21821185761215,33.88121774145354,33.54422362529491,33.20722950913628,32.870235392977676,32.533241276819034,32.19624716066043,31.859253044501802,31.522258928343177,31.185264812184567,30.848270696025924,30.511276579867314,30.17428246370869,29.837288347550064,29.500294231391457,29.16330011523283,28.8263059990742,28.48931188291558,28.152317766756955,27.815323650598344,27.478329534439716,27.141335418281095,26.804341302122488,26.467347185963842,26.13035306980523,25.79335895364661,25.456364837487982,25.13024864627515,24.809571442994873,24.488894239714632,24.168217036434378,23.847539833154123,23.526862629873882,23.206185426593624,22.88550822331337,22.56483102003311,22.244153816752853,21.923476613472612,21.602799410192354,21.2821222069121,20.961445003631855,20.640767800351586,20.320090597071346,19.999413393791087,19.678736190510833,19.35805898723059,19.037381783950316,18.716704580670076,18.39602737738982,18.07535017410956,17.75467297082932,17.43399576754905,17.113318564268805,16.792641360988547,16.471964157708292,16.151286954428052,15.830609751147795,15.509932547867537,15.18925534458728,14.868578141307024,14.547900938026782,14.227223734746527,13.906546531466269,13.585869328186027,13.350153973776102,13.156919543801369,12.963685113826628,12.770450683851886,12.577216253877154,12.383981823902403,12.20636585647956,12.031894201531872,11.85742254658419,11.682950891636512,11.508479236688821,11.334007581741142,11.159535926793462,10.985064271845774,10.814201172054869,10.662846820108369,10.511492468161867,10.360138116215369,10.208783764268869,10.057429412322376,9.906075060375878,9.75933012319176,9.627993794009216,9.49665746482666,9.365321135644116,9.233984806461567,9.102648477279018,8.982332468228583,8.870205172717103,8.758077877205634,8.64595058169416,8.533823286182688,8.438111159408313,8.344921785824011,8.251732412239713,8.158543038655411,8.07490233089598,7.992455206364615,7.910008081833258,7.8275609573019,7.745113832770549,7.662666708239192,7.5802195837078346,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[43.95546379111813,43.917928256716266,43.880392722314404,43.84285718791254,43.805321653510696,43.767786119108834,43.73025058470697,43.69271505030511,43.65517951590326,43.617643981501395,43.58010844709953,43.54257291269768,43.505037378295825,43.46750184389396,43.4299663094921,43.39243077509025,43.35489524068839,43.31735970628653,43.27982417188467,43.24228863748281,43.20475310308096,43.1672175686791,43.12968203427724,43.092146499875376,43.054610965473515,43.01707543107166,42.979539896669806,42.942004362267944,42.90446882786608,42.86693329346423,42.8263166631355,42.77953781668328,42.73275897023106,42.68598012377884,42.63920127732662,42.59242243087441,42.54564358442219,42.49886473796997,42.452085891517754,42.40530704506553,42.358528198613314,42.311749352161094,42.264970505708874,42.218191659256654,42.171412812804434,42.12463396635222,42.07785511989999,42.03107627344779,41.98429742699557,41.93751858054334,41.89073973409113,41.84396088763891,41.79718204118669,41.750403194734474,41.70362434828225,41.656845501830034,41.61006665537781,41.563287808925594,41.51650896247338,41.469730116021154,41.42295126956894,41.376172423116714,41.3293935766645,41.28261473021229,41.23583588376006,41.18905703730785,41.14227819085563,41.09549934440341,41.04872049795119,41.00194165149897,40.955162805046754,40.90838395859454,40.861605112142314,40.8148262656901,40.768047419237874,40.72126857278566,40.674489726333434,40.62771087988122,40.58093203342901,40.53415318697678,40.48737434052457,40.44059549407235,40.39381664762013,40.34703780116791,40.058412896627026,39.72141878046838,39.38442466430977,39.04743054815115,38.71043643199252,38.373442315833906,38.036448199675284,37.69945408351666,37.362459967358035,37.025465851199414,36.6884717350408,36.35147761888217,36.01448350272355,35.67748938656492,35.3404952704063,35.003501154247694,34.666507038089065,34.32951292193044,33.992518805771816,33.655524689613195,33.31853057345458,32.98153645729595,32.64454234113733,32.30754822497872,31.97055410882008,31.63355999266147,31.296565876502843,30.959571760344218,30.62257764418561,30.288302999225834,29.967625795945594,29.64694859266534,29.326271389385084,29.005594186104837,28.684916982824582,28.36423977954432,28.043562576264065,27.72288537298381,27.40220816970357,27.081530966423315,26.760853763143054,26.440176559862813,26.11949935658254,25.7988221533023,25.478144950022045,25.157467746741787,24.836790543461547,24.51611334018127,24.19543613690103,23.874758933620775,23.55408173034052,23.23340452706028,22.912727323780018,22.592050120499763,22.27137291721951,21.950695713939254,21.630018510659006,21.30934130737875,20.988664104098497,20.667986900818253,20.34730969753798,20.02663249425774,19.705955290977485,19.38527808769723,19.064600884416983,18.743923681136714,18.423246477856473,18.102569274576215,17.78189207129596,17.461214868015716,17.140537664735447,16.819860461455203,16.49918325817495,16.17850605489469,15.85782885161445,15.537151648334191,15.216474445053935,14.895797241773677,14.575120038493422,14.25444283521318,13.933765631932923,13.613088428652667,13.292411225372424,13.0566958709625,12.863461440987768,12.670227011013024,12.476992581038282,12.300974542223457,12.12650288727576,11.952031232328089,11.777559577380401,11.603087922432717,11.42861626748504,11.254144612537349,11.07967295758967,10.90537045419612,10.75401610224962,10.60266175030313,10.45130739835663,10.29995304641013,10.148598694463631,9.99724434251713,9.845889990570637,9.712446502766932,9.581110173584381,9.449773844401838,9.31843751521928,9.187101186036738,9.057410250141407,8.945282954629933,8.833155659118466,8.721028363606987,8.608901068095518,8.501542810478945,8.408353436894643,8.315164063310348,8.221974689726046,8.13057569098392,8.048128566452563,7.965681441921219,7.883234317389855,7.800787192858498,7.71834006832714,7.635892943795789,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[43.545291273475215,43.50775573907335,43.4702202046715,43.43268467026964,43.39514913586778,43.35761360146592,43.32007806706407,43.282542532662205,43.24500699826035,43.20747146385849,43.16993592945663,43.13240039505477,43.09486486065291,43.05732932625106,43.01209103837199,42.96531219191978,42.91853334546756,42.87175449901534,42.824975652563126,42.7781968061109,42.731417959658685,42.684639113206465,42.637860266754245,42.591081420302025,42.54430257384981,42.49752372739759,42.45074488094537,42.40396603449315,42.35718718804093,42.31040834158872,42.2636294951365,42.21685064868428,42.17007180223206,42.12329295577984,42.076514109327626,42.0297352628754,41.982956416423185,41.936177569970965,41.889398723518745,41.84261987706653,41.79584103061431,41.74906218416209,41.70228333770987,41.65550449125765,41.60872564480544,41.561946798353205,41.515167951901,41.46838910544878,41.42161025899655,41.374831412544346,41.328052566092126,41.281273719639906,41.234494873187685,41.18771602673546,41.14093718028325,41.09415833383103,41.04737948737881,41.00060064092659,40.953821794474365,40.90704294802215,40.86026410156994,40.81348525511772,40.7667064086655,40.719927562213286,40.673148715761066,40.62636986930884,40.579591022856626,40.532812176404406,40.48603332995219,40.43925448349997,40.39247563704775,40.34569679059553,40.29891794414331,40.25213909769109,40.20536025123887,40.15858140478666,40.11180255833444,40.06502371188222,40.01824486543,39.97146601897778,39.92468717252556,39.877908326073346,39.831129479621126,39.784350633168906,39.49572572862802,39.15873161246938,38.82173749631077,38.484743380152146,38.14774926399352,37.810755147834904,37.47376103167628,37.13676691551766,36.79977279935903,36.462778683200405,36.12578456704179,35.78879045088317,35.45179633472455,35.125680148896265,34.80500294561601,34.48432574233577,34.16364853905551,33.84297133577525,33.522294132495,33.201616929214744,32.8809397259345,32.56026252265425,32.239585319373994,31.91890811609375,31.59823091281348,31.277553709533237,30.95687650625298,30.636199302972724,30.31552209969248,29.99484489641221,29.674167693131967,29.353490489851712,29.032813286571454,28.712136083291213,28.391458880010955,28.070781676730697,27.750104473450442,27.429427270170184,27.108750066889943,26.78807286360969,26.46739566032943,26.146718457049186,25.826041253768917,25.505364050488676,25.184686847208418,24.864009643928163,24.54333244064792,24.222655237367647,23.901978034087403,23.581300830807148,23.260623627526893,22.939946424246653,22.619269220966395,22.29859201768614,21.97791481440588,21.657237611125627,21.336560407845383,21.015883204565128,20.69520600128487,20.374528798004626,20.053851594724357,19.733174391444113,19.412497188163858,19.091819984883603,18.77114278160336,18.450465578323087,18.129788375042846,17.809111171762588,17.488433968482333,17.16775676520209,16.84707956192182,16.52640235864158,16.20572515536132,15.885047952081063,15.56437074880082,15.243693545520564,14.92301634224031,14.602339138960051,14.281661935679796,13.960984732399552,13.640307529119296,13.31963032583904,12.998953122558799,12.763237768148874,12.570054882915008,12.395583227967329,12.221111573019638,12.046639918071966,11.87216826312427,11.697696608176598,11.52322495322891,11.348753298281228,11.17428164333355,10.999809988385858,10.845185384390863,10.693831032444365,10.542476680497865,10.391122328551374,10.239767976604874,10.088413624658372,9.937059272711874,9.796899211524634,9.66556288234209,9.53422655315954,9.402890223976987,9.271553894794446,9.140217565611888,9.020360736542754,8.90823344103128,8.796106145519806,8.683978850008339,8.571851554496861,8.47178508796527,8.378595714380968,8.28540634079667,8.19221696721237,8.103801926540509,8.021354802009151,7.938907677477794,7.856460552946451,7.774013428415087,7.691566303883729,7.60911917935237,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[43.131599685122396,43.08482083867018,43.03804199221796,42.99126314576574,42.94448429931352,42.8977054528613,42.85092660640908,42.80414775995687,42.75736891350465,42.71059006705243,42.66381122060021,42.61703237414799,42.57025352769577,42.523474681243556,42.47669583479133,42.429916988339116,42.3831381418869,42.336359295434676,42.28958044898246,42.24280160253024,42.19602275607802,42.14924390962581,42.10246506317359,42.05568621672137,42.00890737026915,41.962128523816936,41.91534967736471,41.868570830912496,41.821791984460276,41.775013138008056,41.72823429155584,41.68145544510362,41.634676598651396,41.58789775219918,41.54111890574697,41.49434005929474,41.44756121284253,41.4007823663903,41.35400351993809,41.30722467348588,41.26044582703365,41.213666980581436,41.16688813412921,41.120109287676996,41.07333044122478,41.026551594772556,40.97977274832034,40.932993901868116,40.8862150554159,40.83943620896368,40.79265736251146,40.74587851605925,40.69909966960702,40.65232082315481,40.6055419767026,40.55876313025037,40.51198428379816,40.46520543734593,40.418426590893716,40.3716477444415,40.324868897989276,40.27809005153706,40.231311205084836,40.18453235863262,40.1377535121804,40.09097466572818,40.04419581927597,39.99741697282375,39.95063812637153,39.90385927991931,39.8570804334671,39.81030158701488,39.76352274056266,39.71674389411044,39.669965047658216,39.623186201205996,39.57640735475378,39.529628508301556,39.48284966184934,39.43607081539712,39.387526079786475,39.330151863722975,39.272777647659474,39.21540343159598,38.95618990261864,38.656608511058515,38.35702711949841,38.046897810576425,37.72622060729616,37.40554340401593,37.08486620073567,36.76418899745541,36.44351179417515,36.122834590894904,35.802157387614656,35.481480184334394,35.16080298105415,34.840125777773885,34.51944857449363,34.19877137121339,33.87809416793313,33.55741696465287,33.23673976137262,32.916062558092364,32.59538535481212,32.27470815153187,31.95403094825161,31.633353744971366,31.312676541691097,30.991999338410853,30.671322135130595,30.35064493185034,30.029967728570096,29.709290525289827,29.388613322009583,29.067936118729328,28.747258915449073,28.42658171216883,28.10590450888857,27.785227305608313,27.464550102328058,27.1438728990478,26.82319569576756,26.502518492487305,26.181841289207046,25.861164085926802,25.540486882646533,25.219809679366293,24.899132476086034,24.57845527280578,24.257778069525536,23.937100866245263,23.61642366296502,23.295746459684764,22.97506925640451,22.65439205312427,22.333714849844014,22.013037646563756,21.692360443283498,21.371683240003243,21.051006036723003,20.730328833442744,20.409651630162486,20.088974426882245,19.768297223601976,19.447620020321732,19.126942817041474,18.80626561376122,18.48558841048098,18.164911207200706,17.844234003920462,17.523556800640208,17.202879597359953,16.88220239407971,16.561525190799436,16.240847987519196,15.920170784238938,15.599493580958681,15.278816377678439,14.958139174398184,14.637461971117926,14.31678476783767,13.996107564557413,13.67543036127717,13.354753157996914,13.03407595471666,12.713398751436417,12.490191913711199,12.315720258763518,12.141248603815836,11.966776948868146,11.792305293920478,11.61783363897278,11.443361984025106,11.268890329077418,11.094418674129738,10.936354666532106,10.785000314585599,10.633645962639108,10.48229161069261,10.33093725874611,10.179582906799618,10.028228554853118,9.88135192028234,9.750015591099789,9.618679261917242,9.487342932734698,9.356006603552146,9.224670274369595,9.095438518455573,8.983311222944096,8.871183927432627,8.759056631921153,8.646929336409679,8.535216739035896,8.44202736545159,8.348837991867294,8.255648618282994,8.162459244698693,8.077028162097099,7.99458103756574,7.912133913034383,7.829686788503024,7.747239663971682,7.664792539440318,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[42.704007764442075,42.65722891798986,42.61045007153764,42.563671225085415,42.5168923786332,42.47011353218098,42.42333468572876,42.37655583927655,42.32977699282433,42.28299814637211,42.23621929991989,42.18944045346767,42.142661607015455,42.095882760563235,42.049103914111015,42.002325067658795,41.95554622120658,41.908767374754355,41.86198852830214,41.81520968184992,41.7684308353977,41.72165198894548,41.67487314249327,41.62809429604104,41.58131544958883,41.53453660313661,41.48775775668439,41.440978910232175,41.39420006377995,41.347421217327735,41.300642370875515,41.253863524423295,41.20708467797108,41.16030583151886,41.11352698506664,41.06674813861442,41.0199692921622,40.97319044570999,40.92641159925777,40.87963275280555,40.83285390635333,40.78607505990111,40.73929621344889,40.692517366996675,40.645738520544455,40.598959674092235,40.552180827640015,40.505401981187795,40.458623134735575,40.41184428828336,40.365065441831135,40.31828659537892,40.2715077489267,40.22472890247448,40.17795005602227,40.13117120957005,40.08439236311783,40.03761351666561,39.99083467021339,39.944055823761175,39.897276977308955,39.850498130856735,39.803719284404515,39.756940437952295,39.70309801578778,39.64572379972429,39.588349583660786,39.530975367597286,39.47360115153379,39.416226935470284,39.35885271940679,39.3014785033433,39.244104287279804,39.186730071216296,39.1293558551528,39.0719816390893,39.0146074230258,38.95723320696231,38.89985899089881,38.842484774835306,38.785110558771805,38.72773634270831,38.67036212664482,38.61298791058132,38.35377438160398,38.05419299004385,37.754611598483756,37.455030206923645,37.155448815363535,36.85586742380343,36.55628603224333,36.25670464068321,35.9571232491231,35.65754185756299,35.35796046600289,35.05837907444278,34.75879768288267,34.45921629132256,34.15963489976245,33.860053508202355,33.560472116642245,33.260890725082135,32.96130933352202,32.661727933940895,32.34105073066065,32.02037352738039,31.699696324100138,31.379019120819898,31.058341917539625,30.737664714259385,30.416987510979123,30.096310307698868,29.775633104418624,29.454955901138355,29.134278697858115,28.813601494577856,28.4929242912976,28.172247088017357,27.8515698847371,27.53089268145684,27.210215478176586,26.88953827489633,26.568861071616087,26.248183868335833,25.927506665055574,25.606829461775334,25.28615225849506,24.96547505521482,24.644797851934566,24.324120648654308,24.003443445374067,23.68276624209379,23.36208903881355,23.041411835533296,22.72073463225304,22.4000574289728,22.079380225692542,21.758703022412288,21.438025819132026,21.11734861585177,20.796671412571527,20.475994209291272,20.155317006011018,19.834639802730774,19.513962599450505,19.19328539617026,18.872608192890006,18.55193098960975,18.231253786329507,17.910576583049235,17.58989937976899,17.269222176488736,16.948544973208477,16.627867769928237,16.307190566647968,15.986513363367724,15.665836160087467,15.34515895680721,15.024481753526969,14.703804550246712,14.383127346966454,14.062450143686199,13.741772940405943,13.4210957371257,13.100418533845444,12.779741330565187,12.459064127284945,12.235857289559727,12.061385634612046,11.886913979664364,11.712442324716676,11.537970669769006,11.363499014821308,11.189027359873636,11.027523948673355,10.876169596726857,10.724815244780366,10.57346089283386,10.422106540887368,10.270752188940868,10.11939783699437,9.96804348504788,9.834468299857512,9.703131970674962,9.571795641492411,9.440459312309862,9.309122983127319,9.177786653944768,9.058389004856927,8.946261709345457,8.834134413833981,8.72200711832251,8.609879822811038,8.505459016522224,8.412269642937929,8.319080269353623,8.225890895769327,8.132701522185027,8.050254397653681,7.967807273122331,7.885360148590974,7.802913024059616,7.720465899528258,7.638018774996915,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[42.276415843761725,42.229636997309505,42.182858150857285,42.136079304405065,42.089300457952845,42.04252161150063,41.99574276504841,41.94896391859619,41.90218507214397,41.85540622569175,41.80862737923954,41.76184853278732,41.7150696863351,41.66829083988288,41.62151199343066,41.57473314697844,41.527954300526225,41.481175454074005,41.434396607621785,41.387617761169565,41.340838914717345,41.29406006826513,41.24728122181291,41.20050237536069,41.15372352890847,41.10694468245626,41.06016583600404,41.01338698955182,40.9666081430996,40.91982929664738,40.873050450195166,40.826271603742946,40.779492757290726,40.732713910838505,40.685935064386285,40.63915621793407,40.59237737148185,40.54559852502963,40.49881967857742,40.45204083212519,40.40526198567298,40.35848313922076,40.31170429276854,40.264925446316326,40.218146599864106,40.171367753411886,40.12458890695966,40.07604416785253,40.018669951789036,39.96129573572554,39.90392151966205,39.84654730359855,39.78917308753505,39.731798871471554,39.67442465540805,39.61705043934455,39.55967622328105,39.50230200721755,39.44492779115406,39.387553575090564,39.330179359027056,39.27280514296357,39.21543092690007,39.15805671083656,39.100682494773075,39.04330827870957,38.98593406264607,38.92855984658258,38.87118563051908,38.81381141445558,38.75643719839208,38.699062982328584,38.641688766265084,38.58431455020158,38.52694033413809,38.46956611807459,38.412191902011095,38.354817685947594,38.2974434698841,38.24006925382059,38.1826950377571,38.1253208216936,38.067946605630105,38.010572389566605,37.751358860589264,37.45177746902914,37.15219607746904,36.85261468590893,36.55303329434882,36.253451902788726,35.953870511228615,35.654289119668505,35.354707728108394,35.055126336548284,34.75554494498818,34.45596355342807,34.15638216186796,33.85680077030785,33.55721937874774,33.25763798718764,32.95805659562753,32.65847520406742,32.35889381250731,32.0593124209472,31.7597310293871,31.46014963782699,31.16056824626688,30.860986854706784,30.561405463146656,30.26182407158656,29.96224268002645,29.66266128846634,29.36307989690624,29.063498505346114,28.76391711378602,28.464335722225908,28.1647543306658,27.8651729391057,27.56559154754559,27.266010155985477,26.955880854025096,26.63520365074484,26.314526447464598,25.993849244184343,25.673172040904088,25.352494837623844,25.031817634343575,24.71114043106333,24.390463227783076,24.069786024502818,23.749108821222578,23.4284316179423,23.10775441466206,22.787077211381806,22.466400008101548,22.14572280482131,21.82504560154105,21.504368398260798,21.183691194980536,20.86301399170028,20.542336788420037,20.221659585139783,19.900982381859528,19.58030517857928,19.25962797529901,18.93895077201877,18.618273568738516,18.297596365458258,17.976919162178017,17.656241958897745,17.335564755617504,17.014887552337246,16.694210349056988,16.373533145776747,16.05285594249648,15.732178739216234,15.41150153593598,15.090824332655721,14.770147129375477,14.449469926095222,14.128792722814964,13.80811551953471,13.487438316254451,13.16676111297421,12.846083909693952,12.525406706413698,12.204729503133454,11.981522665408237,11.807051010460556,11.632579355512874,11.458107700565185,11.283636045617513,11.118693230814596,10.967338878868098,10.8159845269216,10.664630174975102,10.513275823028609,10.361921471082104,10.21056711913561,10.059212767189113,9.91892100861521,9.787584679432666,9.65624835025012,9.524912021067568,9.393575691885017,9.262239362702468,9.13346678676975,9.021339491258274,8.909212195746802,8.797084900235332,8.684957604723854,8.572830309212383,8.475701294008548,8.38251192042425,8.289322546839953,8.19613317325565,8.10592775774162,8.023480633210271,7.941033508678912,7.8585863841475625,7.776139259616206,7.693692135084848,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[41.84882392308136,41.80204507662915,41.75526623017693,41.7084873837247,41.66170853727249,41.614929690820276,41.56815084436805,41.521371997915836,41.474593151463615,41.427814305011395,41.381035458559175,41.33425661210696,41.28747776565474,41.24069891920252,41.1939200727503,41.14714122629808,41.10036237984587,41.05358353339365,41.00680468694143,40.96002584048921,40.91324699403699,40.86646814758477,40.819689301132556,40.77291045468033,40.726131608228116,40.679352761775895,40.63257391532368,40.58579506887146,40.53901622241924,40.49223737596702,40.4454585295148,40.391616103853806,40.33424188779031,40.276867671726805,40.21949345566331,40.16211923959981,40.10474502353631,40.04737080747282,39.989996591409316,39.932622375345815,39.87524815928232,39.81787394321882,39.76049972715532,39.70312551109183,39.645751295028326,39.588377078964825,39.53100286290133,39.47362864683783,39.41625443077434,39.35888021471084,39.301505998647336,39.24413178258384,39.186757566520335,39.12938335045684,39.07200913439335,39.01463491832985,38.95726070226635,38.899886486202846,38.84251227013935,38.78513805407586,38.72776383801235,38.67038962194886,38.613015405885356,38.555641189821856,38.49826697375836,38.44089275769487,38.38351854163137,38.32614432556787,38.26877010950437,38.211395893440866,38.15402167737737,38.09664746131388,38.03927324525037,37.98189902918688,37.924524813123384,37.86715059705988,37.80977638099639,37.75240216493289,37.69502794886939,37.63765373280589,37.580279516742394,37.5229053006789,37.46553108461539,37.4081568685519,37.14894333957456,36.84936194801443,36.54978055645434,36.25019916489422,35.95061777333411,35.65103638177401,35.3514549902139,35.05187359865379,34.75229220709368,34.45271081553357,34.153129423973475,33.853548032413364,33.55396664085325,33.254385249293136,32.954803857733026,32.65522246617293,32.35564107461283,32.05605968305271,31.7564782914926,31.456896899932488,31.157315508372392,30.85773411681228,30.55815272525217,30.258571333692075,29.95898994213195,29.65940855057185,29.359827159011736,29.060245767451626,28.76066437589153,28.461082984331405,28.16150159277131,27.8619202012112,27.562338809651088,27.26275741809099,26.96317602653088,26.66359463497077,26.364013243410657,26.064431851850546,25.76485046029045,25.465269068730336,25.16568767717023,24.86610628561013,24.56652489405001,24.26694350248991,23.9673621109298,23.667780719369688,23.36819932780959,23.068617936249467,22.769036544689367,22.469455153129257,22.169873761569143,21.87029237000905,21.570710977389563,21.250033774109305,20.929356570829047,20.608679367548792,20.288002164268548,19.967324960988293,19.64664775770803,19.325970554427794,19.00529335114752,18.68461614786728,18.363938944587023,18.043261741306768,17.722584538026524,17.40190733474625,17.08123013146601,16.760552928185753,16.439875724905498,16.119198521625258,15.798521318344985,15.477844115064745,15.157166911784488,14.83648970850423,14.515812505223987,14.195135301943731,13.874458098663474,13.553780895383216,13.233103692102961,12.912426488822717,12.591749285542463,12.271072082262206,11.950394878981964,11.727188041256746,11.552716386309065,11.378244731361384,11.209862512955837,11.058508161009344,10.90715380906284,10.755799457116343,10.604445105169845,10.453090753223346,10.301736401276854,10.150382049330346,10.003373717372918,9.872037388190368,9.740701059007819,9.609364729825272,9.478028400642726,9.346692071460174,9.215355742277623,9.09641727317109,8.984289977659623,8.872162682148147,8.760035386636673,8.647908091125204,8.53913294507917,8.445943571494874,8.352754197910574,8.259564824326274,8.16637545074198,8.079153993298203,7.996706868766852,7.914259744235502,7.831812619704144,7.749365495172794,7.666918370641436,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[41.42123200240104,41.37445315594882,41.3276743094966,41.28089546304439,41.23411661659216,41.18733777013995,41.14055892368773,41.09378007723551,41.04700123078329,41.000222384331074,40.95344353787885,40.906664691426634,40.859885844974414,40.813106998522194,40.764562255918605,40.70718803985511,40.64981382379162,40.592439607728124,40.53506539166462,40.47769117560112,40.42031695953762,40.36294274347412,40.30556852741063,40.248194311347135,40.19082009528363,40.133445879220126,40.07607166315663,40.01869744709313,39.96132323102964,39.90394901496614,39.846574798902644,39.789200582839136,39.73182636677564,39.67445215071214,39.61707793464865,39.55970371858515,39.50232950252165,39.44495528645815,39.38758107039465,39.33020685433115,39.27283263826766,39.21545842220416,39.15808420614066,39.10070999007716,39.04333577401366,38.98596155795016,38.92858734188667,38.87121312582316,38.81383890975967,38.756464693696174,38.69909047763267,38.64171626156917,38.58434204550568,38.526967829442185,38.46959361337868,38.412219397315184,38.35484518125169,38.29747096518818,38.24009674912469,38.182722533061195,38.12534831699769,38.067974100934194,38.01059988487069,37.95322566880719,37.8958514527437,37.8384772366802,37.781103020616705,37.723728804553204,37.66635458848971,37.60898037242621,37.55160615636271,37.494231940299215,37.436857724235715,37.379483508172214,37.32210929210872,37.26473507604522,37.20736085998172,37.149986643918226,37.092612427854725,37.035238211791224,36.97786399572773,36.92048977966423,36.86311556360073,36.80574134753723,36.546527818559895,36.24694642699977,35.947365035439674,35.64778364387956,35.34820225231945,35.04862086075935,34.74903946919924,34.44945807763913,34.14987668607902,33.85029529451891,33.55071390295881,33.2511325113987,32.95155111983859,32.65196972827847,32.35238833671837,32.052806945158274,31.75322555359816,31.453644162038053,31.154062770477942,30.854481378917825,30.554899987357732,30.25531859579762,29.955737204237508,29.65615581267741,29.356574421117287,29.05699302955719,28.757411637997077,28.457830246436966,28.158248854876874,27.858667463316745,27.55908607175665,27.25950468019654,26.95992328863643,26.66034189707633,26.360760505516218,26.061179113956108,25.761597722395997,25.462016330835887,25.16243493927579,24.862853547715677,24.563272156155563,24.26369076459547,23.964109373035342,23.66452798147525,23.364946589915135,23.065365198355025,22.76578380679493,22.466202415234804,22.166621023674708,21.867039632114597,21.567458240554487,21.267876848994387,20.968295457434273,20.668714065874166,20.369132674314052,20.06955128275394,19.769969891193846,19.470388499633735,19.170807108073625,18.871225716513525,18.5716443249534,18.272062933393304,17.972481541833194,17.67290015027308,17.373318758712983,17.073737367152862,16.774155975592766,16.474574584032652,16.174993192472545,15.864863897473786,15.544186694193515,15.223509490913273,14.902832287633016,14.58215508435276,14.261477881072517,13.94080067779226,13.620123474512004,13.299446271231746,12.97876906795149,12.658091864671247,12.33741466139099,12.016737458110736,11.696060254830494,11.472853417105275,11.301031795097096,11.149677443150596,10.998323091204098,10.846968739257605,10.695614387311101,10.544260035364601,10.392905683418105,10.241551331471607,10.090196979525114,9.956490096948086,9.82515376776554,9.69381743858299,9.56248110940044,9.431144780217895,9.299808451035348,9.17149505508392,9.059367759572448,8.947240464060974,8.835113168549507,8.72298587303803,8.610858577526558,8.50937522256551,8.416185848981204,8.322996475396907,8.229807101812607,8.136617728228307,8.052380228854807,7.9699331043234425,7.887485979792092,7.805038855260742,7.722591730729383,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[40.98811534063741,40.920220214234014,40.85232508783062,40.78793692859697,40.73056271253348,40.673188496469976,40.615814280406475,40.55844006434298,40.50106584827948,40.44369163221598,40.38631741615249,40.328943200088986,40.271568984025485,40.21419476796199,40.156820551898484,40.09944633583499,40.0420721197715,39.984697903707996,39.927323687644495,39.869949471580995,39.8125752555175,39.755201039454,39.6978268233905,39.640452607327006,39.583078391263506,39.525704175200005,39.46832995913651,39.41095574307301,39.35358152700951,39.296207310946016,39.238833094882516,39.181458878819015,39.12408466275552,39.06671044669202,39.00933623062852,38.95196201456503,38.894587798501526,38.837213582438025,38.77983936637453,38.72246515031103,38.66509093424753,38.60771671818404,38.550342502120536,38.492968286057035,38.43559406999354,38.37821985393004,38.32084563786654,38.26347142180304,38.206097205739546,38.14872298967605,38.09134877361255,38.03397455754906,37.97660034148555,37.91922612542206,37.861851909358556,37.804477693295055,37.74710347723156,37.68972926116806,37.63235504510456,37.57498082904107,37.517606612977566,37.46023239691407,37.40285818085057,37.34548396478707,37.28810974872358,37.23073553266008,37.17336131659658,37.11598710053308,37.05861288446958,37.00123866840609,36.94386445234258,36.88649023627909,36.829116020215594,36.77174180415209,36.71436758808859,36.65699337202509,36.5996191559616,36.542244939898104,36.4848707238346,36.4274965077711,36.3701222917076,36.3127480756441,36.25537385958061,36.19799964351711,35.938786114539774,35.63920472297964,35.339623331419546,35.04004193985944,34.740460548299325,34.44087915673923,34.14129776517912,33.84171637361901,33.5421349820589,33.24255359049879,32.94297219893869,32.64339080737857,32.34380941581847,32.04422802425835,31.74464663269825,31.44506524113815,31.14548384957804,30.845902458017925,30.546321066457818,30.246739674897707,29.947158283337608,29.647576891777497,29.347995500217383,29.04841410865729,28.748832717097166,28.449251325537066,28.149669933976956,27.850088542416845,27.550507150856745,27.25092575929662,26.951344367736525,26.651762976176414,26.352181584616304,26.052600193056204,25.753018801496097,25.45343740993598,25.153856018375876,24.85427462681576,24.554693235255662,24.255111843695556,23.95553045213544,23.655949060575345,23.35636766901522,23.056786277455124,22.757204885895014,22.457623494334904,22.158042102774807,21.858460711214683,21.558879319654583,21.259297928094472,20.959716536534362,20.660135144974262,20.360553753414152,20.06097236185404,19.76139097029393,19.46180957873382,19.162228187173724,18.862646795613614,18.5630654040535,18.2634840124934,17.963902620933276,17.66432122937318,17.36473983781307,17.06515844625296,16.765577054692862,16.465995663132738,16.16641427157264,15.866832880012531,15.56725148845242,15.26767009689232,14.968088705332196,14.6685073137721,14.36892592221199,14.069344530651877,13.76976313909178,13.470181747531669,13.170600355971558,12.871018964411448,12.571437572851336,12.27185618129124,11.980837056498485,11.706942443680347,11.43304783086222,11.240846725291833,11.089492373345339,10.93813802139884,10.78678366945234,10.63542931750585,10.484074965559344,10.332720613612846,10.181366261666348,10.040942805705791,9.909606476523248,9.778270147340692,9.646933818158146,9.515597488975597,9.384261159793045,9.252924830610501,9.134445541485269,9.022318245973793,8.91019095046232,8.798063654950846,8.68593635943938,8.573809063927905,8.47961750005183,8.386428126467534,8.29323875288323,8.200049379298934,8.108053588942745,8.02560646441139,7.943159339880038,7.8607122153486735,7.778265090817324,7.695817966285972,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[40.52633908774905,40.45844396134565,40.390548834942265,40.322653708538866,40.25475858213547,40.18686345573208,40.118968329328695,40.051073202925295,39.98317807652191,39.91528295011851,39.847387823715124,39.779492697311724,39.71159757090833,39.64370244450494,39.57580731810155,39.50791219169815,39.44001706529476,39.37212193889137,39.30422681248798,39.23633168608458,39.17720398028493,39.11982976422143,39.062455548157935,39.005081332094434,38.94770711603094,38.89033289996744,38.83295868390394,38.77558446784044,38.718210251776945,38.66083603571345,38.603461819649944,38.54608760358645,38.48871338752295,38.431339171459456,38.373964955395955,38.316590739332455,38.25921652326896,38.20184230720546,38.14446809114196,38.087093875078466,38.029719659014965,37.972345442951465,37.914971226887964,37.85759701082447,37.80022279476097,37.742848578697476,37.685474362633975,37.628100146570475,37.57072593050698,37.51335171444348,37.45597749837998,37.398603282316486,37.341229066252986,37.283854850189485,37.22648063412599,37.16910641806249,37.11173220199899,37.054357985935496,36.996983769872,36.939609553808495,36.882235337745,36.8248611216815,36.767486905618,36.71011268955451,36.652738473491006,36.59536425742751,36.53799004136401,36.48061582530052,36.42324160923702,36.36586739317352,36.30849317711002,36.25111896104652,36.19374474498302,36.13637052891953,36.07899631285602,36.02162209679253,35.96424788072903,35.906873664665525,35.84949944860203,35.79212523253853,35.73475101647503,35.67737680041154,35.620002584348036,35.56262836828454,35.3034148393072,35.00383344774708,34.70425205618698,34.40467066462687,34.10508927306675,33.805507881506664,33.505926489946546,33.206345098386436,32.906763706826325,32.607182315266215,32.30760092370612,32.00801953214601,31.708438140585898,31.408856749025787,31.10927535746568,30.80969396590558,30.51011257434547,30.21053118278536,29.91094979122525,29.61136839966514,29.31178700810504,29.01220561654493,28.71262422498482,28.41304283342472,28.113461441864594,27.813880050304498,27.514298658744387,27.214717267184277,26.91513587562418,26.615554484064052,26.31597309250396,26.016391700943846,25.716810309383735,25.417228917823635,25.11764752626353,24.818066134703415,24.518484743143308,24.218903351583194,23.919321960023094,23.619740568462987,23.32015917690287,23.02057778534278,22.720996393782652,22.42141500222256,22.12183361066245,21.822252219102335,21.522670827542235,21.22308943598211,20.923508044422015,20.623926652861904,20.324345261301794,20.024763869741697,19.725182478181583,19.425601086621477,19.126019695061363,18.826438303501252,18.526856911941156,18.227275520381042,17.927694128820935,17.628112737260835,17.32853134570071,17.028949954140614,16.729368562580504,16.42978717102039,16.151611439836937,15.877716827018789,15.603822214200662,15.329927601382522,15.056032988564382,14.782138375746255,14.508243762928103,14.234349150109978,13.960454537291836,13.686559924473697,13.412665311655571,13.138770698837432,12.86487608601929,12.590981473201152,12.317086860383013,12.043192247564885,11.769297634746746,11.495403021928608,11.221508409110479,11.029307303540092,10.8779529515936,10.726598599647101,10.575244247700603,10.42388989575411,10.272535543807606,10.12539551446351,9.99405918528096,9.862722856098411,9.731386526915868,9.600050197733314,9.468713868550767,9.337377539368216,9.209523323398095,9.097396027886626,8.985268732375152,8.87314143686368,8.761014141352206,8.648886845840732,8.543049151122464,8.449859777538165,8.356670403953864,8.263481030369569,8.170291656785263,8.081279824499344,7.998832699967987,7.91638557543663,7.833938450905278,7.751491326373914,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[40.06456283486065,39.99666770845725,39.92877258205387,39.86087745565047,39.792982329247074,39.72508720284368,39.65719207644029,39.589296950036896,39.52140182363351,39.45350669723011,39.385611570826725,39.317716444423326,39.24982131801993,39.18192619161654,39.11403106521315,39.046135938809755,38.97824081240636,38.91034568600297,38.84245055959958,38.774555433196184,38.70666030679279,38.6387651803894,38.570870053986006,38.50297492758261,38.435079801179214,38.36718467477583,38.299289548372435,38.23139442196904,38.16349929556564,38.09560416916226,38.027709042758865,37.95981391635547,37.89191878995208,37.82402366354869,37.75612853714529,37.6882334107419,37.623845248036346,37.566471031972846,37.509096815909345,37.45172259984585,37.39434838378235,37.33697416771886,37.27959995165535,37.222225735591856,37.16485151952836,37.10747730346486,37.05010308740136,36.99272887133786,36.93535465527437,36.877980439210866,36.820606223147365,36.76323200708387,36.70585779102037,36.64848357495688,36.59110935889338,36.53373514282988,36.476360926766375,36.41898671070288,36.36161249463939,36.30423827857588,36.24686406251239,36.189489846448886,36.132115630385385,36.07474141432189,36.0173671982584,35.9599929821949,35.9026187661314,35.8452445500679,35.7878703340044,35.7304961179409,35.6731219018774,35.61574768581391,35.558373469750414,35.50099925368691,35.44362503762341,35.38625082155991,35.32887660549642,35.27150238943292,35.21412817336942,35.156753957305924,35.09937974124242,35.04200552517892,34.98463130911543,34.92725709305193,34.66804356407459,34.36846217251446,34.068880780954366,33.769299389394256,33.469717997834145,33.17013660627404,32.87055521471393,32.57097382315382,32.27139243159372,31.9718110400336,31.67222964847351,31.372648256913394,31.073066865353287,30.773485473793173,30.473904082233062,30.17432269067297,29.874741299112856,29.575159907552745,29.275578515992635,28.975997124432524,28.676415732872425,28.37683434131231,28.077252949752207,27.777671558192104,27.47809016663198,27.178508775071883,26.878927383511773,26.579345991951662,26.279764600391566,25.98018320883144,25.68060181727134,25.38102042571123,25.081439034151117,24.78185764259102,24.482276251030918,24.1826948594708,23.883113467910693,23.58353207635058,23.28395068479048,22.984369293230376,22.68478790167026,22.385206510110166,22.08562511855004,21.78604372698994,21.48646233542983,21.18688094386972,20.887299552309624,20.59628043599349,20.322385823175363,20.048491210357223,19.774596597539084,19.500701984720955,19.22680737190282,18.95291275908468,18.67901814626654,18.4051235334484,18.13122892063027,17.857334307812135,17.58343969499399,17.309545082175866,17.035650469357716,16.761755856539587,16.487861243721447,16.213966630903307,15.940072018085182,15.666177405267034,15.392282792448906,15.118388179630767,14.844493566812627,14.5705989539945,14.296704341176348,14.022809728358222,13.74891511554008,13.475020502721941,13.201125889903816,12.927231277085676,12.653336664267535,12.379442051449397,12.105547438631257,11.83165282581313,11.55775821299499,11.283863600176852,11.009968987358723,10.817767881788336,10.666413529841845,10.515059177895345,10.363704825948846,10.212350474002355,10.078511894038666,9.947175564856117,9.81583923567357,9.68450290649102,9.553166577308476,9.421830248125922,9.290493918943376,9.172473809799442,9.060346514287968,8.948219218776499,8.836091923265025,8.723964627753553,8.611837332242079,8.513291428608785,8.42010205502449,8.326912681440188,8.23372330785589,8.140533934271593,8.054506060055926,7.972058935524575,7.889611810993218,7.80716468646186,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[39.60278658197225,39.53489145556886,39.46699632916547,39.399101202762076,39.33120607635868,39.26331094995529,39.1954158235519,39.127520697148505,39.059625570745105,38.99173044434171,38.92383531793832,38.85594019153493,38.788045065131534,38.72014993872814,38.65225481232475,38.584359685921356,38.51646455951797,38.44856943311457,38.38067430671118,38.312779180307786,38.24488405390439,38.176988927501,38.109093801097615,38.041198674694215,37.97330354829082,37.90540842188744,37.83751329548404,37.769618169080644,37.701723042677244,37.63382791627386,37.565932789870466,37.49803766346707,37.43014253706368,37.36224741066029,37.294352284256895,37.2264571578535,37.1585620314501,37.09066690504672,37.02277177864332,36.95487665223993,36.88698152583654,36.81908639943315,36.75119127302975,36.683296146626354,36.61540102022296,36.547505893819576,36.47961076741618,36.41171564101278,36.34382051460939,36.275925388206005,36.208030261802605,36.14013513539921,36.07224000899582,36.013112299724256,35.95573808366076,35.898363867597254,35.84098965153376,35.78361543547027,35.72624121940677,35.668867003343266,35.61149278727977,35.554118571216264,35.49674435515277,35.43937013908928,35.38199592302578,35.324621706962276,35.26724749089878,35.20987327483528,35.15249905877179,35.09512484270829,35.03775062664479,34.98037641058129,34.92300219451779,34.86562797845429,34.80825376239079,34.7508795463273,34.6935053302638,34.636131114200296,34.5787568981368,34.5213826820733,34.4640084660098,34.40663424994631,34.349260033882814,34.291885817819306,34.03267228884197,33.73309089728185,33.43350950572175,33.133928114161634,32.83434672260152,32.53476533104143,32.23518393948132,31.935602547921206,31.636021156361096,31.336439764800986,31.03685837324089,30.737276981680775,30.437695590120672,30.138114198560558,29.838532807000448,29.53895141544035,29.239370023880237,28.939788632320127,28.640207240760017,28.340625849199906,28.04104445763981,27.741463066079696,27.441881674519585,27.14230028295949,26.842718891399365,26.54313749983927,26.243556108279158,25.943974716719044,25.644393325158948,25.344811933598823,25.045230542038727,24.76705481933192,24.493160206513785,24.219265593695656,23.94537098087752,23.67147636805938,23.39758175524124,23.1236871424231,22.849792529604972,22.575897916786836,22.302003303968696,22.02810869115057,21.754214078332417,21.48031946551429,21.206424852696152,20.932530239878012,20.658635627059883,20.384741014241733,20.110846401423608,19.836951788605468,19.56305717578733,19.2891625629692,19.015267950151063,18.74137333733292,18.46747872451478,18.193584111696644,17.919689498878515,17.645794886060376,17.371900273242236,17.09800566042411,16.82411104760596,16.550216434787828,16.27632182196969,16.002427209151552,15.728532596333423,15.454637983515275,15.180743370697147,14.90684875787901,14.632954145060868,14.359059532242743,14.08516491942459,13.811270306606463,13.537375693788324,13.263481080970186,12.989586468152059,12.715691855333917,12.44179724251578,12.167902629697638,11.894008016879502,11.620113404061374,11.346218791243231,11.072324178425097,10.798429565606968,10.606228460036581,10.454874108090088,10.303519756143588,10.16296460279637,10.031628273613826,9.900291944431272,9.768955615248723,9.637619286066176,9.506282956883625,9.374946627701082,9.24755159171226,9.135424296200787,9.023297000689315,8.91116970517784,8.799042409666372,8.686915114154898,8.576723079679411,8.48353370609511,8.39034433251081,8.297154958926514,8.203965585342214,8.110776211757914,8.027732295612536,7.945285171081171,7.862838046549821,7.780390922018463,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[39.14101032908389,39.07311520268049,39.005220076277105,38.937324949873705,38.86942982347032,38.80153469706693,38.733639570663534,38.665744444260135,38.59784931785675,38.52995419145335,38.46205906504996,38.394163938646564,38.32626881224317,38.25837368583978,38.19047855943639,38.12258343303299,38.0546883066296,37.986793180226215,37.91889805382282,37.85100292741942,37.78310780101603,37.71521267461264,37.647317548209244,37.57942242180585,37.51152729540246,37.44363216899907,37.375737042595674,37.30784191619228,37.23994678978889,37.172051663385496,37.1041565369821,37.03626141057871,36.96836628417532,36.900471157771925,36.83257603136853,36.76468090496514,36.69678577856175,36.628890652158354,36.56099552575496,36.49310039935156,36.425205272948176,36.35731014654478,36.28941502014139,36.22151989373799,36.153624767334605,36.085729640931206,36.01783451452782,35.94993938812442,35.882044261721035,35.81414913531764,35.74625400891425,35.67835888251085,35.61046375610746,35.542568629704064,35.47467350330068,35.40677837689728,35.338883250493886,35.27098812409049,35.2030929976871,35.13519787128371,35.067302744880315,34.99940761847692,34.93151249207352,34.86361736567014,34.79572223926675,34.72782711286335,34.65993198645996,34.59203686005657,34.524141733653174,34.45975356747572,34.40237935141222,34.34500513534872,34.28763091928523,34.23025670322173,34.172882487158226,34.11550827109473,34.05813405503123,34.00075983896773,33.94338562290424,33.88601140684074,33.82863719077724,33.77126297471374,33.71388875865024,33.65651454258675,33.39730101360941,33.09771962204928,32.79813823048919,32.498556838929076,32.198975447368966,31.899394055808862,31.599812664248756,31.300231272688645,31.00064988112853,30.70106848956842,30.401487098008328,30.10190570644821,29.802324314888104,29.502742923327993,29.211723815488504,28.937829202670383,28.66393458985224,28.3900399770341,28.11614536421596,27.84225075139782,27.568356138579695,27.294461525761555,27.020566912943416,26.746672300125287,26.472777687307136,26.19888307448901,25.92498846167087,25.65109384885273,25.377199236034603,25.103304623216452,24.829410010398327,24.555515397580187,24.281620784762048,24.00772617194392,23.733831559125782,23.459936946307643,23.186042333489503,22.91214772067136,22.63825310785323,22.3643584950351,22.090463882216955,21.816569269398833,21.54267465658068,21.268780043762554,20.994885430944414,20.720990818126275,20.447096205308146,20.173201592489995,19.89930697967187,19.625412366853727,19.35151775403559,19.07762314121746,18.803728528399322,18.529833915581182,18.255939302763043,17.982044689944907,17.708150077126778,17.434255464308638,17.1603608514905,16.886466238672373,16.61257162585422,16.33867701303609,16.064782400217954,15.790887787399814,15.516993174581687,15.243098561763539,14.96920394894541,14.695309336127272,14.421414723309132,14.147520110491005,13.873625497672853,13.599730884854726,13.325836272036588,13.051941659218446,12.77804704640032,12.504152433582181,12.230257820764042,11.956363207945902,11.682468595127762,11.408573982309635,11.134679369491495,10.860784756673358,10.586890143855229,10.394689038284842,10.247417311554091,10.116080982371537,9.98474465318899,9.853408324006447,9.722071994823892,9.590735665641343,9.459399336458796,9.328063007276246,9.21050207811362,9.098374782602143,8.986247487090672,8.874120191579198,8.761992896067724,8.649865600556256,8.546965357165744,8.453775983581444,8.360586609997144,8.267397236412844,8.174207862828549,8.083405655700483,8.000958531169125,7.9185114066377755,7.836064282106411,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[38.67434617143531,38.606451045031925,38.538555918628525,38.47066079222514,38.40276566582175,38.33487053941835,38.266975413014954,38.19908028661157,38.13118516020817,38.06329003380478,37.99539490740138,37.92749978099799,37.8596046545946,37.791709528191205,37.72381440178781,37.65591927538442,37.58802414898103,37.520129022577635,37.45223389617424,37.38433876977085,37.31644364336746,37.248548516964064,37.18065339056067,37.11275826415728,37.044863137753886,36.97696801135049,36.9090728849471,36.84117775854371,36.77328263214031,36.70538750573692,36.63749237933353,36.56959725293014,36.501702126526745,36.43380700012335,36.36591187371995,36.29801674731657,36.230121620913174,36.16222649450978,36.09433136810638,36.026436241702996,35.958541115299596,35.89064598889621,35.82275086249281,35.75485573608942,35.686960609686025,35.61906548328264,35.55117035687924,35.48327523047585,35.415380104072455,35.34748497766906,35.27958985126567,35.21169472486228,35.143799598458884,35.07590447205549,35.0080093456521,34.940114219248706,34.87221909284531,34.80432396644191,34.73642884003853,34.668533713635135,34.60063858723174,34.53274346082834,34.46484833442495,34.396953208021564,34.32905808161817,34.26116295521477,34.193267828811386,34.12537270240799,34.0574775760046,33.9895824496012,33.921687323197816,33.85379219679442,33.78589707039103,33.71800194398764,33.650106817584245,33.58221169118085,33.51431656477746,33.44642143837407,33.378526311970674,33.31063118556728,33.24273605916389,33.17484093276049,33.09898504738438,33.02153702189152,32.80470190803966,32.55998937651598,32.290958473641254,32.017063860823114,31.743169248004975,31.46927463518685,31.19538002236871,30.92148540955057,30.64759079673243,30.37369618391429,30.099801571096165,29.825906958278026,29.552012345459886,29.278117732641743,29.004223119823603,28.73032850700548,28.456433894187338,28.1825392813692,27.90864466855106,27.63475005573292,27.360855442914794,27.086960830096658,26.813066217278514,26.539171604460385,26.265276991642235,25.99138237882411,25.717487766005974,25.44359315318783,25.1696985403697,24.895803927551547,24.621909314733426,24.34801470191529,24.07412008909715,23.80022547627902,23.526330863460885,23.25243625064274,22.978541637824602,22.704647025006462,22.430752412188333,22.156857799370197,21.882963186552058,21.609068573733932,21.335173960915782,21.06127934809765,20.78738473527951,20.51349012246137,20.239595509643244,19.96570089682509,19.691806284006965,19.417911671188826,19.144017058370686,18.87012244555256,18.59622783273442,18.32233321991628,18.04843860709814,17.774543994280002,17.500649381461873,17.226754768643737,16.952860155825597,16.678965543007468,16.405070930189318,16.13117631737119,15.857281704553051,15.58338709173491,15.309492478916784,15.035597866098636,14.761703253280508,14.487808640462369,14.213914027644229,13.940019414826104,13.666124802007952,13.392230189189824,13.118335576371685,12.844440963553545,12.570546350735418,12.29665173791728,12.02275712509914,11.748862512281,11.474967899462861,11.201073286644734,10.927178673826596,10.653284061008454,10.379389448190327,10.200533691129243,10.0691973619467,9.937861032764147,9.806524703581598,9.675188374399054,9.5438520452165,9.412515716033953,9.285579860026436,9.173452564514962,9.061325269003493,8.949197973492016,8.837070677980545,8.724943382469071,8.612816086957597,8.51720763465207,8.42401826106777,8.33082888748347,8.23763951389917,8.14445014031487,8.056631891257073,7.974184766725715,7.891737642194357,7.8092905176630065,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[38.17224472614748,38.10434959974409,38.0364544733407,37.968559346937305,37.90066422053392,37.83276909413052,37.76487396772713,37.696978841323734,37.62908371492034,37.56118858851695,37.493293462113556,37.42539833571016,37.35750320930676,37.28960808290338,37.221712956499985,37.153817830096585,37.08592270369319,37.01802757728981,36.95013245088641,36.882237324483015,36.81434219807962,36.746447071676236,36.67855194527284,36.610656818869444,36.54276169246605,36.47486656606266,36.406971439659266,36.33907631325588,36.27118118685248,36.20328606044909,36.1353909340457,36.0674958076423,35.99960068123891,35.93170555483552,35.863810428432124,35.79591530202873,35.72802017562534,35.660125049221946,35.59222992281856,35.52433479641516,35.456439670011775,35.388544543608376,35.32064941720499,35.25275429080159,35.184859164398205,35.116964037994805,35.04906891159142,34.98117378518802,34.91327865878463,34.84538353238124,34.77748840597784,34.70959327957445,34.64169815317105,34.57380302676766,34.50590790036428,34.43801277396088,34.370117647557485,34.30222252115409,34.2343273947507,34.16643226834731,34.098537141943915,34.03064201554052,33.96274688913712,33.89485176273374,33.826956636330344,33.75587720570737,33.678429180214515,33.60098115472165,33.52353312922879,33.446085103735925,33.36863707824307,33.29118905275021,33.21374102725735,33.136293001764486,33.05884497627163,32.981396950778766,32.90394892528591,32.82650089979305,32.74905287430018,32.67160484880733,32.594156823314464,32.51670879782161,32.439260772328744,32.36181274683589,32.14497763298402,31.90026510146035,31.65555256993669,31.410840038413028,31.166127506889364,30.921414975365707,30.67670244384204,30.431989912318375,30.187277380794708,29.942564849271044,29.697852317747387,29.453139786223723,29.208427254700055,28.96371472317639,28.719002191652727,28.47428966012907,28.229577128605406,27.98486459708174,27.730424718943667,27.456530106125527,27.1826354933074,26.908740880489262,26.634846267671122,26.360951654852993,26.087057042034843,25.813162429216717,25.539267816398578,25.265373203580438,24.99147859076231,24.717583977944155,24.443689365126033,24.169794752307894,23.895900139489754,23.62200552667163,23.34811091385349,23.07421630103535,22.800321688217206,22.52642707539907,22.25253246258094,21.9786378497628,21.704743236944665,21.430848624126536,21.156954011308386,20.88305939849026,20.609164785672117,20.33527017285398,20.061375560035852,19.787480947217702,19.513586334399573,19.239691721581433,18.965797108763297,18.691902495945165,18.41800788312703,18.14411327030889,17.87021865749075,17.59632404467261,17.32242943185448,17.048534819036345,16.774640206218205,16.500745593400076,16.226850980581926,15.952956367763798,15.679061754945659,15.40516714212752,15.131272529309394,14.857377916491243,14.583483303673116,14.309588690854977,14.035694078036837,13.761799465218711,13.48790485240056,13.214010239582432,12.940115626764293,12.666221013946153,12.392326401128026,12.118431788309886,11.844537175491748,11.570642562673607,11.296747949855467,11.022853337037342,10.748958724219202,10.475064111401062,10.201169498582935,10.022313741521847,9.890977412339305,9.759641083156753,9.628304753974206,9.49696842479166,9.365632095609108,9.248530346427783,9.136403050916309,9.024275755404837,8.912148459893366,8.800021164381889,8.687893868870418,8.580639285722691,8.487449912138391,8.394260538554095,8.301071164969795,8.207881791385494,8.114692417801194,8.029858126813654,7.947411002282303,7.864963877750946,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[37.6701432808597,37.6022481544563,37.53435302805291,37.46645790164951,37.39856277524613,37.330667648842734,37.26277252243934,37.19487739603595,37.126982269632556,37.05908714322916,36.991192016825764,36.92329689042237,36.855401764018985,36.78750663761559,36.7196115112122,36.65171638480881,36.583821258405415,36.51592613200202,36.44803100559863,36.38013587919523,36.31224075279184,36.244345626388444,36.17645049998506,36.10855537358166,36.040660247178266,35.97276512077488,35.90486999437149,35.83697486796809,35.769079741564695,35.70118461516131,35.63328948875791,35.56539436235452,35.497499235951125,35.42960410954773,35.36170898314434,35.29381385674095,35.225918730337554,35.15802360393416,35.09012847753077,35.022233351127376,34.95433822472398,34.88644309832059,34.8185479719172,34.7506528455138,34.68275771911041,34.61486259270702,34.54696746630363,34.47907233990023,34.41117721349684,34.33532133853755,34.25787331304468,34.18042528755183,34.102977262058964,34.0255292365661,33.948081211073244,33.87063318558038,33.79318516008752,33.715737134594654,33.6382891091018,33.56084108360894,33.48339305811608,33.40594503262322,33.32849700713036,33.2510489816375,33.17360095614464,33.096152930651776,33.01870490515892,32.941256879666064,32.8638088541732,32.78636082868034,32.70891280318748,32.631464777694625,32.55401675220176,32.4765687267089,32.399120701216034,32.32167267572318,32.24422465023032,32.16677662473746,32.089328599244595,32.01188057375174,31.934432548258876,31.85698452276602,31.779536497273156,31.7020884717803,31.485253357928435,31.24054082640476,30.995828294881104,30.75111576335744,30.506403231833772,30.26169070031012,30.01697816878645,29.772265637262784,29.52755310573912,29.282840574215456,29.0381280426918,28.793415511168135,28.548702979644467,28.303990448120803,28.05927791659714,27.814565385073482,27.56985285354982,27.32514032202615,27.080427790502483,26.83571525897882,26.591002727455162,26.3462901959315,26.101577664407834,25.856865132884177,25.612152601360503,25.367440069836846,25.122727538313182,24.878015006789514,24.63330247526586,24.388589943742183,24.143877412218526,23.899164880694862,23.654452349171198,23.40973981764754,23.165027286123877,22.895996351427968,22.62210173860983,22.34820712579169,22.07431251297356,21.800417900155427,21.526523287337284,21.25262867451916,20.978734061701005,20.70483944888288,20.43094483606474,20.1570502232466,19.883155610428474,19.60926099761032,19.335366384792195,19.061471771974055,18.787577159155916,18.51368254633779,18.23978793351965,17.96589332070151,17.69199870788337,17.41810409506523,17.144209482247103,16.870314869428967,16.596420256610827,16.3225256437927,16.048631030974548,15.774736418156419,15.50084180533828,15.226947192520141,14.953052579702014,14.679157966883864,14.405263354065738,14.131368741247599,13.857474128429459,13.583579515611332,13.30968490279318,13.035790289975054,12.761895677156913,12.488001064338773,12.214106451520648,11.940211838702508,11.666317225884367,11.392422613066229,11.118528000248089,10.844633387429962,10.570738774611822,10.296844161793684,10.022949548975555,9.844093791914469,9.712757462731926,9.581421133549373,9.450084804366824,9.323608128340615,9.211480832829134,9.099353537317667,8.987226241806194,8.875098946294719,8.76297165078325,8.650844355271772,8.550881563209025,8.457692189624725,8.364502816040424,8.27131344245613,8.178124068871828,8.085531486901601,8.00308436237025,7.920637237838894,7.838190113307543,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[37.16804183557186,37.10014670916848,37.03225158276508,36.96435645636169,36.8964613299583,36.8285662035549,36.76067107715151,36.69277595074812,36.62488082434473,36.556985697941336,36.489090571537936,36.42119544513455,36.35330031873115,36.285405192327765,36.217510065924365,36.14961493952097,36.08171981311758,36.01382468671419,35.945929560310795,35.8780344339074,35.81013930750401,35.74224418110062,35.674349054697224,35.60645392829383,35.53855880189044,35.470663675487046,35.40276854908365,35.33487342268026,35.26697829627687,35.199083169873475,35.13118804347008,35.06329291706669,34.99221349686053,34.914765471367666,34.83731744587481,34.759869420381946,34.68242139488909,34.60497336939623,34.52752534390336,34.45007731841051,34.37262929291765,34.29518126742479,34.217733241931924,34.14028521643907,34.06283719094621,33.98538916545335,33.90794113996049,33.83049311446762,33.753045088974766,33.67559706348191,33.598149037989046,33.52070101249619,33.443252987003326,33.36580496151047,33.28835693601761,33.21090891052474,33.13346088503188,33.05601285953902,32.97856483404616,32.901116808553304,32.82366878306044,32.746220757567585,32.66877273207472,32.591324706581865,32.513876681089,32.436428655596146,32.35898063010328,32.281532604610426,32.20408457911756,32.1266365536247,32.04918852813184,31.971740502638987,31.894292477146124,31.81684445165326,31.7393964261604,31.66194840066754,31.584500375174684,31.50705234968182,31.429604324188958,31.3521562986961,31.274708273203238,31.197260247710382,31.11981222221752,31.042364196724662,30.825529082872798,30.580816551349123,30.336104019825466,30.091391488301802,29.846678956778135,29.60196642525448,29.357253893730814,29.112541362207146,28.867828830683482,28.62311629915982,28.378403767636165,28.133691236112497,27.88897870458883,27.644266173065166,27.3995536415415,27.154841110017845,26.91012857849418,26.665416046970513,26.420703515446846,26.175990983923185,25.931278452399525,25.686565920875864,25.441853389352197,25.19714085782854,24.95242832630486,24.70771579478121,24.46300326325754,24.21829073173388,23.973578200210223,23.728865668686545,23.48415313716289,23.239440605639224,22.99472807411556,22.750015542591903,22.50530301106824,22.260590479544575,22.015877948020908,21.77116541649724,21.526452884973587,21.281740353449923,21.037027821926255,20.792315290402605,20.547602758878927,20.30289022735527,20.058177695831606,19.81346516430794,19.568752632784285,19.324040101260607,19.079327569736954,18.834615038213286,18.58990250668962,18.335462596730395,18.06156798391226,17.787673371094115,17.513778758275976,17.23988414545784,16.96598953263971,16.69209491982157,16.41820030700343,16.144305694185306,15.870411081367154,15.596516468549027,15.322621855730887,15.048727242912747,14.774832630094622,14.500938017276471,14.227043404458346,13.953148791640206,13.679254178822065,13.40535956600394,13.131464953185787,12.857570340367658,12.58367572754952,12.309781114731381,12.035886501913254,11.761991889095114,11.488097276276974,11.214202663458837,10.940308050640695,10.66641343782257,10.39251882500443,10.118624212186292,9.844729599368163,9.665873842307077,9.534537513124533,9.403201183941983,9.286558614741955,9.174431319230486,9.062304023719006,8.950176728207541,8.838049432696067,8.725922137184591,8.614313214279651,8.521123840695346,8.42793446711105,8.334745093526749,8.24155571994245,8.148366346358154,8.058757722458184,7.976310597926827,7.893863473395476,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[36.665940390284035,36.59804526388064,36.53015013747725,36.46225501107386,36.39435988467047,36.32646475826707,36.25856963186368,36.19067450546029,36.122779379056894,36.05488425265351,35.98698912625011,35.919093999846716,35.85119887344332,35.78330374703993,35.71540862063654,35.647513494233145,35.57165762969065,35.4942096041978,35.416761578704936,35.33931355321207,35.261865527719216,35.18441750222635,35.1069694767335,35.02952145124063,34.95207342574777,34.874625400254914,34.79717737476206,34.719729349269194,34.64228132377633,34.564833298283475,34.48738527279061,34.409937247297755,34.33248922180489,34.25504119631203,34.17759317081917,34.10014514532631,34.02269711983345,33.94524909434059,33.867801068847726,33.79035304335487,33.71290501786201,33.63545699236915,33.55800896687629,33.48056094138343,33.403112915890574,33.32566489039771,33.248216864904855,33.170768839411984,33.09332081391913,33.01587278842627,32.93842476293341,32.86097673744055,32.78352871194768,32.706080686454825,32.62863266096197,32.551184635469106,32.47373660997625,32.396288584483386,32.31884055899053,32.241392533497674,32.1639445080048,32.08649648251195,32.009048457019084,31.931600431526228,31.854152406033368,31.776704380540505,31.69925635504765,31.62180832955479,31.54436030406193,31.466912278569065,31.389464253076206,31.31201622758335,31.234568202090486,31.157120176597626,31.079672151104766,31.002224125611903,30.924776100119047,30.847328074626184,30.769880049133327,30.692432023640464,30.6149839981476,30.537535972654744,30.46008794716188,30.382639921669025,30.16580480781716,29.921092276293486,29.67637974476983,29.431667213246165,29.186954681722497,28.942242150198844,28.69752961867518,28.45281708715151,28.208104555627845,27.96339202410418,27.718679492580527,27.47396696105686,27.229254429533196,26.984541898009528,26.739829366485864,26.49511683496221,26.250404303438543,26.005691771914876,25.76097924039121,25.516266708867544,25.27155417734389,25.026841645820223,24.78212911429656,24.537416582772906,24.292704051249228,24.04799151972557,23.803278988201907,23.558566456678243,23.31385392515459,23.069141393630908,22.824428862107254,22.579716330583587,22.335003799059926,22.09029126753627,21.845578736012605,21.600866204488938,21.35615367296527,21.111441141441603,20.86672860991795,20.622016078394285,20.377303546870618,20.132591015346968,19.88787848382329,19.643165952299633,19.39845342077597,19.153740889252305,18.909028357728648,18.66431582620497,18.419603294681316,18.17489076315765,17.93017823163398,17.685465700110328,17.44075316858666,17.196040637062996,16.951328105539332,16.706615574015665,16.46190304249201,16.217190510968344,15.97247797944468,15.727765447921023,15.483052916397344,15.238340384873691,14.993627853350024,14.74891532182636,14.504202790302704,14.25949025877903,14.014777727255376,13.770065195731709,13.501034229214673,13.227139616396546,12.953245003578393,12.679350390760266,12.405455777942128,12.131561165123987,11.857666552305862,11.583771939487722,11.309877326669582,11.035982713851443,10.762088101033303,10.488193488215177,10.214298875397036,9.940404262578898,9.666509649760771,9.487653892699685,9.361636396654776,9.249509101143301,9.137381805631827,9.02525451012036,8.913127214608881,8.800999919097414,8.688872623585938,8.584555491765972,8.491366118181675,8.398176744597372,8.304987371013075,8.211797997428775,8.118608623844475,8.031983958014774,7.949536833483415,7.867089708952058,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[36.15977885053869,36.07450354964182,35.99444644526263,35.91699841976978,35.83955039427691,35.76210236878406,35.6846543432912,35.60720631779834,35.52975829230547,35.45231026681262,35.374862241319754,35.2974142158269,35.219966190334034,35.14251816484118,35.065070139348315,34.98762211385546,34.910174088362595,34.83272606286974,34.755278037376875,34.67783001188401,34.600381986391156,34.52293396089829,34.445485935405436,34.36803790991257,34.29058988441972,34.21314185892685,34.13569383343399,34.058245807941134,33.98079778244827,33.903349756955414,33.82590173146255,33.748453705969695,33.67100568047683,33.59355765498397,33.51610962949111,33.43866160399825,33.36121357850539,33.28376555301253,33.20631752751967,33.12886950202681,33.05142147653395,32.97397345104109,32.89652542554823,32.81907740005537,32.741629374562514,32.66418134906965,32.58673332357679,32.509285298083924,32.43183727259107,32.35438924709821,32.276941221605355,32.199493196112485,32.12204517061963,32.04459714512677,31.96714911963391,31.88970109414105,31.812253068648182,31.734805043155326,31.65735701766247,31.579908992169607,31.50246096667675,31.42501294118388,31.347564915691027,31.270116890198167,31.192668864705308,31.115220839212444,31.037772813719588,30.96032478822673,30.882876762733865,30.805428737241005,30.727980711748145,30.65053268625529,30.573084660762426,30.495636635269562,30.418188609776703,30.340740584283843,30.263292558790987,30.185844533298123,30.108396507805264,30.030948482312404,29.95350045681954,29.876052431326684,29.79860440583382,29.72115638034096,29.53120603456503,29.30262431065506,29.057911779131402,28.813199247607738,28.56848671608407,28.323774184560417,28.079061653036753,27.834349121513085,27.589636589989425,27.344924058465757,27.100211526942104,26.855498995418436,26.61078646389477,26.366073932371105,26.121361400847437,25.876648869323784,25.631936337800116,25.387223806276452,25.14251127475279,24.897798743229117,24.653086211705467,24.408373680181796,24.163661148658132,23.91894861713448,23.6742360856108,23.429523554087144,23.18481102256348,22.940098491039816,22.69538595951616,22.450673427992484,22.205960896468827,21.961248364945163,21.7165358334215,21.471823301897846,21.227110770374175,20.98239823885051,20.737685707326843,20.492973175803183,20.248260644279526,20.00354811275586,19.758835581232194,19.514123049708537,19.269410518184863,19.02469798666121,18.779985455137542,18.535272923613874,18.29056039209022,18.045847860566543,17.80113532904289,17.556422797519225,17.311710265995558,17.066997734471904,16.822285202948237,16.57757267142457,16.332860139900905,16.088147608377238,15.843435076853584,15.598722545329919,15.354010013806253,15.109297482282598,14.864584950758921,14.619872419235264,14.3751598877116,14.130447356187933,13.88573482466428,13.641022293140605,13.396309761616948,13.151597230093284,12.906884698569616,12.662172167045963,12.417459635522285,12.172747103998631,11.928034572474964,11.6833220409513,11.438609509427645,11.193896977903977,10.949184446380313,10.704471914856645,10.45975938333298,10.215046851809326,9.970334320285659,9.725621788761995,9.48090925723834,9.324586883056128,9.212459587544659,9.100332292033185,8.988204996521713,8.876077701010244,8.763950405498763,8.651823109987296,8.554797769252307,8.461608395668007,8.36841902208371,8.275229648499405,8.18204027491511,8.088850901330808,8.005210193571363,7.922763069040013,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[35.60743367365956,35.52215837276269,35.43688307186582,35.351607770968954,35.266332470072086,35.18105716917521,35.09578186827835,35.010506567381476,34.925231266484616,34.83995596558775,34.75468066469087,34.669405363794006,34.58413006289714,34.49885476200027,34.4135794611034,34.328304160206535,34.24302885930967,34.1577535584128,34.0737828150401,33.99633478954725,33.91888676405438,33.84143873856152,33.763990713068665,33.6865426875758,33.60909466208294,33.53164663659008,33.45419861109722,33.37675058560436,33.2993025601115,33.22185453461864,33.14440650912578,33.066958483632924,32.98951045814006,32.9120624326472,32.83461440715434,32.75716638166148,32.67971835616862,32.60227033067576,32.524822305182894,32.44737427969004,32.36992625419718,32.29247822870432,32.215030203211455,32.1375821777186,32.06013415222574,31.98268612673288,31.90523810124002,31.827790075747156,31.7503420502543,31.67289402476144,31.595445999268577,31.517997973775714,31.440549948282857,31.363101922789998,31.285653897297138,31.208205871804275,31.130757846311415,31.053309820818555,30.975861795325695,30.898413769832835,30.820965744339976,30.74351771884711,30.666069693354252,30.588621667861396,30.511173642368533,30.433725616875673,30.356277591382817,30.278829565889954,30.201381540397094,30.123933514904234,30.04648548941137,29.969037463918514,29.891589438425655,29.814141412932795,29.73669338743993,29.659245361947068,29.581797336454212,29.504349310961352,29.426901285468492,29.34945325997563,29.27200523448277,29.194557208989913,29.11710918349705,29.03966115800419,28.84971081222826,28.637260002395703,28.424809192563163,28.212358382730613,27.999907572898067,27.787456763065528,27.57500595323298,27.362555143400435,27.15010433356789,26.937653523735342,26.725202713902807,26.512751904070257,26.30030109423771,26.08785028440516,25.875399474572617,25.662948664740078,25.450497854907532,25.238046997166325,24.99333446564266,24.748621934118994,24.50390940259534,24.259196871071673,24.014484339548005,23.769771808024352,23.525059276500674,23.280346744977017,23.035634213453353,22.79092168192969,22.546209150406032,22.301496618882354,22.0567840873587,21.812071555835036,21.567359024311372,21.32264649278772,21.07793396126405,20.833221429740384,20.58850889821672,20.343796366693056,20.0990838351694,19.854371303645735,19.609658772122067,19.364946240598414,19.120233709074736,18.87552117755108,18.630808646027415,18.386096114503747,18.141383582980094,17.896671051456416,17.651958519932762,17.407245988409095,17.16253345688543,16.917820925361774,16.67310839383811,16.428395862314442,16.183683330790778,15.93897079926711,15.694258267743457,15.44954573621979,15.204833204696126,14.96012067317247,14.715408141648794,14.470695610125137,14.225983078601473,13.981270547077806,13.736558015554152,13.491845484030478,13.24713295250682,13.002420420983155,12.757707889459489,12.512995357935836,12.268282826412158,12.023570294888504,11.778857763364838,11.534145231841173,11.289432700317517,11.04472016879385,10.800007637270186,10.55529510574652,10.310582574222853,10.0658700426992,9.821157511175532,9.576444979651868,9.331732448128212,9.175410073946,9.063282778434532,8.951155482923058,8.839028187411586,8.726900891900117,8.618229420322928,8.525040046738631,8.43185067315433,8.338661299570031,8.245471925985735,8.152282552401429,8.060883553659309,7.978436429127952,7.895989304596594,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[35.05508849678043,34.96981319588355,34.884537894986686,34.799262594089825,34.71398729319295,34.62871199229608,34.543436691399215,34.45816139050234,34.37288608960548,34.287610788708605,34.20233548781174,34.11706018691487,34.031784886018,33.946509585121134,33.86123428422427,33.7759589833274,33.69068368243053,33.605408381533664,33.520133080636796,33.43485777973993,33.349582478843054,33.264307177946186,33.179031877049326,33.09375657615245,33.00848127525558,32.923205974358716,32.83793067346185,32.75265537256498,32.66738007166811,32.582104770771245,32.49682946987437,32.4115541689775,32.326278868080635,32.24100356718377,32.1557282662869,32.075671159324706,31.99822313383185,31.920775108338987,31.843327082846123,31.765879057353263,31.688431031860404,31.610983006367544,31.53353498087468,31.456086955381824,31.378638929888968,31.30119090439611,31.223742878903245,31.14629485341038,31.068846827917525,30.991398802424662,30.913950776931802,30.83650275143894,30.75905472594608,30.681606700453223,30.604158674960367,30.526710649467503,30.44926262397464,30.371814598481777,30.29436657298892,30.216918547496057,30.1394705220032,30.062022496510338,29.98457447101748,29.907126445524625,29.82967842003176,29.7522303945389,29.674782369046042,29.59733434355318,29.51988631806032,29.44243829256746,29.364990267074596,29.28754224158174,29.21009421608888,29.13264619059602,29.055198165103157,28.977750139610293,28.900302114117437,28.822854088624577,28.745406063131718,28.667958037638854,28.590510012145998,28.513061986653135,28.43561396116028,28.358165935667415,28.16821558989149,27.95576478005893,27.743313970226396,27.530863160393846,27.318412350561296,27.105961540728764,26.893510730896217,26.681059921063667,26.46860911123112,26.25615830139857,26.04370749156604,25.831256681733485,25.618805871900946,25.406355062068393,25.19390425223585,24.98145344240331,24.769002632570764,24.556551822738218,24.34410101290567,24.13165020307312,23.919199393240582,23.706748583408036,23.49429777357549,23.28184696374295,23.069396153910393,22.856945344077857,22.644494534245307,22.43204372441276,22.219592914580222,22.007142104747665,21.79469129491513,21.58224048508258,21.369789675250033,21.157338865417497,20.928757152153924,20.684044620630253,20.439332089106593,20.194619557582925,19.949907026059268,19.705194494535604,19.460481963011937,19.215769431488283,18.971056899964605,18.72634436844095,18.481631836917288,18.23691930539362,17.992206773869967,17.74749424234629,17.50278171082263,17.25806917929897,17.0133566477753,16.768644116251647,16.523931584727983,16.279219053204315,16.034506521680655,15.789793990156982,15.545081458633328,15.300368927109666,15.055656395585995,14.810943864062342,14.566231332538663,14.32151880101501,14.076806269491348,13.832093737967678,13.587381206444023,13.34266867492035,13.097956143396697,12.853243611873028,12.608531080349366,12.363818548825709,12.119106017302034,11.874393485778379,11.62968095425471,11.384968422731047,11.140255891207392,10.895543359683723,10.650830828160059,10.406118296636393,10.161405765112729,9.916693233589072,9.671980702065405,9.42726817054174,9.182555639018087,9.026233264835875,8.914105969324407,8.80197867381293,8.689851378301459,8.588471697809256,8.495282324224952,8.402092950640656,8.308903577056356,8.215714203472055,8.122524829887759,8.034109789215892,7.951662664684542,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[34.502743319901334,34.41746801900447,34.33219271810759,34.246917417210724,34.16164211631386,34.07636681541699,33.99109151452012,33.905816213623254,33.82054091272638,33.73526561182951,33.649990310932644,33.564715010035776,33.47943970913891,33.39416440824205,33.30888910734517,33.223613806448306,33.13833850555144,33.05306320465457,32.9677879037577,32.88251260286083,32.79723730196396,32.7119620010671,32.626686700170225,32.54141139927336,32.45613609837649,32.37086079747962,32.285585496582755,32.20031019568589,32.11503489478902,32.02975959389215,31.944484292995284,31.859208992098417,31.77393369120154,31.68865839030468,31.603383089407806,31.51810778851094,31.43283248761407,31.347557186717204,31.262281885820336,31.17700658492346,31.091731284026597,31.006455983129733,30.921180682232865,30.835905381335994,30.75063008043913,30.665354779542255,30.580079478645388,30.49480417774852,30.409528876851653,30.324253575954785,30.238978275057914,30.155007529102225,30.077559503609365,30.00011147811651,29.922663452623645,29.845215427130782,29.767767401637922,29.69031937614506,29.612871350652203,29.535423325159343,29.457975299666487,29.380527274173623,29.30307924868076,29.225631223187904,29.14818319769504,29.07073517220218,28.99328714670932,28.915839121216464,28.8383910957236,28.760943070230738,28.68349504473788,28.606047019245025,28.528598993752162,28.4511509682593,28.37370294276644,28.29625491727358,28.218806891780723,28.14135886628786,28.063910840794996,27.98646281530214,27.909014789809277,27.83156676431642,27.754118738823557,27.6766707133307,27.486720367554767,27.274269557722214,27.061818747889674,26.849367938057128,26.636917128224578,26.424466318392042,26.212015508559496,25.999564698726946,25.7871138888944,25.57466307906185,25.362212269229317,25.149761459396768,24.937310649564225,24.72485983973167,24.51240902989913,24.299958220066593,24.087507410234043,23.875056600401493,23.662605790568946,23.4501549807364,23.23770417090386,23.025253361071314,22.812802551238768,22.600351741406232,22.38790093157367,22.175450121741136,21.96299931190859,21.750548502076043,21.538097692243504,21.325646882410947,21.113196072578408,20.90074526274586,20.68829445291331,20.475843643080776,20.263392833248233,20.05094202341568,19.83849121358314,19.626040403750586,19.413589593918047,19.201138784085504,18.988687974252954,18.77623716442042,18.56378635458786,18.351335544755322,18.138884734922776,17.92643392509023,17.71398311525769,17.501532305425137,17.289081495592598,17.07663068576005,16.864179838665187,16.619467307141534,16.374754775617866,16.1300422440942,15.885329712570535,15.640617181046869,15.395904649523214,15.151192117999548,14.906479586475882,14.661767054952229,14.41705452342855,14.172341991904895,13.92762946038123,13.682916928857566,13.438204397333909,13.193491865810234,12.94877933428658,12.704066802762913,12.459354271239247,12.214641739715592,11.969929208191916,11.72521667666826,11.480504145144597,11.235791613620929,10.991079082097276,10.74636655057361,10.501654019049942,10.256941487526277,10.01222895600261,9.767516424478956,9.522803892955292,9.278091361431624,9.03337882990797,8.877056455725759,8.764929160214292,8.652801864702816,8.558713975295587,8.46552460171129,8.372335228126985,8.27914585454269,8.185956480958389,8.092767107374089,8.007336024772496,7.924888900241132,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[33.9503981430222,33.86512284212533,33.779847541228456,33.69457224033159,33.60929693943472,33.52402163853785,33.438746337640985,33.35347103674412,33.26819573584725,33.182920434950375,33.09764513405351,33.01236983315664,32.92709453225977,32.841819231362905,32.756543930466044,32.67126862956917,32.5859933286723,32.500718027775434,32.41544272687857,32.3301674259817,32.24489212508483,32.15961682418796,32.07434152329109,31.98906622239422,31.903790921497354,31.81851562060049,31.733240319703622,31.647965018806747,31.562689717909883,31.477414417013016,31.392139116116148,31.30686381521928,31.221588514322406,31.136313213425545,31.05103791252867,30.965762611631803,30.88048731073494,30.795212009838068,30.7099367089412,30.624661408044332,30.53938610714746,30.454110806250597,30.36883550535373,30.283560204456858,30.198284903559994,30.11300960266312,30.02773430176625,29.942459000869384,29.857183699972516,29.77190839907565,29.68663309817878,29.601357797281914,29.51608249638504,29.430807195488175,29.34553189459131,29.260256593694436,29.174981292797572,29.0897059919007,29.004430691003833,28.91915539010697,28.833880089210098,28.74860478831323,28.66332948741636,28.57805418651949,28.492778885622624,28.407503584725752,28.32222828382889,28.23695298293202,28.15689587338683,28.07944784789397,28.00199982240111,27.924551796908254,27.84710377141539,27.769655745922528,27.692207720429668,27.614759694936808,27.53731166944395,27.45986364395109,27.38241561845823,27.30496759296537,27.227519567472505,27.15007154197965,27.072623516486786,26.99517549099393,26.805225145217996,26.59277433538544,26.3803235255529,26.167872715720353,25.955421905887807,25.74297109605527,25.530520286222725,25.318069476390175,25.10561866655763,24.893167856725082,24.680717046892546,24.468266237059993,24.25581542722745,24.0433646173949,23.830913807562354,23.618462997729818,23.40601218789727,23.193561378064725,22.981110568232175,22.76865975839963,22.55620894856709,22.343758138734543,22.131307328901997,21.918856519069458,21.7064057092369,21.493954899404365,21.281504089571815,21.06905327973927,20.856602469906733,20.644151660074176,20.431700850241636,20.21925004040909,20.00679923057654,19.794348420744004,19.581897610911458,19.36944680107891,19.156995991246365,18.944545181413815,18.732094371581276,18.519643561748733,18.307192751916183,18.094741942083648,17.88229113225109,17.66984032241855,17.457389512586005,17.24493870275346,17.03248789292092,16.820037083088362,16.607586273255826,16.39513546342328,16.18268465359073,15.97023384375819,15.757783033925644,15.545332224093098,15.332881414260552,15.120430604428005,14.907979794595466,14.69552898476292,14.483078174930373,14.270627365097834,14.058176555265277,13.845725745432738,13.633274935600191,13.420824125767645,13.208373315935107,12.995922506102552,12.783471696270015,12.554889993652786,12.31017746212912,12.065464930605465,11.820752399081789,11.576039867558134,11.331327336034468,11.086614804510802,10.841902272987149,10.597189741463481,10.352477209939815,10.10776467841615,9.863052146892484,9.618339615368829,9.373627083845165,9.128914552321497,8.884202020797844,8.727879646615632,8.622145626366212,8.528956252781912,8.435766879197612,8.342577505613313,8.249388132029011,8.156198758444715,8.063009384860415,7.980562260329077,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[33.39607847813353,33.307233066534806,33.221957765637946,33.13668246474107,33.05140716384421,32.966131862947336,32.88085656205047,32.7955812611536,32.71030596025673,32.625030659359865,32.539755358463,32.45448005756613,32.369204756669255,32.283929455772395,32.19865415487553,32.11337885397865,32.028103553081785,31.942828252184917,31.857552951288046,31.772277650391178,31.68700234949431,31.60172704859744,31.516451747700575,31.431176446803704,31.345901145906833,31.26062584500997,31.1753505441131,31.090075243216234,31.004799942319362,30.919524641422495,30.834249340525627,30.74897403962876,30.663698738731892,30.578423437835024,30.493148136938153,30.40787283604128,30.322597535144418,30.237322234247547,30.15204693335068,30.06677163245381,29.981496331556944,29.896221030660076,29.81094572976321,29.725670428866334,29.640395127969473,29.555119827072605,29.469844526175734,29.384569225278863,29.299293924382003,29.21401862348513,29.128743322588264,29.043468021691396,28.958192720794525,28.87291741989766,28.787642119000793,28.70236681810392,28.617091517207054,28.53181621631018,28.44654091541332,28.361265614516448,28.275990313619577,28.19071501272271,28.10543971182584,28.020164410928974,27.934889110032106,27.84961380913524,27.76433850823837,27.6790632073415,27.593787906444632,27.50851260554776,27.423237304650893,27.33796200375403,27.25268670285716,27.16741140196029,27.082136101063423,26.996860800166555,26.911585499269687,26.82631019837282,26.74103489747595,26.655759596579077,26.57048429568221,26.485208994785346,26.399933693888475,26.314658392991607,26.12340350131501,25.910952691482457,25.698501881649918,25.48605107181737,25.273600261984825,25.061149452152286,24.848698642319743,24.636247832487193,24.423797022654647,24.2113462128221,23.99889540298956,23.78644459315701,23.573993783324465,23.361542973491918,23.14909216365937,22.936641353826833,22.724190543994283,22.511739734161736,22.29928892432919,22.08683811449664,21.874387304664108,21.661936494831558,21.44948568499901,21.237034875166472,21.024584065333915,20.812133255501376,20.59968244566883,20.387231635836283,20.174780826003744,19.962330016171187,19.74987920633865,19.5374283965061,19.32497758667356,19.11252677684102,18.900075967008473,18.687625157175926,18.47517434734338,18.26272353751083,18.050272727678294,17.837821917845744,17.625371108013198,17.412920298180662,17.2004694883481,16.988018678515566,16.77556786868302,16.56311705885047,16.350666249017934,16.138215439185377,15.92576462935284,15.713313819520295,15.500863009687746,15.288412199855207,15.07596139002266,14.863510580190114,14.651059770357564,14.438608960525018,14.226158150692482,14.013707340859934,13.801256531027386,13.58880572119485,13.376354911362293,13.163904101529754,12.951453291697208,12.73900248186466,12.526551672032122,12.314100862199568,12.10165005236703,11.889199242534483,11.676748432701935,11.464297622869397,11.25184681303684,11.039396003204303,10.826945193371754,10.614494383539208,10.402043573706669,10.189592763874122,9.977141954041576,9.764691144209028,9.55224033437648,9.339789524543942,9.127338714711394,8.91488790487885,8.713884078117252,8.592387903852542,8.499198530268245,8.406009156683945,8.312819783099645,8.21963040951535,8.126441035931045,8.036235620417033,7.953788495885675,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[32.79486466205371,32.704234188477024,32.61360371490034,32.52297324132366,32.432342767746974,32.34171229417029,32.25108182059361,32.160451347016924,32.06982087344025,31.979190399863562,31.888559926286877,31.7979294527102,31.707298979133512,31.61666850555683,31.52603803198015,31.435407558403462,31.34477708482678,31.2541466112501,31.16797878510768,31.082703484210814,30.997428183313946,30.912152882417075,30.82687758152021,30.741602280623344,30.65632697972647,30.571051678829605,30.485776377932737,30.40050107703587,30.315225776139,30.22995047524213,30.144675174345263,30.059399873448395,29.974124572551528,29.88884927165466,29.80357397075779,29.71829866986092,29.633023368964054,29.547748068067182,29.462472767170315,29.377197466273447,29.29192216537658,29.206646864479712,29.121371563582844,29.036096262685973,28.95082096178911,28.865545660892238,28.78027035999537,28.694995059098495,28.609719758201635,28.524444457304764,28.439169156407893,28.35389385551103,28.268618554614157,28.18334325371729,28.098067952820426,28.012792651923554,27.927517351026687,27.842242050129812,27.75696674923295,27.671691448336084,27.586416147439213,27.501140846542345,27.415865545645474,27.33059024474861,27.245314943851742,27.16003964295487,27.074764342058007,26.98948904116114,26.904213740264268,26.818938439367397,26.73366313847053,26.648387837573665,26.563112536676798,26.477837235779926,26.39256193488306,26.30728663398619,26.222011333089323,26.136736032192456,26.051460731295588,25.966185430398717,25.880910129501846,25.79563482860498,25.71035952770811,25.625084226811243,25.433829335134646,25.22137852530209,25.00892771546955,24.796476905637004,24.584026095804457,24.37157528597192,24.159124476139375,23.946673666306825,23.73422285647428,23.521772046641733,23.309321236809197,23.096870426976643,22.884419617144097,22.67196880731155,22.459517997479004,22.247067187646465,22.03461637781392,21.822165567981372,21.609714758148826,21.39726394831628,21.18481313848374,20.972362328651194,20.759911518818647,20.547460708986108,20.33500989915355,20.122559089321012,19.910108279488465,19.69765746965592,19.48520665982338,19.272755849990823,19.060305040158287,18.847854230325737,18.635403420493194,18.422952610660655,18.210501800828105,17.998050990995562,17.785600181163012,17.573149371330466,17.36069856149793,17.14824775166538,16.935796941832834,16.723346132000298,16.51089532216774,16.2984445123352,16.085993702502655,15.873542892670105,15.66109208283757,15.448641273005013,15.236190463172473,15.023739653339927,14.81128884350738,14.598838033674841,14.386387223842295,14.173936414009749,13.961485604177199,13.749034794344652,13.536583984512117,13.324133174679567,13.11168236484702,12.899231555014484,12.686780745181926,12.474329935349388,12.261879125516842,12.049428315684292,11.836977505851756,11.6245266960192,11.440693392027413,11.262583616401901,11.084473840776392,10.906364065150889,10.728254289525369,10.550144513899868,10.372034738274357,10.193924962648847,10.015815187023343,9.837705411397833,9.659595635772323,9.481485860146813,9.303376084521302,9.125266308895798,8.947156533270288,8.769046757644778,8.590936982019276,8.469440807754566,8.376251434170271,8.283062060585971,8.189872687001671,8.096683313417374,8.009461855973614,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[32.19365084597389,32.10302037239721,32.01238989882052,31.92175942524384,31.83112895166716,31.74049847809048,31.649868004513795,31.55923753093711,31.46860705736043,31.377976583783745,31.28734611020706,31.19671563663038,31.106085163053695,31.015454689477014,30.92482421590033,30.83419374232365,30.743563268746964,30.652932795170287,30.5623023215936,30.471671848016914,30.381041374440233,30.29041090086355,30.199780427286868,30.109149953710183,30.018519480133502,29.927889006556818,29.837258532980137,29.746628059403456,29.655997585826768,29.565367112250087,29.474736638673406,29.384106165096725,29.293475691520037,29.202845217943356,29.11399980457742,29.028724503680554,28.94344920278369,28.85817390188682,28.77289860098995,28.687623300093083,28.602347999196212,28.517072698299344,28.431797397402477,28.346522096505606,28.261246795608745,28.175971494711874,28.090696193815003,28.00542089291813,27.920145592021264,27.8348702911244,27.74959499022753,27.66431968933066,27.579044388433793,27.493769087536926,27.408493786640058,27.323218485743183,27.23794318484632,27.152667883949448,27.067392583052587,26.982117282155716,26.896841981258845,26.811566680361977,26.72629137946511,26.641016078568242,26.555740777671375,26.470465476774507,26.385190175877643,26.29991487498077,26.214639574083904,26.129364273187033,26.044088972290165,25.958813671393298,25.87353837049643,25.788263069599562,25.70298776870269,25.61771246780582,25.532437166908956,25.447161866012088,25.36188656511522,25.27661126421835,25.19133596332148,25.106060662424614,25.020785361527746,24.935510060630875,24.744255168954282,24.531804359121722,24.319353549289186,24.106902739456636,23.89445192962409,23.682001119791554,23.469550309959004,23.257099500126458,23.04464869029391,22.832197880461365,22.619747070628826,22.40729626079628,22.194845450963733,21.982394641131187,21.769943831298637,21.5574930214661,21.345042211633555,21.132591401801008,20.920140591968458,20.707689782135915,20.495238972303376,20.282788162470826,20.07033735263828,19.85788654280574,19.645435732973183,19.432984923140648,19.220534113308098,19.00808330347555,18.795632493643016,18.58318168381046,18.37073087397792,18.158280064145373,17.945829254312827,17.733378444480287,17.52092763464774,17.308476824815195,17.096026014982645,16.883575205150102,16.671124395317563,16.458673585485013,16.246222775652466,16.03377196581993,15.821321155987373,15.608870346154836,15.396419536322288,15.183968726489741,14.971517916657204,14.759067106824647,14.54661629699211,14.345612481563084,14.167502705937572,13.989392930312068,13.81128315468656,13.633173379061049,13.455063603435537,13.276953827810027,13.098844052184525,12.920734276559013,12.742624500933504,12.564514725308001,12.386404949682483,12.20829517405698,12.03018539843147,11.852075622805959,11.673965847180458,11.49585607155494,11.317746295929437,11.139636520303927,10.961526744678416,10.783416969052913,10.605307193427395,10.427197417801892,10.249087642176383,10.070977866550871,9.892868090925369,9.714758315299859,9.536648539674347,9.358538764048838,9.180428988423326,9.002319212797824,8.824209437172314,8.646099661546803,8.467989885921302,8.346493711656592,8.253304338072297,8.160114964487995,8.066925590903695,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[31.59243702989412,31.501806556317433,31.41117608274076,31.32054560916407,31.22991513558739,31.139284662010706,31.04865418843402,30.958023714857337,30.86739324128066,30.776762767703975,30.68613229412729,30.59550182055061,30.504871346973925,30.414240873397244,30.323610399820556,30.23297992624388,30.142349452667197,30.051718979090513,29.96108850551383,29.870458031937144,29.77982755836046,29.689197084783782,29.598566611207097,29.507936137630413,29.41730566405373,29.326675190477047,29.236044716900366,29.14541424332368,29.054783769747,28.964153296170316,28.873522822593635,28.782892349016954,28.692261875440266,28.601631401863585,28.5110009282869,28.420370454710216,28.329739981133535,28.239109507556854,28.14847903398017,28.057848560403485,27.9672180868268,27.876587613250123,27.785957139673435,27.695326666096754,27.604696192520077,27.514065718943385,27.423435245366704,27.332804771790023,27.242174298213342,27.15154382463666,27.060913351059973,26.97474552315035,26.88947022225348,26.80419492135661,26.718919620459744,26.633644319562876,26.54836901866601,26.463093717769134,26.377818416872273,26.292543115975405,26.20726781507853,26.121992514181663,26.036717213284795,25.951441912387928,25.86616661149106,25.780891310594193,25.69561600969733,25.610340708800457,25.52506540790359,25.439790107006722,25.354514806109854,25.269239505212987,25.18396420431612,25.098688903419248,25.01341360252238,24.92813830162551,24.84286300072865,24.757587699831774,24.672312398934906,24.58703709803804,24.50176179714117,24.416486496244303,24.331211195347436,24.245935894450568,24.054681002773965,23.842230192941408,23.629779383108872,23.41732857327633,23.204877763443776,22.99242695361124,22.77997614377869,22.567525333946143,22.355074524113597,22.14262371428105,21.93017290444852,21.71772209461597,21.50527128478342,21.292820474950872,21.080369665118326,20.86791885528579,20.65546804545324,20.443017235620694,20.230566425788147,20.0181156159556,19.805664806123062,19.593213996290512,19.38076318645797,19.16831237662543,18.955861566792873,18.743410756960337,18.530959947127783,18.31850913729524,18.106058327462705,17.893607517630144,17.68115670779761,17.46870589796506,17.256255088132516,17.07242179547326,16.894312019847753,16.71620224422224,16.53809246859673,16.35998269297122,16.181872917345714,16.003763141720206,15.825653366094695,15.647543590469194,15.469433814843676,15.291324039218173,15.113214263592662,14.935104487967152,14.75699471234165,14.578884936716129,14.400775161090628,14.222665385465117,14.044555609839609,13.866445834214105,13.688336058588593,13.510226282963085,13.332116507337574,13.154006731712062,12.97589695608656,12.79778718046105,12.619677404835539,12.441567629210036,12.26345785358452,12.085348077959015,11.907238302333505,11.729128526707996,11.551018751082491,11.372908975456975,11.194799199831472,11.01668942420596,10.83857964858045,10.660469872954948,10.48236009732943,10.304250321703927,10.126140546078418,9.948030770452908,9.769920994827405,9.591811219201894,9.413701443576382,9.235591667950873,9.057481892325361,8.879372116699859,8.701262341074349,8.523152565448838,8.345042789823337,8.223546615558625,8.13035724197433,8.038361451618151,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[30.991223213814305,30.90059274023762,30.80996226666094,30.719331793084255,30.628701319507574,30.53807084593089,30.447440372354208,30.356809898777524,30.26617942520084,30.175548951624158,30.084918478047474,29.99428800447079,29.903657530894108,29.813027057317427,29.72239658374074,29.631766110164058,29.541135636587377,29.450505163010693,29.35987468943401,29.269244215857327,29.178613742280646,29.087983268703965,28.99735279512728,28.906722321550596,28.81609184797391,28.72546137439723,28.63483090082055,28.544200427243865,28.453569953667184,28.3629394800905,28.272309006513815,28.181678532937134,28.09104805936045,28.000417585783765,27.909787112207084,27.8191566386304,27.72852616505372,27.637895691477034,27.547265217900353,27.45663474432367,27.366004270746984,27.275373797170303,27.18474332359362,27.094112850016934,27.003482376440253,26.912851902863572,26.822221429286888,26.731590955710203,26.640960482133526,26.55033000855684,26.45969953498016,26.369069061403472,26.27843858782679,26.18780811425011,26.097177640673426,26.00654716709674,25.91591669352006,25.825286219943372,25.734655746366695,25.64402527279001,25.55339479921333,25.46276432563664,25.37213385205996,25.28150337848328,25.190872904906595,25.10024243132991,25.00961195775323,24.920766542620093,24.835491241723226,24.750215940826354,24.664940639929487,24.579665339032623,24.49439003813575,24.40911473723888,24.323839436342013,24.238564135445145,24.153288834548277,24.06801353365141,23.982738232754542,23.89746293185767,23.812187630960803,23.72691233006394,23.641637029167068,23.5563617282702,23.365106836593604,23.152656026761044,22.940205216928508,22.727754407095958,22.515303597263415,22.302852787430876,22.090401977598326,21.877951167765783,21.66550035793323,21.453049548100683,21.240598738268147,21.028147928435597,20.81569711860305,20.603246308770505,20.390795498937955,20.17834468910542,19.977340885008932,19.79923110938342,19.621121333757912,19.4430115581324,19.264901782506897,19.08679200688139,18.908682231255877,18.730572455630373,18.552462680004854,18.374352904379354,18.196243128753842,18.01813335312833,17.840023577502826,17.66191380187731,17.483804026251807,17.305694250626296,17.127584475000788,16.949474699375287,16.771364923749775,16.593255148124264,16.415145372498756,16.237035596873245,16.05892582124774,15.880816045622232,15.702706269996721,15.524596494371218,15.346486718745698,15.168376943120197,14.990267167494686,14.812157391869174,14.634047616243674,14.455937840618155,14.27782806499265,14.099718289367143,13.921608513741631,13.743498738116127,13.56538896249062,13.387279186865108,13.209169411239596,13.031059635614087,12.852949859988584,12.674840084363073,12.496730308737563,12.31862053311206,12.140510757486542,11.962400981861038,11.784291206235526,11.606181430610015,11.428071654984514,11.249961879358995,11.071852103733494,10.893742328107983,10.715632552482473,10.53752277685697,10.359413001231452,10.18130322560595,10.003193449980438,9.825083674354929,9.646973898729424,9.468864123103916,9.290754347478405,9.112644571852893,8.934534796227384,8.756425020601881,8.57831524497637,8.40020546935086,8.222095693725358,8.100599519460651,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null],[30.390009397734485,30.2993789241578,30.20874845058112,30.118117977004434,30.027487503427754,29.936857029851073,29.846226556274388,29.755596082697704,29.66496560912102,29.574335135544338,29.483704661967653,29.39307418839097,29.302443714814288,29.211813241237607,29.12118276766092,29.030552294084238,28.939921820507557,28.849291346930876,28.75866087335419,28.668030399777507,28.577399926200826,28.486769452624145,28.39613897904746,28.305508505470776,28.214878031894095,28.12424755831741,28.03361708474073,27.942986611164045,27.852356137587364,27.76172566401068,27.671095190433995,27.580464716857314,27.48983424328063,27.399203769703945,27.308573296127264,27.21794282255058,27.1273123489739,27.036681875397214,26.946051401820533,26.85542092824385,26.764790454667168,26.674159981090483,26.583529507513802,26.492899033937114,26.402268560360437,26.311638086783752,26.22100761320707,26.130377139630383,26.039746666053702,25.94911619247702,25.858485718900333,25.767855245323656,25.67722477174697,25.58659429817029,25.49596382459361,25.40533335101692,25.31470287744024,25.224072403863552,25.13344193028687,25.042811456710194,24.95218098313351,24.861550509556825,24.770920035980136,24.68028956240346,24.589659088826778,24.499028615250094,24.408398141673413,24.317767668096728,24.227137194520047,24.136506720943363,24.045876247366678,23.955245773789997,23.864615300213316,23.77398482663663,23.683354353059947,23.592723879483263,23.50209340590658,23.411462932329897,23.320832458753216,23.23020198517653,23.139571511599847,23.048941038023166,22.958310564446485,22.8676800908698,22.7041501989191,22.52604042329358,22.347930647668075,22.169820872042568,21.991711096417056,21.813601320791555,21.635491545166044,21.457381769540532,21.27927199391502,21.10116221828951,20.923052442664012,20.744942667038497,20.56683289141299,20.388723115787474,20.210613340161967,20.032503564536466,19.854393788910954,19.676284013285443,19.498174237659935,19.320064462034424,19.141954686408923,18.96384491078341,18.7857351351579,18.6076253595324,18.429515583906877,18.251405808281376,18.073296032655865,17.895186257030357,17.717076481404852,17.538966705779334,17.360856930153833,17.18274715452832,17.00463737890281,16.82652760327731,16.6484178276518,16.470308052026287,16.29219827640078,16.114088500775264,15.935978725149763,15.757868949524257,15.579759173898744,15.401649398273243,15.223539622647724,15.04542984702222,14.867320071396712,14.6892102957712,14.511100520145696,14.33299074452018,14.154880968894677,13.976771193269167,13.798661417643656,13.620551642018153,13.442441866392642,13.264332090767132,13.086222315141622,12.908112539516111,12.730002763890607,12.551892988265099,12.373783212639587,12.195673437014085,12.017563661388566,11.839453885763064,11.661344110137552,11.483234334512042,11.30512455888654,11.127014783261023,10.94890500763552,10.770795232010009,10.5926854563845,10.414575680758997,10.236465905133478,10.058356129507976,9.880246353882466,9.702136578256955,9.524026802631452,9.345917027005942,9.167807251380431,8.989697475754921,8.81158770012941,8.633477924503907,8.455368148878398,8.277258373252886,8.099148597627385,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null,null]]},{\"marker\":{\"color\":\"darkblue\",\"size\":3},\"type\":\"scatter3d\",\"x\":[0.2,0.3,0.4,0.5,0.6,0.7,0.75,0.8],\"y\":[9.33333333,9.1010101,8.63636364,6.71212121,3.06666667,0.95959596,0.49090909,0.17171717],\"z\":[68.01934262042212,71.67361810162683,73.72882962673707,72.72681395594431,53.5014333402316,26.643102863473732,15.700600770453711,7.795904064860669]}],                        {\"autosize\":true,\"margin\":{\"b\":5,\"l\":10,\"r\":20,\"t\":50},\"scene\":{\"xaxis\":{\"title\":{\"text\":\"Mach Number\"}},\"yaxis\":{\"title\":{\"text\":\"Alpha [deg]\"}},\"zaxis\":{\"title\":{\"text\":\"L/D\"}}},\"template\":{\"data\":{\"bar\":[{\"error_x\":{\"color\":\"rgb(36,36,36)\"},\"error_y\":{\"color\":\"rgb(36,36,36)\"},\"marker\":{\"line\":{\"color\":\"white\",\"width\":0.5},\"pattern\":{\"fillmode\":\"overlay\",\"size\":10,\"solidity\":0.2}},\"type\":\"bar\"}],\"barpolar\":[{\"marker\":{\"line\":{\"color\":\"white\",\"width\":0.5},\"pattern\":{\"fillmode\":\"overlay\",\"size\":10,\"solidity\":0.2}},\"type\":\"barpolar\"}],\"carpet\":[{\"aaxis\":{\"endlinecolor\":\"rgb(36,36,36)\",\"gridcolor\":\"white\",\"linecolor\":\"white\",\"minorgridcolor\":\"white\",\"startlinecolor\":\"rgb(36,36,36)\"},\"baxis\":{\"endlinecolor\":\"rgb(36,36,36)\",\"gridcolor\":\"white\",\"linecolor\":\"white\",\"minorgridcolor\":\"white\",\"startlinecolor\":\"rgb(36,36,36)\"},\"type\":\"carpet\"}],\"choropleth\":[{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"},\"type\":\"choropleth\"}],\"contour\":[{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"},\"colorscale\":[[0.0,\"#440154\"],[0.1111111111111111,\"#482878\"],[0.2222222222222222,\"#3e4989\"],[0.3333333333333333,\"#31688e\"],[0.4444444444444444,\"#26828e\"],[0.5555555555555556,\"#1f9e89\"],[0.6666666666666666,\"#35b779\"],[0.7777777777777778,\"#6ece58\"],[0.8888888888888888,\"#b5de2b\"],[1.0,\"#fde725\"]],\"type\":\"contour\"}],\"contourcarpet\":[{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"},\"type\":\"contourcarpet\"}],\"heatmap\":[{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"},\"colorscale\":[[0.0,\"#440154\"],[0.1111111111111111,\"#482878\"],[0.2222222222222222,\"#3e4989\"],[0.3333333333333333,\"#31688e\"],[0.4444444444444444,\"#26828e\"],[0.5555555555555556,\"#1f9e89\"],[0.6666666666666666,\"#35b779\"],[0.7777777777777778,\"#6ece58\"],[0.8888888888888888,\"#b5de2b\"],[1.0,\"#fde725\"]],\"type\":\"heatmap\"}],\"heatmapgl\":[{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"},\"colorscale\":[[0.0,\"#440154\"],[0.1111111111111111,\"#482878\"],[0.2222222222222222,\"#3e4989\"],[0.3333333333333333,\"#31688e\"],[0.4444444444444444,\"#26828e\"],[0.5555555555555556,\"#1f9e89\"],[0.6666666666666666,\"#35b779\"],[0.7777777777777778,\"#6ece58\"],[0.8888888888888888,\"#b5de2b\"],[1.0,\"#fde725\"]],\"type\":\"heatmapgl\"}],\"histogram\":[{\"marker\":{\"line\":{\"color\":\"white\",\"width\":0.6}},\"type\":\"histogram\"}],\"histogram2d\":[{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"},\"colorscale\":[[0.0,\"#440154\"],[0.1111111111111111,\"#482878\"],[0.2222222222222222,\"#3e4989\"],[0.3333333333333333,\"#31688e\"],[0.4444444444444444,\"#26828e\"],[0.5555555555555556,\"#1f9e89\"],[0.6666666666666666,\"#35b779\"],[0.7777777777777778,\"#6ece58\"],[0.8888888888888888,\"#b5de2b\"],[1.0,\"#fde725\"]],\"type\":\"histogram2d\"}],\"histogram2dcontour\":[{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"},\"colorscale\":[[0.0,\"#440154\"],[0.1111111111111111,\"#482878\"],[0.2222222222222222,\"#3e4989\"],[0.3333333333333333,\"#31688e\"],[0.4444444444444444,\"#26828e\"],[0.5555555555555556,\"#1f9e89\"],[0.6666666666666666,\"#35b779\"],[0.7777777777777778,\"#6ece58\"],[0.8888888888888888,\"#b5de2b\"],[1.0,\"#fde725\"]],\"type\":\"histogram2dcontour\"}],\"mesh3d\":[{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"},\"type\":\"mesh3d\"}],\"parcoords\":[{\"line\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"type\":\"parcoords\"}],\"pie\":[{\"automargin\":true,\"type\":\"pie\"}],\"scatter\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"type\":\"scatter\"}],\"scatter3d\":[{\"line\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"marker\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"type\":\"scatter3d\"}],\"scattercarpet\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"type\":\"scattercarpet\"}],\"scattergeo\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"type\":\"scattergeo\"}],\"scattergl\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"type\":\"scattergl\"}],\"scattermapbox\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"type\":\"scattermapbox\"}],\"scatterpolar\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"type\":\"scatterpolar\"}],\"scatterpolargl\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"type\":\"scatterpolargl\"}],\"scatterternary\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"type\":\"scatterternary\"}],\"surface\":[{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"},\"colorscale\":[[0.0,\"#440154\"],[0.1111111111111111,\"#482878\"],[0.2222222222222222,\"#3e4989\"],[0.3333333333333333,\"#31688e\"],[0.4444444444444444,\"#26828e\"],[0.5555555555555556,\"#1f9e89\"],[0.6666666666666666,\"#35b779\"],[0.7777777777777778,\"#6ece58\"],[0.8888888888888888,\"#b5de2b\"],[1.0,\"#fde725\"]],\"type\":\"surface\"}],\"table\":[{\"cells\":{\"fill\":{\"color\":\"rgb(237,237,237)\"},\"line\":{\"color\":\"white\"}},\"header\":{\"fill\":{\"color\":\"rgb(217,217,217)\"},\"line\":{\"color\":\"white\"}},\"type\":\"table\"}]},\"layout\":{\"annotationdefaults\":{\"arrowhead\":0,\"arrowwidth\":1},\"autotypenumbers\":\"strict\",\"coloraxis\":{\"colorbar\":{\"outlinewidth\":1,\"tickcolor\":\"rgb(36,36,36)\",\"ticks\":\"outside\"}},\"colorscale\":{\"diverging\":[[0.0,\"rgb(103,0,31)\"],[0.1,\"rgb(178,24,43)\"],[0.2,\"rgb(214,96,77)\"],[0.3,\"rgb(244,165,130)\"],[0.4,\"rgb(253,219,199)\"],[0.5,\"rgb(247,247,247)\"],[0.6,\"rgb(209,229,240)\"],[0.7,\"rgb(146,197,222)\"],[0.8,\"rgb(67,147,195)\"],[0.9,\"rgb(33,102,172)\"],[1.0,\"rgb(5,48,97)\"]],\"sequential\":[[0.0,\"#440154\"],[0.1111111111111111,\"#482878\"],[0.2222222222222222,\"#3e4989\"],[0.3333333333333333,\"#31688e\"],[0.4444444444444444,\"#26828e\"],[0.5555555555555556,\"#1f9e89\"],[0.6666666666666666,\"#35b779\"],[0.7777777777777778,\"#6ece58\"],[0.8888888888888888,\"#b5de2b\"],[1.0,\"#fde725\"]],\"sequentialminus\":[[0.0,\"#440154\"],[0.1111111111111111,\"#482878\"],[0.2222222222222222,\"#3e4989\"],[0.3333333333333333,\"#31688e\"],[0.4444444444444444,\"#26828e\"],[0.5555555555555556,\"#1f9e89\"],[0.6666666666666666,\"#35b779\"],[0.7777777777777778,\"#6ece58\"],[0.8888888888888888,\"#b5de2b\"],[1.0,\"#fde725\"]]},\"colorway\":[\"#1F77B4\",\"#FF7F0E\",\"#2CA02C\",\"#D62728\",\"#9467BD\",\"#8C564B\",\"#E377C2\",\"#7F7F7F\",\"#BCBD22\",\"#17BECF\"],\"font\":{\"color\":\"rgb(36,36,36)\"},\"geo\":{\"bgcolor\":\"white\",\"lakecolor\":\"white\",\"landcolor\":\"white\",\"showlakes\":true,\"showland\":true,\"subunitcolor\":\"white\"},\"hoverlabel\":{\"align\":\"left\"},\"hovermode\":\"closest\",\"mapbox\":{\"style\":\"light\"},\"paper_bgcolor\":\"white\",\"plot_bgcolor\":\"white\",\"polar\":{\"angularaxis\":{\"gridcolor\":\"rgb(232,232,232)\",\"linecolor\":\"rgb(36,36,36)\",\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\"},\"bgcolor\":\"white\",\"radialaxis\":{\"gridcolor\":\"rgb(232,232,232)\",\"linecolor\":\"rgb(36,36,36)\",\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\"}},\"scene\":{\"xaxis\":{\"backgroundcolor\":\"white\",\"gridcolor\":\"rgb(232,232,232)\",\"gridwidth\":2,\"linecolor\":\"rgb(36,36,36)\",\"showbackground\":true,\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\",\"zeroline\":false,\"zerolinecolor\":\"rgb(36,36,36)\"},\"yaxis\":{\"backgroundcolor\":\"white\",\"gridcolor\":\"rgb(232,232,232)\",\"gridwidth\":2,\"linecolor\":\"rgb(36,36,36)\",\"showbackground\":true,\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\",\"zeroline\":false,\"zerolinecolor\":\"rgb(36,36,36)\"},\"zaxis\":{\"backgroundcolor\":\"white\",\"gridcolor\":\"rgb(232,232,232)\",\"gridwidth\":2,\"linecolor\":\"rgb(36,36,36)\",\"showbackground\":true,\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\",\"zeroline\":false,\"zerolinecolor\":\"rgb(36,36,36)\"}},\"shapedefaults\":{\"fillcolor\":\"black\",\"line\":{\"width\":0},\"opacity\":0.3},\"ternary\":{\"aaxis\":{\"gridcolor\":\"rgb(232,232,232)\",\"linecolor\":\"rgb(36,36,36)\",\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\"},\"baxis\":{\"gridcolor\":\"rgb(232,232,232)\",\"linecolor\":\"rgb(36,36,36)\",\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\"},\"bgcolor\":\"white\",\"caxis\":{\"gridcolor\":\"rgb(232,232,232)\",\"linecolor\":\"rgb(36,36,36)\",\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\"}},\"title\":{\"x\":0.05},\"xaxis\":{\"automargin\":true,\"gridcolor\":\"rgb(232,232,232)\",\"linecolor\":\"rgb(36,36,36)\",\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\",\"title\":{\"standoff\":15},\"zeroline\":false,\"zerolinecolor\":\"rgb(36,36,36)\"},\"yaxis\":{\"automargin\":true,\"gridcolor\":\"rgb(232,232,232)\",\"linecolor\":\"rgb(36,36,36)\",\"showgrid\":false,\"showline\":true,\"ticks\":\"outside\",\"title\":{\"standoff\":15},\"zeroline\":false,\"zerolinecolor\":\"rgb(36,36,36)\"}}},\"title\":{\"text\":\"NACA23012\"},\"width\":700},                        {\"responsive\": true}                    ).then(function(){\n",
       "                            \n",
       "var gd = document.getElementById('c51ae7e6-0857-465a-9c98-1ba2bd53fd0f');\n",
       "var x = new MutationObserver(function (mutations, observer) {{\n",
       "        var display = window.getComputedStyle(gd).display;\n",
       "        if (!display || display === 'none') {{\n",
       "            console.log([gd, 'removed!']);\n",
       "            Plotly.purge(gd);\n",
       "            observer.disconnect();\n",
       "        }}\n",
       "}});\n",
       "\n",
       "// Listen for the removal of the full notebook cells\n",
       "var notebookContainer = gd.closest('#notebook-container');\n",
       "if (notebookContainer) {{\n",
       "    x.observe(notebookContainer, {childList: true});\n",
       "}}\n",
       "\n",
       "// Listen for the clearing of the current output cell\n",
       "var outputEl = gd.closest('.output');\n",
       "if (outputEl) {{\n",
       "    x.observe(outputEl, {childList: true});\n",
       "}}\n",
       "\n",
       "                        })                };                });            </script>        </div>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "import pandas as pd\n",
    "import glob\n",
    "import os\n",
    "import plotly.graph_objects as go\n",
    "import plotly\n",
    "import numpy as np\n",
    "from scipy.interpolate import griddata\n",
    "\n",
    "import plotly.express as px\n",
    "import math\n",
    "\n",
    "\n",
    "path = f\"MCC0.00/\"\n",
    "all_files = glob.glob(path +\"**/00_coeff00.dat\")\n",
    "#all_files = glob.glob(path + \"/**/**/*.dat\")\n",
    "li = [pd.read_csv(filename, index_col=None, header=0, sep='\\s+') for filename in all_files]\n",
    "df = pd.concat(li , axis=0, ignore_index=True)\n",
    "\n",
    "col_names = {'MACH':'mach', 'ALPHA':'alpha', 'C-lift':'c_lift','C-drag':'c_drag', 'C-my':'c_my'}\n",
    "df.rename(columns=col_names, inplace=True)\n",
    "df['l_over_d'] = df['c_lift']/df['c_drag']\n",
    "pd.set_option('display.max_columns', None)\n",
    "pd.set_option('display.max_rows', None)\n",
    "pd.set_option('display.max_colwidth', None)\n",
    "\n",
    "S = 100\n",
    "N = int(len(df)/S)\n",
    "frames = [ df.iloc[i*S:(i+1)*S].copy() for i in range(N)]\n",
    "df_new=pd.DataFrame()\n",
    "z=[frames[i]['l_over_d'].idxmax() for i in range(len(frames))]\n",
    "df_2 = df.iloc[df.index.isin(z)]\n",
    "df_2 = df_2.sort_values(by=['mach'])\n",
    "\n",
    "xi = np.linspace(min(df['mach']), max(df['mach']), num=500)\n",
    "yi = np.linspace(min(df['alpha']), max(df['alpha']), num=500)\n",
    "x_grid, y_grid = np.meshgrid(xi,yi)\n",
    "z_grid = griddata((df['mach'],df['alpha']),df['l_over_d'],(x_grid,y_grid),method='linear')\n",
    "fig_line = go.Scatter3d(x=df_2['mach'], y=df_2['alpha'], z=df_2['l_over_d'], marker=dict(\n",
    "        size=3,\n",
    "        color=\"darkblue\"\n",
    "    ))\n",
    "fig = go.Figure(data=[go.Surface(x=x_grid,y=y_grid,z=z_grid,\n",
    "                       colorscale='viridis', opacity=.8),fig_line])\n",
    "fig.update_layout(title='NACA23012', autosize=True,\n",
    "                  margin=dict(l=65, r=50, b=65, t=90))\n",
    "fig.update_layout(scene = dict(\n",
    "                    xaxis_title='Mach Number',\n",
    "                    yaxis_title='Alpha [deg]',\n",
    "                    zaxis_title='L/D'),\n",
    "                    width=700,\n",
    "                    margin=dict(r=20, b=5, l=10, t=50))\n",
    "fig.show()"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "fc54e790",
   "metadata": {
    "slideshow": {
     "slide_type": "skip"
    }
   },
   "source": [
    "### Wind-tunnel measurements"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "14b78753",
   "metadata": {
    "slideshow": {
     "slide_type": "skip"
    }
   },
   "source": [
    "In the wind-tunnel a wing with a constant airfoil cross-section is placed between the walls of a test section. The flow within the wind-tunnel section can be set at various Mach numbers and the wing section can be simultaneously set to different angles of attack to record Cl, Cd and Cm for a sweep of (Mach number,angle of attack) combinations. In case these results are desired for an airfoil section with a trailing-edge flap (TEF), for e.g., then Cl, Cd and Cm are recorded for a sweep of (Mach number,angle of attack, trailing-edge deflection angle) combinations. "
   ]
  }
 ],
 "metadata": {
  "celltoolbar": "Slideshow",
  "hide_input": false,
  "kernelspec": {
   "display_name": "Python 3 (ipykernel)",
   "language": "python",
   "name": "python3"
  },
  "language_info": {
   "codemirror_mode": {
    "name": "ipython",
    "version": 3
   },
   "file_extension": ".py",
   "mimetype": "text/x-python",
   "name": "python",
   "nbconvert_exporter": "python",
   "pygments_lexer": "ipython3",
   "version": "3.8.5"
  },
  "latex_envs": {
   "LaTeX_envs_menu_present": true,
   "autoclose": true,
   "autocomplete": true,
   "bibliofile": "biblio.bib",
   "cite_by": "apalike",
   "current_citInitial": 1,
   "eqLabelWithNumbers": false,
   "eqNumInitial": 1,
   "hotkeys": {
    "equation": "Ctrl-E",
    "itemize": "Ctrl-I"
   },
   "labels_anchors": false,
   "latex_user_defs": false,
   "report_style_numbering": false,
   "user_envs_cfg": false
  },
  "rise": {
   "autolaunch": false,
   "backimage": "../../assets/tum_bg_top_right.png",
   "enable_chalkboard": true,
   "footer": "Sumeet Kumar, PhD candidate",
   "scroll": true
  },
  "varInspector": {
   "cols": {
    "lenName": 16,
    "lenType": 16,
    "lenVar": 40
   },
   "kernels_config": {
    "python": {
     "delete_cmd_postfix": "",
     "delete_cmd_prefix": "del ",
     "library": "var_list.py",
     "varRefreshCmd": "print(var_dic_list())"
    },
    "r": {
     "delete_cmd_postfix": ") ",
     "delete_cmd_prefix": "rm(",
     "library": "var_list.r",
     "varRefreshCmd": "cat(var_dic_list()) "
    }
   },
   "position": {
    "height": "563.848px",
    "left": "1441px",
    "right": "20px",
    "top": "120px",
    "width": "339.004px"
   },
   "types_to_exclude": [
    "module",
    "function",
    "builtin_function_or_method",
    "instance",
    "_Feature"
   ],
   "window_display": false
  }
 },
 "nbformat": 4,
 "nbformat_minor": 5
}
